<xsl:stylesheet version = '1.0'
     xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

<!-- this parameter can be overriden from Ant -->
<xsl:param name="title">Unknown Antlib</xsl:param>

<xsl:template match="/">
<html><head><title><xsl:value-of select="$title" /></title></head>
<body>
<h1><xsl:value-of select="$title" /></h1>
<hr/>

<xsl:apply-templates select="//macrodef|//presetdef" />
</body>
</html>
</xsl:template>

<xsl:template match="macrodef">

<!-- add an anchor to the element name -->
<a><xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute></a>
<h2><xsl:value-of select="@name" /></h2>
<p><xsl:value-of select="@description" /></p>
<!-- if it has any attributes, display the attribute table -->
<xsl:if test="count(./attribute) &gt; 0" >
	<table border="1">
		<tr>
			<th>Attribute</th>
			<th>Description</th>
			<th>Required</th>
		</tr>
		<xsl:apply-templates select="./attribute" />
	</table>
</xsl:if>
<!-- if it has any elements, display them one by one -->
<xsl:if test="count(./element) &gt; 0" >
	<h3>Parameters specified as nested elements</h3>
	<xsl:apply-templates select="./element" />
</xsl:if>
<hr/>
</xsl:template>

<xsl:template match="presetdef">

<!-- add an anchor to the element name -->
<a><xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute></a>
<h2><xsl:value-of select="@name" /></h2>
<p>This task wraps the <xsl:value-of select="name(./child::*)" /> task, providing preset defaults.</p>
<hr/>
</xsl:template>

<xsl:template match="attribute">
	<tr>
		<td><xsl:value-of select="@name" /></td>
		<td><xsl:value-of select="@description" /></td>
		<!--if default is unspecified then Yes, if default is specified then show it, otherwise No -->
		<td><xsl:choose>
			<xsl:when test="@default = &quot;&quot;">No</xsl:when>
			<xsl:when test="@default != &quot;&quot;">No, default is "<xsl:value-of select="@default"/>"</xsl:when>
			<xsl:otherwise>Yes</xsl:otherwise>
		</xsl:choose>
		</td>
	</tr>
</xsl:template>

<xsl:template match="element">
	<h4><xsl:value-of select="@name"/></h4>
	<p><xsl:value-of select="@description"/></p>
</xsl:template>

</xsl:stylesheet>