/*
 * Created on Apr 7, 2003
 */
 
using System;
using com.plumtree.nullnavigation.views;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.nullnavigation
{
  /// <summary>
  /// Absolutely null navigation.  No links displayed whatsoever.  
  /// Topbar view turned off.
  /// </summary>
  /// <author>DavidP</author>
  public class NavNull : INavTypes
  {
    private bool m_bTopBarEnabled = true;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetID()"></seealso>
    public virtual int GetID()
    {
      return NavTypeConstants.NAVTYPE_ID_NULL;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetName(java.lang.String)"></seealso>
    public virtual String GetName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(681, "ptmsgs_portalcommonmsgs", _strLangID);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetScope(java.lang.String)"></seealso>
    public virtual String GetScope(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(682, "ptmsgs_portalcommonmsgs", _strLangID);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#JavaScriptIncludes(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner)
    {
      HTMLScriptCollection result = new HTMLScriptCollection();
      HTMLScript changeGlobalsScript = new HTMLScript("text/javaScript");
      if (!m_bTopBarEnabled)
      {
        changeGlobalsScript.AddInnerHTMLString("gTopBarHeight = 24;");
        result.AddInnerHTMLElement(changeGlobalsScript);
      }
      // Javascript required for nav tabs
      result.AddInnerHTMLElement(NavigationJSPortalMenuHelpers.GetPlumtreeMandatoryTabJavaScript(owner));
      // Override js variables from NavigationSettings.xml
      // Width of each entry in the menus
      int nMenuCellWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTISCDROPDOWNMENU_WIDTH,
       owner);
      if (-1 != nMenuCellWidth)
      {
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
        script.AddInnerHTMLString("\n\tgMenuCellWidth = " + nMenuCellWidth + ";");
        result.AddInnerHTMLElement(script);
      }
      // Override js variables from NavigationSettings.xml
      // Width of the tabs to open dropdown menus
      int nNavTabWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_WIDTH,
       owner);
      if (-1 != nNavTabWidth)
      {
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
        script.AddInnerHTMLString("\n\tgHorizontalTabWidth = " + nNavTabWidth + ";");
        result.AddInnerHTMLElement(script);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#IsFeatureEnabled(com.plumtree.portaluiinfrastructure.navtype.NavFeatureEnum)"></seealso>
    public virtual bool IsFeatureEnabled(NavFeatureEnum feature)
    {
      // turn on topbar view
      if (feature.Equals(NavFeatureEnum.TOPBAR))
      {
        return m_bTopBarEnabled;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetNavAreaView(com.plumtree.portaluiinfrastructure.navtype.NavAreaEnum)"></seealso>
    public virtual String GetNavAreaView(NavAreaEnum area)
    {
      if (area.Equals(NavAreaEnum.ABOVEBANNER))
      {
        return NavigationAdminOnly.STR_MVC_CLASS_NAME;
      } else
      if (area.Equals(NavAreaEnum.TOPBAR))
      {
        return PlumtreeTopBarView.STR_MVC_CLASS_NAME;
      }
      return null;
    }
  }
}