/*
 * Created on Apr 7, 2003
 */
package com.plumtree.nullnavigation;

import com.plumtree.nullnavigation.common.constants.*;
import com.plumtree.nullnavigation.views.*;
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Empty navigation apart from mandatory links only.  Topbar view also turned off.  
 * Headers and footers are displayed.
 * 
 * @author DavidP
 */
public class NavNullPlusMandatoryTabs implements INavTypes 
{
	
	private boolean m_bTopBarEnabled = true;

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetID()
	 */
	public int GetID() 
	{
		return NavTypeConstants.NAVTYPE_ID_NULL_MANDATORY_ONLY;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetName(java.lang.String)
	 */
	public String GetName(String _strLangID) 
	{
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
   		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

		return rm.GetString(678, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetScope(java.lang.String)
	 */
	public String GetScope(String _strLangID) 
	{
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
   		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

		return rm.GetString(679, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#JavaScriptIncludes(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner) 
	{
		HTMLScriptCollection result = new HTMLScriptCollection();
		
		HTMLScript changeGlobalsScript = new HTMLScript("text/javaScript");
		if (!m_bTopBarEnabled)
		{
			changeGlobalsScript.AddInnerHTMLString(
				"gTopBarHeight = 24;" );
			result.AddInnerHTMLElement(changeGlobalsScript);
		}
		// Javascript required for jsportalmenus
		result.AddInnerHTMLElement( NavigationJSPortalMenuHelpers.GetPlumtreeJSFrameworkNoCommunityTabJavaScript(owner) );

		// Override js variables from NavigationSettings.xml
		// Width of each entry in the menus
		int nMenuCellWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTISCDROPDOWNMENU_WIDTH, owner); 
		if ( -1 != nMenuCellWidth )
		{ 
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value"); 
			script.AddInnerHTMLString("\n\tgMenuCellWidth = "+nMenuCellWidth+";");
			result.AddInnerHTMLElement(script);
		}
		// Override js variables from NavigationSettings.xml
		// Width of the tabs to open dropdown menus
		int nNavTabWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_WIDTH, owner); 
		if ( -1 != nNavTabWidth )
		{ 
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
			script.AddInnerHTMLString("\n\tgHorizontalTabWidth = "+nNavTabWidth+";");
			result.AddInnerHTMLElement(script);
		}

		// Send down localized string down to js for image alts in dynamic generated html
		HTMLScript scriptMenu = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		String imgAlt = owner.GetString(673, ResourceConstants.PORTALCOMMONMSGS);
		scriptMenu.AddInnerHTMLString("var gNavTabDownArrowImageAlt = '"+ imgAlt +"';");
		result.AddInnerHTMLElement(scriptMenu);
		
		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#IsFeatureEnabled(com.plumtree.portaluiinfrastructure.navtype.NavFeatureEnum)
	 */
	public boolean IsFeatureEnabled(NavFeatureEnum feature) 
	{
		// turn on topbar view
		if (feature.equals(NavFeatureEnum.TOPBAR))
			return m_bTopBarEnabled;
			
		// turn on header also
		if (feature.equals(NavFeatureEnum.HEADER))
			return true;		
			
		// leave the footer on
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetNavAreaView(com.plumtree.portaluiinfrastructure.navtype.NavAreaEnum)
	 */
	public String GetNavAreaView(NavAreaEnum area) 
	{
		if (area.equals(NavAreaEnum.ABOVEBANNER))
		{
			return NavigationMandatoryLinksOnly.ObjectName;
		}
		else if (area.equals(NavAreaEnum.TOPBAR))
		{
			return PlumtreeTopBarView.STR_MVC_CLASS_NAME;
		}
			
		return null;
	}
}

