#!/bin/sh
#-----------------------------------------------------------------------------
#
# BEA BID Service Start/Stop Script
# *********** 64 Bit Version ***************
#
# This script exports the following environment variables for use
# by the service wrapper executable:
#
# COMMON_PATH			Absolute path to the common utilities directory
#				/opt/plumtree/common
# APPLICATION_PATH		Absolute path to the versioned application, e.g.
#				/opt/plumtree/ptapplication/3.0
# WRAPPER_PATH			Absolute path to the common service wrapper 
#				home e.g. 
#				/opt/plumtree/common/wrapper/3.2.3
# WRAPPER_NATIVE_LIB_PATH 	Absolute path to the platform-specific service
#				wrapper native library directory, e.g.
#				$WRAPPER_PATH/lib/native/$PLATFORM
#
# BIT_MODE tells Java we should  run the VM in 64 bit mode
#
# Copyright (c) 2002-8 BEA Software, Inc.
# All rights reserved.
#
# This software is the confidential and proprietary information of Plumtree
# Software, Inc. ("Confidential Information").  You shall not disclose such
# Confidential Information and shall use it only in accordance with the terms
# of the license agreement you entered into with Plumtree.
#-----------------------------------------------------------------------------

# Application
APP_NAME="ptportal"
APP_LONG_NAME="Aqualogic Interaction Portal Service"

# Check Unix variant
# IMPORTANT - 64 bit JRE is not supported for products that reference search api libraries.
case "`uname -s`" in
    Darwin)
		PLATFORM="darwin"
		JRE_PATH="jre/1.6.0_64"
                BIT_DEPTH="64"
		;;
    SunOS)
		PLATFORM="solaris"
		BIT_MODE="-d64"
		JRE_PATH="jre/1.6.0_64"
		BIT_DEPTH="64"
		;;
    Linux)
		case "`uname -p`" in
			x86_64)
			  PLATFORM="linux64"
			  JRE_PATH="jre/1.6.0_64"
			  BIT_DEPTH="64"
			  ;;
			*)
			  PLATFORM="linux32"
			  JRE_PATH="jre/1.6.0_32"
			  BIT_DEPTH="32"
			  JVM_6="-Xgc:genpar"
			  ;;
		esac
		#JRocket does not support -d32 parameter
		BIT_MODE=""
		;;
    AIX)
		PLATFORM="aix"
		BIT_MODE="-d64"
		JRE_PATH="jre/1.6.0_64/jre"
		BIT_DEPTH="64"
		;;
	HP-UX)
		PLATFORM="hpux"
		BIT_MODE="-d64"
		JRE_PATH="jre/1.6.0_64"
		BIT_DEPTH="64"
		;;
    *)
        echo "$APP_LONG_NAME is not supported on `uname -s`."; exit 1
    	;;
esac

if [ "${PLATFORM}" = "hpux" ]; then
    case "`uname -m`" in
	ia64)
	    PLATFORM="hpux-ia64"
		;;
	*)
	    ;;
    esac
fi

echo "PLATFORM is $PLATFORM"
echo "BIT_DEPTH is $BIT_DEPTH"
export BIT_MODE

# Priority at which to run the wrapper.  See "man nice" for valid priorities.
#  nice is only used if a priority is specified.
# TODO: This should come from a conf file
PRIORITY=

# Do not modify anything beyond this point
#-----------------------------------------------------------------------------

# Application Home, parent of the directory (bin) containing this script. 
# May be a relative path at this point
WRAPPER_HOMEDIR="`dirname $0`/.."
# Location of wrapper executable relative to the Application Home
WRAPPER_CMD="../../common/wrapper/3.2.3/bin/native/$PLATFORM/wrapper"
# Location of wrapper config file relative to the Application Home
WRAPPER_CONF="./settings/config/ptportal.conf"

# Starting with WRAPPER_HOMEDIR, a relative path to the application home
# directory, turn it into APPLICATION_PATH, an absolute path
case $WRAPPER_HOMEDIR in
    /*)
        HOMEDIR="$WRAPPER_HOMEDIR/."
        ;;
    *)
        PWD=`pwd`
        HOMEDIR="$PWD/$WRAPPER_HOMEDIR/."
        ;;
esac
#echo "Before transformation, HOMEDIR is $HOMEDIR"
# Change spaces to ":" so the tokens can be parsed.
HOMEDIR=`echo $HOMEDIR | sed -e 's; ;:;g'`
# Get the real path to this HOMEDIR, resolving any symbolic links
TOKENS=`echo $HOMEDIR | sed -e 's;/; ;g'`
HOMEREALPATH=
for C in $TOKENS; do
    HOMEREALPATH="$HOMEREALPATH/$C"
    while [ -h "$HOMEREALPATH" ] ; do
        LS="`ls -ld "$HOMEREALPATH"`"
        LINK="`expr "$LS" : '.*-> \(.*\)$'`"
        if expr "$LINK" : '/.*' > /dev/null; then
            HOMEREALPATH="$LINK"
        else
            HOMEREALPATH="`dirname "$HOMEREALPATH"`""/$LINK"
        fi
    done
done
# Change ":" chars back to spaces.
HOMEREALPATH=`echo $HOMEREALPATH | sed -e 's;:; ;g'`
HOMEREALPATH="`dirname "$HOMEREALPATH"`"
#echo "After transformation, HOMEREALPATH is $HOMEREALPATH"

# Plumtree Environment Variables
# These exported variables are used by the service wrapper

APPLICATION_PATH="$HOMEREALPATH"
export APPLICATION_PATH

COMMON_PATH="$HOMEREALPATH/../../common"
export COMMON_PATH

JRE_PATH="$COMMON_PATH/$JRE_PATH"
export JRE_PATH

WRAPPER_PATH="$HOMEREALPATH/../../common/wrapper/3.2.3"
export WRAPPER_PATH

WRAPPER_NATIVE_LIB_PATH="$WRAPPER_PATH/lib/native/$PLATFORM"
export WRAPPER_NATIVE_LIB_PATH

# Get absolute path to the server home directory 
SERVER_HOME_DIR=`cd "$HOMEREALPATH" 2>&-; pwd`
SERVER_HOME_URL="file:"$SERVER_HOME_DIR

#echo "HOMEREALPATH = $HOMEREALPATH"
#echo "SERVER_HOME_DIR = $SERVER_HOME_DIR"

## Change the current directory to the location of the WORKDIR
#cd "`dirname "$REALPATH"`"
#pwd

# Change the current directory to the Application Home
#echo "Current directory is `pwd`"
#echo "WRAPPER_HOMEDIR is $WRAPPER_HOMEDIR"
cd "$WRAPPER_HOMEDIR"
#echo "Current directory is now `pwd`

# Location of the pid file.
PIDDIR=$HOMEDIR

# Process ID
PIDFILE="$PIDDIR/$APP_NAME.pid"
pid=""

# Process ID
STATFILE="$PIDDIR/$APP_NAME.stat"
stat=""

# Resolve the location of the 'ps' command
PSEXE="/usr/bin/ps"
if [ ! -x $PSEXE ]
then
    PSEXE="/bin/ps"
    if [ ! -x $PSEXE ]
    then
        echo "Unable to locate 'ps'."
        echo "Please report this with the location on your system."
        exit 1
    fi
fi

# Build the nice clause
if [ "X$PRIORITY" = "X" ]
then
    CMDNICE=""
else
    CMDNICE="nice -$PRIORITY"
fi


status() {
    getpid
    if [ "X$pid" = "X" ]
    then
        echo "$APP_LONG_NAME"
        echo "Running: No"
        exit 0
    else
        echo "$APP_LONG_NAME" 
        echo "Process ID: ($pid)"
        echo "Running: Yes"
        exit 0
    fi
}

getpid() {
    if [ -f $PIDFILE ]
    then
        if [ -r $PIDFILE ]
        then
            pid=`cat $PIDFILE`
            if [ "X$pid" != "X" ]
            then
                # Verify that a process with this pid is still running.
                pid=`$PSEXE -p $pid | grep $pid | grep -v grep | awk '{print $1}' | tail -1`
                if [ "X$pid" = "X" ]
                then
                    # This is a stale pid file.
                    rm -f $PIDFILE
                    echo "Removed stale pid file: $PIDFILE"
                fi
            fi
        else
            echo "Cannot read $PIDFILE."
            exit 1
        fi
    fi
}

testpid() {
    pid=`$PSEXE -p $pid | grep $pid | grep -v grep | awk '{print $1}' | tail -1`
    if [ "X$pid" = "X" ]
    then
        # Process is gone so remove the pid file.
        rm -f $PIDFILE
    fi
}

console() {
    echo "Running $APP_LONG_NAME..."
    getpid
    if [ "X$pid" = "X" ]
    then
        echo "command.........: "$WRAPPER_CMD
        echo "configuration...: "$WRAPPER_CONF
        echo "platform........: "$PLATFORM
        echo "server home dir.: "$SERVER_HOME_DIR
        echo "server home url.: "$SERVER_HOME_URL
        exec $CMDNICE $WRAPPER_CMD $SERVER_HOME_DIR/$WRAPPER_CONF \
             "set.SERVER_HOME_DIR=`echo $SERVER_HOME_DIR`" \
             "set.SERVER_HOME_URL=`echo $SERVER_HOME_URL`" \
             set.PLATFORM=$PLATFORM \
             set.PROGRAM_NAME=$WRAPPER_PROGRAM \
             wrapper.pidfile=$PIDFILE \
             wrapper.java.statusfile=$STATFILE
    else
        echo "$APP_LONG_NAME is already running."
        exit 1
    fi
}
 
start() {
    echo "Starting $APP_LONG_NAME..."
    getpid
    if [ "X$pid" = "X" ]
    then
        echo "command.........: "$WRAPPER_CMD
        echo "configuration...: "$WRAPPER_CONF
        echo "platform........: "$PLATFORM
        echo "server home.....: "$SERVER_HOME_DIR
        echo "server home URL.: "$SERVER_HOME_URL
        exec $CMDNICE $WRAPPER_CMD $SERVER_HOME_DIR/$WRAPPER_CONF \
             "set.SERVER_HOME_DIR=`echo $SERVER_HOME_DIR`" \
             "set.SERVER_HOME_URL=`echo $SERVER_HOME_URL`" \
             set.PLATFORM=$PLATFORM \
             set.PROGRAM_NAME=$WRAPPER_PROGRAM \
             wrapper.pidfile=$PIDFILE \
             wrapper.java.statusfile=$STATFILE \
             wrapper.daemonize=TRUE
    else
        echo "$APP_LONG_NAME is already running."
        exit 1
    fi
}
 
stopit() {
    echo "Stopping $APP_LONG_NAME..."
    getpid
    if [ "X$pid" = "X" ]
    then
        echo "$APP_LONG_NAME was not running."
    else
         # Running so try to stop it.
        kill $pid
        if [ $? -ne 0 ]
        then
            # An explanation for the failure should have been given
            echo "Unable to stop $APP_LONG_NAME."
            exit 1
        fi

        # We can not predict how long it will take for the wrapper to
        #  actually stop as it depends on settings in ptportal.conf.
        #  Loop until it does.
        savepid=$pid
        CNT=0
        TOTCNT=0
        while [ "X$pid" != "X" ]
        do
            # Loop for up to 5 minutes
            if [ "$TOTCNT" -lt "300" ]
            then
                if [ "$CNT" -lt "5" ]
                then
                    CNT=`expr $CNT + 1`
                else
                    echo "Waiting for $APP_LONG_NAME to exit..."
                    CNT=0
                fi
                TOTCNT=`expr $TOTCNT + 1`

                sleep 1

                testpid
            else
                pid=
            fi
        done

        pid=$savepid
        testpid
        if [ "X$pid" != "X" ]
        then
            echo "Timed out waiting for $APP_LONG_NAME to exit."
            echo "  Attempting a forced exit..."
            kill -9 $pid
        fi

        pid=$savepid
        testpid
        if [ "X$pid" != "X" ]
        then
            echo "Failed to stop $APP_LONG_NAME."
            exit 1
        else
            echo "Stopped $APP_LONG_NAME."
        fi
    fi
}

dump() {
    echo "Dumping $APP_LONG_NAME..."
    getpid
    if [ "X$pid" = "X" ]
    then
        echo "$APP_LONG_NAME was not running."

    else
        kill -3 $pid

        if [ $? -ne 0 ]
        then
            echo "Failed to dump $APP_LONG_NAME."
            exit 1
        else
            echo "Dumped $APP_LONG_NAME."
        fi
    fi
}

case "$1" in

    'console')
        console
        ;;

    'start')
        start
        ;;

    'stop')
        stopit
        ;;

    'restart')
        stopit
        start
        ;;
        
    'status')
        # REMOVE to avoid error
        # checkUser "" $1
        status
        ;;
        
    'dump')
        dump
        ;;

    *)
        echo "Usage: $0 { console | start | stop | restart | status | dump }"
        exit 1
        ;;
esac

exit 0
