using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalnavigation.common.constants;
using com.plumtree.portalnavigation.views;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation
{
  /// <summary>
  /// Horizontal combobox implementation of key views
  /// </summary>
  /// <author>robertz</author>
  /// <author>DavidP</author>
  public class NavTypeHorizontalComboBox : INavTypes
  {
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetID()"></seealso>
    public virtual int GetID()
    {
      return NavTypeConstants.NAVTYPE_ID_HORIZONTAL_COMBOBOX_DROPDOWN;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetName(java.lang.String)"></seealso>
    public virtual String GetName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(669, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetScope(java.lang.String)"></seealso>
    public virtual String GetScope(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(670, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
      }
    
    /// <seealso cref=""></seealso>
    public virtual String GetNavAreaView(NavAreaEnum area)
    {
      if (area.Equals(NavAreaEnum.BELOWBANNER))
      {
        return NavigationCommSectionComboBoxView.STR_MVC_CLASS_NAME;
      } else
      if (area.Equals(NavAreaEnum.ABOVEBANNER))
      {
        return NavigationHorizontalComboBoxView.STR_MVC_CLASS_NAME;
      } else
      if (area.Equals(NavAreaEnum.TOPBAR))
      {
        return PlumtreeTopBarView.STR_MVC_CLASS_NAME;
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#JavaScriptIncludes()"></seealso>
    public virtual HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner)
    {
      HTMLScriptCollection result = new HTMLScriptCollection();
      String strPortalImageServerJavaScriptURL = ConfigHelper.GetPortalImageServerJavaScriptURL(owner);
      // javascript file to display tabmandatory community tabs
      HTMLScript commonScript = new HTMLScript("text/javaScript");
      commonScript.SetSrc(strPortalImageServerJavaScriptURL + "navigationhorizontalcommon.js");
      result.AddInnerHTMLElement(commonScript);
      // Override js variables from NavigationSettings.xml
      int nNavTabWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_WIDTH,
       owner);
      if (-1 != nNavTabWidth)
      {
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
        script.AddInnerHTMLString("\n\tgHorizontalTabWidth = " + nNavTabWidth + ";");
        result.AddInnerHTMLElement(script);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#IsFeatureEnabled(com.plumtree.portaluiinfrastructure.navtype.NavFeatureEnum)"></seealso>
    public virtual bool IsFeatureEnabled(NavFeatureEnum feature)
    {
      return true;
    }
  }
}