using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalnavigation.common.constants;
using com.plumtree.portalnavigation.views;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
namespace com.plumtree.portalnavigation
{
  /// <summary>
  /// Now supports browser detection internally.
  /// The views in this navtype support auto-browser handling and can be used by external
  /// custom navigations.
  /// Custom navs that use the views offereed by this nav must also 
  /// use the javascript functions offered by this nav, which also
  /// switch down per-browser.
  /// </summary>
  /// <author>robertz</author>
  /// <author>DavidP</author>
  /// <author>DustinA</author>
  public class NavTypeJSPortalMenuDropDown : INavTypes
  {
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetID()"></seealso>
    public virtual int GetID()
    {
      return NavTypeConstants.NAVTYPE_ID_HORIZONTAL_DHTML_DROPDOWN_JSPORTALMENU;
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetName(java.lang.String)"></seealso>
    public virtual String GetName(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(671, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetScope(java.lang.String)"></seealso>
    public virtual String GetScope(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(672, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetNavAreaView(com.plumtree.portaluiinfrastructure.navtype.NavAreaEnum)"></seealso>
    public virtual String GetNavAreaView(NavAreaEnum area)
    {
      if (area.Equals(NavAreaEnum.BELOWBANNER))
      {
        return NavigationCommSectionDropDownView.STR_MVC_CLASS_NAME;
      } else
      if (area.Equals(NavAreaEnum.ABOVEBANNER))
      {
        return NavigationJSPortalMenuDropDownView.STR_MVC_CLASS_NAME;
      } else
      if (area.Equals(NavAreaEnum.TOPBAR))
      {
        return PlumtreeTopBarView.STR_MVC_CLASS_NAME;
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#JavaScriptIncludes()"></seealso>
    public virtual HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner)
    {
      HTMLScriptCollection result = new HTMLScriptCollection();
      // use browser detection to include the appropriate javascript
      BrowserType browser = (BrowserType) owner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      // DAP Key Note on Browser Mapping: We do mapping here to allow others to use this view in custom 
      // navigations as a nested view
      // Combobox Menus: Netscape 4 All Platforms, Macintosh Safari
      // Safari note: Must wait until Konqueror supports W3C spec 
      // for Javascript, slated for Safari 2.0
      // Also get combobox for anything we don't recognize
      // Note: Bug in IE on Mac forces us to combobox
      if (!browser.IsJSPortalMenuCompliant())
      {
        INavTypes navType = new NavTypeHorizontalComboBox();
        result.AddInnerHTMLElement(navType.JavaScriptIncludes(owner));
      } else
      // JS Portal Menu CommunityTabs: Netscape > 4 All Platforms, and IE all platforms 
      {
        // Javascript required for jsportalmenus
        result.AddInnerHTMLElement(NavigationJSPortalMenuHelpers.GetPlumtreeJSFrameworkJavaScript(owner));
        // Override js variables from NavigationSettings.xml
        // Width of each entry in the menus
        int nMenuCellWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTISCDROPDOWNMENU_WIDTH,
         owner);
        if (-1 != nMenuCellWidth)
        {
          HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
          script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
          script.AddInnerHTMLString("\n\tgMenuCellWidth = " + nMenuCellWidth + ";");
          result.AddInnerHTMLElement(script);
        }
        // Override js variables from NavigationSettings.xml
        // Width of the tabs to open dropdown menus
        int nNavTabWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_WIDTH,
         owner);
        if (-1 != nNavTabWidth)
        {
          HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
          script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
          script.AddInnerHTMLString("\n\tgHorizontalTabWidth = " + nNavTabWidth + ";");
          result.AddInnerHTMLElement(script);
        }
        // Send down localized string down to js for image alts in dynamic generated html
        HTMLScript scriptMenu = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        String imgAlt = owner.GetString(673, ResourceConstants.PORTALCOMMONMSGS);
        scriptMenu.AddInnerHTMLString("var gNavTabDownArrowImageAlt = \'" + imgAlt + "\';");
        result.AddInnerHTMLElement(scriptMenu);
        // Check for minimized browser window during page load. Will sometimes cause the calculations for the
        // positioning of menu tabs to be off. Reload the page when the window is restored if this is the case.
        HTMLScript ss = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        ss.AddInnerHTMLString("document.PCC.RegisterForWindowEvent(\"onfocus\", CheckForPageReload);");
        result.AddInnerHTMLElement(ss);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.navtype.INavTypes#IsFeatureEnabled(com.plumtree.portaluiinfrastructure.navtype.NavFeatureEnum)"></seealso>
    public virtual bool IsFeatureEnabled(NavFeatureEnum feature)
    {
      return true;
    }
  }
}