using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Accessible navigation view (used for 508, and low bandwidth).
  /// This view displays actions for the My Pages, My Communities, Directory 
  /// sections. 
  /// This view is used by NavTypeAccessible in the Above Body section.
  /// No javascript is used.
  /// </summary>
  /// <author>MichaelD</author>
  public class NavigationAccessibleAboveBodyView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationAccessibleAboveBodyView");
    
    /// <summary>
    /// MVC object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationAccessibleAboveBody";
    public const String STR_OPTIONS_ANCHOR = "options";
    protected AActivitySpace m_asOwner;
    protected IPluggableNavModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = null;
      try
      {
        result = WriteOptionsJumpLink();
      }
      catch (Exception e)
      {
        log.Error(e, "Could not display accessible above body navigation view.");
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IPluggableNavModelRO) model;
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationAccessibleAboveBodyView();
    }
    protected virtual HTMLElementCollection WriteOptionsJumpLink()
    {
      String strLink;
      if (NavPageType.COMMUNITY == m_model.GetCurNavPageType())
      {
        strLink = m_asOwner.GetString(762, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS);
        } else
      if (NavPageType.MYPAGE == m_model.GetCurNavPageType())
      {
        strLink = m_asOwner.GetString(761, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS);
        } else
      {
        return null;
      }
      HTMLElementCollection col = new HTMLElementCollection();
      HTMLTable table = new HTMLTable();
      col.AddInnerHTMLElement(table);
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLTableRow row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetAlign(CommonHTMLStrings.RIGHT);
      cell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      HTMLAnchor anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL + STR_OPTIONS_ANCHOR);
      cell.AddInnerHTMLElement(anchor);
      anchor.AddInnerHTMLString(strLink);
      anchor.SetTitle(strLink);
      return col;
    }
  }
}