using System;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts.navpagetype;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Accessible navigation view (used for 508, and low bandwidth).
  /// This view displays My Pages, My Communities, Directory and mandatory links in vertical 
  /// sections. Mandatory Communities with tab are not displayed separately from the My Communities section. 
  /// This view is used by NavTypeAccessible in the Above Body section. It uses helper functions
  /// in NavigationCommonVerticalView. 
  /// No javascript is used.
  /// </summary>
  /// <author>MichaelD</author>
  public class NavigationAccessibleLeftVerticalView : NavigationCommonVerticalView,IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationAccessibleLeftVerticalView");
    
    /// <summary>
    /// MVC object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationAccessibleLeftVertical";
    
    /// <summary>
    /// The maximum length of strings before truncation for accessible menu: Needs to be long enough for Community Members and Knowledge Directory *
    /// </summary>
    public const int ACCESSIBLE_MENU_TEXT_MAX_LENGTH = 31;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLElementCollection col = new HTMLElementCollection();
      try
      {
        if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType())
        {
          // DCA - check if we should show My Pages
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
          {
            Write508Section(col, m_asOwner.GetString(260, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
             m_model.GetCategoryLinks(NavCategoryType.MYPAGE, false), m_asOwner.GetString(765,
             ResourceConstants.PORTALCOMMONMSGS), false);
          }
          // DCA - check if we should show Communities
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
          {
            Write508MyCommunitiesSection(col);
          }
          // DCA - check if we should show the Directory
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
          {
            Write508Section(col, m_asOwner.GetString(254, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
             m_model.GetCategoryLinks(NavCategoryType.DIRECTORY, false), m_asOwner.GetString(766,
             ResourceConstants.PORTALCOMMONMSGS), false);
          }
          // Display the mandatory links menu
          Write508Section(col, m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK),
           m_model.GetCategoryLinks(NavCategoryType.MANDATORYLINK, false),
           m_asOwner.GetString(716, ResourceConstants.PORTALCOMMONMSGS), true);
          }
        // Display 508 access key table (shortcuts) and skip nav link
        Write508ShortcutsSection(result);
        result.AddInnerHTMLElement(col);
        WriteAdminLink(col);
        Write508JumpLink(result);
      }
      catch (Exception e)
      {
        log.Error(e, "Could not display accessible left vertical navigation view.");
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IPluggableNavModelRO) model;
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationAccessibleLeftVerticalView();
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the current Community section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <throws>Exception</throws>
    /// <throws>HTMLException</throws>
    protected virtual void Write508MyCommunitiesSection(HTMLElementCollection col)
    {
      // Community Actions
      HTMLTable table = CreateHeaderTable(true);
      col.AddInnerHTMLElement(table);
      AddSectionHeaderRow(table, m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
      AddVerticalSpacerRow(table);
      // Current community pages + sub & related comms
      if (NavPageType.COMMUNITY == m_model.GetCurNavPageType())
      {
        CommunityNavPage commP = (CommunityNavPage) m_model.GetPageSpecificMethods();
        WriteCurCommunitySection(col, commP);
        AddVerticalSpacerRow(table);
      }
      // Populate the membership communities
      table = CreateListStartTable();
      col.AddInnerHTMLElement(table);
      if (NavPageType.COMMUNITY == m_model.GetCurNavPageType())
      {
        AddStandardListBoldRow(table, m_asOwner.GetString(664, ResourceConstants.PORTALCOMMONMSGS));
        }
      ICPListEntryIterator iterator = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES,
       false);
      if (iterator != null && iterator.GetTotalCount() > 0)
      {
        CListURLFullMediator mediator = new CListURLFullMediator(m_asOwner,
         iterator);
        mediator.SetLabelMaxLength(ACCESSIBLE_MENU_TEXT_MAX_LENGTH);
        mediator.SetShowImages(false);
        while (mediator.Next())
        {
          AddStandardListRow(table, (HTMLElement) mediator.GetEntry());
        }
      } else
      {
        AddStandardListRow(table, new HTMLGenericElement(m_asOwner.GetString(768,
         ResourceConstants.PORTALCOMMONMSGS)));
      }
      AddVerticalSpacerRow(table);
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the directory section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <throws>HTMLException</throws>
    protected virtual void Write508Section(HTMLElementCollection col, String strTitle,
     ICPListEntryIterator iterator, String strIfIteratorEmpty, bool bShowImages)
    {
      HTMLTable table = CreateHeaderTable(true);
      col.AddInnerHTMLElement(table);
      AddSectionHeaderRow(table, strTitle);
      AddVerticalSpacerRow(table);
      table = CreateListStartTable();
      col.AddInnerHTMLElement(table);
      if (iterator != null && iterator.GetTotalCount() > 0)
      {
        CListURLFullMediator mediator = new CListURLFullMediator(m_asOwner,
         iterator);
        mediator.SetLabelMaxLength(ACCESSIBLE_MENU_TEXT_MAX_LENGTH);
        mediator.SetShowImages(bShowImages);
        while (mediator.Next())
        {
          AddStandardListRow(table, (HTMLElement) mediator.GetEntry());
        }
      } else
      {
        AddStandardListRow(table, new HTMLGenericElement(strIfIteratorEmpty));
        }
      AddVerticalSpacerRow(table);
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Community pages section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException</throws>
    protected override void WriteCommPages(HTMLElementCollection col, CommunityNavPage commP)
    {
      ICPListEntryIterator cpList = commP.GetCurCommPages();
      CListURLFullMediator mediator = new CListURLFullMediator(m_asOwner,
       cpList);
      mediator.SetLabelMaxLength(ACCESSIBLE_MENU_TEXT_MAX_LENGTH);
      HTMLTable table = CreateListStartTable();
      col.AddInnerHTMLElement(table);
      while (mediator.Next())
      {
        AddSUBSUBSectionListRow(table, (HTMLElement) mediator.GetEntry(),
         false);
      }
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a subsubsection link, 
    /// used for related and subcommunities section.=
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="element">The element link to add</param>
    /// <param name="bIndent">True to indent the string</param>
    /// <throws>HTMLException </throws>
    protected static void AddSUBSUBSectionListRow(HTMLTable table, HTMLElement element,
     bool bIndent)
    {
      if (null == element)
      {
        return;
      }
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBAR_SUB_SUBSECTION_BG);
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = null;
      if (bIndent)
      {
        tCell = new HTMLTableCell();
        tRow.AddInnerHTMLElement(tCell);
        tCell.SetHeight("20");
        tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLElement(element);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan(((bIndent) ? "2" : "3"));
      tCell.SetHeight("20");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a header bar
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="headerString">The header string</param>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    protected override void AddSectionHeaderRow(HTMLTable table, String headerString)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetWidth(CommonHTMLStrings.FIVE);
      tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      tCell.SetAlign(CommonHTMLStrings.LEFT);
      tCell.SetColSpan("2");
      HTMLH3 h3 = new HTMLH3();
      h3.AddInnerHTMLEncodedString(headerString);
      h3.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
      tCell.AddInnerHTMLElement(h3);
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with an HTMLAnchor link
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="anchor">The anchor link to add</param>
    /// <throws>HTMLException </throws>
    protected static void AddStandardListRow(HTMLTable table, HTMLElement element)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      HTMLTableCell tCell = new HTMLTableCell();
      if (null == element)
      {
        return;
      }
      tCell = new HTMLTableCell();
      table.AddInnerHTMLElement(tRow);
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLElement(element);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan("3");
      tCell.SetHeight("25");
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Subcommunity section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException</throws>
    protected override void AddCurCommSubSectionHeaderRow(HTMLElementCollection col,
     CommunityNavPage commP)
    {
      HTMLTable table = CreateHeaderTable(true);
      col.AddInnerHTMLElement(table);
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      tCell.SetWidth("100%");
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
      tCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(GeneralHelpers.TruncateLongString(commP.GetCurCommunityName(),
       ACCESSIBLE_MENU_TEXT_MAX_LENGTH, false)));
    }
  }
}