using System;
using com.plumtree.openlog;
using com.plumtree.portalnavigation.common.constants;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portalpages.common.uiparts.navpagetype;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Horizontal navigation scheme using HTML select elements as menus 
  /// (aka comboboxes or pull-down menus).
  /// This navigation view displays one to three community specific combobox menus with
  /// Community actions and community pages, Subcommunities and Related communities.
  /// This view is used by the NavTypeHorizontalComboBox navigation scheme in the below banner
  /// section, although it can be used in any horizontal space since it doesn't have any external
  /// dependencies.
  /// Combobox menus are native HTML elements, making them simple to create and use and they work in all
  /// browsers. The downside is that they are not very customizable. All entries in the list use the 
  /// same style and they don't have support for images or other HTML in the menus.
  /// Javascript is used to handle menu clicks.   
  /// </summary>
  /// <author>robertz</author>
  public class NavigationCommSectionComboBoxView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationCommSectionComboBoxView");
    
    /// <summary>
    /// MVC name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationCommSectionComboBox";
    
    /// <summary>
    /// Javascript variable name constants *
    /// </summary>
    protected const String m_strInCommID = "InComm";
    protected const String m_strRelComms = "RelComms";
    protected const String m_strSubComms = "SubComms";
    
    /// <summary>
    /// Not used *
    /// </summary>
    protected int m_nNumberCols = 0;
    private AActivitySpace m_asOwner;
    private IPluggableNavModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationCommSectionComboBoxView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      // This is ugly but keeps the code formatted nicer
      // Only want this on community pages
      if (NavPageType.COMMUNITY != m_model.GetCurNavPageType())
      {
        return new HTMLElementCollection();
      }
      HTMLElementCollection result = new HTMLElementCollection();
      // Outer table -- this is a top-level HTMLElement, so the language
      // needs to be set on it.
      HTMLTable table = new HTMLTable();
      String strLang = (String) PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      table.SetLangGlobal(strLang);
      try
      {
        CommunityNavPage commP = (CommunityNavPage) m_model.GetPageSpecificMethods();
        table.SetBorder(CommonHTMLStrings.ZERO);
        table.SetCellPadding(CommonHTMLStrings.ZERO);
        table.SetCellSpacing(CommonHTMLStrings.ZERO);
        HTMLTableRow row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        // Create the combobox menus and add them to the row			
        WriteInCommComboBox(row, commP);
        WriteSubCommsComboBox(row, commP);
        WriteRelCommsComboBox(row, commP);
        // Add the "Go up to parent" Tab if a parent community exists
        ICPListEntryIterator cpParComm = commP.GetParentComm();
        if (cpParComm.GetTotalCount() > 0)
        {
          row.AddInnerHTMLElement(GetHorSpacerCell());
          AddGoToParentCommTab(row, cpParComm);
        }
        // Spacer cell to fill out the row to the end 
        HTMLTableCell tCell = new HTMLTableCell();
        tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        row.AddInnerHTMLElement(tCell);
        table.AddInnerHTMLElement(row);
        // Need to get the HTML from the table html element as a string and 
        // enclose it in an HTML form pad it with special HTML to avoid the problem
        // where Netscape inserts extra whitespace after forms. 
        // Set the image server url in the table manually since we are extracting the html
        // in the table element as a string.
        table.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(m_asOwner));
        // This is an awful hack but only way I found to get rid of the extra form spacing in Netscape.
        result.AddInnerHTMLElement(new HTMLGenericElement("<table cellpadding=\"0\" cellspacing=\"0\" border=\"0\" width=\"100%\"><tr><td class=\"banHeaderBg\">" + "<table cellpadding=\"0\" cellspacing=\"0\" border=\"0\" width=\"100%\"><form name=\"filler2\">" + table.GetInnerHTMLDisplayString() + "</form></table></td></tr></table>"));
        // Create a spacer table for vertical padding			
        HTMLTable spacerTable = new HTMLTable();
        spacerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        spacerTable.SetBorder(CommonHTMLStrings.ZERO);
        spacerTable.SetCellPadding(CommonHTMLStrings.ZERO);
        spacerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        HTMLTableRow spacerRow = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        spacerTable.AddInnerHTMLElement(spacerRow);
        NavigationCommonHelpers.CreateVerticalSpacerCell(spacerRow);
        result.AddInnerHTMLElement(spacerTable);
      }
      catch (Exception e)
      {
        log.Error(e, "Unable displaying Community Section Combobox menus: " + e.Message);
        return new HTMLGenericElement("There was a problem displaying the Community Section Combobox menu bar.");
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_model = (IPluggableNavModelRO) model;
    }
    
    /// <summary>
    /// Adds an HTML option with specified string to the provided HTML Select.
    /// The title will be prefixed and suffixed with dashes.
    /// " - Label - "
    /// </summary>
    /// <param name="select">The Select to add the generated option to</param>
    /// <param name="strTitle">The option label</param>
    /// <throws>HTMLException</throws>
    protected virtual void AddTitleSelectBoxOption(HTMLSelect select, String strTitle)
    {
      HTMLOption option = new HTMLOption("");
      option.SetValue("");
      option.AddInnerHTMLString("- " + strTitle + " -");
      select.AddInnerHTMLElement(option);
    }
    
    /// <summary>
    /// Helper method that adds an HTML select to the provided HTMLTableCell, also
    /// returns the HTML Select element.
    /// </summary>
    /// <param name="tCell">The HTMLTableCell to add the generated select too</param>
    /// <param name="strSelectName">HTML ID of the select</param>
    /// <returns>							The generated HTML select</returns>
    /// <throws>HTMLException </throws>
    protected virtual HTMLSelect CreateSelectEleNavMenu(HTMLTableCell tCell,
     String strSelectName)
    {
      HTMLSelect select = new HTMLSelect(strSelectName, strSelectName);
      select.SetStyleClass(PTStyleClass.NAV_PULLDOWN_TEXT);
      // Javascript function to handle menu changes, defined in NavigationHorizontalComboBoxView
      select.SetOnChange("NavSelectMenuChange(options[selectedIndex].value, options)");
      tCell.AddInnerHTMLElement(select);
      return select;
    }
    
    /// <summary>
    /// Adds an HTML Select with an HTML Select containing In This Community links 
    /// (Community pages and Community knowledge directoy)
    /// </summary>
    /// <param name="tRow">The Select to add the generated HTML select to</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException </throws>
    protected virtual void WriteInCommComboBox(HTMLTableRow tRow, CommunityNavPage commP)
    {
      tRow.AddInnerHTMLElement(GetHorSpacerCell());
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      HTMLSelect select = CreateSelectEleNavMenu(tCell, "in_se_insidecomm");
      // mj: only show "Inside this Community" if we're supposed to
      if (commP.ShowCommunityNavigation())
      {
        AddTitleSelectBoxOption(select, "<B>" + m_asOwner.GetString(316, ResourceConstants.PORTALCOMMONMSGS) + "</B>");
        } else
      {
        // mj: otherwise, use the community name as the title
        AddTitleSelectBoxOption(select, "<B>" + m_model.GetCategoryTitle(NavCategoryType.COMMUNITY) + "</B>");
        }
      // Get the community pages
      ICPListEntryIterator cpList = commP.GetCurCommPages();
      CListURLTemplateMediator mediator = new CListURLTemplateMediator(m_asOwner,
       cpList);
      mediator.SetLabelMaxLength(NavigationHorizontalComboBoxView.MENU_TEXT_MAX_LENGTH);
      // Create a row in the menu for each page
      while (mediator.Next())
      {
        HTMLOption option = new HTMLOption("");
        String[] arStrings = (String[]) mediator.GetEntry();
        // Label
        String pageName = arStrings[CListURLTemplateMediator.TEMPLATEARR_INDEX_LABEL];
        // URL Template, no url template for the current page.
        if (arStrings.Length > 1)
        {
          String pageURL = arStrings[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL];
          option.SetValue(pageURL);
        }
        option.AddInnerHTMLString(pageName);
        select.AddInnerHTMLElement(option);
      }
      // Add an extra spacer row
      NavigationHorizontalComboBoxView.AddSpacerSelectBoxOptionFiller(select);
      }
    
    /// <summary>
    /// Adds an HTML Select with an HTML Select containing Related Community links.
    /// Nothing is added if no related communities exist
    /// </summary>
    /// <param name="tRow">The Select to add the generated HTML select to</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException </throws>
    protected virtual void WriteRelCommsComboBox(HTMLTableRow tRow, CommunityNavPage commP)
    {
      ICPListEntryIterator cpRelComms = commP.GetCurRelCommunities();
      // Don't display combobox at all if no peer comms
      if (cpRelComms.GetTotalCount() > 0)
      {
        // Add padding
        tRow.AddInnerHTMLElement(GetHorSpacerCell());
        HTMLTableCell tCell = new HTMLTableCell();
        tRow.AddInnerHTMLElement(tCell);
        HTMLSelect select = CreateSelectEleNavMenu(tCell, "in_se_mypagenav");
        AddTitleSelectBoxOption(select, "<B>" + m_asOwner.GetString(318, ResourceConstants.PORTALCOMMONMSGS) + "</B>");
        CListURLTemplateMediator mediator = null;
        mediator = new CListURLTemplateMediator(m_asOwner, cpRelComms);
        mediator.SetLabelMaxLength(NavigationHorizontalComboBoxView.MENU_TEXT_MAX_LENGTH);
        // Create a row for each related community	
        while (mediator.Next())
        {
          HTMLOption option = new HTMLOption("");
          String[] arStrings = (String[]) mediator.GetEntry();
          // Label
          String pageName = arStrings[CListURLTemplateMediator.TEMPLATEARR_INDEX_LABEL];
          // Entry only has a label, probably the current page
          if (1 == arStrings.Length)
          {
            option.AddInnerHTMLString(pageName);
          } else
          {
            tRow.AddInnerHTMLElement(GetHorSpacerCell());
            // URL Template
            String pageURL = arStrings[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL];
            option.SetValue(pageURL);
            option.AddInnerHTMLString(pageName);
          }
          select.AddInnerHTMLElement(option);
        }
        NavigationHorizontalComboBoxView.AddSpacerSelectBoxOptionFiller(select);
        }
    }
    // end if relcomms > 0
    
    /// <summary>
    /// Adds an HTML Select with an HTML Select containing Subcommunity links.
    /// Nothing is added if no subcommunities exist
    /// </summary>
    /// <param name="tRow">The Select to add the generated HTML select to</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException </throws>
    protected virtual void WriteSubCommsComboBox(HTMLTableRow tRow, CommunityNavPage commP)
    {
      HTMLTableCell tCell = new HTMLTableCell();
      HTMLSelect select = CreateSelectEleNavMenu(tCell, "in_se_subcomms");
      AddTitleSelectBoxOption(select, "<B>" + m_asOwner.GetString(317, ResourceConstants.PORTALCOMMONMSGS) + "</B>");
      ICPListEntryIterator cpList = null;
      cpList = commP.GetCurSubCommunities();
      // mj: if there are no subcommunities, do not show the combo box
      if (cpList.GetTotalCount() < 1)
      {
        return;
      }
      tRow.AddInnerHTMLElement(GetHorSpacerCell());
      // mj: there are subcommunities, so add the combo box to the row
      tRow.AddInnerHTMLElement(tCell);
      CListURLTemplateMediator mediator = new CListURLTemplateMediator(m_asOwner,
       cpList);
      mediator.SetLabelMaxLength(NavigationHorizontalComboBoxView.MENU_TEXT_MAX_LENGTH);
      // Create a row for each subcommunity
      while (mediator.Next())
      {
        HTMLOption option = new HTMLOption("");
        String[] arStrings = (String[]) mediator.GetEntry();
        // Label
        String pageName = arStrings[CListURLTemplateMediator.TEMPLATEARR_INDEX_LABEL];
        if (arStrings.Length > 1)
        {
          // URL Template, no url template for the current page
          String pageURL = arStrings[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL];
          option.SetValue(pageURL);
        }
        option.AddInnerHTMLString(pageName);
        select.AddInnerHTMLElement(option);
      }
      NavigationHorizontalComboBoxView.AddSpacerSelectBoxOptionFiller(select);
      }
    
    /// <summary>
    /// Adds a tab with go to parent community image and action if there is a parent community. 
    /// NavigationCommSectionDropDownView has a copy of this funtion too, update both when editing.
    /// </summary>
    /// <param name="tRow">The HTMLTableRow to add the Tab too</param>
    /// <param name="cpList">ICPListIterator with a parent community (can only be one) or empty list if none exists.</param>
    /// <throws>Exception</throws>
    protected virtual void AddGoToParentCommTab(HTMLTableRow tRow, ICPListEntryIterator cpList)
    {
      CListURLTemplateMediator mediator = new CListURLTemplateMediator(m_asOwner,
       cpList);
      if (!mediator.Next())
      {
        // No parent community, don't need this tab
        return;
      }
      // Cell with the image
      HTMLTableCell tCell = new HTMLTableCell();
      tCell.SetStyleClass(PTStyleClass.NAV_MIDTAB_BG);
      tRow.AddInnerHTMLElement(tCell);
      // "Go up to Parent Community"  
      String toolTip = m_asOwner.GetString(644, ResourceConstants.PORTALCOMMONMSGS);
      // Get the Up arrrow image
      HTMLImg parent = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_FOLDER_UP,
       true, this.m_asOwner).GetHTMLElement();
      parent.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(m_asOwner));
      parent.SetHeight("20");
      parent.SetBorder(CommonHTMLStrings.ZERO);
      parent.SetAlign(CommonHTMLStrings.MIDDLE);
      parent.SetAlt(toolTip);
      // Get the Community image
      HTMLImg comm = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
       true, this.m_asOwner).GetHTMLElement();
      comm.SetBorder(CommonHTMLStrings.ZERO);
      comm.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      comm.SetAlt(toolTip);
      String[] strings = (String[]) mediator.GetEntry();
      // Will be used as a javascript string with ' (single quote) as string delimiter so need to use " (double
      // quotes as string delimeter in the link, (clisturltemplatelinkmediator creates jscript with ')
      HTMLAnchor anchor = new HTMLAnchor("#");
      anchor.SetOnClick(NavigationCommonHelpers.URLTEMPLATE_REDIRECT_JSFUNCNAME + "(\'" + strings[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL] + "\'); return false;");
      anchor.SetTitle(toolTip);
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.NAV_MIDTAB_BTN);
      span.AddInnerHTMLElement(anchor);
      tCell.AddInnerHTMLElement(span);
      // Add both images to the anchor
      anchor.AddInnerHTMLElement(parent);
      anchor.AddInnerHTMLElement(comm);
    }
    
    /// <summary>
    /// Helper function that creates a horizontal spacer cell 4 pixels wide.
    /// </summary>
    /// <returns>HTMLTableCell 4 pixel wide spacer cell </returns>
    public static HTMLTableCell GetHorSpacerCell()
    {
      HTMLTableCell tSpacer = new HTMLTableCell();
      tSpacer.SetStyleClass(PTStyleClass.NAV_MIDTABSPACER_BG);
      tSpacer.AddInnerHTMLElement(NavigationCommonHelpers.GetSpacerImage("4",
       "1"));
      return tSpacer;
    }
  }
}