using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.browsing.login.createaccount;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.portalsettings;
using com.plumtree.portalpages.browsing.search.advanced;
using com.plumtree.portalpages.browsing.search.network;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portalpages.common.uiparts.navpagetype;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.interpreter.filter.utils;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Common parent class for vertical navigation schemes.
  /// Contains variables and methods common for vertical schemes.  
  /// </summary>
  /// <author>robertz</author>
  public class NavigationCommonVerticalView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationCommonVerticalView");
    
    /// <summary>
    /// The name of the anchor used to skip past the navigation in 508 mode. 
    /// </summary>
    private const String STR_SKIP_ANCHOR = "skip";
    
    /// <summary>
    /// string constants for performance. 
    /// </summary>
    private const String STR_EMPTY = "";
    private const String STR_508_XML_FILE = "ptmsgs_portal508quickkeymsgs";
    
    /// <summary>
    /// The maximum length of strings before truncation *
    /// </summary>
    public const int MENU_TEXT_MAX_LENGTH = 26;
    protected AActivitySpace m_asOwner;
    protected IPluggableNavModelRO m_model;
    /////////////////////
    // 508 helper methods
    /////////////////////
    
    /// <summary>
    /// This method displays the hidden link after the navigation banner so that
    /// 508 users can skip the navigation.
    /// This is mainly relevant for IE.
    /// </summary>
    /// <param name="HTMLElementCollection">the collection to add the shortcut section to.</param>
    public virtual void Write508JumpLink(HTMLElementCollection result)
    {
      HTMLAnchor myAnchor;
      myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
      myAnchor.SetName(STR_SKIP_ANCHOR);
      myAnchor.SetTitle(m_asOwner.GetString(40, STR_508_XML_FILE));
      result.AddInnerHTMLElement(myAnchor);
    }
    
    /// <summary>
    /// This method displays the access key shortcuts for the 508 banner.
    /// This is mainly relevant for IE.
    /// These entries need to appear every time, unlike the normal navigation
    /// bar, where
    /// </summary>
    /// <param name="HTMLElementCollection">the collection to add the shortcut section to.</param>
    public virtual void Write508ShortcutsSection(HTMLElementCollection result)
    {
      HTMLAnchor myAnchor;
      HTMLAnchor medAnchor;
      ICPListEntryIterator cpList;
      // Use an ASURL Link Mediator because we only want active links, not labels.
      CListURLFullLinkMediator mediator;
      // Y -- Skip navigation
      myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL + STR_SKIP_ANCHOR);
      myAnchor.SetAccessKey(m_asOwner.GetString(0, STR_508_XML_FILE));
      myAnchor.SetTitle(m_asOwner.GetString(13, STR_508_XML_FILE));
      result.AddInnerHTMLElement(myAnchor);
      // Common keys for all users
      // M -- My page home page
      // Just get the first mypage in the list
      cpList = m_model.GetCategoryLinks(NavCategoryType.MYPAGE, false);
      mediator = new CListURLFullLinkMediator(m_asOwner, cpList);
      mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
      // The first myPage entry should be the users default mypage
      if (mediator.Next())
      {
        medAnchor = (HTMLAnchor) mediator.GetEntry();
        if (medAnchor != null)
        {
          myAnchor = new HTMLAnchor(STR_EMPTY);
          myAnchor.SetHRef(medAnchor.GetHRef());
          myAnchor.SetAccessKey(m_asOwner.GetString(1, STR_508_XML_FILE));
          myAnchor.SetTitle(m_asOwner.GetString(14, STR_508_XML_FILE));
          result.AddInnerHTMLElement(myAnchor);
        }
      }
      // C -- Default community home page
      // Get the first mandatory community; if there's none, get first community
      medAnchor = null;
      bool bMandatory = false;
      cpList = m_model.GetCategoryLinks(NavCategoryType.MANDATORYTABS, false);
      mediator = new CListURLFullLinkMediator(m_asOwner, cpList);
      mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
      if (0 != cpList.GetTotalCount())
      {
        if (mediator.Next())
        {
          medAnchor = (HTMLAnchor) mediator.GetEntry();
          bMandatory = true;
        }
      }
      // No mandatory found, get first community
      if (!bMandatory)
      {
        cpList = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES, false);
        mediator = new CListURLFullLinkMediator(m_asOwner, cpList);
        mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
        if (mediator.Next())
        {
          medAnchor = (HTMLAnchor) mediator.GetEntry();
        }
      }
      if (medAnchor != null)
      {
        myAnchor = new HTMLAnchor(STR_EMPTY);
        myAnchor.SetHRef(medAnchor.GetHRef());
        myAnchor.SetAccessKey(m_asOwner.GetString(2, STR_508_XML_FILE));
        myAnchor.SetTitle(m_asOwner.GetString(15, STR_508_XML_FILE));
        result.AddInnerHTMLElement(myAnchor);
      }
      cpList = m_model.GetCategoryLinks(NavCategoryType.DIRECTORY, false);
      mediator = new CListURLFullLinkMediator(m_asOwner, cpList);
      mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
      // B -- Browse for documents
      if (mediator.Next())
      {
        medAnchor = (HTMLAnchor) mediator.GetEntry();
        if (medAnchor != null)
        {
          myAnchor = new HTMLAnchor(STR_EMPTY);
          myAnchor.SetHRef(medAnchor.GetHRef());
          myAnchor.SetAccessKey(m_asOwner.GetString(3, STR_508_XML_FILE));
          myAnchor.SetTitle(m_asOwner.GetString(16, STR_508_XML_FILE));
          result.AddInnerHTMLElement(myAnchor);
        }
      }
      if (!m_model.IsGuestSession())
      {
        // Common keys for non-guest users
        // Q -- Advanced Search for documents
        ASURL advsearch = new ASURL(m_asOwner);
        advsearch.SetLinkCreateNewSpace(AdvancedSearchAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        advsearch.SetLinkTitle(m_asOwner.GetString(339, ResourceConstants.PORTALCOMMONMSGS));
        advsearch.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        advsearch.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
        myAnchor = (HTMLAnchor) advsearch.GetURLAsHTMLElement();
        myAnchor.SetAccessKey(m_asOwner.GetString(5, STR_508_XML_FILE));
        myAnchor.SetTitle(m_asOwner.GetString(18, STR_508_XML_FILE));
        result.AddInnerHTMLElement(myAnchor);
        // N -- Search Other Networks
        ASURL netsearch = new ASURL(m_asOwner);
        netsearch.SetLinkCreateNewSpace(NetworkSearchAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        netsearch.SetLinkTitle(m_asOwner.GetString(340, ResourceConstants.PORTALCOMMONMSGS));
        netsearch.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
        myAnchor = (HTMLAnchor) netsearch.GetURLAsHTMLElement();
        myAnchor.SetAccessKey(m_asOwner.GetString(6, STR_508_XML_FILE));
        myAnchor.SetTitle(m_asOwner.GetString(19, STR_508_XML_FILE));
        result.AddInnerHTMLElement(myAnchor);
        // W -- My Account (Portal Settings). 
        ASURL myAccount = new ASURL(m_asOwner);
        myAccount.SetLinkCreateNewSpace(PortalSettingsAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        myAccount.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        myAccount.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
        myAnchor = (HTMLAnchor) myAccount.GetURLAsHTMLElement();
        myAnchor.SetAccessKey(m_asOwner.GetString(8, STR_508_XML_FILE));
        myAnchor.SetTitle(m_asOwner.GetString(21, STR_508_XML_FILE));
        result.AddInnerHTMLElement(myAnchor);
        // L -- Log Off
        myAnchor = new HTMLAnchor(STR_EMPTY);
        // IsEditProfile is used because NavPageType.USERPROFILE is deprecated and will be removed in the next version.
        if (!m_model.IsEditProfile())
        {
          ASURL logoff = new ASURL(m_asOwner);
          logoff.SetLinkGetSpaceIfCached(LoginAS.STR_MVC_CLASS_NAME, m_asOwner);
          logoff.SetControl(LoginControl.STR_MVC_CLASS_NAME);
          logoff.AddControlArgument(LoginHelper.PARAM_DOLOGOUT);
          try
          {
            myAnchor = (HTMLAnchor) logoff.GetURLAsHTMLElement();
            myAnchor.SetAccessKey(m_asOwner.GetString(10, STR_508_XML_FILE));
            myAnchor.SetTitle(m_asOwner.GetString(23, STR_508_XML_FILE));
            result.AddInnerHTMLElement(myAnchor);
          }
          catch (Exception e)
          {
          }
        }
      } else
      // no handling - URL is a label and didn't cast
      {
        // common keys for guest users
        // U -- Create an Account
        if (PTLoginHelper.GetAllowUserCreation(m_asOwner, m_asOwner.GetApplication()))
        {
          ASURL createAccount = new ASURL(m_asOwner);
          createAccount.SetLinkCreateNewSpace(CreateAccountAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          createAccount.SetControl(CreateAccountControl.STR_MVC_CLASS_NAME);
          myAnchor = (HTMLAnchor) createAccount.GetURLAsHTMLElement();
          myAnchor.SetAccessKey(m_asOwner.GetString(12, STR_508_XML_FILE));
          myAnchor.SetTitle(m_asOwner.GetString(25, STR_508_XML_FILE));
          result.AddInnerHTMLElement(myAnchor);
        }
      }
      // more common keys for all users
      // H -- Help
      HTMLAnchor helpAnchor = HTMLConstructHelpers.GetHelpAnchor(m_asOwner);
      myAnchor = new HTMLAnchor(STR_EMPTY);
      myAnchor.SetHRef(helpAnchor.GetHRef());
      myAnchor.SetAccessKey(m_asOwner.GetString(11, STR_508_XML_FILE));
      myAnchor.SetTitle(m_asOwner.GetString(24, STR_508_XML_FILE));
      result.AddInnerHTMLElement(myAnchor);
      result.AddInnerHTMLElement(Get508PortletAccessAnchors());
    }
    
    /// <summary>
    /// Return a collection of access key anchors elements pointing to each portlet
    /// displayed.
    /// </summary>
    /// <returns></returns>
    protected virtual HTMLElementCollection Get508PortletAccessAnchors()
    {
      if (m_asOwner.GetIsAccessStyleStandard())
      {
        return null;
      }
      if (m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
      {
        MyPortalModel mpModel = (MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        HTMLElementCollection elementCollection = new HTMLElementCollection();
        int j = 0;
        for (int i = 0;i < mpModel.GetPortletCount();i++)
        {
          if (mpModel.GetPortletSupports508(i))
          {
            String strPortletName = XPHttpUtility.HtmlEncode(mpModel.GetPortletNameFromIndex(j));
            String strPortletIndex = XPConvert.ToString(j);
            HTMLAnchor htmlAnchor = new HTMLAnchor("#" + strPortletIndex);
            htmlAnchor.SetTitle(XPResourceManager.FormatMessage(m_asOwner.GetString(33,
             ResourceConstants.PORTAL508QUICKKEYMSGS), strPortletIndex, strPortletName));
            htmlAnchor.SetAccessKey(strPortletIndex);
            elementCollection.AddInnerHTMLElement(htmlAnchor);
            j++;
          }
        }
        return elementCollection;
      }
      return null;
    }
    /////////////////////////
    // Generic helper methods
    /////////////////////////
    
    /// <summary>
    /// Helper method that creates an HTMLTable to start a list
    /// </summary>
    /// <returns>Table template for lists </returns>
    public static HTMLTable CreateListStartTable()
    {
      HTMLTable table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetCellPadding("5");
      table.SetCellSpacing("0");
      table.SetBorder("0");
      return table;
    }
    
    /// <summary>
    /// Helper method that creates a header HTMLTable 
    /// </summary>
    /// <param name="bSpacer">True to add a spacer row below the header</param>
    /// <returns>Table template for headers</returns>
    public static HTMLTable CreateHeaderTable(bool bSpacer)
    {
      HTMLTable table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetCellPadding("0");
      table.SetCellSpacing("0");
      table.SetBorder("0");
      if (bSpacer)
      {
        AddVerticalSpacerRow(table);
      }
      return table;
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with just a string and no anchor to 
    /// the specified HTMLTable.
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="text">Label to add</param>
    /// <throws>HTMLException </throws>
    public static void WriteTextRow(HTMLTable table, String text)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      HTMLTableCell tCell = new HTMLTableCell();
      table.AddInnerHTMLElement(tRow);
      //		tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      //		tRow.AddInnerHTMLElement(tCell);
      //		tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.AddInnerHTMLString(text);
      tCell.SetColSpan("3");
    }
    
    /// <summary>
    /// Generates the ASURL with just the URL to the control for collapse/expanding 
    /// vertical navigation sections.
    /// </summary>
    /// <param name="nSectionID">NavVisibility ID of the navigation section</param>
    /// <param name="bCollapsed">True if the entire section is collapsed</param>
    /// <returns>ASURL					Generated ASURL with just the URL</returns>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    protected virtual ASURL GetCollapseExpandURL(int nSectionID, bool bCollapse)
    {
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkGetSpaceIfCached(m_asOwner.GetName(), m_asOwner);
      url.SetControl(NavigationControl.STR_MVC_CLASS_NAME);
      url.AddControlArgument(((bCollapse) ? NavigationControl.ACTION_COLLAPSE : NavigationControl.ACTION_EXPAND),
       XPConvert.ToString(nSectionID));
      // Form up the components of the url; strip off the control args from the request 
      // for re-use, as that's the only way to deal with gatewayed prefs pages that are
      // in a subspace
      String fullUrl = m_asOwner.GetCurrentRequestURL();
      String normalizedUrl = m_asOwner.GetCurrentNormalizedBaseURL();
      String controlArgs = "";
      String baseUrl = "";
      String redirectUrl = "";
      String testUrl = fullUrl;
      // Form the correct base url you'll use later in forming the 
      // redirect url with control arguments
      baseUrl = ConfigHelper.GetApplicationBaseURLToAS(normalizedUrl, m_asOwner.GetName(),
       false);
      // Strip off control args for redirect based on separator				
      int iQSIndex = XPStringUtility.IndexOf(fullUrl, "?");
      if (-1 != iQSIndex)
      {
        controlArgs = XPStringUtility.Substring(fullUrl, iQSIndex + 1, fullUrl.Length);
        testUrl = XPStringUtility.Substring(fullUrl, 0, iQSIndex);
      }
      // If this is a gateway url, set boolean
      int iGWIndex = XPStringUtility.IndexOf(testUrl, GatewayHandlers.GATEWAY_UNIQUE);
      if (-1 != iGWIndex)
      {
        if (-1 == iQSIndex)
        {
          controlArgs = XPStringUtility.Substring(fullUrl, iGWIndex + 1, fullUrl.Length);
          }
        // flip question mark to slash as we're gatewaying here			
        redirectUrl = XPStringUtility.Substring(baseUrl, 0, baseUrl.Length - 1) + "/" + controlArgs;
        } else
      {
        // Build the link; baseUrl already has question mark
        redirectUrl = baseUrl + controlArgs;
      }
      url.AddControlArgument(NavigationControl.PREV_PAGE_QSPARAM, redirectUrl);
      return url;
    }
    
    /// <summary>
    /// Gets the ASURL with image to collapse/expand vertical navigation sections 
    /// </summary>
    /// <param name="nSectionID">NavVisibility ID of the navigation section</param>
    /// <param name="bCollapsed">True if the entire section is collapsed</param>
    /// <returns>ASURL					Generated ASURL with image for collapsing/expanding section</returns>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    public virtual ASURL GetSectionCollapseExpandURL(int nSectionID, bool bCollapse)
    {
      ASURL url = GetCollapseExpandURL(nSectionID, bCollapse);
      HTMLImg image = null;
      try
      {
        image = (HTMLImg) UIConstructFactory.GetConstruct(((bCollapse) ? PTImageType.ICON_ARROW_EXPAND : PTImageType.ICON_ARROW_COLLAPSE),
         true, this.m_asOwner).GetHTMLElement();
      }
      catch (Exception e)
      {
        log.Error(e, "Could not display expand arror in simple navigation view.");
        }
      String altText = ((bCollapse) ? m_asOwner.GetString(250, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS) : m_asOwner.GetString(251,
       com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
      url.AddInnerHTMLElement(image);
      url.SetLinkTitle(altText);
      image.SetAlt(altText);
      image.SetHeight("16");
      image.SetWidth("16");
      image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      image.SetBorder(CommonHTMLStrings.ZERO);
      return url;
    }
    
    /// <summary>
    /// Gets the ASURL with image to collapse/expand vertical actions subsection
    /// </summary>
    /// <param name="nSectionID">NavVisibility ID of the navigation section</param>
    /// <param name="bCollapsed">True if the entire section is collapsed</param>
    /// <returns>ASURL					Generated ASURL with image for collapsing/expanding actions section</returns>
    /// <throws>Exception</throws>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    public virtual ASURL GetActionCollapseExpandURL(int nSectionID, bool bCollapse)
    {
      ASURL url = GetCollapseExpandURL(nSectionID, bCollapse);
      HTMLImg htmlImg = (HTMLImg) UIConstructFactory.GetConstruct(((bCollapse) ? PTImageType.ACTION_ACTIONBAR_EXPAND : PTImageType.ACTION_ACTIONBAR_COLLAPSE),
       true, this.m_asOwner).GetHTMLElement();
      htmlImg.SetAlt(((bCollapse) ? m_asOwner.GetString(264, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS) : m_asOwner.GetString(263,
       com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS)));
      htmlImg.SetHeight("25");
      htmlImg.SetWidth("25");
      htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      htmlImg.SetBorder(CommonHTMLStrings.ZERO);
      url.AddInnerHTMLElement(htmlImg);
      url.SetLinkTitle(((bCollapse) ? m_asOwner.GetString(264, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS) : m_asOwner.GetString(263,
       com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS)));
      return url;
    }
    
    /// <summary>
    /// DCA - Creating HTML for Administration Button
    /// Don't need this function
    /// </summary>
    /// <param name="table">HTMLTable to add the generated row to</param>
    /// <param name="asURL">Administrator ASURL</param>
    /// <throws>HTMLException </throws>
    protected static void AddAdminListRow(HTMLTable table, HTMLAnchor anchor)
    {
      if (null == anchor)
      {
        return;
      }
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = new HTMLTableCell();
      tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      tCell.SetHeight("20");
      tRow.AddInnerHTMLElement(tCell);
      tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      tCell.SetColSpan("2");
      tCell.AddInnerHTMLElement(anchor);
      // DCA - String Label needs to be surrounded by an HTMLSpan
      XPArrayList arrElements = anchor.GetInnerHTMLElementsAsArrayList(true);
      String strLabel = ((HTMLGenericElement) arrElements.GetElement(0)).GetDisplayString();
      anchor.ClearInnerHTMLElements();
      HTMLSpan mySpan = new HTMLSpan();
      mySpan.AddInnerHTMLString(strLabel);
      mySpan.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
      anchor.AddInnerHTMLElement(mySpan);
      tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      tCell = new HTMLTableCell();
      tCell.SetHeight("5");
      tCell.SetColSpan("3");
      tRow.AddInnerHTMLElement(tCell);
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with an action link
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="text">Label to add</param>
    /// <param name="collapseLink">Display the link to collapse the current action subsection</param>
    /// <throws>HTMLException </throws>
    protected virtual void AddActionListRow(HTMLTable table, HTMLAnchor anchor,
     ASURL collapseLink)
    {
      if (anchor != null)
      {
        HTMLTableRow tRow = new HTMLTableRow();
        HTMLTableCell tCell = new HTMLTableCell();
        table.AddInnerHTMLElement(tRow);
        tRow.AddInnerHTMLElement(tCell);
        tRow.SetStyleClass(PTStyleClass.NAV_MIDTAB_BG);
        tCell.SetStyleClass(PTStyleClass.NAV_MIDTAB_BTN);
        tCell.SetHeight("16");
        HTMLTableCell tOuter = tCell;
        // Inner table
        HTMLTable tTable = new HTMLTable();
        BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
        if ((AccessStyles.STANDARD == m_asOwner.GetAccessStyle()) || (!browser.IsNetscape67()))
        {
          HTMLAnchor tempAnchor = new HTMLAnchor("#");
          tCell.AddInnerHTMLElement(tempAnchor);
          tempAnchor.AddInnerHTMLElement(tTable);
        } else
        {
          tCell.AddInnerHTMLElement(tTable);
        }
        tTable.SetCellPadding("0");
        tTable.SetCellSpacing("0");
        tTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        HTMLTableRow tInnerRow = new HTMLTableRow();
        tCell = new HTMLTableCell();
        tCell.SetHeight("20");
        tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        tCell.SetStyleClass(PTStyleClass.OBJECT_BTN);
        tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        tCell.SetNoWrap(true);
        tTable.AddInnerHTMLElement(tInnerRow);
        tInnerRow.AddInnerHTMLElement(tCell);
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.ACTIONBAR_BAN_TEXT);
        span.AddInnerHTMLElement(anchor);
        tCell.AddInnerHTMLElement(span);
        // Only display collapse link if we are not in 508/low bandwidth
        if ((null != collapseLink) && (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD) && !TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
        {
          tOuter.SetColSpan("1");
          tCell = new HTMLTableCell();
          tRow.AddInnerHTMLElement(tCell);
          tCell.SetAlign(CommonHTMLStrings.RIGHT);
          tCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_BTN);
          tCell.AddInnerHTMLElement(collapseLink.GetURLAsHTMLElement());
        } else
        {
          tOuter.SetColSpan("2");
        }
      }
    }
    // Vertical Navigation Helper functions
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a spacer row
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <throws>HTMLException </throws>
    protected static void AddVerticalSpacerRow(HTMLTable table)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      String sHeight = "2";
      tCell.SetHeight(sHeight);
      // bjf -- setting this to autofit, as this row was coming up as filling only one column,
      // while other rows seemed to be taking up three.
      tCell.SetAutoFit(true);
      tCell.AddInnerHTMLElement(NavigationCommonHelpers.GetSpacerImage("1",
       sHeight));
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a header bar
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="headerString">The header string</param>
    /// <throws>HTMLException </throws>
    protected virtual void AddSectionHeaderRow(HTMLTable table, String headerString)
    {
      String spacer = CommonHTMLStrings.SPACE + CommonHTMLStrings.SPACE;
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      tCell.SetAlign(CommonHTMLStrings.LEFT);
      tCell.SetColSpan("3");
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLString(spacer + XPHttpUtility.HtmlEncode(headerString));
      }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a collapsible/expandable header bar
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="headerString">The header string</param>
    /// <param name="nID">NavVisibility ID of the navigation section</param>
    /// <param name="bCollapsed">True if the entire section is collapsed</param>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    protected virtual void AddSectionHeaderRow(HTMLTable table, String headerString,
     int nID, bool bCollapsed)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = new HTMLTableCell();
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      tCell.SetAlign(CommonHTMLStrings.LEFT);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
      tRow.AddInnerHTMLElement(tCell);
      // Only add expand/collapse images if we are in standard mode
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD && !TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
      {
        ASURL url = GetSectionCollapseExpandURL(nID, !bCollapsed);
        tCell.AddInnerHTMLElement(url.GetURLAsHTMLElement());
      } else
      {
        tCell.AddInnerHTMLString("&nbsp;");
      }
      tCell.SetColSpan("3");
      tCell.AddInnerHTMLEncodedString(headerString);
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with an ASURL link
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="asURL">The ASURL link to add</param>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    protected static void AddStandardListRow(HTMLTable table, ASURL asURL)
    {
      if (null == asURL)
      {
        return;
      }
      HTMLTableRow tRow = new HTMLTableRow();
      HTMLTableCell tCell = new HTMLTableCell();
      tCell = new HTMLTableCell();
      table.AddInnerHTMLElement(tRow);
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLElement(asURL.GetURLAsHTMLElement());
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan("3");
      tCell.SetHeight("25");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with an HTMLAnchor link
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="anchor">The anchor link to add</param>
    /// <throws>HTMLException </throws>
    protected static void AddStandardListRow(HTMLTable table, HTMLAnchor anchor)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      HTMLTableCell tCell = new HTMLTableCell();
      if (null == anchor)
      {
        return;
      }
      tCell = new HTMLTableCell();
      table.AddInnerHTMLElement(tRow);
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLElement(anchor);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan("3");
      tCell.SetHeight("25");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a bolded string
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="strLabel">The string to display</param>
    /// <throws>HTMLException </throws>
    protected static void AddStandardListBoldRow(HTMLTable table, String strLabel)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      HTMLTableCell tCell = new HTMLTableCell();
      tCell = new HTMLTableCell();
      table.AddInnerHTMLElement(tRow);
      tRow.AddInnerHTMLElement(tCell);
      HTMLB htmlB = new HTMLB();
      tCell.AddInnerHTMLElement(htmlB);
      htmlB.AddInnerHTMLString(strLabel);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan("3");
      tCell.SetHeight("25");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a subsubsection link, 
    /// used for related and subcommunities section.=
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="anchor">The anchor link to add</param>
    /// <param name="bIndent">True to indent the string</param>
    /// <throws>HTMLException </throws>
    protected static void AddSUBSUBSectionListRow(HTMLTable table, HTMLAnchor anchor,
     bool bIndent)
    {
      if (null == anchor)
      {
        return;
      }
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBAR_SUB_SUBSECTION_BG);
      table.AddInnerHTMLElement(tRow);
      HTMLTableCell tCell = null;
      if (bIndent)
      {
        tCell = new HTMLTableCell();
        tRow.AddInnerHTMLElement(tCell);
        tCell.SetHeight("20");
        tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLElement(anchor);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan(((bIndent) ? "2" : "3"));
      tCell.SetHeight("20");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a subsection link
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="anchor">The anchor link to add</param>
    /// <throws>HTMLException </throws>
    protected static void AddSubSectionListRow(HTMLTable table, HTMLAnchor anchor)
    {
      if (null == anchor)
      {
        return;
      }
      HTMLTableRow tRow = new HTMLTableRow();
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
      HTMLTableCell tCell = new HTMLTableCell();
      tCell = new HTMLTableCell();
      table.AddInnerHTMLElement(tRow);
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLElement(anchor);
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
      tCell.SetColSpan("3");
      tCell.SetHeight("20");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a section header
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="headerString">The header string to display</param>
    /// <throws>HTMLException </throws>
    protected virtual void AddSubSectionHeaderRow(HTMLTable table, String headerString)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetHeight("20");
      tCell.SetVAlign("middle");
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
      tCell.AddInnerHTMLString(headerString);
      tCell.SetColSpan("3");
    }
    
    /// <summary>
    /// Adds an HTMLTableCell inside an HTMLTableRow with a collapsible/expandable section header
    /// </summary>
    /// <param name="table">The table to add the generated HTMLTableRow to</param>
    /// <param name="headerString">The header string to display</param>
    /// <param name="nID">NavVisibility ID of the navigation section</param>
    /// <param name="bCollapsed">True if the entire section is collapsed</param>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    protected virtual void AddSubSectionHeaderRow(HTMLTable table, String headerString,
     int nID, bool bCollapsed)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      // Only add expand/collapse images if we are in standard mode
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD && !TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
      {
        ASURL url = GetSectionCollapseExpandURL(nID, !bCollapsed);
        tCell.AddInnerHTMLElement(url.GetURLAsHTMLElement());
      }
      //		tCell = new HTMLTableCell();
      //		tRow.AddInnerHTMLElement(tCell);
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      //tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
      //tCell.AddInnerHTMLString(headerString);
      HTMLSpan span = new HTMLSpan();
      tCell.AddInnerHTMLElement(span);
      span.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
      span.AddInnerHTMLString(headerString);
      tCell.SetColSpan("3");
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Subcommunity section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException</throws>
    protected virtual void AddCurCommSubSectionHeaderRow(HTMLElementCollection col,
     CommunityNavPage commP)
    {
      HTMLTable table = CreateHeaderTable(true);
      col.AddInnerHTMLElement(table);
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetHeight("20");
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      tCell.SetWidth("100%");
      tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
      tCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(GeneralHelpers.TruncateLongString(commP.GetCurCommunityName(),
       MENU_TEXT_MAX_LENGTH, false)));
      ICPListEntryIterator cpList = commP.GetParentComm();
      // Can't use the CListURLTemplateLinkMediator because we would get an anchor with displau label,
      // only want the url, construct our own anchor from the template string array instead
      CListURLTemplateMediator mediator = new CListURLTemplateMediator(m_asOwner,
       cpList);
      // Go up to parent community link
      if (mediator.Next())
      {
        // Spacer cell
        tRow.AddInnerHTMLElement(CreateActionBarDivider());
        //<td height="20" valign="middle" class="objectBtn" nowrap><span class="objectBtnText"><a href="#">
        //<img src="../../../../common/images/action_folder_up.gif" width="8" height="25" align="absmiddle" border="0" alt="Up a Community Level">
        //<img src="../../../../common/images/icon_community.gif" width="20" height="20" align="absmiddle" border="0" alt="Up a Community Level">&nbsp;</a></span></td>
        tCell = new HTMLTableCell();
        tRow.AddInnerHTMLElement(tCell);
        tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        tCell.SetStyleClass(PTStyleClass.OBJECT_BTN);
        tCell.SetNoWrap(true);
        tCell.SetHeight("20");
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_BTN_TEXT);
        tCell.AddInnerHTMLElement(span);
        String toolTip = m_asOwner.GetString(644, ResourceConstants.PORTALCOMMONMSGS);
        String[] strings = (String[]) mediator.GetEntry();
        HTMLAnchor anchor = new HTMLAnchor("#");
        anchor.SetOnClick(NavigationCommonHelpers.URLTEMPLATE_REDIRECT_JSFUNCNAME + "(\'" + strings[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL] + "\'); return false;");
        anchor.SetTitle(toolTip);
        span.AddInnerHTMLElement(anchor);
        // Go up to parent community
        HTMLImg image = null;
        image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_FOLDER_UP).GetHTMLElement();
        image.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(m_asOwner));
        image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        image.SetBorder(CommonHTMLStrings.ZERO);
        image.SetAlt(toolTip);
        anchor.AddInnerHTMLElement(image);
        image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY).GetHTMLElement();
        image.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(m_asOwner));
        image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        image.SetBorder(CommonHTMLStrings.ZERO);
        image.SetAlt(toolTip);
        anchor.AddInnerHTMLElement(image);
      } else
      {
        tCell.SetColSpan("3");
      }
    }
    
    /// <summary>
    /// Adds an HTMLTable with the Administration link to the specified HTMLElementCollection
    /// </summary>
    /// <param name="col">HTMLCollection to add the Admin HTMLTable too</param>
    /// <throws>HTMLException</throws>
    /// <throws>Exception</throws>
    protected virtual void WriteAdminLink(HTMLElementCollection col)
    {
      // no admin in 508 or low bandwidth mode
      // (check done in model)
      //		if (m_model.HasAdminLinkAccess())
      //		{
      HTMLTable table = CreateHeaderTable(false);
      col.AddInnerHTMLElement(table);
      // form admin link
      ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.ADMIN,
       false);
      if (cpList.GetTotalCount() > 0)
      {
        AddSectionHeaderRow(table, m_asOwner.GetString(275, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
        table = CreateListStartTable();
        col.AddInnerHTMLElement(table);
        CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);
        while (mediator.Next())
        {
          // DCA - more prominent look for Administration link
          //					AddAdminListRow(table, (HTMLAnchor) mediator.GetEntry());
          AddStandardListRow(table, (HTMLAnchor) mediator.GetEntry());
        }
      }
    }
    //		}
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the current Community section,
    /// with the Community pages, Subcommunities and related communities
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>Exception</throws>
    protected virtual void WriteCurCommunitySection(HTMLElementCollection col,
     CommunityNavPage commP)
    {
      AddCurCommSubSectionHeaderRow(col, commP);
      WriteCommPages(col, commP);
      WriteSubCommsSubSection(col, commP);
      WriteRelatedCommunitiesSubSection(col, commP);
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the current Community section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>Exception</throws>
    /// <throws>HTMLException</throws>
    protected virtual void WriteMyCommunitiesSection(HTMLElementCollection col)
    {
      if (SectionVisible(NavVisibility.VISIBILITY_COMMUNITY_SECTION))
      {
        // Community Actions
        HTMLTable table = CreateHeaderTable(true);
        col.AddInnerHTMLElement(table);
        AddSectionHeaderRow(table, m_asOwner.GetString(252, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_COMMUNITY_SECTION, false);
        ICPListEntryIterator iterActions = m_model.GetCategoryLinks(NavCategoryType.COMMUNITY,
         true);
        if (SectionVisible(NavVisibility.VISIBILITY_COMMUNITYACTIONS_SECTION))
        {
          CListURLMediator med = new CListURLMediator(m_asOwner, iterActions);
          med.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
          int i = iterActions.GetTotalCount();
          while (med.Next())
          {
            AddActionListRow(table, (HTMLAnchor) med.GetEntry(), ((i-- == 1) ? GetActionCollapseExpandURL(NavVisibility.VISIBILITY_COMMUNITYACTIONS_SECTION,
             true) : null));
          }
        } else
        // Minimized actions subsection bar
        {
          WriteMinimizedSubSectionBar(table, m_asOwner.GetString(274, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
           NavVisibility.VISIBILITY_COMMUNITYACTIONS_SECTION, iterActions);
          }
        //AddVerticalSpacerRow(table);
        // Current community pages + sub & related comms
        if (NavPageType.COMMUNITY == m_model.GetCurNavPageType())
        {
          CommunityNavPage commP = (CommunityNavPage) m_model.GetPageSpecificMethods();
          WriteCurCommunitySection(col, commP);
        }
        // Populate the membership communities
        table = CreateListStartTable();
        AddVerticalSpacerRow(table);
        col.AddInnerHTMLElement(table);
        ICPListEntryIterator clist = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES,
         false);
        CListURLMediator mediator = new CListURLMediator(m_asOwner, clist);
        mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
        if (NavPageType.COMMUNITY == m_model.GetCurNavPageType() || clist.GetTotalCount() > 0)
        {
          AddStandardListBoldRow(table, m_asOwner.GetString(664, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
          }
        while (mediator.Next())
        {
          HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
          //AddStandardListRow(table, url);
          AddStandardListRow(table, url);
        }
        AddVerticalSpacerRow(table);
      } else
      {
        HTMLTable table = CreateHeaderTable(true);
        col.AddInnerHTMLElement(table);
        AddSectionHeaderRow(table, m_asOwner.GetString(252, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_COMMUNITY_SECTION, true);
        AddVerticalSpacerRow(table);
      }
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Community pages section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException</throws>
    protected virtual void WriteCommPages(HTMLElementCollection col, CommunityNavPage commP)
    {
      ICPListEntryIterator cpList = commP.GetCurCommPages();
      CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);
      mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
      HTMLTable table = CreateListStartTable();
      col.AddInnerHTMLElement(table);
      while (mediator.Next())
      {
        HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
        AddSUBSUBSectionListRow(table, anchor, false);
      }
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Subcommunities section of 
    /// the current community
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>Exception</throws>
    /// <throws>HTMLException</throws>
    /// <throws>Exception</throws>
    protected virtual void WriteSubCommsSubSection(HTMLElementCollection col,
     CommunityNavPage commP)
    {
      ICPListEntryIterator cpSubComs = commP.GetCurSubCommunities();
      if (cpSubComs.GetTotalCount() < 1)
      {
        return;
      }
      if (SectionVisible(NavVisibility.VISIBILITY_SUB_COMMS_SECTION))
      {
        HTMLTable table = CreateHeaderTable(false);
        col.AddInnerHTMLElement(table);
        if (cpSubComs.GetTotalCount() > 0)
        {
          CListURLMediator mediator = new CListURLMediator(m_asOwner, cpSubComs);
          mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
          AddSubSectionHeaderRow(table, m_asOwner.GetString(266, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
           NavVisibility.VISIBILITY_SUB_COMMS_SECTION, false);
          table = CreateListStartTable();
          col.AddInnerHTMLElement(table);
          while (mediator.Next())
          {
            HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
            AddSUBSUBSectionListRow(table, url, true);
          }
        }
      } else
      {
        HTMLTable table = CreateListStartTable();
        col.AddInnerHTMLElement(table);
        AddSubSectionHeaderRow(table, m_asOwner.GetString(266, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_SUB_COMMS_SECTION, true);
      }
    }
    //		}
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the directory section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <throws>HTMLException</throws>
    protected virtual void WriteDocumentsSection(HTMLElementCollection col)
    {
      HTMLTable table = CreateHeaderTable(true);
      col.AddInnerHTMLElement(table);
      AddVerticalSpacerRow(table);
      if (SectionVisible(NavVisibility.VISIBILITY_DIRECTORY_SECTION))
      {
        AddSectionHeaderRow(table, m_asOwner.GetString(254, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_DIRECTORY_SECTION, false);
        table = CreateListStartTable();
        col.AddInnerHTMLElement(table);
        CListURLMediator mediator = new CListURLMediator(m_asOwner, m_model.GetCategoryLinks(NavCategoryType.DIRECTORY,
         false));
        mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
        while (mediator.Next())
        {
          HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
          AddStandardListRow(table, url);
        }
      } else
      {
        AddSectionHeaderRow(table, m_asOwner.GetString(254, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_DIRECTORY_SECTION, true);
      }
      AddVerticalSpacerRow(table);
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Mandatory Communities
    /// section. Note that My communities section lists these aswell.
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <throws>Exception</throws>
    /// <throws>HTMLException</throws>
    protected virtual void WriteMandatoryCommunitiesSection(HTMLElementCollection col)
    {
      if (SectionVisible(NavVisibility.VISIBILITY_MANDATORYCOMMS_SECTION))
      {
        ICPListEntryIterator cplist = m_model.GetCategoryLinks(NavCategoryType.MANDATORYTABS,
         false);
        CListURLMediator mediator = new CListURLMediator(m_asOwner, cplist);
        mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
        if (0 != cplist.GetTotalCount())
        {
          HTMLTable table = CreateHeaderTable(true);
          col.AddInnerHTMLElement(table);
          AddVerticalSpacerRow(table);
          AddSectionHeaderRow(table, m_asOwner.GetString(253, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
           NavVisibility.VISIBILITY_MANDATORYCOMMS_SECTION, false);
          table = CreateListStartTable();
          col.AddInnerHTMLElement(table);
          while (mediator.Next())
          {
            HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
            AddStandardListRow(table, url);
          }
          AddVerticalSpacerRow(table);
        }
      } else
      {
        HTMLTable table = CreateHeaderTable(true);
        col.AddInnerHTMLElement(table);
        AddVerticalSpacerRow(table);
        AddSectionHeaderRow(table, m_asOwner.GetString(253, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_MANDATORYCOMMS_SECTION, true);
        AddVerticalSpacerRow(table);
      }
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Mandatory links section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <throws>HTMLException</throws>
    protected virtual void WriteMandatoryLinksSection(HTMLElementCollection col)
    {
      String strMandLinksName = m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK);
      ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MANDATORYLINK,
       false);
      CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);
      // Don't even make a section header for the mandatory links if the mandatory links name is blank.
      if ((null != strMandLinksName) && !("").Equals(strMandLinksName))
      {
        HTMLTable table = CreateHeaderTable(true);
        col.AddInnerHTMLElement(table);
        if (cpList.GetTotalCount() > 0)
        {
          // If there are mandatory links, then make the section header expandable and collapsable.
          if (SectionVisible(NavVisibility.VISIBILITY_MANDATORYLINKS_SECTION))
          {
            // If the mandatory links are visible (the section is expanded), then show them.
            AddSectionHeaderRow(table, strMandLinksName, NavVisibility.VISIBILITY_MANDATORYLINKS_SECTION,
             false);
            mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
            table = CreateListStartTable();
            col.AddInnerHTMLElement(table);
            while (mediator.Next())
            {
              HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
              AddStandardListRow(table, anchor);
            }
          } else
          {
            // If the mandatory links section is collapsed, then don't show the mandatory links.
            AddSectionHeaderRow(table, strMandLinksName, NavVisibility.VISIBILITY_MANDATORYLINKS_SECTION,
             true);
          }
        } else
        {
          // bjf -- don't show mandatory links if there aren't any
          AddSectionHeaderRow(table, strMandLinksName);
          // String: There are no mandatory links.
          HTMLAnchor anchor = new HTMLAnchor(null);
          anchor.AddInnerHTMLString(m_asOwner.GetString(716, ResourceConstants.PORTALCOMMONMSGS));
          AddStandardListRow(table, anchor);
        }
        AddVerticalSpacerRow(table);
      }
    }
    
    /// <summary>
    /// Adds an HTMLTableRow to specified HTMLTable with a collapsed
    /// Subsection Bar. Used to display collapsed actions subsection
    /// with only the action images.
    /// </summary>
    /// <param name="table">The HTMLTable to add the generated row too.</param>
    /// <param name="strTitle">Subsection header string</param>
    /// <param name="nID">NavVisibility ID of the section</param>
    /// <param name="cpList">Actions as ICPListEntryIterator</param>
    /// <throws>HTMLException</throws>
    /// <throws>Exception</throws>
    protected virtual void WriteMinimizedSubSectionBar(HTMLTable table, String strTitle,
     int nID, ICPListEntryIterator cpList)
    {
      HTMLTableRow tRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tRow);
      tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
      HTMLTableCell tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);
      tCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      while (mediator.Next())
      {
        HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
        XPArrayList list = anchor.GetInnerHTMLElementsAsArrayList(false);
        // Only get the target url and image from each entry. Don't want the 
        // label.
        HTMLAnchor imgAnchor = new HTMLAnchor(anchor.GetHRef());
        imgAnchor.SetOnClick(anchor.GetOnClick());
        imgAnchor.AddInnerHTMLElement((HTMLGenericElement) list.GetElement(0));
        tCell.AddInnerHTMLElement(imgAnchor);
      }
      // Add the section expand action image
      tCell = new HTMLTableCell();
      tRow.AddInnerHTMLElement(tCell);
      tCell.SetAlign(CommonHTMLStrings.RIGHT);
      tCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      tCell.AddInnerHTMLElement(GetActionCollapseExpandURL(nID, false).GetURLAsHTMLElement());
      }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Mypage links section
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <throws>HTMLException</throws>
    /// <throws>Exception</throws>
    protected virtual void WriteMyPagesSection(HTMLElementCollection col)
    {
      if (SectionVisible(NavVisibility.VISIBILITY_MYPAGE_SECTION))
      {
        HTMLTable table = CreateHeaderTable(true);
        col.AddInnerHTMLElement(table);
        AddSectionHeaderRow(table, m_asOwner.GetString(260, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_MYPAGE_SECTION, false);
        ICPListEntryIterator iterActions = m_model.GetCategoryLinks(NavCategoryType.MYPAGE,
         true);
        if (SectionVisible(NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION))
        {
          //					AddSubSectionHeaderRow(table, _ui_MyPageActions, NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION, false);
          //
          CListURLMediator med = new CListURLMediator(m_asOwner, iterActions);
          med.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
          int i = iterActions.GetTotalCount();
          while (med.Next())
          {
            //						AddStandardListRow(table, (HTMLAnchor)mediator.GetEntry());
            AddActionListRow(table, (HTMLAnchor) med.GetEntry(), ((i-- == 1) ? GetActionCollapseExpandURL(NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION,
             true) : null));
          }
        } else
        // Minimized actions subsection bar
        {
          WriteMinimizedSubSectionBar(table, m_asOwner.GetString(273, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
           NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION, iterActions);
          }
        AddVerticalSpacerRow(table);
        ICPListEntryIterator iterPages = m_model.GetCategoryLinks(NavCategoryType.MYPAGE,
         false);
        CListURLMediator mediator = new CListURLMediator(m_asOwner, iterPages);
        mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
        while (mediator.Next())
        {
          AddStandardListRow(table, (HTMLAnchor) mediator.GetEntry());
        }
        AddVerticalSpacerRow(table);
      } else
      // Minimized mypage section bar
      {
        HTMLTable table = CreateHeaderTable(true);
        col.AddInnerHTMLElement(table);
        AddSectionHeaderRow(table, m_asOwner.GetString(260, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_MYPAGE_SECTION, true);
        AddVerticalSpacerRow(table);
      }
    }
    
    /// <summary>
    /// Adds an HTMLTable to the HTMLElementCollection with the Related communities section of 
    /// the current community
    /// </summary>
    /// <param name="col">The HTMLElementCollection to add the HTMLTable too</param>
    /// <param name="commP">The CommunityNavPage</param>
    /// <throws>HTMLException</throws>
    protected virtual void WriteRelatedCommunitiesSubSection(HTMLElementCollection col,
     CommunityNavPage commP)
    {
      ICPListEntryIterator cpList = commP.GetCurRelCommunities();
      if (cpList.GetTotalCount() < 1)
      {
        return;
      }
      if (SectionVisible(NavVisibility.VISIBILITY_RELATED_COMMS_SECTION))
      {
        // Don't display the section if there no related comms.
        if (cpList.GetTotalCount() > 0)
        {
          HTMLTable table = CreateHeaderTable(false);
          col.AddInnerHTMLElement(table);
          AddSubSectionHeaderRow(table, m_asOwner.GetString(267, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
           NavVisibility.VISIBILITY_RELATED_COMMS_SECTION, false);
          table = CreateListStartTable();
          col.AddInnerHTMLElement(table);
          if (cpList.GetTotalCount() == 0)
          {
            WriteTextRow(table, m_asOwner.GetString(287, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
            } else
          {
            CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);
            while (mediator.Next())
            {
              AddSUBSUBSectionListRow(table, (HTMLAnchor) mediator.GetEntry(),
               true);
            }
          }
        }
      } else
      // Minimized related comms subsection bar
      {
        HTMLTable table = CreateListStartTable();
        col.AddInnerHTMLElement(table);
        AddSubSectionHeaderRow(table, m_asOwner.GetString(267, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
         NavVisibility.VISIBILITY_RELATED_COMMS_SECTION, true);
      }
    }
    //		}
    
    /// <summary>
    /// This helper method checks if the section is visible, or if
    /// we are in 508 mode, in which case we don't allow collapsing
    /// sections.
    /// </summary>
    /// <param name="int">nSection the ID of the section</param>
    /// <returns>boolean true implies visible</returns>
    private bool SectionVisible(int nSection)
    {
      return ((m_asOwner.GetAccessStyle() != AccessStyles.STANDARD) || TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner) || (m_model.GetSectionVisibility(nSection)));
      }
    
    /// <summary>
    /// Helper function that gets a table cell used as a thin divider. 
    /// </summary>
    /// <returns>HTMLTableCell				Divider cell</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell CreateActionBarDivider()
    {
      HTMLTableCell tCell = new HTMLTableCell();
      tCell.SetWidth("1");
      tCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_DIVIDER);
      tCell.AddInnerHTMLElement(NavigationCommonHelpers.GetSpacerImage("1",
       "20"));
      return tCell;
    }
  }
}