using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalnavigation.common.constants;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Horizontal navigaton scheme with dropdown menus using the JSPortalMenu framework.
  /// This navigation view displays "My Pages", "My Communities", "Directory" and mandatory links
  /// dropdown menus using the JSPortalMenu framework. Mandatory communities and link to Administration
  /// are displayed using same tabs as the menu tabs. The tabs will wrap to multiple rows if there are 
  /// too many tabs to fit on one row.
  /// This view is used by the NavTypeJSPortalMenuDropDown in the above banner view. The menu framework
  /// is defined in navjsportalmenufuncs.js and functions in navjsportalmenucommon.js is used for the
  /// mandatory community tabs. 
  /// Now supports browser detection internally, so this view can be used
  /// as a nested view by other navigation views.
  /// This view supports auto-browser handling so it can be used by external
  /// custom navigations. Custom navs that use this view MUST also use the 
  /// JavaScriptIncludes() method on NavTypeJSPortalMenuDropDown to return 
  /// proper javascript to support this view.
  /// </summary>
  /// <author>RobertZ</author>
  /// <author>DavidP</author>
  public class NavigationJSPortalMenuDropDownView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationJSPortalMenuDropDownView");
    private AActivitySpace m_asOwner;
    private IPluggableNavModelRO m_model;
    protected int m_nMyPageMenuEntries = 0;
    protected int m_nMyCommsMenuEntries = 0;
    protected int m_nDirectoryMenuEntries = 0;
    protected int m_nMandatoryLinksEntries = 0;
    // we use these views for dynamic routing of browser handling
    private NavigationHorizontalComboBoxView m_comboBoxMenuView = null;
    
    /// <summary>
    /// Drop down view class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PTHztlDDNav_New";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationJSPortalMenuDropDownView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection myGroup = new HTMLElementCollection();
      HTMLElement result = myGroup;
      // Detect the browser type and map to the right menu view
      BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      // DAP Key Note on Browser Mapping: 
      // We do mapping here to allow others to use this view in custom 
      // navigations as a nested view.  
      // Combobox Menus: Netscape 4 All Platforms, Macintosh Safari
      // Safari note: Must wait until Konqueror supports W3C spec 
      // for Javascript, slated for Safari 2.0
      // Also get combobxo for anything we don't recognize
      // Note javascript handling is browser-specific in NavType also
      // Bug in IE MAC forces us to combobox there
      if (!browser.IsJSPortalMenuCompliant())
      {
        result = m_comboBoxMenuView.Display();
      } else
      // New jsportal menus now supports Netscape 7.1
      // normal jsportalmenus navigation 
      {
        try
        {
          // Populate the arrays	   	
          HTMLScriptCollection col = new HTMLScriptCollection();
          result.AddInnerHTMLElement(col);
          // Populate menus 
          CreateMyPageMenu(col);
          CreateCommMembershipMenu(col);
          CreateDocMenu(col);
          CreateMandatoryLinksMenu(col);
          // Populate the array of Mandatory Tab entries 
          col.AddInnerHTMLElement(NavigationCommonHelpers.CreateMandatoryTabsArray(m_model.GetCategoryLinks(NavCategoryType.MANDATORYTABS,
           true), m_asOwner));
          // Populate the array of Dropdown menu tabs
          col.AddInnerHTMLElement(CreateDDTabsArray());
          // Write the Javascript functions
          col.AddInnerHTMLElement(NavigationCommonHelpers.GenerateJSHTMLHelperFunctions(m_asOwner));
          HTMLScript script = new HTMLScript("text/javaScript");
          result.AddInnerHTMLElement(script);
          result.AddInnerHTMLString("<!-- start NAV DHTML MIDBAR -->");
          // include jsportalmenus js files
          result.AddInnerHTMLElement(ConfigHelper.GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTALMENU,
           m_asOwner));
          script = new HTMLScript("text/javaScript");
          // write div holders for the dropdown menus
          script.AddInnerHTMLString("writePortalMenuDivs(" + JSHelper.GetSafeJSVariableWarn(NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY) + ");\n");
          // get PTMenu.css location string	
          IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
          String defaultStyleSheet = ConfigHelper.GetImageServerBaseURL(m_asOwner) + "common/private/js/jsportalmenus/" + ConfigHelper.GetJSIncluderComponentVersion(ConfigHelper.JSCOMPONENT_JSPORTALMENU) + "/styles/css/PTPMMenu.css";
          // initialize menu	
          script.AddInnerHTMLString("initDDandManTabsRows(" + JSHelper.GetSafeJSVariableWarn(NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY) + "," + JSHelper.GetSafeJSVariableWarn(NavigationCommonHelpers.JSCRIPT_VAR_MANDTAB_ARRAY) + ",\'" + defaultStyleSheet + "\');");
          script.AddInnerHTMLString("document.PCC.RegisterForWindowEvent(\"onload\", \"gbPageLoaded = true;\" );");
          result.AddInnerHTMLElement(script);
          result.AddInnerHTMLString("<!-- end NAV DHTML MIDBAR -->");
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying Dropdown menu tabs: " + e.Message);
          return new HTMLGenericElement("Error displaying Dropdown menu tabs.");
          }
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IPluggableNavModelRO) model;
      m_asOwner = parent;
      m_comboBoxMenuView = new NavigationHorizontalComboBoxView();
      m_comboBoxMenuView.Init(model, parent);
    }
    
    /// <summary>
    /// Creates the dropdown menu with the Communities the current user is a member of.
    /// Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
    /// </summary>
    /// <param name="col">The HTMLScriptCollection to add the javascript too</param>
    /// <throws>HTMLException</throws>
    protected virtual void CreateCommMembershipMenu(HTMLScriptCollection col)
    {
      ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES,
       true);
      m_nMyCommsMenuEntries = cpList.GetTotalCount();
      NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, cpList, NavigationJSPortalMenuHelpers.m_strCommID);
      }
    
    /// <summary>
    /// This function populates an array of Tabs with the navigation menus to show
    /// Element 0: Display name
    /// Element 1: ID of the menu
    /// Element 2: Tooltip (if needed);
    /// </summary>
    /// <param name="script">HTMLScript block with the array</param>
    /// <throws>HTMLException </throws>
    protected virtual HTMLScript CreateDDTabsArray()
    {
      // Roughly estimate the size of the buffer
      XPStringBuilder buf = new XPStringBuilder(300);
      String strMaxLength = (String) m_asOwner.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_TRUNCATION_WIDTH);
      int nMaxLength = XPConvert.ToInteger(strMaxLength);
      //buf.Append("\t" + "var " + NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY + " = [\n");
      buf.Append("[");
      if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType())
      {
        String toolTip = "";
        String label = "";
        String labelTrunc = "";
        if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS) && m_nMyPageMenuEntries > 0)
        {
          label = JSHelper.JSEncodeString(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS));
          labelTrunc = GeneralHelpers.TruncateLongString(label, nMaxLength,
           false);
          buf.Append(" [\"" + labelTrunc + "\",\"" + NavigationJSPortalMenuHelpers.m_strMyPageID + "\",\"" + ((label.Length == labelTrunc.Length) ? "null" : label) + "\"]\n,");
          }
        if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS) && m_nMyCommsMenuEntries > 0)
        {
          label = JSHelper.JSEncodeString(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
          labelTrunc = GeneralHelpers.TruncateLongString(label, nMaxLength,
           false);
          buf.Append("[\"" + labelTrunc + "\",\"" + NavigationJSPortalMenuHelpers.m_strCommID + "\",\"" + ((label.Length == labelTrunc.Length) ? "null" : label) + "\"]\n,");
          }
        if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS) && m_nDirectoryMenuEntries > 0)
        {
          label = JSHelper.JSEncodeString(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS));
          labelTrunc = GeneralHelpers.TruncateLongString(label, nMaxLength,
           false);
          buf.Append("[\"" + labelTrunc + "\",\"" + NavigationJSPortalMenuHelpers.m_strDocID + "\",\"" + ((label.Length == labelTrunc.Length) ? "null" : label) + "\"]\n,");
          }
        String strMandLinksName = m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK);
        String strTruncMandLinksName = GeneralHelpers.TruncateLongString(strMandLinksName,
         XPConvert.ToInteger(strMaxLength), false);
        if ((null != strTruncMandLinksName) && !("").Equals(strTruncMandLinksName) && m_nMandatoryLinksEntries > 0)
        {
          // Add tooltip if the string was truncated.
          toolTip = (strTruncMandLinksName.Length == strMandLinksName.Length) ? "null" : JSHelper.JSEncodeString(XPHttpUtility.HtmlEncode(strMandLinksName));
          buf.Append("[\"" + JSHelper.JSEncodeString(XPHttpUtility.HtmlEncode(strTruncMandLinksName)) + "\",\"" + NavigationJSPortalMenuHelpers.m_strMandLinksID + "\",\"" + 
          // Need to HTMLEncode this, goes into the title attribute of a span.  
          toolTip + "\"]\n");
        } else
        {
          if (buf.GetLength() > 1)
          {
            // remove last comma
            buf.RemoveCharAt(buf.GetLength() - 1);
          }
        }
      }
      buf.Append("]");
      return JSHelper.AddSafeJSVariable(NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY,
       buf.ToString());
    }
    
    /// <summary>
    /// Creates the dropdown menu with the Directory links.
    /// Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
    /// </summary>
    /// <param name="col">The HTMLScriptCollection to add the javascript too</param>
    /// <throws>HTMLException</throws>
    protected virtual void CreateDocMenu(HTMLScriptCollection col)
    {
      ICPListEntryIterator list = m_model.GetCategoryLinks(NavCategoryType.DIRECTORY,
       false);
      m_nDirectoryMenuEntries = list.GetTotalCount();
      NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, list, NavigationJSPortalMenuHelpers.m_strDocID);
      }
    
    /// <summary>
    /// Creates the dropdown menu with the current user's Mandatory Links
    /// Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
    /// </summary>
    /// <param name="col">The HTMLScriptCollection to add the javascript too</param>
    /// <throws>HTMLException</throws>
    protected virtual void CreateMandatoryLinksMenu(HTMLScriptCollection col)
    {
      ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MANDATORYLINK,
       true);
      String strMandLinksName = m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK);
      m_nMandatoryLinksEntries = cpList.GetTotalCount();
      // bjf -- if there aren't any links, then don't show the menu
      if ((null != strMandLinksName) && !("").Equals(strMandLinksName) && (cpList.GetTotalCount() != 0))
      {
        NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, cpList, NavigationJSPortalMenuHelpers.m_strMandLinksID);
        }
    }
    
    /// <summary>
    /// Creates the dropdown menu with the current user's My pages
    /// Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
    /// </summary>
    /// <param name="col">The HTMLScriptCollection to add the javascript too</param>
    /// <throws>HTMLException</throws>
    protected virtual void CreateMyPageMenu(HTMLScriptCollection col)
    {
      //ASQueryResult asPages = m_model.GetCurMyPages();
      ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MYPAGE,
       true);
      ((ASCompoundList) cpList).AddCompoundList(m_model.GetCategoryLinks(NavCategoryType.MYPAGE,
       false));
      m_nMyPageMenuEntries = cpList.GetTotalCount();
      NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, cpList, NavigationJSPortalMenuHelpers.m_strMyPageID);
      }
  }
}