using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Simple left hand navigation view (used for 508, among other things).
  /// This view displays My Pages, My Communities, Directory and mandatory links in vertical 
  /// sections. These sections can be collapsed to save space. Mandatory Communities with tab 
  /// are displayed in the My Communities section in this scheme. 
  /// This view is used by NavTypeSimpleLeftVertical in the Left side section. It uses helper functions
  /// in NavigationCommonVerticalView. 
  /// No javascript is used.
  /// </summary>
  /// <author>RobertZ</author>
  public class NavigationSimpleLeftVerticalView : NavigationCommonVerticalView,IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationSimpleLeftVerticalView");
    
    /// <summary>
    /// MVC object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationSimpleLeftVerticalBar";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLElementCollection col = new HTMLElementCollection();
      try
      {
        // Communities section
        if (m_model.GetCurNavPageType() == NavPageType.COMMUNITY)
        {
          WriteMyCommunitiesSection(col);
        }
        if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType())
        {
          // DCA - check if we should show My Pages
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
          {
            WriteMyPagesSection(col);
          }
          if (m_model.GetCurNavPageType() != NavPageType.COMMUNITY)
          {
            // DCA - check if we should show Communities
            if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
            {
              WriteMyCommunitiesSection(col);
            }
          }
          // DCA - check if we should show the Directory
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
          {
            WriteDocumentsSection(col);
          }
          // Display the mandatory links menu
          WriteMandatoryLinksSection(col);
        }
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          result.AddInnerHTMLElement(col);
        } else
        {
          // Display 508 access key table (shortcuts) and skip nav link
          Write508ShortcutsSection(result);
          result.AddInnerHTMLElement(col);
          Write508JumpLink(result);
        }
        // Add the link to administration
        WriteAdminLink(col);
      }
      catch (Exception e)
      {
        log.Error(e, "Could not display simple navigation view.");
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IPluggableNavModelRO) model;
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationSimpleLeftVerticalView();
    }
  }
}