using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// The left vertical view for Section specific vertical view.
  /// This view displays only one of the My Pages, My Communities, Directory or mandatory links sections
  /// at a time. Navigation between sections is done through the NavigationTabTroupsTabsView. Mandatory Communities 
  /// with tab are displayed in the My Communities list when on a community page. When not inside a community,
  /// mandatory communities are listed in their own section. 
  /// This view is used by NavTypeTabGroupsLeftVertical in the Left side section. It uses helper functions
  /// in NavigationCommonVerticalView and relies on the NavigationTabGroupsTabsView to navigate between
  /// different areas of the portal.
  /// No javascript is used.
  /// </summary>
  /// <author>RobertZ</author>
  public class NavigationTabGroupsLeftVerticalView : NavigationCommonVerticalView,IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationTabGroupsLeftVerticalView");
    
    /// <summary>
    /// MVC name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationTabGroupsLeftVertical";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationTabGroupsLeftVerticalView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IPluggableNavModelRO) model;
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection myGroup = new HTMLElementCollection();
      HTMLElement result = myGroup;
      try
      {
        // Outer table
        HTMLTable table = new HTMLTable();
        table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        table.SetCellPadding(CommonHTMLStrings.ZERO);
        table.SetCellSpacing(CommonHTMLStrings.ZERO);
        HTMLElementCollection col = new HTMLElementCollection();
        // "Inside this Community" section, community pages
        if (NavPageType.COMMUNITY == m_model.GetCurNavPageType())
        {
          WriteMyCommunitiesSection(col);
        }
        if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType())
        {
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
          {
            if (NavPageType.MYPAGE == m_model.GetCurNavPageType())
            {
              WriteMyPagesSection(col);
            }
          }
          // Only show the mandatory communities when not on a community page, mandatory comms
          // already in my communities.
          if (NavPageType.COMMUNITY != m_model.GetCurNavPageType())
          {
            WriteMandatoryCommunitiesSection(col);
          }
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
          {
            if (NavPageType.DIRECTORY == m_model.GetCurNavPageType())
            {
              WriteDocumentsSection(col);
            }
          }
          // Mandatory Links section				
          WriteMandatoryLinksSection(col);
        }
        result.AddInnerHTMLElement(col);
      }
      catch (Exception e)
      {
        log.Error(e, "Could not display tabbed left vertical navigation view.");
        return new HTMLGenericElement("Error displaying Tabbed Left Vertical Bar");
        }
      return result;
    }
  }
}