using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalnavigation.common.constants;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.browsing.objectselection.communities;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalnavigation.views
{
  /// <summary>
  /// Horizontal tabs for selecting links sections in NavigationTabGroupsLeftVerticalView
  /// This navigation view displays tabs for My Pages, My Communities, Directory and Administration.
  /// Clicking on the My Communities tab goes to the first community in a user's community list.
  /// This view is used by NavTypeTabGroupsLeftVertical in the Below banner section. It works together
  /// with NavigationTabGroupsLeftVerticalView, which provides navigation inside each feature area.
  /// </summary>
  /// <author>robertz</author>
  public class NavigationTabGroupsTabsView : NavigationCommonVerticalView,IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalnavigation.views.NavigationTabGroupsTabsView");
    private AActivitySpace m_asOwner;
    private IPluggableNavModelRO m_model;
    
    /// <summary>
    /// Truncation width of the strings in the tabs *
    /// </summary>
    public const int TABGROUPS_TAB_TRUNCATION_WIDTH = 17;
    
    /// <summary>
    /// MVC Name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationTabGroupsTabs";
    private const String JS_EDIT_PROFILE_NO_COMM_ALERT = "showEditProfileNoCommAlert";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationTabGroupsTabsView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(150);
      sb.Append("function " + JS_EDIT_PROFILE_NO_COMM_ALERT + "()\n").Append("{\n").Append("\talert(\'" + m_asOwner.GetString(757,
       ResourceConstants.PORTALCOMMONMSGS) + "\');").Append("}\n");
      script.AddInnerHTMLString(sb.ToString());
      return script;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IPluggableNavModelRO) model;
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        // Outer table
        HTMLTable tabs = new HTMLTable();
        result.AddInnerHTMLElement(tabs);
        tabs.SetCellSpacing(CommonHTMLStrings.ZERO);
        tabs.SetCellPadding(CommonHTMLStrings.ZERO);
        tabs.SetBorder(CommonHTMLStrings.ZERO);
        tabs.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        tabs.SetID("tabbedleftverticaltable");
        HTMLTableRow row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.NAV_TABOFF_BG);
        tabs.AddInnerHTMLElement(row);
        HTMLAnchor anchor;
        ASURL url;
        HTMLElementCollection col;
        HTMLImg img;
        // bjf -- adding a spacer before the first tab, bug 14394.
        NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
        if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType())
        {
          // My page tabs
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
          {
            img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_MYPAGE,
             true, this.m_asOwner).GetHTMLElement();
            img.SetBorder(CommonHTMLStrings.ZERO);
            img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
            String mypage = GeneralHelpers.TruncateLongString(m_asOwner.GetString(260,
             ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH,
             false);
            img.SetAlt(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS));
            // If selected tab, just make label, not a link
            bool bIsMyPage = NavPageType.MYPAGE == m_model.GetCurNavPageType();
            if (bIsMyPage)
            {
              col = new HTMLElementCollection();
              col.AddInnerHTMLElement(img);
              col.AddInnerHTMLString(mypage);
              row.AddInnerHTMLElement(CreateTab(col, true));
            } else
            {
              url = new ASURL(m_asOwner);
              url.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
              url.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
              url.AddControlArgument(SetPageControl.STR_PAGE_ID, 0);
              url.AddInnerHTMLElement(img);
              url.AddInnerHTMLString(mypage);
              anchor = (HTMLAnchor) url.GetURLAsHTMLElement();
              anchor.SetTitle(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS));
              row.AddInnerHTMLElement(CreateTab(anchor, bIsMyPage));
            }
            // Spacer cell after the tab
            NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
          }
          // My Communities tab
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
          {
            img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
             true, this.m_asOwner).GetHTMLElement();
            img.SetBorder(CommonHTMLStrings.ZERO);
            img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
            String comm = GeneralHelpers.TruncateLongString(m_asOwner.GetString(252,
             ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH,
             false);
            img.SetAlt(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
            // If selected tab, just make label, not a link
            bool bIsComm = NavPageType.COMMUNITY == m_model.GetCurNavPageType();
            if (bIsComm)
            {
              col = new HTMLElementCollection();
              col.AddInnerHTMLElement(img);
              col.AddInnerHTMLString(comm);
              row.AddInnerHTMLElement(CreateTab(col, true));
            } else
            {
              url = new ASURL(m_asOwner);
              // AGC- Bug# 12782. This link was originally assuming that a some community was available
              // and selected. This caused errors because it failed to take into account missing default
              // communities or even having no community selected at all. Here's the proper behavior:
              // 1. Go to comm page (if specified)
              // 2. If no access to comm page -> Go to default comm
              // 3. If no default comm -> Join comm page
              int nDefaultPageID = m_model.GetDefaultCommunity();
              nDefaultPageID = m_model.GetAccessibleCommunityID(nDefaultPageID);
              bool bIsEditProfileNoCommunities = false;
              if (nDefaultPageID != -1)
              {
                url.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME,
                 m_asOwner);
                url.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
                url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
                 nDefaultPageID);
                url.AddControlArgument(SetCommunityControl.STR_PAGE_ID, 0);
                log.Debug("Creating link to default community with id: " + nDefaultPageID);
                } else
              if (m_model.IsEditProfile())
              {
                bIsEditProfileNoCommunities = true;
              } else
              {
                // No valid community, go to the join communities editor
                url.SetLinkCreateNewSpace(CommunitySelectionEditorAS.STR_MVC_CLASS_NAME,
                 m_asOwner);
                url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
                url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
                 EditorStartControl.EDITOR_START_FLAG_MISC);
                log.Debug("No Community memberships, creating link to community selection page.");
                }
              if (bIsEditProfileNoCommunities)
              {
                anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
                anchor.SetOnClick(JS_EDIT_PROFILE_NO_COMM_ALERT + "(); return false;");
                anchor.AddInnerHTMLElement(img);
                anchor.AddInnerHTMLString(comm);
              } else
              {
                url.AddInnerHTMLElement(img);
                url.AddInnerHTMLString(comm);
                anchor = (HTMLAnchor) url.GetURLAsHTMLElement();
              }
              anchor.SetTitle(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
              row.AddInnerHTMLElement(CreateTab(anchor, bIsComm));
            }
            // Spacer cell after the tab
            NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
          }
          // Directory tab
          if (m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
          {
            img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT,
             true, this.m_asOwner).GetHTMLElement();
            img.SetBorder(CommonHTMLStrings.ZERO);
            img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
            String directory = GeneralHelpers.TruncateLongString(m_asOwner.GetString(254,
             ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH,
             false);
            img.SetAlt(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS));
            // If selected tab, just make label, not a link
            bool bIsDirPage = NavPageType.DIRECTORY == m_model.GetCurNavPageType();
            if (bIsDirPage)
            {
              col = new HTMLElementCollection();
              col.AddInnerHTMLElement(img);
              col.AddInnerHTMLString(directory);
              row.AddInnerHTMLElement(CreateTab(col, true));
            } else
            {
              // Create a link to the directory page
              url = new ASURL(m_asOwner);
              if (DirAS.STR_MVC_CLASS_NAME.Equals(m_asOwner.GetName()))
              {
                url.SetLinkGetCachedSpace(m_asOwner);
              } else
              {
                url.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
                }
              url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
              url.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, DirConstants.BROWSE_MODE);
              url.AddInnerHTMLElement(img);
              url.AddInnerHTMLString(directory);
              anchor = (HTMLAnchor) url.GetURLAsHTMLElement();
              anchor.SetTitle(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS));
              row.AddInnerHTMLElement(CreateTab(anchor, bIsDirPage));
            }
            // Spacer cell after the tab
            NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
          }
          // Link to administrative portal
          if (m_model.HasAdministratorAccess())
          {
            img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ADMINISTRATION,
             true, this.m_asOwner).GetHTMLElement();
            img.SetBorder(CommonHTMLStrings.ZERO);
            img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
            String admin = GeneralHelpers.TruncateLongString(m_asOwner.GetString(275,
             ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH,
             false);
            // Administration					
            img.SetAlt(m_asOwner.GetString(275, ResourceConstants.PORTALCOMMONMSGS));
            // Get the link to the admin portal
            ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.ADMIN,
             false);
            CListURLFullLinkMediator mediator = new CListURLFullLinkMediator(m_asOwner,
             cpList);
            HTMLAnchor adminURL = null;
            if (cpList.Next())
            {
              adminURL = (HTMLAnchor) mediator.GetEntry();
            }
            // If selected tab, just make label, not a link		
            bool bIsAdminPage = ObjMgrAS.STR_MVC_CLASS_NAME == m_asOwner.GetName();
            if (bIsAdminPage)
            {
              col = new HTMLElementCollection();
              col.AddInnerHTMLString(admin);
              row.AddInnerHTMLElement(CreateTab(col, true));
            } else
            {
              row.AddInnerHTMLElement(CreateTab(adminURL, false));
            }
          }
        }
        // Spacer filler cell to fill out the remaining space
        HTMLTableCell cell = new HTMLTableCell();
        cell = new HTMLTableCell();
        cell.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        row.AddInnerHTMLElement(cell);
      }
      catch (Exception e)
      {
        log.Error(e, "Error displaying navigation section tabs, error: " + e.Message);
        return new HTMLGenericElement("Error displaying section tabs: " + e.Message);
        }
      return result;
    }
    
    /// <summary>
    /// Helper function that returns an HTMLTableCell with a clickable navigation tab
    /// </summary>
    /// <param name="element">Either a link from an ASURL or just an image with label</param>
    /// <param name="bOn">True if the current tab is the selected one</param>
    /// <returns>HTMLTableCell	HTMLTableCell with </returns>
    /// <throws>Exception</throws>
    public virtual HTMLTableCell CreateTab(HTMLElement element, bool bOn)
    {
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.NAV_TAB_TEXT);
      span.AddInnerHTMLString("&nbsp;&nbsp;");
      span.AddInnerHTMLElement(element);
      span.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;");
      // Different stylesheet if currently selected
      HTMLTableCell cell = new HTMLTableCell();
      if (bOn)
      {
        cell.SetStyleClass(PTStyleClass.NAV_TAB_ON_WHITE_BG);
      }
      cell.SetHeight("20");
      cell.SetWidth("160");
      cell.SetAlign(CommonHTMLStrings.MIDDLE);
      cell.SetNoWrap(true);
      cell.AddInnerHTMLElement(span);
      return cell;
    }
  }
}