package com.plumtree.portalnavigation;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalnavigation.common.constants.*;
import com.plumtree.portalnavigation.views.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The NavType for Accessible Navigation
 * 
 * @author MichaelD
 *
 */
public class NavTypeAccessible implements INavTypes
{
	
	/**
	 * 
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetID()
	 */
	public int GetID()
	{
		return NavTypeConstants.NAVTYPE_ID_ACCESSIBLE;
	}

	/**
	 * 
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetName(String)
	 */
	public String GetName(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(759, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetScope(String)
	 */
	public String GetScope(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager()
			.GetEntry("ResourceManager");

		return rm.GetString(760, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
	}
	
	/** 
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetNavAreaView(com.plumtree.portaluiinfrastructure.navtype.NavAreaEnum)
	 **/
	public String GetNavAreaView(NavAreaEnum area)
	{
		if (area.equals(NavAreaEnum.LEFTOFBODY))
		{
			return NavigationAccessibleLeftVerticalView.STR_MVC_CLASS_NAME;
		}
		else if (area.equals(NavAreaEnum.ABOVEBODY))
		{
			return NavigationAccessibleAboveBodyView.STR_MVC_CLASS_NAME;
		}
		else if (area.equals(NavAreaEnum.BELOWBODY))
		{
			return NavigationAccessibleBelowBodyView.STR_MVC_CLASS_NAME;
		}
		else if (area.equals(NavAreaEnum.TOPBAR))
		{
			return PlumtreeTopBarView.STR_MVC_CLASS_NAME;
		}
		
		return null;
	}
		
	/**
	 *
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#JavaScriptIncludes()
	 */
	public HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner)
	{
		return null;
	}
	
	/** 
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#IsFeatureEnabled(com.plumtree.portaluiinfrastructure.navtype.NavFeatureEnum)
	 **/
	public boolean IsFeatureEnabled( NavFeatureEnum feature )
	{	
		return true;
	}
}


