/**
 * Created on Mar 20, 2003
 */
package com.plumtree.portalnavigation;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalnavigation.common.constants.*;
import com.plumtree.portalnavigation.views.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * Now supports browser detection internally.
 * 
 * The views in this navtype support auto-browser handling and can be used by external
 * custom navigations.
 * 
 * Custom navs that use the views offereed by this nav must also 
 * use the javascript functions offered by this nav, which also
 * switch down per-browser.
 * 
 * @author robertz
 * @author DavidP
 * @author DustinA
 *
 */
public class NavTypeJSPortalMenuDropDown implements INavTypes 
{

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetID()
	 */
	public int GetID() {
		return NavTypeConstants.NAVTYPE_ID_HORIZONTAL_DHTML_DROPDOWN_JSPORTALMENU;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetName(java.lang.String)
	 */
	public String GetName(String _strLangID) {
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
   		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

		return rm.GetString(671, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetScope(java.lang.String)
	 */
	public String GetScope(String _strLangID) {
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
   		XPResourceManager rm     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

		return rm.GetString(672, ResourceConstants.PORTALCOMMONMSGS, _strLangID);
	}
	
	/** 
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#GetNavAreaView(com.plumtree.portaluiinfrastructure.navtype.NavAreaEnum)
	 **/
	public String GetNavAreaView(NavAreaEnum area)
	{
		if (area.equals(NavAreaEnum.BELOWBANNER))
		{
			return NavigationCommSectionDropDownView.STR_MVC_CLASS_NAME;
		}
		else if (area.equals(NavAreaEnum.ABOVEBANNER))
		{
			return NavigationJSPortalMenuDropDownView.STR_MVC_CLASS_NAME;
		}
		else if (area.equals(NavAreaEnum.TOPBAR))
		{
			return PlumtreeTopBarView.STR_MVC_CLASS_NAME;
		}
		
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#JavaScriptIncludes()
	 */
	public HTMLScriptCollection JavaScriptIncludes(AActivitySpace owner)
	{
		HTMLScriptCollection result = new HTMLScriptCollection();
		
		// use browser detection to include the appropriate javascript
		BrowserType browser = (BrowserType) owner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
		
		// DAP Key Note on Browser Mapping: We do mapping here to allow others to use this view in custom 
		// navigations as a nested view
				
		// Combobox Menus: Netscape 4 All Platforms, Macintosh Safari
		// Safari note: Must wait until Konqueror supports W3C spec 
		// for Javascript, slated for Safari 2.0
		// Also get combobox for anything we don't recognize
		// Note: Bug in IE on Mac forces us to combobox
		if ( !browser.IsJSPortalMenuCompliant() )
		{
			INavTypes navType = new NavTypeHorizontalComboBox();
			result.AddInnerHTMLElement(navType.JavaScriptIncludes(owner));
		}				
		// JS Portal Menu CommunityTabs: Netscape > 4 All Platforms, and IE all platforms 
		else 
		{
				
			// Javascript required for jsportalmenus
			result.AddInnerHTMLElement( NavigationJSPortalMenuHelpers.GetPlumtreeJSFrameworkJavaScript(owner) );
			
			// Override js variables from NavigationSettings.xml
			// Width of each entry in the menus
			int nMenuCellWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTISCDROPDOWNMENU_WIDTH, owner); 
			if ( -1 != nMenuCellWidth )
			{ 
				HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
				script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value"); 
				script.AddInnerHTMLString("\n\tgMenuCellWidth = "+nMenuCellWidth+";");
				result.AddInnerHTMLElement(script);
			}
			// Override js variables from NavigationSettings.xml
			// Width of the tabs to open dropdown menus
			int nNavTabWidth = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_WIDTH, owner); 
			if ( -1 != nNavTabWidth )
			{ 
				HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
				script.AddInnerHTMLString(" // Overriding default value with NavigationSettings.xml value");
				script.AddInnerHTMLString("\n\tgHorizontalTabWidth = "+nNavTabWidth+";");
				result.AddInnerHTMLElement(script);
			}

			// Send down localized string down to js for image alts in dynamic generated html
			HTMLScript scriptMenu = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			String imgAlt = owner.GetString(673, ResourceConstants.PORTALCOMMONMSGS);
			scriptMenu.AddInnerHTMLString("var gNavTabDownArrowImageAlt = '"+ imgAlt +"';");
			result.AddInnerHTMLElement(scriptMenu);
			
		
			// Check for minimized browser window during page load. Will sometimes cause the calculations for the
			// positioning of menu tabs to be off. Reload the page when the window is restored if this is the case.
			HTMLScript ss = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			ss.AddInnerHTMLString("document.PCC.RegisterForWindowEvent(\"onfocus\", CheckForPageReload);");
			result.AddInnerHTMLElement(ss);
		}
		
		return result;
	}

	
	/** 
	 * @see com.plumtree.portaluiinfrastructure.navtype.INavTypes#IsFeatureEnabled(com.plumtree.portaluiinfrastructure.navtype.NavFeatureEnum)
	 **/
	public boolean IsFeatureEnabled( NavFeatureEnum feature )
	{	
		return true;
	}
}

