package com.plumtree.portalnavigation.views;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Accessible navigation view (used for 508, and low bandwidth).
 * 
 * This view displays actions for the My Pages, My Communities, Directory 
 * sections. 
 * 
 * This view is used by NavTypeAccessible in the Above Body section.
 * 
 * No javascript is used.
 *
 * @author MichaelD
 */
public class NavigationAccessibleAboveBodyView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalnavigation.views.NavigationAccessibleAboveBodyView");

	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "NavigationAccessibleAboveBody";
	
	public static final String STR_OPTIONS_ANCHOR = "options";

	protected AActivitySpace m_asOwner;
	protected IPluggableNavModelRO m_model;

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = null;
		
		try
		{
				result = WriteOptionsJumpLink();
		}
		catch (Exception e)
		{
			
				log.Error(e, "Could not display accessible above body navigation view.");
			
		}
			
		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  	= (IPluggableNavModelRO) model;
		m_asOwner     = parent;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NavigationAccessibleAboveBodyView();
	}	

	protected HTMLElementCollection WriteOptionsJumpLink()
		throws HTMLException, Exception
	{
		String strLink;
		if ( NavPageType.COMMUNITY == m_model.GetCurNavPageType() ) 
		{
			strLink = m_asOwner.GetString(762, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS);
		}
		else if ( NavPageType.MYPAGE == m_model.GetCurNavPageType() ) 
		{
			strLink = m_asOwner.GetString(761, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS);
		}
		else
		{
			return null;
		}
		HTMLElementCollection col = new HTMLElementCollection();
		
		HTMLTable table = new HTMLTable();
		col.AddInnerHTMLElement(table);
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		
		HTMLTableRow row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);
		
		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetAlign(CommonHTMLStrings.RIGHT);
		cell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		
		HTMLAnchor anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL + STR_OPTIONS_ANCHOR);
		cell.AddInnerHTMLElement(anchor);
		anchor.AddInnerHTMLString(strLink);
		anchor.SetTitle(strLink);
		
		return col;
	}
}

