package com.plumtree.portalnavigation.views;

import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portalpages.common.uiparts.navpagetype.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Accessible navigation view (used for 508, and low bandwidth).
 * 
 * This view displays My Pages, My Communities, Directory and mandatory links in vertical 
 * sections. Mandatory Communities with tab are not displayed separately from the My Communities section. 
 * 
 * This view is used by NavTypeAccessible in the Above Body section. It uses helper functions
 * in NavigationCommonVerticalView. 
 * 
 * No javascript is used.
 *
 * @author MichaelD
 */
public class NavigationAccessibleLeftVerticalView extends NavigationCommonVerticalView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalnavigation.views.NavigationAccessibleLeftVerticalView");

	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "NavigationAccessibleLeftVertical";
	
	/** The maximum length of strings before truncation for accessible menu: Needs to be long enough for Community Members and Knowledge Directory **/ 
	public static final int ACCESSIBLE_MENU_TEXT_MAX_LENGTH = 31;

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		
		HTMLElementCollection col = new HTMLElementCollection();

		try
		{
			if ( NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType() ) 
			{	
				// DCA - check if we should show My Pages
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
				{
					Write508Section(col,
						m_asOwner.GetString(260, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
						m_model.GetCategoryLinks(NavCategoryType.MYPAGE, false),
						m_asOwner.GetString(765, ResourceConstants.PORTALCOMMONMSGS),
						false);
				}
				
				// DCA - check if we should show Communities
				if (m_model.GetSubPortalEnabled(
						PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
				{	
					Write508MyCommunitiesSection(col);
				}
				
				// DCA - check if we should show the Directory
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
				{
					Write508Section(col, 
						m_asOwner.GetString(254, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS), 
						m_model.GetCategoryLinks(NavCategoryType.DIRECTORY, false),
						m_asOwner.GetString(766, ResourceConstants.PORTALCOMMONMSGS),
						false);
				}
			
				// Display the mandatory links menu
				Write508Section(col,
					m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK),
					m_model.GetCategoryLinks(NavCategoryType.MANDATORYLINK, false),
					m_asOwner.GetString(716, ResourceConstants.PORTALCOMMONMSGS),
					true);	
			}

			// Display 508 access key table (shortcuts) and skip nav link
			Write508ShortcutsSection(result);
			
			result.AddInnerHTMLElement(col);

			WriteAdminLink(col);

			Write508JumpLink(result);
		}
		catch (Exception e)
		{
			
				log.Error(e, "Could not display accessible left vertical navigation view.");
			
		}
			
		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  	= (IPluggableNavModelRO) model;
		m_asOwner     = parent;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NavigationAccessibleLeftVerticalView();
	}	

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the current Community section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @throws Exception
	 * @throws HTMLException
	 */
	protected void Write508MyCommunitiesSection(HTMLElementCollection col)
		throws HTMLException, Exception
	{
		// Community Actions
		HTMLTable table = CreateHeaderTable(true);
		col.AddInnerHTMLElement(table);
		AddSectionHeaderRow(table,
			m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
		AddVerticalSpacerRow(table);

		// Current community pages + sub & related comms
		if (NavPageType.COMMUNITY == m_model.GetCurNavPageType()) 
		{
			CommunityNavPage commP = (CommunityNavPage) m_model.GetPageSpecificMethods();
			WriteCurCommunitySection(col, commP);
			AddVerticalSpacerRow(table);
		}

		// Populate the membership communities
		table = CreateListStartTable();
		col.AddInnerHTMLElement(table);
		
		if (NavPageType.COMMUNITY == m_model.GetCurNavPageType()) 
		{
			AddStandardListBoldRow(table, m_asOwner.GetString(664, ResourceConstants.PORTALCOMMONMSGS));
		}
	
		ICPListEntryIterator iterator = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES, false);

		if (iterator != null && iterator.GetTotalCount() > 0)
		{
			CListURLFullMediator mediator  = new CListURLFullMediator(m_asOwner, iterator);
			mediator.SetLabelMaxLength(ACCESSIBLE_MENU_TEXT_MAX_LENGTH);
			mediator.SetShowImages(false);
			
			while (mediator.Next())
			{
				AddStandardListRow(table, (HTMLElement) mediator.GetEntry());
			}
		}
		else
		{
			AddStandardListRow(table, new HTMLGenericElement(m_asOwner.GetString(768, ResourceConstants.PORTALCOMMONMSGS)));
		}
		AddVerticalSpacerRow(table);
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the directory section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @throws HTMLException
	 */
	protected void Write508Section(HTMLElementCollection col, String strTitle, ICPListEntryIterator iterator, String strIfIteratorEmpty, boolean bShowImages)
		throws HTMLException
	{
		HTMLTable table = CreateHeaderTable(true);
		col.AddInnerHTMLElement(table);
		AddSectionHeaderRow(table, strTitle);
		AddVerticalSpacerRow(table);

		table = CreateListStartTable();
		col.AddInnerHTMLElement(table);
		
		if (iterator != null && iterator.GetTotalCount() > 0)
		{
			CListURLFullMediator mediator = new CListURLFullMediator(m_asOwner, iterator);
			mediator.SetLabelMaxLength(ACCESSIBLE_MENU_TEXT_MAX_LENGTH);
			mediator.SetShowImages(bShowImages);
	
			while (mediator.Next())
			{
				AddStandardListRow(table, (HTMLElement)mediator.GetEntry());
			}
		}
		else
		{
			AddStandardListRow(table, new HTMLGenericElement(strIfIteratorEmpty));
		}
		AddVerticalSpacerRow(table);
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Community pages section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws HTMLException
	 */
	protected void WriteCommPages(HTMLElementCollection col, CommunityNavPage commP) throws HTMLException
	{

		ICPListEntryIterator cpList =commP.GetCurCommPages();
		CListURLFullMediator mediator   = new CListURLFullMediator(m_asOwner, cpList);
		mediator.SetLabelMaxLength(ACCESSIBLE_MENU_TEXT_MAX_LENGTH);
		HTMLTable table = CreateListStartTable();
		col.AddInnerHTMLElement(table);
		while (mediator.Next())
		{
			AddSUBSUBSectionListRow(table, (HTMLElement)mediator.GetEntry(), false);
		}
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a subsubsection link, 
	 * used for related and subcommunities section.=
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param element					The element link to add 	 
	 * @param bIndent					True to indent the string
	 * @throws HTMLException 
	 * 
	 */
	protected static void AddSUBSUBSectionListRow(HTMLTable table, HTMLElement element, boolean bIndent) throws HTMLException
	{
		if (null == element)
		{
			return;
		}
		HTMLTableRow tRow   = new HTMLTableRow();
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBAR_SUB_SUBSECTION_BG);
		table.AddInnerHTMLElement(tRow);
		
		HTMLTableCell tCell = null;

		if ( bIndent )
		{
			tCell = new HTMLTableCell();
			tRow.AddInnerHTMLElement(tCell);
			tCell.SetHeight("20");
			tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
			tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		} 
		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		
		tCell.AddInnerHTMLElement(element);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		
		tCell.SetColSpan( ((bIndent) ? "2" : "3") );
		tCell.SetHeight("20");
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a header bar
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param headerString				The header string
	 * @throws HTMLException 
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	protected void AddSectionHeaderRow(HTMLTable table, String headerString)
		throws HTMLException
	{
		HTMLTableRow tRow = new HTMLTableRow();
		tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
		table.AddInnerHTMLElement(tRow);

		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.SetWidth(CommonHTMLStrings.FIVE);
		tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		
		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		tCell.SetAlign(CommonHTMLStrings.LEFT);
		tCell.SetColSpan("2");
		
		HTMLH3 h3 = new HTMLH3();
		h3.AddInnerHTMLEncodedString(headerString);
		h3.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
		tCell.AddInnerHTMLElement(h3);
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with an HTMLAnchor link
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param anchor					The anchor link to add 	 
	 * @throws HTMLException 
	 * 	 
	 */
	protected static void AddStandardListRow(HTMLTable table, HTMLElement element)
		throws HTMLException
	{
		HTMLTableRow tRow   = new HTMLTableRow();
		HTMLTableCell tCell = new HTMLTableCell();
		
		if (null == element)
		{
			return;
		}

		tCell = new HTMLTableCell();
		table.AddInnerHTMLElement(tRow);
		tRow.AddInnerHTMLElement(tCell);
		tCell.AddInnerHTMLElement(element);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		tCell.SetColSpan("3");
		tCell.SetHeight("25");
	}
	
	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Subcommunity section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws HTMLException
	 */
	protected void AddCurCommSubSectionHeaderRow(HTMLElementCollection col, CommunityNavPage commP) throws HTMLException
	{
		HTMLTable table = CreateHeaderTable(true);
		col.AddInnerHTMLElement(table);
		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);

		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);

		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		tCell.SetWidth("100%");
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
		tCell.AddInnerHTMLString( XPHttpUtility.HtmlEncode(GeneralHelpers.TruncateLongString( commP.GetCurCommunityName(), ACCESSIBLE_MENU_TEXT_MAX_LENGTH, false)) );
	}
}

