/**
 * Created on Mar 21, 2003
 *
 */
package com.plumtree.portalnavigation.views;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.login.*;
import com.plumtree.portalpages.browsing.login.createaccount.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.portalsettings.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portalpages.browsing.search.network.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portalpages.common.uiparts.navpagetype.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.interpreter.filter.utils.*;
import com.plumtree.uiinfrastructure.login.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * Common parent class for vertical navigation schemes.
 * Contains variables and methods common for vertical schemes.  
 * 
 * @author robertz
 */
public class NavigationCommonVerticalView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalnavigation.views.NavigationCommonVerticalView");

	/** The name of the anchor used to skip past the navigation in 508 mode. */
	private static final String STR_SKIP_ANCHOR = "skip";

	/** string constants for performance. */
	private static final String STR_EMPTY		 = "";
	private static final String STR_508_XML_FILE = "ptmsgs_portal508quickkeymsgs";

	/** The maximum length of strings before truncation **/ 
	public static final int	MENU_TEXT_MAX_LENGTH  = 26;

	protected AActivitySpace m_asOwner;
	protected IPluggableNavModelRO m_model;


	/////////////////////
	// 508 helper methods
	/////////////////////

	/**
	 * This method displays the hidden link after the navigation banner so that
	 * 508 users can skip the navigation.
	 * This is mainly relevant for IE.
	 *
	 * @param HTMLElementCollection the collection to add the shortcut section to.
	 */
	public void Write508JumpLink(HTMLElementCollection result)
		throws HTMLException
	{
		HTMLAnchor myAnchor;

		myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
		myAnchor.SetName(STR_SKIP_ANCHOR);
		myAnchor.SetTitle(m_asOwner.GetString(40, STR_508_XML_FILE));

		result.AddInnerHTMLElement(myAnchor);
	}

	/**
	 * This method displays the access key shortcuts for the 508 banner.
	 * This is mainly relevant for IE.
	 *
	 * These entries need to appear every time, unlike the normal navigation
	 * bar, where
	 *
	 * @param HTMLElementCollection the collection to add the shortcut section to.
	 */
	public void Write508ShortcutsSection(HTMLElementCollection result)
		throws HTMLException
	{
		/**
		 * we'll use myAnchor to pass to the view
		 * and med anchor to get an anchor from a mediator (the mediator anchors
		 * have labels set that we can't change, so we'll get the medAnchor and
		 * pass the HREF to the myAnchor.
		 */

		HTMLAnchor myAnchor, medAnchor;
		ICPListEntryIterator cpList;
		// Use an ASURL Link Mediator because we only want active links, not labels.
		CListURLFullLinkMediator mediator;

		// Y -- Skip navigation
		myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL +
				STR_SKIP_ANCHOR);
		myAnchor.SetAccessKey(m_asOwner.GetString(0, STR_508_XML_FILE));
		myAnchor.SetTitle(m_asOwner.GetString(13, STR_508_XML_FILE));
		result.AddInnerHTMLElement(myAnchor);

		// Common keys for all users
		// M -- My page home page
		// Just get the first mypage in the list
		
		
		cpList		 = m_model.GetCategoryLinks(NavCategoryType.MYPAGE, false);
		mediator     = new CListURLFullLinkMediator(m_asOwner, cpList);
		mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

		// The first myPage entry should be the users default mypage
		if (mediator.Next())
		{
			medAnchor = (HTMLAnchor) mediator.GetEntry();
			if(medAnchor != null)
			{
				myAnchor = new HTMLAnchor(STR_EMPTY);
				myAnchor.SetHRef(medAnchor.GetHRef());
				myAnchor.SetAccessKey(m_asOwner.GetString(1, STR_508_XML_FILE));
				myAnchor.SetTitle(m_asOwner.GetString(14, STR_508_XML_FILE));
				result.AddInnerHTMLElement(myAnchor);
			}
		}

		// C -- Default community home page
		// Get the first mandatory community; if there's none, get first community
		medAnchor = null;

		boolean bMandatory = false;
		cpList		 = m_model.GetCategoryLinks(NavCategoryType.MANDATORYTABS, false);
		mediator     = new CListURLFullLinkMediator(m_asOwner, cpList);
		mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

		if (0 != cpList.GetTotalCount())
		{
			if (mediator.Next())
			{
				medAnchor	   = (HTMLAnchor) mediator.GetEntry();
				bMandatory     = true;
			}
		}

		// No mandatory found, get first community
		if (!bMandatory)
		{
			cpList		 = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES, false);
			mediator     = new CListURLFullLinkMediator(m_asOwner, cpList);
			mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

			if (mediator.Next())
			{
				medAnchor = (HTMLAnchor) mediator.GetEntry();
			}
		}

		if (medAnchor != null)
		{
			myAnchor = new HTMLAnchor(STR_EMPTY);
			myAnchor.SetHRef(medAnchor.GetHRef());
			myAnchor.SetAccessKey(m_asOwner.GetString(2, STR_508_XML_FILE));
			myAnchor.SetTitle(m_asOwner.GetString(15, STR_508_XML_FILE));
			result.AddInnerHTMLElement(myAnchor);
		}

		cpList		 = m_model.GetCategoryLinks(NavCategoryType.DIRECTORY, false);
		mediator     = new CListURLFullLinkMediator(m_asOwner, cpList);
		mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

		// B -- Browse for documents
		if (mediator.Next())
		{
			medAnchor = (HTMLAnchor) mediator.GetEntry();
			if(medAnchor != null)
			{
				myAnchor = new HTMLAnchor(STR_EMPTY);
				myAnchor.SetHRef(medAnchor.GetHRef());
				myAnchor.SetAccessKey(m_asOwner.GetString(3, STR_508_XML_FILE));
				myAnchor.SetTitle(m_asOwner.GetString(16, STR_508_XML_FILE));
				result.AddInnerHTMLElement(myAnchor);
			}
		}

		if (!m_model.IsGuestSession())
		{
			// Common keys for non-guest users

			// Q -- Advanced Search for documents
			ASURL advsearch = new ASURL(m_asOwner);
			advsearch.SetLinkCreateNewSpace(AdvancedSearchAS.STR_MVC_CLASS_NAME, m_asOwner);
			advsearch.SetLinkTitle(m_asOwner.GetString(339, ResourceConstants.PORTALCOMMONMSGS));
			advsearch.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			advsearch.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
			myAnchor = (HTMLAnchor) advsearch.GetURLAsHTMLElement();
			myAnchor.SetAccessKey(m_asOwner.GetString(5, STR_508_XML_FILE));
			myAnchor.SetTitle(m_asOwner.GetString(18, STR_508_XML_FILE));
			result.AddInnerHTMLElement(myAnchor);

			// N -- Search Other Networks
			ASURL netsearch = new ASURL(m_asOwner);
			netsearch.SetLinkCreateNewSpace(NetworkSearchAS.STR_MVC_CLASS_NAME, m_asOwner);
			netsearch.SetLinkTitle(m_asOwner.GetString(340, ResourceConstants.PORTALCOMMONMSGS));
			netsearch.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
			myAnchor = (HTMLAnchor) netsearch.GetURLAsHTMLElement();
			myAnchor.SetAccessKey(m_asOwner.GetString(6, STR_508_XML_FILE));
			myAnchor.SetTitle(m_asOwner.GetString(19, STR_508_XML_FILE));
			result.AddInnerHTMLElement(myAnchor);

			// W -- My Account (Portal Settings). 
			ASURL myAccount = new ASURL(m_asOwner);
			myAccount.SetLinkCreateNewSpace(PortalSettingsAS.STR_MVC_CLASS_NAME, m_asOwner);
			myAccount.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			myAccount.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
			myAnchor = (HTMLAnchor) myAccount.GetURLAsHTMLElement();
			myAnchor.SetAccessKey(m_asOwner.GetString(8, STR_508_XML_FILE));
			myAnchor.SetTitle(m_asOwner.GetString(21, STR_508_XML_FILE));
			result.AddInnerHTMLElement(myAnchor);

			// L -- Log Off
			myAnchor = new HTMLAnchor(STR_EMPTY);

			// IsEditProfile is used because NavPageType.USERPROFILE is deprecated and will be removed in the next version.
			if(!m_model.IsEditProfile())
			{
				ASURL logoff = new ASURL(m_asOwner);
				logoff.SetLinkGetSpaceIfCached(LoginAS.STR_MVC_CLASS_NAME, m_asOwner);
				logoff.SetControl(LoginControl.STR_MVC_CLASS_NAME);
				logoff.AddControlArgument(LoginHelper.PARAM_DOLOGOUT);

				try
				{
					myAnchor = (HTMLAnchor) logoff.GetURLAsHTMLElement();
					myAnchor.SetAccessKey(m_asOwner.GetString(10,
							STR_508_XML_FILE));
					myAnchor.SetTitle(m_asOwner.GetString(23, STR_508_XML_FILE));
					result.AddInnerHTMLElement(myAnchor);
				}
				catch (Exception e)
				{
					// no handling - URL is a label and didn't cast
				}
			}
		}
		else
		{
			// common keys for guest users
			// U -- Create an Account
			if(PTLoginHelper.GetAllowUserCreation(m_asOwner, m_asOwner.GetApplication()))
			{
				ASURL createAccount = new ASURL(m_asOwner);
				createAccount.SetLinkCreateNewSpace(CreateAccountAS.STR_MVC_CLASS_NAME, m_asOwner);
				createAccount.SetControl(CreateAccountControl.STR_MVC_CLASS_NAME);
				myAnchor = (HTMLAnchor) createAccount.GetURLAsHTMLElement();
				myAnchor.SetAccessKey(m_asOwner.GetString(12, STR_508_XML_FILE));
				myAnchor.SetTitle(m_asOwner.GetString(25, STR_508_XML_FILE));
				result.AddInnerHTMLElement(myAnchor);
			}
		}

		// more common keys for all users
		// H -- Help
		HTMLAnchor helpAnchor = HTMLConstructHelpers.GetHelpAnchor( m_asOwner );
		myAnchor = new HTMLAnchor(STR_EMPTY);
		myAnchor.SetHRef(helpAnchor.GetHRef());
		myAnchor.SetAccessKey(m_asOwner.GetString(11, STR_508_XML_FILE));
		myAnchor.SetTitle(m_asOwner.GetString(24, STR_508_XML_FILE));
		result.AddInnerHTMLElement(myAnchor);
		
		result.AddInnerHTMLElement(Get508PortletAccessAnchors());
	}
	
	/**
	 * Return a collection of access key anchors elements pointing to each portlet
	 * displayed.
	 * 
	 * @return
	 */
	protected HTMLElementCollection Get508PortletAccessAnchors() {
		if (m_asOwner.GetIsAccessStyleStandard())
		{
			return null;				
		}
		
		if ( m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME) )
		{
			MyPortalModel mpModel = (MyPortalModel)m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME); 
			HTMLElementCollection elementCollection = new HTMLElementCollection();
			int j = 0;
			for (int i = 0; i < mpModel.GetPortletCount(); i++)
			{
				if (mpModel.GetPortletSupports508(i))
				{
					String strPortletName = XPHttpUtility.HtmlEncode(mpModel.GetPortletNameFromIndex(j));
					String strPortletIndex = XPConvert.ToString(j);
					HTMLAnchor htmlAnchor = new HTMLAnchor("#" + strPortletIndex);
					htmlAnchor.SetTitle(
						XPResourceManager.FormatMessage(
							m_asOwner.GetString(33, ResourceConstants.PORTAL508QUICKKEYMSGS), 
								strPortletIndex, strPortletName));
					htmlAnchor.SetAccessKey(strPortletIndex);
					elementCollection.AddInnerHTMLElement(htmlAnchor);
					j++;
				}						
			}
			return elementCollection;
		}
		return null;		
	}

	/////////////////////////
	// Generic helper methods
	/////////////////////////
	
	/**
	 * Helper method that creates an HTMLTable to start a list
	 * 
	 * @return Table template for lists 
	 */
	public static HTMLTable CreateListStartTable()
	{
		HTMLTable table = new HTMLTable();
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		table.SetCellPadding("5");
		table.SetCellSpacing("0");
		table.SetBorder("0");
		
		return table;
	}

	/**
	 * Helper method that creates a header HTMLTable 
	 * 
	 * @param bSpacer				True to add a spacer row below the header
	 * @return Table template for headers
	 */	
	public static HTMLTable CreateHeaderTable(boolean bSpacer)
	{
		HTMLTable table = new HTMLTable();
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		table.SetCellPadding("0");
		table.SetCellSpacing("0");
		table.SetBorder("0");
		
		if ( bSpacer ) {
			AddVerticalSpacerRow(table);
		}
		
		return table;
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with just a string and no anchor to 
	 * the specified HTMLTable.
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param text 						Label to add
	 *
	 * @throws HTMLException 
	 */
	public static void WriteTextRow(HTMLTable table, String text)
		throws HTMLException
	{
		HTMLTableRow tRow = new HTMLTableRow();

		HTMLTableCell tCell = new HTMLTableCell();
		table.AddInnerHTMLElement(tRow);
//		tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
//		tRow.AddInnerHTMLElement(tCell);

//		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);

		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		tCell.AddInnerHTMLString(text);
		tCell.SetColSpan("3");
	}

	/**
	 * Generates the ASURL with just the URL to the control for collapse/expanding 
	 * vertical navigation sections.
	 * 
	 * 
	 * @param nSectionID				NavVisibility ID of the navigation section
	 * @param bCollapsed				True if the entire section is collapsed
	 * @return ASURL					Generated ASURL with just the URL
	 * 
	 * @throws HTMLException 
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	protected ASURL GetCollapseExpandURL(int nSectionID, boolean bCollapse)
	{
		ASURL url = new ASURL(m_asOwner);
		url.SetLinkGetSpaceIfCached(m_asOwner.GetName(), m_asOwner);
		url.SetControl(NavigationControl.STR_MVC_CLASS_NAME);
		url.AddControlArgument( ((bCollapse) ? NavigationControl.ACTION_COLLAPSE : NavigationControl.ACTION_EXPAND),
								XPConvert.ToString(nSectionID));

		// Form up the components of the url; strip off the control args from the request 
		// for re-use, as that's the only way to deal with gatewayed prefs pages that are
		// in a subspace
		String fullUrl = m_asOwner.GetCurrentRequestURL();
		String normalizedUrl = m_asOwner.GetCurrentNormalizedBaseURL(); 
		String controlArgs = "";
		String baseUrl = "";
		String redirectUrl = "";
		String testUrl = fullUrl;
		
		// Form the correct base url you'll use later in forming the 
		// redirect url with control arguments
		baseUrl = ConfigHelper.GetApplicationBaseURLToAS(normalizedUrl,
			m_asOwner.GetName(), false);
		
		// Strip off control args for redirect based on separator				
		int iQSIndex = fullUrl.indexOf("?");
		if (-1 != iQSIndex)
		{
			controlArgs = fullUrl.substring(iQSIndex+1,fullUrl.length());
			testUrl = fullUrl.substring(0,iQSIndex);
		}
		
		// If this is a gateway url, set boolean
		int iGWIndex = testUrl.indexOf(GatewayHandlers.GATEWAY_UNIQUE);
		if (-1 != iGWIndex)
		{
			if (-1 == iQSIndex)
			{
				controlArgs = fullUrl.substring(iGWIndex+1,fullUrl.length());
			}
			
			// flip question mark to slash as we're gatewaying here			
			redirectUrl = baseUrl.substring(0,baseUrl.length()-1) + "/" +
							controlArgs;	
		}
		else
		{
			// Build the link; baseUrl already has question mark
			redirectUrl = baseUrl + controlArgs;
		}
			
		url.AddControlArgument(NavigationControl.PREV_PAGE_QSPARAM, redirectUrl );
		
		return url;
	}

	/**
	 * Gets the ASURL with image to collapse/expand vertical navigation sections 
	 * 
	 * @param nSectionID				NavVisibility ID of the navigation section
	 * @param bCollapsed				True if the entire section is collapsed
	 * @return ASURL					Generated ASURL with image for collapsing/expanding section
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	public ASURL GetSectionCollapseExpandURL(int nSectionID, boolean bCollapse)
	{
		ASURL url = GetCollapseExpandURL(nSectionID, bCollapse);
		
		HTMLImg image = null;
		try
		{
			image = (HTMLImg) UIConstructFactory.GetConstruct(((bCollapse)
					? PTImageType.ICON_ARROW_EXPAND
					: PTImageType.ICON_ARROW_COLLAPSE), true, this.m_asOwner)
				.GetHTMLElement();
		}
		catch (Exception e)
		{
			
				log.Error(e, "Could not display expand arror in simple navigation view.");
			
		}
		String altText = ((bCollapse)
			? m_asOwner.GetString(250, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS)
			: m_asOwner.GetString(251, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
		url.AddInnerHTMLElement(image);
		url.SetLinkTitle(altText);
		image.SetAlt(altText);
		image.SetHeight("16");
		image.SetWidth("16");
		image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		image.SetBorder(CommonHTMLStrings.ZERO);
		
		return url;
	}

	/**
	 * Gets the ASURL with image to collapse/expand vertical actions subsection
	 *
	 * @param nSectionID				NavVisibility ID of the navigation section
	 * @param bCollapsed				True if the entire section is collapsed
	 * @return ASURL					Generated ASURL with image for collapsing/expanding actions section
	 *
	 * @throws Exception
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	public ASURL GetActionCollapseExpandURL(int nSectionID, boolean bCollapse)
		throws HTMLException
	{
		ASURL url = GetCollapseExpandURL(nSectionID, bCollapse);
		
		HTMLImg htmlImg = (HTMLImg) UIConstructFactory.GetConstruct( ((bCollapse) ? PTImageType.ACTION_ACTIONBAR_EXPAND :
																					PTImageType.ACTION_ACTIONBAR_COLLAPSE),
																		true, this.m_asOwner).GetHTMLElement();

		htmlImg.SetAlt( ((bCollapse) ? m_asOwner.GetString(264, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS):m_asOwner.GetString(263, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS)) );
		htmlImg.SetHeight("25");
		htmlImg.SetWidth("25");
		htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		htmlImg.SetBorder(CommonHTMLStrings.ZERO);

		url.AddInnerHTMLElement(htmlImg);
		url.SetLinkTitle(((bCollapse) ? m_asOwner.GetString(264, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS):m_asOwner.GetString(263, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS)) );

		return url;
	}


	/**
	 * DCA - Creating HTML for Administration Button
	 * Don't need this function
	 * 
	 * @param table 					HTMLTable to add the generated row to
	 * @param asURL 					Administrator ASURL
	 *
	 * @throws HTMLException 
	 */
	protected static void AddAdminListRow(HTMLTable table, HTMLAnchor anchor)
		throws HTMLException
	{
		if (null == anchor)
		{
			return;
		}

		HTMLTableRow tRow = new HTMLTableRow();
		tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
		table.AddInnerHTMLElement(tRow);

		HTMLTableCell tCell = new HTMLTableCell();
		tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		tCell.SetHeight("20");
		tRow.AddInnerHTMLElement(tCell);

		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		tCell.SetColSpan("2");
		tCell.AddInnerHTMLElement(anchor);

		// DCA - String Label needs to be surrounded by an HTMLSpan
		XPArrayList arrElements = anchor.GetInnerHTMLElementsAsArrayList(true);
		String strLabel		    = ((HTMLGenericElement) arrElements.GetElement(0)).GetDisplayString();
		anchor.ClearInnerHTMLElements();

		HTMLSpan mySpan = new HTMLSpan();
		mySpan.AddInnerHTMLString(strLabel);
		mySpan.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
		anchor.AddInnerHTMLElement(mySpan);

		tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		tCell = new HTMLTableCell();
		tCell.SetHeight("5");
		tCell.SetColSpan("3");
		tRow.AddInnerHTMLElement(tCell);
	}


	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with an action link
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param text 						Label to add
	 * @param collapseLink				Display the link to collapse the current action subsection
	 * @throws HTMLException 
	 */
	protected void AddActionListRow(HTMLTable table, HTMLAnchor anchor,
		ASURL collapseLink)
		throws HTMLException
	{
		if (anchor != null)
		{
			HTMLTableRow tRow   = new HTMLTableRow();
			HTMLTableCell tCell	= new HTMLTableCell();
			table.AddInnerHTMLElement(tRow);
			tRow.AddInnerHTMLElement(tCell);
			tRow.SetStyleClass(PTStyleClass.NAV_MIDTAB_BG);
			tCell.SetStyleClass(PTStyleClass.NAV_MIDTAB_BTN);
			tCell.SetHeight("16");			
			HTMLTableCell tOuter = tCell;
			
			// Inner table
			HTMLTable tTable = new HTMLTable();

			BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
			if ((AccessStyles.STANDARD == m_asOwner.GetAccessStyle()) || (!browser.IsNetscape67()))
			{
				HTMLAnchor tempAnchor = new HTMLAnchor("#");
				tCell.AddInnerHTMLElement(tempAnchor);
				tempAnchor.AddInnerHTMLElement(tTable);
			}
			else
			{
				tCell.AddInnerHTMLElement(tTable);
			}

			tTable.SetCellPadding("0");
			tTable.SetCellSpacing("0");
			tTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			HTMLTableRow tInnerRow = new HTMLTableRow();
			tCell = new HTMLTableCell();
			tCell.SetHeight("20");
			tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			tCell.SetStyleClass(PTStyleClass.OBJECT_BTN);
			tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			tCell.SetNoWrap(true);
						
			tTable.AddInnerHTMLElement(tInnerRow);
			tInnerRow.AddInnerHTMLElement(tCell);
			
			HTMLSpan span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.ACTIONBAR_BAN_TEXT);
			span.AddInnerHTMLElement(anchor);
			tCell.AddInnerHTMLElement(span);
			
			

			// Only display collapse link if we are not in 508/low bandwidth
			if ((null != collapseLink) && (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD) && !TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner) )
			{
				tOuter.SetColSpan("1");
				
				tCell = new HTMLTableCell();
				tRow.AddInnerHTMLElement(tCell);
				tCell.SetAlign(CommonHTMLStrings.RIGHT);
				tCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_BTN);
				tCell.AddInnerHTMLElement(collapseLink.GetURLAsHTMLElement());
			} else {
				tOuter.SetColSpan("2");
				
			}
			
		}
	}

	// Vertical Navigation Helper functions

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a spacer row
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 *
	 * @throws HTMLException 
	 */
	protected static void AddVerticalSpacerRow(HTMLTable table)
	{
		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		
		String sHeight = "2";
		tCell.SetHeight(sHeight);
		// bjf -- setting this to autofit, as this row was coming up as filling only one column,
		// while other rows seemed to be taking up three.
		tCell.SetAutoFit(true);

		tCell.AddInnerHTMLElement(NavigationCommonHelpers.GetSpacerImage("1", sHeight));
	}
	
	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a header bar
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param headerString				The header string
	 * @throws HTMLException 
	 */
	protected void AddSectionHeaderRow(HTMLTable table, String headerString)
		throws HTMLException
	{
		String spacer= CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE;

		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		HTMLTableCell tCell = new HTMLTableCell();

		tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		tCell.SetAlign(CommonHTMLStrings.LEFT);
		tCell.SetColSpan("3");
		tRow.AddInnerHTMLElement(tCell);

		tCell.AddInnerHTMLString(spacer+XPHttpUtility.HtmlEncode(headerString));
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a collapsible/expandable header bar
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param headerString				The header string
	 * @param nID						NavVisibility ID of the navigation section
	 * @param bCollapsed				True if the entire section is collapsed
	 * @throws HTMLException 
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	protected void AddSectionHeaderRow(HTMLTable table, String headerString,
		int nID, boolean bCollapsed)
		throws HTMLException
	{
		HTMLTableRow tRow = new HTMLTableRow();
		tRow.SetStyleClass(PTStyleClass.MENU_HEADER_BG);
		table.AddInnerHTMLElement(tRow);

		HTMLTableCell tCell = new HTMLTableCell();
		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		tCell.SetAlign(CommonHTMLStrings.LEFT);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSECTION_HEADER);
		tRow.AddInnerHTMLElement(tCell);

		// Only add expand/collapse images if we are in standard mode
		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD && !TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
		{
			ASURL url = GetSectionCollapseExpandURL(nID, !bCollapsed);

			tCell.AddInnerHTMLElement(url.GetURLAsHTMLElement());
		} else {
			tCell.AddInnerHTMLString("&nbsp;");
		}

		tCell.SetColSpan("3");
		tCell.AddInnerHTMLEncodedString(headerString);
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with an ASURL link
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param asURL						The ASURL link to add 	 
	 * @throws HTMLException 
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	protected static void AddStandardListRow(HTMLTable table, ASURL asURL)
		throws HTMLException
	{
		if (null == asURL)
		{
			return;
		}

		HTMLTableRow tRow   = new HTMLTableRow();
		HTMLTableCell tCell = new HTMLTableCell();

		tCell = new HTMLTableCell();
		table.AddInnerHTMLElement(tRow);
		tRow.AddInnerHTMLElement(tCell);
		tCell.AddInnerHTMLElement(asURL.GetURLAsHTMLElement());
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		tCell.SetColSpan("3");
		tCell.SetHeight("25");
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with an HTMLAnchor link
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param anchor					The anchor link to add 	 
	 * @throws HTMLException 
	 * 	 
	 */
	protected static void AddStandardListRow(HTMLTable table, HTMLAnchor anchor)
		throws HTMLException
	{
		HTMLTableRow tRow   = new HTMLTableRow();
		HTMLTableCell tCell = new HTMLTableCell();
		
		if (null == anchor)
		{
			return;
		}

		tCell = new HTMLTableCell();
		table.AddInnerHTMLElement(tRow);
		tRow.AddInnerHTMLElement(tCell);
		tCell.AddInnerHTMLElement(anchor);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		tCell.SetColSpan("3");
		tCell.SetHeight("25");
	}
	
	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a bolded string
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param strLabel					The string to display 	 
	 * @throws HTMLException 
	 * 
	 */
	protected static void AddStandardListBoldRow(HTMLTable table, String strLabel) throws HTMLException
	{
		
		HTMLTableRow tRow   = new HTMLTableRow();
		HTMLTableCell tCell = new HTMLTableCell();

		tCell = new HTMLTableCell();
		table.AddInnerHTMLElement(tRow);
		tRow.AddInnerHTMLElement(tCell);
		HTMLB htmlB = new HTMLB();
		tCell.AddInnerHTMLElement(htmlB);
		htmlB.AddInnerHTMLString(strLabel);
		
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		tCell.SetColSpan("3");
		tCell.SetHeight("25");
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a subsubsection link, 
	 * used for related and subcommunities section.=
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param anchor					The anchor link to add 	 
	 * @param bIndent					True to indent the string
	 * @throws HTMLException 
	 * 
	 */
	protected static void AddSUBSUBSectionListRow(HTMLTable table, HTMLAnchor anchor, boolean bIndent) throws HTMLException
	{
		if (null == anchor)
		{
			return;
		}
		HTMLTableRow tRow   = new HTMLTableRow();
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBAR_SUB_SUBSECTION_BG);
		table.AddInnerHTMLElement(tRow);
		
		HTMLTableCell tCell = null;

		if ( bIndent )
		{
			tCell = new HTMLTableCell();
			tRow.AddInnerHTMLElement(tCell);
			tCell.SetHeight("20");
			tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
			tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		} 
		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		
		tCell.AddInnerHTMLElement(anchor);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		
		tCell.SetColSpan( ((bIndent) ? "2" : "3") );
		tCell.SetHeight("20");
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a subsection link
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param anchor					The anchor link to add 	 
	 * @throws HTMLException 
	 * 	 
	 */
	protected static void AddSubSectionListRow(HTMLTable table, HTMLAnchor anchor) throws HTMLException
	{
		if (null == anchor)
		{
			return;
		}
		HTMLTableRow tRow   = new HTMLTableRow();
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);
		HTMLTableCell tCell = new HTMLTableCell();

		tCell = new HTMLTableCell();
		table.AddInnerHTMLElement(tRow);
		tRow.AddInnerHTMLElement(tCell);
		tCell.AddInnerHTMLElement(anchor);
		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBAR_TEXT);
		
		tCell.SetColSpan("3");
		tCell.SetHeight("20");
	}

	
	
	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a section header
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param headerString				The header string to display 	 
	 * @throws HTMLException 
	 * 
	 */
	protected void AddSubSectionHeaderRow(HTMLTable table, String headerString)
		throws HTMLException
	{
		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);

		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);

		tCell.SetHeight("20");
		tCell.SetVAlign("middle");

		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
		tCell.AddInnerHTMLString(headerString);
		tCell.SetColSpan("3");
	}

	/**
	 * Adds an HTMLTableCell inside an HTMLTableRow with a collapsible/expandable section header
	 *
	 * @param table 					The table to add the generated HTMLTableRow to
	 * @param headerString				The header string to display 	 
	 * @param nID						NavVisibility ID of the navigation section
	 * @param bCollapsed				True if the entire section is collapsed
	 * @throws HTMLException 
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 * 
	 */
	protected void AddSubSectionHeaderRow(HTMLTable table, String headerString,
		int nID, boolean bCollapsed)
		throws HTMLException
	{
		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);

		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);

		// Only add expand/collapse images if we are in standard mode
		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD && !TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
		{
			ASURL url = GetSectionCollapseExpandURL(nID, !bCollapsed);

			tCell.AddInnerHTMLElement(url.GetURLAsHTMLElement());
		}

//		tCell = new HTMLTableCell();
//		tRow.AddInnerHTMLElement(tCell);

		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);

		//tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
		//tCell.AddInnerHTMLString(headerString);
		
		HTMLSpan span = new HTMLSpan();
		tCell.AddInnerHTMLElement(span);
		
		span.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
		span.AddInnerHTMLString(headerString);
		
		tCell.SetColSpan("3");
	}
	
	
	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Subcommunity section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws HTMLException
	 */
	protected void AddCurCommSubSectionHeaderRow(HTMLElementCollection col, CommunityNavPage commP) throws HTMLException
	{
		HTMLTable table = CreateHeaderTable(true);
		col.AddInnerHTMLElement(table);
		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);

		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);

		tCell.SetHeight("20");
		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		tCell.SetWidth("100%");

		tCell.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_HEADER);
		
		 
		
		tCell.AddInnerHTMLString( XPHttpUtility.HtmlEncode(GeneralHelpers.TruncateLongString( commP.GetCurCommunityName(), MENU_TEXT_MAX_LENGTH, false)) );
		
		ICPListEntryIterator cpList = commP.GetParentComm();
		// Can't use the CListURLTemplateLinkMediator because we would get an anchor with displau label,
		// only want the url, construct our own anchor from the template string array instead
		CListURLTemplateMediator mediator = new CListURLTemplateMediator(m_asOwner, cpList);
		
		// Go up to parent community link
		if ( mediator.Next() )
		{
			// Spacer cell
			tRow.AddInnerHTMLElement(CreateActionBarDivider());
			
			//<td height="20" valign="middle" class="objectBtn" nowrap><span class="objectBtnText"><a href="#">
			//<img src="../../../../common/images/action_folder_up.gif" width="8" height="25" align="absmiddle" border="0" alt="Up a Community Level">
			//<img src="../../../../common/images/icon_community.gif" width="20" height="20" align="absmiddle" border="0" alt="Up a Community Level">&nbsp;</a></span></td>
			tCell = new HTMLTableCell();
			tRow.AddInnerHTMLElement(tCell);
			tCell.SetVAlign(CommonHTMLStrings.MIDDLE);
			tCell.SetStyleClass(PTStyleClass.OBJECT_BTN);
			tCell.SetNoWrap(true);
			tCell.SetHeight("20");
			
			
			HTMLSpan span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_BTN_TEXT);
			tCell.AddInnerHTMLElement(span);
			
			String toolTip = m_asOwner.GetString(644, ResourceConstants.PORTALCOMMONMSGS);
			
			String[] strings = (String[])mediator.GetEntry();
			HTMLAnchor anchor = new HTMLAnchor("#");
			anchor.SetOnClick(NavigationCommonHelpers.URLTEMPLATE_REDIRECT_JSFUNCNAME+"('" +
							strings[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL] + "'); return false;");
			anchor.SetTitle(toolTip);						
			
			span.AddInnerHTMLElement(anchor);
			// Go up to parent community
			HTMLImg image = null;
			image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_FOLDER_UP).GetHTMLElement();
			image.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(m_asOwner));
			image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			image.SetBorder(CommonHTMLStrings.ZERO);
			image.SetAlt(toolTip);	
			
			anchor.AddInnerHTMLElement(image);
			
			image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY).GetHTMLElement();
			image.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(m_asOwner));
			image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			image.SetBorder(CommonHTMLStrings.ZERO);
			image.SetAlt(toolTip);	
					
			anchor.AddInnerHTMLElement(image);
		}
		else
		{
		 	tCell.SetColSpan("3");	
		}
		
	}

	 
	
	/**
	 * Adds an HTMLTable with the Administration link to the specified HTMLElementCollection
	 * 
	 * @param col						HTMLCollection to add the Admin HTMLTable too
	 * @throws HTMLException
	 * @throws Exception
	 */
	protected void WriteAdminLink(HTMLElementCollection col)
		throws HTMLException, Exception
	{
		// no admin in 508 or low bandwidth mode
		// (check done in model)
//		if (m_model.HasAdminLinkAccess())
//		{
		
			HTMLTable table = CreateHeaderTable(false);
			col.AddInnerHTMLElement(table);

			// form admin link
			ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.ADMIN, false);

			if (cpList.GetTotalCount() > 0)
			{
				
				AddSectionHeaderRow(table, m_asOwner.GetString(275, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
				table = CreateListStartTable();
				col.AddInnerHTMLElement(table);
				CListURLMediator mediator = new CListURLMediator(m_asOwner,
						cpList);

				while (mediator.Next())
				{
					// DCA - more prominent look for Administration link
//					AddAdminListRow(table, (HTMLAnchor) mediator.GetEntry());
					AddStandardListRow(table, (HTMLAnchor) mediator.GetEntry());
				}
			}
//		}
	}
	
	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the current Community section,
	 * with the Community pages, Subcommunities and related communities
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws Exception
	 */
	protected void WriteCurCommunitySection(HTMLElementCollection col, CommunityNavPage commP) throws Exception
	{
		
		AddCurCommSubSectionHeaderRow(col, commP);
		
		WriteCommPages(col, commP);
		
		WriteSubCommsSubSection(col, commP);
		WriteRelatedCommunitiesSubSection(col, commP);
		
		
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the current Community section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws Exception
	 * @throws HTMLException
	 */
	protected void WriteMyCommunitiesSection(HTMLElementCollection col)
		throws HTMLException, Exception
	{
		if (SectionVisible(NavVisibility.VISIBILITY_COMMUNITY_SECTION))
		{
			// Community Actions
			HTMLTable table = CreateHeaderTable(true);
			col.AddInnerHTMLElement(table);
			
			AddSectionHeaderRow(table,
				m_asOwner.GetString(252, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_COMMUNITY_SECTION, false);

			ICPListEntryIterator iterActions = m_model.GetCategoryLinks(NavCategoryType.COMMUNITY, true);
			
			if (SectionVisible(NavVisibility.VISIBILITY_COMMUNITYACTIONS_SECTION))
			{
				CListURLMediator med = new CListURLMediator(m_asOwner,
						iterActions);
				med.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

				int i = iterActions.GetTotalCount();

				while (med.Next())
				{
					AddActionListRow(table, (HTMLAnchor) med.GetEntry(),
						((i-- == 1 )
						? GetActionCollapseExpandURL(NavVisibility.VISIBILITY_COMMUNITYACTIONS_SECTION, true)
						: null));
				}
			}
			else // Minimized actions subsection bar
			{
				WriteMinimizedSubSectionBar(table,
					m_asOwner.GetString(274, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
					NavVisibility.VISIBILITY_COMMUNITYACTIONS_SECTION,
					iterActions);
				//AddVerticalSpacerRow(table);
			}
			
			// Current community pages + sub & related comms
			if (NavPageType.COMMUNITY == m_model.GetCurNavPageType()) 
			{
				CommunityNavPage commP = (CommunityNavPage) m_model.GetPageSpecificMethods();
				WriteCurCommunitySection(col, commP);
			}
			

			// Populate the membership communities
			table = CreateListStartTable();
			AddVerticalSpacerRow(table);
			col.AddInnerHTMLElement(table);
			
			ICPListEntryIterator clist = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES, false);
			CListURLMediator mediator  = new CListURLMediator(m_asOwner, clist);
			mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
			
			if (NavPageType.COMMUNITY == m_model.GetCurNavPageType() || clist.GetTotalCount() > 0) 
			{
				AddStandardListBoldRow(table, m_asOwner.GetString(664, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
			}

			while (mediator.Next())
			{
				HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
				//AddStandardListRow(table, url);
				AddStandardListRow(table, url);
			}
			AddVerticalSpacerRow(table);
		}
		else
		{
			HTMLTable table = CreateHeaderTable(true);
			col.AddInnerHTMLElement(table);
			AddSectionHeaderRow(table,
				m_asOwner.GetString(252, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_COMMUNITY_SECTION, true);
			AddVerticalSpacerRow(table);
		}
		
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Community pages section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws HTMLException
	 */
	protected void WriteCommPages(HTMLElementCollection col, CommunityNavPage commP) throws HTMLException
	{

		ICPListEntryIterator cpList =commP.GetCurCommPages();
		CListURLMediator mediator   = new CListURLMediator(m_asOwner, cpList);
		mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
		HTMLTable table = CreateListStartTable();
		col.AddInnerHTMLElement(table);
		while (mediator.Next())
		{
			HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
			AddSUBSUBSectionListRow(table, anchor, false);
		}
	}


	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Subcommunities section of 
	 * the current community
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws Exception
	 * @throws HTMLException
	 * @throws Exception
	 */
	protected void WriteSubCommsSubSection(HTMLElementCollection col, CommunityNavPage commP)
		throws HTMLException, Exception
	{
		
		ICPListEntryIterator cpSubComs = commP.GetCurSubCommunities();
		if ( cpSubComs.GetTotalCount() < 1 ) {
			return;
		}
		if (SectionVisible(NavVisibility.VISIBILITY_SUB_COMMS_SECTION) ) 
		{
		
			HTMLTable table = CreateHeaderTable(false);
			col.AddInnerHTMLElement(table);
			
			
			if (cpSubComs.GetTotalCount() > 0)
			{
				CListURLMediator mediator	   = new CListURLMediator(m_asOwner, cpSubComs);
				mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);
		
				AddSubSectionHeaderRow(table,
						m_asOwner.GetString(266, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
						NavVisibility.VISIBILITY_SUB_COMMS_SECTION, false);
		
				table = CreateListStartTable();
				col.AddInnerHTMLElement(table);
				
				while (mediator.Next())
				{
					HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
					AddSUBSUBSectionListRow(table, url, true);
				}
			}
		} else {
			HTMLTable table = CreateListStartTable();
			col.AddInnerHTMLElement(table);
			AddSubSectionHeaderRow(table,
				m_asOwner.GetString(266, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_SUB_COMMS_SECTION, true);
		}
//		}
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the directory section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @throws HTMLException
	 */
	protected void WriteDocumentsSection(HTMLElementCollection col)
		throws HTMLException
	{
		
		HTMLTable table = CreateHeaderTable(true);
		col.AddInnerHTMLElement(table);
		AddVerticalSpacerRow(table);
		
		if (SectionVisible(NavVisibility.VISIBILITY_DIRECTORY_SECTION))
		{					
			AddSectionHeaderRow(table,
				m_asOwner.GetString(254, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_DIRECTORY_SECTION, false);


			table = CreateListStartTable();
			col.AddInnerHTMLElement(table);
			CListURLMediator mediator = new CListURLMediator(m_asOwner,
					m_model.GetCategoryLinks(NavCategoryType.DIRECTORY, false));
			mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

			while (mediator.Next())
			{
				HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
				AddStandardListRow(table, url);
			}
		}
		else
		{
			AddSectionHeaderRow(table,
				m_asOwner.GetString(254, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_DIRECTORY_SECTION, true);
			
		}
		AddVerticalSpacerRow(table);
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Mandatory Communities
	 * section. Note that My communities section lists these aswell.
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @throws Exception
	 * @throws HTMLException
	 */
	protected void WriteMandatoryCommunitiesSection(HTMLElementCollection col)
		throws HTMLException, Exception
	{
		
		if (SectionVisible(NavVisibility.VISIBILITY_MANDATORYCOMMS_SECTION))
		{
			ICPListEntryIterator cplist = m_model.GetCategoryLinks(NavCategoryType.MANDATORYTABS, false);
			CListURLMediator mediator   = new CListURLMediator(m_asOwner, cplist);
			mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

			if (0 != cplist.GetTotalCount())
			{
				HTMLTable table = CreateHeaderTable(true);
				col.AddInnerHTMLElement(table);
				AddVerticalSpacerRow(table);
				AddSectionHeaderRow(table,
					m_asOwner.GetString(253, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
					NavVisibility.VISIBILITY_MANDATORYCOMMS_SECTION, false);

				table = CreateListStartTable();
				col.AddInnerHTMLElement(table);
				while (mediator.Next())
				{
					HTMLAnchor url = (HTMLAnchor) mediator.GetEntry();
					AddStandardListRow(table, url);
				}
				AddVerticalSpacerRow(table);
			}
			
		}
		else
		{
			HTMLTable table = CreateHeaderTable(true);
			col.AddInnerHTMLElement(table);
			AddVerticalSpacerRow(table);
			AddSectionHeaderRow(table,
				m_asOwner.GetString(253, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_MANDATORYCOMMS_SECTION, true);
			AddVerticalSpacerRow(table);
		}
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Mandatory links section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @throws HTMLException
	 */
	protected void WriteMandatoryLinksSection(HTMLElementCollection col) throws HTMLException
	{
		String strMandLinksName     = m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK);
		ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MANDATORYLINK, false);
		CListURLMediator mediator   = new CListURLMediator(m_asOwner, cpList);

		// Don't even make a section header for the mandatory links if the mandatory links name is blank.
		if ((null != strMandLinksName) && !("").equals(strMandLinksName))
		{
			HTMLTable table = CreateHeaderTable(true);
			col.AddInnerHTMLElement(table);
			if (cpList.GetTotalCount() > 0)
			{
				// If there are mandatory links, then make the section header expandable and collapsable.
				if (SectionVisible(NavVisibility.VISIBILITY_MANDATORYLINKS_SECTION))
				{
					// If the mandatory links are visible (the section is expanded), then show them.
					AddSectionHeaderRow(table, strMandLinksName, NavVisibility.VISIBILITY_MANDATORYLINKS_SECTION, false);

					mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

					table = CreateListStartTable();
					col.AddInnerHTMLElement(table);
					while ( mediator.Next() )
					{
						HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
						AddStandardListRow(table, anchor);
					}
				}
				else
				{
					// If the mandatory links section is collapsed, then don't show the mandatory links.
					AddSectionHeaderRow(table, strMandLinksName,
						NavVisibility.VISIBILITY_MANDATORYLINKS_SECTION, true);
				}
			} else {
				// bjf -- don't show mandatory links if there aren't any
				AddSectionHeaderRow(table, strMandLinksName);
			
				// String: There are no mandatory links.
				HTMLAnchor anchor = new HTMLAnchor(null);
				anchor.AddInnerHTMLString(m_asOwner.GetString(716, ResourceConstants.PORTALCOMMONMSGS));
				AddStandardListRow(table, anchor);
			}
			AddVerticalSpacerRow(table);
		}
	}

	/**
	 * Adds an HTMLTableRow to specified HTMLTable with a collapsed
	 * Subsection Bar. Used to display collapsed actions subsection
	 * with only the action images.
	 * 
	 * @param table					The HTMLTable to add the generated row too.
	 * @param strTitle				Subsection header string 
	 * @param nID					NavVisibility ID of the section
	 * @param cpList				Actions as ICPListEntryIterator
	 * @throws HTMLException
	 * @throws Exception
	 */
	protected void WriteMinimizedSubSectionBar(HTMLTable table,
		String strTitle, int nID, ICPListEntryIterator cpList)
		throws HTMLException, Exception
	{
		
		
		HTMLTableRow tRow = new HTMLTableRow();
		table.AddInnerHTMLElement(tRow);
		tRow.SetStyleClass(PTStyleClass.NAV_SIDEBARSUBSECTION_BG);

		HTMLTableCell tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);

		tCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

		tCell.SetVAlign(CommonHTMLStrings.MIDDLE);

		CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);

		tCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);

		while (mediator.Next())
		{
			HTMLAnchor anchor    = (HTMLAnchor) mediator.GetEntry();
			XPArrayList list     = anchor.GetInnerHTMLElementsAsArrayList(false);
			// Only get the target url and image from each entry. Don't want the 
			// label.
			HTMLAnchor imgAnchor = new HTMLAnchor(anchor.GetHRef());
			imgAnchor.SetOnClick(anchor.GetOnClick());
			imgAnchor.AddInnerHTMLElement((HTMLGenericElement) list.GetElement(0));
			tCell.AddInnerHTMLElement(imgAnchor);
		}
		// Add the section expand action image
		tCell = new HTMLTableCell();
		tRow.AddInnerHTMLElement(tCell);
		tCell.SetAlign(CommonHTMLStrings.RIGHT);
		tCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		tCell.AddInnerHTMLElement(GetActionCollapseExpandURL(nID,false).GetURLAsHTMLElement());
		
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Mypage links section
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @throws HTMLException
	 * @throws Exception
	 */
	protected void WriteMyPagesSection(HTMLElementCollection col)
		throws HTMLException, Exception
	{
		if (SectionVisible(NavVisibility.VISIBILITY_MYPAGE_SECTION))
		{
			HTMLTable table = CreateHeaderTable(true);
			col.AddInnerHTMLElement(table);
			AddSectionHeaderRow(table,
				m_asOwner.GetString(260, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_MYPAGE_SECTION, false);

			ICPListEntryIterator iterActions = m_model.GetCategoryLinks(NavCategoryType.MYPAGE, true);

			if (SectionVisible(NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION))
			{
				//					AddSubSectionHeaderRow(table, _ui_MyPageActions, NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION, false);
				//
				CListURLMediator med = new CListURLMediator(m_asOwner,
						iterActions);
				med.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

				int i = iterActions.GetTotalCount();

				while (med.Next())
				{
					//						AddStandardListRow(table, (HTMLAnchor)mediator.GetEntry());
					AddActionListRow(table,
						(HTMLAnchor) med.GetEntry(),
						((i-- == 1)
						? GetActionCollapseExpandURL(
							NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION, true)
						: null));
					
				}
			}
			else // Minimized actions subsection bar
			{
				
				WriteMinimizedSubSectionBar(table,
					m_asOwner.GetString(273, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
					NavVisibility.VISIBILITY_MYPAGESACTIONS_SECTION,
					iterActions);
				
			}
			AddVerticalSpacerRow(table);

			ICPListEntryIterator iterPages = m_model.GetCategoryLinks(NavCategoryType.MYPAGE, false);
			CListURLMediator mediator	   = new CListURLMediator(m_asOwner,
					iterPages);
			mediator.SetLabelMaxLength(MENU_TEXT_MAX_LENGTH);

			while (mediator.Next())
			{
				AddStandardListRow(table, (HTMLAnchor) mediator.GetEntry());
			}
			AddVerticalSpacerRow(table);
		}
		else
		{ // Minimized mypage section bar
			HTMLTable table = CreateHeaderTable(true);
			col.AddInnerHTMLElement(table);
			AddSectionHeaderRow(table,
				m_asOwner.GetString(260, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_MYPAGE_SECTION, true);
			AddVerticalSpacerRow(table);

		}
	}

	/**
	 * Adds an HTMLTable to the HTMLElementCollection with the Related communities section of 
	 * the current community
	 * 
	 * @param col						The HTMLElementCollection to add the HTMLTable too
	 * @param commP						The CommunityNavPage
	 * @throws HTMLException
	 */
	protected void WriteRelatedCommunitiesSubSection(HTMLElementCollection col, CommunityNavPage commP)
		throws HTMLException
	{
		ICPListEntryIterator cpList = commP.GetCurRelCommunities();
		if ( cpList.GetTotalCount() < 1 ) {
			return; 
		}
		
		if (SectionVisible(NavVisibility.VISIBILITY_RELATED_COMMS_SECTION) ) 
		{
			// Don't display the section if there no related comms.
			if (  cpList.GetTotalCount() > 0 )
			{
				HTMLTable table = CreateHeaderTable(false);
				col.AddInnerHTMLElement(table);
				
				AddSubSectionHeaderRow(table,
					m_asOwner.GetString(267, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
					NavVisibility.VISIBILITY_RELATED_COMMS_SECTION, false);


				table = CreateListStartTable();
				
				col.AddInnerHTMLElement(table);
				
				if  ( cpList.GetTotalCount() == 0 )
				{
					WriteTextRow(table, m_asOwner.GetString(287, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS));
				}
				else
				{
					CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);

					while (mediator.Next())
					{
						AddSUBSUBSectionListRow(table, (HTMLAnchor) mediator.GetEntry(), true);
					}
				}

			}
		}
		else
		{ // Minimized related comms subsection bar
			HTMLTable table = CreateListStartTable();
			col.AddInnerHTMLElement(table);
			AddSubSectionHeaderRow(table,
				m_asOwner.GetString(267, com.plumtree.portalnavigation.common.constants.ResourceConstants.PORTALCOMMONMSGS),
				NavVisibility.VISIBILITY_RELATED_COMMS_SECTION, true);

		}
//		}
	}

	/**
	 * This helper method checks if the section is visible, or if
	 * we are in 508 mode, in which case we don't allow collapsing
	 * sections.
	 *
	 * @param int nSection the ID of the section
	 * @return boolean true implies visible
	 */
	private boolean SectionVisible(int nSection)
	{
		return (
				(m_asOwner.GetAccessStyle() != AccessStyles.STANDARD) ||
				TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner) ||
				(m_model.GetSectionVisibility(nSection))
				);
	}
	
	/**
	 * Helper function that gets a table cell used as a thin divider. 
	 * 
	 * @return HTMLTableCell				Divider cell
	 * @throws HTMLException
	 */
	protected HTMLTableCell CreateActionBarDivider() throws HTMLException
	{
		HTMLTableCell tCell = new HTMLTableCell();
		tCell.SetWidth("1");
		tCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_DIVIDER);
		tCell.AddInnerHTMLElement(NavigationCommonHelpers.GetSpacerImage("1", "20"));
		 
		return tCell;
	}


}