package com.plumtree.portalnavigation.views;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalnavigation.common.constants.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * Horizontal navigaton scheme with dropdown menus using the JSPortalMenu framework.
 * 
 * This navigation view displays "My Pages", "My Communities", "Directory" and mandatory links
 * dropdown menus using the JSPortalMenu framework. Mandatory communities and link to Administration
 * are displayed using same tabs as the menu tabs. The tabs will wrap to multiple rows if there are 
 * too many tabs to fit on one row.
 * 
 * This view is used by the NavTypeJSPortalMenuDropDown in the above banner view. The menu framework
 * is defined in navjsportalmenufuncs.js and functions in navjsportalmenucommon.js is used for the
 * mandatory community tabs. 
 * 
 * Now supports browser detection internally, so this view can be used
 * as a nested view by other navigation views.
 * 
 * This view supports auto-browser handling so it can be used by external
 * custom navigations. Custom navs that use this view MUST also use the 
 * JavaScriptIncludes() method on NavTypeJSPortalMenuDropDown to return 
 * proper javascript to support this view.
 *
 * @author RobertZ
 * @author DavidP
 */
public class NavigationJSPortalMenuDropDownView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalnavigation.views.NavigationJSPortalMenuDropDownView");

	private AActivitySpace m_asOwner;
	private IPluggableNavModelRO m_model;
	
	protected int m_nMyPageMenuEntries = 0;
	protected int m_nMyCommsMenuEntries = 0;
	protected int m_nDirectoryMenuEntries = 0;
	protected int m_nMandatoryLinksEntries = 0;
	
	// we use these views for dynamic routing of browser handling
	private NavigationHorizontalComboBoxView m_comboBoxMenuView = null;
	
	/** Drop down view class name */
	public static final String STR_MVC_CLASS_NAME = "PTHztlDDNav_New";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NavigationJSPortalMenuDropDownView();
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;
		
		// Detect the browser type and map to the right menu view
		BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
		
		// DAP Key Note on Browser Mapping: 
		// We do mapping here to allow others to use this view in custom 
		// navigations as a nested view.  
		
		// Combobox Menus: Netscape 4 All Platforms, Macintosh Safari
		// Safari note: Must wait until Konqueror supports W3C spec 
		// for Javascript, slated for Safari 2.0
		// Also get combobxo for anything we don't recognize
		// Note javascript handling is browser-specific in NavType also
		// Bug in IE MAC forces us to combobox there
		if ( !browser.IsJSPortalMenuCompliant() )
		{
			result = m_comboBoxMenuView.Display(); 
		}				
		// New jsportal menus now supports Netscape 7.1
		else // normal jsportalmenus navigation 
		{
			try
			{
				// Populate the arrays	   	
				HTMLScriptCollection col = new HTMLScriptCollection();
				result.AddInnerHTMLElement(col);
				
				// Populate menus 
				CreateMyPageMenu(col);
				CreateCommMembershipMenu(col);
				CreateDocMenu(col);
				CreateMandatoryLinksMenu(col);
	
				// Populate the array of Mandatory Tab entries 
				col.AddInnerHTMLElement(NavigationCommonHelpers.CreateMandatoryTabsArray(m_model.GetCategoryLinks(NavCategoryType.MANDATORYTABS, true), m_asOwner));
				// Populate the array of Dropdown menu tabs
				col.AddInnerHTMLElement(CreateDDTabsArray());
				// Write the Javascript functions
				col.AddInnerHTMLElement(NavigationCommonHelpers.GenerateJSHTMLHelperFunctions(m_asOwner));
				
				HTMLScript script = new HTMLScript("text/javaScript");
				result.AddInnerHTMLElement(script);
				
	
				result.AddInnerHTMLString("<!-- start NAV DHTML MIDBAR -->");
				
				// include jsportalmenus js files
				result.AddInnerHTMLElement(ConfigHelper.GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTALMENU, m_asOwner));
				script = new HTMLScript("text/javaScript");
				
				// write div holders for the dropdown menus
				script.AddInnerHTMLString("writePortalMenuDivs(" +
					JSHelper.GetSafeJSVariableWarn(NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY) + ");\n");
				
				// get PTMenu.css location string	
				IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
				String defaultStyleSheet = ConfigHelper.GetImageServerBaseURL(m_asOwner) + "common/private/js/jsportalmenus/" + 
					ConfigHelper.GetJSIncluderComponentVersion(ConfigHelper.JSCOMPONENT_JSPORTALMENU) + "/styles/css/PTPMMenu.css";
				
				// initialize menu	
				script.AddInnerHTMLString("initDDandManTabsRows(" +
					JSHelper.GetSafeJSVariableWarn(NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY) + "," +
					JSHelper.GetSafeJSVariableWarn(NavigationCommonHelpers.JSCRIPT_VAR_MANDTAB_ARRAY) + ",'" + 
					defaultStyleSheet + "');");		
				script.AddInnerHTMLString("document.PCC.RegisterForWindowEvent(\"onload\", \"gbPageLoaded = true;\" );");
				
				result.AddInnerHTMLElement(script);
				
				result.AddInnerHTMLString("<!-- end NAV DHTML MIDBAR -->");
	
			}
			catch (Exception e)
			{
				
					log.Error(e, "Error displaying Dropdown menu tabs: "+ e.getMessage());
				
					
				return new HTMLGenericElement("Error displaying Dropdown menu tabs.");
			}
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (IPluggableNavModelRO) model;
		m_asOwner     = parent;
		
		m_comboBoxMenuView = new NavigationHorizontalComboBoxView();
		
		m_comboBoxMenuView.Init(model,parent);
	}

	/**
	 * Creates the dropdown menu with the Communities the current user is a member of.
	 * Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
	 * 
	 * @param col					The HTMLScriptCollection to add the javascript too
	 * @throws HTMLException
	 */
	protected void CreateCommMembershipMenu(HTMLScriptCollection col)
		throws HTMLException
	{
		ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MYCOMMUNITIES, true);
		m_nMyCommsMenuEntries =  cpList.GetTotalCount();
		NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, cpList, NavigationJSPortalMenuHelpers.m_strCommID);
	}

	/**
	 * This function populates an array of Tabs with the navigation menus to show
	 * 	Element 0: Display name
	 *  Element 1: ID of the menu
	 *  Element 2: Tooltip (if needed);
	 * 
	 * @param script 					HTMLScript block with the array
	 *
	 * @throws HTMLException 
	 */
	protected HTMLScript CreateDDTabsArray() throws HTMLException
	{
		// Roughly estimate the size of the buffer
		XPStringBuilder buf = new XPStringBuilder(300);
		
		String strMaxLength = (String)m_asOwner.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_TRUNCATION_WIDTH);
		int nMaxLength = XPConvert.ToInteger(strMaxLength);

		//buf.Append("\t" + "var " + NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY + " = [\n");
		buf.Append("[");
		
		if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType()) 
		{
			String toolTip = "";
			String label = "";
			String labelTrunc = "";
			if( m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS) &&
				  m_nMyPageMenuEntries > 0	) 
			{
				label = JSHelper.JSEncodeString(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS));
				labelTrunc = GeneralHelpers.TruncateLongString(label, nMaxLength, false);
				
				buf.Append(" [\"" + labelTrunc + "\",\"" +
					NavigationJSPortalMenuHelpers.m_strMyPageID + "\",\"" +
					( (label.length()==labelTrunc.length()) ? "null" : label ) + "\"]\n,");
			}
	
			if( m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS) &&
			    m_nMyCommsMenuEntries > 0 
			  )
			{
				label = JSHelper.JSEncodeString(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
				labelTrunc = GeneralHelpers.TruncateLongString(label, nMaxLength, false);
				
				buf.Append("[\"" +
					labelTrunc + "\",\"" +
					NavigationJSPortalMenuHelpers.m_strCommID + "\",\"" +
					( (label.length()==labelTrunc.length()) ? "null" : label ) + "\"]\n,");
			}
	
			if( m_model.GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS)  &&
				  m_nDirectoryMenuEntries > 0	)	
			{
				label = JSHelper.JSEncodeString(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS));
				labelTrunc = GeneralHelpers.TruncateLongString(label, nMaxLength, false);
				
				buf.Append("[\"" +
					labelTrunc + "\",\"" +
					NavigationJSPortalMenuHelpers.m_strDocID + "\",\"" +
					( (label.length()==labelTrunc.length()) ? "null" : label ) + "\"]\n,");
			}
		
			String strMandLinksName     = m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK);
			String strTruncMandLinksName = GeneralHelpers.TruncateLongString(strMandLinksName, XPConvert.ToInteger(strMaxLength), false);
	
			if ((null != strTruncMandLinksName) && !("").equals(strTruncMandLinksName) && m_nMandatoryLinksEntries > 0 )
			{
				// Add tooltip if the string was truncated.
				toolTip = (strTruncMandLinksName.length()==strMandLinksName.length()) ? "null" : JSHelper.JSEncodeString(XPHttpUtility.HtmlEncode(strMandLinksName)); 
				buf.Append("[\"" +  JSHelper.JSEncodeString(XPHttpUtility.HtmlEncode(strTruncMandLinksName)) + "\",\"" + 
									NavigationJSPortalMenuHelpers.m_strMandLinksID + "\",\"" +
									// Need to HTMLEncode this, goes into the title attribute of a span.  
									toolTip + "\"]\n");
			} else {
				if ( buf.GetLength() > 1 )
				{
					// remove last comma
					buf.RemoveCharAt(buf.GetLength() - 1);
				}	
			}
		}
		buf.Append("]");
		return JSHelper.AddSafeJSVariable(NavigationCommonHelpers.JSCRIPT_VAR_DDTABS_ARRAY, buf.ToString());
	}

	/**
	 * Creates the dropdown menu with the Directory links.
	 * Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
	 * 
	 * @param col					The HTMLScriptCollection to add the javascript too
	 * @throws HTMLException
	 */
	protected void CreateDocMenu(HTMLScriptCollection col)
		throws HTMLException
	{
		ICPListEntryIterator list = m_model.GetCategoryLinks(NavCategoryType.DIRECTORY, false);
		m_nDirectoryMenuEntries =  list.GetTotalCount();
		NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, list, NavigationJSPortalMenuHelpers.m_strDocID);
	}

	/**
	 * Creates the dropdown menu with the current user's Mandatory Links
	 * Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
	 * 
	 * @param col					The HTMLScriptCollection to add the javascript too
	 * @throws HTMLException
	 */
	protected void CreateMandatoryLinksMenu(HTMLScriptCollection col)
		throws HTMLException
	{
		ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MANDATORYLINK, true);
		String strMandLinksName     = m_model.GetCategoryTitle(NavCategoryType.MANDATORYLINK);
		m_nMandatoryLinksEntries =  cpList.GetTotalCount();
		// bjf -- if there aren't any links, then don't show the menu
		if ((null != strMandLinksName) && !("").equals(strMandLinksName) &&
				(cpList.GetTotalCount() != 0))
		{
			NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, cpList, NavigationJSPortalMenuHelpers.m_strMandLinksID);
		}
	}

	/**
	 * Creates the dropdown menu with the current user's My pages
	 * Defines javascript variables in HTMLScript blocks that are added to the HTMLScriptCollection  
	 * 
	 * @param col					The HTMLScriptCollection to add the javascript too
	 * @throws HTMLException
	 */
	protected void CreateMyPageMenu(HTMLScriptCollection col)
		throws HTMLException
	{
		//ASQueryResult asPages = m_model.GetCurMyPages();
		ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MYPAGE, true);
		((ASCompoundList)cpList).AddCompoundList(m_model.GetCategoryLinks(NavCategoryType.MYPAGE, false));
		m_nMyPageMenuEntries =  cpList.GetTotalCount();
		NavigationJSPortalMenuHelpers.MakeDDMenu(col, m_asOwner, cpList, NavigationJSPortalMenuHelpers.m_strMyPageID);
	}
	
	
}

