package com.plumtree.portalnavigation.views;


import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Simple left hand navigation view (used for 508, among other things).
 * 
 * This view displays My Pages, My Communities, Directory and mandatory links in vertical 
 * sections. These sections can be collapsed to save space. Mandatory Communities with tab 
 * are displayed in the My Communities section in this scheme. 
 * 
 * This view is used by NavTypeSimpleLeftVertical in the Left side section. It uses helper functions
 * in NavigationCommonVerticalView. 
 * 
 * No javascript is used.
 *
 * @author RobertZ
 */
public class NavigationSimpleLeftVerticalView extends NavigationCommonVerticalView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalnavigation.views.NavigationSimpleLeftVerticalView");

	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "NavigationSimpleLeftVerticalBar";

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		
		HTMLElementCollection col = new HTMLElementCollection();

		try
		{
			// Communities section
			if ( m_model.GetCurNavPageType() == NavPageType.COMMUNITY )
			{
				WriteMyCommunitiesSection(col);
			}

			if ( NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType() ) 
			{	
				// DCA - check if we should show My Pages
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
				{
					WriteMyPagesSection(col);
				}
				
				if ( m_model.GetCurNavPageType() != NavPageType.COMMUNITY )
				{
					// DCA - check if we should show Communities
					if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
					{	
						WriteMyCommunitiesSection(col);
					}
				}
				
				// DCA - check if we should show the Directory
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
				{
					WriteDocumentsSection(col);
				}
			
				// Display the mandatory links menu
				WriteMandatoryLinksSection(col);	
			}

			if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
			{
				result.AddInnerHTMLElement(col);
			}
			else
			{
				// Display 508 access key table (shortcuts) and skip nav link
				Write508ShortcutsSection(result);
				
				result.AddInnerHTMLElement(col);

				Write508JumpLink(result);
			}
			
			// Add the link to administration
			WriteAdminLink(col);
			
		}
		catch (Exception e)
		{
			
				log.Error(e, "Could not display simple navigation view.");
			
		}
			
		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  	= (IPluggableNavModelRO) model;
		m_asOwner     = parent;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NavigationSimpleLeftVerticalView();
	}	

}

