package com.plumtree.portalnavigation.views;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalnavigation.common.constants.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.objectselection.communities.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Horizontal tabs for selecting links sections in NavigationTabGroupsLeftVerticalView
 * 
 * This navigation view displays tabs for My Pages, My Communities, Directory and Administration.
 * Clicking on the My Communities tab goes to the first community in a user's community list.
 * 
 * This view is used by NavTypeTabGroupsLeftVertical in the Below banner section. It works together
 * with NavigationTabGroupsLeftVerticalView, which provides navigation inside each feature area.
 * 
 * @author robertz
 *
 */
public class NavigationTabGroupsTabsView extends NavigationCommonVerticalView implements IView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalnavigation.views.NavigationTabGroupsTabsView");

	
	private AActivitySpace m_asOwner;
	private IPluggableNavModelRO m_model;
	
	/** Truncation width of the strings in the tabs **/
	public static final int TABGROUPS_TAB_TRUNCATION_WIDTH = 17;
	
	/** MVC Name **/
	public static final String STR_MVC_CLASS_NAME = "NavigationTabGroupsTabs";
	
	private static final String JS_EDIT_PROFILE_NO_COMM_ALERT = "showEditProfileNoCommAlert";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NavigationTabGroupsTabsView();
	}
	
	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		XPStringBuilder sb = new XPStringBuilder(150);
		sb.Append("function " + JS_EDIT_PROFILE_NO_COMM_ALERT + "()\n")
			.Append("{\n")
			.Append("	alert('" + m_asOwner.GetString(757, ResourceConstants.PORTALCOMMONMSGS) + "');")
			.Append("}\n");
		script.AddInnerHTMLString(sb.ToString());
		return script;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (IPluggableNavModelRO) model;
		m_asOwner     = parent;
	}
	
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			// Outer table
			HTMLTable tabs = new HTMLTable();
			result.AddInnerHTMLElement(tabs);
			tabs.SetCellSpacing(CommonHTMLStrings.ZERO);
			tabs.SetCellPadding(CommonHTMLStrings.ZERO);
			tabs.SetBorder(CommonHTMLStrings.ZERO);
			tabs.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			tabs.SetID("tabbedleftverticaltable");

			HTMLTableRow row = new HTMLTableRow();
			row.SetStyleClass(PTStyleClass.NAV_TABOFF_BG);
			tabs.AddInnerHTMLElement(row);
			HTMLAnchor anchor;
			ASURL url;
			HTMLElementCollection col;
			HTMLImg img;
			// bjf -- adding a spacer before the first tab, bug 14394.
			NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
 
			if (NavPageType.COMMUNITYPREVIEW != m_model.GetCurNavPageType()) 
			{
				// My page tabs
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
				{
	
					img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_MYPAGE,
											true, this.m_asOwner).GetHTMLElement();
					img.SetBorder(CommonHTMLStrings.ZERO);
					img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					String mypage = GeneralHelpers.TruncateLongString(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH, false);
					img.SetAlt(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS));
					
					// If selected tab, just make label, not a link
					boolean bIsMyPage = NavPageType.MYPAGE == m_model.GetCurNavPageType();
					if ( bIsMyPage  ) {
						col = new HTMLElementCollection();
						col.AddInnerHTMLElement(img);
						col.AddInnerHTMLString(mypage);
	
						row.AddInnerHTMLElement(CreateTab(col, true ));
	
					} else {
						url = new ASURL(m_asOwner);
						url.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
						url.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
						url.AddControlArgument(SetPageControl.STR_PAGE_ID, 0);
						url.AddInnerHTMLElement(img);
						url.AddInnerHTMLString(mypage);
						anchor = (HTMLAnchor)url.GetURLAsHTMLElement();
						anchor.SetTitle(m_asOwner.GetString(260, ResourceConstants.PORTALCOMMONMSGS));
						row.AddInnerHTMLElement(CreateTab(anchor, bIsMyPage ));
					}
					// Spacer cell after the tab
					NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
				}
				// My Communities tab
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
				{
					img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
							true, this.m_asOwner).GetHTMLElement();

					img.SetBorder(CommonHTMLStrings.ZERO);
					img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					String comm = GeneralHelpers.TruncateLongString(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH, false);
					img.SetAlt(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
	
					// If selected tab, just make label, not a link
					boolean bIsComm = NavPageType.COMMUNITY == m_model.GetCurNavPageType();
					
					if ( bIsComm ) {
						col = new HTMLElementCollection();
						col.AddInnerHTMLElement(img);
						col.AddInnerHTMLString(comm);
	
						row.AddInnerHTMLElement(CreateTab(col, true ));
	
					} else {
	
						url = new ASURL(m_asOwner);
	
						// AGC- Bug# 12782. This link was originally assuming that a some community was available
						// and selected. This caused errors because it failed to take into account missing default
						// communities or even having no community selected at all. Here's the proper behavior:
						// 1. Go to comm page (if specified)
						// 2. If no access to comm page -> Go to default comm
						// 3. If no default comm -> Join comm page
						int nDefaultPageID = m_model.GetDefaultCommunity();
						nDefaultPageID = m_model.GetAccessibleCommunityID(nDefaultPageID);
	
						boolean bIsEditProfileNoCommunities = false;
						if (nDefaultPageID != -1)
						{
							url.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME,
								m_asOwner);
							url.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
							url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
								nDefaultPageID);
							url.AddControlArgument(SetCommunityControl.STR_PAGE_ID,
								0);
	
							
								log.Debug("Creating link to default community with id: " +
									nDefaultPageID);
							
							
						}
						else if(m_model.IsEditProfile())
						{
							bIsEditProfileNoCommunities = true;
						}
						else
						{
							// No valid community, go to the join communities editor
							
							url.SetLinkCreateNewSpace(CommunitySelectionEditorAS.STR_MVC_CLASS_NAME,
								m_asOwner);
							url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
							url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
								EditorStartControl.EDITOR_START_FLAG_MISC);
	
							
								log.Debug("No Community memberships, creating link to community selection page.");
							
						}
						
						if (bIsEditProfileNoCommunities)
						{
							anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
							anchor.SetOnClick(JS_EDIT_PROFILE_NO_COMM_ALERT + "(); return false;");
							anchor.AddInnerHTMLElement(img);
							anchor.AddInnerHTMLString(comm);
						}
						else
						{
							url.AddInnerHTMLElement(img);
							url.AddInnerHTMLString(comm);
							anchor = (HTMLAnchor)url.GetURLAsHTMLElement();
						}
						anchor.SetTitle(m_asOwner.GetString(252, ResourceConstants.PORTALCOMMONMSGS));
						row.AddInnerHTMLElement(CreateTab(anchor, bIsComm ));
					}
					// Spacer cell after the tab
					NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
				}
	
				// Directory tab
				if (m_model.GetSubPortalEnabled(
							PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
				{
					img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT,
							true, this.m_asOwner).GetHTMLElement();
					
					img.SetBorder(CommonHTMLStrings.ZERO);
					img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					String directory = GeneralHelpers.TruncateLongString(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH, false);
					img.SetAlt(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS));
	
					// If selected tab, just make label, not a link
					boolean bIsDirPage = NavPageType.DIRECTORY == m_model.GetCurNavPageType();
					if ( bIsDirPage ) {
						col = new HTMLElementCollection();
						col.AddInnerHTMLElement(img);
						col.AddInnerHTMLString(directory);
	
						row.AddInnerHTMLElement(CreateTab(col, true));
	
					} else {
						// Create a link to the directory page
						url = new ASURL(m_asOwner);
						if (DirAS.STR_MVC_CLASS_NAME.equals(m_asOwner.GetName()))
						{
							url.SetLinkGetCachedSpace(m_asOwner);
						}
						else
						{
							url.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
						}
				
						url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
						url.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, DirConstants.BROWSE_MODE);
						url.AddInnerHTMLElement(img);
						url.AddInnerHTMLString(directory);
						anchor = (HTMLAnchor)url.GetURLAsHTMLElement();
						anchor.SetTitle(m_asOwner.GetString(254, ResourceConstants.PORTALCOMMONMSGS));
						
						row.AddInnerHTMLElement(CreateTab(anchor, bIsDirPage));	
						
					}
					// Spacer cell after the tab
					NavigationCommonHelpers.CreateHorizontalSpacerCell(row);
				}
				// Link to administrative portal
				if (m_model.HasAdministratorAccess())
				{
					img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ADMINISTRATION,
							true, this.m_asOwner).GetHTMLElement();

					img.SetBorder(CommonHTMLStrings.ZERO);
					img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					String admin = GeneralHelpers.TruncateLongString(m_asOwner.GetString(275, ResourceConstants.PORTALCOMMONMSGS), TABGROUPS_TAB_TRUNCATION_WIDTH, false); 
					// Administration					
					img.SetAlt(m_asOwner.GetString(275, ResourceConstants.PORTALCOMMONMSGS));
					// Get the link to the admin portal
					ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.ADMIN, false);
					CListURLFullLinkMediator mediator = new CListURLFullLinkMediator(m_asOwner, cpList);
					HTMLAnchor adminURL = null;
					if ( cpList.Next() ) {
						adminURL = (HTMLAnchor)mediator.GetEntry();
					}
					
					// If selected tab, just make label, not a link		
					boolean bIsAdminPage = ObjMgrAS.STR_MVC_CLASS_NAME == m_asOwner.GetName();
					if ( bIsAdminPage ) {
						col = new HTMLElementCollection();
						col.AddInnerHTMLString(admin);
						row.AddInnerHTMLElement( CreateTab(col, true) );
					} else {
						row.AddInnerHTMLElement( CreateTab(adminURL, false) );	
					}
					
				}
			}

			// Spacer filler cell to fill out the remaining space
			HTMLTableCell cell = new HTMLTableCell();
			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			row.AddInnerHTMLElement(cell);
		}
		catch (Exception e)
		{
			
				log.Error(e, "Error displaying navigation section tabs, error: "+e.getMessage());

			
			return new HTMLGenericElement("Error displaying section tabs: " +
				e.getMessage());

		}

		return result;
	}
	
	/**
	 * Helper function that returns an HTMLTableCell with a clickable navigation tab
	 *
	 * @param element 			Either a link from an ASURL or just an image with label
	 * @param bOn				True if the current tab is the selected one
	 * @return HTMLTableCell	HTMLTableCell with 
	 * @throws Exception
	 */
	public HTMLTableCell CreateTab(HTMLElement element, boolean bOn)
		throws Exception
	{
		HTMLSpan span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.NAV_TAB_TEXT);
		span.AddInnerHTMLString("&nbsp;&nbsp;");
		span.AddInnerHTMLElement(element);
		span.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;");

		// Different stylesheet if currently selected
		HTMLTableCell cell = new HTMLTableCell();
		if ( bOn )
		{
			cell.SetStyleClass(PTStyleClass.NAV_TAB_ON_WHITE_BG);
		}

		cell.SetHeight("20");
		cell.SetWidth("160");
		cell.SetAlign(CommonHTMLStrings.MIDDLE);
		cell.SetNoWrap(true);
		cell.AddInnerHTMLElement(span);

		return cell;
	}

}

