using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.editors.document;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.approval;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.approval.document
{
  /// <author>Ben Geislinger</author>
  public class DocumentApprovalModel : AApprovalModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.approval.document.DocumentApprovalModel");
    public const String STR_MVC_CLASS_NAME = "DocumentApprovalModel";
    private IPTSession ptSession = null;
    private Object[] m_filterByIDs = null;
    
    /// <summary>
    /// Modifies the object name on repost.
    /// </summary>
    public virtual void ActionOnRepost()
    {
    }
    public override bool GetDisplaySelectAllButton()
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool AddColumnsHeaderForEachItem()
    {
      return false;
    }
    //////////////////////////////////////////////////
    //					EditorModel methods
    /////////////////////////////////////////////////
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DocumentApprovalModel();
    }
    
    /// <returns></returns>
    public override bool DisplayDescriptionImmediatelyUnderTitle()
    {
      return false;
    }
    public override bool DisplayItemTypeHeaderAboveActionbar()
    {
      return true;
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
    }
    
    /// <returns></returns>
    public override bool GetAllowClearingOfApprovalRequests()
    {
      return false;
    }
    
    /// <param name="item"></param>
    /// <returns></returns>
    public override bool GetAllowClearingOfItem(AItemDescriptor item)
    {
      return false;
    }
    
    /// <returns></returns>
    public override ApprovalItemType GetDefaultItemType()
    {
      return ApprovalPortalItemType.DOCUMENT;
    }
    
    /// <returns></returns>
    public override bool GetDisableRadioSelection()
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool GetDisplayHeadersForItemTypesWithNoItems()
    {
      return true;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override bool GetDisplayInstances(ApprovalItemType type)
    {
      return true;
    }
    
    /// <returns></returns>
    public override bool GetDisplayStatusColumn()
    {
      return false;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override bool GetDisplayTypeHeader(ApprovalItemType type)
    {
      return false;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override String GetEmptyTypeSectionSubTitle(ApprovalItemType type)
    {
      return m_asOwner.GetString(1688, ResourceConstants.PORTALADMINMSGS);
      }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public override String GetSubTitle()
    {
      int iLow = this.GetLowItemIndexForCurrentPage(ApprovalPortalItemType.DOCUMENT) + 1;
      int iHigh = this.GetHighItemIndexForCurrentPage(ApprovalPortalItemType.DOCUMENT) + 1;
      int iMax = this.GetTypeCount(ApprovalPortalItemType.DOCUMENT);
      String sOut = XPResourceManager.FormatMessage(m_asOwner.GetString(1689,
       ResourceConstants.PORTALADMINMSGS), iLow, iHigh, iMax);
      return sOut;
    }
    
    /// <returns></returns>
    public override XPArrayList GetSupportedItemTypes()
    {
      log.Debug("GetSupportedItemTypes");
      XPArrayList alTemp = new XPArrayList();
      alTemp.Add(ApprovalPortalItemType.DOCUMENT);
      return alTemp;
    }
    public virtual Object[] GetFilterByIDs()
    {
      return m_filterByIDs;
    }
    public virtual void SetFilterByIDs(Object[] _filterByIDs)
    {
      m_filterByIDs = _filterByIDs;
    }
    public virtual void ModifyCardFolders(int CardID, int[] FolderIDs)
    {
      IPTSession ptSession = GetSession();
      IPTCatalog ptCatalog = ptSession.GetCatalog();
      try
      {
        ptCatalog.AddCardToMultipleFolders(CardID, FolderIDs, PT_CARDREF_STATES.PT_PENDING_APPROVAL,
         false);
      }
      catch (Exception ex)
      {
        log.Error("ex: " + ex);
      }
      // now update the  cache in which this item is found
      // The basic idea is to get the page of item descriptors
      // containing the card that was modified...then iterate
      // over the complete list of folderIDs and add new instances
      // where they did not exist before
      IXPEnumerator enumItems = this.GetItemDescriptors(this.GetCurrentType());
      IXPEnumerator enumInstances;
      DocumentItemDescriptor item;
      DocumentInstanceDescriptor instance = null;
      if (enumItems != null)
      {
        while (enumItems.MoveNext())
        {
          item = (DocumentItemDescriptor) enumItems.GetCurrent();
          // find the item that corresponds to the updated card
          if (CardID == item.GetObjectID())
          {
            for (int i = 0;i < FolderIDs.Length;i++)
            {
              bool bFound = false;
              enumInstances = item.GetInstances();
              // for each card examine the cached instances
              while (enumInstances.MoveNext())
              {
                instance = (DocumentInstanceDescriptor) enumInstances.GetCurrent();
                if (instance.GetFolderObjectID() == FolderIDs[i])
                {
                  bFound = true;
                }
              }
              // if our instance iteration did not contain an entry for
              // a given folder then add one....
              if (!bFound)
              {
                try
                {
                  IPTFolder ptFolder = ptCatalog.OpenFolder(FolderIDs[i],
                   false);
                  log.Debug("folder path: " + ptFolder.GetPath());
                  // Open folder URL
                  ASURL url = new ASURL(m_asOwner);
                  url.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, this.m_asOwner);
                  url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
                  url.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
                   FolderIDs[i]);
                  //						url.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
                  //							XPConvert.ToString(((DirModel)model).GetDirectoryMode()));
                  String strOpenFolderURL = url.GetURLAsString();
                  HTMLAnchor ePath = new HTMLAnchor(strOpenFolderURL);
                  ePath.AddInnerHTMLEncodedString(ptFolder.GetPath());
                  instance = new DocumentInstanceDescriptor(item, ePath, this.m_asOwner);
                  instance.SetObjectID(CardID);
                  instance.SetFolderObjectID(FolderIDs[i]);
                  item.AddInstance(instance);
                }
                catch (Exception ex)
                {
                  log.Error("Couldn\'t open folder with id: " + FolderIDs[i]);
                  }
              }
            }
          }
        }
      }
    }
    
    /// <returns></returns>
    public override String GetTitle()
    {
      return m_asOwner.GetString(7, ResourceConstants.PORTALADMINMSGS);
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override XPArrayList InternalGetItemDescriptors(ApprovalItemType type,
     int iLow, int iHigh)
    {
      log.Debug("InternalGetItemDescriptors()");
      log.Debug("InternalGetItemDescriptors - type: " + type);
      log.Debug("InternalGetItemDescriptors() - iLow: " + iLow);
      log.Debug("InternalGetItemDescriptors() - iHigh: " + iHigh);
      if (type != ApprovalPortalItemType.DOCUMENT)
      {
        return null;
      }
      IPTSession ptSession = GetSession();
      IPTCatalog ptCatalog = ptSession.GetCatalog();
      XPArrayList alItems = new XPArrayList();
      String sItemName;
      String sDescription;
      String sUUID;
      String sSubmittedBy;
      XPDateTime submittedDate;
      HTMLElement ePath;
      DocumentItemDescriptor item;
      DocumentInstanceDescriptor instance;
      int iSkip = iLow;
      int iMax = (iHigh - iLow) + 1;
      IPTCard ptCard = null;
      IPTFolder ptFolder = null;
      IPTQueryResult qrCards;
      IPTQueryResult qrFolders;
      int[] ia;
      int iRootFolderID = PT_INTRINSICS.PT_FOLDER_ROOTFOLDER;
      int iCount;
      int iMask;
      try
      {
        iMask = PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_IMAGEUUID;
        Object oOrderBy = null;
        if (this.DoSortSubmittedBy())
        {
          log.Debug("InternalGetItemDescriptors() - sorting by submitted by!");
          oOrderBy = PT_PROPIDS.PT_PROPID_CARD_CRAWLERID;
        } else
        if (this.DoSortName())
        {
          log.Debug("InternalGetItemDescriptors() - sorting by name!");
          oOrderBy = PT_PROPIDS.PT_PROPID_NAME;
        } else
        if (this.DoSortDate())
        {
          log.Debug("InternalGetItemDescriptors() - sorting by date!");
          oOrderBy = PT_PROPIDS.PT_PROPID_CREATED;
        } else
        {
          log.Debug("InternalGetItemDescriptors() - sorting by submitted by!");
          oOrderBy = PT_PROPIDS.PT_PROPID_CARD_CRAWLERID;
        }
        /* filter results by crawler IDs if necessary */
        Object[][] filter = null;
        if (null != m_filterByIDs)
        {
          filter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_CARD_CRAWLERID,
           PT_FILTEROPS.PT_FILTEROP_IN, m_filterByIDs);
        }
        qrCards = ptCatalog.QueryUnapprovedCardsByBranch(iRootFolderID, true,
         iMask, oOrderBy, iSkip, iMax, filter);
        int cardObjectID = -1;
        int folderObjectID = -1;
        iCount = qrCards.RowCount();
        log.Debug("Query unapproved cards, iCount: " + iCount);
        for (int x = 0;x < iCount;x++)
        {
          log.Debug("About to get row: " + x);
          cardObjectID = qrCards.ItemAsInt(x, PT_PROPIDS.PT_PROPID_OBJECTID);
          sUUID = null;
          sUUID = qrCards.ItemAsString(x, PT_PROPIDS.PT_PROPID_IMAGEUUID);
          log.Debug("About to open card: " + cardObjectID);
          ptCard = ptCatalog.OpenCard(cardObjectID, false);
          sItemName = ptCard.GetLocalizedName();
          sDescription = ptCard.GetLocalizedDescription();
          int iCrawlerID = ptCard.GetCrawlerID();
          log.Debug("InternalGetItemDescriptors() - iCrawlerID: " + iCrawlerID);
          if ((iCrawlerID != -1) && (iCrawlerID != 0))
          {
            try
            {
              IPTObjectManager om = ptSession.GetCrawlers();
              IPTCrawler c = (IPTCrawler) om.Open(iCrawlerID, false);
              sSubmittedBy = c.GetLocalizedName();
            }
            catch (Exception ex)
            {
              sSubmittedBy = "";
            }
          } else
          {
            try
            {
              IPTServerContext ptSC = (IPTServerContext) ptCard.GetInterfaces("IPTServerContext");
              int iOwner = ptSC.GetOwnerID();
              IPTObjectManager om = ptSession.GetUsers();
              IPTUser u = (IPTUser) om.Open(iOwner, false);
              sSubmittedBy = u.GetLocalizedName();
            }
            catch (Exception ex)
            {
              log.Error("Couldnt determine owner for card.");
              sSubmittedBy = "";
            }
          }
          submittedDate = ptCard.GetCreated();
          item = new DocumentItemDescriptor(sItemName, sDescription, sSubmittedBy,
           submittedDate, this.m_asOwner);
          item.SetObjectID(cardObjectID);
          item.SetImgUUID(sUUID);
          //Edit Card URL
          ASURL url = new ASURL(m_asOwner);
          url.SetLinkCreateNewSpace(CardEditorAS.STR_MVC_CLASS_NAME, this.m_asOwner);
          url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
          url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
          url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
          url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
           cardObjectID);
          String strEditCardURL = url.GetURLAsString();
          item.SetEditHRef(strEditCardURL);
          Redirect r = new Redirect();
          r.SetLinkCreateNewSpace(CardEditorAS.STR_MVC_CLASS_NAME, this.m_asOwner);
          r.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
          r.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
          r.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
          r.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
           cardObjectID);
          item.SetEditRedirect(r);
          String sURL = ptCard.GetDocumentURL();
          item.SetPreviewHRef(sURL);
          item.SetDescription(sDescription);
          alItems.Add(item);
          ia = new int[1];
          ia[0] = cardObjectID;
          qrFolders = ptCatalog.QueryCardPaths(ia, true, true);
          int iFolderCount = 0;
          try
          {
            iFolderCount = qrFolders.RowCount();
          }
          catch (Exception ex)
          {
            log.Error("couldn\'t get folder count.");
          }
          log.Debug("iFolderCount: " + iFolderCount);
          for (int y = 0;y < iFolderCount;y++)
          {
            try
            {
              folderObjectID = qrFolders.ItemAsInt(y, PT_PROPIDS.PT_PROPID_CARD_PARENTFOLDERID);
              ptFolder = ptCatalog.OpenFolder(folderObjectID, false);
              log.Debug("folder path: " + ptFolder.GetPath());
              // Open folder URL
              url = new ASURL(m_asOwner);
              url.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, this.m_asOwner);
              url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
              url.AddControlArgument(OpenSubFolderControl.m_SubFolderID, folderObjectID);
              //						url.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
              //							XPConvert.ToString(((DirModel)model).GetDirectoryMode()));
              String strOpenFolderURL = url.GetURLAsString();
              ePath = new HTMLAnchor(strOpenFolderURL);
              ePath.AddInnerHTMLEncodedString(ptFolder.GetPath());
              instance = new DocumentInstanceDescriptor(item, ePath, this.m_asOwner);
              instance.SetObjectID(cardObjectID);
              instance.SetFolderObjectID(folderObjectID);
              item.AddInstance(instance);
            }
            catch (Exception ex)
            {
              log.Error("Couldn\'t open folder with id: " + folderObjectID);
              }
          }
        }
      }
      catch (Exception ex)
      {
        log.Error("ex: " + ex);
      }
      return alItems;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override int InternalGetTypeCount(ApprovalItemType type)
    {
      if (type != ApprovalPortalItemType.DOCUMENT)
      {
        return 0;
      }
      IPTSession ptSession = GetSession();
      IPTCatalog ptCatalog = ptSession.GetCatalog();
      int iCount = 0;
      try
      {
        /* filter results by crawler IDs if necessary */
        if (null != m_filterByIDs)
        {
          Object[][] filter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_CARD_CRAWLERID,
           PT_FILTEROPS.PT_FILTEROP_IN, m_filterByIDs);
          IPTQueryResult qrCards = ptCatalog.QueryUnapprovedCardsByBranch(PT_INTRINSICS.PT_FOLDER_ROOTFOLDER,
           true, PT_PROPIDS.PT_PROPID_OBJECTID, null, 0, -1, filter);
          iCount = qrCards.RowCount();
        } else
        {
          iCount = ptCatalog.QueryUnapprovedCardsCountGlobal(true);
        }
      }
      catch (Exception ex)
      {
      }
      return iCount;
    }
    
    /// <returns></returns>
    public override bool IsDateSortable()
    {
      return true;
    }
    
    /// <returns></returns>
    public override bool IsDescriptionEditable()
    {
      return true;
    }
    
    /// <returns></returns>
    public override bool IsNameSortable()
    {
      return true;
    }
    
    /// <returns></returns>
    public override bool IsSubmittedBySortable()
    {
      return true;
    }
    
    /// <returns></returns>
    public override bool IsTitleEditable()
    {
      return true;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      if (_sPageName.Equals(DocumentApprovalDP.STR_MVC_CLASS_NAME))
      {
        SaveMainPage(_htFormData);
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
    }
    
    /// <returns></returns>
    private IPTSession GetSession()
    {
      if (ptSession == null)
      {
        ptSession = (IPTSession) m_asOwner.GetUserSession();
      }
      return ptSession;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.approval.IApprovalModelRO#DisplayItemComment()
     */
     
    public override bool DisplayItemComment()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.approval.IApprovalModelRO#DisplayViewItems()
     */
     
    public override bool DisplayViewItems()
    {
      return true;
    }
  }
}