using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.approval;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.approval.document
{
  /// <author>Ben Geislinger</author>
  public class DocumentInstanceDescriptor : AInstanceDescriptor
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.approval.document.DocumentInstanceDescriptor");
    private int iClassID = -1;
    private int iFolderObjectID = -1;
    private int iObjectID = -1;
    
    /// <summary>
    /// Creates a new DocumentInstanceDescriptor object.
    /// </summary>
    /// <param name="item"></param>
    /// <param name="ePath"></param>
    public DocumentInstanceDescriptor(DocumentItemDescriptor item, HTMLElement ePath,
     AActivitySpace space) : base((AItemDescriptor) item, ePath, ApprovalPortalItemType.DOCUMENT,
     space)
    {
    }
    public override void Execute()
    {
      log.Debug("ENTERING Execute() - iObjectID: " + iObjectID);
      IPTSession ptSession = (IPTSession) mySpace.GetUserSession();
      IPTCatalog catalog = ptSession.GetCatalog();
      try
      {
        if (this.GetApprove())
        {
          log.Debug("Execute() - About to server APPROVE.");
          int[] ia = new int[1];
          ia[0] = iObjectID;
          catalog.SetApprovalStateByFolder(iFolderObjectID, PT_CARDREF_STATES.PT_APPROVED,
           ia);
        } else
        if (this.GetReject())
        {
          log.Debug("Execute() - About to server REJECT.");
          int[] ia = new int[1];
          ia[0] = iObjectID;
          catalog.RemoveCards(iFolderObjectID, ia);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Couldn\'t approve or reject object.");
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         "Couldn\'t approve object.", ex.Message);
        myError.SetActivitySpace(mySpace.GetName());
        myError.SetClearWithActivitySpaceChange(true);
        UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(), mySpace.GetApplication());
        }
    }
    
    /// <returns></returns>
    public virtual int GetClassID()
    {
      return iClassID;
    }
    
    /// <returns></returns>
    public virtual int GetFolderObjectID()
    {
      return iFolderObjectID;
    }
    
    /// <returns></returns>
    public virtual int GetObjectID()
    {
      return iObjectID;
    }
    
    /// <param name="i"></param>
    public virtual void SetClassID(int i)
    {
      iClassID = i;
    }
    
    /// <param name="i"></param>
    public virtual void SetFolderObjectID(int i)
    {
      iFolderObjectID = i;
      base.SetPTFolderID(i);
    }
    
    /// <param name="i"></param>
    public virtual void SetObjectID(int i)
    {
      iObjectID = i;
    }
  }
}