using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.approval;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.admin.approval.document
{
  /// <author>Ben Geislinger</author>
  public class DocumentItemDescriptor : AItemDescriptor
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.approval.document.DocumentItemDescriptor");
    private String sStatus = "";
    private int iClassID = -1;
    private int iObjectID = -1;
    private String sOriginalName = null;
    private String sOriginalDesc = null;
    
    /// <summary>
    /// Creates a new DocumentItemDescriptor object.
    /// </summary>
    /// <param name="name"></param>
    /// <param name="description"></param>
    /// <param name="submittedBy"></param>
    /// <param name="submittedDate"></param>
    /// <param name="space"></param>
    public DocumentItemDescriptor(String name, String description, String submittedBy,
     XPDateTime submittedDate, AActivitySpace space) : base(name, description,
     submittedBy, submittedDate, space, ApprovalPortalItemType.DOCUMENT)
    {
      sOriginalName = name;
      sOriginalDesc = description;
    }
    public override void Execute()
    {
      log.Debug("ENTERING Execute() - iObjectID: " + iObjectID);
      IPTSession ptSession = (IPTSession) mySpace.GetUserSession();
      IPTCatalog catalog = ptSession.GetCatalog();
      try
      {
        if (this.GetApprove())
        {
          log.Debug("Execute() - About to server APPROVE.");
          catalog.ApproveCardWhereUnapproved(this.GetObjectID());
        } else
        if (this.GetReject())
        {
          log.Debug("Execute() - About to server REJECT.");
          catalog.DiscardCardWhereUnapproved(1);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Couldn\'t approve or reject object.");
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         this.mySpace.GetString(2420, ResourceConstants.PORTALADMINMSGS),
         ex.Message);
        myError.SetActivitySpace(mySpace.GetName());
        myError.SetClearWithActivitySpaceChange(true);
        UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(), mySpace.GetApplication());
        }
      /* update card if name or description has changed */
      String sName = this.GetName();
      String sDesc = this.GetDescription();
      bool nameChanged = (null != sName && !sName.Equals(sOriginalName));
      bool descChanged = (null != sDesc && !sDesc.Equals(sOriginalDesc));
      if (nameChanged || descChanged)
      {
        IPTCard card = null;
        try
        {
          /* update name/desc */
          card = catalog.OpenCard(this.GetObjectID(), true);
          if (nameChanged)
          {
            card.SetName(sName);
          }
          if (descChanged)
          {
            card.SetDescription(sDesc);
          }
          card.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INDEXONSTORE, 1);
          /* save */
          ((IPTServerContext) card).Store();
          ((IPTServerContext) card).UnlockObject();
          //	it worked!
          sOriginalName = sName;
          sOriginalDesc = sDesc;
        }
        catch (Exception ex)
        {
          if (card != null)
          {
            //	 just try to unlock it in case an exception was thrown
            //	after opening it.
            try
            {
              ((IPTServerContext) card).UnlockObject();
            }
            catch (Exception ex2)
            {
            }
          }
          if (nameChanged)
          {
            log.Error(ex, "Couldnt save new name on card.");
          }
          if (descChanged)
          {
            log.Error(ex, "Couldnt save new description on card.");
          }
          UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
           this.mySpace.GetString(2419, ResourceConstants.PORTALADMINMSGS),
           ex.Message);
          myError.SetActivitySpace(mySpace.GetName());
          myError.SetClearWithActivitySpaceChange(true);
          UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(), mySpace.GetApplication());
          }
      }
    }
    //	card changed
    
    /// <returns></returns>
    public virtual int GetClassID()
    {
      return iClassID;
    }
    
    /// <returns></returns>
    public virtual int GetObjectID()
    {
      return iObjectID;
    }
    
    /// <returns></returns>
    public override String GetStatus()
    {
      return sStatus;
    }
    
    /// <param name="i"></param>
    public virtual void SetClassID(int i)
    {
      iClassID = i;
    }
    
    /// <param name="i"></param>
    public virtual void SetObjectID(int i)
    {
      iObjectID = i;
    }
    
    /// <param name="s"></param>
    public virtual void SetStatus(String s)
    {
      sStatus = s;
    }
  }
}