using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.objectapproval;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.approval.ptobject
{
  /// <author>BenG</author>
  public class ObjectApprovalDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.approval.ptobject.ObjectApprovalDP");
    // COMMENT1- All the DPs in your AS need to have a unique name.
    private static readonly String STR_MVC_CLASS_NAME = ObjectApprovalModel.GetDefaultItemTypeStatic().GetName();
    protected ApprovalItemType type = null;
    protected String sTypeName = null;
    
    /// <summary>
    /// This constructor takes a string representing an ApprovalItemType.
    /// This ApprovalItemType is the ApprovalItemType displayed by this DP.
    /// </summary>
    public ObjectApprovalDP(String s)
    {
      log.Debug("ObjectApprovalDP() - s: " + s);
      sTypeName = s;
      ApprovalItemType t = ObjectApprovalModel.GetDefaultItemTypeStatic();
      type = t.GetType(sTypeName);
    }
    
    /// <summary>
    /// Creates a new ObjectApprovalDP object.
    /// </summary>
    public ObjectApprovalDP()
    {
      log.Debug("ObjectApprovalDP() - No type name provided.");
    }
    
    /// <returns></returns>
    public static String GetDefaultName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      AActivitySpace space = this.m_asOwner;
      ObjectApprovalModel myModel = (ObjectApprovalModel) space.GetModel(ObjectApprovalModel.STR_MVC_CLASS_NAME);
      String sMenuText = myModel.GetMenuOptionText(type);
      return (sMenuText);
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(3159, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      String s;
      //	hack - the GetName method does not always return the name of this
      //	class.  If possible, it returns the name of the item type displayed
      //	by this page.  See ObjectApprovalAS.
      if (sTypeName != null)
      {
        s = sTypeName;
      } else
      {
        s = ObjectApprovalModel.GetDefaultItemTypeStatic().GetName();
      }
      return s;
    }
    
    /// <summary>
    /// Returns the HTML for that Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      log.Debug("PageDisplay() - sTypeName: " + sTypeName);
      if (type == null)
      {
        type = ((ObjectApprovalModel) this.m_asOwner.GetModel(ObjectApprovalModel.STR_MVC_CLASS_NAME)).GetCurrentType();
        sTypeName = type.GetName();
      }
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      /*
       //	we get the default item type because we need to call
       //	method on an ApprovalItemType instance.  It doesn't matter which
       //	instance, the method should be static but it cannot be.
       ApprovalItemType t = ObjectApprovalModel.GetDefaultItemTypeStatic();
       
       //	Here we call the display method and pass the type name
       //	of this display page.
       ApprovalItemType typeToDisplay = null;
       
       typeToDisplay = t.GetType(sTypeName);
       
       if (typeToDisplay == null)
       {
       typeToDisplay = t;
       }
       */
       
      ApprovalItemType typeToDisplay = type;
      ObjectApprovalModel m = (ObjectApprovalModel) this.m_asOwner.GetModel(ObjectApprovalModel.STR_MVC_CLASS_NAME);
      if (m.GetTypeCount(type) <= 0)
      {
        typeToDisplay = null;
      }
      views.AddInnerHTMLElement(((ApprovalView) m_asOwner.GetView(ApprovalView.STR_MVC_CLASS_NAME)).Display(typeToDisplay));
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
  }
}