using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.objectapproval;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.approval.ptobject
{
  /// <author>BenG</author>
  public class ObjectApprovalStatusDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.approval.ptobject.ObjectApprovalStatusDP");
    // COMMENT1- All the DPs in your AS need to have a unique name.
    private static readonly String STR_MVC_CLASS_NAME = ObjectApprovalModel.GetDefaultItemTypeStatic().GetName();
    protected ApprovalItemType type = null;
    protected String sTypeName = null;
    
    /// <summary>
    /// This constructor takes a string representing an ApprovalItemType.
    /// This ApprovalItemType is the ApprovalItemType displayed by this DP.
    /// </summary>
    public ObjectApprovalStatusDP(String s)
    {
      log.Debug("ObjectApprovalDP() - s: " + s);
      sTypeName = s;
      ApprovalItemType t = ObjectApprovalModel.GetDefaultItemTypeStatic();
      type = t.GetType(sTypeName);
    }
    
    /// <summary>
    /// Creates a new ObjectApprovalStatusDP object.
    /// </summary>
    public ObjectApprovalStatusDP()
    {
      log.Debug("ObjectApprovalStatusDP() - No type name provided.");
    }
    
    /// <returns></returns>
    public static String GetDefaultName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      AActivitySpace space = this.m_asOwner;
      ObjectApprovalModel myModel = (ObjectApprovalModel) space.GetModel(ObjectApprovalModel.STR_MVC_CLASS_NAME);
      String sMenuText = myModel.GetStatusPageMenuOptionText(type);
      return (sMenuText);
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      if (type == null)
      {
        // mel: When type == null, this is the generic ObjectApprovalStatusDP
        // that will only be shown when there are
        // no outstanding approval requests for any type.
        return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(3161,
         ResourceConstants.PORTALADMINMSGS), this.m_asOwner);
      }
      // No outstanding approval requests for this particular type
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1649, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      String s;
      //	hack - the GetName method does not always return the name of this
      //	class.  If possible, it returns the name of the item type displayed
      //	by this page.  See ObjectApprovalAS.
      if (sTypeName != null)
      {
        s = sTypeName;
      } else
      {
        s = ObjectApprovalModel.GetDefaultItemTypeStatic().GetName();
      }
      return s;
    }
    
    /// <summary>
    /// Returns the HTML for that Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      log.Debug("PageDisplay() - sTypeName: " + sTypeName);
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLElementCollection views = new HTMLElementCollection();
      if (type == null)
      {
        // mel: When type == null, this is the generic ObjectApprovalStatusDP
        // that will only be shown when there are
        // no outstanding approval requests for any type.
        // This code change for bug 41845 ensures that nothing but a
        // message is shown, i.e. no approval view.
        result.AddInnerHTMLElement(base.PageDisplay());
        result.AddInnerHTMLElement(CreateLeftNavBar(views));
        return result;
      }
      // mel: The old code took the default from the model, which was admin folder.
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      //	we get the default item type because we need to call
      //	method on an ApprovalItemType instance.  It doesn't matter which
      //	instance, the method should be static but it cannot be.
      ApprovalItemType t = ObjectApprovalModel.GetDefaultItemTypeStatic();
      //	Here we call the display method and pass the type name
      //	of this display page.
      ApprovalItemType typeToDisplay = null;
      typeToDisplay = t.GetType(sTypeName);
      if (typeToDisplay == null)
      {
        typeToDisplay = t;
      }
      views.AddInnerHTMLElement(((ApprovalView) m_asOwner.GetView(ApprovalView.STR_MVC_CLASS_NAME)).Display(typeToDisplay));
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
  }
}