using System;
using com.plumtree.portalpages.common.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.adminfolder
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the Advanced Settings page of the Admin Folder Editor.
  /// </summary>
  /// <author>RickyW</author>
  public class AdminFolderAdvDP : EditorDP
  {
    
    /// <summary>
    /// class name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AdminFolderAdvDP";
    
    /// <summary>
    /// Customizes the spacing on the left and right sides of the content
    /// table.  The default value is 15.  Set to 0 if you don't want views
    /// to be indented.
    /// </summary>
    public AdminFolderAdvDP() : base()
    {
      base.SetContentTableCellSpacing("15");
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(8, ResourceConstants.PORTALADMINMSGS);
    }
    // localized strings
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the Advanced Settings page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // For each Section you want to display on that page,
      // copy the line below and change the name of the Section.
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(AdminFolderAdvView.STR_MVC_CLASS_NAME)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // call DisplayJavascript() for all views displayed that have JS.
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(AdminFolderAdvView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()"></seealso>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(9, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
  }
}