using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.subportal;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.securitymatrix;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.adminfolder
{
  /// <summary>
  /// This class is used to register the models, views, controls, and display pages
  /// for the AdminFolder editor.  This class can also be used to get any of those
  /// objects back with the class name.
  /// </summary>
  /// <author>RickyW</author>
  public class AdminFolderEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.adminfolder.AdminFolderEditorAS");
    
    /// <summary>
    /// class name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AdminFolderEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AdminFolderEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        // Return the main title of the Editor in create mode.
        return GetString(16, ResourceConstants.PORTALADMINMSGS);
      } else
      {
        // Return the main title of the Editor in edit mode.
        return (XPResourceManager.FormatMessage(GetString(2618, ResourceConstants.PORTALADMINMSGS),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (AdminFolderDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (AdminFolderRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = AdminFolderModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(AdminFolderModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      ABOBlankSelectDP dpABOBlankSelect = new ABOBlankSelectDP();
      dpABOBlankSelect.SetRepostControlName(AdminFolderRepostControl.STR_MVC_CLASS_NAME);
      RegisterPage(dpABOBlankSelect);
      RegisterPage(new ABOPopupSelectDP());
      ABOBlankResultsDP dpABOBlankResults = new ABOBlankResultsDP();
      dpABOBlankResults.SetRepostControlName(AdminFolderRepostControl.STR_MVC_CLASS_NAME);
      RegisterPage(dpABOBlankResults);
      RegisterPage(new ABOPopupResultsDP());
      // Register Views
      RegisterView(ABOPopupSelectView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ABOPopupResultsView.STR_MVC_CLASS_NAME, myModel);
      AdminFolderAdvDP myAdvDP = new AdminFolderAdvDP();
      //		AdminFolderBlankSelectDP myABOBlankSelectDP = new AdminFolderBlankSelectDP();
      //		AdminFolderABODP myABOSelectDP			    = new AdminFolderABODP();
      //		AdminFolderBlankLinksDP myABOBlankLinksDP   = new AdminFolderBlankLinksDP();
      //		AdminFolderABOLinksDP myABOLinksDP		    = new AdminFolderABOLinksDP();
      // finally register
      RegisterPage(myAdvDP);
      //		RegisterPage(myABOBlankSelectDP);
      //		RegisterPage(myABOSelectDP);
      //		RegisterPage(myABOBlankLinksDP);
      //		RegisterPage(myABOLinksDP);
      // Register Views
      RegisterView(AdminFolderAdvView.STR_MVC_CLASS_NAME, myModel);
      //		RegisterView(AdminFolderABOView.STR_MVC_CLASS_NAME, myModel);
      //		RegisterView(AdminFolderABOLinksView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(AdminFolderDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(AdminFolderRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set the default page
      SetCurrentPage(LocNamesDP.STR_MVC_CLASS_NAME);
      if (!(this.IsSubSpace()) || !GetParentSpaceName().Equals(SubPortalAS.STR_MVC_CLASS_NAME))
      {
        // Create general settings submenu
        int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(18, ResourceConstants.PORTALADMINMSGS));
        // Add subportal settings page
        m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AdminFolderAdvDP.STR_MVC_CLASS_NAME);
        }
      // Create standard settings submenu
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1700, ResourceConstants.PORTALADMINMSGS));
      // Add Properties and Names page
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      // Add Security page
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      // Add Migration History page
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          int iTitleId = 9;
          int iTipId = 10;
          int iSecondaryTipId = 11;
          tm.SetTipTitle(this.GetString(iTitleId, ResourceConstants.TIPS));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           ResourceConstants.TIPS));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, ResourceConstants.TIPS);
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (AdminFolderAdvDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AdministrativeFolder_SubportalSettings");
      }
    }
  }
}