using System;
using com.plumtree.openfoundation.io;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.common.setjob;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.authsource
{
  /// <author>OlegS</author>
  public abstract class AuthSourceModel : ObjEditorModel,IAuthSourceModelRO,
  PropertyValidatorOwner
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.authsource.AuthSourceModel");
    protected const String templatesDir = "ldap";
    protected static readonly String templatesPatttern = templatesDir + XPFileSystemObject.GetPathSeparator() + "*.xml";
    public String m_lastTreeSpaceId_ADMINFOLDERTREESPACE = null;
    public String m_lastTreeSpaceId_USERGROUPTREESPACE = null;
    public XPStringBuilder m_errors;
    // set just before SavePage() from SetRepostAction() hook
    public int m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
    public int m_templateSelected = -1;
    // aj: the category as a String
    protected String m_sCategory;
    // member variables
    protected XPArrayList m_ActionData = null;
    protected XPArrayList m_groupsOrder;
    protected int m_iddefFolder = 0;
    protected Object m_originalPassword;
    protected bool m_sameTimeCreatedAndModified;
    protected int m_nReenabled = 0;
    protected bool m_bImportCrossASMemberships;
    
    /// <summary>
    /// Creates a new AuthSourceModel object.
    /// </summary>
    public AuthSourceModel() : base()
    {
      m_errors = new XPStringBuilder();
      m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
      m_groupsOrder = new XPArrayList();
      m_groupsOrder.Add(0);
    }
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
    }
    
    /// <returns></returns>
    public virtual XPStringBuilder GetErrorString()
    {
      return m_errors;
    }
    public override void DoTaskAfterStore()
    {
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskAfterStoreSetJob();
      }
    public override void DoTaskBeforeStore()
    {
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStoreSetJob();
      }
    public override void DoTaskOnComeBackFromSubEditor()
    {
      base.DoTaskOnComeBackFromSubEditor();
      ((SelectPTObjectModel) m_asOwner.GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).DoTaskOnComeBackFromSubEditor();
      }
    
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      Object[][] groups = mappedGroups(0);
      for (int i = 0;i < groups[0].Length;i++)
      {
        m_groupsOrder.Add(i);
      }
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      XPDateTime dtc = ptAS.GetCreated();
      XPDateTime dtm = ptAS.GetLastModified();
      m_sameTimeCreatedAndModified = (dtc.GetTimeInMilliSeconds() == dtm.GetTimeInMilliSeconds());
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().SetMandatoryPage(false, ((AuthSourceEditorAS) m_asOwner).GetPageNameMain());
        // aj: load the category here
        m_sCategory = ptAS.GetPrefixString();
        if (m_sCategory == null)
        {
          m_sCategory = "";
        }
      } else
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        // aj: category is empty
        m_sCategory = "";
        // aj: bug 27447 - create the disabled group folder...
        CreateDisabledGroupFolder(ptAS);
      }
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskOnStartSetJob(m_ptObject,
       m_Session, GetEditorType());
      onPossibleChangeOfSyncMode(-1);
      // aj: initialize the cross memberships flag
      m_bImportCrossASMemberships = ptAS.GetImportCrossASMembers();
    }
    
    /// <summary>
    /// Creates a disabled group folder and associated with the given
    /// auth source.
    /// </summary>
    /// <param name="ptAS">- IPTAuthSource to associate the disabled folder with...</param>
    protected virtual void CreateDisabledGroupFolder(IPTAuthSource ptAS)
    {
      int nAuthSourceFolderID = ptAS.GetAdminFolderID();
      if (nAuthSourceFolderID > 0)
      {
        // aj: try to create a new folder, we may not have permissions to
        //     in which case we should not fail
        try
        {
          IPTAdminCatalog pCat = m_Session.GetAdminCatalog();
          IPTAdminFolder pDisabledGroupFolder = pCat.CreateAdminFolder(nAuthSourceFolderID,
           PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_REGULARFOLDER);
          pDisabledGroupFolder.SetName(m_asOwner.GetString(3167, ResourceConstants.PORTALADMINMSGS));
          pDisabledGroupFolder.Store();
          pDisabledGroupFolder.UnlockObject();
          int nDisabledGroupFolderID = pDisabledGroupFolder.GetObjectID();
          // aj: if successful, then set on the auth source
          if (nDisabledGroupFolderID > 0)
          {
            ptAS.SetDeletedGroupFolderID(nDisabledGroupFolderID);
          }
        }
        catch (XPException xpe)
        {
          // aj: log and skip this step...
          log.Warn(xpe, "AuthSourceModel::CreateDisabledGroupFolder - Unable to create a \'Groups to Delete\' folder for new Authentication Source. User will have to manually create this directory and specify it in the editor.");
          }
      }
    }
    
    /// <param name="o"></param>
    /// <returns></returns>
    public virtual String ExtractOneElement(Object o)
    {
      if (o == null)
      {
        return null;
      }
      String[] sa = (String[]) o;
      String result = ((sa == null) || (sa.Length < 1)) ? null : sa[0];
      if ((result == null) || (XPStringUtility.Trim(result).Length < 1))
      {
        result = null;
      }
      return result;
    }
    
    /// <returns></returns>
    public virtual String GetEmptyListInstructions()
    {
      return m_asOwner.GetString(2058, ResourceConstants.PORTALADMINMSGS);
      }
    
    /// <returns></returns>
    public virtual String GetEmptyListMainMessage()
    {
      return m_asOwner.GetString(2057, ResourceConstants.PORTALADMINMSGS);
      }
    
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      TraceHelper.Trace("SavePage(" + _sPageName + ")");
      TraceHelper.TraceQueryString(_htFormData);
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageNameMain()))
      {
        nPageStatus = SaveMainPage(_htFormData);
      } else
      if (_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageName2()))
      {
        nPageStatus = SavePage2(_htFormData);
      } else
      if (_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageName3()))
      {
        nPageStatus = SavePage3(_htFormData);
      } else
      if (_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageName4()))
      {
        nPageStatus = SavePage4(_htFormData);
      } else
      if (_sPageName.Equals(SetJobDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      if (m_nAction == AuthSourceRepostControl.POSTTOSELF_ACTION_FINISH)
      {
        // in case Finish is hit on main or other page
        validateAllProperties();
      } else
      if (_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageNameMain()))
      {
        validatePage1Properties();
      } else
      if ((!_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageName3())) && (!_sPageName.Equals(((AuthSourceEditorAS) m_asOwner).GetPageName4())))
      {
        validatePage2Properties();
      }
      if (m_nAction == AuthSourceRepostControl.POSTTOSELF_ACTION_FINISH || m_nAction == AuthSourceRepostControl.POSTTOSELF_ACTION_GOTOPAGE)
      {
        //	validate folders selected on fully sync page; note that onChangeCheckboxForSyncGroup is hit after this point
        IPTAuthSource ptAS = (IPTAuthSource) GetObject();
        //			int folderid=ptAS.GetDeletedUserFolderID();
        //			if(folderid==-1)
        //				SetInvalid(m_asOwner.GetString(2440, ResourceConstants.PORTALADMINMSGS)); //"Folder for disabled users is empty"
        int folderid = ptAS.GetDeletedGroupFolderID();
        if (folderid == -1)
        {
          //"Folder for disabled groups is empty"
          SetInvalid(m_asOwner.GetString(2441, ResourceConstants.PORTALADMINMSGS));
          }
      }
      if (m_errors.GetLength() > 0)
      {
        nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        String msg = m_asOwner.GetString(2055, ResourceConstants.PORTALADMINMSGS) + " " + m_errors.ToString();
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        m_errors.SetLength(0);
      }
      return nPageStatus;
    }
    protected virtual void validateAllProperties()
    {
      validatePage1Properties();
      validatePage2Properties();
    }
    protected virtual void validatePage1Properties()
    {
      // aj: if there are no errors yet, then go ahead
      //     and validate the category...
      if (m_errors.GetLength() == 0)
      {
        if (m_sCategory == null || XPStringUtility.Trim(m_sCategory).Length == 0)
        {
          String sErrorMsg = m_asOwner.GetString(3122, ResourceConstants.PORTALADMINMSGS);
          m_errors.Append(sErrorMsg);
        }
      }
    }
    protected virtual void validatePage2Properties()
    {
    }
    
    /// <param name="doFilterByAuthSource"></param>
    /// <returns></returns>
    public virtual Object[][] allGroups(bool doFilterByAuthSource)
    {
      PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetUserGroups());
      int fields = PT_PROPIDS.PT_PROPID_OBJECTID | 
      //|PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
      PT_PROPIDS.PT_PROPID_NAME;
      Object[][] filter = null;
      if (doFilterByAuthSource)
      {
        filter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_USERGROUP_AUTHSOURCE,
         PT_FILTEROPS.PT_FILTEROP_EQ, GetObjectID());
      }
      query.SetMaxRows(10000);
      query.Query(fields, -1, null, filter);
      int n = query.GetCount();
      // if(n==10000) - filtering will be imperfect
      Object[][] result = null;
      if (n > 0)
      {
        result = new Object[4][];
        for (int j2c_index = 0;j2c_index < 4;j2c_index++)
        {
          result[j2c_index] = new Object[n];
        }
        for (int i = 0;i < n;i++)
        {
          int id = XPConvert.ToInteger(query.GetItem(i, PT_PROPIDS.PT_PROPID_OBJECTID));
          String name = (String) query.GetItem(i, PT_PROPIDS.PT_PROPID_NAME);
          result[0][i] = id;
          result[1][i] = name;
          result[2][i] = null;
          result[3][i] = null;
        }
      }
      return result;
    }
    
    /// <returns></returns>
    public virtual AActivitySpace asOwner()
    {
      return m_asOwner;
    }
    
    /// <returns></returns>
    public virtual Object[][] authPartners()
    {
      PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetAuthSources());
      int fields = PT_PROPIDS.PT_PROPID_OBJECTID | 
      //|PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
      PT_PROPIDS.PT_PROPID_NAME;
      Object[][] filter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        filter[j2c_index] = new Object[3];
      }
      // filter SYNCONLY authsources out, cannot use these as partners
      filter[0][0] = PT_PROPIDS.PT_PROPID_AUTHSOURCE_SUPPORTSSYNC;
      filter[1][0] = PT_FILTEROPS.PT_FILTEROP_NE;
      filter[2][0] = PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_SYNCONLY;
      // don't want the default Plumtree User Database to appear as AuthPartner
      filter[0][1] = PT_PROPIDS.PT_PROPID_AUTHSOURCE_AUTHTYPE;
      filter[1][1] = PT_FILTEROPS.PT_FILTEROP_NE;
      filter[2][1] = PT_AUTHTYPES.PT_AUTHTYPE_PLUMTREE;
      // don't want current object; for creation means id!=0 and is Ok
      filter[0][2] = PT_PROPIDS.PT_PROPID_OBJECTID;
      filter[1][2] = PT_FILTEROPS.PT_FILTEROP_NE;
      filter[2][2] = GetObjectID();
      query.Query(fields, -1, null, filter);
      int n = query.GetCount();
      Object[][] result = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        result[j2c_index] = new Object[n + 1];
      }
      int indPartner;
      for (indPartner = 0;indPartner < n;indPartner++)
      {
        int id = XPConvert.ToInteger(query.GetItem(indPartner, PT_PROPIDS.PT_PROPID_OBJECTID));
        String name = (String) query.GetItem(indPartner, PT_PROPIDS.PT_PROPID_NAME);
        result[0][indPartner] = id;
        result[1][indPartner] = name;
      }
      // Add SSO Auth Partner
      result[0][indPartner] = PT_INTRINSICS.PT_AUTHSOURCE_SSO;
      result[1][indPartner] = m_asOwner.GetString(3064, "ptmsgs_portaladminmsgs");
      return result;
    }
    
    /// <returns></returns>
    public virtual int bulkCopyNum()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetBulkCopyNum();
    }
    
    /// <param name="m_props"></param>
    /// <param name="ptAS"></param>
    /// <param name="idx_start"></param>
    public virtual void copyDataFromAuthSourceToPropValues(XPArrayList m_props,
     IPTAuthSource ptAS, int idx_start)
    {
    }
    //		for (IXPEnumerator i = m_props.GetEnumerator(); i.MoveNext();)
    //		{
    //			PropertyValue pv = (PropertyValue) i.GetCurrent();
    //			String name		 = (String) pv.idServer();
    //			
    //		}
    //		IXPPropertyBag ptBag = ptAS.GetProviderInfo();
    //		String sCategory = ptBag.ReadAsString("RAP_AUTH_CATEGORY");
    //		if(sCategory == null)
    //		{
    //			m_authenticationSourceCategory = "";
    //		} else {
    //			m_authenticationSourceCategory = sCategory;
    //		}
    protected virtual void SetInvalid(String s)
    {
      // remove unneccesary details
      if (XPStringUtility.StartsWith(s, "Native exception:"))
      {
        int b = XPStringUtility.IndexOf(s, '[');
        if (b >= 0)
        {
          int e = XPStringUtility.IndexOf(s, ']', b);
          if (e > b + 10)
          {
            s = XPStringUtility.Substring(s, b + 1, e);
          }
        }
      }
      // except duplicates
      if (XPStringUtility.IndexOf(m_errors.ToString(), s) < 0)
      {
        if (m_errors.GetLength() > 0)
        {
          m_errors.Append("; ");
        }
        m_errors.Append(s);
      }
    }
    
    /// <param name="m_props"></param>
    /// <param name="ptAS"></param>
    /// <param name="idx_start"></param>
    public virtual void copyDataFromPropValuesToAuthSource(XPArrayList m_props,
     IPTAuthSource ptAS, int idx_start)
    {
      IXPPropertyBag ptBag = ptAS.GetProviderInfo();
      try
      {
        ptAS.SetProviderInfo(ptBag);
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
    }
    
    /// <summary>
    /// Returns the Auth Source's category
    /// </summary>
    /// <returns></returns>
    public virtual String GetAuthSourceCategory()
    {
      return m_sCategory;
    }
    
    /// <returns></returns>
    public virtual Object[][] defaultProfiles()
    {
      PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetUsers());
      int fields = PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME;
      query.Query(fields, PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES, null,
       null);
      int n = query.GetCount();
      Object[][] result = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        result[j2c_index] = new Object[n + 1];
      }
      for (int i = 0;i < n;i++)
      {
        int id = XPConvert.ToInteger(query.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
        String name = (String) query.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
        result[0][i] = id;
        result[1][i] = name;
      }
      result[0][n] = null;
      return result;
    }
    
    /// <returns></returns>
    public virtual int deferredGroupFolderID()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetDeletedGroupFolderID();
    }
    
    /// <returns></returns>
    public virtual int deletedUserFolderID()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetDeletedUserFolderID();
    }
    
    /// <returns></returns>
    public virtual Object[][] fullySyncedGroups()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      Object[] groupIds = (Object[]) ptAS.GetFullSyncGroups();
      int n = (groupIds == null) ? 0 : groupIds.Length;
      Object[][] result = new Object[4][];
      for (int j2c_index = 0;j2c_index < 4;j2c_index++)
      {
        result[j2c_index] = new Object[n];
      }
      for (int i = 0;i < n;i++)
      {
        result[0][i] = groupIds[i];
        result[1][i] = userGroupName(XPConvert.ToInteger(groupIds[i]));
        // unused
        result[2][i] = null;
        // unused
        result[3][i] = null;
      }
      return result;
    }
    
    /// <param name="j"></param>
    /// <returns></returns>
    public virtual int groupsOrder(int j)
    {
      return XPConvert.ToInteger(m_groupsOrder.GetElement(j));
    }
    
    /// <returns></returns>
    public virtual String lastTreeSpaceId_ADMINFOLDERTREESPACE()
    {
      return m_lastTreeSpaceId_ADMINFOLDERTREESPACE;
    }
    
    /// <returns></returns>
    public virtual String lastTreeSpaceId_USERGROUPTREESPACE()
    {
      return m_lastTreeSpaceId_USERGROUPTREESPACE;
    }
    
    /// <summary>
    /// Helper function
    /// </summary>
    /// <returns></returns>
    public virtual String listOfMappedGroups()
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      Object[][] groups = mappedGroups(0);
      if (groups != null)
      {
        String clsid = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
        char sep = (char) 0;
        for (int i = 0;i < groups[0].Length;i++)
        {
          int id = XPConvert.ToInteger(groups[0][i]);
          if (id != 0)
          {
            if (sep == 0)
            {
              sep = ',';
            } else
            {
              sb.Append(sep);
            }
            sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
          }
        }
      }
      return (sb.GetLength() == 0) ? null : sb.ToString();
    }
    
    /// <summary>
    /// Helper function
    /// </summary>
    /// <returns></returns>
    public virtual String listOfSyncGroups()
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      Object[] ids = (Object[]) ptAS.GetFullSyncGroups();
      if ((ids != null) && (ids.Length != 0))
      {
        String clsid = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
        char sep = (char) 0;
        for (int i = 0;i < ids.Length;i++)
        {
          int id = XPConvert.ToInteger(ids[i]);
          if (id != 0)
          {
            if (sep == 0)
            {
              sep = ',';
            } else
            {
              sb.Append(sep);
            }
            sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
          }
        }
      }
      return (sb.GetLength() == 0) ? null : sb.ToString();
    }
    
    /// <summary>
    /// Helper function
    /// </summary>
    /// <returns></returns>
    public virtual String listOfUnmappedGroups()
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      int nmappedgroups = 0;
      if (true)
      {
        // just to see if there are any
        Object[][] mappedgroups = mappedGroups(0);
        nmappedgroups = (mappedgroups == null || mappedgroups[0] == null) ? 0 : mappedgroups[0].Length;
        }
      if (nmappedgroups > 0)
      {
        Object[][] unmappedgroups = unmappedGroups();
        int nunmappedgroups = (unmappedgroups == null || unmappedgroups[0] == null) ? 0 : unmappedgroups[0].Length;
        String clsid = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
        char sep = (char) 0;
        for (int i = 0;i < nunmappedgroups;i++)
        {
          int id = XPConvert.ToInteger(unmappedgroups[0][i]);
          if (id != 0)
          {
            if (sep == 0)
            {
              sep = ',';
            } else
            {
              sb.Append(sep);
            }
            sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
          }
        }
      }
      return (sb.GetLength() == 0) ? null : sb.ToString();
    }
    
    /// <summary>
    /// Helper function
    /// </summary>
    /// <returns></returns>
    public virtual String listOfAlienGroups()
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      Object[][] allgroups = allGroups(false);
      int nallgroups = (allgroups == null || allgroups[0] == null) ? 0 : allgroups[0].Length;
      if (nallgroups > 0)
      {
        Object[][] ourgroups = allGroups(true);
        int nourgroups = (ourgroups == null || ourgroups[0] == null) ? 0 : ourgroups[0].Length;
        if (nourgroups > 0)
        {
          XPHashtable our = new XPHashtable(nourgroups);
          for (int i = 0;i < nourgroups;i++)
          {
            our.PutElement(ourgroups[0][i], "");
          }
          ourgroups = null;
          for (int i = 0;i < nallgroups;i++)
          {
            if (our.GetElement(allgroups[0][i]) != null)
            {
              allgroups[0][i] = null;
            }
          }
        }
        String clsid = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
        char sep = (char) 0;
        for (int i = 0;i < nallgroups;i++)
        {
          Object oid = allgroups[0][i];
          if (oid == null)
          {
            continue;
          }
          int id = XPConvert.ToInteger(oid);
          if (id != 0)
          {
            if (sep == 0)
            {
              sep = ',';
            } else
            {
              sb.Append(sep);
            }
            sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
          }
        }
      }
      return (sb.GetLength() == 0) ? null : sb.ToString();
    }
    
    /// <summary>
    /// Helper function
    /// </summary>
    /// <returns></returns>
    public virtual String listOfNewGroupsFolder()
    {
      XPStringBuilder sb = new XPStringBuilder(10);
      int id = newGroupFolderId();
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      try
      {
        ptSession.GetAdminCatalog().OpenAdminFolder(id, false);
      }
      catch (Exception e)
      {
        return null;
      }
      String clsid = XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
      sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
      return (sb.GetLength() == 0) ? null : sb.ToString();
    }
    public virtual String joinLists(String lst1, String lst2)
    {
      String result = null;
      if (lst1 == null)
      {
        result = lst2;
      } else
      {
        if (lst2 == null)
        {
          result = lst1;
        } else
        {
          result = lst1 + ',' + lst2;
        }
      }
      return result;
    }
    
    /// <param name="reserveTopRows"></param>
    /// <returns></returns>
    public virtual Object[][] mappedGroups(int reserveTopRows)
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      Object[] groupIds = (Object[]) ptAS.GetDefaultProfilesMap_GroupIDs();
      Object[] userIds = (Object[]) ptAS.GetDefaultProfilesMap_UserIDs();
      Object[] folderIds = (Object[]) ptAS.GetDefaultProfilesMap_FolderIDs();
      bool modified = false;
      int n = (groupIds == null) ? 0 : groupIds.Length;
      n+=reserveTopRows;
      Object[][] result = new Object[4][];
      for (int j2c_index = 0;j2c_index < 4;j2c_index++)
      {
        result[j2c_index] = new Object[n + 1];
      }
      for (int i = 0;i < reserveTopRows;i++)
      {
        result[0][i] = null;
        result[1][i] = null;
        result[2][i] = null;
        result[3][i] = null;
      }
      for (int i = reserveTopRows;i < n;i++)
      {
        int j = i - reserveTopRows;
        result[0][i] = groupIds[j];
        result[1][i] = userGroupName(XPConvert.ToInteger(groupIds[j]));
        result[2][i] = userIds[j];
        if ((folderIds[j] == null) || (XPConvert.ToInteger(folderIds[j]) == 0))
        {
          folderIds[j] = GetDefaultFolderId();
          modified = true;
        }
        result[3][i] = folderIds[j];
      }
      int iddefUser = GetDefaultProfileId();
      int iddefFolder = ptAS.GetNewUserFolderID();
      if (iddefFolder == 0)
      {
        iddefFolder = GetDefaultFolderId();
        modified = true;
      }
      // fake zero id for the last one
      result[0][n] = 0;
      result[1][n] = m_asOwner.GetString(2047, ResourceConstants.PORTALADMINMSGS);
      result[2][n] = iddefUser;
      result[3][n] = iddefFolder;
      if (modified)
      {
        saveGroups(result);
      }
      return result;
    }
    
    /// <param name="_fixDeletedfolder">
    /// - if the folderid no longer exists,
    /// replace the id with a default folder
    /// </param>
    /// <returns></returns>
    public virtual int newGroupFolderId()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      int folderid = ptAS.GetNewGroupFolderID();
      if (folderid == 0)
      {
        folderid = GetDefaultFolderId();
        try
        {
          ptAS.SetNewGroupFolderID(folderid);
        }
        catch (Exception e)
        {
          SetInvalid(e.Message);
        }
      }
      return folderid;
    }
    
    /// <returns></returns>
    public virtual int numTemplates()
    {
      return GetPTSession().GetNumberOfSerializedPropertyBags(templatesPatttern);
      }
    
    /// <returns></returns>
    public virtual int selectedPartnerId()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetAuthPartnerID();
    }
    
    /// <returns></returns>
    public virtual int selectedTemplate()
    {
      return m_templateSelected;
    }
    
    /// <returns></returns>
    public virtual int supportSyncMode()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetSupportsSync();
    }
    
    /// <returns></returns>
    public virtual int syncType()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetSyncType();
    }
    
    /// <param name="index"></param>
    /// <returns></returns>
    public virtual IXPPropertyBag templateContents(int index)
    {
      return GetPTSession().GetSerializedPropertyBag(templatesPatttern, index);
      }
    
    /// <param name="index"></param>
    /// <returns></returns>
    public virtual String templateName(int index)
    {
      return GetPTSession().GetSerializedPropertyBagName(templatesPatttern,
       index);
    }
    
    /// <returns></returns>
    public virtual Object[][] unmappedGroups()
    {
      Object[][] mappedgroups = mappedGroups(0);
      // can be null
      Object[][] allgroups = allGroups(true);
      int nmappedgroups = (mappedgroups == null || mappedgroups[0] == null) ? 0 : mappedgroups[0].Length;
      int nallgroups = (allgroups == null || allgroups[0] == null) ? 0 : allgroups[0].Length;
      if (nmappedgroups == 0)
      {
        return allgroups;
      }
      // +1 for special "0" in mapped groups, which is never matched
      int nunmappedgroups = nallgroups - nmappedgroups + 1;
      Object[][] unmappedgroups = null;
      if (nunmappedgroups > 0)
      {
        unmappedgroups = new Object[4][];
        for (int j2c_index = 0;j2c_index < 4;j2c_index++)
        {
          unmappedgroups[j2c_index] = new Object[nunmappedgroups];
        }
        int j = 0;
        for (int i = 0;i < nallgroups;i++)
        {
          int ida = XPConvert.ToInteger(allgroups[0][i]);
          bool skip = false;
          for (int k = 0;!skip && (k < nmappedgroups);k++)
          {
            int idm = XPConvert.ToInteger(mappedgroups[0][k]);
            skip = (idm == ida);
          }
          if (!skip)
          {
            for (int n = 0;n < 4;n++)
            {
              unmappedgroups[n][j] = allgroups[n][i];
            }
            j++;
          }
        }
      }
      return unmappedgroups;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveMainPage(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      int nActionWithoutID = removeIdFromAction(GetAction());
      if ((AuthSourceRepostControl.ACTION_ADD_GROUP == nActionWithoutID) || (AuthSourceRepostControl.ACTION_ADD_SYNC_GROUP == nActionWithoutID))
      {
        m_lastTreeSpaceId_USERGROUPTREESPACE = ExtractOneElement(_htFormData.GetElement(AuthSourceMainView.HTMLHIDDEN_SPACEID_USERGROUPTREESPACE));
        } else
      if ((AuthSourceRepostControl.ACTION_CHANGE_TARGET_FOLDER == nActionWithoutID) || (AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP == nActionWithoutID))
      {
        m_lastTreeSpaceId_ADMINFOLDERTREESPACE = ExtractOneElement(_htFormData.GetElement(AuthSourceMainView.HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE));
        } else
      if (AuthSourceRepostControl.ACTION_DEL_GROUP == nActionWithoutID)
      {
        ExtractCheckboxes((String[]) _htFormData.GetElement(AuthSourceMainView.HTMLCHECKBOX_GROUP));
        }
      // any action
      // aj: load the category from the form data.  if it's null, then we're probably
      //     in edit mode and it doesn't exist in the form.  otherwise we are in 
      //     create mode and we should persist it to the model and ptobject
      String sCategory = ExtractOneElement(_htFormData.GetElement(AuthSourceMainView.HTMLINPUT_AuthenticationSourceCategory));
      if (sCategory != null)
      {
        m_sCategory = sCategory;
        IPTAuthSource ptAS = (IPTAuthSource) GetObject();
        IXPPropertyBag ptBag = ptAS.GetProviderInfo();
        ptBag.Write("RAP_AUTH_CATEGORY", (m_sCategory != null) ? (m_sCategory) : (""));
        ptAS.SetProviderInfo(ptBag);
      }
      // save groups, which may have modified default profiles
      ExtractAndSaveDefaultProfiles(_htFormData);
      return nPageStatus;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SavePage2(XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SavePage3(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      // fortunately radio button values are the same as in Plumtree.idl
      String s = ExtractOneElement(_htFormData.GetElement(AuthSource3View.HTMLINPUT_AuthenticationAndSynchronizationChoice));
      int oldmode = supportSyncMode();
      int newmode = (s == null) ? 1 : XPConvert.ToInteger(s);
      try
      {
        ptAS.SetSupportsSync(newmode);
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
      s = ExtractOneElement(_htFormData.GetElement(AuthSource3View.HTMLINPUT_SynchronizationType));
      try
      {
        if (null != s)
        {
          ptAS.SetSyncType(XPConvert.ToInteger(s));
        }
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
      s = ExtractOneElement(_htFormData.GetElement(AuthSource3View.HTMLINPUT_BatchSize));
      try
      {
        if (null != s)
        {
          int nImport = XPConvert.ToInteger(s);
          if (nImport < 10 || nImport > 1000)
          {
            String msg = m_asOwner.GetString(2700, ResourceConstants.PORTALADMINMSGS);
            SetInvalid(msg);
          } else
          {
            ptAS.SetBulkCopyNum(XPConvert.ToInteger(s));
          }
        }
      }
      catch (Exception e)
      {
        String msg = m_asOwner.GetString(2700, ResourceConstants.PORTALADMINMSGS);
        SetInvalid(msg);
      }
      if (newmode == PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_SYNCONLY)
      {
        s = ExtractOneElement(_htFormData.GetElement(AuthSource3View.HTMLINPUT_PARTNERS));
        } else
      {
        s = null;
      }
      if (s != null)
      {
        try
        {
          ptAS.SetAuthPartnerID(XPConvert.ToInteger(s));
        }
        catch (Exception e)
        {
          String msg = m_asOwner.GetString(2060, ResourceConstants.PORTALADMINMSGS);
          SetInvalid(msg);
        }
      } else
      {
        try
        {
          ptAS.SetAuthPartnerID(0);
        }
        catch (Exception e)
        {
          SetInvalid(e.Message);
        }
      }
      onPossibleChangeOfSyncMode(oldmode);
      // aj: finally save the cross AS import mode
      s = ExtractOneElement(_htFormData.GetElement(AuthSource3View.HTMLINPUT_CrossAsMemberships));
      if (s != null && s.Equals(CommonHTMLStrings.ONE))
      {
        m_bImportCrossASMemberships = true;
      } else
      {
        m_bImportCrossASMemberships = false;
      }
      return nPageStatus;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SavePage4(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      int nActionWithoutID = removeIdFromAction(GetAction());
      if (AuthSourceRepostControl.ACTION_DEL_SYNC_GROUP == nActionWithoutID)
      {
        ExtractSyncCheckboxes((String[]) _htFormData.GetElement(AuthSource4View.HTMLCHECKBOX_GROUP));
        } else
      if (AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP == nActionWithoutID)
      {
        ExtractDisabledCheckboxes((String[]) _htFormData.GetElement(AuthSource4View.HTMLCHECKBOX_DISABLED));
        }
      return nPageStatus;
    }
    
    /// <returns></returns>
    protected virtual int GetAction()
    {
      return m_nAction;
    }
    
    /// <param name="id"></param>
    protected virtual void SetDefaultFolderId(int id)
    {
      m_iddefFolder = id;
    }
    
    /// <returns></returns>
    protected virtual int GetDefaultFolderId()
    {
      if (m_iddefFolder == 0)
      {
        IPTAuthSource ptAS = (IPTAuthSource) GetObject();
        m_iddefFolder = ptAS.GetNewGroupFolderID();
        if (m_iddefFolder == 0)
        {
          m_iddefFolder = ptAS.GetNewUserFolderID();
        }
        if (m_iddefFolder == 0)
        {
          m_iddefFolder = ptAS.GetAdminFolderID();
        }
      }
      return m_iddefFolder;
    }
    protected virtual int GetDefaultProfileId()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetDefaultProfileForNewUsers();
    }
    protected virtual void ClearActionData()
    {
      if (m_ActionData == null)
      {
        m_ActionData = new XPArrayList();
      } else
      {
        m_ActionData.Clear();
      }
    }
    
    /// <param name="ids"></param>
    protected virtual void ExtractCheckboxes(String[] ids)
    {
      ClearActionData();
      for (int i = 0;(ids != null) && (i < ids.Length);i++)
      {
        // 0 not removable
        int id = 0;
        try
        {
          id = XPConvert.ToInteger(ids[i]);
        }
        catch (Exception e)
        {
        }
        if (id != 0)
        {
          m_ActionData.Add(id);
        }
      }
    }
    
    /// <param name="ids"></param>
    protected virtual void ExtractDisabledCheckboxes(String[] ids)
    {
      ClearActionData();
      for (int i = 0;(ids != null) && (i < ids.Length);i++)
      {
        // expected values are 1 or 2
        int id = 0;
        try
        {
          id = XPConvert.ToInteger(ids[i]);
        }
        catch (Exception e)
        {
        }
        if (id != 0)
        {
          m_ActionData.Add(id);
        }
      }
    }
    
    /// <param name="o"></param>
    /// <returns></returns>
    protected virtual bool ExtractOneBoolElement(Object o)
    {
      String s = ExtractOneElement(o);
      return ((s == null) || (s.Length < 1) || (XPStringUtility.CharAt(s,
       0) != '1')) ? false : true;
    }
    public virtual void onAddAllSyncGroups()
    {
      Object[][] allgroups = allGroups(true);
      int nallgroups = (allgroups == null || allgroups[0] == null) ? 0 : allgroups[0].Length;
      Object[] newsyncgroups = new Object[nallgroups];
      for (int i = 0;i < nallgroups;i++)
      {
        newsyncgroups[i] = allgroups[0][i];
      }
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      try
      {
        ptAS.SetFullSyncGroups(newsyncgroups);
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
    }
    /* this old version actually adds all MAPPED groups
     IPTAuthSource ptAS = (IPTAuthSource) GetObject();
     Object[] syncgroups  = (Object[]) ptAS.GetFullSyncGroups();
     int nsync	= (syncgroups == null) ? 0 : syncgroups.length;
     Object[][] mappedgroups = mappedGroups(0);
     int nmap = (mappedgroups == null) ? 0 : mappedgroups[0].length;
     int ntmp = nsync + nmap;
     Object[] tmp = new Object[ntmp];
     int k = 0;
     
     for (; k < nmap; k++)
     tmp[k] = mappedgroups[0][k];
     
     for (int i = 0; i < nsync; i++)
     {
     Object id    = syncgroups[i];
     boolean skip = false;
     
     for (int j = 0; !skip && (j < k); j++)
     skip = (id.equals(tmp[j]));
     
     if (!skip)
     tmp[k++] = id;
     }
     
     Object[] newsyncgroups = new Object[k];
     
     for (int i = 0; i < k; i++)
     newsyncgroups[i] = tmp[i];
     
     ptAS.SetFullSyncGroups(newsyncgroups);
     */
     
    
    /// <param name="id"></param>
    public virtual void onAddSyncGroup(int id)
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      Object[] oldids = (Object[]) ptAS.GetFullSyncGroups();
      int oldlen = (oldids == null) ? 0 : oldids.Length;
      Object[] newids = new Object[oldlen + 1];
      int i = 0;
      bool dup = false;
      for (;(i < oldlen) && !dup;i++)
      {
        newids[i] = oldids[i];
        for (int j = 0;(j < oldlen) && !dup;j++)
        {
          dup|=(id == XPConvert.ToInteger(oldids[j]));
        }
      }
      if (!dup)
      {
        newids[i] = id;
        try
        {
          ptAS.SetFullSyncGroups(newids);
        }
        catch (Exception e)
        {
          SetInvalid(e.Message);
        }
      }
    }
    public virtual void onRemoveSyncGroup()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      Object[] oldids = (Object[]) ptAS.GetFullSyncGroups();
      if ((oldids == null) || (oldids.Length < 1))
      {
        return;
      }
      Object[] newids = new Object[oldids.Length];
      for (int i = 0;i < oldids.Length;i++)
      {
        newids[i] = oldids[i];
      }
      for (IXPEnumerator j = m_ActionData.GetEnumerator();j.MoveNext();)
      {
        int id = XPConvert.ToInteger(j.GetCurrent());
        if (id == -1)
        {
          newids = null;
          break;
        }
        for (int i = 0;i < oldids.Length;i++)
        {
          if (XPConvert.ToInteger(oldids[i]) == id)
          {
            newids[i] = null;
            break;
          }
        }
      }
      Object[] newids2 = null;
      if (newids != null)
      {
        int n = 0;
        for (int i = 0;i < newids.Length;i++)
        {
          if (newids[i] != null)
          {
            n++;
          }
        }
        if (n == 0)
        {
          newids = null;
        } else
        {
          newids2 = new Object[n];
          int k = 0;
          for (int i = 0;i < newids.Length;i++)
          {
            if (newids[i] != null)
            {
              newids2[k++] = newids[i];
            }
          }
        }
      }
      try
      {
        ptAS.SetFullSyncGroups(newids2);
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
    }
    protected static int removeIdFromAction(int action)
    {
      return AuthSourceRepostControl.removeIdFromAction(action);
    }
    
    /// <param name="ids"></param>
    protected virtual void ExtractSyncCheckboxes(String[] ids)
    {
      ClearActionData();
      for (int i = 0;(ids != null) && (i < ids.Length);i++)
      {
        int id = -2;
        try
        {
          id = XPConvert.ToInteger(ids[i]);
        }
        catch (Exception e)
        {
        }
        if (id != -2)
        {
          m_ActionData.Add(id);
        }
      }
    }
    
    /// <summary>
    /// Action to be taken when a group is added to the list
    /// </summary>
    /// <param name="id"></param>
    public virtual void onAddGroup(int id)
    {
      // reserve one row at the top
      Object[][] groups = mappedGroups(1);
      groups[0][0] = id;
      groups[1][0] = userGroupName(id);
      groups[2][0] = GetDefaultProfileId();
      groups[3][0] = GetDefaultFolderId();
      // inserting new mapped group at 0th row index
      m_groupsOrder.Insert(0, 0);
      // bump all the rest down one row
      // adjust order
      for (int i = groups[0].Length - 1;i > 0;i--)
      {
        m_groupsOrder.SetElement(i, XPConvert.ToInteger(m_groupsOrder.GetElement(i)) + 1);
        }
      saveGroups(groups);
    }
    
    /// <param name="k"></param>
    public virtual void onChangeCheckboxForSyncGroup(int k)
    {
      bool bChecked = false;
      if (!m_ActionData.IsEmpty())
      {
        for (IXPEnumerator i = m_ActionData.GetEnumerator();i.MoveNext();
        )
        {
          if (XPConvert.ToInteger(i.GetCurrent()) == k)
          {
            bChecked = true;
          }
        }
      }
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      try
      {
        if (!bChecked)
        {
          switch (k){
          case 1:
          ptAS.SetDeletedUserFolderID(0);
          break;
          case 2:
          ptAS.SetDeletedGroupFolderID(0);
          break;
          }
        } else
        {
          switch (k){
          case 1:
          ptAS.SetDeletedUserFolderID(-1);
          break;
          case 2:
          ptAS.SetDeletedGroupFolderID(-1);
          break;
          }
        }
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
    }
    
    /// <summary>
    /// Action take when the selected folder is changed
    /// </summary>
    /// <param name="id"></param>
    /// <param name="folderid"></param>
    public virtual void onChangeFolder(int id, int folderid)
    {
      Object[][] groups = mappedGroups(0);
      for (int j = 0;j < groups[0].Length;j++)
      {
        int i = XPConvert.ToInteger(m_groupsOrder.GetElement(j));
        int idi = XPConvert.ToInteger(groups[0][i]);
        if (idi == id)
        {
          groups[3][i] = folderid;
          if (id == 0)
          // the "All Users" folder serves as default if the default is not set
          {
            if (m_iddefFolder == 0)
            {
              SetDefaultFolderId(folderid);
            }
          }
          break;
        }
      }
      saveGroups(groups);
    }
    
    /// <param name="folderid"></param>
    public virtual void onChangeFolderForNewGroups(int folderid)
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      try
      {
        ptAS.SetNewGroupFolderID(folderid);
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
    }
    
    /// <summary>
    /// Event handler for when the folder is changed for a sync group
    /// </summary>
    /// <param name="id"></param>
    /// <param name="folderid"></param>
    public virtual void onChangeFolderForSyncGroup(int id, int folderid)
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      try
      {
        switch (id){
        case 1:
        ptAS.SetDeletedUserFolderID(folderid);
        break;
        case 2:
        ptAS.SetDeletedGroupFolderID(folderid);
        break;
        }
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
    }
    
    /// <summary>
    /// Action to be taken when a group is moved in the list
    /// </summary>
    /// <param name="id"></param>
    /// <param name="dir"></param>
    public virtual void onMoveGroup(int id, int dir)
    {
      Object[][] groups = mappedGroups(0);
      for (int j = 0;j < groups[0].Length;j++)
      {
        int i = XPConvert.ToInteger(m_groupsOrder.GetElement(j));
        int idi = XPConvert.ToInteger(groups[0][i]);
        if (idi == id)
        {
          int k = -1;
          switch (dir){
          case -2:
          k = 0;
          break;
          case -1:
          k = j - 1;
          break;
          case +1:
          k = j + 1;
          break;
          case +2:
          k = groups[0].Length - 1 - 1;
          // -1 for last one that is unmoveable
          break;
          }
          if ((k >= 0) && (k <= (groups[0].Length - 1 - 1)))
          {
            if (dir > 0)
            {
              for (int n = j;n < k;n++)
              {
                Object tmp = m_groupsOrder.GetElement(n);
                m_groupsOrder.SetElement(n, m_groupsOrder.GetElement(n + 1));
                m_groupsOrder.SetElement(n + 1, tmp);
              }
            } else
            {
              for (int n = k;n < j;n++)
              {
                Object tmp = m_groupsOrder.GetElement(n);
                m_groupsOrder.SetElement(n, m_groupsOrder.GetElement(n + 1));
                m_groupsOrder.SetElement(n + 1, tmp);
              }
            }
          }
          break;
        }
      }
      saveGroups(groups);
    }
    
    /// <param name="oldmode"></param>
    public virtual void onPossibleChangeOfSyncMode(int oldmode)
    {
      int mode = supportSyncMode();
      if (mode != oldmode)
      {
        bool authonly = (mode == PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_AUTHONLY);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(authonly, SetJobDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(authonly, ((AuthSourceEditorAS) m_asOwner).GetPageName4());
        }
    }
    
    /// <summary>
    /// Action to be taken when a group is removed from the list
    /// </summary>
    public virtual void onRemoveGroup()
    {
      Object[][] groups = mappedGroups(0);
      if (groups == null)
      {
        return;
      }
      for (IXPEnumerator j = m_ActionData.GetEnumerator();j.MoveNext();)
      {
        int id = XPConvert.ToInteger(j.GetCurrent());
        for (int i = 0;i < groups[0].Length;i++)
        {
          if (groups[0][i] != null)
          {
            int idi = XPConvert.ToInteger(groups[0][i]);
            if (idi != 0)
            // 0 non removable
            {
              // -1 - remove all
              if ((idi == id) || (id == -1))
              {
                groups[0][i] = null;
              }
            }
          }
        }
      }
      saveGroups(groups);
    }
    
    /// <summary>
    /// Action to be taken when a group is removed from the list
    /// </summary>
    public virtual void onReenableUsers()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      m_nReenabled = ptAS.EnableAgentDisabledUsers();
    }
    public virtual int GetNumDisabledUsers()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      int nDisabled = ptAS.GetAgentDisabledUsersCount();
      return nDisabled;
    }
    public virtual int GetNumReenabledUsers()
    {
      return m_nReenabled;
    }
    
    /// <summary>
    /// Save the information about he selected groups to the model class
    /// </summary>
    /// <param name="groups"></param>
    protected virtual void saveGroups(Object[][] groups)
    {
      // -1 - don't alloc for the last one
      int n = groups[0].Length - 1;
      Object[] vsaUserGroupIDs = new Object[n];
      Object[] vsaUserIDs = new Object[n];
      Object[] vsaFolderIDs = new Object[n];
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      int nAddedGroups = 0;
      for (int j = 0;j < groups[0].Length;j++)
      {
        int i = XPConvert.ToInteger(m_groupsOrder.GetElement(j));
        if (groups[0][i] == null)
        {
          // group removed
          continue;
        }
        int groupid = XPConvert.ToInteger(groups[0][i]);
        if (groupid == 0)
        {
          try
          {
            ptAS.SetDefaultProfileForNewUsers(XPConvert.ToInteger(groups[2][i]));
            ptAS.SetNewUserFolderID(XPConvert.ToInteger(groups[3][i]));
          }
          catch (Exception e)
          {
            SetInvalid(e.Message);
          }
        } else
        {
          vsaUserGroupIDs[nAddedGroups] = groups[0][i];
          vsaUserIDs[nAddedGroups] = groups[2][i];
          vsaFolderIDs[nAddedGroups] = groups[3][i];
          nAddedGroups++;
        }
      }
      Object[] vsaUserGroupIDs2 = null;
      Object[] vsaUserIDs2 = null;
      Object[] vsaFolderIDs2 = null;
      if (nAddedGroups > 0)
      {
        vsaUserGroupIDs2 = new Object[nAddedGroups];
        vsaUserIDs2 = new Object[nAddedGroups];
        vsaFolderIDs2 = new Object[nAddedGroups];
        for (int i = 0;i < nAddedGroups;i++)
        {
          vsaUserGroupIDs2[i] = vsaUserGroupIDs[i];
          vsaUserIDs2[i] = vsaUserIDs[i];
          vsaFolderIDs2[i] = vsaFolderIDs[i];
        }
      }
      try
      {
        ptAS.SetDefaultProfilesMap(vsaUserGroupIDs2, vsaUserIDs2, vsaFolderIDs2);
        ptAS.SetUseDefaultProfilesMap(nAddedGroups > 0);
      }
      catch (Exception e)
      {
        SetInvalid(e.Message);
      }
      // erase order (which went to DB)
      for (int i = 0;i < m_groupsOrder.GetSize();i++)
      {
        m_groupsOrder.SetElement(i, i);
      }
    }
    protected virtual void ExtractAndSaveDefaultProfiles(XPHashtable _htFormData)
    {
      Object[][] groups = mappedGroups(0);
      if (groups == null)
      {
        return;
      }
      bool modified = false;
      for (int i = 0;i < groups[0].Length;i++)
      {
        if (groups[0][i] == null)
        {
          continue;
        }
        int id = XPConvert.ToInteger(groups[0][i]);
        String value = ExtractOneElement(_htFormData.GetElement(AuthSourceMainView.HTMLINPUT_PROFILES_ + id));
        if (value == null)
        {
          continue;
        }
        int dpid = -1;
        try
        {
          dpid = XPConvert.ToInteger(value);
        }
        catch (Exception e)
        {
          log.Error(e, "AuthSourceModel::ExtractDefaultProfiles Unexpected non-numeric value " + value);
          }
        if (dpid < 0)
        {
          log.Error("AuthSourceModel::ExtractDefaultProfiles Unexpected non-numeric value " + value);
          continue;
        }
        int newdpid = dpid;
        modified|=(newdpid != XPConvert.ToInteger(groups[2][i]));
        groups[2][i] = newdpid;
      }
      if (modified)
      {
        saveGroups(groups);
      }
    }
    
    /// <returns></returns>
    public virtual String userFolderPathIfSingle()
    // null if not single
    {
      String result = null;
      int folderid = 0;
      Object[][] groups = mappedGroups(0);
      for (int i = 0;i < groups[0].Length;i++)
      {
        Object tmp = groups[3][i];
        if (tmp == null)
        {
          continue;
        }
        int folderidi = XPConvert.ToInteger(tmp);
        if (folderidi != folderid)
        {
          if (folderid == 0)
          {
            folderid = folderidi;
          } else
          // multiple folders
          {
            folderid = 0;
            break;
          }
        }
      }
      if (folderid != 0)
      {
        IPTAdminFolder ptFolder = m_Session.GetAdminCatalog().OpenAdminFolder(folderid,
         false);
        if (ptFolder != null)
        {
          result = ptFolder.GetPath();
        }
      }
      return result;
    }
    
    /// <param name="id"></param>
    /// <returns></returns>
    protected virtual String userGroupName(int id)
    {
      String result = m_asOwner.GetString(2047, ResourceConstants.PORTALADMINMSGS);
      if (id != 0)
      {
        try
        {
          IPTUserGroup ptGroup = (IPTUserGroup) m_Session.GetUserGroups().Open(id,
           false);
          result = ptGroup.GetLocalizedName();
        }
        catch (Exception e)
        {
          result = m_asOwner.GetString(2052, ResourceConstants.PORTALADMINMSGS) + ": " + XPConvert.ToString(id);
          }
      }
      return result;
    }
    public virtual bool sameTimeCreatedAndModified()
    {
      return m_sameTimeCreatedAndModified;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.authsource.IAuthSourceModelRO#ImportCrossASMemberships()
     */
     
    public virtual bool ImportCrossASMemberships()
    {
      return m_bImportCrossASMemberships;
    }
  }
}