using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.common.setjob;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.editors.authsource
{
  /// <author>OlegS</author>
  public abstract class AuthSourceRepostControl : ObjEditorRepostControl
  {
    
    /// <summary>
    /// Bulk Re-Enable Users 
    /// </summary>
    public const int ACTION_REENABLE_USERS = 84;
    
    /// <summary>
    /// Delete group 
    /// </summary>
    public const int ACTION_DEL_GROUP = 99;
    
    /// <summary>
    /// Add group 
    /// </summary>
    public const int ACTION_ADD_GROUP = 98;
    
    /// <summary>
    /// Create default profile 
    /// </summary>
    public const int ACTION_CREATE_DEFAULT_PROFILE = 97;
    // + group id * 100
    
    /// <summary>
    /// Move group to the top of the list 
    /// </summary>
    public const int ACTION_MOVE_GROUP_TOP = 96;
    // + group id * 100
    
    /// <summary>
    /// Move group up one 
    /// </summary>
    public const int ACTION_MOVE_GROUP_UP = 95;
    // + group id * 100
    
    /// <summary>
    /// Move group down one 
    /// </summary>
    public const int ACTION_MOVE_GROUP_DOWN = 94;
    // + group id * 100
    
    /// <summary>
    /// Move group to the bottom of the list 
    /// </summary>
    public const int ACTION_MOVE_GROUP_BOTTOM = 93;
    // + group id * 100
    
    /// <summary>
    /// Change the target folder for the group 
    /// </summary>
    public const int ACTION_CHANGE_TARGET_FOLDER = 92;
    // + group id * 100
    
    /// <summary>
    /// Add a sync group 
    /// </summary>
    public const int ACTION_ADD_SYNC_GROUP = 91;
    
    /// <summary>
    /// Add all sync groups 
    /// </summary>
    public const int ACTION_ADD_ALL_SYNC_GROUPS = 90;
    // + group id * 100
    
    /// <summary>
    /// Delete a sync group 
    /// </summary>
    public const int ACTION_DEL_SYNC_GROUP = 89;
    // + 1 or 2 * 100 // TODO: make this 100
    
    /// <summary>
    /// Change the folder for the sync group 
    /// </summary>
    public const int ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP = 88;
    
    /// <summary>
    /// Change the folder where the created groups go 
    /// </summary>
    public const int ACTION_CHANGE_NEW_GROUP_FOLDER = 87;
    
    /// <summary>
    /// Synchronization radio button selection changed  
    /// </summary>
    public const int ACTION_SYNC_CHOICE_CHANGED = 86;
    // LDAP only but defined here
    
    /// <summary>
    /// Validate button pressed  
    /// </summary>
    public const int ACTION_VALIDATE = 85;
    public static int makeAction(int action, int groupid)
    {
      return groupid * 100 + action;
    }
    
    /// <summary>
    /// Remove the ID from the action
    /// </summary>
    /// <param name="action">The action being taken</param>
    /// <returns>the integer with the ID removed</returns>
    public static int removeIdFromAction(int action)
    {
      int groupid = action / 100;
      return action - groupid * 100;
    }
    protected static int getIdFromAction(int action)
    {
      return action / 100;
    }
    
    /// <summary>
    /// Returns the model class
    /// </summary>
    /// <returns></returns>
    protected virtual AuthSourceModel GetModel()
    {
      return (AuthSourceModel) m_model;
    }
    
    /// <summary>
    /// Function called on repost
    /// </summary>
    /// <param name="_nAction">The action to take</param>
    protected override void PerformAction(int _nAction)
    {
      TraceHelper.Trace("PerformAction " + _nAction);
      base.PerformAction(_nAction);
      ((SetJobRepostControl) m_asOwner.GetControl(SetJobRepostControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
       m_htFormData);
      int nActionWithoutID = removeIdFromAction(_nAction);
      if (ACTION_ADD_GROUP == nActionWithoutID)
      {
        XPArrayList lst = TreeHelper.GetSelection(m_asOwner, AuthSourceMainView.USERGROUPTREESPACE);
        for (IXPEnumerator i = lst.GetEnumerator();i.MoveNext();)
        {
          int id = XPConvert.ToInteger(i.GetCurrent());
          GetModel().onAddGroup(id);
        }
      } else
      if (ACTION_MOVE_GROUP_TOP == nActionWithoutID)
      {
        GetModel().onMoveGroup(getIdFromAction(_nAction), -2);
      } else
      if (ACTION_MOVE_GROUP_UP == nActionWithoutID)
      {
        GetModel().onMoveGroup(getIdFromAction(_nAction), -1);
      } else
      if (ACTION_MOVE_GROUP_DOWN == nActionWithoutID)
      {
        GetModel().onMoveGroup(getIdFromAction(_nAction), +1);
      } else
      if (ACTION_MOVE_GROUP_BOTTOM == nActionWithoutID)
      {
        GetModel().onMoveGroup(getIdFromAction(_nAction), +2);
      } else
      if (ACTION_CHANGE_TARGET_FOLDER == nActionWithoutID)
      {
        XPArrayList lst = TreeHelper.GetSelection(m_asOwner, AuthSourceMainView.ADMINFOLDERTREESPACE);
        if (!lst.IsEmpty())
        {
          int id = XPConvert.ToInteger(lst.GetElement(0));
          GetModel().onChangeFolder(getIdFromAction(_nAction), id);
        }
      } else
      if (ACTION_DEL_GROUP == nActionWithoutID)
      {
        GetModel().onRemoveGroup();
      } else
      if (ACTION_CHANGE_NEW_GROUP_FOLDER == nActionWithoutID)
      {
        XPArrayList lst = TreeHelper.GetSelection(m_asOwner, AuthSourceMainView.ADMINFOLDERTREESPACE_NEWGROUP);
        if (!lst.IsEmpty())
        {
          int id = XPConvert.ToInteger(lst.GetElement(0));
          GetModel().onChangeFolderForNewGroups(id);
        }
      } else
      if (ACTION_ADD_SYNC_GROUP == nActionWithoutID)
      {
        XPArrayList lst = TreeHelper.GetSelection(m_asOwner, AuthSource4View.USERGROUPTREESPACE);
        for (IXPEnumerator i = lst.GetEnumerator();i.MoveNext();)
        {
          int id = XPConvert.ToInteger(i.GetCurrent());
          GetModel().onAddSyncGroup(id);
        }
      } else
      if (ACTION_DEL_SYNC_GROUP == nActionWithoutID)
      {
        GetModel().onRemoveSyncGroup();
      } else
      if (ACTION_ADD_ALL_SYNC_GROUPS == nActionWithoutID)
      {
        GetModel().onAddAllSyncGroups();
      } else
      if (ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP == nActionWithoutID)
      {
        XPArrayList lst = TreeHelper.GetSelection(m_asOwner, AuthSource4View.ADMINFOLDERTREESPACE);
        if (!lst.IsEmpty())
        {
          int id = XPConvert.ToInteger(lst.GetElement(0));
          GetModel().onChangeFolderForSyncGroup(getIdFromAction(_nAction),
           id);
        } else
        // from checkbox
        {
          GetModel().onChangeCheckboxForSyncGroup(getIdFromAction(_nAction));
          }
      } else
      if (ACTION_REENABLE_USERS == nActionWithoutID)
      {
        GetModel().onReenableUsers();
        Redirect doneRedirect = new Redirect();
        doneRedirect.SetLinkGetCachedSpace(m_asOwner);
        doneRedirect.SetControl(STR_MVC_CLASS_NAME);
        doneRedirect.SetSubSpaceKey("ReenableUsersPopup");
        doneRedirect.SetDisplayPage(AuthSourceReenableUsersConfirmPopupDP.STR_MVC_CLASS_NAME);
        SetRedirect(doneRedirect);
      } else
      if (ACTION_SYNC_CHOICE_CHANGED == nActionWithoutID)
      {
      }
    }
    // do nothing
    
    /// <summary>
    /// Set the action to be taken on repost
    /// </summary>
    protected override void SetRepostAction()
    {
      base.SetRepostAction();
      GetModel().m_nAction = m_nAction;
    }
  }
}