using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.authsource;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.authsource.plumtree
{
  /// <summary>
  /// This is a simple editor for the Plumtree auth source. Eventually it would be valuable to be able 
  /// to select an authentication partner, to allow intrinsic Plumtree users to log in via SSO. This
  /// would require changes to InternalSession.Connect, and would be most valuable in conjunction with
  /// the secondary auth partner feature.
  /// </summary>
  /// <author>mikej</author>
  public class PlumtreeAuthSourceEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.authsource.plumtree.PlumtreeAuthSourceEditorAS");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PlumtreeAuthSourceEditor";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.authsource.plumtree.PlumtreeAuthSourceEditorAS";
    
    /// <summary>
    /// Gets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      return GetString(1704, ResourceConstants.PORTALADMINMSGS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PlumtreeAuthSourceEditorAS();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (ObjEditorRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PlumtreeAuthSourceEditorModel.STR_MVC_CLASS_NAME;
      base.Init();
      RegisterView(AuthSourceSelectAuthPartnerView.STR_MVC_CLASS_NAME, GetModel(m_strModelName));
      // mj: register dps
      RegisterPage(new MainDP());
      // mj: set default page
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      // mj: set left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(625, ResourceConstants.PORTALADMINMSGS));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1703, ResourceConstants.PORTALADMINMSGS));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      //m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          //	Tip Title
          tm.SetTipTitle(GetString(626, ResourceConstants.PORTALADMINMSGS));
          HTMLElementCollection collection = new HTMLElementCollection();
          collection.SetPreComment("TIPWRITER: This tip is configured in the " + sClassName + " file.");
          //	Tip Text
          HTMLElement eTip = new HTMLGenericElement(GetString(627, ResourceConstants.PORTALADMINMSGS));
          HTMLList l = new HTMLList(HTMLListTypes.UNORDERED_LIST);
          HTMLListItem it = null;
          collection.AddInnerHTMLElement(eTip);
          collection.AddInnerHTMLElement(l);
          //	Primary Tip
          tm.SetTip(collection);
          //	Secondary Tip
          tm.SetSecondarTip(null);
          //	Item 1
          it = new HTMLListItem();
          l.AddInnerHTMLElement(it);
          it.AddInnerHTMLString(GetString(628, ResourceConstants.PORTALADMINMSGS));
          //	Item 2
          it = new HTMLListItem();
          l.AddInnerHTMLElement(it);
          it.AddInnerHTMLString(GetString(629, ResourceConstants.PORTALADMINMSGS));
          //	Item 3
          it = new HTMLListItem();
          l.AddInnerHTMLElement(it);
          it.AddInnerHTMLString(GetString(630, ResourceConstants.PORTALADMINMSGS));
          }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
  }
}
//	Got the tips model
