using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.authsource;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.authsource.plumtree
{
  /// <summary>
  /// Model for the Plumtree auth source editor. Currently does nothing.
  /// </summary>
  /// <author>mikej</author>
  public class PlumtreeAuthSourceEditorModel : ObjEditorModel
  {
    public const String STR_MVC_CLASS_NAME = "PlumtreeAuthSourceModel";
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PlumtreeAuthSourceEditorModel();
    }
    
    /// <returns></returns>
    public virtual Object[][] authPartners()
    {
      PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetAuthSources());
      int fields = PT_PROPIDS.PT_PROPID_OBJECTID | 
      //|PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
      PT_PROPIDS.PT_PROPID_NAME;
      Object[][] filter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        filter[j2c_index] = new Object[3];
      }
      // filter SYNCONLY authsources out, cannot use these as partners
      filter[0][0] = PT_PROPIDS.PT_PROPID_AUTHSOURCE_SUPPORTSSYNC;
      filter[1][0] = PT_FILTEROPS.PT_FILTEROP_NE;
      filter[2][0] = PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_SYNCONLY;
      // don't want the default Plumtree User Database to appear as AuthPartner
      filter[0][1] = PT_PROPIDS.PT_PROPID_AUTHSOURCE_AUTHTYPE;
      filter[1][1] = PT_FILTEROPS.PT_FILTEROP_NE;
      filter[2][1] = PT_AUTHTYPES.PT_AUTHTYPE_PLUMTREE;
      // don't want current object; for creation means id!=0 and is Ok
      filter[0][2] = PT_PROPIDS.PT_PROPID_OBJECTID;
      filter[1][2] = PT_FILTEROPS.PT_FILTEROP_NE;
      filter[2][2] = GetObjectID();
      query.Query(fields, -1, null, filter);
      int n = query.GetCount();
      Object[][] result = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        result[j2c_index] = new Object[n + 1];
      }
      int indPartner;
      for (indPartner = 0;indPartner < n;indPartner++)
      {
        int id = XPConvert.ToInteger(query.GetItem(indPartner, PT_PROPIDS.PT_PROPID_OBJECTID));
        String name = (String) query.GetItem(indPartner, PT_PROPIDS.PT_PROPID_NAME);
        result[0][indPartner] = id;
        result[1][indPartner] = name;
      }
      // Add SSO Auth Partner
      result[0][indPartner] = PT_INTRINSICS.PT_AUTHSOURCE_SSO;
      result[1][indPartner] = m_asOwner.GetString(3064, "ptmsgs_portaladminmsgs");
      return result;
    }
    
    /// <returns></returns>
    public virtual int selectedPartnerId()
    {
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      return ptAS.GetAuthPartnerID();
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SaveMainPage(_htFormData);
      }
      return nPageStatus;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveMainPage(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      String strPartner = ModelHelper.GetFormElementString(_htFormData, AuthSourceSelectAuthPartnerView.HTMLINPUT_PARTNERS,
       "");
      IPTAuthSource ptAS = (IPTAuthSource) GetObject();
      if (strPartner != null)
      {
        ptAS.SetAuthPartnerID(XPConvert.ToInteger(strPartner));
      } else
      {
        ptAS.SetAuthPartnerID(0);
      }
      return nPageStatus;
    }
  }
}