using System;
// Framework Imports
using XPLocale=com.plumtree.openfoundation.internationalization.XPLocale;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.serversettings.search;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.search.admin;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.bestbets
{
  /// <author>CraigS, based on JulieF template</author>
  public class BestBetModel : EditorModel,IBestBetModelRO,IBestBetModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.bestbets.BestBetModel");
    public const String STR_MVC_CLASS_NAME = "BestBet";
    public const int MAX_TARGETS = 20;
    protected String m_originalSearchString = null;
    protected String m_searchString = null;
    protected String m_setupSearchString = null;
    protected XPArrayList m_arrListTargets = new XPArrayList();
    protected bool m_bIsBestBetInDB = false;
    public virtual void ActionOnRepost()
    {
    }
    // Anything needed here?
    //
    // IBestBetModel implementation
    //
    public virtual void AddTarget(String newTargId, String newTargApp, String newTargName)
    {
      if (m_arrListTargets.GetSize() >= MAX_TARGETS)
      {
        log.Error("already have " + m_arrListTargets.GetSize() + " targets");
        return;
      }
      const int MAX_NAME_LENGTH = 250;
      if (newTargName.Length > MAX_NAME_LENGTH)
      {
        newTargName = XPStringUtility.Substring(newTargName, 0, MAX_NAME_LENGTH);
        }
      IPTBestBetTarget bbTarget = PortalObjectsFactory.CreateBestBetTarget();
      bbTarget.setId(newTargId);
      bbTarget.setType(newTargApp);
      bbTarget.setName(newTargName);
      m_arrListTargets.Add(bbTarget);
    }
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="formData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable formData)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      bool isAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession);
      bool hasRight = ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SEARCH_SERVER_TUNING);
      if (!(isAdmin || hasRight))
      {
        return false;
      }
      m_originalSearchString = null;
      m_bIsBestBetInDB = false;
      m_searchString = "";
      m_setupSearchString = "";
      m_arrListTargets = new XPArrayList();
      String[] item = (String[]) formData.GetElement(BestBetRepostControl.HTMLINPUT_ITEM_TO_EDIT_ON_START);
      if (null != item)
      {
        // zero-based index into displayed Best Bet list thats maintained by parent model.
        int indexIntoParentModel = -1;
        try
        {
          indexIntoParentModel = XPConvert.ToInteger(item[0]);
        }
        catch (Exception e)
        {
          throw XPException.GetInstance(e);
        }
        if (indexIntoParentModel >= 0)
        {
          // Ask our parent space for its cached info on this item
          AActivitySpace parentSpace = m_asOwner.GetParentSpace();
          if (null != parentSpace)
          {
            ISearchServerTuningEditorModelRO parentModel = (ISearchServerTuningEditorModelRO) (parentSpace.GetModel(SearchServerTuningEditorModel.STR_MVC_CLASS_NAME));
            if (null != parentModel && indexIntoParentModel < parentModel.GetNumBestBetsOnPage())
            {
              // initialize it
              m_searchString = parentModel.GetBestBetTrigger(indexIntoParentModel);
              m_setupSearchString = parentModel.GetBestBetSetupString(indexIntoParentModel);
              m_originalSearchString = m_searchString;
              m_bIsBestBetInDB = (parentModel.HasBestBetBeenNewlyAdded(indexIntoParentModel) == false);
              m_arrListTargets = new XPArrayList();
              IXPList listOriginal = parentModel.GetBestBetTargets(indexIntoParentModel);
              for (int i = 0;i < listOriginal.GetSize();i++)
              {
                IPTBestBetTarget origTarget = (IPTBestBetTarget) listOriginal.GetElement(i);
                IPTBestBetTarget bbTarget = PortalObjectsFactory.CreateBestBetTarget();
                bbTarget.setId(origTarget.getId());
                bbTarget.setType(origTarget.getType());
                bbTarget.setName(origTarget.getName());
                m_arrListTargets.Add(bbTarget);
              }
            }
          }
        }
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new BestBetModel();
    }
    
    /// <param name="id"></param>
    public virtual void DeleteTarget(int id)
    {
      if ((id <= 0) || (id > _numTargets()))
      {
        log.Error("id out of range: id=" + id + " numTargets=" + _numTargets());
        return;
      }
      m_arrListTargets.RemoveAt(id - 1);
    }
    public virtual void MoveTargetUp(int id)
    {
      if (id > 1 && id <= MAX_TARGETS)
      {
        SwapTarget(id, id - 1);
      }
    }
    public virtual void MoveTargetDown(int id)
    {
      if (id > 0 && id < _numTargets())
      {
        SwapTarget(id, id + 1);
      }
    }
    public virtual void MoveToTop(int id)
    {
      if (id > 1 && id <= MAX_TARGETS)
      {
        SwapTarget(1, id);
      }
    }
    public virtual void MoveToBottom(int id)
    {
      if (_numTargets() == id)
      {
        return;
      } else
      {
        SwapTarget(_numTargets(), id);
      }
    }
    protected virtual void SwapTarget(int id1, int id2)
    {
      String tempId = GetTargetId(id1);
      String tempApp = GetTargetApp(id1);
      String tempName = GetTargetName(id1);
      SetTargetApp(id1, GetTargetApp(id2));
      SetTargetName(id1, GetTargetName(id2));
      SetTargetId(id1, GetTargetId(id2));
      SetTargetApp(id2, tempApp);
      SetTargetName(id2, tempName);
      SetTargetId(id2, tempId);
    }
    
    /// <summary>
    /// Implements actions when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      // This editor is always run as a subeditor of the
      // Search Server Settings editor, which handles saving any changes
      // made here.  Just notify it that we may have changed.
      updateParentSpaceOnSubEditorClose();
    }
    
    /// <returns></returns>
    public virtual int GetMaxTargets()
    {
      return MAX_TARGETS;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetNumTargets()
    {
      return _numTargets();
    }
    //
    // IBestBetModelRO implementation
    //
    public virtual String GetSearchString()
    {
      return m_searchString;
    }
    //
    // IBestBetModelRO implementation
    //
    public virtual String GetSetupSearchString()
    {
      return m_setupSearchString;
    }
    
    /// <param name="id"></param>
    /// <returns></returns>
    public virtual String GetTargetApp(int id)
    {
      IPTBestBetTarget bbTarget = (IPTBestBetTarget) m_arrListTargets.GetElement(id - 1);
      if (bbTarget == null)
      {
        return null;
      }
      return bbTarget.getType();
    }
    
    /// <param name="id"></param>
    /// <returns></returns>
    public virtual String GetTargetId(int id)
    {
      IPTBestBetTarget bbTarget = (IPTBestBetTarget) m_arrListTargets.GetElement(id - 1);
      if (bbTarget == null)
      {
        return null;
      }
      return bbTarget.getId();
    }
    
    /// <param name="id"></param>
    /// <returns></returns>
    public virtual String GetTargetName(int id)
    {
      IPTBestBetTarget bbTarget = (IPTBestBetTarget) m_arrListTargets.GetElement(id - 1);
      if (bbTarget == null)
      {
        return null;
      }
      return bbTarget.getName();
    }
    public virtual void SetTargetApp(int id, String newApp)
    {
      IPTBestBetTarget bbTarget = (IPTBestBetTarget) m_arrListTargets.GetElement(id - 1);
      if (bbTarget != null)
      {
        bbTarget.setType(newApp);
      }
    }
    public virtual void SetTargetName(int id, String newName)
    {
      IPTBestBetTarget bbTarget = (IPTBestBetTarget) m_arrListTargets.GetElement(id - 1);
      if (bbTarget != null)
      {
        bbTarget.setName(newName);
      }
    }
    public virtual void SetTargetId(int id, String newID)
    {
      IPTBestBetTarget bbTarget = (IPTBestBetTarget) m_arrListTargets.GetElement(id - 1);
      if (bbTarget != null)
      {
        bbTarget.setId(newID);
      }
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="pageName"></param>
    /// <param name="formData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String pageName, XPHashtable formData)
    {
      if (pageName.Equals(BestBetEditorDP.STR_MVC_CLASS_NAME))
      {
        return SaveMainPage(formData);
      }
      return RepostControl.PAGE_STATUS_INVALID;
    }
    
    /// <summary>
    /// Called (via Finish()) when the
    /// Done button is pressed, when this editor is running as a subeditor of the
    /// SearchServerSettings editor.  Informs the parent editor of the changes that
    /// have been made.
    /// </summary>
    public virtual void updateParentSpaceOnSubEditorClose()
    {
      ISearchServerTuningEditorModelRO parentModel = GetParentModel();
      if (null != parentModel)
      {
        parentModel.UpdateBestBetFromSubEditor(m_originalSearchString, m_bIsBestBetInDB,
         m_searchString, m_setupSearchString, m_arrListTargets);
      }
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_formData"></param>
    protected virtual int SaveMainPage(XPHashtable formData)
    {
      String[] data;
      bool clickedFinish = false;
      // Some errors should only be raised if the user is clicking "Finish".
      data = (String[]) formData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
      if (data[0].Equals(XPConvert.ToString(RepostControl.POSTTOSELF_ACTION_FINISH)))
      {
        clickedFinish = true;
      }
      data = (String[]) formData.GetElement(BestBetEditorView.SEARCH_STRING_SETTING);
      if ((null != data) && !(0 == data.Length))
      {
        // Trim whitespace from the query string
        m_searchString = XPStringUtility.Trim(data[0]);
        // Make the query string lower case.
        XPLocale locale = new XPLocale(m_asOwner.GetLocale());
        m_searchString = XPStringUtility.ToLowerCase(m_searchString, locale);
        // Get the string used to find Best Bet targets
        String[] setupSearchData = (String[]) formData.GetElement(StartSearchControl.USER_QUERY);
        if (setupSearchData != null && setupSearchData.Length > 0)
        {
          m_setupSearchString = setupSearchData[0];
        }
        if (clickedFinish)
        {
          if (0 == m_searchString.Length)
          {
            // Raise an error
            UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(171, ResourceConstants.PORTALADMINMSGS),
             m_asOwner.GetString(171, ResourceConstants.PORTALADMINMSGS));
            UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
            return RepostControl.PAGE_STATUS_INVALID;
          }
        }
        // Check whether the user has entered a search string that duplicates another BB
        ISearchServerTuningEditorModelRO parentModel = GetParentModel();
        if (null != parentModel && clickedFinish)
        {
          bool isNotDup = parentModel.CheckDuplicateBestBetQuery(m_originalSearchString,
           m_searchString, !m_bIsBestBetInDB);
          if (!isNotDup)
          {
            // Raise an error
            UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(173, ResourceConstants.PORTALADMINMSGS),
             m_asOwner.GetString(173, ResourceConstants.PORTALADMINMSGS));
            UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
            return RepostControl.PAGE_STATUS_INVALID;
          }
        }
      } else
      // end parentModel != null
      // data == null || data.length == 0
      {
        log.Warn("BestBetModel::SaveMainPage Search string parameter was not in query string.");
        return RepostControl.PAGE_STATUS_INVALID;
      }
      // We don't want to allow saving the page if no targets have been defined.
      if (clickedFinish && (0 == _numTargets()))
      {
        UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(172, ResourceConstants.PORTALADMINMSGS),
         m_asOwner.GetString(172, ResourceConstants.PORTALADMINMSGS));
        UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Helper method to get the parent space's model interface, if any.
    /// </summary>
    private ISearchServerTuningEditorModelRO GetParentModel()
    {
      AActivitySpace parentSpace = m_asOwner.GetParentSpace();
      if (null != parentSpace)
      {
        return (ISearchServerTuningEditorModelRO) (parentSpace.GetModel(SearchServerTuningEditorModel.STR_MVC_CLASS_NAME));
        }
      return null;
    }
    private int _numTargets()
    {
      if (m_arrListTargets == null)
      {
        return 0;
      }
      return m_arrListTargets.GetSize();
    }
  }
}