using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.editors.bestbets
{
  /// <author>CraigS, based on JulieF template</author>
  public class BestBetRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.bestbets.BestBetRepostControl");
    public const String STR_MVC_CLASS_NAME = "BestBetRepost";
    public const int POSTTOSELF_NOOP = 10;
    public const int POSTTOSELF_ACTION_DELTARGS = 11;
    public const int POSTTOSELF_ACTION_ADDTARG = 12;
    public const int POSTTOSELF_ACTION_DELTARG_START = 13;
    public const int POSTTOSELF_ACTION_DELTARG_END = 33;
    public const int POSTTOSELF_ACTION_MOVETARGUP_START = 34;
    public const int POSTTOSELF_ACTION_MOVETARGUP_END = 54;
    public const int POSTTOSELF_ACTION_MOVETARGDOWN_START = 55;
    public const int POSTTOSELF_ACTION_MOVETARGDOWN_END = 75;
    public const int POSTTOSELF_ACTION_MOVETOBOTTOM_START = 76;
    public const int POSTTOSELF_ACTION_MOVETOBOTTOM_END = 96;
    public const int POSTTOSELF_ACTION_MOVETOTOP_START = 97;
    public const int POSTTOSELF_ACTION_MOVETOTOP_END = 117;
    public const String HTMLINPUT_SELECTED_ITEM = "in_cb_selectedItem";
    public const String HTMLINPUT_ITEM_TO_EDIT_ON_START = "inititem";
    public const String HIDDEN_ADD_DELETE = "in_hi_add_delete";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new BestBetRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int action)
    {
      base.PerformAction(action);
      BestBetModel bbModel = (BestBetModel) m_model;
      if (action == POSTTOSELF_NOOP)
      {
      } else
      // PTDEbug something here
      if (action >= POSTTOSELF_ACTION_MOVETOBOTTOM_START && action <= POSTTOSELF_ACTION_MOVETOBOTTOM_END)
      {
        int nTargetNum = action - POSTTOSELF_ACTION_MOVETOBOTTOM_START;
        bbModel.MoveToBottom(nTargetNum);
      } else
      if (action >= POSTTOSELF_ACTION_MOVETOTOP_START && action <= POSTTOSELF_ACTION_MOVETOTOP_END)
      {
        int nTargetNum = action - POSTTOSELF_ACTION_MOVETOTOP_START;
        bbModel.MoveToTop(nTargetNum);
      } else
      if (action >= POSTTOSELF_ACTION_MOVETARGUP_START && action <= POSTTOSELF_ACTION_MOVETARGUP_END)
      {
        int nTargetNum = action - POSTTOSELF_ACTION_MOVETARGUP_START;
        bbModel.MoveTargetUp(nTargetNum);
      } else
      if (action >= POSTTOSELF_ACTION_MOVETARGDOWN_START && action <= POSTTOSELF_ACTION_MOVETARGDOWN_END)
      {
        int nTargetNum = action - POSTTOSELF_ACTION_MOVETARGDOWN_START;
        bbModel.MoveTargetDown(nTargetNum);
      } else
      if (action >= POSTTOSELF_ACTION_DELTARG_START && action <= POSTTOSELF_ACTION_DELTARG_END)
      {
        int nTargetNum = action - POSTTOSELF_ACTION_DELTARG_START;
        bbModel.DeleteTarget(nTargetNum);
      } else
      if (action == POSTTOSELF_ACTION_DELTARGS)
      {
        bool done = false;
        // Deletion order matters here--must go back to front.
        for (int j = bbModel.GetNumTargets();j >= 1;j--)
        {
          if (m_htFormData.ContainsKey(BestBetEditorView.DEL_TARGET_CB + XPConvert.ToString(j)))
          {
            done = true;
            bbModel.DeleteTarget(j);
          }
        }
        if (!done && m_htFormData.ContainsKey(HIDDEN_ADD_DELETE))
        {
          String[] item = (String[]) m_htFormData.GetElement(HIDDEN_ADD_DELETE);
          if (item[0] != null && !item[0].Equals(""))
          {
            int nTargDel = 0;
            try
            {
              nTargDel = XPConvert.ToInteger(item[0]);
            }
            catch (Exception e)
            {
              nTargDel = -1;
            }
            if (nTargDel > 0)
            {
              bbModel.DeleteTarget(nTargDel);
            }
          }
        }
      } else
      if (action == POSTTOSELF_ACTION_ADDTARG)
      {
        String key = null;
        if (m_htFormData.ContainsKey(HIDDEN_ADD_DELETE))
        {
          key = HIDDEN_ADD_DELETE;
        } else
        if (m_htFormData.ContainsKey(HTMLINPUT_SELECTED_ITEM))
        {
          key = HTMLINPUT_SELECTED_ITEM;
        }
        if (key != null)
        {
          String[] item = (String[]) m_htFormData.GetElement(key);
          try
          {
            int resultNum = XPConvert.ToInteger(item[0]);
            ISearchResultModelRO _searchModel = (ISearchResultModelRO) (m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME));
            String strNewTargetId = XPConvert.ToString(_searchModel.GetResultBestBetKey(resultNum));
            String strNewTargetApp = XPConvert.ToString(_searchModel.GetResultApp(resultNum));
            bool bTargetIsNew = true;
            for (int i = 1;bTargetIsNew && i <= bbModel.GetNumTargets();i++)
            {
              String strTargetId = bbModel.GetTargetId(i);
              String strTargetApp = bbModel.GetTargetApp(i);
              if (strTargetId.Equals(strNewTargetId) && strTargetApp.Equals(strNewTargetApp))
              {
                bTargetIsNew = false;
              }
            }
            if (bTargetIsNew)
            {
              bbModel.AddTarget(strNewTargetId, strNewTargetApp, _searchModel.GetResultName(resultNum));
              }
          }
          catch (Exception e)
          {
            log.Error(e, e.Message);
          }
        }
      }
    }
    public static int GetMoveUpCode(int id)
    {
      // Can't move up past #1 spot.
      if (id <= 1 || id > 20)
      {
        return POSTTOSELF_NOOP;
      } else
      {
        return POSTTOSELF_ACTION_MOVETARGUP_START + id;
      }
    }
    public static int GetMoveDownCode(int id)
    {
      if (id < 1 || id > 20)
      {
        return POSTTOSELF_NOOP;
      } else
      {
        return POSTTOSELF_ACTION_MOVETARGDOWN_START + id;
      }
    }
    public static int GetMoveTopCode(int id)
    {
      // Can't move up past #1 spot.
      if (id <= 1 || id > 20)
      {
        return POSTTOSELF_NOOP;
      } else
      {
        return POSTTOSELF_ACTION_MOVETOTOP_START + id;
      }
    }
    public static int GetMoveBottomCode(int id)
    {
      if (id < 1 || id > 20)
      {
        return POSTTOSELF_NOOP;
      } else
      {
        return POSTTOSELF_ACTION_MOVETOBOTTOM_START + id;
      }
    }
  }
}