using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.bestbets
{
  /// <author>CraigS</author>
  public class SearchBoxView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.bestbets.SearchBoxView");
    public const String STR_MVC_CLASS_NAME = "SearchBoxView";
    protected AActivitySpace _parent;
    protected IBaseSearchResultModelRO _searchModel;
    protected IBestBetModelRO _bbModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SearchBoxView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable table = new HTMLTable();
      result.AddInnerHTMLElement(table);
      HTMLTableRow row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      try
      {
        // Make a searchform factory with a unique name
        SearchFormFactory factory = new SearchFormFactory(AFormDP.HTMLFORM_NAME,
         AFormDP.HTMLFORM_NAME, _parent, /* completeForm= */
        false);
        // Use ten items per page, since we're in a popup.
        factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS,
         10);
        // Restrict to same types as banner search.
        factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
         StartSearchControl.GetBannerSearchObjectTypes());
        // Suppress header, footer, and canvas portlets
        factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE,
         SearchSettingCollection.GADGET_SEARCH_TYPE_BANNERSEARCH);
        // Hack: Force the form to be submitted if the user hits enter in the
        // search box.  Dangerous, this can cause double submits if not used carefully.
        factory.ForceSubmitOfEnclosingForm();
        // Display the guts of the form
        result.AddInnerHTMLElement(factory.GetResult());
        HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT, factory.GetInputBoxName(),
         "myID");
        input.SetOnKeyDown(factory.GetInputBoxOnKeyDown());
        input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        input.SetSize(30);
        if (_searchModel.IsInitialized())
        {
          input.SetValue(_searchModel.GetSearchString());
        } else
        {
          // for an initial search, get the current query string out of the
          // best-bet model
          input.SetValue(_bbModel.GetSetupSearchString());
        }
        cell.AddInnerHTMLElement(input);
        //result.AddInnerHTMLElement(input);
        // Add space before the search button
        //result.AddInnerHTMLString("&nbsp;&nbsp;");
        //cell.AddInnerHTMLString("&nbsp;&nbsp;");
        // Add submit button
        HTMLAnchor submitLink = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        submitLink.SetOnClick(factory.GetAnchorOnClick());
        submitLink.AddInnerHTMLElement(SearchFormFactory.GetSearchButton(_parent));
        //result.AddInnerHTMLElement(submitLink);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetVAlign("middle");
        cell.AddInnerHTMLElement(submitLink);
      }
      catch (HTMLException e)
      {
        log.Error(e, e.Message);
        throw XPException.GetInstance(e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      // by default, return nothing
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      _searchModel = (IBaseSearchResultModelRO) model;
      _parent = parent;
      // Get the best-bet model as well
      _bbModel = (IBestBetModelRO) _parent.GetModel(BestBetModel.STR_MVC_CLASS_NAME);
      }
  }
}