using System;
using com.plumtree.portalpages.common.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.common.setjob
{
  /// <summary>
  /// This DP displays the Views for the object owner
  /// and the Job selector table.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SetJobDP : EditorDP
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SetJob";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(181, ResourceConstants.PORTALADMINMSGS));
      }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1667, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // JF- Job owner view
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjectOwnerView.STR_MVC_CLASS_NAME)).Display());
      // JF- Spacer table
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // JF- Job selector tab
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(ObjectOwnerView.STR_MVC_CLASS_NAME).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB).DisplayJavascript());
      return myScripts;
    }
  }
}