using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.job;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.common.setjob
{
  /// <summary>
  /// Model class for the set Job page: Job owner and Job selector table.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SetJobModel : EditorHelperModel,ISetJobModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.common.setjob.SetJobModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SetJob";
    
    /// <summary>
    /// Select Jobs storage name
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_SELECT_JOB = "SelectJobObjectEditor";
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_KEY_OWNERTREE = "ObjectOwner";
    
    /// <summary>
    /// Object being created or edited 
    /// </summary>
    private IPTObject m_ptObject;
    
    /// <summary>
    /// Plumtree session 
    /// </summary>
    private IPTSession m_ptSession;
    
    /// <summary>
    /// Member variable to store the current name of the Owner 
    /// </summary>
    private String m_sOwnerName;
    
    /// <summary>
    /// Tree Space ID. The first time the ID is empty and a new AS is opened,
    /// but after that, we save the ID and the same tree AS is reopened each time. 
    /// </summary>
    private String m_sOwnerTreeSpaceID = "";
    
    /// <summary>
    /// Class ID of the object being created or edited 
    /// </summary>
    private int m_nClassID;
    
    /// <summary>
    /// ID of the object being created or edited 
    /// </summary>
    private int m_nObjectID;
    
    /// <summary>
    /// Member variable to store the current ID of the Owner 
    /// </summary>
    private int m_nOwnerID;
    
    /// <summary>
    /// possible value for m_nOwnerID that indicates that the current user does not have access to see the owner 
    /// </summary>
    public const int INVALID_OWNER_ID = -1;
    
    /// <summary>
    /// This method is called on come back from tree to get the new
    /// selected owner from the tree.
    /// </summary>
    public virtual void ChangeOwner()
    {
      // JF- Only sys admins have rights to change the owner.
      if (IsSysAdmin())
      {
        TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(SUBSPACE_KEY_OWNERTREE);
        if (null != asTree)
        {
          ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList mySelected = myTree.GetSelectedItems();
          if (0 != mySelected.GetSize())
          {
            m_nOwnerID = ((TreeLeafNode) mySelected.GetElement(0)).m_nObjectID;
            m_sOwnerName = ((TreeLeafNode) mySelected.GetElement(0)).GetName();
            }
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SetJobModel();
    }
    
    /// <summary>
    /// Removes this Object from the Jobs that have been deleted from the Job Page.
    /// Then is adds the Object to the new selected Jobs.
    /// </summary>
    public virtual void DoTaskAfterStoreSetJob()
    {
      IPTQueryResult ptqrOldSelectedJobs = m_ptSession.GetScheduler().QueryJobsByOperation(m_nClassID,
       m_nObjectID);
      SelectPTObjectModel mySelectJobsModel = (SelectPTObjectModel) m_asOwner.GetModel(STR_MVC_STORAGE_NAME_SELECT_JOB);
      // JF- Array of jobs that were in the old list and that are still in the new list. 
      // We don't need to change those ones
      XPArrayList arrAlreadyAddedJobs = new XPArrayList();
      int nJobID;
      IPTJob ptJob;
      IPTServerContext ptscJob;
      for (int i = 0;i < ptqrOldSelectedJobs.RowCount();i++)
      {
        nJobID = ptqrOldSelectedJobs.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (mySelectJobsModel.ContainsObject(PT_CLASSIDS.PT_JOB_ID, nJobID))
        {
          arrAlreadyAddedJobs.Add(nJobID);
        } else
        {
          RemoveObjectFromJob(nJobID);
        }
      }
      PTGrowableSortedArrayWrapper newJobList = mySelectJobsModel.GetItems();
      Object intJobID;
      for (int i = 0;i < newJobList.GetCount();i++)
      {
        // Get the Job ID.
        intJobID = newJobList.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
        try
        {
          // RWW - Open the job for edit in exclusive mode.  If the job
          // is in process, it will be locked and we will not be able 
          // to edit it.  Our UI error will then be set to inform the 
          // user that some job settings could not be saved.
          ptJob = (IPTJob) m_ptSession.GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).Open(XPConvert.ToInteger(intJobID),
           true);
          ptscJob = (IPTServerContext) ptJob.GetInterfaces("IPTServerContext");
          try
          {
            //JH- set the owner on the job only if user is admin and the ownerID is valid
            if (IsSysAdmin() && INVALID_OWNER_ID != m_nOwnerID)
            {
              ptscJob.SetOwnerID(m_nOwnerID);
            }
            ptscJob.Store();
          }
          catch (Exception e)
          {
            // Error stating that some jobs could not be saved.
            String sMessage = this.m_asOwner.GetString(2672, "ptmsgs_portaladminmsgs");
            GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
             "SetJobModel::DoTaskAfterStoreSetJob", e, false, UIErrorLevel.SERIOUS,
             sMessage);
          }
          finally
          {
            // Always unlock the job when we're done.
            ptscJob.UnlockObject();
          }
        }
        catch (Exception ex)
        {
          // Error stating that some jobs could not be edited.
          String sMessage = this.m_asOwner.GetString(2695, "ptmsgs_portaladminmsgs");
          GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
           "SetJobModel::DoTaskAfterStoreSetJob", ex, false, UIErrorLevel.SERIOUS,
           sMessage);
        }
        if (!arrAlreadyAddedJobs.Contains(intJobID))
        {
          nJobID = XPConvert.ToInteger(intJobID);
          AddObjectToJob(nJobID);
        }
      }
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public virtual void DoTaskBeforeStoreSetJob()
    {
      // JF- Only sys admins have rights to change the owner.
      if (IsSysAdmin())
      {
        IPTServerContext ptServerContext = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
        ptServerContext.SetOwnerID(m_nOwnerID);
      }
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void DoTaskOnStartSetJob(IPTObject _ptObject, IPTSession _ptSession,
     int _nEditorType)
    {
      m_ptObject = _ptObject;
      m_ptSession = _ptSession;
      m_nClassID = m_ptObject.GetClassID();
      IPTServerContext ptServerContext = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
      m_nObjectID = ptServerContext.GetObjectID();
      InitializeOwner();
      InitializeJobSelector(_nEditorType);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the current ID of the owner.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetOwnerID()
    {
      return m_nOwnerID;
    }
    
    /// <summary>
    /// Returns the current name of the owner.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetOwnerName()
    {
      return m_sOwnerName;
    }
    
    /// <summary>
    /// Returns owner tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetOwnerTreeSpaceID()
    {
      return m_sOwnerTreeSpaceID;
    }
    
    /// <summary>
    /// Returns true if the current user has sys admin activity rights.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsSysAdmin()
    {
      return PlumtreeHelpers.CheckCurrentUserIsAdmin(m_ptSession);
    }
    
    /// <summary>
    /// Saves the selected value in the priority drop-down.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // JF- Only sys admins have rights to change the owner.
      if (IsSysAdmin())
      {
        SaveOwnerTreeID(_htFormData);
      }
      ((SelectPTObjectModel) m_asOwner.GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).SaveSection(_htFormData);
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Helper method to add Object to Job
    /// </summary>
    /// <param name="_nJobID"></param>
    private void AddObjectToJob(int _nJobID)
    {
      IPTJob ptJob = (IPTJob) m_ptSession.GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).Open(_nJobID,
       false);
      IPTServerContext ptscJob = (IPTServerContext) ptJob.GetInterfaces("IPTServerContext");
      try
      {
        ptscJob.LockObject();
        ptJob.AddJobListEntry(-1, m_nClassID, m_nObjectID);
        ptscJob.Store();
      }
      catch (Exception e)
      {
        log.Error("The following exception was thrown when trying to add the Job with ID: " + _nJobID + " to this Object: " + e);
        }
      finally
      {
        if (PT_LOCKSTATES.PT_LOCKED == ptscJob.GetLockState())
        {
          ptscJob.UnlockObject();
        }
      }
    }
    
    /// <summary>
    /// Helper method to start the Select Job List.
    /// </summary>
    private void InitializeJobSelector(int _nEditorType)
    {
      SelectPTObjectModel mySelectJobsModel = (SelectPTObjectModel) m_asOwner.GetModel(STR_MVC_STORAGE_NAME_SELECT_JOB);
      mySelectJobsModel.InitializeSelectPTObject(m_asOwner.GetString(182,
       ResourceConstants.PORTALADMINMSGS), m_asOwner.GetString(183, ResourceConstants.PORTALADMINMSGS),
       PTImageType.ICON_JOB, m_asOwner.GetString(184, ResourceConstants.PORTALADMINMSGS),
       new int[]{PT_CLASSIDS.PT_JOB_ID}, 15);
      // JF- Set Strings to display when list is empty
      mySelectJobsModel.SetEmptyListMessages(m_asOwner.GetString(186, ResourceConstants.PORTALADMINMSGS),
       m_asOwner.GetString(187, ResourceConstants.PORTALADMINMSGS));
      mySelectJobsModel.SetDefaultRowIcon(PTImageType.ICON_JOB);
      Object[][] arrCreateNewInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrCreateNewInfo[j2c_index] = new Object[SelectPTObjectModel.CREATE_NEW_COL_MAX];
        }
      arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ASNAME] = JobEditorAS.STR_MVC_CLASS_NAME;
      arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_LABEL] = m_asOwner.GetString(185,
       ResourceConstants.PORTALADMINMSGS);
      arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ICON] = PTImageType.ICON_JOB;
      mySelectJobsModel.SetEnableCreateNew(arrCreateNewInfo);
      // Set title and sub title for the tree
      mySelectJobsModel.SetTreeTitle(m_asOwner.GetString(1783, ResourceConstants.PORTALADMINMSGS));
      mySelectJobsModel.SetTreeSubTitle(m_asOwner.GetString(1782, ResourceConstants.PORTALADMINMSGS));
      // JF- Populate the list in Edit mode 	
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == _nEditorType)
      {
        IPTQueryResult ptqrJobs = m_ptSession.GetScheduler().QueryJobsByOperation(m_nClassID,
         m_nObjectID);
        Object[][] oRows = new Object[ptqrJobs.RowCount()][];
        for (int j2c_index = 0;j2c_index < ptqrJobs.RowCount();j2c_index++)
        {
          oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
          }
        for (int i = 0;i < ptqrJobs.RowCount();i++)
        {
          oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
          oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = ptqrJobs.ItemAsInt(i,
           PT_PROPIDS.PT_PROPID_OBJECTID);
          oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] = ptqrJobs.ItemAsString(i,
           PT_PROPIDS.PT_PROPID_NAME);
        }
        mySelectJobsModel.SetDefaultObjects(oRows);
      }
      // JF- Hide some intrinsic Jobs that cannot be changed.
      int[][] aHiddenJobs = new int[6][];
      for (int j2c_index = 0;j2c_index < 6;j2c_index++)
      {
        aHiddenJobs[j2c_index] = new int[2];
      }
      aHiddenJobs[0][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      aHiddenJobs[0][SelectPTObjectModel.HIDE_COL_OBJECTID] = PT_INTRINSICS.PT_SYSTEMMAINTENANCE_JOBID;
      aHiddenJobs[1][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      aHiddenJobs[1][SelectPTObjectModel.HIDE_COL_OBJECTID] = PT_INTRINSICS.PT_WEEKLYHOUSEKEEPING_JOBID;
      aHiddenJobs[2][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      aHiddenJobs[2][SelectPTObjectModel.HIDE_COL_OBJECTID] = PT_INTRINSICS.PT_AUDITLOGMANAGEMENT_JOBID;
      aHiddenJobs[3][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      // Search update 1
      aHiddenJobs[3][SelectPTObjectModel.HIDE_COL_OBJECTID] = 4;
      aHiddenJobs[4][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      // Search update 2
      aHiddenJobs[4][SelectPTObjectModel.HIDE_COL_OBJECTID] = 5;
      aHiddenJobs[5][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_JOB_ID;
      // Search update 3
      aHiddenJobs[5][SelectPTObjectModel.HIDE_COL_OBJECTID] = 6;
      mySelectJobsModel.SetHiddenObjects(aHiddenJobs);
    }
    
    /// <summary>
    /// Initializes the object owner.
    /// </summary>
    /// <param name="_ptObject"></param>
    private void InitializeOwner()
    {
      IPTServerContext ptServerContext = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
      m_nOwnerID = ptServerContext.GetOwnerID();
      IPTQueryResult qrOwnerName = m_ptSession.GetUsers().QuerySingleObject(m_nOwnerID);
      if (0 == qrOwnerName.RowCount())
      {
        // SCC if the current user is a sysadmin and therefore has access to 
        // see all users, then this means that the user does not exist anymore 
        // and that the owner should be defaulted back to the Administrator
        if (IsSysAdmin())
        {
          log.Info("JobOwnerModel::InitializeJobOwner The user with ID " + m_nOwnerID + " was not found in the DB. We are setting the owner to the Administrator user.");
          m_nOwnerID = PT_INTRINSICS.PT_USER_SYSADMIN;
          qrOwnerName = m_ptSession.GetUsers().QuerySingleObject(m_nOwnerID);
          // just in case...
          if (0 == qrOwnerName.RowCount())
          {
            m_nOwnerID = INVALID_OWNER_ID;
            m_sOwnerName = null;
            return;
          }
        } else
        {
          // current user does not have READ access on the owner.
          m_nOwnerID = INVALID_OWNER_ID;
          m_sOwnerName = null;
          return;
        }
      }
      m_sOwnerName = qrOwnerName.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
      }
    
    /// <summary>
    /// Helper method to remove an Object from a Job.
    /// </summary>
    /// <param name="_nJobID"></param>
    private void RemoveObjectFromJob(int _nJobID)
    {
      int nOperationClassID;
      int nOperationObjectID;
      int nIndex = -1;
      IPTJob ptJob = (IPTJob) m_ptSession.GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).Open(_nJobID,
       false);
      IPTQueryResult ptqrJobList = ptJob.QueryJobList();
      for (int i = 0;i < ptqrJobList.RowCount();i++)
      {
        nOperationClassID = ptqrJobList.ItemAsInt(i, PT_PROPIDS.PT_PROPID_JOB_OPERATIONCLASSID);
        nOperationObjectID = ptqrJobList.ItemAsInt(i, PT_PROPIDS.PT_PROPID_JOB_OPERATIONOBJECTID);
        if ((m_nClassID == nOperationClassID) && (m_nObjectID == nOperationObjectID))
        {
          nIndex = ptqrJobList.ItemAsInt(i, PT_PROPIDS.PT_PROPID_JOB_LISTINDEX);
          break;
        }
      }
      if (nIndex != -1)
      {
        IPTServerContext ptscJob = (IPTServerContext) ptJob.GetInterfaces("IPTServerContext");
        ptscJob.LockObject();
        ptJob.RemoveJobListEntry(nIndex);
        ptscJob.Store();
        ptscJob.UnlockObject();
      }
    }
    
    /// <summary>
    /// Helper method to save the Tree ID on repost.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    private void SaveOwnerTreeID(XPHashtable _htFormData)
    {
      // JF- We save the tree ID only if we don't already have it.
      if (("").Equals(m_sOwnerTreeSpaceID) && _htFormData.ContainsKey(ObjectOwnerView.HTMLINPUT_OWNERTREEASID))
      {
        String[] data = (String[]) _htFormData.GetElement(ObjectOwnerView.HTMLINPUT_OWNERTREEASID);
        if ((null != data) && !(0 == data.Length))
        {
          m_sOwnerTreeSpaceID = data[0];
        }
      }
    }
  }
}