using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.inherit;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.communitytemplate
{
  /// <author>michaeld</author>
  public class CommunityTemplateEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.communitytemplate.CommunityTemplateEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CommTemp";
    
    /// <summary>
    /// SelectPTObject Model for communities that use the template 
    /// </summary>
    public const String PLUGIN_COMMUNITIES = "CommunitiesList";
    
    /// <summary>
    /// SelectPTObject Model for selecting page templates 
    /// </summary>
    public const String PLUGIN_SELECT_PAGE_TEMPLATE = "SelectPageTemplate";
    
    /// <summary>
    /// SelectPTObject Model for selecting a header 
    /// </summary>
    public const String PLUGIN_SELECT_HEADER = "SelectHeader";
    
    /// <summary>
    /// SelectPTObject Model for selecting a footer 
    /// </summary>
    public const String PLUGIN_SELECT_FOOTER = "SelectFooter";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CommunityTemplateEditorAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(189, ResourceConstants.PORTALADMINMSGS);
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2604, ResourceConstants.PORTALADMINMSGS),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (CommunityTemplateDepView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Returns the class name of the Community Template Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (CommunityTemplateRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Community Template Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = CommunityTemplateModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = (EditorModel) GetModel(m_strModelName);
      // Register DisplayPages
      RegisterPage(new CommunityTemplateMainDP());
      RegisterPage(new CommunityTemplateCommunitiesDP());
      RegisterPage(new HeaderAndFooterSelectorDP());
      // Register Views
      RegisterView(HeaderAndFooterSelectorView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(CommunityTemplateDepView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(CommunityTemplateRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(HeaderAndFooterRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register the select PTObject list as a plug-in section
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, PLUGIN_SELECT_PAGE_TEMPLATE);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel mySelectPageTemplateModel = GetModel(PLUGIN_SELECT_PAGE_TEMPLATE);
      RegisterView(SelectPageTemplateView.STR_MVC_CLASS_NAME, PLUGIN_SELECT_PAGE_TEMPLATE,
       mySelectPageTemplateModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, PLUGIN_SELECT_PAGE_TEMPLATE,
       mySelectPageTemplateModel);
      // Register the select PTObject list as a plug-in section
      RegisterModel(InheritListModel.STR_MVC_CLASS_NAME, PLUGIN_COMMUNITIES);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myCommunitiesModel = GetModel(PLUGIN_COMMUNITIES);
      RegisterView(CommunitiesListView.STR_MVC_CLASS_NAME, PLUGIN_COMMUNITIES,
       myCommunitiesModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, PLUGIN_COMMUNITIES,
       myCommunitiesModel);
      // Set default page
      SetCurrentPage(CommunityTemplateMainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(192, ResourceConstants.PORTALADMINMSGS));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CommunityTemplateMainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CommunityTemplateCommunitiesDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1784, ResourceConstants.PORTALADMINMSGS));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          int iTitleId = 15;
          int iTipId = 16;
          int iSecondaryTipId = 17;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
     */
     
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (CommunityTemplateMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_CommunityTemplate_MainSettings");
      } else
      if (HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Community_HeaderandFooter");
      }
    }
  }
}