using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.inherit;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.communitytemplate
{
  /// <author>michaeld</author>
  public class CommunityTemplateModel : ObjEditorModel,IEditorModelRO,IHeaderAndFooterModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.communitytemplate.CommunityTemplateModel");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CommTemp";
    
    /// <summary>
    /// Repost Action: From Tree 
    /// </summary>
    public const int POSTTOSELF_ACTION_RETURN_FROM_TREE = 32;
    
    /// <summary>
    /// List Key: Header 
    /// </summary>
    public const int LIST_KEY_HEADER = 2;
    
    /// <summary>
    /// List Key: Footer 
    /// </summary>
    public const int LIST_KEY_FOOTER = 3;
    public const int HEADERFOOTER_ID_FORCE_SUBPORTAL = -1;
    
    /// <summary>
    /// Name of the Footer *
    /// </summary>
    private String m_strFooterName;
    
    /// <summary>
    /// Name of the Header *
    /// </summary>
    private String m_strHeaderName;
    
    /// <summary>
    /// If true, enables the force subportal header/footer checkbox *
    /// </summary>
    private bool m_bIsTemplateSelector = true;
    
    /// <summary>
    /// Form Data 
    /// </summary>
    private XPHashtable m_htFormData;
    
    /// <summary>
    /// Old Selected Objects 
    /// </summary>
    private XPSortedDictionary m_xpsdOldSelectedObjects;
    private bool m_bFooterHasCommunityPrefs;
    private bool m_bHeaderHasCommunityPrefs;
    
    /// <summary>
    /// Have the page templates changed? Set in before store method, used in after store method. 
    /// </summary>
    private bool m_bPageTemplateChanged;
    
    /// <summary>
    /// PortletID of the Footer *
    /// </summary>
    private int m_nFooterID = 0;
    
    /// <summary>
    /// Portlet ID of the Header *
    /// </summary>
    private int m_nHeaderID = 0;
    //
    // Header and Footer Category END
    //
    public CommunityTemplateModel()
    {
      m_htFormData = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CommunityTemplateModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
      if (m_nEditorType == EditorStartControl.EDITOR_START_FLAG_CREATE)
      {
        PTGrowableSortedArrayWrapper aSelectedObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE)).GetItems();
        for (int i = 0;i < aSelectedObjectValues.GetCount();i++)
        {
          int oObjectID = XPConvert.ToInteger(aSelectedObjectValues.GetItem(i,
           SelectPTObjectModel.EXPLIST_COL_OBJECTID));
          ((IPTCommunityTemplate) m_ptObject).AddPageTemplate(oObjectID);
          }
      } else
      {
        if (m_bPageTemplateChanged)
        {
          // Start ABO
          ((IPTScheduledOperation) m_ptObject).ScheduleImmediateJob();
        }
      }
    }
    
    /// <summary>
    /// Initializes IPTProperty with the property type member  variable just
    /// before we store the object in the DB. Also sets 2 other values to
    /// default.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      m_bPageTemplateChanged = false;
      if (m_nEditorType == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        // Add and Remove page templates
        PTGrowableSortedArrayWrapper aSelectedObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE)).GetItems();
        int oObjectID;
        int[] arrPageTemplateIDs = new int[aSelectedObjectValues.GetCount()];
        for (int i = 0;i < aSelectedObjectValues.GetCount();i++)
        {
          oObjectID = XPConvert.ToInteger(aSelectedObjectValues.GetItem(i,
           SelectPTObjectModel.EXPLIST_COL_OBJECTID));
          arrPageTemplateIDs[i] = oObjectID;
          if (m_xpsdOldSelectedObjects.ContainsKey(oObjectID))
          {
            m_xpsdOldSelectedObjects.RemoveElement(oObjectID);
          } else
          {
            ((IPTCommunityTemplate) m_ptObject).AddPageTemplate(arrPageTemplateIDs[i]);
            m_bPageTemplateChanged = true;
          }
        }
        IXPEnumerator xpeKeys = m_xpsdOldSelectedObjects.GetKeys();
        while (xpeKeys.MoveNext())
        {
          ((IPTCommunityTemplate) m_ptObject).RemovePageTemplate(XPConvert.ToInteger(xpeKeys.GetCurrent()));
          m_bPageTemplateChanged = true;
        }
        ((IPTCommunityTemplate) m_ptObject).UpdatePageTemplateOrder(arrPageTemplateIDs);
        }
      if (((IPTCommunityTemplate) m_ptObject).GetHeaderID() != m_nHeaderID)
      {
        // Set Header ID
        ((IPTCommunityTemplate) m_ptObject).SetHeaderID(m_nHeaderID);
      }
      if (((IPTCommunityTemplate) m_ptObject).GetFooterID() != m_nFooterID)
      {
        // Set Footer ID
        ((IPTCommunityTemplate) m_ptObject).SetFooterID(m_nFooterID);
      }
    }
    // END ***************** helper methods *****************
    
    /// <summary>
    /// Initializes the property type member variable with  the one from
    /// IPTProperty in Edit mode and the default  value in create mode.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      StartSelectPageTemplate();
      //    	StartSelectHeaderOrFooter(CommunityTemplateEditorAS.strStorageSelectHeader);
      //    	StartSelectHeaderOrFooter(CommunityTemplateEditorAS.strStorageSelectFooter);
      //       executed just after the Object was created or retrieved from the DB.
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        // ***CHANGE_HERE SECURITY PAGE*** Hide the security page in edit mode
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        } else
      {
        // ***CHANGE_HERE SECURITY PAGE*** Hide the security page in edit mode
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      StartHeaderAndFooter();
      StartCommunities();
    }
    
    /// <summary>
    /// Not a community return -1.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetCommunityID()"></seealso>
    public virtual int GetCommunityID()
    {
      return -1;
    }
    
    /// <param name="name"></param>
    /// <returns></returns>
    public virtual String GetData(String name)
    {
      String[] values = (String[]) m_htFormData.GetElement(name);
      if (values == null)
      {
        return "";
      }
      return values[0];
    }
    
    /// <returns></returns>
    public virtual bool GetFooterHasCommunityPrefs()
    {
      return m_bFooterHasCommunityPrefs;
    }
    
    /// <returns></returns>
    public virtual int GetFooterID()
    {
      log.Debug("Footer for this community is: " + m_nFooterID);
      return m_nFooterID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetFooterName()"></seealso>
    public virtual String GetFooterName()
    {
      log.Debug("Footer name for this community is: " + m_strFooterName);
      return m_strFooterName;
    }
    
    /// <returns></returns>
    public virtual bool GetHeaderHasCommunityPrefs()
    {
      return m_bHeaderHasCommunityPrefs;
    }
    
    /// <returns></returns>
    public virtual int GetHeaderID()
    {
      log.Debug("Header for this community is: " + m_nHeaderID);
      return m_nHeaderID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetHeaderName()"></seealso>
    public virtual String GetHeaderName()
    {
      log.Debug("Header name for this community is: " + m_strHeaderName);
      return m_strHeaderName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.community.IHeaderAndFooterModel#IsTemplateSelector()"></seealso>
    public virtual bool IsTemplateSelector()
    {
      return m_bIsTemplateSelector;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromFooterTree(XPHashtable _htFormData)
    {
      if (m_asOwner.GetSubSpaceExists(HeaderAndFooterSelectorView.TREE_FOOTER_SUBSPACE))
      {
        AActivitySpace asTree = m_asOwner.GetSubSpace(HeaderAndFooterSelectorView.TREE_FOOTER_SUBSPACE);
        ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList itemList = treeModel.GetSelectedItems();
        if (itemList.GetSize() != 1)
        {
          log.Error("Footer tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
          }
        TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
        if (item == null)
        {
          log.Error("Tree selected item null");
        } else
        // TODO CR DLH: Shouldn't we do something here?  Otherwise it's easy to get NPEs.
        {
          m_nFooterID = item.m_nObjectID;
          m_strFooterName = item.GetName();
          m_bFooterHasCommunityPrefs = GatewayUtils.GetPortletSupportsPersonalization(m_nFooterID,
           PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
           GetPTSession());
        }
      } else
      {
        log.Error("Unable to retrieve the footer portlet tree subspace. Subspace does not exist.");
        }
    }
    
    /// <param name="_htFormData"></param>
    public virtual void RefreshItemFromHeaderTree(XPHashtable _htFormData)
    {
      if (m_asOwner.GetSubSpaceExists(HeaderAndFooterSelectorView.TREE_HEADER_SUBSPACE))
      {
        AActivitySpace asTree = m_asOwner.GetSubSpace(HeaderAndFooterSelectorView.TREE_HEADER_SUBSPACE);
        ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList itemList = treeModel.GetSelectedItems();
        if (itemList.GetSize() != 1)
        {
          log.Error("Banner tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
          }
        TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
        if (item == null)
        {
          log.Error("Tree selected item null");
        }
        m_nHeaderID = item.m_nObjectID;
        m_strHeaderName = item.GetName();
        m_bHeaderHasCommunityPrefs = GatewayUtils.GetPortletSupportsPersonalization(m_nHeaderID,
         PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
         GetPTSession());
      } else
      {
        log.Error("Unable to retrieve the footer portlet tree subspace. Subspace does not exist.");
        }
    }
    // BEGIN ***************** helper methods *****************
    // END ***************** repost action methods *****************
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      // Switch between your DP and for each one call
      //       the associated save method
      if (_sPageName.Equals(CommunityTemplateMainDP.STR_MVC_CLASS_NAME))
      {
        // if this is the display page where you have your select ptobject you need to
        // call the associated saveSection method.
        ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE)).SaveSection(_htFormData);
        } else
      if (_sPageName.Equals(HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME))
      {
      }
      // if this is the display page where you have your select ptobject you need to
      // call the associated saveSection method.
      //			((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.strStorageSelectHeader)).
      //				SaveSection(_htFormData);
      // if this is the display page where you have your select ptobject you need to
      // call the associated saveSection method.
      //			((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.strStorageSelectFooter)).
      //				SaveSection(_htFormData);
      return nPageStatus;
    }
    
    /// <param name="bHeader"></param>
    public virtual void SetDefaultHeaderOrFooter(bool bHeader)
    {
      if (bHeader)
      {
        m_nHeaderID = 0;
        m_strHeaderName = m_asOwner.GetString(212, ResourceConstants.PORTALADMINMSGS);
        m_bHeaderHasCommunityPrefs = false;
      } else
      {
        m_nFooterID = 0;
        m_strFooterName = m_asOwner.GetString(213, ResourceConstants.PORTALADMINMSGS);
        m_bFooterHasCommunityPrefs = false;
      }
    }
    public virtual void SetUseForceSubPortal(bool bForce)
    {
      if (bForce)
      {
        m_nHeaderID = HEADERFOOTER_ID_FORCE_SUBPORTAL;
        m_nFooterID = HEADERFOOTER_ID_FORCE_SUBPORTAL;
        m_strHeaderName = m_asOwner.GetString(2159, ResourceConstants.PORTALADMINMSGS);
        m_strFooterName = m_asOwner.GetString(2160, ResourceConstants.PORTALADMINMSGS);
        } else
      {
        m_nHeaderID = 0;
        m_nFooterID = 0;
        m_strHeaderName = m_asOwner.GetString(212, ResourceConstants.PORTALADMINMSGS);
        m_strFooterName = m_asOwner.GetString(213, ResourceConstants.PORTALADMINMSGS);
        }
    }
    
    /// <summary>
    /// This is a function used in the community editor to determine whether the
    /// footer was set in the community template, in which case we disable some
    /// of the buttons on the footer selection page.  When we're in the community
    /// template editor, we just return true.
    /// </summary>
    /// <returns>true</returns>
    public virtual bool UsingFooterFromCommunityTemplate()
    {
      return false;
    }
    
    /// <summary>
    /// This is a function used in the community editor to determine whether the
    /// header was set in the community template, in which case we disable some
    /// of the buttons on the header selection page.  When we're in the community
    /// template editor, we just return true.
    /// </summary>
    /// <returns>true</returns>
    public virtual bool UsingHeaderFromCommunityTemplate()
    {
      return false;
    }
    
    /// <summary>
    /// Helper method to start the Selected Header or Footer List.
    /// </summary>
    private void StartHeaderAndFooter()
    {
      int nObjectID = 0;
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        try
        {
          nObjectID = ((IPTCommunityTemplate) m_ptObject).GetHeaderID();
          if (CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nObjectID)
          {
            m_strHeaderName = m_asOwner.GetString(2159, ResourceConstants.PORTALADMINMSGS);
            m_nHeaderID = nObjectID;
          } else
          {
            IPTQueryResult ptqrObjects = this.m_Session.GetGadgets().QuerySingleObject(nObjectID);
            if (ptqrObjects.RowCount() == 1)
            {
              // DCA - delay htmlencoding til used in view
              //m_strHeaderName				   = XPHttpUtility.HtmlEncode(ptqrObjects.ItemAsString(0,
              //		PT_PROPIDS.PT_PROPID_NAME));
              m_strHeaderName = ptqrObjects.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
              m_nHeaderID = nObjectID;
              int nWebServiceID = ptqrObjects.ItemAsInt(0, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);
              m_bHeaderHasCommunityPrefs = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
               PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
               m_Session);
            } else
            // No header stored, using default
            {
              m_strHeaderName = m_asOwner.GetString(212, ResourceConstants.PORTALADMINMSGS);
              m_bHeaderHasCommunityPrefs = false;
            }
          }
        }
        catch (Exception e)
        {
          log.Warn("Couldn\'t get the stored header ID: " + nObjectID + "  for CommunityTemplate ");
          }
        try
        {
          nObjectID = ((IPTCommunityTemplate) m_ptObject).GetFooterID();
          if (CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nObjectID)
          {
            m_strFooterName = m_asOwner.GetString(2160, ResourceConstants.PORTALADMINMSGS);
            m_nFooterID = nObjectID;
          } else
          {
            IPTQueryResult ptqrObjects = this.m_Session.GetGadgets().QuerySingleObject(nObjectID);
            if (ptqrObjects.RowCount() == 1)
            {
              // DCA - delay htmlencoding til used in view
              //m_strFooterName				   = XPHttpUtility.HtmlEncode(ptqrObjects.ItemAsString(0,
              //		PT_PROPIDS.PT_PROPID_NAME));
              m_strFooterName = ptqrObjects.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
              m_nFooterID = nObjectID;
              int nWebServiceID = ptqrObjects.ItemAsInt(0, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);
              m_bFooterHasCommunityPrefs = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
               PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
               m_Session);
            } else
            {
              m_strFooterName = m_asOwner.GetString(213, ResourceConstants.PORTALADMINMSGS);
              m_bFooterHasCommunityPrefs = false;
            }
          }
        }
        catch (Exception e)
        {
          log.Warn("Couldn\'t get the stored header ID: " + nObjectID + "  for CommunityTemplate ");
          }
      } else
      {
        m_nFooterID = 0;
        m_nHeaderID = 0;
        m_strFooterName = m_asOwner.GetString(213, ResourceConstants.PORTALADMINMSGS);
        m_strHeaderName = m_asOwner.GetString(212, ResourceConstants.PORTALADMINMSGS);
        m_bFooterHasCommunityPrefs = false;
        m_bHeaderHasCommunityPrefs = false;
      }
    }
    
    /// <summary>
    /// Helper method to start the Communities List.
    /// </summary>
    private void StartCommunities()
    {
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        InheritListModel inheritModel = ((InheritListModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_COMMUNITIES));
        inheritModel.InitializeInheritList(m_asOwner.GetString(3044, ResourceConstants.PORTALADMINMSGS),
         PT_CLASSIDS.PT_COMMUNITY_ID, 67);
        inheritModel.SetEmptyListMessages(m_asOwner.GetString(3045, ResourceConstants.PORTALADMINMSGS),
         "");
        //     Use the method bellow to set the icon to display on each row.
        //     (By default there will be no icon.)
        inheritModel.SetDefaultRowIcon(PTImageType.ICON_COMMUNITY);
        // Add inherited communities.
        inheritModel.SetDefaultObjects(m_Session, PT_CLASSIDS.PT_COMMUNITY_ID,
         m_nObjectID, PT_PROPIDS.PT_PROPID_COMMUNITY_COMMUNITYTEMPLATEID,
         PT_PROPIDS.PT_PROPID_COMMUNITY_INHERITCOMMUNITYTEMPLATE);
      } else
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, CommunityTemplateCommunitiesDP.STR_MVC_CLASS_NAME);
        }
    }
    
    /// <summary>
    /// Takes a query result of page templates and sets up the member variables from
    /// it.
    /// </summary>
    /// <param name="IASQueryResult">ptqrPortlets</param>
    /// <returns>Object[][]</returns>
    private Object[][] SetupPageTemplates(IASQueryResult asqrPageTemplates,
     SelectPTObjectModel selectPTObject)
    {
      int nPageTemplateCount;
      if (null == asqrPageTemplates)
      {
        nPageTemplateCount = 0;
      } else
      {
        nPageTemplateCount = asqrPageTemplates.GetCount();
      }
      Object[][] arrReturn = new Object[nPageTemplateCount][];
      for (int j2c_index = 0;j2c_index < nPageTemplateCount;j2c_index++)
      {
        arrReturn[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
        }
      m_xpsdOldSelectedObjects = new XPSortedDictionary();
      for (int i = 0;i < nPageTemplateCount;i++)
      {
        arrReturn[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = selectPTObject.m_nNextIndex;
        selectPTObject.m_nNextIndex++;
        arrReturn[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_PAGETEMPLATE_ID;
        arrReturn[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = asqrPageTemplates.GetFields(i,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        arrReturn[i][SelectPTObjectModel.EXPLIST_COL_STRING] = (String) asqrPageTemplates.GetFields(i,
         PT_PROPIDS.PT_PROPID_NAME);
        // Setup Old Selected Portlets
        m_xpsdOldSelectedObjects.PutElement(arrReturn[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID],
         "");
      }
      return arrReturn;
    }
    // BEGIN ***************** save DP methods *****************
    // END ***************** save DP methods *****************
    //***** Private methods
    
    /// <summary>
    /// Helper method to start the Selected Page Template List.
    /// </summary>
    private void StartSelectPageTemplate()
    {
      SelectPTObjectModel selectPTObject = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE));
      /* Initialize the Select PTObject list.
       _sSectionTitle: Main title.
       _sSectionSubTitle: Sub title.
       _imgAddIcon: Icon for the add action.
       _sAddLabel: Text to display next to the add icon.
       _arrObjectClassIDs Class ID of the Objects displayed on the list.
       _nListKey: In case you have multiple Expandable Lists on
       the same DP, they should have a different key
       (otherwise, just set it to 1).
       */
       
      selectPTObject.InitializeSelectPTObject(m_asOwner.GetString(199, ResourceConstants.PORTALADMINMSGS),
       m_asOwner.GetString(200, ResourceConstants.PORTALADMINMSGS), PTImageType.ICON_PAGE_TEMPLATE,
       m_asOwner.GetString(201, ResourceConstants.PORTALADMINMSGS), new int[]{PT_CLASSIDS.PT_PAGETEMPLATE_ID},
       1);
      selectPTObject.SetEnableMoveRowActions(true);
      selectPTObject.SetTreeTitle(m_asOwner.GetString(201, ResourceConstants.PORTALADMINMSGS));
      selectPTObject.SetTreeSubTitle(m_asOwner.GetString(1785, ResourceConstants.PORTALADMINMSGS));
      selectPTObject.SetEmptyListMessages(m_asOwner.GetString(208, ResourceConstants.PORTALADMINMSGS),
       m_asOwner.GetString(209, ResourceConstants.PORTALADMINMSGS));
      int[][] anObjectToHide = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        anObjectToHide[j2c_index] = new int[SelectPTObjectModel.HIDE_COL_MAX];
        }
      anObjectToHide[0][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_PAGETEMPLATE_ID;
      anObjectToHide[0][SelectPTObjectModel.HIDE_COL_OBJECTID] = PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID;
      selectPTObject.SetHiddenObjects(anObjectToHide);
      //     Use the method bellow to set the icon to display on each row.
      //     (By default there will be no icon.)
      selectPTObject.SetDefaultRowIcon(PTImageType.ICON_PAGE_TEMPLATE);
      // Setup initial page templates
      IASQueryResult asqrPageTemplates = null;
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        ASQueryResultWrapper qrw = new ASQueryResultWrapper(((IPTCommunityTemplate) m_ptObject).QueryPageTemplates());
        asqrPageTemplates = qrw;
      }
      Object[][] arrDefaultPageTemplates = SetupPageTemplates(asqrPageTemplates,
       selectPTObject);
      // Add default rows.
      selectPTObject.SetDefaultObjects(arrDefaultPageTemplates);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndFooterModel#GetCommunityFolderID()
     */
     
    public virtual int GetCommunityFolderID()
    {
      return -1;
    }
  }
}