using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.condition;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.condition
{
  public class RuleEditorMainDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "RuleEditorMainDP";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetEditorTitle();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      result.AddInnerHTMLElement(HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2966,
       "ptmsgs_portaladminmsgs"), m_asOwner));
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      // Do some formatting
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetAlign(CommonHTMLStrings.CENTER);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing("15");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.AddInnerHTMLElement(m_asOwner.GetView(ErrorView.STR_MVC_CLASS_NAME).Display());
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.AddInnerHTMLElement(m_asOwner.GetView(CreateRuleView.STR_MVC_CLASS_NAME).Display());
      // Display Condition Type Expandable Lists
      IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
      while (condTypes.MoveNext())
      {
        AConditionType current = (AConditionType) condTypes.GetCurrent();
        IView condListView = m_asOwner.GetView(current.GetConditionTypeIdentifier());
        if (null != condListView)
        {
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLElement(condListView.Display());
        }
      }
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(CreateRuleView.STR_MVC_CLASS_NAME).DisplayJavascript());
      // Display Condition Type Expandable Lists
      IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
      while (condTypes.MoveNext())
      {
        AConditionType current = (AConditionType) condTypes.GetCurrent();
        IView condListView = m_asOwner.GetView(current.GetConditionTypeIdentifier());
        if (null != condListView)
        {
          myScripts.AddInnerHTMLElement(condListView.DisplayJavascript());
          }
      }
      return myScripts;
    }
  }
}