using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.web;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <summary>
  /// This DP displays the Views for the main page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public abstract class AMainDP : EditorDP
  {
    
    /// <summary>
    /// Returns HTML for common Crawler Views.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement GetHTMLForCommonView()
    {
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).Display());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(DestFolderSettingsView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY)).Display());
      return views;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(216, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the page title. By default it is the same as the left navigation string.
    /// </summary>
    /// <returns>String</returns>
    public override String GetPageTitle()
    {
      String sDSName = ((CrawlerModel) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetDataSourceName();
      return GetLeftNavString() + " - " + XPResourceManager.FormatMessage(m_asOwner.GetString(2141,
       "ptmsgs_portaladminmsgs"), XPHttpUtility.HtmlEncode(sDSName));
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(DestFolderSettingsView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
  }
}