using System;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <summary>
  /// This DP displays the Views for the advanced settings page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class AdvSettingsDP : EditorDP
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CrAdvSettings";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(215, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2469, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement((m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LANGUAGE)).Display());
      /* JQ: Combined the DefaultConfView with the RejectedDocsView since
       * they both dealt with rejection and rejected docs
       */
       
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(RejectedDocsView.STR_MVC_CLASS_NAME)).Display());
      // JF- The following View is in Edit mode only
      CrawlerModel myModel = (CrawlerModel) m_asOwner.GetModel(m_asOwner.m_strModelName);
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == myModel.GetEditorType())
      {
        /* Importing docs view */
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ImportingDocsView.STR_MVC_CLASS_NAME)).Display());
        }
      // olegs - added
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CrawlerTagView.STR_MVC_CLASS_NAME)).Display());
      // end
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CrawlerThreadConfigView.STR_MVC_CLASS_NAME)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(ImportingDocsView.STR_MVC_CLASS_NAME).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(RejectedDocsView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
  }
}