using System;
// Framework imports
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <summary>
  /// This Section contains the HTML for the dependencies page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class CrawlerDependenciesView : ObjDependenciesView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.crawler.CrawlerDependenciesView");
    
    /// <summary>
    /// Member variables 
    /// </summary>
    private CreatedHelper m_chHelper = null;
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CrawlerDependencies";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CrawlerDependenciesView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_chHelper = new CreatedHelper(parent, (CrawlerModel) model);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Adds javascript for creating or adding to jobs
    /// </summary>
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      try
      {
        m_chHelper.addJobJavascript(myScript);
      }
      catch (HTMLException he)
      {
        log.Error(he, "CrawlerDependenciesView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()"></seealso>
    protected override HTMLElementCollection GetHTMLForDependencies()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      //Display the standard success message
      m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(1399, "ptmsgs_portaladminmsgs"),
       ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());
      //Text: This job will display the following operations:
      m_chHelper.displayTextRow(result, m_asOwner.GetString(2388, "ptmsgs_portaladminmsgs"),
       null);
      //Start a list
      m_chHelper.beginList(result);
      int nFolderID = ((ObjEditorModel) m_model).GetFolderID();
      m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(PT_CLASSIDS.PT_SAVEDSEARCH_ID,
       null, nFolderID, m_asOwner.GetString(2389, "ptmsgs_portaladminmsgs"),
       m_asOwner, null, true));
      //Display the jobs
      m_chHelper.displayJobRows(result, m_asOwner.GetString(2201, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(2202, "ptmsgs_portaladminmsgs"));
      m_chHelper.displayEmptyRow(result);
      //Display the standard warning if everyone has access to this object
      m_chHelper.displayEveryoneWarning(result, (CrawlerModel) m_model, m_asOwner.GetString(2298,
       "ptmsgs_portaladminmsgs"));
      return result;
    }
  }
}