using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using IOKComponent=com.plumtree.openkernel.config.IOKComponent;
using IOKContext=com.plumtree.openkernel.config.IOKContext;
using OKConfigFactory=com.plumtree.openkernel.factory.OKConfigFactory;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.common.setjob;
using com.plumtree.portalpages.admin.editors.doctypemap;
using com.plumtree.portalpages.common.documentlanguage;
using com.plumtree.portalpages.common.linksettings;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using IPTCrawlerConfig=com.plumtree.server.crawlers.IPTCrawlerConfig;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using UIError=com.plumtree.uiinfrastructure.errordisplay.UIError;
using UIErrorHandler=com.plumtree.uiinfrastructure.errordisplay.UIErrorHandler;
using UIErrorLevel=com.plumtree.uiinfrastructure.errordisplay.UIErrorLevel;
using UIErrorScope=com.plumtree.uiinfrastructure.errordisplay.UIErrorScope;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using ConfigPathResolver=com.plumtree.xpshared.config.ConfigPathResolver;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <summary>
  /// This is the main Editor Model for the Crawler Editor.
  /// </summary>
  /// <author>Julie Fournier</author>
  public abstract class CrawlerModel : ObjEditorModel,ICrawlerModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.crawler.CrawlerModel");
    
    /// <summary>
    /// Query String param: data source ID
    /// </summary>
    public const String QS_CRAWLEREDITOR_DATASOURCE_ID = "dataSourceID";
    
    /// <summary>
    /// When the mirroring check box is checked, the destination folders selection becomes single select.
    /// That's why we need to notify the User.
    /// </summary>
    public bool m_bDisplayMirroringAlert = false;
    
    /// <summary>
    /// Determines whether refresh settings should be applied to previously imported cards
    /// </summary>
    public bool m_bRefreshExistingCards = false;
    
    /// <summary>
    /// Number of deleted cards in the deletion history.
    /// </summary>
    public int m_nDeletionCards = 0;
    
    /// <summary>
    /// Number of deleted cards in the rejection history.
    /// </summary>
    public int m_nRejectionCards = 0;
    
    /// <summary>
    /// Name of the Data Source
    /// </summary>
    public String m_sDataSourceName = "";
    
    /// <summary>
    /// Crawler Start Location Property Bag 
    /// </summary>
    protected IXPPropertyBag m_pbStartLocation;
    
    /// <summary>
    /// Crawler Runtime Configuration Property Bag 
    /// Put infomation about the number of threads, etc. here
    /// </summary>
    protected IXPPropertyBag crawlerRuntimeConfig;
    
    /// <summary>
    /// Flag to know whether the Crawler's DS supports mirroring.
    /// </summary>
    protected bool m_bDSSupportMirroring = false;
    
    /// <summary>
    /// Flag to know whether this Crawler supports ACL import or no.
    /// </summary>
    protected bool m_bSupportsACLImport = false;
    
    /// <summary>
    /// Flag to know whether this Crawler is configured to import only new links.
    /// </summary>
    protected bool m_bImportOnlyNewLinks;
    
    /// <summary>
    /// Number of sections to display on the Document Type Map page.
    /// </summary>
    private int m_nDocMapSectionCount;
    
    /// <summary>
    /// Clears the crawler's deletion history.
    /// </summary>
    public virtual void ClearDeletionHistory()
    {
      m_nDeletionCards = ((IPTCrawler) m_ptObject).ClearDeletedCardsMemory(true,
       false);
    }
    
    /// <summary>
    /// Returns the Data Source name.
    /// </summary>
    public virtual String GetDataSourceName()
    {
      return m_sDataSourceName;
    }
    
    /// <summary>
    /// Clears the crawler's rejection history.
    /// </summary>
    public virtual void ClearRejectionHistory()
    {
      m_nRejectionCards = ((IPTCrawler) m_ptObject).ClearCardRejectsMemory(true);
      }
    
    /// <summary>
    /// Performs the change mirroring action
    /// </summary>
    public virtual void ChangeMirroringStatus()
    {
      int nCrawlerSettings = GetCrawlerSettings();
      SelectPTObjectModel mySelectDestFoldersModel = (SelectPTObjectModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER);
      mySelectDestFoldersModel.ResetTreeID();
      // JF- We have decided to mirror, we need to change the tree to multi select to single.
      if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR & nCrawlerSettings))
      {
        mySelectDestFoldersModel.SetTreeMultiSelect(false);
        PTGrowableSortedArrayWrapper saItems = mySelectDestFoldersModel.GetItems();
        if (saItems.GetCount() > 1)
        {
          int[] arrRowsToDelete = new int[saItems.GetCount() - 1];
          for (int i = 0;i < saItems.GetCount() - 1;i++)
          {
            arrRowsToDelete[i] = i + 1;
          }
          saItems.RemoveRows(arrRowsToDelete);
          m_bDisplayMirroringAlert = true;
        }
      } else
      {
        // JF- We have decided to not mirror, we need to change the tree to single select to multi.
        mySelectDestFoldersModel.SetTreeMultiSelect(true);
      }
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskAfterStoreSetJob();
      if (m_bRefreshExistingCards)
      {
        ApplyRefreshSettingsToExistingCards();
      }
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      StoreDestFolders();
      StoreContentLanguage();
      StoreLinkSettings();
      StoreAdvSettings();
      // Call Finish on the Card Security page
      ((ObjectSecurityModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY)).Finish();
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStoreSetJob();
      GbDocTypeListModel myGbDocTypeModel;
      for (int i = 0;i < m_nDocMapSectionCount;i++)
      {
        myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP + i);
        myGbDocTypeModel.Finish();
      }
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      base.DoTaskOnComeBackFromSubEditor();
      ((SelectPTObjectModel) m_asOwner.GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).DoTaskOnComeBackFromSubEditor();
      GbDocTypeListModel myGbDocTypeModel;
      for (int i = 0;i < m_nDocMapSectionCount;i++)
      {
        myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP + i);
        myGbDocTypeModel.DoTaskOnComeBackFromSubEditor(i);
      }
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      // JF- Check if the Crawler's DS supports mirroring and ACL import
      InitMirroringAndACLImportFlags();
      InitDataSourceName();
      // JF- Init the select Folder array
      StartSelectFolder();
      // JF- Init the Set Job plug-in page
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskOnStartSetJob(m_ptObject,
       m_Session, GetEditorType());
      // JF- Init the language Section
      StartContentLanguage();
      // JF- Init the link settings page
      StartLinkSettings();
      // JF- Init the Card Security page
      StartCardSecurity();
      // JF- Init the Importing Docs view
      StartImportSettings();
      // JF- Init the Document Type Map page
      StartGbDocTypeList();
      // JF- Hide the Security page in create mode
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
    }
    
    /// <summary>
    /// Helper method to get the Data Source name.
    /// </summary>
    private void InitDataSourceName()
    {
      IPTDataSource ptDataSource = (IPTDataSource) m_Session.GetDataSources().Open(((IPTCrawler) m_ptObject).GetDataSourceID(),
       false);
      m_sDataSourceName = ptDataSource.GetLocalizedName();
    }
    
    /// <summary>
    /// Returns crawler settings
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCrawlerSettings()
    {
      return ((IPTCrawler) m_ptObject).GetSettings();
    }
    
    /// <summary>
    /// Returns the number of Sections to display on the Document Type Map page.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetDocMapSectionCount()
    {
      return m_nDocMapSectionCount;
    }
    
    /// <summary>
    /// Returns the flag m_bImportOnlyNewLinks.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetImportOnlyNewLinks()
    {
      return m_bImportOnlyNewLinks;
    }
    
    /// <summary>
    /// Tells whether the Crawler's DS supports mirroring or no.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSupportMirroring()
    {
      return m_bDSSupportMirroring;
    }
    
    /// <summary>
    /// Tells whether the Crawler supports ACL import.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSupportsACLImport()
    {
      return m_bSupportsACLImport;
    }
    
    /// <summary>
    /// Returns taxonomist settings
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetTaxSettings()
    {
      return ((IPTCrawler) m_ptObject).GetTaxonomist().GetSettings();
    }
    
    /// <summary>
    /// Helper methods to save the settings on MainDP.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public virtual int SaveMainDP(XPHashtable _htFormData)
    {
      // JF- Save destination folders list
      ((SelectPTObjectModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).SaveSection(_htFormData);
      // JF- Save the content security list	
      ((ObjectSecurityModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY)).SaveSection(_htFormData);
      // JF- Save settings
      int nCrawlerSettings = GetCrawlerSettings();
      int nTaxSettings = GetTaxSettings();
      // JF- Mirroring checkbox
      if ((m_bDSSupportMirroring) && (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType()))
      {
        if (!_htFormData.ContainsKey(DestFolderSettingsView.HTMLCHECKBOX_MIRROR))
        {
          nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR;
          } else
        {
          nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR;
          }
      }
      if (!_htFormData.ContainsKey(DestFolderSettingsView.HTMLCHECKBOX_APPROVE_DOCS))
      {
        nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ALL_CARDS_AS_APPROVED;
        } else
      {
        nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ALL_CARDS_AS_APPROVED;
        }
      if (0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR & nCrawlerSettings))
      {
        if (!_htFormData.ContainsKey(DestFolderSettingsView.HTMLCHECKBOX_APPLY_FILTERS))
        {
          nTaxSettings = nTaxSettings | PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_ONLY_APPLY_SUBFOLDER_FILTERS;
          } else
        {
          nTaxSettings = nTaxSettings & ~PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_ONLY_APPLY_SUBFOLDER_FILTERS;
          }
      }
      if (m_bSupportsACLImport)
      {
        if (!_htFormData.ContainsKey(DestFolderSettingsView.HTMLCHECKBOX_IMPORT_SECURITY))
        {
          nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_ACL_IMPORT;
          /* since we aren't importing ACLs, we should reset the ACL Refresh Flag */
          nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_FORCE_ACL_REFRESH;
          } else
        {
          nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_ACL_IMPORT;
          }
      }
      try
      {
        ((IPTCrawler) m_ptObject).SetSettings(nCrawlerSettings);
        ((IPTCrawler) m_ptObject).GetTaxonomist().SetSettings(nTaxSettings);
        }
      catch (Exception e)
      {
        log.Error("CrawlerModel::SaveMainDP The following exception happened " + "when trying to set the new Crawler settings: " + e);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(SetJobDP.STR_MVC_CLASS_NAME))
      {
        ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        } else
      if (_sPageName.Equals(AdvSettingsDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SaveAdvSettingsPage(_htFormData);
      } else
      if (_sPageName.Equals(LinkSettingsDP.STR_MVC_CLASS_NAME))
      {
        ((LinkSettingsPlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LINK_SETTINGS)).SaveSection(_htFormData);
        PutApplyExisting(_htFormData);
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to start the security page.
    /// </summary>
    public virtual void StartCardSecurity()
    {
      ObjectSecurityModel myCardSecurityModel = (ObjectSecurityModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY);
      myCardSecurityModel.InitializeSecurityPage(m_ptObject, m_Session);
      myCardSecurityModel.SetSectionTitle(m_asOwner.GetString(231, "ptmsgs_portaladminmsgs"));
      // JF- We need to change to list key otherwise it will be the same as the security page.
      myCardSecurityModel.SetListKey(21);
    }
    
    /// <summary>
    /// Helper method to init the Content language common section.
    /// </summary>
    public virtual void StartContentLanguage()
    {
      String sLanguage = ((IPTCrawler) m_ptObject).GetContentLanguage();
      ((CardLanguagePlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LANGUAGE)).InitializePlugIn(sLanguage,
       m_asOwner.GetString(232, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(233,
       "ptmsgs_portaladminmsgs"), false);
    }
    
    /// <summary>
    /// Helper method to init the Importing Docs view
    /// </summary>
    public virtual void StartImportSettings()
    {
      int nCrawlerSettings = GetCrawlerSettings();
      if ((0 == (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_CRAWLER_NEW_CARDS)) && (0 == (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS)))
      {
        m_bImportOnlyNewLinks = false;
      } else
      {
        m_bImportOnlyNewLinks = true;
      }
    }
    
    /// <summary>
    /// Helper method to init the Link Settings page.
    /// </summary>
    public virtual void StartLinkSettings()
    {
      IPTCrawler ptCrawler = (IPTCrawler) m_ptObject;
      ((LinkSettingsPlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LINK_SETTINGS)).InitializePlugInForCrawlers(ptCrawler.GetCardRefreshRateUnits(),
       ptCrawler.GetCardRefreshRateValue(), ptCrawler.GetCheckLinkOnly(),
       ptCrawler.GetCardMissingDocumentDeletionDelayUnits(), ptCrawler.GetCardMissingDocumentDeletionDelayValue(),
       ptCrawler.GetCardExpirationDelayUnits(), ptCrawler.GetCardExpirationDelayValue());
      }
    
    /// <summary>
    /// Helper method to start the Select Folder List.
    /// </summary>
    public virtual void StartSelectFolder()
    {
      SelectPTObjectModel mySelectDestFoldersModel = (SelectPTObjectModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER);
      mySelectDestFoldersModel.InitializeSelectPTObject(m_asOwner.GetString(224,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(225, "ptmsgs_portaladminmsgs"),
       PTImageType.ICON_FOLDER, m_asOwner.GetString(226, "ptmsgs_portaladminmsgs"),
       new int[]{PT_CLASSIDS.PT_CATALOGFOLDER_ID}, 20);
      mySelectDestFoldersModel.SetDefaultRowIcon(PTImageType.ICON_FOLDER);
      // JF- Set Strings to display when list is empty
      mySelectDestFoldersModel.SetEmptyListMessages(m_asOwner.GetString(227,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(228, "ptmsgs_portaladminmsgs"));
      // Set the tree leaf type
      mySelectDestFoldersModel.SetTreeLeafType(TreeConstants.N_COMPOSITESELECT);
      // requiring edit access on directory folder; fixing bug 33284 =mgs
      mySelectDestFoldersModel.SetAccessLevel(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
      // Set title and sub title for the tree
      mySelectDestFoldersModel.SetTreeTitle(m_asOwner.GetString(1795, "ptmsgs_portaladminmsgs"));
      mySelectDestFoldersModel.SetTreeSubTitle(m_asOwner.GetString(1794, "ptmsgs_portaladminmsgs"));
      // JF- Set JS validation to prevent the list from being empty.
      String sJSFunctionName = ((SelectPTObjectModel) mySelectDestFoldersModel).SetEnableEmptyListClientValidation(m_asOwner.GetString(229,
       "ptmsgs_portaladminmsgs"));
      // JF- Then add this JavaScript function name to the Display Page validation functions
      AMainDP myMainDP = (AMainDP) m_asOwner.GetPage(GetMainDPName());
      myMainDP.AddToValidationFunction(sJSFunctionName);
      // JF- Populate the list in Edit mode 	
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        Object[] arrDestFolders = (Object[]) ((IPTCrawler) m_ptObject).GetTaxonomist().GetDestinationFolders();
        if (null != arrDestFolders)
        {
          IPTFolder ptFolder;
          int k = 0;
          XPHashtable htFolders = new XPHashtable();
          for (int i = 0;i < arrDestFolders.Length;i++)
          {
            try
            {
              ptFolder = m_Session.GetCatalog().OpenFolder(XPConvert.ToInteger(arrDestFolders[i]),
               false);
              htFolders.PutElement(arrDestFolders[i], ptFolder);
            }
            catch (Exception e)
            {
              log.Error("StartSelectFolder Unable to open admin foler with ID: " + arrDestFolders[i] + ". The exception was: " + e);
              }
          }
          Object[][] oRows = new Object[htFolders.GetSize()][];
          for (int j2c_index = 0;j2c_index < htFolders.GetSize();j2c_index++)
          {
            oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
            }
          IXPEnumerator enumKeys = htFolders.GetKeys();
          while (enumKeys.MoveNext())
          {
            ptFolder = (IPTFolder) htFolders.GetElement(enumKeys.GetCurrent());
            oRows[k][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_CATALOGFOLDER_ID;
            oRows[k][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = enumKeys.GetCurrent();
            oRows[k][SelectPTObjectModel.EXPLIST_COL_STRING] = ptFolder.GetPath();
            k++;
          }
          mySelectDestFoldersModel.SetDefaultObjects(oRows);
          /* If this is a mirror crawl, then we want to use single-select */
          int nCrawlerSettings = GetCrawlerSettings();
          if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR & nCrawlerSettings))
          {
            mySelectDestFoldersModel.SetTreeMultiSelect(false);
          } else
          {
            mySelectDestFoldersModel.SetTreeMultiSelect(true);
          }
        }
      }
    }
    
    /// <summary>
    /// Helper method to get back the data from the content language page and set them on the crawler.
    /// </summary>
    public virtual void StoreContentLanguage()
    {
      String sLanguage = ((CardLanguagePlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LANGUAGE)).GetCardLanguageCode();
      ((IPTCrawler) m_ptObject).SetContentLanguage(sLanguage);
    }
    
    /// <summary>
    /// Helper method to get back the data from the link settings page and set them on the crawler.
    /// </summary>
    public virtual void StoreLinkSettings()
    {
      LinkSettingsPlugInModel myModel = (LinkSettingsPlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LINK_SETTINGS);
      IPTCrawler ptCrawler = (IPTCrawler) m_ptObject;
      ptCrawler.SetCardExpirationDelay(myModel.GetExpireAfterUnits(), myModel.GetExpireAfterValue());
      ptCrawler.SetCardMissingDocumentDeletionDelay(myModel.GetBrokenLinksDeleteUnits(),
       myModel.GetBrokenLinksDeleteValue());
      ptCrawler.SetCardRefreshRate(myModel.GetRefreshUnits(), myModel.GetRefreshValue());
      ptCrawler.SetCheckLinkOnly(myModel.GetCheckLinkOnly());
    }
    
    /// <summary>
    /// Returns the name of the MainDP display page.
    /// </summary>
    /// <returns>String</returns>
    protected abstract String GetMainDPName();
    
    /// <summary>
    /// Retrieves the DS ID and initializes the Crawler.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected override void InitPTObject(XPHashtable _htFormData)
    {
      base.InitPTObject(_htFormData);
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        int nDataSourceID = GetDataSourceIDFromQS(_htFormData);
        if (-1 == nDataSourceID)
        {
          throw new XPException(m_asOwner.GetString(230, "ptmsgs_portaladminmsgs"));
          }
        ((IPTCrawler) m_ptObject).Initialize(nDataSourceID);
        m_pbStartLocation = PortalObjectsFactory.CreatePropertyBag();
        InitProviderPropertyBag(m_pbStartLocation);
        crawlerRuntimeConfig = PortalObjectsFactory.CreatePropertyBag();
      } else
      {
        m_pbStartLocation = ((IPTCrawler) m_ptObject).GetStartLocation();
        crawlerRuntimeConfig = ((IPTCrawler) m_ptObject).GetCrawlerRuntimeConfiguration();
        }
    }
    
    /// <summary>
    /// Initializes the Crawler property bag.
    /// (Called in create mode ONLY)
    /// </summary>
    /// <param name="_pbStartLocation"></param>
    protected abstract void InitProviderPropertyBag(IXPPropertyBag _pbStartLocation);
    
    /// <summary>
    /// Helper method to store the advanced settings.
    /// </summary>
    protected virtual void StoreAdvSettings()
    {
      if (!m_bImportOnlyNewLinks)
      {
        int nCrawlerSettings = GetCrawlerSettings();
        nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS;
        nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_CRAWLER_NEW_CARDS;
        nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_REFRESH_RECRAWLED_CARDS;
        nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_RETAXONOMIZE_RECRAWLED_CARDS;
        nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_RECRAWL_DELETED_CARDS;
        ((IPTCrawler) m_ptObject).SetSettings(nCrawlerSettings);
      }
    }
    
    /// <summary>
    /// Helper method to store the destination folders.
    /// </summary>
    protected virtual void StoreDestFolders()
    {
      IPTTaxonomist ptTaxonomist = ((IPTCrawler) m_ptObject).GetTaxonomist();
      Object[] arrDestFolders = (Object[]) ptTaxonomist.GetDestinationFolders();
      if (null != arrDestFolders)
      {
        // JF- First we remove all the old destination folders
        for (int i = 0;i < arrDestFolders.Length;i++)
        {
          try
          {
            ptTaxonomist.RemoveDestinationFolder(XPConvert.ToInteger(arrDestFolders[i]));
            }
          catch (Exception e)
          {
            log.Error("CrawlerModel::StoreDestFolders Unable to delete the desctination folder with ID: " + arrDestFolders[i] + "The following exception happened: " + e);
            }
        }
      }
      // JF- Then we had the new ones
      PTGrowableSortedArrayWrapper aDestFolersValues = ((SelectPTObjectModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).GetItems();
      int nObjectID;
      for (int i = 0;i < aDestFolersValues.GetCount();i++)
      {
        nObjectID = XPConvert.ToInteger(aDestFolersValues.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
        ptTaxonomist.AddDestinationFolder(nObjectID);
      }
    }
    
    /// <summary>
    /// Helper method to retrieve the the Data Source ID from the QS.
    /// </summary>
    /// <param name="_htFormData"></param>
    private int GetDataSourceIDFromQS(XPHashtable _htFormData)
    {
      int nDataSourceID = -1;
      if (!_htFormData.ContainsKey(QS_CRAWLEREDITOR_DATASOURCE_ID))
      {
        log.Error("CrawlerModel::GetDataSourceIDFromQS The data source ID was " + "not found in the Query String. The Editor cannot be started.");
        } else
      {
        String[] data = (String[]) _htFormData.GetElement(QS_CRAWLEREDITOR_DATASOURCE_ID);
        try
        {
          nDataSourceID = XPConvert.ToInteger(data[0]);
        }
        catch (Exception e)
        {
          log.Error("CrawlerModel::GetDataSourceIDFromQS The data source ID was invalid: " + data + ". The Editor cannot be started. The following exception happened:" + e);
          }
      }
      return nDataSourceID;
    }
    
    /// <summary>
    /// Helper method to init the member variable m_bDSSupportMirroring.
    /// </summary>
    private void InitMirroringAndACLImportFlags()
    {
      int nDataSourceID = ((IPTCrawler) m_ptObject).GetDataSourceID();
      IPTDataSource ptDataSource = (IPTDataSource) m_Session.GetDataSources().Open(nDataSourceID,
       false);
      int nWebServiceID = ptDataSource.GetWebServiceID();
      if (0 != nWebServiceID)
      {
        IPTWebService ptWebService = (IPTWebService) m_Session.GetWebServices().Open(nWebServiceID,
         false);
        IXPPropertyBag ptProvInfo = ptWebService.GetProviderInfo();
        if (1 == ptProvInfo.ReadAsInt(AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSMIRRORING))
        {
          m_bDSSupportMirroring = true;
        }
        if (1 == ptProvInfo.ReadAsInt(AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSACLIMPORT))
        {
          m_bSupportsACLImport = true;
        }
      }
    }
    
    /// <summary>
    /// Returns the Query Result of the Unmapped External Domains filtered by the Data Source of this Crawler.
    /// </summary>
    /// <returns>IPTQueryResult</returns>
    public virtual IPTQueryResult GetUnmappedExternalDomains()
    {
      try
      {
        IPTACLSyncMap ptAclSynMap = (IPTACLSyncMap) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
         false);
        int nDataSourceID = ((IPTCrawler) m_ptObject).GetDataSourceID();
        Object[][] arrFilter = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          arrFilter[j2c_index] = new Object[1];
        }
        arrFilter[0][0] = PT_PROPIDS.PT_PROPID_ACLSYNCUNMAPPED_DATASOURCEID;
        arrFilter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
        arrFilter[2][0] = nDataSourceID;
        return ptAclSynMap.QueryUnmappedExternalDomains(arrFilter);
      }
      catch (Exception e)
      {
        log.Error("CrawlerModel::GetUnmappedExternalDomains The following exception happened " + "when trying to set the open and query the ACL Synch map: " + e);
        }
      return null;
    }
    public virtual String GetCrawlerTag()
    {
      return ((IPTCrawler) m_ptObject).GetCrawlerTag();
    }
    
    /// <summary>
    /// Tells whether previously imported cards should be updated for new refresh settings.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetApplyExisting()
    {
      return m_bRefreshExistingCards;
    }
    
    /// <summary>
    /// Get the runtime configuration property bag
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.crawler.ICrawlerModelRO#GetRuntimeConfiguration()"></seealso>
    public virtual IXPPropertyBag GetRuntimeConfiguration()
    {
      return crawlerRuntimeConfig;
    }
    
    /// <summary>
    /// Helper method to save the Advance Settings page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    private int SaveAdvSettingsPage(XPHashtable _htFormData)
    {
      int nPageStatus = ((CardLanguagePlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LANGUAGE)).SaveSection(_htFormData);
      if (_htFormData.ContainsKey(RejectedDocsView.HTMLRADIO_REJECTED_DOCS))
      {
        String[] data = (String[]) _htFormData.GetElement(RejectedDocsView.HTMLRADIO_REJECTED_DOCS);
        try
        {
          int nCheckBoxValue = XPConvert.ToInteger(data[0]);
          int nTaxSettings = GetTaxSettings();
          if (0 == nCheckBoxValue)
          {
            nTaxSettings = nTaxSettings | PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_PUT_REJECTED_CARDS_IN_UNCLASSIFIED;
            nTaxSettings = nTaxSettings & ~PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_DELETE_REJECTED_CARDS;
            } else
          if (1 == nCheckBoxValue)
          {
            nTaxSettings = nTaxSettings & ~PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_PUT_REJECTED_CARDS_IN_UNCLASSIFIED;
            nTaxSettings = nTaxSettings | PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_DELETE_REJECTED_CARDS;
            }
          ((IPTCrawler) m_ptObject).GetTaxonomist().SetSettings(nTaxSettings);
          }
        catch (Exception e)
        {
          log.Error("CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to set the new Crawler settings: " + e);
          }
      }
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        int nCrawlerSettings = GetCrawlerSettings();
        if (m_bImportOnlyNewLinks)
        {
          if (_htFormData.ContainsKey(ImportingDocsView.HTMLRADIO_ALREADY_IMPORTED))
          {
            String[] data = (String[]) _htFormData.GetElement(ImportingDocsView.HTMLRADIO_ALREADY_IMPORTED);
            try
            {
              int nAlreadyImportedDocs = XPConvert.ToInteger(data[0]);
              if (PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS == nAlreadyImportedDocs)
              {
                nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS;
                nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_CRAWLER_NEW_CARDS;
                } else
              if (PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_CRAWLER_NEW_CARDS == nAlreadyImportedDocs)
              {
                nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_CRAWLER_NEW_CARDS;
                nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS;
                }
            }
            catch (Exception e)
            {
              log.Error("CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to get the value of " + ImportingDocsView.HTMLRADIO_ALREADY_IMPORTED + ": " + e);
              }
          }
          if (0 != (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_ACL_IMPORT))
          {
            if (!_htFormData.ContainsKey(ImportingDocsView.HTMLCHECKBOX_REFRESH_ACLS))
            {
              nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_FORCE_ACL_REFRESH;
              } else
            {
              nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_FORCE_ACL_REFRESH;
              }
          }
          if (!_htFormData.ContainsKey(ImportingDocsView.HTMLCHECKBOX_REFRESH_THEM))
          {
            nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_REFRESH_RECRAWLED_CARDS;
            } else
          {
            nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_REFRESH_RECRAWLED_CARDS;
            }
          if (0 == (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR))
          {
            if (!_htFormData.ContainsKey(ImportingDocsView.HTMLCHECKBOX_SORT_THEM))
            {
              nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_RETAXONOMIZE_RECRAWLED_CARDS;
              } else
            {
              nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_RETAXONOMIZE_RECRAWLED_CARDS;
              }
          }
          if (!_htFormData.ContainsKey(ImportingDocsView.HTMLCHECKBOX_REGENERATE_LINKS))
          {
            nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_RECRAWL_DELETED_CARDS;
            } else
          {
            nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_RECRAWL_DELETED_CARDS;
            }
        }
        if (0 == (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR))
        {
          if (_htFormData.ContainsKey(RejectedDocsView.HTMLRADIO_REIMPORT_DOCS))
          {
            String[] data = (String[]) _htFormData.GetElement(RejectedDocsView.HTMLRADIO_REIMPORT_DOCS);
            try
            {
              int nCheckBoxValue = XPConvert.ToInteger(data[0]);
              if (0 == nCheckBoxValue)
              {
                nCrawlerSettings = nCrawlerSettings & ~PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS;
                } else
              {
                nCrawlerSettings = nCrawlerSettings | PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS;
                }
            }
            catch (Exception e)
            {
              log.Error("CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to get the value of " + RejectedDocsView.HTMLRADIO_REIMPORT_DOCS + ": " + e);
              }
          } else
          {
            nCrawlerSettings = nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS;
            }
          if (!_htFormData.ContainsKey(ImportingDocsView.HTMLCHECKBOX_IMPORT_ONLY_NEW_DOCS))
          {
            m_bImportOnlyNewLinks = false;
          } else
          {
            m_bImportOnlyNewLinks = true;
          }
        }
        ((IPTCrawler) m_ptObject).SetSettings(nCrawlerSettings);
      }
      // olegs - added
      if (_htFormData.ContainsKey(CrawlerTagView.HTMLTEXT_CRAWLERTAG))
      {
        String[] data = (String[]) _htFormData.GetElement(CrawlerTagView.HTMLTEXT_CRAWLERTAG);
        try
        {
          String tag = data[0];
          if (tag == null)
          {
            tag = "";
          }
          ((IPTCrawler) m_ptObject).SetCrawlerTag(tag);
        }
        catch (Exception e)
        {
          log.Error("CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to set the new Crawler settings: " + e);
          }
      }
      // and that's all??
      // end
      /* Now, get the thread configuration. Set the numbers of theads that fetch documents and threads that
       * process(index, set properties, set Acl's , etc) the nodes.
       */
       
      IPTCrawlerConfig crawlConfig = ((IPTCrawlerManager) m_Session.GetCrawlers()).GetCrawlerConfig();
      /* Set the maximum number of pulling(fetching) threads */
      if (_htFormData.ContainsKey(CrawlerThreadConfigView.HTMLTEXT_NUM_PULL_THREADS))
      {
        try
        {
          String[] data = (String[]) _htFormData.GetElement(CrawlerThreadConfigView.HTMLTEXT_NUM_PULL_THREADS);
          IXPPropertyBag crawlRuntimeConfig = ((IPTCrawler) m_ptObject).GetCrawlerRuntimeConfiguration();
          String strNumPullThreads = data[0];
          if (strNumPullThreads != null && strNumPullThreads.Length > 0)
          {
            int numPullThreads = XPConvert.ToInteger(strNumPullThreads);
            if (crawlRuntimeConfig == null)
            {
              crawlRuntimeConfig = PortalObjectsFactory.CreatePropertyBag();
              }
            //make sure the value is in config-allowable range
            int minimumAllowed = crawlConfig.getMinPullingThreads();
            int maximumAllowed = crawlConfig.getMaxPullingThreads();
            //make sure the value is in config-allowable range
            if (numPullThreads < minimumAllowed)
            {
              RaiseError(m_asOwner.GetString(2914, "ptmsgs_portaladminmsgs") + "cannot be set below " + minimumAllowed);
              numPullThreads = minimumAllowed;
              nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            } else
            if (numPullThreads > maximumAllowed)
            {
              RaiseError(m_asOwner.GetString(2914, "ptmsgs_portaladminmsgs") + "cannot be set above " + maximumAllowed);
              numPullThreads = maximumAllowed;
              nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            }
            crawlRuntimeConfig.Write(PT_CRAWL_INFO.MAX_NUMBER_PULLING_THREADS,
             numPullThreads);
          } else
          {
            crawlRuntimeConfig.Write(PT_CRAWL_INFO.MAX_NUMBER_PULLING_THREADS,
             crawlConfig.getDefaultPullingThreads());
          }
          ((IPTCrawler) m_ptObject).SetCrawlerRuntimeConfiguration(crawlRuntimeConfig);
          }
        catch (XPFormatException xfe)
        {
          RaiseError("Invalid parameter for " + m_asOwner.GetString(2914,
           "ptmsgs_portaladminmsgs"));
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
        catch (Exception e)
        {
          log.Error(e, "CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to set the new value for the number of pulling threads: ");
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
      }
      /* now set the maximum namber of processing threads */
      if (_htFormData.ContainsKey(CrawlerThreadConfigView.HTMLTEXT_NUM_PROCESS_THREADS))
      {
        try
        {
          String[] data = (String[]) _htFormData.GetElement(CrawlerThreadConfigView.HTMLTEXT_NUM_PROCESS_THREADS);
          IXPPropertyBag crawlRuntimeConfig = ((IPTCrawler) m_ptObject).GetCrawlerRuntimeConfiguration();
          String strNumProcessinglThreads = data[0];
          if (strNumProcessinglThreads != null && strNumProcessinglThreads.Length > 0)
          {
            int numProccessThreads = XPConvert.ToInteger(strNumProcessinglThreads);
            if (crawlRuntimeConfig == null)
            {
              crawlRuntimeConfig = PortalObjectsFactory.CreatePropertyBag();
              }
            int minimumAllowed = crawlConfig.getMinProcessingThreads();
            int maximumAllowed = crawlConfig.getMaxProcessingThreads();
            //make sure the value is in config-allowable range
            if (numProccessThreads < minimumAllowed)
            {
              RaiseError(m_asOwner.GetString(2915, "ptmsgs_portaladminmsgs") + "cannot be set below " + minimumAllowed);
              numProccessThreads = minimumAllowed;
              nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            } else
            if (numProccessThreads > maximumAllowed)
            {
              RaiseError(m_asOwner.GetString(2915, "ptmsgs_portaladminmsgs") + "cannot be set above " + maximumAllowed);
              numProccessThreads = maximumAllowed;
              nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            }
            crawlRuntimeConfig.Write(PT_CRAWL_INFO.MAX_NUMBER_PROCESSING_THREADS,
             numProccessThreads);
          } else
          {
            crawlRuntimeConfig.Write(PT_CRAWL_INFO.MAX_NUMBER_PROCESSING_THREADS,
             crawlConfig.getDefaultProcessingThreads());
          }
          ((IPTCrawler) m_ptObject).SetCrawlerRuntimeConfiguration(crawlRuntimeConfig);
          }
        catch (XPFormatException xfe)
        {
          RaiseError("Invalid parameter for " + m_asOwner.GetString(2915,
           "ptmsgs_portaladminmsgs"));
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
        catch (Exception e)
        {
          log.Error(e, "CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to set the new value for the number of processing threads: ");
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to init the Document Type Map page.
    /// </summary>
    private void StartGbDocTypeList()
    {
      GbDocTypeListModel myGbDocTypeModel;
      IPTDocumentTypeMap ptDocTypeMap = ((IPTCrawler) m_ptObject).GetDocumentTypeMap();
      IASQueryResult qrSections = new ASQueryResultWrapper(ptDocTypeMap.GetSections());
      m_nDocMapSectionCount = qrSections.GetCount();
      ((CrawlerEditorAS) m_asOwner).RegisterClassesForDocumentType(m_nDocMapSectionCount);
      for (int i = 0;i < m_nDocMapSectionCount;i++)
      {
        myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP + i);
        String strSectionName = (String) qrSections.GetFields(i, PT_PROPIDS.PT_PROPID_DTMSECTION_NAME);
        myGbDocTypeModel.InitializeGbDocTypeList(ptDocTypeMap, i, strSectionName);
        myGbDocTypeModel.SetFolderID(GetFolderID());
      }
    }
    
    /// <summary>
    /// Helper method to set "apply to existing cards" value.
    /// </summary>
    private void PutApplyExisting(XPHashtable _htFormData)
    {
      if (_htFormData.ContainsKey(ExistingCardsView.HTMLCHECKBOX_APPLYTOEXISTING))
      {
        m_bRefreshExistingCards = true;
      } else
      {
        m_bRefreshExistingCards = false;
      }
    }
    
    /// <summary>
    /// Helper method to actually apply the refresh settings to existing cards.
    /// </summary>
    private void ApplyRefreshSettingsToExistingCards()
    {
      try
      {
        IPTCardRefreshInfo ptCardRefreshInfo = (IPTCardRefreshInfo) (PortalObjectsFactory.CreateCardRefreshInfo());
        LinkSettingsPlugInModel myModel = (LinkSettingsPlugInModel) m_asOwner.GetModel(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LINK_SETTINGS);
        ptCardRefreshInfo.SetCheckLinkOnly(myModel.GetCheckLinkOnly());
        ptCardRefreshInfo.SetCardRefreshRate(myModel.GetRefreshUnits(), myModel.GetRefreshValue());
        ptCardRefreshInfo.SetCardMissingDocumentDeletionDelay(myModel.GetBrokenLinksDeleteUnits(),
         myModel.GetBrokenLinksDeleteValue());
        ptCardRefreshInfo.SetCardExpirationDate(CalculateDateFromInterval(myModel.GetExpireAfterUnits(),
         myModel.GetExpireAfterValue()));
        ptCardRefreshInfo.SetCardNextRefreshDate(CalculateDateFromInterval(myModel.GetRefreshUnits(),
         myModel.GetRefreshValue()));
        IPTCardRefreshAgent ptCardRefreshAgent = (IPTCardRefreshAgent) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_CARD_REFRESH_AGENT,
         false);
        IPTCardRefreshAdmin ptCardRefreshAdmin = (IPTCardRefreshAdmin) ptCardRefreshAgent.GetInterfaces("IPTCardRefreshAdmin");
        ptCardRefreshAdmin.SetRefreshInfo(PT_CLASSIDS.PT_CRAWLER_ID, m_nObjectID,
         ptCardRefreshInfo);
      }
      catch (Exception e)
      {
        log.Error("CrawlerModel::SaveAdvSettingsPage The following exception happened " + "when trying to set the new Crawler settings: " + e);
        }
    }
    
    /// <summary>
    /// Helper method to calculate the next action date from the present time.
    /// </summary>
    private XPDateTime CalculateDateFromInterval(int nUnits, int nInterval)
    {
      XPDateTime dtLastDate = new XPDateTime();
      XPCalendar xpcDateNext = XPCalendar.GetInstance();
      int units = 0;
      switch (nUnits){
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_ANNUALY:
      units = XPCalendar.YEAR;
      break;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY:
      units = XPCalendar.MONTH;
      break;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY:
      units = XPCalendar.WEEK_OF_YEAR;
      break;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY:
      units = XPCalendar.DATE;
      break;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY:
      units = XPCalendar.HOUR;
      break;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY:
      units = XPCalendar.MINUTE;
      break;
      }
      if (0 == units)
      {
        return null;
      }
      xpcDateNext.SetTime(dtLastDate);
      xpcDateNext.Add(units, nInterval);
      XPDateTime dtNextDate = xpcDateNext.GetTime();
      return dtNextDate;
    }
    
    /// <summary>
    /// Helper method to raise an error
    /// </summary>
    /// <param name="strError">- Error message</param>
    /// <param name="strError">- Extended error message</param>
    public virtual void RaiseError(String strError, String strExtended)
    /*"borrowed" from DirModel */
    {
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       strError, strExtended);
      myError.SetActivitySpace(m_asOwner.GetName());
      myError.SetDisplayOnSeparatePage(false);
      myError.SetClearWithActivitySpaceChange(true);
      myError.SetImmediateClear(false);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
    
    /// <summary>
    /// Helper method to raise an error
    /// </summary>
    /// <param name="strError">- Error message</param>
    public virtual void RaiseError(String strError)
    /*"borrowed" from DirModel */
    {
      RaiseError(strError, strError);
    }
  }
}