using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using IPTCrawler=com.plumtree.server.IPTCrawler;
using PT_CRAWL_INFO=com.plumtree.server.PT_CRAWL_INFO;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <author>Oleg Sinitsin</author>
  public class CrawlerThreadConfigView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     typeof(CrawlerThreadConfigView));
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CrCrawlerThreadConfig";
    public const String HTMLTEXT_NUM_PULL_THREADS = "in_tx_PullingThreads";
    public const String HTMLTEXT_NUM_PROCESS_THREADS = "in_tx_ProcessingThreads";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CrawlerThreadConfigView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      HTMLSpan mySpan;
      IXPPropertyBag crawlerRuntimeConfig = ((ICrawlerModelRO) m_model).GetRuntimeConfiguration();
      String pullingTreads = crawlerRuntimeConfig.ReadAsString(PT_CRAWL_INFO.MAX_NUMBER_PULLING_THREADS);
      String processingTreads = crawlerRuntimeConfig.ReadAsString(PT_CRAWL_INFO.MAX_NUMBER_PROCESSING_THREADS);
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2913,
         "ptmsgs_portaladminmsgs")));
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        /* add the pulling threads config number */
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("150");
        myCell.SetVAlign("top");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2914, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLTEXT_NUM_PULL_THREADS,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetSize(2);
        myInput.SetMaxLength(2);
        myInput.SetValue(pullingTreads);
        /* add processing threads number */
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("150");
        myCell.SetVAlign("top");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2915, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLTEXT_NUM_PROCESS_THREADS,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetSize(2);
        myInput.SetMaxLength(2);
        myInput.SetValue(processingTreads);
      }
      catch (Exception e)
      {
        log.Error(e, "Display() : The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1796, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}