using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <summary>
  /// This DP displays the Views for the document type page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class DocTypeDP : EditorDP
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CrDocType";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(247, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2467, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      ICrawlerModelRO myModel = (ICrawlerModelRO) ((EditorAS) m_asOwner).GetModel(((EditorAS) m_asOwner).m_strModelName);
      int nDocTypeSectionCount = myModel.GetDocMapSectionCount();
      for (int i = 0;i < nDocTypeSectionCount;i++)
      {
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP + i)).Display());
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      ICrawlerModelRO myModel = (ICrawlerModelRO) ((EditorAS) m_asOwner).GetModel(((EditorAS) m_asOwner).m_strModelName);
      int nDocTypeSectionCount = myModel.GetDocMapSectionCount();
      for (int i = 0;i < nDocTypeSectionCount;i++)
      {
        myScripts.AddInnerHTMLElement(m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP + i).DisplayJavascript());
        }
      return myScripts;
    }
  }
}