using System;
// Plumtree Server
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.crawler
{
  /// <summary>
  /// View for the Rejected Documents section.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class RejectedDocsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.crawler.RejectedDocsView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CrRejectedDocs";
    
    /// <summary>
    /// HTML Object name: re-import docs radio button 
    /// </summary>
    public const String HTMLRADIO_REIMPORT_DOCS = "in_ra_ReImportDocs";
    
    /// <summary>
    /// HTML Object name: clear history button 
    /// </summary>
    public const String HTMLBUTTON_CLEAR_REJ_HISTORY = "in_bu_ClearHistory";
    
    /// <summary>
    /// HTML Object name: Rejected Documents radio button 
    /// </summary>
    public const String HTMLRADIO_REJECTED_DOCS = "in_ra_RejectedDocs";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RejectedDocsView();
    }
    
    /// <summary>
    /// Returns the HTML for this View.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      HTMLSpan mySpan;
      int nCrawlerSettings = ((ICrawlerModelRO) m_model).GetCrawlerSettings();
      bool bSupportMirroring = ((ICrawlerModelRO) m_model).GetSupportMirroring();
      int nTaxSettings = ((ICrawlerModelRO) m_model).GetTaxSettings();
      int nEditorType = ((ICrawlerModelRO) m_model).GetEditorType();
      bool bHeaderSet = false;
      try
      {
        /* Defualt Rejected Documents (moved from DefaultConfView.java) */
        if ((!bSupportMirroring) || (0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR & nCrawlerSettings)))
        {
          /* set the header */
          result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(268,
           "ptmsgs_portaladminmsgs")));
          bHeaderSet = true;
          myTable = new HTMLTable();
          result.AddInnerHTMLElement(myTable);
          myTable.SetWidth("100%");
          myTable.SetBorder("0");
          myTable.SetCellPadding("5");
          myTable.SetCellSpacing("0");
          // 1st Row - when Rejected documents are found
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          // 1st cell - instruction text
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("150");
          myCell.SetNoWrap(true);
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(2592, "ptmsgs_portaladminmsgs"));
          // 2nd cell - radio buttons
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("100%");
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_REJECTED_DOCS,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
          myInput.SetValue("0");
          if (0 != (PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_PUT_REJECTED_CARDS_IN_UNCLASSIFIED & nTaxSettings))
          {
            myInput.SetChecked(true);
          }
          myCell.AddInnerHTMLString(m_asOwner.GetString(2593, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(new HTMLBr());
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_REJECTED_DOCS,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
          myInput.SetValue("1");
          if (0 == (PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_PUT_REJECTED_CARDS_IN_UNCLASSIFIED & nTaxSettings))
          {
            myInput.SetChecked(true);
          }
          myCell.AddInnerHTMLString(m_asOwner.GetString(2594, "ptmsgs_portaladminmsgs"));
          }
        /* Rejected Documents History
         * The following View is in Edit mode only
         */
         
        if ((EditorStartControl.EDITOR_START_FLAG_EDIT == nEditorType) && (0 == (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR)))
        {
          /* set header if not set */
          if (!bHeaderSet)
          {
            result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(268,
             "ptmsgs_portaladminmsgs")));
          }
          myTable = new HTMLTable();
          result.AddInnerHTMLElement(myTable);
          myTable.SetWidth("100%");
          myTable.SetBorder("0");
          myTable.SetCellPadding("5");
          myTable.SetCellSpacing("0");
          // 1st Row - When revisting rejected docs
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          // 1st cell - instruction text
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("150");
          myCell.SetNoWrap(true);
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(2591, "ptmsgs_portaladminmsgs"));
          // 2nd cell - radio buttons
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("100%");
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_REIMPORT_DOCS,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
          myInput.SetValue("0");
          if (0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS & nCrawlerSettings))
          {
            myInput.SetChecked(true);
          }
          myCell.AddInnerHTMLString(m_asOwner.GetString(2596, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(new HTMLBr());
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_REIMPORT_DOCS,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
          myInput.SetValue("1");
          if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS & nCrawlerSettings))
          {
            myInput.SetChecked(true);
          }
          myCell.AddInnerHTMLString(m_asOwner.GetString(2594, "ptmsgs_portaladminmsgs"));
          /* clear rejection history button */
          myCell.AddInnerHTMLString(SPACE);
          myCell.AddInnerHTMLString(SPACE);
          myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLEAR_REJ_HISTORY,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          myInput.SetValue(m_asOwner.GetString(2595, "ptmsgs_portaladminmsgs"));
          myInput.SetOnClick("ConfirmRejectionHistory();");
        }
      }
      catch (Exception e)
      {
        log.Error(e, "RejectedDocsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(272, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns Java Script for that Section.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript;
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        myScript = new HTMLScript("text/javaScript");
        if (((CrawlerModel) m_model).m_nRejectionCards > 0)
        {
          sb.Append("alert(\"" + XPResourceManager.FormatMessage(m_asOwner.GetString(273,
           "ptmsgs_portaladminmsgs"), "" + ((CrawlerModel) m_model).m_nRejectionCards + "") + "\");\n");
          ((CrawlerModel) m_model).m_nRejectionCards = 0;
        }
        sb.Append("function ConfirmRejectionHistory()\n");
        sb.Append("{\n");
        sb.Append("  if (confirm(\"" + m_asOwner.GetString(2156, "ptmsgs_portaladminmsgs") + "\"))\n");
        sb.Append("  {\n");
        sb.Append("    postToSelf(" + CrawlerRepostControl.POSTTOSELF_ACTION_CLEAR_REJECTION_HISTORY + ");\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "RejectedDocsView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException(m_asOwner.GetString(274, "ptmsgs_portaladminmsgs"),
         e);
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}