using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.admin.editors.datasource
{
  /// <summary>
  /// This class contains the common model elements for datasources.
  /// </summary>
  /// <author>JohnH</author>
  public abstract class DSModel : ObjEditorModel,IDSModelRO
  {
    //Member Variables
    protected int m_intURLType;
    protected int m_intWebServiceID = 0;
    
    /// <summary>
    /// This member holds the CLASSID of the object we will be created from. It
    /// can either be the classid for WebServices or for Portlet Templates.
    /// </summary>
    private int m_nCreatorID = -1;
    // An invalid mode. It should never be returned unless this editor is seriously messed up.
    
    /// <summary>
    /// The following static members define the possible modes this editor can be in.
    /// </summary>
    public const int PMODE_INVALID = -1;
    // The mode used when the portlet is being created from scratch.
    public const int PMODE_CREATE = 0;
    // The mode used when we are editing a portlet.
    public const int PMODE_EDIT = 1;
    
    /// <summary>
    /// This member defines the current mode of the PortletEditor (as per the above enumeration);
    /// When this member is changed, we must send an update to all of our pages and views.
    /// </summary>
    private int m_nPMode;
    public DSModel() : base()
    {
      m_intURLType = PT_URL_TYPES.PT_URL_TYPE_DATASOURCE_GENERATED;
      m_nPMode = PMODE_INVALID;
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
    }
    // END ***************** save DP methods *****************
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      //m_intURLType
      try
      {
        ((IPTDataSource) m_ptObject).SetURLType(m_intURLType);
      }
      catch (Exception e)
      {
        throw new XPException(m_asOwner.GetString(281, "ptmsgs_portaladminmsgs"),
         e);
      }
      //m_intWebServiceID
      try
      {
        ((IPTDataSource) m_ptObject).SetWebServiceID(m_intWebServiceID);
      }
      catch (Exception e)
      {
        throw new XPException(m_asOwner.GetString(70, "ptmsgs_provUIWWW"),
         e);
      }
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      // If we are editing an object, gather all the relevant data from the database
      // and populate the member variables.
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        m_nPMode = PMODE_EDIT;
        //m_intURLType
        try
        {
          m_intURLType = ((IPTDataSource) m_ptObject).GetURLType();
        }
        catch (Exception e)
        {
          //				if (bError)
          //				{
          //					XPStringBuilder sb = new XPStringBuilder(200);
          //
          //					sb.Append("SubPortalModel::DoTaskOnStartEditor ")
          //					.Append(m_asOwner.GetString(282, "ptmsgs_portaladminmsgs"))
          //					.Append("The following exception occured: ").Append(e);
          //					myLogger.Error(sb.ToString());
          //				}
          throw new XPException(m_asOwner.GetString(282, "ptmsgs_portaladminmsgs"),
           e);
        }
        //m_intWebServiceID
        try
        {
          m_intWebServiceID = ((IPTDataSource) m_ptObject).GetWebServiceID();
          }
        catch (Exception e)
        {
          throw new XPException(m_asOwner.GetString(85, "ptmsgs_provUIWWW"),
           e);
        }
      } else
      {
        m_nPMode = PMODE_CREATE;
      }
      //Initialize the web service picker
      //		StartWebServiceList();
      // set web service id
      ((DataSourceSelectWebServiceModel) m_asOwner.GetModel(DSEditorAS.strSelectWSModel)).InitPModel((IPTDataSource) m_ptObject);
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        // no security page when creating
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
    }
    //	public void StartWebServiceList()
    //	{
    //		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(DSEditorAS.STR_MVC_STORAGE_NAME_SELECT_PTOBJECT);
    //
    //		// Initialize the Select PTObject list.
    //		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(
    //				116, "ptmsgs_provUIWWW"),
    //
    //		m_asOwner.GetString(117, "ptmsgs_provUIWWW"), PTImageType.ICON_WEB_SERVICE,
    //
    //		m_asOwner.GetString(118, "ptmsgs_provUIWWW"),
    //			new int[] { PT_CLASSIDS.PT_WEBSERVICE_ID }, 3);
    //
    //		//     Use the method below to set the icon to display on each row.
    //		//     (By default there will be no icon.)
    //		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_WEB_SERVICE);
    //		mySelectPTObjectModel.SetTreeMultiSelect(false);
    //		mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(2142,
    //							"ptmsgs_portaladminmsgs"));
    //		mySelectPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(2143,
    //							"ptmsgs_portaladminmsgs"));
    //							
    //		ClassTypeDescManager ptObjDescMgr = PTConfigHelper.GetPTClassTypeDescrManager();
    //
    //		String strCLSID = ((IPTDataSource) m_ptObject).GetDataSourceProviderCLSID();
    //
    //		if ( ptObjDescMgr.GetProviderEnglishNameGivenCLSID(strCLSID).equals("SOAP") )
    //		{
    //			//Make this a read-only list
    //			mySelectPTObjectModel.SetIsListReadOnly(true);
    //		}
    //		
    //		//     Use the method below to set the message and instructions to display when the list is empty.
    //		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(119,
    //				"ptmsgs_provUIWWW"),
    //			m_asOwner.GetString(120, "ptmsgs_provUIWWW"));
    //
    //		Object[][] arrCreateNewInfo = new Object[1][SelectPTObjectModel.CREATE_NEW_COL_MAX];
    //		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_WEBSERVICE_ID);
    //		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ASNAME]	    = CrawlWSWebServiceEditorAS.STR_MVC_CLASS_NAME;
    //
    //		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_LABEL]     = m_asOwner.GetString(121,
    //				"ptmsgs_provUIWWW");
    //		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ICON] = PTImageType.ICON_WEB_SERVICE;
    //
    //		mySelectPTObjectModel.SetEnableCreateNew(arrCreateNewInfo);
    //
    //		if (m_intWebServiceID != 0)
    //		{
    //			// get the name
    //			PTObjectManagerQueryWrapper omqrWebServices = new PTObjectManagerQueryWrapper(m_Session.GetWebServices());
    //			omqrWebServices.QuerySingleObject(m_intWebServiceID);
    //			
    //			if (0 == omqrWebServices.GetCount()) //The web service has been deleted
    //			{
    //				this.SetWebServiceID(0);
    //			}
    //			else
    //			{
    //	
    //				// Initialize the list with preselected objects.
    //				Object[][] oRows = new Object[1][SelectPTObjectModel.EXPLIST_COL_MAX];
    //	
    //				// JH- Set the class ID
    //				oRows[0][SelectPTObjectModel.EXPLIST_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_WEBSERVICE_ID);
    //	
    //				// JH- Set the Object ID
    //				oRows[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(m_intWebServiceID);
    //	
    //				String strObjName = (String) omqrWebServices.GetFields(0,
    //						PT_PROPIDS.PT_PROPID_NAME);
    //	
    //				// JH- Set the Object name
    //				oRows[0][SelectPTObjectModel.EXPLIST_COL_STRING] = strObjName;
    //	
    //				// JH- Then add the array to the list
    //				mySelectPTObjectModel.SetDefaultObjects(oRows);
    //			}
    //		}
    //	}
    
    /// <summary>
    /// Returns the URL type for the data source.  This value is either
    /// PT_URL_TYPES.PT_URL_TYPE_SIMPLE_FIELD_MAPPING or PT_URL_TYPES.
    /// PT_URL_TYPE_DATASOURCE_GENERATED
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetURLType()
    {
      return m_intURLType;
    }
    
    /// <summary>
    /// Sets the URL type for the data source.  This value is either
    /// PT_URL_TYPES. PT_URL_TYPE_SIMPLE_FIELD_MAPPING or PT_URL_TYPES.
    /// PT_URL_TYPE_DATASOURCE_GENERATED
    /// </summary>
    /// <param name="uRLType">The uRLType to set</param>
    public virtual void SetURLType(int uRLType)
    {
      m_intURLType = uRLType;
    }
    
    /// <summary>
    /// Returns the Web Service ID for the data source.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetWebServiceID()
    {
      return m_intWebServiceID;
    }
    
    /// <summary>
    /// Sets the Web Service ID for the data source.
    /// </summary>
    /// <param name="webServiceID">The webServiceID to set</param>
    public virtual void SetWebServiceID(int webServiceID)
    {
      m_intWebServiceID = webServiceID;
    }
    // BEGIN ***************** save DP methods *****************
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public virtual int SaveMainPage(XPHashtable _htFormData)
    {
      String[] data;
      int nPageStatus = ObjEditorRepostControl.PAGE_STATUS_VALID;
      //		((SelectPTObjectModel) m_asOwner.GetModel(DSEditorAS.STR_MVC_STORAGE_NAME_SELECT_PTOBJECT)).SaveSection(_htFormData);
      //Get the Target Site information from the TargetSite and URL Type views
      try
      {
        //Get the URL Type information
        data = (String[]) _htFormData.GetElement(DSURLTypeView.HTMLRADIO_USEGATEWAY);
        if ((null != data) && !(data[0].Equals("")))
        {
          //Set the URL Type
          m_intURLType = XPConvert.ToInteger(data[0]);
        }
      }
      catch (Exception e)
      {
        throw new XPException(m_asOwner.GetString(284, "ptmsgs_portaladminmsgs"),
         e);
      }
      // Get back the web service ID from the select ptobject
      //		PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(DSEditorAS.STR_MVC_STORAGE_NAME_SELECT_PTOBJECT)).GetItems();
      //
      //		if (aSelectPTObjectValues.GetCount() > 0)
      //		{
      //			m_intWebServiceID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(0,
      //					SelectPTObjectModel.EXPLIST_COL_OBJECTID));
      //		}
      //		else
      //		{
      //			m_intWebServiceID = 0;
      //		}
      /* JHQ 021104 - bug 28266: if the gateway is not being used,
       * then it should clear out any prior ws assignment
       */
       
      if (PT_URL_TYPES.PT_URL_TYPE_DATASOURCE_GENERATED != GetURLType())
      {
        if (IsWebServiceRemovable())
        {
          ((DataSourceSelectWebServiceModel) m_asOwner.GetModel(DSEditorAS.strSelectWSModel)).ClearWebService();
          m_intWebServiceID = 0;
        }
      } else
      {
        /* JHQ 021104 - bug 28266: Calling the SaveSection() on the plugin
         * model so that the webservice selected via the tree control is saved
         */
         
        ((DataSourceSelectWebServiceModel) m_asOwner.GetModel(DSEditorAS.strSelectWSModel)).SaveSection(_htFormData);
        }
      //Validate that the user has chosen a web service if the gateway is being used
      if ((0 == m_intWebServiceID) && (PT_URL_TYPES.PT_URL_TYPE_DATASOURCE_GENERATED == GetURLType()))
      {
        nPageStatus = DSRepostControl.PAGE_STATUS_INVALID;
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(104, "ptmsgs_provUIWWW"), m_asOwner.GetString(104,
         "ptmsgs_provUIWWW"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return nPageStatus;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      nPageStatus = SaveMainPage(_htFormData);
      return nPageStatus;
    }
    //	/**
    //	 * Helper method to retrieve the the Web Service ID from the QS.
    //	 *
    //	 * @param _htFormData
    //	 *
    //	 * @return int
    //	 */
    //	private int GetWebServiceIDFromQS(XPHashtable _htFormData) {
    //		int nWebServiceID = -1;
    //
    //		if (!_htFormData.ContainsKey(XUIHelperMethods.QS_XUI_WEBSERVICE_ID)) {
    //			PlumtreeHelpers.SetUIError(
    //				m_asOwner,
    //				Component.Portal_Providers,
    //				"DSModel::GetWebServiceIDFromQS",
    //				null,
    //				false,
    //				UIErrorLevel.SERIOUS,
    //				m_asOwner.GetString(16, "ptmsgs_provUIRAP"));
    //		} else {
    //			String[] data = (String[]) _htFormData.GetElement(XUIHelperMethods.QS_XUI_WEBSERVICE_ID);
    //
    //			try {
    //				nWebServiceID = XPConvert.ToInteger(data[0]);
    //			} catch (Exception e) {
    //				PlumtreeHelpers.SetUIError(
    //					m_asOwner,
    //					Component.Portal_Providers,
    //					"DSModel::GetWebServiceIDFromQS",
    //					e,
    //					false,
    //					UIErrorLevel.SERIOUS,
    //					m_asOwner.GetString(16, "ptmsgs_provUIRAP"));
    //			}
    //		}
    //
    //		return nWebServiceID;
    //	}
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ObjEditorModel#SetMemberVariablesFromQS(XPHashtable)"></seealso>
    public override void SetMemberVariablesFromQS(XPHashtable _htFormData)
    {
      base.SetMemberVariablesFromQS(_htFormData);
      m_nCreatorID = WSModelHelper.GetFormElementInt(_htFormData, "webServiceID",
       -1);
    }
    
    /// <summary>
    /// Returns the nPMode.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetPMode()
    {
      return m_nPMode;
    }
    
    /// <summary>
    /// Returns the creatorID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCreatorID()
    {
      return m_nCreatorID;
    }
    
    /// <summary>
    /// Returns whether the WebService is changeable from the DataSource Editor.
    /// </summary>
    /// <returns>boolean</returns>
    public abstract bool IsWebServiceChangeable();
    
    /// <summary>
    /// Returns whether the WebService is removable from the DataSource Editor.
    /// </summary>
    /// <returns>boolean</returns>
    public abstract bool IsWebServiceRemovable();
  }
}