using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.admin.editors.datasource
{
  /// <author>adolfoc</author>
  public class DataSourceSelectWebServiceModel : EditorHelperModel,IDataSourceSelectWebServiceModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.datasource.DataSourceSelectWebServiceModel");
    public const String STR_MVC_CLASS_NAME = "DataSourceSelectWebServiceModel";
    
    /// <summary>
    /// This member defines a static string used to identify when m_htFormData
    /// has been initialized.
    /// </summary>
    public const String DEFAULTDATA = "Default Data";
    
    /// <summary>
    /// Our DataSource - handed to us in InitPModel
    /// </summary>
    private IPTDataSource m_ptDataSource = null;
    
    /// <summary>
    /// The following member holds a pointer to the Web Service object that
    /// this DataSource depends on. NOTE: The Web Service can change at any
    /// time and is NOT necessarily up-to-date. Do not use this member
    /// directly, but call GetWSObject() to get an up-to-date Web Service.
    /// </summary>
    private IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// This member contains form data sent to this control (used for the Tree control, mostly).
    /// </summary>
    private XPHashtable m_htFormData;
    
    /// <summary>
    /// This member is used in determining whether or not the web service changed - whether
    /// or not we need to apprise our peers of the change.
    /// </summary>
    private int m_nOldWebServiceID = 0;
    public DataSourceSelectWebServiceModel() : base()
    {
      m_htFormData = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DataSourceSelectWebServiceModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()"></seealso>
    public virtual void DoTaskBeforePStore()
    {
      // Web Service Section
      IPTServerContext ptscWS = (IPTServerContext) m_ptWebService.GetInterfaces("IPTServerContext");
      m_ptDataSource.SetWebServiceID(ptscWS.GetObjectID());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnPModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String,String)"></seealso>
    public virtual void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
    {
    }
    // AGC- This model initiates this change - it doesn't consume it.
    
    /// <seealso cref="com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)"></seealso>
    public virtual String GetData(String name)
    {
      String[] values = (String[]) m_htFormData.GetElement(name);
      if (values == null)
      {
        return DEFAULTDATA;
      }
      return values[0];
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Call this method to set the WebServiceObject to a new one.
    /// </summary>
    public virtual IPTWebService GetWSObject()
    {
      return m_ptWebService;
    }
    
    /// <summary>
    /// Returns the name value from m_strWebServiceTreeData.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetWebServiceName()
    {
      if (null == m_ptWebService)
      {
        return null;
      }
      return m_ptWebService.GetLocalizedName();
    }
    
    /// <summary>
    /// Returns the selected web service ID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetWebServiceID()
    {
      return m_nOldWebServiceID;
    }
    
    /// <summary>
    /// Returns the path value from m_strWebServiceTreeData.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetWebServicePath()
    {
      if (null == m_ptWebService)
      {
        return null;
      }
      int nAdminFolderID = m_ptWebService.GetAdminFolderID();
      DSModel mParentModel = (DSModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      IPTSession ptSession = mParentModel.GetPTSession();
      IPTAdminCatalog ptAFCatalog = ptSession.GetAdminCatalog();
      try
      {
        IPTAdminFolder ptAFParent = ptAFCatalog.OpenAdminFolder(nAdminFolderID,
         false);
        String strPath = ptAFParent.GetPath();
        return strPath;
      }
      catch (PTException pte)
      {
        return null;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)"></seealso>
    public virtual void InitPModel(IPTDataSource ptDataSource)
    {
      m_ptDataSource = ptDataSource;
      DSModel mParentModel = (DSModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      int lWebServiceObjectID;
      switch (mParentModel.GetPMode()){
      case DSModel.PMODE_CREATE:
      // AGC- We may have been passed in a WebServiceID by a popup tree when
      // we were created. If so, let's get it and select it.
      int creatorID = mParentModel.GetCreatorID();
      if (creatorID != -1)
      {
        lWebServiceObjectID = creatorID;
        SetWSObject(lWebServiceObjectID);
      }
      break;
      default:
      lWebServiceObjectID = ptDataSource.GetWebServiceID();
      try
      {
        IPTSession ptSession = mParentModel.GetPTSession();
        IPTWebService ptWebServiceToSet = (IPTWebService) ptSession.GetWebServices().Open(lWebServiceObjectID,
         false);
        m_ptWebService = ptWebServiceToSet;
        // Don't forget to update the Old Web service ID.
        m_nOldWebServiceID = lWebServiceObjectID;
      }
      catch (Exception e)
      {
        log.Error(e, "DataSourceSelectWebService::InitPModel Could not retrieve webservice from DataSource. View will be non-read-only.");
        // AGC- We only force writable if (for some reason) the
        // WebService could not be found/set - which might happen if
        // we are imported from a broken object delivery package.
        m_ptWebService = null;
      }
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ISelectWebServiceModelRO#IsWebServiceChangeable()"></seealso>
    public virtual bool IsWebServiceChangeable()
    {
      DSModel mParentModel = (DSModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      return mParentModel.IsWebServiceChangeable();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ISelectWebServiceModelRO#IsWebServiceRemovable()"></seealso>
    public virtual bool IsWebServiceRemovable()
    {
      DSModel mParentModel = (DSModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      return mParentModel.IsWebServiceRemovable();
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromTree()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(DSEditorAS.WSTREE_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(DSEditorAS.WSTREE_SUBSPACE);
          ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList itemList = treeModel.GetSelectedItems();
          if (itemList.GetSize() != 1)
          {
            log.Error("Tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
            }
          TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
          if (item == null)
          {
            log.Error("Tree selected item null");
          } else
          {
            SetWSObject(item.m_nObjectID);
          }
        }
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error RefreshItemFromTree.");
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      if (IsWebServiceChangeable())
      {
        // Store our form data for later use - especially for use in the tree control.
        int nSize = _htFormData.GetSize();
        IXPEnumerator xpKeys = _htFormData.GetKeys();
        for (int i = 0;i < nSize;i++)
        {
          xpKeys.MoveNext();
          m_htFormData.PutElement((String) xpKeys.GetCurrent(), (String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
          }
        RefreshItemFromTree();
        if (null != m_ptWebService)
        {
          return RepostControl.PAGE_STATUS_VALID;
        } else
        {
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, m_asOwner.GetString(594, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(594,
           "ptmsgs_portaladminmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          return RepostControl.PAGE_STATUS_INVALID;
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// This method clears the selected items from the tree.
    /// </summary>
    public virtual void ClearWebService()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(DSEditorAS.WSTREE_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(DSEditorAS.WSTREE_SUBSPACE);
          ATreeModel treeModel = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
          treeModel.ClearSelectedItems();
        }
        m_ptWebService = null;
        m_nOldWebServiceID = 0;
        DSModel mParentModel = (DSModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
        mParentModel.SetWebServiceID(0);
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error ClearRemoteServer.");
      }
    }
    
    /// <summary>
    /// Call this method to set the WebServiceObject to a new one.
    /// Returns true if the update was successful AND the webservice was changed.
    /// Returns false if the update failed OR the new Webservice was identical to
    /// the existing web service.
    /// </summary>
    private bool SetWSObject(int nObjectID)
    {
      DSModel mParentModel = (DSModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      if (0 >= nObjectID)
      {
        m_ptWebService = null;
      }
      bool bUpdated = false;
      try
      {
        // Let's only make the change if necessary
        if (m_nOldWebServiceID != nObjectID)
        {
          // Oh my, it changed.
          IPTSession ptSession = mParentModel.GetPTSession();
          IPTWebService ptWebServiceToSet = (IPTWebService) ptSession.GetWebServices().Open(nObjectID,
           false);
          // MES- CR: Is reinitialization of Portlets supported?
          // AGC- Yes. Specifically allowed so that we can do this.
          //				m_ptDataSource.SetProviderCLSID(strProviderID);
          m_ptWebService = ptWebServiceToSet;
          // Don't forget to update the Old Web service ID.
          m_nOldWebServiceID = nObjectID;
          mParentModel.SetWebServiceID(nObjectID);
          bUpdated = true;
        }
      }
      // We must tell our peers of the change. It may have significant consequences.
      //				mParentModel.UpdatePSubModels();
      catch (Exception e)
      {
        log.Error(e, "DataSourceSelectWebServiceModel::GetWSObject - Unable to change Web Service object. Continuing with existing Web Service (which may be null): " + e.Message);
        }
      return bUpdated;
    }
  }
}