using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.defaultprofile
{
  /// <summary>
  /// File: EditDefaultProfileModel.java
  /// ----------------------------------
  /// Helper methods to determine if we are currently editing a default profile
  /// can be found in PlumtreeHelpers.
  /// </summary>
  /// <author>NaveenP</author>
  public class EditDefaultProfileModel : IRepostModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.defaultprofile.EditDefaultProfileModel");
    public const String STR_MVC_CLASS_NAME = "EditDefaultProfile";
    
    /// <summary>
    /// Attributes to be stored on the persistent subsession 
    /// </summary>
    private const String STR_OLDSESSION_ATT = "OldSession";
    private const String STR_COOKIE_ACCESS_STYLE = "CookieAccessStyle";
    private const String STR_PREV_URL_ATT = "EditProfilePrevURL";
    
    /// <summary>
    /// these need to be nulled out after execution 
    /// </summary>
    private IXPRequest m_xpRequest = null;
    private IWebData m_WebData = null;
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner = null;
    
    /// <summary>
    /// Default URL for default profile user
    /// </summary>
    private ASURL m_DefaultPageURL;
    
    /// <summary>
    /// Session 
    /// </summary>
    private IPTSession m_ptSession;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
      // null out XPRequest & IWebData
      m_xpRequest = null;
      m_WebData = null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new EditDefaultProfileModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public virtual void Finish()
    {
      try
      {
        // Restore the original session with locale and timezone
        m_ptSession = (IPTSession) m_asOwner.GetPersistentSubSession().GetAttribute(STR_OLDSESSION_ATT);
        // Restore the login cookie's access style to original state.
        SetCookieAccessStyle(XPConvert.ToString(m_asOwner.GetPersistentSubSession().GetAttribute(STR_COOKIE_ACCESS_STYLE)));
        }
      catch (Exception e)
      {
        log.Error(e, "Error switching back to admin user");
        return;
      }
      LoginResult loginResult = LoginHelper.INSTANCE.AttemptLogin(m_ptSession,
       m_asOwner, m_xpRequest, m_WebData);
      if (!loginResult.m_bSuccess)
      {
        log.Error("Error switching back to admin user: " + loginResult.m_strError);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, loginResult.m_strError, loginResult.m_strError);
        myError.SetActivitySpace(m_asOwner.GetName());
        myError.SetClearWithActivitySpaceChange(true);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return;
      }
      // Remove the flag to indicate that we are no longer editing a default profile
      m_asOwner.GetPersistentSubSession().RemoveAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG);
      log.Info("Default Profile editor finished, restoring old session.");
      }
    
    /// <returns>ASURL</returns>
    public virtual ASURL GetDefaultURL()
    {
      return m_DefaultPageURL;
    }
    ///////////////////////////////////////
    // Read only methods from IModelRO
    ///////////////////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModelRO#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public virtual Redirect GetRedirectAfterFinish()
    {
      // This is the URL before this EditDefaultProfile editor starts; 
      // now we want to return to it
      String prevURL = (String) m_asOwner.GetPersistentSubSession().GetAttribute(STR_PREV_URL_ATT);
      bool bInvalidPrevURL = false;
      if (null == prevURL)
      {
        bInvalidPrevURL = true;
      } else
      {
        // Check if no query string in the URL (maybe the case due to javascript in
        // parent pop-up window etc)
        int qsStart = XPStringUtility.IndexOf(prevURL, '?');
        if (-1 == qsStart)
        {
          bInvalidPrevURL = true;
        } else
        {
          if ((prevURL.Length - 1) == qsStart)
          {
            // no query string after "?"
            bInvalidPrevURL = true;
          }
        }
      }
      if (bInvalidPrevURL)
      {
        ASURL asurl = new ASURL(m_asOwner);
        asurl.SetLinkGetSpaceIfCached(ObjMgrAS.STR_MVC_CLASS_NAME, m_asOwner);
        prevURL = asurl.GetURLAsString();
      } else
      {
        // remove the URL from the persistent sub session (no longer needed)
        m_asOwner.GetPersistentSubSession().RemoveAttribute(STR_PREV_URL_ATT);
        }
      Redirect redirect = new Redirect();
      redirect.SetLinkGetCachedSpace(m_asOwner);
      redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      ClosePopUpDP closePopupDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      closePopupDP.SetToClose(false);
      HTMLScript script = new HTMLScript("text/javaScript");
      try
      {
        script.AddInnerHTMLString("parent.window.location=\'" + prevURL + "\';");
        }
      catch (Exception e)
      {
        log.Error(e, e.Message);
      }
      closePopupDP.SetScript(script);
      return redirect;
    }
    
    /// <returns></returns>
    public virtual IPTSession GetSession()
    {
      return m_ptSession;
    }
    
    /// <returns>String</returns>
    public virtual String GetUserName()
    {
      return m_ptSession.GetSessionInfo().GetCurrentUserName();
    }
    /////////////////////////
    // Methods from IModel
    /////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) parent.GetUserSession();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual void SetHTTPItems(IXPRequest request, IWebData webdata)
    {
      m_xpRequest = request;
      m_WebData = webdata;
    }
    
    /// <param name="nUserID"></param>
    /// <throws>Exception</throws>
    public virtual void SetUser(int nUserID)
    {
      // Backup the previous URL (to return to when this editor finishes)
      // Note that we need the actual previous URL; parent space alone is not sufficient
      // as we do not have the actual Admin folder ID needed by the parent space, which
      // is ObjMgr (in our case of EditDefaulProfile space), and AS Cache is cleared during
      // user impersonation.
      String strPreviousRequestURL = (String) m_asOwner.GetSubSession().GetAttribute(ASConstants.PREVIOUS_REQUEST_URL);
      if (null != strPreviousRequestURL)
      {
        m_asOwner.GetPersistentSubSession().SetAttribute(STR_PREV_URL_ATT,
         strPreviousRequestURL);
      }
      // Backup the old session for the admin user
      m_asOwner.GetPersistentSubSession().SetAttribute(STR_OLDSESSION_ATT,
       m_ptSession);
      // Switch session
      m_ptSession = m_ptSession.ImpersonateUser(nUserID);
      // When editing default profiles, we want to use the user access 
      // style.  Since some methods retrieve the style from the login
      // cookie, we want to temporarily clear the access style.  Once 
      // we're done editing, we'll restore the access style.
      m_asOwner.GetPersistentSubSession().SetAttribute(STR_COOKIE_ACCESS_STYLE,
       GetCookieAccessStyle());
      SetCookieAccessStyle(null);
      // Set a flag to indicate that we are in the default profile editor mode
      // This flag needs to be set before we attempt login so the login process knows
      // that this is a default profile user and needs to be treated differently.
      // (e.g. locale USE_BROWSER and USE_DEFAULT settings shouldn't get converted into real
      // locales in the DB).
      m_asOwner.GetPersistentSubSession().SetAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG,
       "");
      LoginResult loginResult = LoginHelper.INSTANCE.AttemptLogin(m_ptSession,
       m_asOwner, m_xpRequest, m_WebData);
      if (loginResult.m_bSuccess)
      {
        SetDefaultURL();
      } else
      {
        //	login failed
        log.Error("Edit Default Profile failed:" + loginResult.m_strError);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, loginResult.m_strError, loginResult.m_strError);
        myError.SetActivitySpace(m_asOwner.GetName());
        myError.SetClearWithActivitySpaceChange(true);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        // Remove the flag to indicate that we are no longer editing a default profile
        m_asOwner.GetPersistentSubSession().RemoveAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG);
        }
    }
    private void SetDefaultURL()
    {
      m_DefaultPageURL = (ASURL) LoginHelper.INSTANCE.GetDefaultPageRedirect(new ASURL(m_asOwner),
       GetSession(), m_asOwner);
    }
    private String GetCookieAccessStyle()
    {
      XPCookie[] cookies = null;
      if (m_xpRequest != null)
      {
        cookies = m_xpRequest.GetCookies();
      }
      if (cookies != null)
      {
        XPCookie currentCookie;
        int nNumCookies = cookies.Length;
        log.Debug("GetCookieAccessStyle() - got " + nNumCookies + " cookies!");
        for (int i = 0;i < nNumCookies;i++)
        {
          currentCookie = cookies[i];
          if (PTPersonalSettingsHelper.ACCESS_STYLE_COOKIE_NAME.Equals(currentCookie.GetName()))
          {
            //	Retrieve access style cookie.					
            log.Debug("GetCookieAccessStyle() - Found an access style cookie.");
            return currentCookie.GetValue();
          }
        }
      }
      log.Debug("GetCookieAccessStyle() - Access style cookie not found, returning null.");
      return null;
    }
    private void SetCookieAccessStyle(String strAccessStyle)
    {
      XPCookie[] cookies = null;
      if (m_xpRequest != null)
      {
        cookies = m_xpRequest.GetCookies();
      }
      if (cookies != null)
      {
        XPCookie currentCookie;
        int nNumCookies = cookies.Length;
        for (int i = 0;i < nNumCookies;i++)
        {
          currentCookie = cookies[i];
          if (PTPersonalSettingsHelper.ACCESS_STYLE_COOKIE_NAME.Equals(currentCookie.GetName()))
          {
            if (null == strAccessStyle)
            {
              currentCookie.SetDeleteCookie();
            } else
            {
              //	Set access style cookie.					
              currentCookie.SetValue(strAccessStyle);
            }
          }
        }
      }
      // we now need to add the cookie in the WebData so that
      // the cookie sticks long term and not just for this 
      // request.
      int iExpMinutes = 500;
      int iExpSeconds = iExpMinutes * 60;
      XPCookie cookie = new XPCookie(PTPersonalSettingsHelper.ACCESS_STYLE_COOKIE_NAME,
       strAccessStyle);
      cookie.SetPath("");
      if (null == strAccessStyle)
      {
        cookie.SetDeleteCookie();
      } else
      {
        cookie.SetExpireTime(iExpSeconds);
      }
      m_WebData.AddCookie(cookie);
    }
  }
}