using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.defaultprofile
{
  /// <summary>
  /// File:EditDefaultProfileTopView.java
  /// -----------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class EditDefaultProfileTopView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.defaultprofile.EditDefaultProfileTopView");
    public const String STR_MVC_CLASS_NAME = "EditDefaultProfileTop";
    
    /// <summary>
    /// Activity Space Owner 
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    protected EditDefaultProfileModel m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new EditDefaultProfileTopView();
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow = new HTMLTableRow();
      HTMLTableCell mainCell;
      HTMLInput mainInput;
      try
      {
        mainRow.SetVAlign(CommonHTMLStrings.CENTER);
        HTMLImg spaceImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
         true, m_asOwner).GetHTMLElement();
        spaceImg.SetWidth(CommonHTMLStrings.TWO);
        spaceImg.SetHeight(CommonHTMLStrings.ONE);
        spaceImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        spaceImg.SetBorder(CommonHTMLStrings.ZERO);
        mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        mainTable.SetCellPadding(CommonHTMLStrings.ZERO);
        mainTable.SetHeight("65");
        mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        mainTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        mainTable.SetCellPadding(CommonHTMLStrings.ZERO);
        mainTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        mainTable.SetBorder(CommonHTMLStrings.ZERO);
        mainTable.AddInnerHTMLElement(mainRow);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetWidth("55%");
        mainCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetAlign(CommonHTMLStrings.CENTER);
        mainCell.SetStyleClass(PTStyleClass.BAN_HEADER);
        mainCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(331,
         "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(m_asModel.GetUserName())));
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetAlign(CommonHTMLStrings.CENTER);
        mainCell.SetStyleClass(PTStyleClass.BAN_HEADER);
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          mainInput = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_Finish",
           m_asOwner.GetString(330, "ptmsgs_portalbrowsingmsgs"));
          mainInput.SetOnClick("postToSelf(" + RepostControl.POSTTOSELF_ACTION_FINISH + ");");
          } else
        {
          mainInput = new HTMLInput(HTMLInputTypes.SUBMIT, RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH,
           m_asOwner.GetString(330, "ptmsgs_portalbrowsingmsgs"));
        }
        mainInput.SetValue(m_asOwner.GetString(329, "ptmsgs_portalbrowsingmsgs"));
        mainInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        mainCell.AddInnerHTMLElement(mainInput);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetWidth("15%");
        mainCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        result.AddInnerHTMLElement(mainTable);
      }
      catch (Exception e)
      {
        log.Error(e, e.Message);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      XPStringBuilder sb = new XPStringBuilder(50);
      HTMLScript myScript = new HTMLScript("text/javaScript");
      try
      {
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, he.Message);
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace space)
    {
      m_asOwner = space;
      m_asModel = (EditDefaultProfileModel) model;
    }
  }
}