using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.admin.editors.defaultprofile
{
  /// <summary>
  /// File: SetEditDefaultProfileControl.java
  /// ----------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SetEditDefaultProfileControl : ILoginControl,IHTTPControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.defaultprofile.SetEditDefaultProfileControl");
    public const String STR_MVC_CLASS_NAME = "SetEditDefaultProfile";
    public const String m_UserID = "EditUserID";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private EditDefaultProfileModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String[] sValues = (String[]) arguments.GetElement(m_UserID);
      if (sValues == null)
      {
        log.Error("could not find user id in query string.");
        return null;
      }
      int nUserID = XPConvert.ToInteger(sValues[0]);
      try
      {
        m_asModel.SetUser(nUserID);
      }
      catch (Exception e)
      {
        log.Warn(e, "Error starting up Profile Edit mode.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        // DCA - redirect to previous space if an exception occurs
        Redirect result = new Redirect();
        // JF- If the parent space is already in the cache, we redirect to it.
        if (null != m_asOwner.GetParentSpace())
        {
          result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
        } else
        // JF- If not, we redirect to a new one.
        {
          result.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
          }
        return result;
      }
      return null;
    }
    
    /// <param name="request"></param>
    /// <param name="webdata"></param>
    public virtual void SetHTTPItems(IXPRequest request, IWebData webdata)
    {
      m_asModel.SetHTTPItems(request, webdata);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SetEditDefaultProfileControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.ILoginControl#DoGetSession()"></seealso>
    public virtual bool DoGetSession()
    {
      // The interpreter should ask us for the session.
      return true;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.ILoginControl#GetSession()"></seealso>
    public virtual Object GetSession()
    {
      return m_asModel.GetSession();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (EditDefaultProfileModel) model;
      m_asOwner = space;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.ILoginControl#SetRedirectForUseAfterLogin(Redirect)"></seealso>
    public virtual void SetRedirectForUseAfterLogin(Redirect r)
    {
    }
  }
}