using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.doctype
{
  public class DocTypeEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.doctype.DocTypeEditorAS");
    
    /// <summary>
    /// The unique identifying name for this activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DocTypeEditor";
    
    /// <summary>
    /// The unique identifying name for the multi-column list plug-in 
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_PLUG_IN = "DocTypeMultiColList";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.doctype.DocTypeEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DocTypeEditorAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return (GetString(290, "ptmsgs_portaladminmsgs"));
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2605, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (DocTypeDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (DocTypeRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = DocTypeModel.STR_MVC_CLASS_NAME;
      base.Init();
      //Get the model
      IModel myModel = GetModel(m_strModelName);
      //Register the PTMulticolumnlist for the property map
      //Register the model, view and control for the property map list
      RegisterModel(PTMultiColumnListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_PLUG_IN);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myMultiColumnListModel = GetModel(STR_MVC_STORAGE_NAME_PLUG_IN);
      RegisterView(PTMultiColumnListView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_PLUG_IN,
       myMultiColumnListModel);
      RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_PLUG_IN,
       myMultiColumnListModel);
      // Register DisplayPages
      RegisterPage(new MainDP());
      // Register Views
      RegisterView(GenInfoView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(DocTypeDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(DocTypeRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Default page
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(292, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1803, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 27;
          int iTipId = 28;
          int iSecondaryTipId = 29;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_DocumentType_MainSettings");
      }
    }
  }
}