using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.doctype
{
  public class DocTypeModel : ObjEditorModel,IDocTypeModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.doctype.DocTypeModel");
    
    /// <summary>
    /// The unique identifying name for this activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DocType";
    
    /// <summary>
    /// Number of columns in the multicolumn list 
    /// </summary>
    public const int MAPLIST_NUMCOLUMNS = 3;
    //Zero-based list position for the PT object column
    
    /// <summary>
    /// Position of the PTObject in the multicolumn list 
    /// </summary>
    public const int MAPLIST_PTOBJECTPOSITION = 0;
    public const String _ui_DefaultBlankValue = "";
    private String m_strAccessorCLSID = "";
    //Member variables
    private XPHashtable m_arrAccessors;
    //This is a 2 dim array 0,0=property ID, 1,0=mapped attributes, 2,0 = Default Value, 3,0 = Override Value
    private Object[][] m_arrPropMapInfo;
    private bool m_bFullTextIndex = false;
    public DocTypeModel() : base()
    {
      m_arrAccessors = new XPHashtable();
    }
    
    /// <summary>
    /// Sets the accessorCLSID.
    /// </summary>
    /// <param name="accessorCLSID">The accessorCLSID to set</param>
    public virtual void SetAccessorCLSID(String accessorCLSID)
    {
      m_strAccessorCLSID = accessorCLSID;
    }
    
    /// <summary>
    /// Returns the accessorCLSID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetAccessorCLSID()
    {
      return m_strAccessorCLSID;
    }
    
    /// <summary>
    /// Sets the accessors.
    /// </summary>
    /// <param name="accessors">The accessors to set</param>
    public virtual void SetAccessors(XPHashtable accessors)
    {
      m_arrAccessors = accessors;
    }
    
    /// <summary>
    /// Returns the accessors.
    /// </summary>
    /// <returns>XPHashtable</returns>
    public virtual XPHashtable GetAccessors()
    {
      return m_arrAccessors;
    }
    
    /// <summary>
    /// Sets the fullTextIndex.
    /// </summary>
    /// <param name="fullTextIndex">The fullTextIndex to set</param>
    public virtual void SetFullTextIndex(bool bFullTextIndex)
    {
      m_bFullTextIndex = bFullTextIndex;
    }
    
    /// <summary>
    /// Returns the fullTextIndex.
    /// </summary>
    /// <returns>int</returns>
    public virtual bool GetFullTextIndex()
    {
      return m_bFullTextIndex;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DocTypeModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      IPTDocumentType ptDocumentType = (IPTDocumentType) m_ptObject;
      //m_strAccessorCLSID
      try
      {
        if (null != m_strAccessorCLSID)
        {
          ptDocumentType.SetAccessorCLSID(m_strAccessorCLSID);
        }
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "DocTypeModel::DoTaskBeforeStore", e, false, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(302, "ptmsgs_portaladminmsgs"));
      }
      //m_intFullTextIndex
      try
      {
        ptDocumentType.SetFullTextIndex(m_bFullTextIndex);
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "DocTypeModel::DoTaskBeforeStore", e, false, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(303, "ptmsgs_portaladminmsgs"));
      }
      //m_arrPropMapInfo
      //This is a 2 dim array 0,0=property ID, 1,0=mapped attributes, 2,0 = Default Value, 3,0 = Override Value
      try
      {
        if (null != m_arrPropMapInfo)
        {
          IPTPropertyMap myPropertyMap = ptDocumentType.GetPropertyMap();
          //Clear it before adding back the current values
          myPropertyMap.Clear();
          for (int i = 0;i < m_arrPropMapInfo[0].Length;i++)
          {
            int intProperty = XPConvert.ToInteger(m_arrPropMapInfo[0][i]);
            Object[][] arrFields = PTMultiColumnListModel.ParseFields((String) m_arrPropMapInfo[1][i]);
            //removed null checks that were previously here;  nulls are valid entried to the prop map; fixing bug 37120 -mgs
            myPropertyMap.SetMappedFieldNames(intProperty, arrFields);
            ptDocumentType.SetDefaultValue(intProperty, m_arrPropMapInfo[2][i]);
            ptDocumentType.SetOverrideValue(intProperty, m_arrPropMapInfo[3][i]);
            }
        } else
        {
          ptDocumentType.GetPropertyMap().Clear();
          ptDocumentType.ClearDefaults();
          ptDocumentType.ClearOverrides();
        }
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "DocTypeModel::DoTaskBeforeStore", e, false, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(304, "ptmsgs_portaladminmsgs"));
      }
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      IPTDocumentType ptDocumentType = (IPTDocumentType) m_ptObject;
      //Initialize the multi column lists
      StartPropMapList();
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        //m_strAccessorCLSID
        try
        {
          m_strAccessorCLSID = ptDocumentType.GetAccessorCLSID();
        }
        catch (Exception e)
        {
          PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
           "DocTypeModel::DoTaskOnStartEditor", e, true, UIErrorLevel.SERIOUS,
           m_asOwner.GetString(300, "ptmsgs_portaladminmsgs"));
        }
        //m_intFullTextIndex
        try
        {
          m_bFullTextIndex = ptDocumentType.GetFullTextIndex();
        }
        catch (Exception e)
        {
          PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
           "DocTypeModel::DoTaskOnStartEditor", e, true, UIErrorLevel.SERIOUS,
           m_asOwner.GetString(301, "ptmsgs_portaladminmsgs"));
        }
      } else
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      //m_arrAccessors - populate this regardless of start mode
      try
      {
        ASQueryResultWrapper asqrwAccessors = new ASQueryResultWrapper(((IPTAccessorRegistry) m_Session.OpenRegistry(3)).GetRegisteredAccessors());
        for (int i = 0;i < asqrwAccessors.GetCount();i++)
        {
          m_arrAccessors.PutElement(asqrwAccessors.GetFields(i, PT_PROPIDS.PT_PROPID_AREG_CLSID),
           asqrwAccessors.GetFields(i, PT_PROPIDS.PT_PROPID_AREG_NAME));
        }
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "DocTypeModel::DoTaskOnStartEditor", e, true, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(299, "ptmsgs_portaladminmsgs"));
      }
    }
    
    /// <summary>
    /// Returns the name of the class
    /// </summary>
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SaveMainPage(_htFormData);
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to start the Growable List.
    /// </summary>
    public virtual void StartPropMapList()
    // JH: Initialization function for the property map UI control
    {
      PTMultiColumnListModel myListModel = (PTMultiColumnListModel) m_asOwner.GetModel(DocTypeEditorAS.STR_MVC_STORAGE_NAME_PLUG_IN);
      //Set the number of columns.
      //Login form page
      myListModel.SetNumColumns(MAPLIST_NUMCOLUMNS);
      myListModel.SetIncludePTSelect(true);
      myListModel.SetPTObjectPosition(MAPLIST_PTOBJECTPOSITION);
      String[] arrPropMapSubTitles = new String[MAPLIST_NUMCOLUMNS];
      arrPropMapSubTitles[0] = m_asOwner.GetString(308, "ptmsgs_portaladminmsgs");
      arrPropMapSubTitles[1] = m_asOwner.GetString(309, "ptmsgs_portaladminmsgs");
      arrPropMapSubTitles[2] = m_asOwner.GetString(310, "ptmsgs_portaladminmsgs");
      myListModel.InitializePTMultiColumnList(m_asOwner.GetString(306, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(307, "ptmsgs_portaladminmsgs"), arrPropMapSubTitles,
       PTImageType.ICON_PROPERTY, m_asOwner.GetString(311, "ptmsgs_portaladminmsgs"),
       new int[]{PT_CLASSIDS.PT_PROPERTY_ID}, 1);
      // Use the method below to set the value to populate a newly created input text.
      // (By default it will be a null array, so it MUST be initialized.
      String[] arrPropMapDefaults = new String[MAPLIST_NUMCOLUMNS];
      arrPropMapDefaults[0] = "";
      arrPropMapDefaults[1] = "";
      arrPropMapDefaults[2] = "";
      myListModel.SetDefaultValue(arrPropMapDefaults);
      //Set the icon
      myListModel.SetRowIcon(PTImageType.ICON_PROPERTY);
      myListModel.SetTreeMultiSelect(true);
      myListModel.SetTreeSubTitle(m_asOwner.GetString(2098, "ptmsgs_portaladminmsgs"));
      myListModel.SetTreeTitle(m_asOwner.GetString(2098, "ptmsgs_portaladminmsgs"));
      // JH- Hide some intrinsic properties that cannot be mapped.
      int[][] aHiddenProps = new int[4][];
      for (int j2c_index = 0;j2c_index < 4;j2c_index++)
      {
        aHiddenProps[j2c_index] = new int[2];
      }
      aHiddenProps[0][PTMultiColumnListModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_PROPERTY_ID;
      aHiddenProps[0][PTMultiColumnListModel.HIDE_COL_OBJECTID] = 3;
      aHiddenProps[1][PTMultiColumnListModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_PROPERTY_ID;
      aHiddenProps[1][PTMultiColumnListModel.HIDE_COL_OBJECTID] = 4;
      aHiddenProps[2][PTMultiColumnListModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_PROPERTY_ID;
      aHiddenProps[2][PTMultiColumnListModel.HIDE_COL_OBJECTID] = 5;
      aHiddenProps[3][PTMultiColumnListModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_PROPERTY_ID;
      aHiddenProps[3][PTMultiColumnListModel.HIDE_COL_OBJECTID] = 7;
      myListModel.SetHiddenObjects(aHiddenProps);
      //Set the message and instructions to display when the list is empty.
      myListModel.SetEmptyListMessages(m_asOwner.GetString(312, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(313, "ptmsgs_portaladminmsgs"));
      //Get the name value pairs from the database and populate them in here
      try
      {
        IPTPropertyMap ptMap = ((IPTDocumentType) m_ptObject).GetPropertyMap();
        Object[][] arrProperties;
        arrProperties = (Object[][]) ptMap.GetMappedProperties();
        if (arrProperties[0].Length > 0)
        {
          int intCount = arrProperties[0].Length;
          if (intCount > 0)
          {
            Object[][] oRows = new Object[intCount][];
            for (int j2c_index = 0;j2c_index < intCount;j2c_index++)
            {
              oRows[j2c_index] = new Object[MAPLIST_NUMCOLUMNS + 4];
            }
            String strObjName;
            for (int i = 0;i < intCount;i++)
            {
              // get the name
              PTObjectManagerQueryWrapper omqrProperty = new PTObjectManagerQueryWrapper(m_Session.GetProperties());
              int intObjID = XPConvert.ToInteger(arrProperties[0][i]);
              omqrProperty.QuerySingleObject(intObjID);
              if (1 == omqrProperty.GetCount())
              {
                strObjName = (String) omqrProperty.GetFields(0, PT_PROPIDS.PT_PROPID_NAME);
                } else
              {
                strObjName = m_asOwner.GetString(314, "ptmsgs_portaladminmsgs");
                }
              // Set the class ID
              oRows[i][PTMultiColumnListModel.EXPLIST_COL_CLASSID + MAPLIST_PTOBJECTPOSITION] = PT_CLASSIDS.PT_PROPERTY_ID;
              // Set the Object ID
              oRows[i][PTMultiColumnListModel.EXPLIST_COL_OBJECTID + MAPLIST_PTOBJECTPOSITION] = intObjID;
              // Set the Object name
              oRows[i][PTMultiColumnListModel.EXPLIST_COL_STRING + MAPLIST_PTOBJECTPOSITION] = strObjName;
              // Set the mapped field
              Object[][] arrFieldNames = (Object[][]) ptMap.GetMappedFieldNames(intObjID);
              XPStringBuilder sb = new XPStringBuilder(100);
              for (int j = 0;(arrFieldNames != null) && (j < arrFieldNames[0].Length);
              j++)
              {
                sb.Append((String) arrFieldNames[0][j]);
                if (j < (arrFieldNames[0].Length - 1))
                {
                  sb.Append(", ");
                }
              }
              oRows[i][4] = sb.ToString();
              // Set the default value
              oRows[i][5] = ((IPTDocumentType) m_ptObject).GetDefaultValueAsString(intObjID);
              // Set the override value
              oRows[i][6] = ((IPTDocumentType) m_ptObject).GetOverrideValueAsString(intObjID);
              }
            // Then add the array to the list
            myListModel.SetDefaultObjects(oRows);
          }
        }
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "DocTypeModel::StartPropMapList", e, false, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(305, "ptmsgs_portaladminmsgs"));
      }
    }
    
    /// <summary>
    /// Saves the data on the cookie page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    private int SaveMainPage(XPHashtable _htFormData)
    {
      String[] data;
      int intPageResult = DocTypeRepostControl.PAGE_STATUS_VALID;
      try
      {
        data = (String[]) _htFormData.GetElement(GenInfoView.HTMLSELECT_ACCESSORS);
        if ((null != data) && !(data[0].Equals("")))
        {
          //m_strAccessorCLSID
          m_strAccessorCLSID = data[0];
        }
        data = (String[]) _htFormData.GetElement(GenInfoView.HTMLCHECKBOX_INDEX);
        if ((null != data) && !(data[0].Equals("")))
        {
          //m_intFullTextIndex
          m_bFullTextIndex = XPConvert.ToBoolean(XPConvert.ToInteger(data[0]));
          } else
        {
          m_bFullTextIndex = false;
        }
        //First, save the existing section to the activity space
        ((PTMultiColumnListModel) m_asOwner.GetModel(DocTypeEditorAS.STR_MVC_STORAGE_NAME_PLUG_IN)).SaveSection(_htFormData);
        //Now save the values entered to the property map member variable
        Object[][] arrMappingInfo = ((PTMultiColumnListModel) m_asOwner.GetModel(DocTypeEditorAS.STR_MVC_STORAGE_NAME_PLUG_IN)).GetListValues();
        //m_arrPropMapInfo
        PTGrowableSortedArrayWrapper arrProperties;
        arrProperties = ((PTMultiColumnListModel) m_asOwner.GetModel(DocTypeEditorAS.STR_MVC_STORAGE_NAME_PLUG_IN)).GetItems();
        int intNumProperties = arrProperties.GetCount();
        if (intNumProperties > 0)
        {
          m_arrPropMapInfo = new Object[4][];
          for (int j2c_index = 0;j2c_index < 4;j2c_index++)
          {
            m_arrPropMapInfo[j2c_index] = new Object[intNumProperties];
          }
          for (int i = 0;i < intNumProperties;i++)
          {
            m_arrPropMapInfo[0][i] = arrProperties.GetItem(i, PTMultiColumnListModel.EXPLIST_COL_OBJECTID + MAPLIST_PTOBJECTPOSITION);
            m_arrPropMapInfo[1][i] = (String) arrMappingInfo[0][i];
            //Default value
            if ((null == arrMappingInfo[1][i]) || (arrMappingInfo[1][i].Equals("")))
            {
              m_arrPropMapInfo[2][i] = null;
            } else
            {
              m_arrPropMapInfo[2][i] = (String) arrMappingInfo[1][i];
            }
            //Override value
            if ((null == arrMappingInfo[2][i]) || (arrMappingInfo[2][i].Equals("")))
            {
              m_arrPropMapInfo[3][i] = null;
            } else
            {
              m_arrPropMapInfo[3][i] = (String) arrMappingInfo[2][i];
            }
          }
        } else
        {
          m_arrPropMapInfo = null;
        }
      }
      catch (Exception e)
      {
        intPageResult = DocTypeRepostControl.PAGE_STATUS_INVALID;
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "DocTypeModel::SaveMainPage", e, false, UIErrorLevel.SERIOUS, m_asOwner.GetString(298,
         "ptmsgs_portaladminmsgs"));
      }
      return intPageResult;
    }
  }
}