using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.doctype;
using com.plumtree.portalpages.admin.editors.doctypemapextension;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.doctypemap
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Growable Array.
  /// The Growable Array is a list of input texts.
  /// On add, a new input text populated with the default value
  /// will be added at the bottom of the list.
  /// </summary>
  /// <author>SudhaS</author>
  public class GbDocTypeListModel : ExpListModel,IGbDocTypeListModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeListModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GbDocTypeList";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 3;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_DOCTYPE = 1;
    
    /// <summary>
    /// This column contains the Object IDs.
    /// </summary>
    public const int EXPLIST_COL_IDENTIFIER = 2;
    public const String CURRENTSECTION_ID = "CURRENTSECTION_ID";
    public const String CURRENTGBDOCTYPEMODEL_ID = "CURRENTGBDOCTYPEMODEL_ID";
    
    /// <summary>
    /// This is the String that we doisplay in the list.
    /// E.g.: Object name or folder path.
    /// </summary>
    public const String DOCTYPE_ID = "DOCTYPE_ID";
    public const String DOCTYPE_NAME = "DOCTYPE_NAME";
    public const String ROW_INDEX = "ROW_INDEX";
    
    /// <summary>
    /// Second column: the value of the input text. 
    /// </summary>
    public const int EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT = 1;
    private int m_nFolderID = -1;
    
    /// <summary>
    /// Icon to display on each row, just before the input text. 
    /// </summary>
    protected PTImageType m_imgRowIcon;
    //public static final int EXPLIST_COL_DESCRIPTION = 3;
    //public static final int EXPLIST_COL_URI	= 4;
    
    /// <summary>
    /// This is used on add to populate the input
    /// text of the newly added row.
    /// </summary>
    protected String m_sDefaultValue = "";
    protected String m_strSecondAddLabel = "";
    private IPTDocumentTypeMap m_ptDocTypeMap;
    private XPHashtable[] m_DocTypeTables;
    private int m_nGbDocTypeModelID;
    private PTImageType m_imgAddSecondIcon;
    
    /// <summary>
    /// Adds one row at the bottom of the list and
    /// sets the following values:
    /// First column: m_nNextIndex
    /// Second column: m_sDefaultValue
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      bool bCanAddNewRow = true;
      // JF- Before we add a new row at the end of the list, we check
      // if you don't already have a "new row" in the list.
      // The user doesn't need to have more than one empty row (or row with the default value).
      // JF- Check the array see if we have the default value in it.
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        if (m_sDefaultValue.Equals(m_saData.GetItem(i, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT)))
        {
          // JF- We already have a new row no need to add one more.
          bCanAddNewRow = false;
          break;
        }
      }
      if (bCanAddNewRow)
      {
        AddRowsToList(new String[]{m_sDefaultValue});
      }
    }
    
    /// <summary>
    /// Adds an array of new rows to the list.
    /// </summary>
    /// <param name="_aData"></param>
    public virtual void AddRowsToList(String[] _aData)
    {
      Object[] oRow;
      for (int i = 0;i < _aData.Length;i++)
      {
        oRow = new Object[EXPLIST_COL_MAX];
        oRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
        m_nNextIndex++;
        oRow[EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = _aData[i];
        base.GetItems().AddRow(oRow);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GbDocTypeListModel();
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public virtual void DoTaskOnComeBackFromSubEditor(int _nDPID)
    {
      //int n_GbDocTypeID = ((GbDocTypeMainDP) m_asOwner.GetCurrentPage()).GetGbDocTypeID();
      //if (n_GbDocTypeID == _nGbDocTypeModel) {
      EditorAS myEditorAS;
      GbDocTypeExtModel myGbDocTypeModel;
      Object[] oNewRow;
      int nDocTypeID;
      int nRow;
      String strExtName;
      String strDocTypeName;
      bool bEdit;
      bool bAdded;
      //String strDocTypeName;
      String strSubEditorASName = GbDocTypeExtEditorAS.STR_MVC_CLASS_NAME + m_nGbDocTypeModelID;
      if (m_asOwner.GetSubSpaceExists(strSubEditorASName))
      {
        myEditorAS = (EditorAS) m_asOwner.GetSubSpace(strSubEditorASName);
        myGbDocTypeModel = (GbDocTypeExtModel) myEditorAS.GetModel(myEditorAS.m_strModelName);
        bEdit = myGbDocTypeModel.GetIsEdit();
        nDocTypeID = myGbDocTypeModel.GetDocTypeID();
        strExtName = myGbDocTypeModel.GetExtName();
        strDocTypeName = myGbDocTypeModel.GetDocTypeName();
        nRow = myGbDocTypeModel.GetRow();
        bAdded = myGbDocTypeModel.GetIsAdded();
        if (bAdded)
        {
          SetSingleDocTypeIDToNameMapping(strDocTypeName, nDocTypeID, _nDPID);
          myGbDocTypeModel.SetAdded(false);
        }
        if (!bEdit)
        {
          oNewRow = new Object[EXPLIST_COL_MAX];
          oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
          m_nNextIndex++;
          oNewRow[EXPLIST_COL_DOCTYPE] = nDocTypeID;
          oNewRow[EXPLIST_COL_IDENTIFIER] = strExtName;
          base.GetItems().AddRow(oNewRow);
        } else
        {
          base.GetItems().SetItem(nRow, GbDocTypeListModel.EXPLIST_COL_IDENTIFIER,
           strExtName);
          base.GetItems().SetItem(nRow, GbDocTypeListModel.EXPLIST_COL_DOCTYPE,
           nDocTypeID);
          myGbDocTypeModel.SetEdit(false);
        }
        String strNewSubSpaceKey = strSubEditorASName + nRow;
        m_asOwner.ChangeSubSpaceKey(strSubEditorASName, strNewSubSpaceKey);
        }
      //m_asOwner.DeleteSubSpace(sEditorASName);
      strSubEditorASName = DocTypeEditorAS.STR_MVC_CLASS_NAME + _nDPID;
      if (m_asOwner.GetSubSpaceExists(strSubEditorASName))
      {
        m_asOwner.DeleteSubSpace(strSubEditorASName);
      }
    }
    //}
    
    /// <summary>
    /// This method contains the code to store the Document Type Map.
    /// </summary>
    public virtual void Finish()
    {
      try
      {
        int nSectionID = GetSectionID(m_nGbDocTypeModelID);
        // ***CHANGE_HERE SELECTPTOBJECT*** Here is how you can get back the values from the select ptobject
        PTGrowableSortedArrayWrapper aSelectObjectValues = GetItems();
        Object[][] oRows = new Object[2][];
        for (int j2c_index = 0;j2c_index < 2;j2c_index++)
        {
          oRows[j2c_index] = new Object[aSelectObjectValues.GetCount()];
        }
        for (int i = 0;i < aSelectObjectValues.GetCount();i++)
        {
          oRows[0][i] = aSelectObjectValues.GetItem(i, GbDocTypeListModel.EXPLIST_COL_IDENTIFIER);
          oRows[1][i] = aSelectObjectValues.GetItem(i, GbDocTypeListModel.EXPLIST_COL_DOCTYPE);
          }
        // ***CHANGE_HERE*** Copy the code below to lock, sore and unlock the global object.
        // ***CHANGE_HERE*** Put the code here to set the new settings on the Global Object, before you sore it.
        m_ptDocTypeMap.SetMappings(nSectionID, oRows);
      }
      catch (Exception e)
      {
      }
    }
    
    /// <summary>
    /// Return the ASURL object going to the Property Editor as a sub Editor.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor.
    /// If we are going to a new sub Editor, the key can be null and
    /// we will just pass in the default key. If we are going back to an
    /// existing sub Editor, it should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    public virtual ASURL GetASURLToProperty(String _sSubSpaceKey, String _strDefaultSpace)
    {
      ASURL myPopUpURL = null;
      try
      {
        if (null == _sSubSpaceKey)
        {
          _sSubSpaceKey = _strDefaultSpace + m_nGbDocTypeModelID;
        }
        //int nCurrPageID = ((GbDocTypeMainDP) m_asOwner.GetCurrentPage()).GetGbDocTypeID();
        //int nGbDocTypeID = GetSectionID(nCurrPageID);
        int nGbDocTypeID = GetSectionID(m_nGbDocTypeModelID);
        if (XPStringUtility.CompareIgnoreCase(_strDefaultSpace, GbDocTypeExtEditorAS.STR_MVC_CLASS_NAME) == 0)
        {
          myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(_strDefaultSpace,
           _sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE, ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
           XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));
          myPopUpURL.AddControlArgument("globalObjectID", 1);
          myPopUpURL.AddControlArgument(CURRENTSECTION_ID, nGbDocTypeID);
          myPopUpURL.AddControlArgument(CURRENTGBDOCTYPEMODEL_ID, m_nGbDocTypeModelID);
          }
        if (XPStringUtility.CompareIgnoreCase(_strDefaultSpace, DocTypeEditorAS.STR_MVC_CLASS_NAME) == 0)
        {
          myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(_strDefaultSpace,
           _sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE, ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
           XPConvert.ToString(PT_CLASSIDS.PT_DOCUMENTTYPE_ID));
          if (m_nFolderID != -1)
          {
            myPopUpURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID,
             m_nFolderID);
          }
        }
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeListModel : " + e);
      }
      return myPopUpURL;
    }
    public virtual int GetFolderID()
    {
      return m_nFolderID;
    }
    public virtual void SetFolderID(int _nFolderID)
    {
      m_nFolderID = _nFolderID;
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual XPHashtable GetDocTypeMappings(int _nIndex)
    {
      return m_DocTypeTables[_nIndex];
    }
    
    /// <param name="_nDocTypeID"></param>
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual String GetDocTypeStringFromID(int _nDocTypeID, int _nIndex)
    {
      return ((String) m_DocTypeTables[_nIndex].GetElement(_nDocTypeID));
      }
    
    /// <summary>
    /// Returns the URL to edit the object.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_sEditorASName"></param>
    /// <returns>ASURL URL to the Editor</returns>
    public virtual ASURL GetEditObjectURL(int _nDocTypeID, String _strDocTypeIdentifier,
     int _nRowIndex)
    {
      ASURL myURL = new ASURL(m_asOwner);
      //int nCurrPageID = ((GbDocTypeMainDP) m_asOwner.GetCurrentPage()).GetGbDocTypeID();
      int nGbDocTypeID = -1;
      try
      {
        nGbDocTypeID = GetSectionID(m_nGbDocTypeModelID);
      }
      catch (Exception e)
      {
      }
      //int nDocTypeID = XPConvert.ToInteger(_strDocTypeID);
      // JF- For any Object in the list, the sub space key will be
      // this Model name with the object class id and the object id.
      String sSubEditorKey = STR_MVC_CLASS_NAME + _nRowIndex;
      if (m_asOwner.GetSubSpaceExists(sSubEditorKey))
      {
        GbDocTypeExtEditorAS mySubEditor = (GbDocTypeExtEditorAS) m_asOwner.GetSubSpace(sSubEditorKey);
        myURL.SetLinkGetCachedSpace(mySubEditor);
        myURL.AddControlArgument(CURRENTGBDOCTYPEMODEL_ID, m_nGbDocTypeModelID);
        } else
      {
        String sEditorASName = GbDocTypeExtEditorAS.STR_MVC_CLASS_NAME + m_nGbDocTypeModelID;
        myURL.SetLinkCreateNewSpace(GbDocTypeExtEditorAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
        myURL.SetSubSpaceKey(sEditorASName);
        //myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(_nClassID));
        //myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID, XPConvert.ToString(_nObjectID));
        myURL.AddControlArgument(DOCTYPE_ID, _nDocTypeID);
        myURL.AddControlArgument(DOCTYPE_NAME, _strDocTypeIdentifier);
        myURL.AddControlArgument("globalObjectID", 1);
        myURL.AddControlArgument(CURRENTSECTION_ID, nGbDocTypeID);
        myURL.AddControlArgument(ROW_INDEX, _nRowIndex);
        myURL.AddControlArgument(CURRENTGBDOCTYPEMODEL_ID, m_nGbDocTypeModelID);
        }
      return myURL;
    }
    
    /// <summary>
    /// This method should ge used by the client to
    /// get back the array of values at the end of
    /// the Editor and store them.
    /// </summary>
    /// <returns>String[]</returns>
    public virtual String[] GetListValues()
    {
      String[] aListValues = new String[m_saData.GetCount()];
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        aListValues[i] = (String) m_saData.GetItem(i, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
        }
      return aListValues;
    }
    
    /// <returns></returns>
    public virtual int GetModelID()
    {
      return m_nGbDocTypeModelID;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the icon to display on each row before the
    /// input text.
    /// If the value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    public virtual PTImageType GetRowIcon()
    {
      return m_imgRowIcon;
    }
    
    /// <returns></returns>
    public virtual String GetSecondAddLabel()
    {
      return m_strSecondAddLabel;
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    /// <throws>Exception</throws>
    public virtual int GetSectionID(int _nIndex)
    {
      IASQueryResult asqrSections = GetSections();
      int nSectionID = XPConvert.ToInteger(asqrSections.GetFields(_nIndex,
       PT_PROPIDS.PT_PROPID_DTMSECTION_ID));
      return nSectionID;
    }
    
    /// <returns></returns>
    /// <throws>Exception</throws>
    /// <throws>XPException</throws>
    public virtual IASQueryResult GetSections()
    {
      IPTQueryResult qrSections;
      try
      {
        qrSections = m_ptDocTypeMap.GetSections();
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeModel::GetSections Unable to get sections from Document Type Map. The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(1814, "ptmsgs_portaladminmsgs"),
         e);
      }
      return (new ASQueryResultWrapper(qrSections));
    }
    
    /// <summary>
    /// Returns the valid document types for that section.
    /// </summary>
    /// <param name="_nSectionID"></param>
    /// <returns>ASQueryResult</returns>
    /// <throws>Exception</throws>
    public virtual IASQueryResult GetValidDocumentTypes(int _nSectionID)
    {
      IPTQueryResult qrDocTypes;
      try
      {
        qrDocTypes = m_ptDocTypeMap.GetValidDocumentTypes(_nSectionID);
      }
      //((IPTDocumentTypeMap) super.m_ptGlobalObject).get
      catch (Exception e)
      {
        log.Error("GbDocTypeModel::GetValidDocumentTypes Unable to get document types from Document Type Map." + " The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(1813, "ptmsgs_portaladminmsgs"),
         e);
      }
      return (new ASQueryResultWrapper(qrDocTypes));
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeGbDocTypeList(IPTDocumentTypeMap _ptDocTypeMap,
     int _nListKey, String _strSectionName)
    {
      m_ptDocTypeMap = _ptDocTypeMap;
      try
      {
        Object[][] arrExpListColInfo = new Object[4][];
        for (int j2c_index = 0;j2c_index < 4;j2c_index++)
        {
          arrExpListColInfo[j2c_index] = new Object[5];
        }
        arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT;
        arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(1810,
         "ptmsgs_portaladminmsgs");
        arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "10%";
        arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
        arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
        arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT;
        arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(1811,
         "ptmsgs_portaladminmsgs");
        arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "80%";
        arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
        arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = true;
        arrExpListColInfo[2][EXPLIST_COLUMN_ID] = EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT;
        arrExpListColInfo[2][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(1812,
         "ptmsgs_portaladminmsgs");
        arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH] = "7%";
        arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN] = "1";
        arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT] = true;
        arrExpListColInfo[3][EXPLIST_COLUMN_ID] = EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT;
        arrExpListColInfo[3][EXPLIST_COLUMN_TITLE] = "";
        arrExpListColInfo[3][EXPLIST_COLUMN_WIDTH] = "3%";
        arrExpListColInfo[3][EXPLIST_COLUMN_COLSPAN] = "1";
        arrExpListColInfo[3][EXPLIST_COLUMN_ENABLESORT] = true;
        //String strSectionName = ((GbDocTypeModel) m_asOwner.GetModel(GbDocTypeModel.STR_MVC_CLASS_NAME)).GetSectionName(_nListKey);
        //String _ui_GbDocTypeTitle = XPFormat.Format(_ui_GbDocTypeListMainTitle, new String[] {_strSectionName});
        String _ui_GbDocTypeTitle = XPFormat.Format(m_asOwner.GetString(1808,
         "ptmsgs_portaladminmsgs"), new String[]{_strSectionName});
        base.InitializeExpandableList(_ui_GbDocTypeTitle, arrExpListColInfo,
         PTImageType.ICON_EXTENSION, m_asOwner.GetString(1807, "ptmsgs_portaladminmsgs"),
         _nListKey);
        SetSecondAddLabel(m_asOwner.GetString(1809, "ptmsgs_portaladminmsgs"));
        SetSecondAddImageIcon(PTImageType.ICON_DOCUMENT_TYPE);
        IASQueryResult qrSections = GetSections();
        int nSectionID = XPConvert.ToInteger(qrSections.GetFields(_nListKey,
         PT_PROPIDS.PT_PROPID_DTMSECTION_ID));
        Object[][] ptMappings = (Object[][]) m_ptDocTypeMap.GetMappings(nSectionID);
        m_DocTypeTables = new XPHashtable[qrSections.GetCount()];
        ptMappings = (Object[][]) m_ptDocTypeMap.GetMappings(nSectionID);
        SetDocTypesIDToNameMap(GetValidDocumentTypes(nSectionID), _nListKey);
        Object[][] oRows = new Object[ptMappings[0].Length][];
        for (int j2c_index = 0;j2c_index < ptMappings[0].Length;j2c_index++)
        {
          oRows[j2c_index] = new Object[GbDocTypeListModel.EXPLIST_COL_MAX];
          }
        for (int j = 0;j < ptMappings[0].Length;j++)
        {
          oRows[j][GbDocTypeListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
          m_nNextIndex++;
          oRows[j][GbDocTypeListModel.EXPLIST_COL_IDENTIFIER] = (String) ptMappings[0][j];
          //oRows[j][GbDocTypeListModel.EXPLIST_COL_DOCTYPE] = GetDocTypeStringFromID(XPConvert.ToInteger(ptMappings[1][j]), i);
          oRows[j][GbDocTypeListModel.EXPLIST_COL_DOCTYPE] = ptMappings[1][j];
          }
        SetDefaultObjects(oRows);
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeListModel::InitializeGbDocTypeList Unable to get sections from Document Type Map. The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(1814, "ptmsgs_portaladminmsgs"),
         e);
      }
      SetEnableMoveRowActions(true);
    }
    public virtual void SetSecondAddImageIcon(PTImageType _imgAddSecondIcon)
    {
      m_imgAddSecondIcon = _imgAddSecondIcon;
    }
    public virtual PTImageType GetSecondAddImageIcon()
    {
      return m_imgAddSecondIcon;
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_DOCTYPE,
       EXPLIST_COL_IDENTIFIER};
      // JF- Sort array
      // The growable array will always be sorted by the 1st column.
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    
    /// <param name="iRowIDs"></param>
    public virtual void RemoveAllRows(int[] iRowIDs)
    {
      m_nNextIndex = 0;
      base.GetItems().RemoveRows(iRowIDs);
    }
    
    /// <summary>
    /// Add the array passed in argument to the list.
    /// The array should be created using the EXPLIST_COL
    /// constants defined in this class.
    /// </summary>
    /// <param name="_arrRows">Array of rows to add.</param>
    public virtual void SetDefaultObjects(Object[][] _arrRows)
    {
      base.GetItems().AddRows(_arrRows);
    }
    
    /// <summary>
    /// Sets a new default value.
    /// By default this is an empty string.
    /// This value is used on add to populate the input
    /// text of the newly added row.
    /// </summary>
    /// <param name="_sDefaultValue">New value</param>
    public virtual void SetDefaultValue(String _sDefaultValue)
    {
      m_sDefaultValue = _sDefaultValue;
    }
    
    /// <param name="_ptasqrValidDocTypes"></param>
    /// <param name="_nIndex"></param>
    public virtual void SetDocTypesIDToNameMap(IASQueryResult _ptasqrValidDocTypes,
     int _nIndex)
    {
      m_DocTypeTables[_nIndex] = new XPHashtable(_ptasqrValidDocTypes.GetCount());
      for (int i = 0;i < _ptasqrValidDocTypes.GetCount();i++)
      {
        String strDocTypeName = (String) _ptasqrValidDocTypes.GetFields(i,
         PT_PROPIDS.PT_PROPID_NAME);
        int nDocTypeID = XPConvert.ToInteger(_ptasqrValidDocTypes.GetFields(i,
         PT_PROPIDS.PT_PROPID_OBJECTID));
        m_DocTypeTables[_nIndex].PutElement(nDocTypeID, strDocTypeName);
      }
    }
    
    /// <param name="_nGbDocTypeModelID"></param>
    public virtual void SetModelID(int _nGbDocTypeModelID)
    {
      m_nGbDocTypeModelID = _nGbDocTypeModelID;
    }
    
    /// <summary>
    /// Sets the icon to display on each row before the
    /// input text.
    /// By default, no icon is displayed.
    /// </summary>
    /// <param name="_imgRowIcon"></param>
    public virtual void SetRowIcon(PTImageType _imgRowIcon)
    {
      m_imgRowIcon = _imgRowIcon;
    }
    
    /// <param name="_strSecondAddLabel"></param>
    public virtual void SetSecondAddLabel(String _strSecondAddLabel)
    {
      m_strSecondAddLabel = _strSecondAddLabel;
    }
    
    /// <param name="_strDocTypeName"></param>
    /// <param name="_nDocTypeID"></param>
    /// <param name="_nIndex"></param>
    public virtual void SetSingleDocTypeIDToNameMapping(String _strDocTypeName,
     int _nDocTypeID, int _nIndex)
    {
      m_DocTypeTables[_nIndex].PutElement(_nDocTypeID, _strDocTypeName);
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(GbDocTypeListView.HTMLINPUT_ITEM) + _nRowIndex;
      String[] aDataValue;
      // JF- For each input text posted by the form, we get the value back
      // and set the new value in the array.
      if (_htFormData.ContainsKey(sDataKey))
      {
        aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && !(0 == aDataValue.Length))
        {
          _saData.SetItem(_nRowIndex, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT,
           aDataValue[0]);
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}