using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.doctype;
using com.plumtree.portalpages.admin.editors.doctypemapextension;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.doctypemap
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Growable Array.
  /// Is constains the HTML to display the Growable Array.
  /// It gets the data to display from GrowableListModel.
  /// </summary>
  /// <author>SudhaS</author>
  public class GbDocTypeListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeListView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GbDocTypeList";
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String HTMLINPUT_ITEM = "in_tx_Item";
    public const String HTMLHIDDEN_PROPEDITORKEY = "in_hi_PropEditorKey";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GbDocTypeListView();
    }
    
    /// <summary>
    /// Returns Java Script for goToPage function.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = null;
      myScript = new HTMLScript("text/javaScript");
      try
      {
        XPStringBuilder sb;
        sb = new XPStringBuilder(300);
        // JavaScript to sort by column
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("SortBy") + "(varColumnID)\n");
        sb.Append("{\n");
        sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_COLUMNID) + ".value= varColumnID;\n");
        sb.Append("  postToSelf(" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_SORTBYCOLUMN) + ");\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // JavaScript to sort by column
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("DeleteRows") + "()\n");
        sb.Append("{\n");
        sb.Append("  if(0 != " + ((IExpListModelRO) m_model).GetUniqueString("CountCheckedRows") + "()) \n");
        sb.Append("  {\n");
        sb.Append("    postToSelf(" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE) + ");\n");
        sb.Append("  }\n");
        sb.Append("  else\n");
        sb.Append("  {\n");
        sb.Append("    alert(\'" + m_asOwner.GetString(60, "ptmsgs_infrastructure") + "\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // JavaScript to return the number of checked rows.
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CountCheckedRows") + "()\n");
        sb.Append("{ \n");
        sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME + "; \n");
        sb.Append("  var len = frm.elements.length; \n");
        sb.Append("  var nValue = frm." + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_CHECKALL) + ".checked; \n");
        sb.Append("  var i = 0; \n");
        sb.Append("  var nTotal = 0; \n");
        sb.Append("  \n");
        sb.Append("  for(i=0 ; i<len ; i++) \n");
        sb.Append("  { \n");
        sb.Append("    if (frm.elements[i].name == \'" + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW) + "\') \n");
        sb.Append("    { \n");
        sb.Append("       if (frm.elements[i].checked) \n");
        sb.Append("       { \n");
        sb.Append("          nTotal++; \n");
        sb.Append("       } \n");
        sb.Append("    } \n");
        sb.Append("  } \n");
        sb.Append("  return (nTotal);\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // JavaScript to check all the rows
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CheckRows") + "()\n");
        sb.Append("{ \n");
        sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME + "; \n");
        sb.Append("  var len = frm.elements.length; \n");
        sb.Append("  var nValue = frm." + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_CHECKALL) + ".checked; \n");
        sb.Append("  var i = 0; \n");
        sb.Append("  \n");
        sb.Append("  for(i=0 ; i<len ; i++) \n");
        sb.Append("  { \n");
        sb.Append("    if (frm.elements[i].name == \'" + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW) + "\') \n");
        sb.Append("    { \n");
        sb.Append("       frm.elements[i].checked = nValue;\n");
        sb.Append("    } \n");
        sb.Append("  } \n");
        sb.Append("}\n");
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CreateExtension") + "()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(((IGbDocTypeListModelRO) m_model).GetASURLToProperty(null,
         GbDocTypeExtEditorAS.STR_MVC_CLASS_NAME).GetURLAsString()).Append("\', \'PopUpCreateMode\', \'location=no,menubar=no, scrollbars=yes, height=600,width=800\');\n");
        sb.Append("}\n");
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CreateDocumentType") + "()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(((IGbDocTypeListModelRO) m_model).GetASURLToProperty(null,
         DocTypeEditorAS.STR_MVC_CLASS_NAME).GetURLAsString()).
        // fixing bug 34046 by adding an element of uniqueness to this window name.  opened bug #39381 to address the ghettoness of this solution -mgs
        Append("\', \'" + DocTypeEditorAS.STR_MVC_CLASS_NAME + "3\', \'location=no,menubar=no,scrollbars=yes, height=600,width=1000\');\n");
        sb.Append("}\n");
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("EditProperty") + "(varSubSpaceURL,varSubSpaceKey)\n");
        sb.Append("{\n");
        sb.Append("    window.open(varSubSpaceURL, \'PopUpEditMode\' + varSubSpaceKey, \'location=no,menubar=no,scrollbars=yes, height=400,width=800\');\n");
        sb.Append("}\n");
        // Edit object
        //sb = new XPStringBuilder( 200 );
        sb.Append(" function " + ((IGbDocTypeListModelRO) m_model).GetUniqueString("EditObject") + "(varURL,varIndex)");
        sb.Append(" {");
        sb.Append("    window.open(varURL,\'PopUpEditMode\' + varIndex,\'location=no,menubar=no,scrollbars=yes, height=600,width=800\');\n");
        sb.Append(" }");
        /*
         sb.Append("function RemoveProperty(varSubSpaceKey)\n" );
         sb.Append("{\n" );
         sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + HTMLHIDDEN_PROPEDITORKEY + ".value= varSubSpaceKey;\n");
         sb.Append("  postToSelf(" + GbDocTypeRepostControl.POSTTOSELF_ACTION_REMOVEPROPERTY + ");\n");
         sb.Append("}\n" );
         */
         
        myScript.AddInnerHTMLString(sb.ToString());
        if (((IExpListModelRO) m_model).GetEnableMoveRowActions())
        {
          sb = new XPStringBuilder(300);
          // JavaScript to sort by column
          sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("MoveRow") + "(varMoveAction, varRowIndex)\n");
          sb.Append("{\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_ROWINDEX) + ".value= varRowIndex;\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_MOVEACTION) + ".value= varMoveAction;\n");
          sb.Append("  postToSelf(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MOVEROW) + "\');\n");
          sb.Append("}\n");
          myScript.AddInnerHTMLString(sb.ToString());
        }
        String sEmptyListAlert = ((IExpListModelRO) m_model).GetAlertMessageForEmptyList();
        if (null != sEmptyListAlert)
        {
          sb = new XPStringBuilder(300);
          // JavaScript to check if the list is not empty
          // JF- Note that this method is not called anywhere in the framework.
          // It has to be registered as a validation function inside the Editor
          sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CheckEmptyList") + "()\n");
          sb.Append("{\n");
          sb.Append("  \n");
          if (0 == ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
          {
            sb.Append("  alert(\"" + sEmptyListAlert + "\"); \n");
            sb.Append("  return false;\n");
          } else
          {
            sb.Append("  return true;\n");
          }
          sb.Append("}\n");
          myScript.AddInnerHTMLString(sb.ToString());
        }
      }
      catch (Exception e)
      {
        log.Error(e, "ExpListView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException(m_asOwner.GetString(53, 
        //m_asOwner.GetString(15, "ptmsgs_portaladminmsgs")
        "ptmsgs_infrastructure"), e);
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      try
      {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLTableCell myCell;
        // input text
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        myCell.SetWidth("10%");
        myCell.SetHeight("30");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        //int nCurrDisplay = ((GbDocTypeMainDP) m_asOwner.GetCurrentPage()).GetGbDocTypeID();
        int nCurrDisplay = ((IGbDocTypeListModelRO) m_model).GetModelID();
        String strDocTypeIdentifier = (String) _saData.GetItem(_nRowIndex,
         GbDocTypeListModel.EXPLIST_COL_IDENTIFIER);
        int nDocTypeID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, GbDocTypeListModel.EXPLIST_COL_DOCTYPE));
        String strDocTypeName = ((IGbDocTypeListModelRO) m_model).GetDocTypeStringFromID(nDocTypeID,
         nCurrDisplay);
        //String strDocTypeIdentifier = XPConvert.ToString(nDocTypeIdentifier);
        //String strDocTypeID = XPConvert.ToString(nDocTypeID);
        myCell.AddInnerHTMLEncodedString(strDocTypeIdentifier);
        // input text
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        myCell.SetWidth("80%");
        myCell.SetHeight("30");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLEncodedString(strDocTypeName);
        myCell = new HTMLTableCell();
        myCell = GetHTMLForMoveRowActions(_nRowIndex);
        result.AddInnerHTMLElement(myCell);
        //myCell.SetWidth("10%");
        myCell.SetHeight("30");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        //myCell.SetWidth("5%");
        myCell.SetHeight("30");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.SetNoWrap(true);
        // Add icon
        PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT,
         true, this.m_asOwner);
        HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetAlign("absmiddle");
        //myAnchor = new HTMLAnchor("postToSelf('"	// mj: removed 'Javascript:' from function name
        //	+ ((IExpListModelRO)m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "');");
        ASURL myURL = ((IGbDocTypeListModelRO) m_model).GetEditObjectURL(nDocTypeID,
         strDocTypeIdentifier, _nRowIndex);
        //HTMLAnchor myAnchor = new HTMLAnchor(	// mj: removed 'Javascript:' from function name
        HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(((IGbDocTypeListModelRO) m_model).GetUniqueString("EditObject") + "(\'" + myURL.GetURLAsString() + "\',\'" + _nRowIndex + "\'); return false;");
        myAnchor.AddInnerHTMLElement(myImage);
        myCell.AddInnerHTMLElement(myAnchor);
        return result;
      }
      catch (HTMLException e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the space below the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLForActionBar()
    {
      try
      {
        HTMLTable myTable;
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        myTable = new HTMLTable();
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // 1st Row begin (there is only one row)
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
        // Empty Cell
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        // Add icon cell
        myRow.AddInnerHTMLElement(GetHTMLForAddAction());
        // Empty Cell
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        myRow.AddInnerHTMLElement(GetHTMLForSecondAddAction());
        // JF- No need to display the delete icon, if the list is empty.
        if (0 != ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
        {
          // Delete icon cell
          myRow.AddInnerHTMLElement(GetHTMLForDeleteAction());
        }
        // Add Extra HTML to the action bar (like a "create" button)
        AddHTMLToActionBar(myRow);
        // Last Empty Cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetHeight("25");
        myCell.AddInnerHTMLString(SPACE);
        // 1st Row ends
        return myTable;
      }
      catch (HTMLException e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      try
      {
        HTMLTableCell myCell;
        PTConstruct myConstruct;
        HTMLImg myImage;
        HTMLImg myAddIcon;
        HTMLAnchor myAnchor;
        HTMLSpan mySpan;
        myCell = new HTMLTableCell();
        myCell.SetHeight("25");
        myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(SPACE);
        // Add icon
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
         true, this.m_asOwner);
        myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
        myAddIcon.SetAlt("");
        myAddIcon.SetAlign("absmiddle");
        myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
         true, this.m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetAlign("absmiddle");
        //myAnchor = new HTMLAnchor("postToSelf('"	// mj: removed 'Javascript:' from function name
        //	+ ((IExpListModelRO)m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "');");
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        // mj: removed 'Javascript:' from function name
        myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("CreateExtension") + "(); return false;");
        myAnchor.AddInnerHTMLElement(myAddIcon);
        myAnchor.AddInnerHTMLElement(myImage);
        mySpan = new HTMLSpan();
        myAnchor.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
        // Add label
        mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
        mySpan.AddInnerHTMLString(SPACE);
        mySpan.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLElement(myAnchor);
        myCell.AddInnerHTMLString(SPACE);
        return myCell;
      }
      catch (HTMLException e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      return null;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetHTMLForIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForSecondAddAction()
    {
      try
      {
        HTMLTableCell myCell;
        PTConstruct myConstruct;
        HTMLImg myImage;
        HTMLImg myAddIcon;
        HTMLAnchor myAnchor;
        HTMLSpan mySpan;
        myCell = new HTMLTableCell();
        myCell.SetHeight("25");
        myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(SPACE);
        // Add icon
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
         true, this.m_asOwner);
        myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
        myAddIcon.SetAlt("");
        myAddIcon.SetAlign("absmiddle");
        myConstruct = UIConstructFactory.GetConstruct(((IGbDocTypeListModelRO) m_model).GetSecondAddImageIcon(),
         true, this.m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetAlign("absmiddle");
        //myAnchor = new HTMLAnchor("postToSelf('"	// mj: removed 'Javascript:' from function name
        //	+ ((IExpListModelRO)m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "');");
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        // mj: removed 'Javascript:' from function name
        myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("CreateDocumentType") + "(); return false;");
        myAnchor.AddInnerHTMLElement(myAddIcon);
        myAnchor.AddInnerHTMLElement(myImage);
        mySpan = new HTMLSpan();
        myAnchor.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
        // Add label
        mySpan.AddInnerHTMLString(((IGbDocTypeListModelRO) m_model).GetSecondAddLabel());
        mySpan.AddInnerHTMLString(SPACE);
        mySpan.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLElement(myAnchor);
        myCell.AddInnerHTMLString(SPACE);
        return myCell;
      }
      catch (HTMLException e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeListView " + e);
      }
      return null;
    }
  }
}