using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.doctypemap
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the General Info page of the Document Type Map Editor.
  /// </summary>
  /// <author>SudhaS</author>
  public class GbDocTypeMainDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeMainDP");
    public const String STR_MVC_CLASS_NAME = "GbDocTypeMapMain";
    public const String HTMLHIDDEN_POPUP_NAME = "in_hi_PopUpName";
    public const String HTMLHIDDEN_PAGE_ID = "in_hi_PageID";
    private int m_nGbDocTypePageID;
    // ***CHANGE_HERE*** Update the class name below.
    public GbDocTypeMainDP(int _nGbDocTypePageID)
    {
      m_nGbDocTypePageID = _nGbDocTypePageID;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1680, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <returns></returns>
    public virtual int GetGbDocTypeID()
    {
      return m_nGbDocTypePageID;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      // ***CHANGE_HERE*** Returns the String to display on the left navigation menu,
      //       linking to that page.
      String strLeftNav = null;
      try
      {
        strLeftNav = ((IGbDocTypeModelRO) m_asOwner.GetModel(GbDocTypeModel.STR_MVC_CLASS_NAME)).GetSectionName(m_nGbDocTypePageID);
        strLeftNav = XPResourceManager.FormatMessage(m_asOwner.GetString(2476,
         "ptmsgs_portaladminmsgs"), strLeftNav);
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeDP::GetSections Unable to get sections from Document Type Map. The following exception occured: " + e);
        }
      return (strLeftNav);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME + m_nGbDocTypePageID;
    }
    
    /// <summary>
    /// Returns the HTML for the General Settings page.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // ***CHANGE_HERE*** For each Section you want to display on that page,
      //       copy the line below and change the name of the Section.
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(GbDocTypeEditorAS.strStorageGbDocTypeList + m_nGbDocTypePageID)).Display());
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_POPUP_NAME,
       "");
      result.AddInnerHTMLElement(myInput);
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_PAGE_ID, "");
      myInput.SetValue(XPConvert.ToString(m_nGbDocTypePageID));
      result.AddInnerHTMLElement(myInput);
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      // ***CHANGE_HERE*** If that DP doesn't have any JavaScripts,
      //      you can delete the entire DisplayJavaScriptFromChild() method.
      HTMLScriptCollection myScripts = null;
      myScripts = base.DisplayJavaScriptFromChild();
      // ***CHANGE_HERE*** Call the DisplayJavascript() method for all the Views having JavaScripts
      //      displayed by that DP.
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(GbDocTypeEditorAS.strStorageGbDocTypeList + m_nGbDocTypePageID).DisplayJavascript());
      return myScripts;
    }
  }
}