using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.doctypemap
{
  /// <version>$Revision$</version>
  /// <author>Sudha Sathiaseelan</author>
  public class GbDocTypeModel : GbObjEditorModel,IGbDocTypeModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeModel");
    public const String STR_MVC_CLASS_NAME = "GbDocMapType";
    private int m_nSectionsCount;
    // END ***************** save DP methods *****************
    // ***CHANGE_HERE*** Implement the repost action methods that you
    //      will call from your Repost Control.
    // BEGIN ***************** repost action methods *****************
    
    /// <summary>
    /// Modifies the object name on repost.
    /// </summary>
    public virtual void ActionOnRepost()
    {
    }
    // Code to perform on repost.
    // ***CHANGE_HERE*** Put your set/get methods and other helper methods
    // BEGIN ***************** helper methods *****************
    
    /// <summary>
    /// That method is called by the EditorStartControl.  It creates the global
    /// object and puts it in m_ptGlobalObject.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>
    /// boolean Is true if the current user has the rights to access
    /// this Editor.
    /// </returns>
    /// <throws>XPException</throws>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      if (!m_Session.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      if (!m_Session.GetSessionInfo().CheckCurrentUserIsAdmin())
      {
        return false;
      }
      // Set global object ID with values from QS.
      SetMemberVariablesFromQS(_htFormData);
      try
      {
        // JF- We open the Global Obejct with the ID provided in the QS.
        m_ptGlobalObject = m_Session.OpenGlobalObject(m_nGlobalObjectID, false);
        }
      catch (Exception e)
      {
        log.Error(e, "GbObjEditorModel::StartEditor Unable to create Global Object with ID: " + m_nGlobalObjectID + ". The following exception occured: " + e.Message);
        throw new XPException(m_asOwner.GetString(152, 
        //_ui_CreateGlobalObjectError
        "ptmsgs_portalinfrastructure"), e);
      }
      ((GbDocTypeEditorAS) m_asOwner).InitGlobalDocumentSections();
      StartGbDocTypeList();
      StartMigrationHistory();
      DoTaskOnStartEditor(_htFormData);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GbDocTypeModel();
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a
    /// sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      IASQueryResult qrSections;
      try
      {
        qrSections = GetSections();
        for (int i = 0;i < qrSections.GetCount();i++)
        {
          ((GbDocTypeListModel) m_asOwner.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList + i)).DoTaskOnComeBackFromSubEditor(i);
          }
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeModel " + e);
      }
    }
    // END ***************** repost action methods *****************
    
    /// <summary>
    /// This method contains the code to store the Document Type Map.
    /// </summary>
    public override void Finish()
    {
      try
      {
        IASQueryResult qrSections = GetSections();
        GbDocTypeListModel myGbDocTypeModel;
        for (int i = 0;i < qrSections.GetCount();i++)
        {
          myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList + i);
          myGbDocTypeModel.Finish();
        }
        // Set the migration status to approved if the checkbox was checked
        ((IMigrationHistoryModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).StoreMigrationStatus(PT_CLASSIDS.PT_GLOBALOBJECT_ID,
         m_nGlobalObjectID);
        IPTServerContext ptscDocTypeMap;
        ptscDocTypeMap = (IPTServerContext) ((IPTDocumentTypeMap) m_ptGlobalObject).GetInterfaces("IPTServerContext");
        ptscDocTypeMap.LockObject();
        ptscDocTypeMap.Store();
        ptscDocTypeMap.UnlockObject();
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeModel " + e);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(2482, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2482,
         "ptmsgs_portaladminmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    /// <throws>Exception</throws>
    public virtual String GetSectionName(int _nIndex)
    {
      IASQueryResult asqrSections = GetSections();
      String strSectionName = (String) asqrSections.GetFields(_nIndex, PT_PROPIDS.PT_PROPID_DTMSECTION_NAME);
      return strSectionName;
    }
    
    /// <returns></returns>
    /// <throws>Exception</throws>
    /// <throws>XPException</throws>
    public virtual IASQueryResult GetSections()
    {
      IPTQueryResult qrSections;
      try
      {
        qrSections = ((IPTDocumentTypeMap) base.m_ptGlobalObject).GetSections();
        }
      catch (Exception e)
      {
        log.Error("GbDocTypeModel::GetSections Unable to get sections from Document Type Map. The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(334, "ptmsgs_portaladminmsgs"),
         e);
      }
      return (new ASQueryResultWrapper(qrSections));
    }
    
    /// <returns></returns>
    public virtual int GetSectionsCount()
    {
      return m_nSectionsCount;
    }
    // END ***************** helper methods *****************
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      // ***CHANGE_HERE*** Switch between your DP and for each one call
      //       the associated save method.
      if (_sPageName.Equals(GbDocTypeMainDP.STR_MVC_CLASS_NAME))
      {
        SaveMainPage(_htFormData);
      } else
      if (_sPageName.Equals(MigrationHistoryPluginDP.STR_MVC_CLASS_NAME))
      {
        ((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    // ***CHANGE_HERE*** Implement one method per DP to save it
    // BEGIN ***************** save DP methods *****************
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
    }
    protected virtual void StartGbDocTypeList()
    {
      GbDocTypeListModel myGbDocTypeModel = null;
      try
      {
        IASQueryResult qrSections = GetSections();
        m_nSectionsCount = qrSections.GetCount();
        for (int i = 0;i < qrSections.GetCount();i++)
        {
          myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList + i);
          String strSectionName = (String) qrSections.GetFields(i, PT_PROPIDS.PT_PROPID_DTMSECTION_NAME);
          myGbDocTypeModel.InitializeGbDocTypeList((IPTDocumentTypeMap) m_ptGlobalObject,
           i, strSectionName);
        }
      }
      catch (Exception e)
      {
        log.Error("GbDocTypeModel::GetSections Unable to get sections from Document Type Map. The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(334, "ptmsgs_portaladminmsgs"),
         e);
      }
    }
    // JF- The 2 lines below are only needed if you are going to enable the move row actions
    protected override void StartMigrationHistory()
    {
      ((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).InitializeHistory(PT_CLASSIDS.PT_GLOBALOBJECT_ID,
       m_nGlobalObjectID);
    }
  }
}