using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.doctypemapextension
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Growable Array.
  /// The Growable Array is a list of input texts.
  /// On add, a new input text populated with the default value
  /// will be added at the bottom of the list.
  /// </summary>
  /// <author>SudhaS</author>
  public class GbDocTypeExtListModel : ExpListModel,IGbDocTypeExtListModelRO
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GbDocTypeExtList";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 3;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_DOCTYPENAME = 1;
    public const int EXPLIST_COL_DOCTYPEID = 2;
    
    /// <summary>
    /// Second column: the value of the input text. 
    /// </summary>
    public const int EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT = 1;
    
    /// <summary>
    /// Icon to display on each row, just before the input text. 
    /// </summary>
    protected PTImageType m_imgRowIcon;
    //public static final int EXPLIST_COL_DESCRIPTION = 3;
    //public static final int EXPLIST_COL_URI	= 4;
    
    /// <summary>
    /// This is used on add to populate the input
    /// text of the newly added row.
    /// </summary>
    protected String m_sDefaultValue = "";
    protected String m_strSecondAddLabel = "";
    
    /// <param name="_oRow"></param>
    public virtual void AddRow(Object[] _oRow)
    {
      base.GetItems().AddRow(_oRow);
    }
    
    /// <summary>
    /// Adds one row at the bottom of the list and
    /// sets the following values:
    /// First column: m_nNextIndex
    /// Second column: m_sDefaultValue
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      bool bCanAddNewRow = true;
      // JF- Before we add a new row at the end of the list, we check
      // if you don't already have a "new row" in the list.
      // The user doesn't need to have more than one empty row (or row with the default value).
      // JF- Check the array see if we have the default value in it.
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        if (m_sDefaultValue.Equals(m_saData.GetItem(i, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT)))
        {
          // JF- We already have a new row no need to add one more.
          bCanAddNewRow = false;
          break;
        }
      }
      if (bCanAddNewRow)
      {
        AddRowsToList(new String[]{m_sDefaultValue});
      }
    }
    
    /// <summary>
    /// Adds an array of new rows to the list.
    /// </summary>
    /// <param name="_aData"></param>
    public virtual void AddRowsToList(String[] _aData)
    {
      Object[] oRow;
      for (int i = 0;i < _aData.Length;i++)
      {
        oRow = new Object[EXPLIST_COL_MAX];
        oRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
        m_nNextIndex++;
        oRow[EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = _aData[i];
        base.GetItems().AddRow(oRow);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GbDocTypeExtListModel();
    }
    public virtual void DoTaskOnComeBackFromSubEditor()
    {
    }
    
    /// <summary>
    /// Return the ASURL object going to the Property Editor as a sub Editor.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor.
    /// If we are going to a new sub Editor, the key can be null and
    /// we will just pass in the default key. If we are going back to an
    /// existing sub Editor, it should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    public virtual ASURL GetASURLToProperty(String _sSubSpaceKey, String _strDefaultSpace)
    {
      if (null == _sSubSpaceKey)
      {
        _sSubSpaceKey = _strDefaultSpace;
      }
      // ***CHANGE_HERE*** If you don't have a class ID, just pass in null for the 2 last arguments.
      // JF- The helper method below will return the right URL. We don't need to figure out
      // if it's a cahed sub Editor or no.
      ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(_strDefaultSpace,
       _sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE, ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       XPConvert.ToString(PT_CLASSIDS.PT_DOCUMENTTYPE_ID));
      return myPopUpURL;
    }
    
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    public virtual String GetDocTypeFromRowIndex(int _nRowIndex)
    {
      return XPConvert.ToString(base.GetItems().GetItem(_nRowIndex, EXPLIST_COL_DOCTYPEID));
      }
    
    /// <summary>
    /// This method should ge used by the client to
    /// get back the array of values at the end of
    /// the Editor and store them.
    /// </summary>
    /// <returns>String[]</returns>
    public virtual String[] GetListValues()
    {
      String[] aListValues = new String[m_saData.GetCount()];
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        aListValues[i] = (String) m_saData.GetItem(i, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
        }
      return aListValues;
    }
    // ***CHANGE_HERE*** This key is used to create and retrieve sub Editors.
    //private int m_nSubSpaceIndex = 0;
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the icon to display on each row before the
    /// input text.
    /// If the value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    public virtual PTImageType GetRowIcon()
    {
      return m_imgRowIcon;
    }
    
    /// <returns></returns>
    public virtual String GetSecondAddLabel()
    {
      return m_strSecondAddLabel;
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeGbDocTypeExtList(String _sSectionTitle,
     String _sSectionSubTitle1, PTImageType _imgAddIcon, String _sAddLabel,
     int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle1;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_DOCTYPENAME,
       EXPLIST_COL_DOCTYPEID};
      // JF- Sort array
      // The growable array will always be sorted by the 1st column.
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    
    /// <summary>
    /// Add the array passed in argument to the list.
    /// The array should be created using the EXPLIST_COL
    /// constants defined in this class.
    /// </summary>
    /// <param name="_arrRows">Array of rows to add.</param>
    public virtual void SetDefaultObjects(Object[][] _arrRows)
    {
      base.GetItems().AddRows(_arrRows);
    }
    
    /// <summary>
    /// Sets a new default value.
    /// By default this is an empty string.
    /// This value is used on add to populate the input
    /// text of the newly added row.
    /// </summary>
    /// <param name="_sDefaultValue">New value</param>
    public virtual void SetDefaultValue(String _sDefaultValue)
    {
      m_sDefaultValue = _sDefaultValue;
    }
    
    /// <summary>
    /// Sets the icon to display on each row before the
    /// input text.
    /// By default, no icon is displayed.
    /// </summary>
    /// <param name="_imgRowIcon"></param>
    public virtual void SetRowIcon(PTImageType _imgRowIcon)
    {
      m_imgRowIcon = _imgRowIcon;
    }
    
    /// <param name="_strSecondAddLabel"></param>
    public virtual void SetSecondAddLabel(String _strSecondAddLabel)
    {
      m_strSecondAddLabel = _strSecondAddLabel;
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(GbDocTypeExtListView.HTMLINPUT_ITEM) + _nRowIndex;
      String[] aDataValue;
      // JF- For each input text posted by the form, we get the value back
      // and set the new value in the array.
      if (_htFormData.ContainsKey(sDataKey))
      {
        aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && !(0 == aDataValue.Length))
        {
          _saData.SetItem(_nRowIndex, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT,
           aDataValue[0]);
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}