using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.common.setjob;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.externaloperations
{
  /// <summary>
  /// JHQ ExtOpRedesign 050604: External Operations have been re-architected to run script files instead of 
  /// commands from the command line.  These scripts must reside in the automation server's
  /// portal_home/scripts directory.  This directory can be secured as necessary.  Therefore,
  /// we no longer use the RunAsUser/RunAsUserPassword.  Corresponding methods will be 
  /// deprecated and should not be implemented.
  /// </summary>
  /// <author>OlegS</author>
  public class ExternalOperationEditorModel : ObjEditorModel,IExternalOperationEditorModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.externaloperations.ExternalOperationEditorModel");
    public const String STR_MVC_CLASS_NAME = "ExternalOperationEditor";
    public int m_nAction;
    protected IPTExternalOperation m_ptExtOp = null;
    //	protected String m_displayPassword = "";
    protected XPArrayList m_ActionData = null;
    private const int COMMANDLINE_INDEX = 0;
    private const int TIMEOUT_INDEX = 1;
    
    /// <summary>
    /// Creates a new ExternalOperationEditorModel object.
    /// </summary>
    public ExternalOperationEditorModel() : base()
    {
      m_nClassID = PT_CLASSIDS.PT_EXTOPERATION_ID;
      // set just before SaveMainPage() from ExternalOperationEditorRepostControl.SetRepostAction() hook
      m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
    }
    // interface IExternalOperationEditorModelRO
    public virtual String GetCommandLine()
    {
      return (String) m_ptExtOp.GetCommandLine();
    }
    
    /// <returns></returns>
    /// <deprecated>This method should not be implemented.</deprecated>
    public virtual String GetPasswordToDisplay()
    {
      // Deprecated
      throw new XPNotImplementedException("GetPasswordToDisplay is deprecated");
      }
    //		return m_displayPassword;
    
    /// <returns></returns>
    public virtual int GetTimeout()
    {
      return m_ptExtOp.GetTimeout();
    }
    
    /// <returns></returns>
    /// <deprecated>This method should not be implemented.</deprecated>
    public virtual String GetUser()
    {
      // Deprecated
      throw new XPNotImplementedException("GetUser is deprecated");
    }
    //		return (String) m_ptExtOp.GetUser();
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ExternalOperationEditorModel();
    }
    public override void DoTaskAfterStore()
    {
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskAfterStoreSetJob();
      }
    public override void DoTaskBeforeStore()
    {
      Object value = m_ActionData.GetElement(COMMANDLINE_INDEX);
      if ((null == m_ptExtOp.GetCommandLine()) && (value == null))
      {
        log.Error("ExternalOperationEditor.DoTaskBeforeStore(): Command Line is empty");
        throw new XPException(m_asOwner.GetString(2180, "ptmsgs_portaladminmsgs"));
        }
      if (null != value)
      {
        m_ptExtOp.SetCommandLine(XPConvert.ToString(value));
      }
      value = m_ActionData.GetElement(TIMEOUT_INDEX);
      if (null != value)
      {
        m_ptExtOp.SetTimeout(XPConvert.ToInteger(value) * 1000);
      }
      // job plug-in page
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStoreSetJob();
      }
    public override void DoTaskOnComeBackFromSubEditor()
    {
      base.DoTaskOnComeBackFromSubEditor();
      ((SelectPTObjectModel) m_asOwner.GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).DoTaskOnComeBackFromSubEditor();
      }
    // implementation
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      base.DoTaskOnStartEditor(_htFormData);
      // check editor type
      int nEditorType = GetEditorType();
      if (EditorStartControl.EDITOR_START_FLAG_EDIT != nEditorType)
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      switch (nEditorType){
      case EditorStartControl.EDITOR_START_FLAG_CREATE:
      break;
      case EditorStartControl.EDITOR_START_FLAG_EDIT:
      break;
      default:
      log.Error(GetName() + ": Unsupported editor type " + GetEditorType());
      throw new XPException(m_asOwner.GetString(365, "ptmsgs_portaladminmsgs") + 1);
      break;
      }
      // check object
      if (GetObject() == null)
      {
        log.Error(GetName() + ": Null object ");
        throw new XPException(m_asOwner.GetString(365, "ptmsgs_portaladminmsgs") + 2);
        }
      // prepare object
      m_ptExtOp = (IPTExternalOperation) GetObject();
      // job plug-in page
      ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskOnStartSetJob(m_ptObject,
       m_Session, GetEditorType());
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      TraceHelper.Trace("SavePage(" + _sPageName + ")");
      TraceHelper.TraceQueryString(_htFormData);
      int result = base.SavePage(_sPageName, _htFormData);
      ExtractActionData_All(_htFormData);
      if (_sPageName.Equals(ExternalOperationEditorMainDP.STR_MVC_CLASS_NAME))
      {
        result = SaveMainPage(_htFormData);
      } else
      if (_sPageName.Equals(SetJobDP.STR_MVC_CLASS_NAME))
      {
        ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      return result;
    }
    
    /// <returns></returns>
    protected virtual int GetAction()
    {
      return m_nAction;
    }
    protected virtual void ClearActionData()
    {
      if (m_ActionData == null)
      {
        m_ActionData = new XPArrayList();
      } else
      {
        m_ActionData.Clear();
      }
    }
    
    /// <param name="_htFormData"></param>
    protected virtual void ExtractActionData_All(XPHashtable _htFormData)
    {
      ClearActionData();
      m_ActionData.Insert(COMMANDLINE_INDEX, ExtractOneElement(_htFormData.GetElement(ExternalOperationEditorMainView.HTMLTEXT_CommandLine)));
      // JHQ ExtOpRedesign: we no longer use the RunAsUser/RunAsUserPassword
      //		m_ActionData.Add(ExtractOneElement(_htFormData.GetElement(
      //					ExternalOperationEditorMainView.HTMLTEXT_User)));
      //		m_ActionData.Add(ExtractOneElement(_htFormData.GetElement(
      //					ExternalOperationEditorMainView.HTMLTEXT_Password)));
      m_ActionData.Insert(TIMEOUT_INDEX, ExtractOneElement(_htFormData.GetElement(ExternalOperationEditorMainView.HTMLTEXT_Timeout)));
      }
    
    /// <param name="o"></param>
    /// <returns></returns>
    protected virtual String ExtractOneElement(Object o)
    {
      String[] sa = (String[]) o;
      return ((sa == null) || (sa.Length < 1)) ? null : sa[0];
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveMainPage(XPHashtable _htFormData)
    {
      //	ExtractActionData_All(_htFormData) should be called before this method is.
      if (null == m_ActionData)
      {
        return RepostControl.PAGE_STATUS_INVALID;
      }
      int result = RepostControl.PAGE_STATUS_VALID;
      // validate
      String msg = null;
      // JHQ ExtOpRedesign: we no longer use the RunAsUser/RunAsUserPassword
      //		String p1  = (String) m_ActionData.GetElement(2);
      //		m_displayPassword=p1;
      //		String p2  = ExtractOneElement(_htFormData.GetElement(
      //					ExternalOperationEditorMainView.HTMLTEXT_Password2));
      //
      //		if (differ(p1, p2))
      //		{
      //			m_displayPassword="";
      //			msg = append(msg,
      //					m_asOwner.GetString(366, "ptmsgs_portaladminmsgs"));
      //		}
      int timeout = 0;
      int maxTimeout = int.MaxValue / 1000;
      try
      {
        timeout = XPConvert.ToInteger((String) m_ActionData.GetElement(TIMEOUT_INDEX));
        if (timeout < 0)
        {
          throw new Exception("");
        }
        if (timeout > maxTimeout)
        {
          throw new Exception("");
        }
      }
      catch (Exception e)
      {
        timeout = 0;
        String[] args = {XPConvert.ToString(maxTimeout + 1)};
        msg = append(msg, XPFormat.Format(m_asOwner.GetString(2686, "ptmsgs_portaladminmsgs"),
         args));
      }
      String cmdline = (String) m_ActionData.GetElement(COMMANDLINE_INDEX);
      if (cmdline == null || XPStringUtility.Trim(cmdline).Length == 0)
      {
        msg = append(msg, m_asOwner.GetString(2180, "ptmsgs_portaladminmsgs"));
        }
      // JHQ ExtOpRedesign: we no longer use the RunAsUser/RunAsUserPassword
      //		String username=(String)m_ActionData.GetElement(1);
      //		if(username==null || username.trim().length()==0) {
      //			msg = append(msg,	m_asOwner.GetString(2174, "ptmsgs_portaladminmsgs"));
      //		}
      if (msg != null)
      {
        result = RepostControl.PAGE_STATUS_INVALID;
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      // save
      m_ptExtOp.SetCommandLine(cmdline);
      // JHQ ExtOpRedesign: we no longer use the RunAsUser/RunAsUserPassword
      //		m_ptExtOp.SetUser(username);
      //		m_ptExtOp.SetPassword(p1);
      m_ptExtOp.SetTimeout(timeout * 1000);
      return result;
    }
    
    /// <param name="s1"></param>
    /// <param name="s2"></param>
    /// <returns></returns>
    protected virtual String append(String s1, String s2)
    {
      if (s1 == null)
      {
        s1 = "";
      }
      if (s2 == null)
      {
        return s1;
      }
      if (s1.Length == 0)
      {
        return s2;
      } else
      {
        return (s1 + ((XPStringUtility.EndsWith(s1, ".")) ? " " : "; ") + s2);
        }
    }
    
    /// <param name="s1"></param>
    /// <param name="s2"></param>
    /// <returns></returns>
    protected virtual bool differ(String s1, String s2)
    {
      if ((s1 == null) && (s2 == null))
      {
        return false;
      }
      if ((s1 == null) || (s2 == null))
      {
        return true;
      }
      return !s1.Equals(s2);
    }
  }
}