using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.filter;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.filter
{
  /// <author>MikeS</author>
  public class FilterModel : ObjEditorModel,IFilterModelRO
  {
    public const String STR_MVC_CLASS_NAME = "Filter";
    private FilterIterator m_FilterIterator;
    private XPHashtable m_TestFilterArgs = null;
    
    /// <param name="form"></param>
    public virtual void BuildFilterFromForm(XPHashtable form)
    {
      m_ptObject = FilterForm.BuildFilterFromForm(m_asOwner, form, (IPTFilter) m_ptObject);
      // Always make sure our FilterIterator is positioned at the
      // start of the correct filter
      m_FilterIterator.InitFromFilter((IPTFilter) m_ptObject);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new FilterModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      m_FilterIterator = new FilterIterator(m_Session, (IPTFilter) m_ptObject,
       m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the current filter iterator.
    /// </summary>
    /// <returns>the current filter iterator.</returns>
    public virtual IFilterIteratorRO GetFilterIterator()
    {
      return m_FilterIterator;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        BuildFilterFromForm(_htFormData);
      }
      // this block was added to prevent the editor from finishing out if
      // server side validation revealed query construct errors
      String[] data = (String[]) _htFormData.GetElement("in_hi_PostToSelf");
      if (null != data && data.Length > 0)
      {
        int _action = XPConvert.ToInteger(data[0]);
        // we're heading for the finish page
        if (RepostControl.POSTTOSELF_ACTION_FINISH == _action || RepostControl.POSTTOSELF_ACTION_GOTOPAGE == _action)
        {
          SettingsView fView = (SettingsView) m_asOwner.GetView(SettingsView.STR_MVC_CLASS_NAME);
          if (fView.QueryContainsValidationProblemsOnRender())
          {
            nPageStatus = RepostControl.PAGE_STATUS_INVALID;
          }
        }
      }
      return nPageStatus;
    }
    public virtual void SetTestFilterArgs(XPHashtable filterArgs)
    {
      m_TestFilterArgs = filterArgs;
    }
    public virtual void TurnOffFilterReport()
    {
      m_TestFilterArgs = null;
    }
    public virtual XPHashtable GetTestFilterArgs()
    {
      return m_TestFilterArgs;
    }
    public class FilterReport
    {
      public int numResults;
      public bool threwException;
      public String exceptionMessage;
      public XPException exception;
    }
    /* The report is generated by creating a new filter from the control args and running
     * it as an advanced search. A "PASS" is a search that doesn't throw an exception, i.e.
     * it may return 0 results and still be a pass.
     */
     
    public virtual FilterReport GetTestFilterReport()
    {
      if (m_TestFilterArgs == null)
      {
        return null;
      }
      FilterReport retval = new FilterReport();
      try
      {
        IPTFilter testFilter = FilterForm.BuildFilterFromForm(m_asOwner, m_TestFilterArgs,
         (IPTFilter) null);
        testFilter.GetDescription();
        IPTSearchRequest req = ((IPTSession) m_asOwner.GetUserSession()).GetSearchRequest();
        IPTSearchQuery q = req.CreateAdvancedQuery(testFilter);
        try
        {
          IPTSearchResponse resp = req.Search(q);
          retval.numResults = resp.GetTotalMatches();
          retval.threwException = false;
        }
        catch (Exception e)
        {
          SearchExecutionException eprime = SearchUIUtility.GetI18NException(e,
           m_asOwner);
          if (!SearchUIUtility.ExceptionHiddenInPageSource(eprime))
          {
            throw eprime;
          } else
          {
            throw e;
          }
        }
      }
      catch (Exception e)
      {
        XPException exp = new XPException(e);
        retval.threwException = true;
        retval.exceptionMessage = exp.GetMessage();
        retval.exception = exp;
      }
      return retval;
    }
  }
}