using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.treeiterator;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.group
{
  /// <summary>
  /// This version of the tree allows for browsing and
  /// selecting of objects with no hierarchical structure
  /// </summary>
  /// <author>RickyW</author>
  public class ActivityRightsTreeModel : ATreeModel,ITreeModel,ITreeModelRO,
  IRepostModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.group.ActivityRightsTreeModel");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ActivityRightsTree";
    // localized strings: internal
    // localized strings: errors
    // member variables
    
    /// <summary>
    /// Tree iterator 
    /// </summary>
    protected IPTTreeIterator m_ptIterator = null;
    
    /// <summary>
    /// Storage to keep track of select items *
    /// </summary>
    private XPHashtable m_xphtSelected;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ActivityRightsTreeModel();
    }
    
    /// <summary>
    /// This is called when a node is expanded.  Since activity rights
    /// is a flat list, there will be no recursive thoughts here.  This simply
    /// retrieves all the activity rights available to the user and puts it on
    /// the tree as leaf items.
    /// </summary>
    /// <param name="bExpand">expands the branch</param>
    /// <param name="nNodeID">the uniqueid for this node</param>
    public override void ExpandNode(bool bExpand, int nNodeID)
    {
      base.ExpandNode(bExpand, nNodeID);
      // Always expand the dummy title to show all rights
      TreeCompositeNode node = (TreeCompositeNode) m_Root.GetNode(nNodeID);
      node.m_bExpanded = true;
      // Populate with activity rights
      try
      {
        IPTQueryResult ptQRRights = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().QueryActivityRights();
        TreeLeafNode myLeaf;
        if (null != ptQRRights)
        {
          PTSortedArrayWrapper sortedRights;
          // create sort by name.		
          int[][] arrSort = new int[1][];
          for (int j2c_index = 0;j2c_index < 1;j2c_index++)
          {
            arrSort[j2c_index] = new int[2];
          }
          arrSort[0][0] = PT_PROPIDS.PT_PROPID_NAME;
          arrSort[0][1] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
          // use helper class to sort data by name.
          sortedRights = new PTSortedArrayWrapper();
          sortedRights.Initialize(ptQRRights.Columns(), ptQRRights.Data(),
           arrSort, true);
          for (int ii = 0;ii < sortedRights.GetCount();ii++)
          {
            myLeaf = new TreeLeafNode(GetNextUniqueID());
            myLeaf.SetName(XPConvert.ToString(sortedRights.GetItem(ii, PT_PROPIDS.PT_PROPID_NAME)));
            myLeaf.m_nObjectID = XPConvert.ToInteger(sortedRights.GetItem(ii,
             PT_PROPIDS.PT_PROPID_OBJECTID));
            myLeaf.m_nClassID = PT_CLASSIDS.PT_ACTIVITY_ID;
            myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ACTIVITY_RIGHT).GetHTMLElement();
            // determine if the right should be selected
            // by checking against our internal storage 
            if (m_xphtSelected.ContainsKey("" + myLeaf.m_nObjectID))
            {
              myLeaf.m_bSelected = true;
            }
            node.AddLeafChild(myLeaf);
          }
        } else
        {
        }
      }
      // if there are no rights, then perhaps add a
      // message here.  we have not yet encountered
      // this situation, so this may be unnecessary.				
      catch (Exception ex)
      {
        log.Error("ActivityRightsTreeModel::Expand Node Unable to load activity rights tree.  The following exception occured: " + ex);
        throw new XPException(m_asOwner.GetString(396, "ptmsgs_portaladminmsgs"),
         ex);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_xphtSelected = new XPHashtable();
    }
    
    /// <summary>
    /// Initializes and begins the loading of the tree.
    /// </summary>
    public virtual void LoadRights()
    {
      // Root is simply a dummy title
      m_Root = new TreeCompositeNode(GetNextUniqueID());
      m_Root.SetName(m_asOwner.GetString(395, "ptmsgs_portaladminmsgs"));
      if (!m_bShowRoot)
      {
        ExpandNode(true, m_Root.m_nTreeNodeID);
      }
    }
    
    /// <summary>
    /// If there are multiple class ids, determine which
    /// ones to display.  For activity rights, we only
    /// have 1 class id, so this method is unimplemented.
    /// </summary>
    /// <param name="nIDs">determines which classids to display</param>
    public override void SetClassIDsToDisplay(int[] nIDs)
    {
    }
    // Activity rights do not need this currently.
    
    /// <summary>
    /// Determines what items in the tree are to be displayed.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToDisplay(int[])"></seealso>
    /// <param name="nIDs">determines which nodes are not hidden.</param>
    public override void SetObjectIDsToDisplay(int[] nIDs)
    {
    }
    // Activity rights do not need this currently.
    
    /// <summary>
    /// Determines what items in the tree are hidden.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToHide(int[])"></seealso>
    /// <param name="nIDs">determines which nodes are hidden</param>
    public override void SetObjectIDsToHide(int[] nIDs)
    {
    }
    // Activity rights do not need this currently.
    
    /// <summary>
    /// Determines what items in the tree are selected.
    /// </summary>
    /// <param name="nIDs">determines which nodes are selected</param>
    public override void SetObjectIDsToSelect(int[] nIDs)
    {
      // clear selected list
      m_xphtSelected.Clear();
      // add selected elements to internal list
      for (int ii = 0;ii < nIDs.Length;ii++)
      {
        m_xphtSelected.PutElement("" + nIDs[ii], "");
      }
    }
  }
}