using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.selectptobjectsbytype;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.group
{
  /// <summary>
  /// Activity Space for Group Objects.  A group is a collection of users and/or
  /// other groups.
  /// This activity space has the following pages and views:
  /// - GroupMainSettingsDP - group memberships page (default page) (left nav)
  /// +--> SelectPTObjectView - parent groups
  /// +--> SelectPTObjectView - direct user/group member
  /// +--> SelectPTObjectView - RO, dynamic members
  /// - GroupDynamicRulesDP - group dynamic memberships page (left nav)
  /// +--> DynamicRulesView - dynamic rules filters
  /// +--> DynamicMembersPreviewView - dynamic members preview button
  /// - GroupDynamicMembersPreviewPopupDP - the popup display page (preview popup button)
  /// +--> SelectPTObjectView - RO, dynamic members preview
  /// - GroupActivityRightsDP - group activity rights page (left nav)
  /// +--> SelectActivityRightsView - activity rights
  /// +--> SelectActivityRightsView - inherited rights
  /// </summary>
  /// <author>rickyw</author>
  public class GroupEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.group.GroupEditorAS");
    
    /// <summary>
    /// class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GroupEditor";
    // member variables
    
    /// <summary>
    /// Constant for Member SelectIPTObject storage name 
    /// </summary>
    public const String strStorageMemberSelectPTObject = "GroupMemberSelectPTObject";
    
    /// <summary>
    /// Constant for Dynamic Member SelectIPTObject storage name 
    /// </summary>
    public const String strStorageDynMemberSelectPTObject = "GroupDynMemberSelectPTObject";
    
    /// <summary>
    /// Constant for DynamicRulesChooserView storage name 
    /// </summary>
    public const String strDynamicRulesChooser = "DynamicRulesChooser";
    
    /// <summary>
    /// Constant for Dynamic Member Preview Popup SelectIPTObject storage name 
    /// </summary>
    public const String strStorageDynMemberPreviewPopup = "GroupDynMemberPreviewPopup";
    
    /// <summary>
    /// Constant for Parent Group SelectIPTObject storage name 
    /// </summary>
    public const String strStorageParentGroupSelectPTObject = "ParentGroupSelectPTObject";
    
    /// <summary>
    /// Constant for Rights SelectActivityRights storage name 
    /// </summary>
    public const String strStorageSelectActivityRights = "GroupSelectActivityRights";
    
    /// <summary>
    /// Constant for Inherited Rights SelectInheritedRights storage name 
    /// </summary>
    public const String strStorageSelectInheritedRights = "GroupSelectInheritedRights";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.group.GroupEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GroupEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (GroupDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Gets the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(398, "ptmsgs_portaladminmsgs");
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2609, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (GroupRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      // SE: logging
      log.FunctionBegin("GroupEditorAS::Init");
      // Get and initialize my data model.
      m_strModelName = GroupModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      RegisterPage(new GroupMainSettingsDP());
      RegisterPage(new GroupDynamicRulesDP());
      RegisterPage(new GroupDynamicMembersPreviewPopupDP());
      RegisterPage(new GroupActivityRightsDP());
      // Register Views
      RegisterView(GroupDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(GroupRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Default Page - main settings instead of localized names
      SetCurrentPage(GroupMainSettingsDP.STR_MVC_CLASS_NAME);
      // Register Plug-In: Member SelectPTObjectsByTypeModel
      // (just like SelectPTObject, but displays groups then users)
      RegisterModel(SelectPTObjectsByTypeModel.STR_MVC_CLASS_NAME, strStorageMemberSelectPTObject);
      IModel myMemberSelectPTObjectModel = GetModel(strStorageMemberSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageMemberSelectPTObject,
       myMemberSelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageMemberSelectPTObject,
       myMemberSelectPTObjectModel);
      // Register Plug-In: Dynamic Member SelectPTObject (RO)
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageDynMemberSelectPTObject);
      IModel myDynMemberSelectPTObjectModel = GetModel(strStorageDynMemberSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageDynMemberSelectPTObject,
       myDynMemberSelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageDynMemberSelectPTObject,
       myDynMemberSelectPTObjectModel);
      // Register Plug-In: Parent Group SelectPTObject
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageParentGroupSelectPTObject);
      IModel myParentGroupSelectPTObjectModel = GetModel(strStorageParentGroupSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageParentGroupSelectPTObject,
       myParentGroupSelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageParentGroupSelectPTObject,
       myParentGroupSelectPTObjectModel);
      // Register Plug-In: Rights SelectList
      RegisterModel(SelectActivityRightsModel.STR_MVC_CLASS_NAME, strStorageSelectActivityRights);
      IModel myRightsActivityRightsSelectModel = GetModel(strStorageSelectActivityRights);
      RegisterView(SelectActivityRightsView.STR_MVC_CLASS_NAME, strStorageSelectActivityRights,
       myRightsActivityRightsSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectActivityRights,
       myRightsActivityRightsSelectModel);
      // Register Plug-In: Inherited Rights SelectList
      RegisterModel(SelectActivityRightsModel.STR_MVC_CLASS_NAME, strStorageSelectInheritedRights);
      IModel myInheritedRightsSelectModel = GetModel(strStorageSelectInheritedRights);
      RegisterView(SelectActivityRightsView.STR_MVC_CLASS_NAME, strStorageSelectInheritedRights,
       myInheritedRightsSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectInheritedRights,
       myInheritedRightsSelectModel);
      // Register Plug-In: Dynamic Rules Chooser
      RegisterView(DynamicRulesView.STR_MVC_CLASS_NAME, myModel);
      // Register Plug-In: Dynamic Members Preview Button
      RegisterView(DynamicMembersPreviewView.STR_MVC_CLASS_NAME, myModel);
      // Register Plug-In: Dynamic Members Preview SelectPTObject (RO)
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageDynMemberPreviewPopup);
      IModel myDynMemberPreviewModel = GetModel(strStorageDynMemberPreviewPopup);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageDynMemberPreviewPopup,
       myDynMemberPreviewModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageDynMemberPreviewPopup,
       myDynMemberPreviewModel);
      // Sets Left-Nav Menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(400, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupMainSettingsDP.STR_MVC_CLASS_NAME);
      // aj: note - the link below is hidden in DoTaskOnStartEditor() when we are dealing with remote groups
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupDynamicRulesDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupActivityRightsDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1829, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      ((ObjectSecurityModel) GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetLeftNavString(GetString(402,
       "ptmsgs_portaladminmsgs"));
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 36;
          int iTipId = 37;
          int iSecondaryTipId = 38;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
      //	Got the tips model
      // SE: logging
      log.FunctionEnd("GroupEditorAS::Init");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (GroupMainSettingsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Group_MainSettings");
      } else
      if (GroupActivityRightsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Group_ActivityRights");
      } else
      if (LocNamesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_PropertiesandNames");
      } else
      if (ObjectSecurityDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Security");
      } else
      if (MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_MigrationHistoryandStatus");
      } else
      if (GroupDynamicRulesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Group_DynamicMembershipRules");
      }
    }
  }
}