using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.group
{
  public class GroupMainSettingsDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.group.GroupMainSettingsDP");
    
    /// <summary>
    /// class name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GroupMainDP";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(2519, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      // aj: the sub header should be different for remote groups vs. normal ones
      if (((IGroupModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).IsRemoteGroup())
      {
        return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2709,
         "ptmsgs_portaladminmsgs"), this.m_asOwner);
      } else
      {
        return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1663,
         "ptmsgs_portaladminmsgs"), this.m_asOwner);
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      // SE: logging
      log.FunctionBegin("GroupMainSettingDP::PageDisplay");
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      result.AddInnerHTMLElement(ExpListView.GetHiddenInputsForPagination());
      HTMLElementCollection views = new HTMLElementCollection();
      // The Everyone group contains all the users in the portal.  The memberships cannot be edited.
      if (((IGroupModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetObjectID() == PT_INTRINSICS.PT_USERGROUP_EVERYONE)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(2676, "ptmsgs_portaladminmsgs"), "");
        myError.SetTitle("");
        myError.SetActivitySpace(m_asOwner.GetName());
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      // display parent group select ptobject
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(GroupEditorAS.strStorageParentGroupSelectPTObject)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // display member select ptobject
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(GroupEditorAS.strStorageMemberSelectPTObject)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // display dynamic member select ptobject
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(GroupEditorAS.strStorageDynMemberSelectPTObject)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      // SE: logging
      log.FunctionEnd("GroupMainSettingDP::PageDisplay");
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // Display JavaScripts for the members PTObject list.
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(GroupEditorAS.strStorageMemberSelectPTObject).DisplayJavascript());
      // Display JavaScripts for the dynamic members PTObject list.
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(GroupEditorAS.strStorageDynMemberSelectPTObject).DisplayJavascript());
      // Display JavaScripts for the parent groups PTObject list.
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(GroupEditorAS.strStorageParentGroupSelectPTObject).DisplayJavascript());
      myScripts.AddInnerHTMLElement(ExpListView.GetJavaScriptsForPagination(m_asOwner));
      return myScripts;
    }
  }
}