using System;
// UI Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using SelectPTObjectModel=com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectModel;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.group
{
  /// <summary>
  /// Delete that class if you don't have any repost actions.
  /// </summary>
  public class GroupRepostControl : ObjEditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.group.GroupRepostControl");
    public const String STR_MVC_CLASS_NAME = "GroupRepost";
    public const int POSTTOSELF_ACTION_PREVIEW_DYNAMIC_MEMBERS = 10;
    public const int POSTTOSELF_ACTION_MODIFY_GROUP_CHOOSER_ROW = 11;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GroupRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call the associated method for each
    /// action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      ((ExpListControl) m_asOwner.GetControl(GroupEditorAS.strStorageMemberSelectPTObject)).PerformRepostAction(_nAction,
       m_htFormData);
      ((ExpListControl) m_asOwner.GetControl(GroupEditorAS.strStorageParentGroupSelectPTObject)).PerformRepostAction(_nAction,
       m_htFormData);
      ((ExpListControl) m_asOwner.GetControl(GroupEditorAS.strStorageSelectActivityRights)).PerformRepostAction(_nAction,
       m_htFormData);
      ((GroupModel) m_model).SetHiddenMemberGroups();
      ((GroupModel) m_model).SetHiddenParentGroups();
      // aj: add the following switch statement to deal with dynamic members previews
      try
      {
        switch (_nAction){
        case POSTTOSELF_ACTION_PREVIEW_DYNAMIC_MEMBERS:
        ((GroupModel) m_model).PreviewMembershipFilter();
        PerformPreviewPopup();
        break;
        case POSTTOSELF_ACTION_MODIFY_GROUP_CHOOSER_ROW:
        ((GroupModel) m_model).ModifyMemberOfRow(m_htFormData);
        break;
        }
      }
      catch (XPException xpe)
      {
        log.Error(xpe, "GroupRepostControl::PerformAction Unable to perform preview operation.");
        // aj: default message on error & exception message (not extracted)
        String sMessage = m_asOwner.GetString(3180, ResourceConstants.PORTALADMINMSGS);
        String sExceptionMessage = "Unable to preview members, one or more dynamic membership rules are invalid.";
        if (xpe is PTException)
        {
          PTException ptex = (PTException) xpe;
          int iCode = ptex.GetErrorCode();
          if (iCode == PT_RESULTCODES.PT_E_CIRCULAR_GROUP_STRUCTURE)
          {
            sMessage = m_asOwner.GetString(3177, ResourceConstants.PORTALADMINMSGS);
            sExceptionMessage = "Unable to preview member of this group because it creates a circular group dependency.";
            } else
          if (iCode == PT_RESULTCODES.PT_E_DYNAMICRULE_INVALID_OPERATOR)
          {
            sMessage = m_asOwner.GetString(3178, ResourceConstants.PORTALADMINMSGS);
            sExceptionMessage = "Unable to preview member of this group because the dynamic membership rules use an invalid operator.";
            } else
          if (iCode == PT_RESULTCODES.PT_E_DYNAMICRULE_INVALID_PROP_TYPE)
          {
            sMessage = m_asOwner.GetString(3179, ResourceConstants.PORTALADMINMSGS);
            sExceptionMessage = "Unable to preview members of this group because the dynamic membership rules use an invalid property type.";
            }
          UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
           null, sMessage, null);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
        throw new XPException(sExceptionMessage, xpe);
      }
    }
    
    /// <summary>
    /// Note: this is a rip from JenSun's PTMigrationUtility Status popup...
    /// Sets the editor to perform the status popup.
    /// </summary>
    protected virtual void PerformPreviewPopup()
    {
      // SE: logging
      log.FunctionBegin("GroupRepostControl::PerformPreviewPopup");
      try
      {
        HTMLScript myScript = new HTMLScript("text/javascript");
        XPStringBuilder sb;
        // Construct the ASURL for the popup
        ASURL statusPopup = new ASURL(m_asOwner);
        // SE: Bug 62498 - SetLinkGetSpaceIfCached does not include the space id in the ASURL
        // which is needed to render the results correctly. Without the specific space id, the
        // MVCController will attempt to retrieve the correct Activity Space from the cache 
        // but in this case, if there's more than one GroupEditor, it will get the wrong one and
        // render the wrong model data. Calling SetLinkGetCachedSpace will include this specific
        // activity space that is needed to display the correct results.
        //statusPopup.SetLinkGetSpaceIfCached(GroupEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
        statusPopup.SetLinkGetCachedSpace(m_asOwner);
        statusPopup.SetDisplayPage(GroupDynamicMembersPreviewPopupDP.STR_MVC_CLASS_NAME);
        statusPopup.SetControl(GroupRepostControl.STR_MVC_CLASS_NAME);
        // Javascript: Open the popup
        sb = new XPStringBuilder(200);
        sb.Append("window.open(\'").Append(statusPopup.GetURLAsString()).Append("\', \'MembershipPreview\', \'scrollbars=yes,location=no,menubar=no,height=400,width=400\');\n");
        log.Debug("statusPopup = [" + statusPopup.GetURLAsString() + "]");
        log.Debug("Current number of items in GroupEditorAS.strStorageDynMemberPreviewPopup: " + ((SelectPTObjectModel) m_asOwner.GetModel(GroupEditorAS.strStorageDynMemberPreviewPopup)).GetItems().GetCount());
        // aj: always add the javascript to the head of the dynamic rules DP,
        //     current page causes the _last_ page viewed to get the jscript in its head...
        myScript.AddInnerHTMLString(sb.ToString());
        ((EditorDP) ((EditorAS) m_asOwner).GetPage(GroupDynamicRulesDP.STR_MVC_CLASS_NAME)).AddScriptToHead(myScript);
        }
      catch (Exception e)
      {
        log.Error(e, "Unknown error attempting to open Preview Popup. e: " + e.Message);
        }
      // SE: logging
      log.FunctionEnd("GroupRepostControl::PerformPreviewPopup");
    }
  }
}