using System;
// Foundation Imports
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.group
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the the Select List.
  /// The Select List is a list of objects.
  /// New objects can be added to the list by selecting
  /// them from the associated Object tree.
  /// The list is by default sorted by name ascending.
  /// </summary>
  /// <author>RickyW</author>
  public class SelectActivityRightsModel : ExpListModel,ISelectActivityRightsModelRO
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SelectActivityRights";
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_NAME_SELECTTREE = "SelectActivityRightsTree";
    
    /// <summary>
    /// Number total of columns 
    /// </summary>
    public const int EXPLIST_COL_MAX = 4;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_CLASSID = 1;
    
    /// <summary>
    /// This column contains the Object IDs.
    /// </summary>
    public const int EXPLIST_COL_OBJECTID = 2;
    
    /// <summary>
    /// This is the String that we doisplay in the list.
    /// E.g.: Object name or folder path.
    /// </summary>
    public const int EXPLIST_COL_STRING = 3;
    
    /// <summary>
    /// Default initial size for the sorted array.
    /// </summary>
    public const int EXPLIST_DEFAULT_INITIAL_SIZE = 50;
    
    /// <summary>
    /// Is this instance for inherited rights?  Defaults to no.
    /// </summary>
    protected bool m_bIsInherited;
    
    /// <summary>
    /// Icon to display on each row, just before the input text. 
    /// </summary>
    protected PTImageType m_imgRowIcon;
    
    /// <summary>
    /// Tree Space ID. The first time the ID is empty and a new AS is opened,
    /// but after that, we save the ID and the same tree AS is reopened each time. 
    /// </summary>
    protected String m_sTreeSpaceID = "";
    
    /// <summary>
    /// Class ID of the Objects displayed on the list. 
    /// </summary>
    protected int[] m_arrObjectClassIDs;
    
    /// <summary>
    /// Clear the list and add all the values from the tree.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      SaveTreeID(_htFormData);
      ActivityRightsTreeAS asTree = (ActivityRightsTreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_NAME_SELECTTREE));
      if (null != asTree)
      {
        ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList mySelected = myTree.GetSelectedItems();
        Object[] oNewRow;
        // JF- We clear the array before we start adding the selected items from the tree.
        base.GetItems().ClearArray();
        for (int i = 0;i < mySelected.GetSize();i++)
        {
          oNewRow = new Object[EXPLIST_COL_MAX];
          oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
          m_nNextIndex++;
          oNewRow[EXPLIST_COL_CLASSID] = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
          oNewRow[EXPLIST_COL_OBJECTID] = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
          oNewRow[EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
          base.GetItems().AddRow(oNewRow);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SelectActivityRightsModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the array of Class ID of the Objects
    /// displayed on the list as a String.
    /// E.g.: "2,45,3"
    /// This is the format used by the tree.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetObjectClassIDs()
    {
      String sClassIDs = "";
      // JF- We loop through the array of IDs and add each ID 
      // to the String.
      for (int i = 0;i < m_arrObjectClassIDs.Length;i++)
      {
        if (0 != sClassIDs.Length)
        {
          sClassIDs+=",";
        }
        sClassIDs+=(XPConvert.ToString(m_arrObjectClassIDs[i]));
      }
      return sClassIDs;
    }
    
    /// <summary>
    /// Returns the icon to display on each row before the
    /// input text.
    /// If the value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    public virtual PTImageType GetRowIcon()
    {
      return m_imgRowIcon;
    }
    
    /// <summary>
    /// Returns a String of Activity Right Object IDs.
    /// E. g.: "ObjID1, objID2, objID3, etc"
    /// This is the format used by this tree.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSelectedItems()
    {
      String sSelectedItems = "";
      // RW - loop through array and add object id to string
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        // JS- Add the separator
        if (0 != sSelectedItems.Length)
        {
          sSelectedItems+=",";
        }
        sSelectedItems+=m_saData.GetItem(i, EXPLIST_COL_OBJECTID);
      }
      return sSelectedItems;
    }
    
    /// <summary>
    /// Returns tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetTreeSpaceID()
    {
      return m_sTreeSpaceID;
    }
    
    /// <summary>
    /// Returns whether this list is inherited rights.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetIsInherited()
    {
      return m_bIsInherited;
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    /// <param name="_bIsInherited">are we dealing with inherited rights.</param>
    public virtual void InitializeSelectList(String _sSectionTitle, String _sSectionSubTitle,
     PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs,
     int _nListKey, bool _bIsInherited)
    {
      Object[][] arrExpListColInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = !_bIsInherited;
      m_arrObjectClassIDs = _arrObjectClassIDs;
      m_bIsInherited = _bIsInherited;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING};
      // JF- Sort array
      // The growable array will always be sorted by the String column (the one displayed).
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_STRING;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null bellow)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Add the array passed in argument to the list.
    /// The array should be created using the EXPLIST_COL
    /// constants defined in this class.
    /// </summary>
    /// <param name="_arrRows">Array of rows to add.</param>
    public virtual void SetDefaultObjects(Object[][] _arrRows)
    {
      base.GetItems().AddRows(_arrRows);
    }
    
    /// <summary>
    /// Because this select list needs to support both move
    /// row actions enable and disable, we need to change the
    /// colspan of the header row when this happens.
    /// </summary>
    /// <param name="_bEnableMoveRowActions"></param>
    public override void SetEnableMoveRowActions(bool _bEnableMoveRowActions)
    {
      base.SetEnableMoveRowActions(_bEnableMoveRowActions);
      if (m_bEnableMoveRowActions)
      {
        // JF- If the move row actions are enabled, this will 
        // create one more cell at the end of each row and 
        // we need to reflect that change on the header row.
        m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      } else
      {
        m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      }
    }
    
    /// <summary>
    /// Sets the icon to display on each row before the
    /// input text.
    /// By default, no icon is displayed.
    /// </summary>
    /// <param name="_imgRowIcon"></param>
    public virtual void SetRowIcon(PTImageType _imgRowIcon)
    {
      m_imgRowIcon = _imgRowIcon;
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      // JF- Nothing to save on repost.
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Helper method to save the Tree ID on repost.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    protected virtual void SaveTreeID(XPHashtable _htFormData)
    {
      // JF- We save the tree ID only if we don't already have it.
      if (("").Equals(m_sTreeSpaceID) && _htFormData.ContainsKey(GetUniqueString(SelectActivityRightsView.HTMLINPUT_TREEASID)))
      {
        String[] data = (String[]) _htFormData.GetElement(GetUniqueString(SelectActivityRightsView.HTMLINPUT_TREEASID));
        if ((null != data) && !(0 == data.Length))
        {
          m_sTreeSpaceID = data[0];
        }
      }
    }
  }
}