using System;
// Foundation Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.group
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Select List list.
  /// Is constains the HTML to display the object Array.
  /// It gets the data to display from SelectActivityRightsModel.
  /// </summary>
  /// <author>RickyW</author>
  public class SelectActivityRightsView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.group.SelectActivityRightsView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SelectActivityRights";
    
    /// <summary>
    /// HTML Object names 
    /// </summary>
    public const String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SelectActivityRightsView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      // The URL to open a new tree
      ASURL myNewTree = new ASURL(m_asOwner);
      // Tree creation and binding
      myNewTree.SetLinkCreateNewSpace(ActivityRightsTreeAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      myNewTree.SetSubSpaceKey(((ISelectActivityRightsModelRO) m_model).GetUniqueString(SelectActivityRightsModel.SUBSPACE_NAME_SELECTTREE));
      myNewTree.SetControl(ActivityRightsStartTreeControl.STR_MVC_CLASS_NAME);
      // Tree configuration
      myNewTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
      myNewTree.AddControlArgument(AStartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      myNewTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
       ((ISelectActivityRightsModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID));
      myNewTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL, ((ISelectActivityRightsModelRO) m_model).GetUniqueString("OnReturnFromTree"));
      myNewTree.AddControlArgument(AStartTreeControl.CLASS_IDS_TO_DISPLAY,
       ((ISelectActivityRightsModelRO) m_model).GetObjectClassIDs());
      myNewTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
      myNewTree.AddControlArgument(ActivityRightsStartTreeControl.SELECTED_ITEMS,
       ((ISelectActivityRightsModelRO) m_model).GetSelectedItems());
      myNewTree.AddControlArgument(AStartTreeControl.TITLE, m_asOwner.GetString(425,
       "ptmsgs_portaladminmsgs"));
      // set the subtitle display string
      myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(1832,
       "ptmsgs_portaladminmsgs"));
      // The url to open a previously opened server user tree
      // This needs to have the SpaceID added to it.
      ASURL myOldTree = new ASURL(m_asOwner);
      myOldTree.SetLinkCreateNewSpace(ActivityRightsTreeAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      XPStringBuilder sb;
      try
      {
        // Open Tree function
        sb = new XPStringBuilder(200);
        sb.Append("function " + ((ISelectActivityRightsModelRO) m_model).GetUniqueString("OpenTree") + "(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\', \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(myOldTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // On return from Tree function
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((ISelectActivityRightsModelRO) m_model).GetUniqueString("OnReturnFromTree") + "()");
        sb.Append(" {");
        sb.Append(" \tpostToSelf(\'" + ((ISelectActivityRightsModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "\');");
        sb.Append(" }");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "SelectActivityRightsView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // row icon
      PTImageType imgRowIcon = ((ISelectActivityRightsModelRO) m_model).GetRowIcon();
      if (null != imgRowIcon)
      {
        myCell.AddInnerHTMLElement(GetIcon(imgRowIcon));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      // Object Name
      Object oListName = _saData.GetItem(_nRowIndex, SelectActivityRightsModel.EXPLIST_COL_STRING);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode((String) oListName));
      if (((ISelectActivityRightsModelRO) m_model).GetEnableMoveRowActions())
      {
        result.AddInnerHTMLElement(base.GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the space below the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      if (((ISelectActivityRightsModelRO) m_model).GetIsInherited())
      {
        // this is a inherited rights list
        // we want to display some messages
        HTMLTable myTable;
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        myTable = new HTMLTable();
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // add a spacer			
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myTable.AddInnerHTMLElement(myRow);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        // need to determine if there are any items
        IPTGrowableSortedArrayWrapperRO saData = ((IExpListModelRO) m_model).GetReadOnlyItems();
        if (0 == saData.GetCount())
        {
          // if list is empty use this empty list string
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell.AddInnerHTMLString(m_asOwner.GetString(2167, "ptmsgs_portaladminmsgs"));
          } else
        {
          // list is not empty, use this description string
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell.AddInnerHTMLString(m_asOwner.GetString(2166, "ptmsgs_portaladminmsgs"));
          }
        return myTable;
      } else
      {
        // not a inherited rights list
        // proceed as normal
        return null;
      }
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      myAddIcon.SetAlt("");
      myAddIcon.SetAlign("absmiddle");
      // Object icon
      myConstruct = UIConstructFactory.GetConstruct(((ISelectActivityRightsModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(((ISelectActivityRightsModelRO) m_model).GetUniqueString("OpenTree") + "(document." + AFormDP.HTMLFORM_NAME + "." + ((ISelectActivityRightsModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID) + "); return false;");
      myAnchor.AddInnerHTMLElement(myAddIcon);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(((ISelectActivityRightsModelRO) m_model).GetAddLabel());
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(SPACE);
      // hidden input with the tree space ID
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ((ISelectActivityRightsModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID),
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((ISelectActivityRightsModelRO) m_model).GetTreeSpaceID());
      return myCell;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
  }
}