using System;
//Server import
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.sendinvitation;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.invitation
{
  /// <summary>
  /// This Section contains the HTML for the dependencies page.
  /// </summary>
  /// <author></author>
  public class InvitationDependenciesView : ObjDependenciesView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.invitation.InvitationDependenciesView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "InvitationDependencies";
    
    /// <summary>
    /// Send Invitation javascript function name 
    /// </summary>
    public const String JAVASCRIPT_SEND_INVITATION = "sendInvitation";
    //Member variables
    private CreatedHelper m_chHelper = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new InvitationDependenciesView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Adds javascript for creating or adding to jobs
    /// </summary>
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      try
      {
        ASURL sendInvitationURL = new ASURL(m_asOwner);
        sendInvitationURL.SetLinkCreateNewSpace(SendInvitationAS.STR_MVC_CLASS_NAME,
         m_asOwner.GetParentSpace());
        sendInvitationURL.SetControl(InvCodesListControl.STR_MVC_CLASS_NAME);
        // This must be the last argument so we can append the profile ID
        sendInvitationURL.AddControlArgument(InvCodesListModel.CONTROLARGUMENT_OBJECTID,
         ((ObjEditorModel) m_model).GetObjectID());
        XPStringBuilder sb = new XPStringBuilder(500);
        // Send an invitation function
        sb.Append("function ").Append(JAVASCRIPT_SEND_INVITATION).Append("()\n");
        sb.Append("{\n");
        sb.Append("    window.close();");
        sb.Append("    window.opener.location = \'").Append(sendInvitationURL.GetURLAsString()).Append("\'").Append(";\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "CrawlerDependenciesView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_chHelper = new CreatedHelper(parent, (InvitationModel) model);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()"></seealso>
    protected override HTMLElementCollection GetHTMLForDependencies()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        //Display the standard success message
        m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2210,
         "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(),
         ((ObjEditorModel) m_model).GetParentFolderPath());
        //Display the sync user target folder
        IPTInvitation myInvite = (IPTInvitation) ((ObjEditorModel) m_model).GetObject();
        int intUserFolderID = myInvite.GetUserFolderID();
        IPTSession mySession = (IPTSession) m_asOwner.GetUserSession();
        // get the name
        IPTAdminFolder myFolder = mySession.GetAdminCatalog().OpenAdminFolder(intUserFolderID,
         false);
        String strName = myFolder.GetLocalizedName();
        m_chHelper.displayTextRow(result, m_asOwner.GetString(2211, "ptmsgs_portaladminmsgs") + strName,
         null);
        //Display the folder for users
        m_chHelper.beginList(result);
        //Display the send invitation link
        m_chHelper.displayListRowAnchor(result, m_asOwner.GetString(2212,
         "ptmsgs_portaladminmsgs"), JAVASCRIPT_SEND_INVITATION + "()");
      }
      catch (Exception e)
      {
      }
      //Report the error
      return result;
    }
  }
}