using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.defaultprofile;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.invitation
{
  public class InvitationModel : ObjEditorModel,IInvitationModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.invitation.InvitationModel");
    public const String STR_MVC_CLASS_NAME = "Invitation";
    public const String m_sProfileSubspaceKey = "ProfileEditor";
    private String m_sUserTreeSpaceID = "Default Data";
    private Object[][] m_objEveryone;
    private Object[] m_objUserGroups = null;
    //member variables with default settings
    // DCA - Invalid ID
    private int m_nDefaultProfileID = -1;
    // DCA - Invalid ID
    private int m_nUserFolderID = -1;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new InvitationModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      try
      {
        ((IPTInvitation) m_ptObject).SetDefaultProfileID(m_nDefaultProfileID);
        }
      catch (Exception e)
      {
        log.Error("InvitationModel::DoTaskBeforeStore Unable to set the Default Profile ID: " + m_nDefaultProfileID + ". The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(444, "ptmsgs_portaladminmsgs"),
         e);
      }
      try
      {
        ((IPTInvitation) m_ptObject).SetUserFolderID(m_nUserFolderID);
      }
      catch (Exception e)
      {
        log.Error("InvitationModel::DoTaskBeforeStore Unable to set the User Folder ID: " + m_nDefaultProfileID + ". The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(446, "ptmsgs_portaladminmsgs"),
         e);
      }
      // convert m_objUserGroups back to Object[] for Invitation object to store
      PTGrowableSortedArrayWrapper aUserGroups = ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject)).GetItems();
      m_objUserGroups = new Object[aUserGroups.GetCount() - 1];
      int index = aUserGroups.GetCount();
      for (int i = 0;i < aUserGroups.GetCount();i++)
      {
        if (XPConvert.ToInteger(aUserGroups.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID)) == PT_INTRINSICS.PT_USERGROUP_EVERYONE)
        {
          index = i;
        }
        if (i > index)
        {
          ((Object[]) m_objUserGroups)[i - 1] = aUserGroups.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
          } else
        if (i < index)
        {
          ((Object[]) m_objUserGroups)[i] = aUserGroups.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
          }
      }
      try
      {
        ((IPTInvitation) m_ptObject).SetUserGroupIDs(m_objUserGroups);
      }
      catch (Exception e)
      {
        log.Error("InvitationModel::DoTaskBeforeStore Unable to set the User Group IDs. " + "The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(447, "ptmsgs_portaladminmsgs"),
         e);
      }
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        } else
      {
        // ***CHANGE_HERE SECURITY PAGE*** Hide the security page in edit mode
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        try
        {
          m_nDefaultProfileID = ((IPTInvitation) m_ptObject).GetDefaultProfileID();
          }
        catch (Exception e)
        {
          log.Error("InvitationModel::DoTaskOnStartEditor Unable to get the Default Profile ID. The following exception occured: " + e);
          //DCA - invalid ID
          m_nDefaultProfileID = -1;
        }
        try
        {
          m_nUserFolderID = ((IPTInvitation) m_ptObject).GetUserFolderID();
          }
        catch (Exception e)
        {
          log.Error("InvitationModel::DoTaskOnStartEditor Unable to get the User Folder ID. The following exception occured: " + e);
          //DCA - invalid ID
          m_nUserFolderID = -1;
        }
        try
        {
          m_objUserGroups = (Object[]) ((IPTInvitation) m_ptObject).GetUserGroupIDs();
          }
        catch (Exception e)
        {
          log.Error("InvitationModel::DoTaskOnStartEditor Unable to get the User Group IDs. The following exception occured: " + e);
          //DCA - invalid user groups object
          m_objUserGroups = null;
        }
      }
      try
      {
        PTObjectManagerQueryWrapper omUserGroups = new PTObjectManagerQueryWrapper(m_Session.GetUserGroups());
        omUserGroups.QuerySingleObject(PT_INTRINSICS.PT_USERGROUP_EVERYONE);
        IASQueryResult qrEveryone = (IASQueryResult) omUserGroups;
        m_objEveryone = new Object[1][];
        for (int j2c_index = 0;j2c_index < 1;j2c_index++)
        {
          m_objEveryone[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
          }
        m_objEveryone[0][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject)).m_nNextIndex;
        ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject)).m_nNextIndex++;
        m_objEveryone[0][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
        m_objEveryone[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = qrEveryone.GetFields(0,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        m_objEveryone[0][SelectPTObjectModel.EXPLIST_COL_STRING] = qrEveryone.GetFields(0,
         PT_PROPIDS.PT_PROPID_NAME);
      }
      catch (Exception e)
      {
        log.Error("InvitationModel::DoTaskOnStartEditor Unable to set the everyone user group. The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(451, "ptmsgs_portaladminmsgs"),
         e);
      }
      try
      {
        // convert m_objUserGroups to an Object[][] to pass to SelectPTObject;
        Object[][] objUserGroups = new Object[((Object[]) m_objUserGroups).Length][];
        Object[] objGroup;
        for (int i = 0;i < ((Object[]) m_objUserGroups).Length;i++)
        {
          objGroup = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
          objGroup[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject)).m_nNextIndex;
          ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject)).m_nNextIndex++;
          IASQueryResult qrAGroup;
          PTObjectManagerQueryWrapper omUserGroups = new PTObjectManagerQueryWrapper(m_Session.GetUserGroups());
          omUserGroups.QuerySingleObject(XPConvert.ToInteger(((Object[]) m_objUserGroups)[i]));
          qrAGroup = (IASQueryResult) omUserGroups;
          objGroup[SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
          objGroup[SelectPTObjectModel.EXPLIST_COL_OBJECTID] = qrAGroup.GetFields(0,
           PT_PROPIDS.PT_PROPID_OBJECTID);
          objGroup[SelectPTObjectModel.EXPLIST_COL_STRING] = qrAGroup.GetFields(0,
           PT_PROPIDS.PT_PROPID_NAME);
          objUserGroups[i] = objGroup;
        }
        m_objUserGroups = objUserGroups;
      }
      catch (Exception e)
      {
        log.Error("InvitationModel::DoTaskOnStartEditor Unable to set User Groups. The following exception occured: " + e);
        m_objUserGroups = null;
      }
      StartSelectPTObject();
    }
    
    /// <summary>
    /// Returns the User TreeSpace ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetAccessEdit()
    {
      return XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
    }
    
    /// <summary>
    /// Returns the Default Profile ID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetDefaultProfileID()
    {
      return m_nDefaultProfileID;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Get Profiles
    /// </summary>
    /// <returns>IASQueryResult</returns>
    public virtual IASQueryResult GetProfiles()
    {
      IASQueryResult result;
      try
      {
        PTObjectManagerQueryWrapper omqr = new PTObjectManagerQueryWrapper(m_Session.GetUsers());
        omqr.SimpleQuery(PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES, PT_PROPIDS.PT_PROPID_NAME);
        result = omqr;
      }
      catch (Exception e)
      {
        log.Error("InvitationModel::GetProfiles Unable to get the profiles for Drop Down Menu. " + "The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(445, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the User Folder ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetUserFolderName()
    {
      String folderName;
      try
      {
        IPTAdminFolder objAdminFolder = m_Session.GetAdminCatalog().OpenAdminFolder(m_nUserFolderID,
         false);
        folderName = objAdminFolder.GetLocalizedName();
      }
      catch (Exception e)
      {
        log.Error("InvitationModel::GetUserFolderName Unable to get the Users\' Folder Name. The following exception occured: " + e);
        return null;
      }
      return folderName;
    }
    
    /// <summary>
    /// Returns the User Groups Object.
    /// </summary>
    /// <returns>int</returns>
    public virtual Object GetUserGroups()
    {
      return m_objUserGroups;
    }
    
    /// <summary>
    /// Returns the User TreeSpace ID.
    /// </summary>
    /// <returns>int</returns>
    public virtual String GetUserTreeSpaceID()
    {
      return m_sUserTreeSpaceID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        // ***CHANGE_HERE SELECTPTOBJECT***
        // if this is the display page where you have your select ptobject you need to
        // call the associated saveSection method.
        nPageStatus = ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject)).SaveSection(_htFormData);
        // change default profile to profile selected
        String[] data;
        data = (String[]) _htFormData.GetElement(GenInfoView.HTMLSELECT_INV_USERPROF);
        int _profileID = XPConvert.ToInteger(data[0]);
        if (_profileID == -1)
        {
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        } else
        {
          SetDefaultProfileID(_profileID);
        }
        // set m_sUserTreeSpaceID if found in _htFormData
        data = (String[]) _htFormData.GetElement(GenInfoView.HTMLHIDDEN_USERTREESPACEID);
        if (data != null)
        {
          SetUserTreeSpaceID(data[0]);
        }
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Sets the new Default Profile ID in a member variable.
    /// </summary>
    /// <param name="_nDefaultProfileID"></param>
    public virtual void SetDefaultProfileID(int _nDefaultProfileID)
    {
      m_nDefaultProfileID = _nDefaultProfileID;
      log.Debug("InvitationModel::SetDefaultProfile New Default Profile ID: " + _nDefaultProfileID);
      }
    
    /// <summary>
    /// Sets the new User Folder ID in a member variable. 
    /// </summary>
    /// <param name="_nUserFolderID"></param>
    public virtual void SetUserFolderID(int _nUserFolderID)
    {
      m_nUserFolderID = _nUserFolderID;
      log.Debug("InvitationModel::SetUSerFolder New User Folder ID: " + _nUserFolderID);
      }
    
    /// <summary>
    /// Sets the new User Folder ID in a member variable.
    /// </summary>
    /// <param name="_nUserFolderID"></param>
    public virtual void SetUserFolderOnRepost()
    {
      TreeAS asUserTree = (TreeAS) m_asOwner.GetSubSpace("UserTree");
      if (asUserTree != null)
      {
        ITreeModelRO myTree = (ITreeModelRO) asUserTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList mySelected = myTree.GetSelectedItems();
        for (int i = 0;i < mySelected.GetSize();i++)
        {
          m_nUserFolderID = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
          log.Debug("InvitationModel::SetUserFolder New User Folder ID: " + m_nUserFolderID);
          }
      }
    }
    
    /// <summary>
    /// Sets the new User Groups Object in a member variable.
    /// </summary>
    /// <param name="_nUserFolderID"></param>
    public virtual void SetUserGroups(Object[] _objUserGroups)
    {
      m_objUserGroups = _objUserGroups;
      log.Debug("InvitationModel::SetUserGroups New User Groups Object was set.");
      }
    
    /// <summary>
    /// Sets the new User TreeSpace ID in a member variable.
    /// </summary>
    /// <param name="_sUserTreeSpaceID"></param>
    public virtual void SetUserTreeSpaceID(String _sUserTreeSpaceID)
    {
      m_sUserTreeSpaceID = _sUserTreeSpaceID;
      log.Debug("InvitationModel::SetUserTreeSpaceID New User TreeSpace ID: " + _sUserTreeSpaceID);
      }
    
    /// <summary>
    /// Helper method to start the Select PTObject List.
    /// </summary>
    public virtual void StartSelectPTObject()
    {
      SelectPTObjectModel myPTObjectModel = ((SelectPTObjectModel) m_asOwner.GetModel(InvitationEditorAS.strStorageSelectPTObject));
      // ***GroupList*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _sSectionSubTitle: Sub title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      myPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(453, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(454, "ptmsgs_portaladminmsgs"), PTImageType.ICON_GROUP,
       m_asOwner.GetString(455, "ptmsgs_portaladminmsgs"), new int[]{PT_CLASSIDS.PT_USERGROUP_ID},
       1);
      // ***GroupList*** Optional setting
      //     Use the method bellow to set the icon to display on each row.
      //     (By default there will be no icon.)
      myPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_GROUP);
      myPTObjectModel.SetTreeTitle(m_asOwner.GetString(2213, "ptmsgs_portaladminmsgs"));
      myPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(2214, "ptmsgs_portaladminmsgs"));
      // adds the everyone group to the GroupList by default and make it undeletable
      if (m_objEveryone != null && m_objEveryone[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID] != null)
      {
        myPTObjectModel.SetDefaultObjects(m_objEveryone);
        int[][] hiddenObject = new int[1][];
        for (int j2c_index = 0;j2c_index < 1;j2c_index++)
        {
          hiddenObject[j2c_index] = new int[2];
        }
        hiddenObject[0][SelectPTObjectModel.HIDE_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
        hiddenObject[0][SelectPTObjectModel.HIDE_COL_OBJECTID] = XPConvert.ToInteger(m_objEveryone[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID]);
        myPTObjectModel.SetHiddenObjects(hiddenObject);
      }
      if (m_objUserGroups != null)
      {
        myPTObjectModel.GetItems().AddRows((Object[][]) m_objUserGroups);
        }
    }
    
    /// <summary>
    /// Return the ASURL object going to the Profile Editor as a sub Editor.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor.
    /// If we are going to a new sub Editor, the key can be null and
    /// we will just pass in the default key. If we are going back to an
    /// existing sub Editor, it should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    public virtual ASURL GetASURLToSubEditor()
    {
      ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(EditDefaultProfileAS.STR_MVC_CLASS_NAME,
       m_sProfileSubspaceKey, EditorStartControl.EDITOR_START_FLAG_EDIT, ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
       XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
      return myPopUpURL;
    }
  }
}