using System;
// Framework Imports
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.job
{
  /// <summary>
  /// This class extends EditorDP and displays the History
  /// page of the Job Editor.
  /// </summary>
  public class HistoryDP : EditorDP
  {
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobHistory";
    
    /// <summary>
    /// Displays some HTML after the body tag and before the form tag.
    /// For example this is used by pages using a DHTML calendar to display the div tag.
    /// The function is optional.  If it exists, it will be called by the framework, and
    /// the resulting HTMLElement will be added in the right place.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElementCollection DisplayHTMLBeforeForm()
    {
      //Display the DIV tag required for the Date picker control
      IJobLogModelRO ptROModel = (IJobLogModelRO) m_asOwner.GetModel(JobLogModel.STR_MVC_CLASS_NAME);
      return ptROModel.GetDatePickerControlManager().GetPagePreFormContent();
      }
    
    /// <summary>
    /// Returns the HTML that is placed in the HEAD section of this HTML page.
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    public override HTMLElementCollection DisplayHTMLinHEAD()
    {
      HTMLElementCollection retVal = new HTMLElementCollection();
      IJobLogModelRO ptROModel = (IJobLogModelRO) m_asOwner.GetModel(JobLogModel.STR_MVC_CLASS_NAME);
      JSDatePickerMgr ptDatePickerMgr = ptROModel.GetDatePickerControlManager();
      retVal.AddInnerHTMLElement(ptDatePickerMgr.GetJSIncludes());
      return retVal;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(457, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the Job History page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(m_asOwner.GetView(HistoryView.STR_MVC_CLASS_NAME).Display());
      //Add menu bar construct here, along with job list
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(HistoryView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
  }
}