using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
namespace com.plumtree.portalpages.admin.editors.job
{
  /// <version>$Revision$</version>
  /// <author>$author$</author>
  public interface IJobModelRO : IObjEditorModelRO
  {
    
    /// <summary>
    /// Returns Continue on errors setting.
    /// </summary>
    /// <returns>int</returns>
    int GetContinue();
    
    /// <summary>
    /// Returns Log Level setting.
    /// </summary>
    /// <returns>int</returns>
    int GetLogLevel();
    
    /// <summary>
    /// Returns Array of Operations.
    /// </summary>
    /// <returns>PTGrowableSortedArrayWrapper</returns>
    PTGrowableSortedArrayWrapper GetOperations();
    
    /// <summary>
    /// Returns Recurrence Interval setting.  For example
    /// this job will run every N minutes, where N is the recurrence interval.
    /// </summary>
    /// <returns>int</returns>
    int GetRecurrenceInterval();
    
    /// <summary>
    /// Returns Restrictions setting. (0 = none (default), 1 = No Weekday, 2 =
    /// No weekend)
    /// </summary>
    /// <returns>int</returns>
    int GetRestrictions();
    
    /// <summary>
    /// Returns Schedule Type setting. 0=NEVER, 1=ONCE, >1=PERIODICALLY.  Valid
    /// values are:
    /// PT_SCHEDULETYPE_NEVER = 0 PT_SCHEDULETYPE_ONCE = 1
    /// PT_SCHEDULETYPE_MINUTELY = 2 PT_SCHEDULETYPE_HOURLY = 3
    /// PT_SCHEDULETYPE_DAILY = 4 PT_SCHEDULETYPE_WEEKLY = 5
    /// PT_SCHEDULETYPE_MONTHLY = 6 PT_SCHEDULETYPE_ANNUALLY = 7
    /// </summary>
    /// <returns>int</returns>
    int GetScheduleType();
    
    /// <summary>
    /// Returns Suspend Checkpoint Interval setting.
    /// </summary>
    /// <returns>int</returns>
    int GetSuspendCheckpointInterval();
    
    /// <summary>
    /// Returns Suspend Mode setting:  One of PT_SCHEDULE_SUSPEND_MODES:
    /// PT_SCHEDULE_WORK_CONTINUOUSLY (Default),
    /// PT_SCHEDULE_SUSPEND_ON, PT_SCHEDULE_WORK_ON
    /// </summary>
    /// <returns>int</returns>
    int GetSuspendMode();
    
    /// <summary>
    /// Returns timeout setting.
    /// </summary>
    /// <returns>int</returns>
    int GetTimeout();
    
    /// <summary>
    /// Returns timeout units setting.
    /// </summary>
    /// <returns>int</returns>
    int GetTimeoutUnits();
    
    /// <summary>
    /// Returns true if the Add an Operation table on the Main DP should not be
    /// displayed.
    /// </summary>
    /// <returns>boolean</returns>
    bool IsAddOperationDisabled();
    
    /// <returns>XPLocale</returns>
    XPLocale GetLocale();
    
    /// <returns>XPTimeZone</returns>
    XPTimeZone GetTimezone();
    
    /// <summary>
    /// Returns the format pattern for the current locale so that it can be passed into
    /// the date picker control
    /// </summary>
    /// <returns>String</returns>
    String GetDateFormatPattern();
    
    /// <summary>
    /// Get the Date Time picker control manager
    /// </summary>
    /// <returns>JSDateTimePickerMgr</returns>
    JSDateTimePickerMgr GetDateTimePickerControlManager();
    
    /// <summary>
    /// Get the Date Time for the RunOnceNow option
    /// </summary>
    /// <returns>XPDateTime</returns>
    XPDateTime GetRunOnceNowDateTime();
    
    /// <summary>
    /// Returns whether the Folder containing this Job is assigned to any Automation Server
    /// </summary>
    /// <returns>boolean</returns>
    bool IsJobFolderRegistered();
  }
}