using System;
// UI Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.job
{
  /// <summary>
  /// This class is used to register the Model and Display Pages
  /// created for the Job Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.  The Operation Section is implemented with an expandable
  /// list, and therefore doesn't have a corresponding view class.
  /// </summary>
  public class JobEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.job.JobEditorAS");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobEditor";
    
    /// <summary>
    /// A constant for the Select PTObject storage name 
    /// </summary>
    public const String m_strStorageSelectPTObject = "SelectPTObjectJob";
    
    /// <summary>
    /// The class name for the tip writer 
    /// </summary>
    private const String sClassName = "com.plumtree.portalpages.admin.editors.job.JobEditorAS";
    
    /// <summary>
    /// Unique identifier for the Run Once date picker 
    /// </summary>
    public const String RUN_ONCE_DATEPICKER = "DTP_RunOnce";
    
    /// <summary>
    /// Unique identifier for the Run Once date picker 
    /// </summary>
    public const String NEXT_RUN_DATEPICKER = "DTP_NextRun";
    
    /// <summary>
    /// Unique identifier for the Run Once date picker 
    /// </summary>
    public const String NOT_AFTER_DATEPICKER = "DTP_NotAfter";
    
    /// <summary>
    /// Unique identifier for the suspend begin time picker 
    /// </summary>
    public const String SUSPEND_BEGIN_TIMEPICKER = "TP_Begin";
    
    /// <summary>
    /// Unique identifier for the suspend end time picker 
    /// </summary>
    public const String SUSPEND_END_TIMEPICKER = "TP_End";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (JobDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return (GetString(458, "ptmsgs_portaladminmsgs"));
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2619, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (JobRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = JobModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      MainDP jobMainDP = new MainDP();
      RegisterView(JobDependenciesView.STR_MVC_CLASS_NAME, myModel);
      RegisterPage(jobMainDP);
      jobMainDP.AddToValidationFunction("WarnFolderRegistered");
      RegisterPage(new HistoryDP());
      //Register the classes from the joblogs package
      RegisterModel(JobLogModel.STR_MVC_CLASS_NAME);
      IModel myJobLogModel = GetModel(JobLogModel.STR_MVC_CLASS_NAME);
      RegisterView(HistoryView.STR_MVC_CLASS_NAME, myJobLogModel);
      RegisterControl(JobLogRepostControl.STR_MVC_CLASS_NAME, myJobLogModel);
      // Register Views
      // Register the select PTObject list as a plug-in section
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, m_strStorageSelectPTObject);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel mySelectPTObjectModel = GetModel(m_strStorageSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, m_strStorageSelectPTObject,
       mySelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, m_strStorageSelectPTObject,
       mySelectPTObjectModel);
      //RegisterView(OperationView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(TimeoutView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ScheduleView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(LoggingView.STR_MVC_CLASS_NAME, myModel);
      // Job Log Download Page -- this needs to be registered after
      // the Job Log Model.
      RegisterPage(new JobLogDownloadDP());
      // Register Controls
      RegisterControl(JobRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Default page
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      // BEGIN Sub menu "Main Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(460, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, HistoryDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1839, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 42;
          int iTipId = 43;
          int iSecondaryTipId = 44;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()">Sets the help links for the job editor</seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Job_MainSettings");
      } else
      if (HistoryDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Job_JobHistory");
      }
    }
  }
}