using System;
// Framework Imports
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.admin.editors.job
{
  /// <summary>
  /// Delete that class if you don't have any repost actions.***
  /// </summary>
  public class JobRepostControl : ObjEditorRepostControl
  {
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobRepost";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobRepostControl();
    }
    //Repost actions
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      switch (_nAction){
      // JHQ 010804: bug 26619 - if Finish action is triggered and caused
      // a PAGE_STATUS_INVALID, and this job was scheduled to be deleted 
      // after running; then we should just inform the user that this job
      // has been deleted and they need to cancel.
      case POSTTOSELF_ACTION_FINISH:
      // the pagestatus will be invalid if this job was to be deleted 
      // after completion.
      IPTJob myJob = (IPTJob) ((JobModel) m_model).GetObject();
      if (PAGE_STATUS_INVALID == m_nPageStatus && myJob.GetDeleteWhenDone())
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(2648, "ptmsgs_portaladminmsgs"), "Cannot save job " + ((JobModel) m_model).GetObjectID() + " because it was set to be deleted when done.");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return;
      }
      break;
      }
      if (!((JobModel) m_model).IsAddOperationDisabled())
      {
        // You need to call the PerformRepostAction on the select ptobject control
        ((ExpListControl) m_asOwner.GetControl(JobEditorAS.m_strStorageSelectPTObject)).PerformRepostAction(_nAction,
         m_htFormData);
      }
      //Call the repost action on the JobLogRepostControl
      JobLogRepostControl myControl = (JobLogRepostControl) m_asOwner.GetControl(JobLogRepostControl.STR_MVC_CLASS_NAME);
      Redirect _redirect = myControl.CheckActionSecurityAndExecute(m_htFormData);
      //set the redirect
      if (_redirect != null)
      {
        SetRedirect(_redirect);
      }
    }
    protected override void PerformReadOnlyAction(int _nAction)
    {
      base.PerformReadOnlyAction(_nAction);
      SaveCurrentPage();
      //Call the repost action on the JobLogRepostControl
      JobLogRepostControl myControl = (JobLogRepostControl) m_asOwner.GetControl(JobLogRepostControl.STR_MVC_CLASS_NAME);
      myControl.MyPerformReadOnlyAction(_nAction, m_htFormData);
    }
  }
}