using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.job
{
  /// <summary>
  /// This Section represents a section of the Main Settings page
  /// of the Job Editor.
  /// This Section is printed out by MainDP.
  /// </summary>
  /// <author>JohnH</author>
  public class LoggingView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.job.LoggingView");
    public const String STR_MVC_CLASS_NAME = "JobLogging";
    // HTML Object names.
    public const String HTMLSELECT_LEVEL = "in_se_Level";
    public const String HTMLCHECKBOX_SAVECHECKPOINTS = "in_cb_Checkpoints";
    public const String HTMLINPUT_CHECKPOINTMINUTES = "in_tx_CheckpointMinutes";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LoggingView();
    }
    
    /// <summary>
    /// This method Displays the HTML for the Logging Section on the Main Settings
    /// page of the Job Editor.
    /// </summary>
    /// <author>JohnH</author>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      HTMLSelect mySelect;
      HTMLOption myOption;
      int intLogLevel;
      try
      {
        log.Info("Entering LoggingView::Display");
        HTMLComment myComment = new HTMLComment("Begin: Display LoggingView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(492,
         "ptmsgs_portaladminmsgs")));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // 1st Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(493, "ptmsgs_portaladminmsgs"));
        //Add a table cell for the drop-down
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        //Add the new select item
        mySelect = new HTMLSelect(HTMLSELECT_LEVEL, HTMLSELECT_LEVEL);
        mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        //Get the value from the model
        intLogLevel = ((IJobModelRO) m_model).GetLogLevel();
        //Add the first option
        myOption = new HTMLOption(m_asOwner.GetString(494, "ptmsgs_portaladminmsgs"));
        //PT_LOGLEVELS.PT_LOG_SILENT
        myOption.SetValue("0");
        if (0 == intLogLevel)
        {
          myOption.SetSelected(true);
        }
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(494, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        //Add the second option
        myOption = new HTMLOption(m_asOwner.GetString(495, "ptmsgs_portaladminmsgs"));
        //PT_LOGLEVELS.PT_LOG_LOW
        myOption.SetValue("1");
        if (1 == intLogLevel)
        {
          myOption.SetSelected(true);
        }
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(495, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        //Add the third option
        myOption = new HTMLOption(m_asOwner.GetString(496, "ptmsgs_portaladminmsgs"));
        //PT_LOGLEVELS.PT_LOG_NORMAL
        myOption.SetValue("2");
        if (2 == intLogLevel)
        {
          myOption.SetSelected(true);
        }
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(496, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        //Add the fourth option
        myOption = new HTMLOption(m_asOwner.GetString(497, "ptmsgs_portaladminmsgs"));
        //PT_LOGLEVELS.PT_LOG_VERBOSE
        myOption.SetValue("3");
        if (3 == intLogLevel)
        {
          myOption.SetSelected(true);
        }
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(497, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        //Add the select box to the cell
        myCell.AddInnerHTMLElement(mySelect);
        //Second Row - Save Checkpoints checkbox
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //First Cell - the checkbox
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_SAVECHECKPOINTS,
         "");
        if (0 != ((IJobModelRO) m_model).GetSuspendCheckpointInterval())
        {
          myInput.SetChecked(true);
        } else
        {
          myInput.SetChecked(false);
        }
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(499, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        //Minute input box
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_CHECKPOINTMINUTES,
         m_asOwner.GetString(500, "ptmsgs_portaladminmsgs"));
        //Set the default not after date
        myInput.SetValue(XPConvert.ToString(((IJobModelRO) m_model).GetSuspendCheckpointInterval()));
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetSize(3);
        myCell.AddInnerHTMLElement(myInput);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(500, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.LIST_ITALIC_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2710, "ptmsgs_portaladminmsgs"));
        // 1st Row end
        myComment = new HTMLComment("End: Display LoggingView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        log.Error(e, "LoggingView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(498, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}