using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.job
{
  /// <summary>
  /// This Section represents a section of the Main Settings page
  /// of the Job Editor.
  /// This Section is printed out by MainDP.
  /// </summary>
  /// <author>JohnH</author>
  public class ScheduleView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.job.ScheduleView");
    
    /// <summary>
    /// The unique identifier for this view 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobSchedule";
    // HTML Object names.
    
    /// <summary>
    /// The Schedule radio button 
    /// </summary>
    public const String HTMLINPUT_SCHEDULE = "in_ra_Schedule";
    
    /// <summary>
    /// The restrictions select list 
    /// </summary>
    public const String HTMLSELECT_RESTRICTIONS = "in_se_Restrictions";
    
    /// <summary>
    /// The Run frequency text box 
    /// </summary>
    public const String HTMLINPUT_RUN_EVERY = "in_tx_RunEvery";
    
    /// <summary>
    /// The run units text box 
    /// </summary>
    public const String HTMLSELECT_RUN_UNITS = "in_se_RunUnits";
    
    /// <summary>
    /// The suspend options check box 
    /// </summary>
    public const String HTMLCHECKBOX_SUSPENDOPTIONS = "in_cb_SuspendOptions";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ScheduleView();
    }
    
    /// <summary>
    /// This method Displays the HTML for the Schedule Section on the Main Settings
    /// page of the Job Editor.
    /// </summary>
    /// <author>JohnH</author>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLSpan mySpan;
      HTMLInput myInput;
      JSDateTimePickerMgr ptDateTimePickerMgr;
      JSDateTimePicker myDTPicker;
      try
      {
        ptDateTimePickerMgr = ((IJobModelRO) m_model).GetDateTimePickerControlManager();
        HTMLComment myComment = new HTMLComment("Begin: Display ScheduleView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(502,
         "ptmsgs_portaladminmsgs")));
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // 1st Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetColSpan("5");
        myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        myCell.SetHeight("25");
        myCell.AddInnerHTMLString(m_asOwner.GetString(2148, "ptmsgs_portaladminmsgs"));
        //Second row begin - Unscheduled
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //The first cell - Unscheduled radio button
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLINPUT_SCHEDULE,
         m_asOwner.GetString(503, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
        //PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER
        myInput.SetValue("0");
        myInput.SetOnClick("SetDefaults(\'0\');");
        int intScheduleType = ((IJobModelRO) m_model).GetScheduleType();
        if (0 == intScheduleType)
        {
          myInput.SetChecked(true);
        }
        myCell.AddInnerHTMLElement(myInput);
        //The second cell - the "Unscheduled" text span
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(503, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
        //Third cell - an empty cell
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetColSpan("2");
        /* date picker for run once and run once - now option
         * the run once - now option is essentially the same as the
         * run once option, except that it defaults the date-time to the
         * current date-time. The date picker should be null when the
         * run once - now option is selected.
         */
         
        myDTPicker = (JSDateTimePicker) ptDateTimePickerMgr.GetComponent(JobEditorAS.RUN_ONCE_DATEPICKER);
        bool isRunOnceNow = (JobModel.SCHEDULE_TYPE_RUN_ONCE_NOW == ((IJobModelRO) m_model).GetScheduleType());
        bool isRunOnce = (1 == ((IJobModelRO) m_model).GetScheduleType());
        //3rd Row begin - Run Once - Now
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLINPUT_SCHEDULE,
         m_asOwner.GetString(2555, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
        //PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE
        myInput.SetValue(XPConvert.ToString(JobModel.SCHEDULE_TYPE_RUN_ONCE_NOW));
        myCell.AddInnerHTMLElement(myInput);
        //The second cell - the "Run Once - Now" text span
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2555, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
        myInput.SetChecked(isRunOnceNow);
        //third cell - empty cell
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        //3rd Row end
        //4th Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLINPUT_SCHEDULE,
         m_asOwner.GetString(507, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
        //PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE
        myInput.SetValue("1");
        myInput.SetOnClick("SetDefaults(\'1\');");
        myCell.AddInnerHTMLElement(myInput);
        //The second cell - the "Run Once" text span
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(507, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
        /* if the schedule type is run once and the datepicker is not null,
         * then this is a regular run once... whereas if the picker is null,
         * then this is actually a run once - now option.
         */
         
        myInput.SetChecked(isRunOnce);
        //Third Cell - The date picker
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        try
        {
          myCell.AddInnerHTMLElement(myDTPicker.GetSubComponentHTMLByIndex(0));
          }
        catch (Exception e)
        {
          GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
           "ScheduleView::Display", e, false, UIErrorLevel.WARNING, m_asOwner.GetString(2417,
           "ptmsgs_portaladminmsgs"));
        }
        //Fourth cell - the time input box
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.AddInnerHTMLElement(myDTPicker.GetSubComponentHTMLByIndex(1));
        //4th Row end
        //5th Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //First cell - the run periodically radio button
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLINPUT_SCHEDULE,
         m_asOwner.GetString(508, "ptmsgs_portaladminmsgs"));
        myInput.SetValue("-1");
        //Periodically - get the specifics from the duration combo
        myInput.SetOnClick("SetDefaults(\'-1\');");
        myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
        if (1 < intScheduleType)
        {
          myInput.SetChecked(true);
        }
        myCell.AddInnerHTMLElement(myInput);
        //Second Cell - the Run periodically text span
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(508, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
        //Third cell - empty
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        //5th Row end
        //6th Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //First cell - empty
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        //Second cell - "Next:"
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(509, "ptmsgs_portaladminmsgs"));
        //Third cell - the date picker
        myCell = new HTMLTableCell();
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myDTPicker = (JSDateTimePicker) ptDateTimePickerMgr.GetComponent(JobEditorAS.NEXT_RUN_DATEPICKER);
        try
        {
          myCell.AddInnerHTMLElement(myDTPicker.GetSubComponentHTMLByIndex(0));
          }
        catch (Exception e)
        {
          GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
           "ScheduleView::Display", e, false, UIErrorLevel.WARNING, m_asOwner.GetString(2417,
           "ptmsgs_portaladminmsgs"));
        }
        //Fourth cell - the time input box
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.AddInnerHTMLElement(myDTPicker.GetSubComponentHTMLByIndex(1));
        //7th Row begin - the duration combo
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //First cell - empty
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        //Second cell - the every span
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(506, "ptmsgs_portaladminmsgs"));
        //Third cell - The duration combo
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetWidth("100%");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        int nAvailableUnits = PTDurationCombo.DISPLAYMINUTES | PTDurationCombo.DISPLAYHOURS | PTDurationCombo.DISPLAYDAYS | PTDurationCombo.DISPLAYWEEKS;
        if (1 < intScheduleType)
        {
          myCell.AddInnerHTMLElement(PTDurationCombo.GetDurationCombo(HTMLINPUT_RUN_EVERY,
           HTMLSELECT_RUN_UNITS, nAvailableUnits, XPConvert.ToString(((IJobModelRO) m_model).GetRecurrenceInterval()),
           JobModel.DurationFromPTScheduleType(((IJobModelRO) m_model).GetScheduleType()),
           m_asOwner));
        } else
        {
          myCell.AddInnerHTMLElement(PTDurationCombo.GetDurationCombo(HTMLINPUT_RUN_EVERY,
           HTMLSELECT_RUN_UNITS, nAvailableUnits, "1", PTDurationCombo.DISPLAYDAYS,
           m_asOwner));
        }
        //7th Row end
        //8th Row begin - Do not run after
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //First cell - empty
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        //Second cell - Don't run after text
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(510, "ptmsgs_portaladminmsgs"));
        //Third cell - The date picker
        myCell = new HTMLTableCell();
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myDTPicker = (JSDateTimePicker) ptDateTimePickerMgr.GetComponent(JobEditorAS.NOT_AFTER_DATEPICKER);
        try
        {
          myCell.AddInnerHTMLElement(myDTPicker.GetSubComponentHTMLByIndex(0));
          }
        catch (Exception e)
        {
          GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
           "ScheduleView::Display", e, false, UIErrorLevel.WARNING, m_asOwner.GetString(2417,
           "ptmsgs_portaladminmsgs"));
        }
        //Fourth cell - the time input box
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.AddInnerHTMLElement(myDTPicker.GetSubComponentHTMLByIndex(1));
        //8th Row end
        //9th Row begin - Suspend Crawler jobs
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetColSpan("5");
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_SUSPENDOPTIONS,
         "");
        int intSuspendMode = ((IJobModelRO) m_model).GetSuspendMode();
        myInput.SetChecked(PT_SCHEDULE_SUSPEND_MODES.PT_SCHEDULE_SUSPEND_ON == intSuspendMode);
        myInput.SetValue(XPConvert.ToString(PT_SCHEDULE_SUSPEND_MODES.PT_SCHEDULE_SUSPEND_ON));
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(517, "ptmsgs_portaladminmsgs"));
        //9th Row end
        //10th Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        //First cell - empty
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        //Second cell - Weekdays text
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(518, "ptmsgs_portaladminmsgs"));
        //Third cell - From
        myCell = new HTMLTableCell();
        myCell.SetAlign("right");
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(519, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        //Fourth Cell - 2 time input boxes
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLElement(ptDateTimePickerMgr.GetComponentHTML(JobEditorAS.SUSPEND_BEGIN_TIMEPICKER));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(520, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        //Third cell - the end time
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLElement(ptDateTimePickerMgr.GetComponentHTML(JobEditorAS.SUSPEND_END_TIMEPICKER));
        //10th Row end
        myComment = new HTMLComment("End: Display ScheduleView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "ScheduleView::Display", e, true, UIErrorLevel.SERIOUS, m_asOwner.GetString(512,
         "ptmsgs_portaladminmsgs"));
      }
      return result;
    }
    
    /// <summary>
    /// Returns Java Script for the ScheduleView of the job editor.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      JSDateTimePicker ptJSRunOncePicker;
      JSDateTimePicker ptJSNotAfterPicker;
      JSDateTimePicker ptJSNextRunPicker;
      ptJSRunOncePicker = (JSDateTimePicker) ((IJobModelRO) m_model).GetDateTimePickerControlManager().GetComponent(JobEditorAS.RUN_ONCE_DATEPICKER);
      ptJSNotAfterPicker = (JSDateTimePicker) ((IJobModelRO) m_model).GetDateTimePickerControlManager().GetComponent(JobEditorAS.NOT_AFTER_DATEPICKER);
      ptJSNextRunPicker = (JSDateTimePicker) ((IJobModelRO) m_model).GetDateTimePickerControlManager().GetComponent(JobEditorAS.NEXT_RUN_DATEPICKER);
      XPDateFormat myTimeFormat = XPDateFormat.GetTimeInstance(XPDateFormat.MEDIUM,
       ((IJobModelRO) m_model).GetLocale(), ((IJobModelRO) m_model).GetTimezone());
      String strMyFormat = myTimeFormat.ToPattern();
      String strHoursFormat = "HH";
      //
      String strDatePattern = JSHelper.escapeJS(((IJobModelRO) m_model).GetDateFormatPattern());
      //		//the current date
      //		XPCalendar currentDate = XPCalendar.GetInstance();
      bool b24Hour = false;
      if (XPStringUtility.IndexOf(strMyFormat, "H") >= 0)
      {
        strHoursFormat = "HH";
        b24Hour = true;
      } else
      {
        strHoursFormat = "h";
      }
      //Disable the appropriate buttons depending on home page type
      try
      {
        XPStringBuilder sb = new XPStringBuilder(400);
        // SCC: Always return true.  
        //      This method just warns the user if the Job Folder has not been registerd 
        sb.Append("function WarnFolderRegistered()\n");
        sb.Append("{\n");
        if (false == ((IJobModelRO) m_model).IsJobFolderRegistered())
        {
          sb.Append("  var strScheduleRadio = document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_SCHEDULE + ";\n");
          sb.Append("  if (false == strScheduleRadio[0].checked)\n");
          sb.Append("  {\n");
          sb.Append("      alert(\"" + m_asOwner.GetString(2679, "ptmsgs_portaladminmsgs") + "\");\n");
          sb.Append("  }\n");
        }
        sb.Append("  return true;\n");
        sb.Append("}\n");
        String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
         m_asOwner);
        sb.Append("function SetSelected(strElement, strValue)\n");
        sb.Append("{\n");
        sb.Append("\tfor ( i = 0; i < document." + EditorDP.HTMLFORM_NAME + ".elements[strElement].length; i++ )\n");
        sb.Append("\t{\n");
        sb.Append("\t\tvar strCompareValue = new String();\n");
        sb.Append("\t\tstrCompareValue = strValue.toString();\n");
        sb.Append("\t\tif (document." + EditorDP.HTMLFORM_NAME + ".elements[strElement][i].value == strCompareValue.toUpperCase())\n");
        sb.Append("\t\t\tdocument." + EditorDP.HTMLFORM_NAME + ".elements[strElement][i].selected = true;\n");
        sb.Append("\t}\n");
        sb.Append("}\n");
        sb.Append("function SetDefaults(strButtonClicked)\n");
        sb.Append("{\n");
        sb.Append("  var Today = new Date();\n");
        sb.Append("  var DefaultUntil = new Date(2013, 0, 1);\n");
        sb.Append("  if (strButtonClicked == \'0\')\n");
        sb.Append("  {\n");
        sb.Append("    " + ptJSRunOncePicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        if (b24Hour)
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSRunOncePicker.GetHoursInputName() + "\'][0].selected = true;\n");
          } else
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSRunOncePicker.GetHoursInputName() + "\'][11].selected = true;\n");
          }
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSRunOncePicker.GetMinutesInputName() + "\'][0].selected = true;\n");
        sb.Append("    " + ptJSNotAfterPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        if (b24Hour)
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetHoursInputName() + "\'][0].selected = true;\n");
          } else
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetHoursInputName() + "\'][11].selected = true;\n");
          }
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetMinutesInputName() + "\'][0].selected = true;\n");
        sb.Append("    " + ptJSNextRunPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        if (b24Hour)
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNextRunPicker.GetHoursInputName() + "\'][0].selected = true;\n");
          } else
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNextRunPicker.GetHoursInputName() + "\'][11].selected = true;\n");
          }
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNextRunPicker.GetMinutesInputName() + "\'][0].selected = true;\n");
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + HTMLINPUT_RUN_EVERY + "\'].value = \'\';\n");
        sb.Append("  }\n");
        sb.Append("  if (strButtonClicked == \'-1\')\n");
        sb.Append("  {\n");
        sb.Append("    " + ptJSRunOncePicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        if (b24Hour)
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSRunOncePicker.GetHoursInputName() + "\'][0].selected = true;\n");
          } else
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSRunOncePicker.GetHoursInputName() + "\'][11].selected = true;\n");
          }
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSRunOncePicker.GetMinutesInputName() + "\'][0].selected = true;\n");
        sb.Append("     if (document." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetDateInputName() + "\'].value == \'\')\n");
        sb.Append("     {\n");
        sb.Append("    " + ptJSNotAfterPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(PTDate.formatDate(DefaultUntil, \'" + strDatePattern + "\',\'en\'));");
        sb.Append("     }\n");
        sb.Append("    " + ptJSNextRunPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        sb.Append("     {\n");
        sb.Append("    " + ptJSNextRunPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(PTDate.formatDate(Today, \'" + strDatePattern + "\',\'en\'));");
        sb.Append("\t\t\tSetSelected(\'" + ptJSNextRunPicker.GetHoursInputName() + "\', PTDate.formatDate(Today,\'" + strHoursFormat + "\',\'" + strLangID + "\'));\n");
        sb.Append("\t\t\tSetSelected(\'" + ptJSNextRunPicker.GetMinutesInputName() + "\', PTDate.formatDate(Today,\'" + "mm" + "\',\'" + strLangID + "\'));\n");
        if (!b24Hour)
        {
          sb.Append("\t\tSetSelected(\'" + ptJSNextRunPicker.GetAMPMInputName() + "\', PTDate.formatDate(Today,\'" + "a" + "\',\'" + strLangID + "\'));\n");
          }
        sb.Append("     }\n");
        sb.Append("  }\n");
        sb.Append("  if (strButtonClicked == \'1\')\n");
        sb.Append("  {\n");
        sb.Append("    " + ptJSNotAfterPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        if (b24Hour)
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetHoursInputName() + "\'][0].selected = true;\n");
          } else
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetHoursInputName() + "\'][11].selected = true;\n");
          }
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNotAfterPicker.GetMinutesInputName() + "\'][0].selected = true;\n");
        sb.Append("    " + ptJSNextRunPicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        if (b24Hour)
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNextRunPicker.GetHoursInputName() + "\'][0].selected = true;\n");
          } else
        {
          sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNextRunPicker.GetHoursInputName() + "\'][11].selected = true;\n");
          }
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + ptJSNextRunPicker.GetMinutesInputName() + "\'][0].selected = true;\n");
        sb.Append("  \tdocument." + EditorDP.HTMLFORM_NAME + ".elements[\'" + HTMLINPUT_RUN_EVERY + "\'].value = \'\';\n");
        sb.Append("    " + ptJSRunOncePicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(\"\");");
        sb.Append("     {\n");
        sb.Append("    " + ptJSRunOncePicker.GetPTDatepickerVarName() + ".setDisplayFromDateString(PTDate.formatDate(Today, \'" + strDatePattern + "\',\'en\'));");
        sb.Append("\t\t\tSetSelected(\'" + ptJSRunOncePicker.GetHoursInputName() + "\', PTDate.formatDate(Today,\'" + strHoursFormat + "\',\'" + strLangID + "\'));\n");
        sb.Append("\t\t\tSetSelected(\'" + ptJSRunOncePicker.GetMinutesInputName() + "\', PTDate.formatDate(Today,\'" + "mm" + "\',\'" + strLangID + "\'));\n");
        if (!b24Hour)
        {
          sb.Append("\t\tSetSelected(\'" + ptJSRunOncePicker.GetAMPMInputName() + "\', PTDate.formatDate(Today,\'" + "a" + "\',\'" + strLangID + "\'));\n");
          }
        sb.Append("     }\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "ScheduleView::DisplayJavascript", e, true, UIErrorLevel.WARNING,
         m_asOwner.GetString(888, "ptmsgs_portaladminmsgs"));
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}