using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.property;
using com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.lockbox
{
  /// <author>jennifersu</author>
  public class LockboxEditorModel : ObjEditorModel,ILockboxEditorModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.lockbox.LockboxEditorModel");
    public const String STR_MVC_CLASS_NAME = "LockboxEditorModel";
    protected bool m_bNewLockbox = true;
    protected int m_nRow = -1;
    protected int m_nUsernamePropID = -1;
    protected int m_nPasswordPropID = -1;
    protected String m_strUsernamePropName = null;
    protected String m_strPasswordPropName = null;
    private const int PROPERTY_USERNAME = 0;
    private const int PROPERTY_PASSWORD = 1;
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      m_bDisableSecurity = true;
      bool bAccess = base.CheckEditorAccessAndStart(_htFormData);
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        m_ptObject.SetName(m_asOwner.GetString(2903, "ptmsgs_portaladminmsgs"));
        } else
      {
        Object[] arPropIDs = ((IPTProfileSection) m_ptObject).GetChildProperties();
        if (arPropIDs.Length >= 2)
        {
          m_nUsernamePropID = XPConvert.ToInteger(arPropIDs[0]);
          m_nPasswordPropID = XPConvert.ToInteger(arPropIDs[1]);
          IPTObjectManager propManager = m_Session.GetProperties();
          IPTProperty ptUsernameProp = (IPTProperty) propManager.Open(m_nUsernamePropID,
           false);
          m_strUsernamePropName = ptUsernameProp.GetName();
          IPTProperty ptPasswordProp = (IPTProperty) propManager.Open(m_nPasswordPropID,
           false);
          m_strPasswordPropName = ptPasswordProp.GetName();
        }
      }
      return bAccess;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnStartEditor(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        } else
      {
        m_bNewLockbox = false;
      }
      String[] data;
      data = (String[]) _htFormData.GetElement(LockboxListModel.LOCKBOX_ROW);
      if (data != null)
      {
        String strRow = data[0];
        m_nRow = XPConvert.ToInteger(strRow);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LockboxEditorModel();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.lockbox.ILockboxEditorModelRO#IsNewLockbox()
     */
     
    public virtual bool IsNewLockbox()
    {
      return m_bNewLockbox;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.lockbox.ILockboxEditorModelRO#GetRow()
     */
     
    public virtual int GetRow()
    {
      return m_nRow;
    }
    public virtual void ResetInputs()
    {
      m_nRow = -1;
      m_bNewLockbox = true;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Adding a new Lockbox object requires a number of steps under the covers:
    /// 1.\u0009Create a new Profile Section object.
    /// 2.\u0009Create two new Property objects (user name and password).
    /// 3.\u0009Add these Properties to the Profile Section object.
    /// 4.\u0009Map these Properties to the User object in the Global Object Properties map.
    /// 5.\u0009Add these Properties to the User Info Property Map.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      // (only in CREATE mode)
      if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
      {
        // Create username and password properties
        IPTProperty usernameProp = CreateProperty(PROPERTY_USERNAME);
        IPTProperty passwordProp = CreateProperty(PROPERTY_PASSWORD);
        m_nUsernamePropID = ((IPTServerContext) usernameProp).GetObjectID();
        m_nPasswordPropID = ((IPTServerContext) passwordProp).GetObjectID();
        // Add properties to Global Object Properties map
        IPTObjectPropertyMap ptOPM = (IPTObjectPropertyMap) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP,
         true);
        IPTQueryResult ptQR = ptOPM.QueryClassPropertyMappings(PT_CLASSIDS.PT_USER_ID,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        int[] arPropIDs = new int[ptQR.RowCount() + 2];
        int nRow;
        for (nRow = 0;nRow < ptQR.RowCount();nRow++)
        {
          int nPropertyID = ptQR.ItemAsInt(nRow, PT_PROPIDS.PT_PROPID_OBJECTID);
          arPropIDs[nRow] = nPropertyID;
        }
        arPropIDs[nRow] = m_nUsernamePropID;
        arPropIDs[nRow + 1] = m_nPasswordPropID;
        ptOPM.SetClassPropertyMappings(PT_CLASSIDS.PT_USER_ID, arPropIDs);
        // Add properties to User Info Property Map
        IPTProfileManager ptProfileManager = (IPTProfileManager) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER,
         true);
        Object[][] arrMap = ptProfileManager.GetUserInfoMap();
        Object[][] arrNewMap = new Object[2][];
        for (int j2c_index = 0;j2c_index < 2;j2c_index++)
        {
          arrNewMap[j2c_index] = new Object[arrMap[0].Length + 2];
        }
        nRow = 0;
        for (nRow = 0;nRow < arrMap[0].Length;nRow++)
        {
          arrNewMap[0][nRow] = arrMap[0][nRow];
          arrNewMap[1][nRow] = arrMap[1][nRow];
        }
        //			IPTMigrationManager ptMigrationManager = (IPTMigrationManager) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER, false);
        arrNewMap[0][nRow] = m_nUsernamePropID;
        arrNewMap[1][nRow] = ((IPTMigratable) usernameProp).GetObjectUUID();
        arrNewMap[0][nRow + 1] = m_nPasswordPropID;
        arrNewMap[1][nRow + 1] = ((IPTMigratable) passwordProp).GetObjectUUID();
        ptProfileManager.SetUserInfoMap(arrNewMap);
        // Add properties to PTProfileSection
        Object[] arProps = new Object[2];
        arProps[0] = m_nUsernamePropID;
        arProps[1] = m_nPasswordPropID;
        ((IPTProfileSection) m_ptObject).SetChildProperties(arProps);
      }
    }
    
    /// <summary>
    /// Creates a property object and stores in DB.
    /// </summary>
    /// <param name="nPropertyType"></param>
    /// <returns>int property ID</returns>
    private IPTProperty CreateProperty(int nPropertyType)
    {
      IPTProperty ptProperty = (IPTProperty) m_Session.GetObjectManagers(PT_CLASSIDS.PT_PROPERTY_ID).Create(m_nFolderID);
      if (nPropertyType == PROPERTY_USERNAME)
      {
        ptProperty.Initialize(PT_PROPERTY_TYPES.PT_PROPTYPE_STRING);
        ptProperty.SetName(m_strUsernamePropName);
      } else
      {
        ptProperty.Initialize(PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED);
        ptProperty.SetName(m_strPasswordPropName);
      }
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_HREF,
       0);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_REFCLASS,
       -1);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_ISCARDPROP,
       0);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_VISIBLE,
       1);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_READONLYVALUE,
       0);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MANDATORY,
       0);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_SEARCHABLE,
       0);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MULTIVALUED,
       0);
      ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE,
       PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE);
      // JF- Store the Object in the DB.
      IPTServerContext ptSC = (IPTServerContext) ptProperty.GetInterfaces("IPTServerContext");
      try
      {
        ptSC.Store();
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::CreateProperty Unable to store the Object.");
        String sMessage = m_asOwner.GetString(158, "ptmsgs_portalinfrastructure");
        // JF- The exception message should not be extracted.
        String sExceptionMessage = "The Portal was unable to store the Object.";
        if (e is PTException)
        {
          PTException ptex = (PTException) e;
          int iCode = ptex.GetErrorCode();
          if ((iCode == PT_RESULTCODES.PT_E_INSUFFICIENTROLEACCESS) || (iCode == PT_RESULTCODES.PT_E_ACCESSDENIED) || (iCode == PT_RESULTCODES.PT_E_CANNOTEDITREADONLY))
          {
            sMessage = m_asOwner.GetString(441, "ptmsgs_portalinfrastructure");
            sExceptionMessage = "The current user does not have sufficient rights to store this Object";
            } else
          if (iCode == PT_RESULTCODES.PT_E_OBJECTLOCKED)
          {
            sMessage = m_asOwner.GetString(442, "ptmsgs_portalinfrastructure");
            sExceptionMessage = "This Object is already locked. It cannot be stored.";
            } else
          if (iCode == PT_RESULTCODES.PT_E_OBJECTNOTLOCKED)
          {
            sMessage = m_asOwner.GetString(443, "ptmsgs_portalinfrastructure");
            sExceptionMessage = "Unable to lock this Object. It cannot be stored.";
            }
          UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
           null, sMessage, null);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
        throw new XPException(sExceptionMessage, e);
      }
      finally
      {
        ptSC.UnlockObject();
      }
      return ptProperty;
    }
    
    /// <summary>
    /// That method is called by the EditorFinishControl.  It takes care of
    /// storing the IPTObject in the DB  when the user finishes the Editor.
    /// </summary>
    /// <throws>XPException</throws>
    public override void Finish()
    {
      DoTaskBeforeStore();
      ((LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME)).Finish();
      StoreObject();
      SaveMigrationStatus();
      DoTaskAfterStore();
      // JF- The Object has been stored. We are now in Edit mode.
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType)
      {
        m_nEditorType = EditorStartControl.EDITOR_START_FLAG_EDIT;
      }
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(LockboxEditorLocNamesDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = ((LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        if (nPageStatus == RepostControl.PAGE_STATUS_VALID && EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType)
        {
          m_strUsernamePropName = XPStringUtility.Trim(ModelHelper.GetFormElementString(_htFormData,
           LockboxEditorPropertiesView.HTMLINPUT_USERNAME_NAME, "Username"));
          if (m_strUsernamePropName.Equals(""))
          {
            m_strUsernamePropName = "Username";
          }
          m_strPasswordPropName = XPStringUtility.Trim(ModelHelper.GetFormElementString(_htFormData,
           LockboxEditorPropertiesView.HTMLINPUT_PASSWORD_NAME, "Password"));
          if (m_strPasswordPropName.Equals(""))
          {
            m_strPasswordPropName = "Password";
          }
        }
      }
      return nPageStatus;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.lockbox.ILockboxEditorModelRO#GetUsernamePropID()
     */
     
    public virtual int GetUsernamePropID()
    {
      return m_nUsernamePropID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.lockbox.ILockboxEditorModelRO#GetPasswordPropID()
     */
     
    public virtual int GetPasswordPropID()
    {
      return m_nPasswordPropID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.lockbox.ILockboxEditorModelRO#GetUsernamePropName()
     */
     
    public virtual String GetUsernamePropName()
    {
      return m_strUsernamePropName;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.lockbox.ILockboxEditorModelRO#GetPasswordPropName()
     */
     
    public virtual String GetPasswordPropName()
    {
      return m_strPasswordPropName;
    }
    
    /// <summary>
    /// Returns the URL to edit the object.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_sEditorASName"></param>
    /// <returns>ASURL URL to the Editor</returns>
    public virtual ASURL GetEditPropertyURL(int _nPropertyID)
    {
      ASURL myURL = new ASURL(m_asOwner);
      String sEditorASName = PropEditorAS.STR_MVC_CLASS_NAME;
      myURL.SetLinkCreateNewSpace(sEditorASName, m_asOwner);
      myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
      myURL.SetSubSpaceKey(sEditorASName);
      myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));
      myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
       XPConvert.ToString(_nPropertyID));
      return myURL;
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      PropEditorAS myPropEditorAS;
      PropModel myPropModel;
      String strSubEditorASName = PropEditorAS.STR_MVC_CLASS_NAME;
      if (m_asOwner.GetSubSpaceExists(strSubEditorASName))
      {
        myPropEditorAS = (PropEditorAS) m_asOwner.GetSubSpace(strSubEditorASName);
        myPropModel = (PropModel) myPropEditorAS.GetModel(myPropEditorAS.m_strModelName);
        if (myPropModel.GetObjectID() == m_nUsernamePropID)
        {
          m_strUsernamePropName = myPropModel.GetObjectName();
        } else
        if (myPropModel.GetObjectID() == m_nPasswordPropID)
        {
          m_strPasswordPropName = myPropModel.GetObjectName();
        }
      }
    }
  }
}