using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.lockbox
{
  public class LockboxEditorPropertiesView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.lockbox.LockboxEditorPropertiesView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LockboxEditorPropertiesView";
    public const String HTMLINPUT_USERNAME_NAME = "in_tx_Username_Name";
    public const String HTMLINPUT_PASSWORD_NAME = "in_tx_Password_Name";
    public const int STANDARD_INPUT_BOX_WIDTH = 50;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LockboxEditorPropertiesView();
    }
    
    /// <summary>
    /// This method returns the HTMLElement that encompasses the output of the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLSpan mySpan;
      try
      {
        ILockboxEditorModelRO myModel = (ILockboxEditorModelRO) m_asOwner.GetModel(LockboxEditorModel.STR_MVC_CLASS_NAME);
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2916,
         "ptmsgs_portaladminmsgs")));
        result.AddInnerHTMLString("\n<!-- Begin: Display " + STR_MVC_CLASS_NAME + " -->\n");
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        HTMLTableRow myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        HTMLTableCell myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2919, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        HTMLInput nameInput;
        HTMLAnchor propAnchor;
        // If we're creating a new lockbox, let the admin choose the username property name.
        // Otherwise, provide a link to the existing property editor.
        if (EditorStartControl.EDITOR_START_FLAG_CREATE == myModel.GetEditorType())
        {
          nameInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_USERNAME_NAME,
           "");
          myCell.AddInnerHTMLElement(nameInput);
          nameInput.SetSize(STANDARD_INPUT_BOX_WIDTH);
          nameInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        } else
        {
          ASURL usernameURL = myModel.GetEditPropertyURL(myModel.GetUsernamePropID());
          propAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          propAnchor.SetOnClick("EditProperty" + "(\'" + usernameURL.GetURLAsString() + "\'); return false;");
          propAnchor.AddInnerHTMLEncodedString(myModel.GetUsernamePropName());
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.AddInnerHTMLElement(propAnchor);
        }
        // Second row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2920, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        // If we're creating a new lockbox, let the admin choose the password property name.
        // Otherwise, provide a link to the existing property editor.
        if (EditorStartControl.EDITOR_START_FLAG_CREATE == myModel.GetEditorType())
        {
          nameInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_PASSWORD_NAME,
           "");
          myCell.AddInnerHTMLElement(nameInput);
          nameInput.SetSize(STANDARD_INPUT_BOX_WIDTH);
          nameInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        } else
        {
          ASURL passwordURL = myModel.GetEditPropertyURL(myModel.GetPasswordPropID());
          propAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          propAnchor.SetOnClick("EditProperty" + "(\'" + passwordURL.GetURLAsString() + "\'); return false;");
          propAnchor.AddInnerHTMLEncodedString(myModel.GetPasswordPropName());
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.AddInnerHTMLElement(propAnchor);
        }
        result.AddInnerHTMLString("\n<!-- End: Display " + STR_MVC_CLASS_NAME + " -->\n");
        }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display An error occured when trying to display the HTML.");
        throw new XPException(m_asOwner.GetString(62, "ptmsgs_portalinfrastructure"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on
    /// the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      // Edit object
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append(" function EditProperty(varURL)");
      sb.Append(" {");
      sb.Append("    window.open(varURL,\'PopUpPropertyEditMode\',\'location=no,menubar=no,height=600,width=800, scrollbars=yes, resizable=yes\');\n");
      sb.Append(" }\n");
      myScript.AddInnerHTMLString(sb.ToString());
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}