using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.template;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.page
{
  /// <author>michaeld</author>
  public class PageEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.page.PageEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageEditor";
    
    /// <summary>
    /// Page Template List Plugin 
    /// </summary>
    public const String PLUGIN_PAGE_TEMPLATE_LIST = "PageTemplateList";
    
    /// <summary>
    /// Layout table top 
    /// </summary>
    public const int LAYOUTTABLE_TOP = 175;
    
    /// <summary>
    /// Layout table left 
    /// </summary>
    public const int LAYOUTTABLE_LEFT = 259;
    private const String sClassName = "com.plumtree.portalpages.admin.editors.page.PageEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageEditorAS();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()"></seealso>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(2718, "ptmsgs_portaladminmsgs");
      }
      return (XPResourceManager.FormatMessage(GetString(2719, "ptmsgs_portaladminmsgs"),
       GetObjectName()));
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (PageDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (PageRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PageEditorModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      PageMainDP myMainPage = new PageMainDP();
      myMainPage.AddToValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
      RegisterPage(myMainPage);
      log.Info("PageEditorAS::Constructor: Register display pages succesful");
      // Register Views
      RegisterView(PageDependenciesView.STR_MVC_CLASS_NAME, myModel);
      log.Info("PageEditorAS::Constructor: Register views succesful");
      // Register Controls
      RegisterControl(PageRepostControl.STR_MVC_CLASS_NAME, myModel);
      log.Info("PageEditorAS::Constructor: Register controls succesful");
      // Set default page
      SetCurrentPage(PageMainDP.STR_MVC_CLASS_NAME);
      // Register common sections
      //      Register each Section/Model for your plug-in sections
      RegisterModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
      IModel myPageLayoutModel = GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
      RegisterView(PageLayoutView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterView(PageLayoutHeaderView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterView(PageLayoutAlternateView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterControl(PageLayoutControl.STR_MVC_CLASS_NAME, myPageLayoutModel);
      // Register the community template selector as a plug-in section
      RegisterModel(PageTemplateListModel.STR_MVC_CLASS_NAME, PLUGIN_PAGE_TEMPLATE_LIST);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myPageTemplateListModel = GetModel(PLUGIN_PAGE_TEMPLATE_LIST);
      RegisterView(TemplateListView.STR_MVC_CLASS_NAME, PLUGIN_PAGE_TEMPLATE_LIST,
       myPageTemplateListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, PLUGIN_PAGE_TEMPLATE_LIST,
       myPageTemplateListModel);
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(2723, "ptmsgs_portaladminmsgs"));
      // Main Settings
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PageMainDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(2724, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 144;
          int iTipId = 145;
          int iSecondaryTipId = 146;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)"></seealso>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (PageMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Page_MainSettings");
      }
    }
    
    /// <summary>
    /// Adjust the number of pixels for the drag and drop
    /// based on the language of the user.
    /// </summary>
    /// <param name="asOwner"></param>
    /// <returns>int</returns>
    public static int GetLayoutTableTop(AActivitySpace asOwner)
    {
      String strLang = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       asOwner));
      int nLayoutTop = LAYOUTTABLE_TOP;
      if (strLang.Equals("ja"))
      {
        nLayoutTop+=9;
      } else
      if (strLang.Equals("zh"))
      {
        nLayoutTop+=9;
      } else
      if (strLang.Equals("ko"))
      {
        nLayoutTop+=4;
      } else
      if (strLang.Equals("fr"))
      {
        nLayoutTop+=2;
      } else
      if (strLang.Equals("de"))
      {
        nLayoutTop+=2;
      } else
      if (strLang.Equals("en"))
      {
        nLayoutTop+=0;
      } else
      if (strLang.Equals("it"))
      {
        nLayoutTop+=0;
      } else
      if (strLang.Equals("pt"))
      {
        nLayoutTop+=0;
      } else
      if (strLang.Equals("es"))
      {
        nLayoutTop+=0;
      }
      // DCA - check if the page is going to print any errors, adjust the layout position
      if (((ErrorModel) asOwner.GetModel(ErrorModel.STR_MVC_CLASS_NAME)).GetErrors().MoveNext())
      {
        nLayoutTop+=40;
      }
      if (!((IPageEditorModelRO) asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetIsMyPage())
      {
        nLayoutTop+=95;
      }
      if (((IPageEditorModelRO) asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetIsDefaultProfileMyPage())
      {
        nLayoutTop+=12;
      }
      return nLayoutTop;
    }
  }
}