using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.page
{
  /// <author>MichaelD</author>
  public class PageMainDP : EditorDP
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageMain";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(2721, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2722, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      //      This is where you print out the plug-in views.
      if (PT_SERVERCONSTANTS.PT_MAX_READONLYINTRINSIC_OBJECTID < ((IObjEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetObjectID() || PT_SERVERCONSTANTS.PT_MIN_READONLYINTRINSIC_OBJECTID > ((IObjEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetObjectID())
      {
        // This will add some empty space between the two views
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        // if is non-mypage, add page template list plug in
        if (!((IPageEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetIsMyPage())
        {
          views.AddInnerHTMLElement(m_asOwner.GetView(PageEditorAS.PLUGIN_PAGE_TEMPLATE_LIST).Display());
          }
        // This will add some empty space between the two views
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).Display());
        if (!((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
        {
          views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutAlternateView.STR_MVC_CLASS_NAME).Display());
          }
      } else
      {
        HTMLSpan span = new HTMLSpan();
        views.AddInnerHTMLElement(span);
        span.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
        span.AddInnerHTMLString(m_asOwner.GetString(3127, "ptmsgs_portaladminmsgs"));
        }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from PlumtreeDP need
    /// to implement.  The method should add whatever HTML the child class wants to
    /// use the DisplayJavaScript and add it to the head.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#DisplayJavaScriptFromChild()"></seealso>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection result = base.DisplayJavaScriptFromChild();
      if (PT_SERVERCONSTANTS.PT_MAX_READONLYINTRINSIC_OBJECTID < ((IObjEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetObjectID() || PT_SERVERCONSTANTS.PT_MIN_READONLYINTRINSIC_OBJECTID > ((IObjEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetObjectID())
      {
        result.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());
        if (((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
        {
          // DCA - We're going to use the drag and drop layout, set the layout table position
          ((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).SetLayoutTablePosition(PageEditorAS.GetLayoutTableTop(m_asOwner),
           PageEditorAS.LAYOUTTABLE_LEFT);
          result.AddInnerHTMLElement(((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
          } else
        {
          result.AddInnerHTMLElement(((PageLayoutAlternateView) m_asOwner.GetView(PageLayoutAlternateView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
          }
      } else
      {
        // Since the PageLayout Views add the repostLayout javascript function (either
        // directly, or through a .js file), and that function is included as a validation
        // function, meaning it is always called on editor page change, we need to include
        // a null implementation version here if we didn't include either layout view.
        // NOTE: an alternate solution would be to deregister the validation function, or
        // do the intrinsic object check on registration.
        // RemoveFromValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        XPStringBuilder sb = new XPStringBuilder(200);
        sb.Append("function ").Append(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT).Append("()\n").Append("{\n").Append("\t\treturn true;\n").Append("}\n");
        script.AddInnerHTMLString(sb.ToString());
        result.AddInnerHTMLElement(script);
      }
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLAfterForm()
     */
     
    public override HTMLElementCollection DisplayHTMLAfterForm()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      if (PT_SERVERCONSTANTS.PT_MAX_READONLYINTRINSIC_OBJECTID < ((IObjEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetObjectID() || PT_SERVERCONSTANTS.PT_MIN_READONLYINTRINSIC_OBJECTID > ((IObjEditorModelRO) m_asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetObjectID())
      {
        if (((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
        {
          HTMLTable myTable = new HTMLTable();
          myTable.SetOnSelectStart("return false");
          collection.AddInnerHTMLElement(myTable);
          myTable.SetCellPadding(CommonHTMLStrings.ZERO);
          myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          HTMLTableRow myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          HTMLTableCell myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME).Display());
          }
        collection.AddInnerHTMLElement(base.DisplayHTMLAfterForm());
      }
      return collection;
    }
  }
}