using System;
// Plumtree Server Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.inherit;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.pagetemplate
{
  /// <author>michaeld</author>
  public class PageTemplateEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.pagetemplate.PageTemplateEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageTemplateEditor";
    
    /// <summary>
    /// SelectPTObject Model for communities that use the template 
    /// </summary>
    public const String PLUGIN_PAGES = "PagesList";
    
    /// <summary>
    /// Plug in Key: DefaultPageName 
    /// </summary>
    public const String PLUGIN_DEFAULT_PAGE_NAME = "DefaultPageName";
    
    /// <summary>
    /// Plug in Key: DefaultPageNameView 
    /// </summary>
    public const String PLUGIN_DEFAULT_PAGE_NAME_VIEW = "DefaultPageNameView";
    
    /// <summary>
    /// Plug in Key: DefaultPagePrimaryNameView 
    /// </summary>
    public const String PLUGIN_DEFAULT_PAGE_PRIMARY_NAME_VIEW = "DefaultPagePrimaryNameView";
    
    /// <summary>
    /// Plug in Key: DefaultPagePopupNameView 
    /// </summary>
    public const String PLUGIN_DEFAULT_PAGE_NAME_POPUP_VIEW = "DefaultPagePopupNameView";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.pagetemplate.PageTemplateEditorAS";
    
    /// <summary>
    /// Layout table top 
    /// </summary>
    public const int LAYOUTTABLE_TOP = 175;
    
    /// <summary>
    /// Layout table left 
    /// </summary>
    public const int LAYOUTTABLE_LEFT = 259;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageTemplateEditorAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns>String strEditorTitle</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(549, "ptmsgs_portaladminmsgs");
      }
      return (XPResourceManager.FormatMessage(GetString(2611, "ptmsgs_portaladminmsgs"),
       GetObjectName()));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (PageTemplateDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (PageTemplateRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PageTemplateModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      PageTemplateMainDP myMainPage = new PageTemplateMainDP();
      myMainPage.AddToValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
      RegisterPage(myMainPage);
      PageTemplateDefaultPageNameDP myDefaultPageNamePage = new PageTemplateDefaultPageNameDP();
      myDefaultPageNamePage.AddToValidationFunction(LocNamesPrimaryNameView.VALIDATION_FUNC_NAME);
      RegisterPage(myDefaultPageNamePage);
      RegisterPage(new DefaultPageNamePopUpDP());
      log.Info("PageTemplateEditorAS::Constructor: Register display pages succesful");
      // MJD- Register classes for the localize default page names page
      RegisterModel(LocNamesModel.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME);
      RegisterView(LocNamesView.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME_VIEW,
       GetModel(PLUGIN_DEFAULT_PAGE_NAME));
      RegisterView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_PRIMARY_NAME_VIEW,
       GetModel(PLUGIN_DEFAULT_PAGE_NAME));
      RegisterView(LocNamesPopUpView.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME_POPUP_VIEW,
       GetModel(PLUGIN_DEFAULT_PAGE_NAME));
      RegisterControl(LocNamesRepostControl.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME,
       GetModel(PLUGIN_DEFAULT_PAGE_NAME));
      // Register Views
      RegisterView(PageTemplateDependenciesView.STR_MVC_CLASS_NAME, myModel);
      log.Info("PageTemplateEditorAS::Constructor: Register views succesful");
      // Register Controls
      RegisterControl(PageTemplateRepostControl.STR_MVC_CLASS_NAME, myModel);
      log.Info("PageTemplateEditorAS::Constructor: Register controls succesful");
      // Set default page
      SetCurrentPage(PageTemplateMainDP.STR_MVC_CLASS_NAME);
      // Register common sections
      //      Register each Section/Model for your plug-in sections
      RegisterModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
      IModel myPageLayoutModel = GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
      RegisterView(PageLayoutView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterView(PageLayoutHeaderView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterView(PageLayoutAlternateView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterControl(PageLayoutControl.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterPage(new PageTemplatePagesDP());
      // Register the select PTObject list as a plug-in section
      RegisterModel(InheritListModel.STR_MVC_CLASS_NAME, PLUGIN_PAGES);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myPagesModel = GetModel(PLUGIN_PAGES);
      RegisterView(CommunitiesListView.STR_MVC_CLASS_NAME, PLUGIN_PAGES, myPagesModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, PLUGIN_PAGES, myPagesModel);
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(552, "ptmsgs_portaladminmsgs"));
      // Main Settings
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PageTemplateMainDP.STR_MVC_CLASS_NAME);
      // Default Page Name
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PageTemplateDefaultPageNameDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PageTemplatePagesDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1847, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 45;
          int iTipId = 46;
          int iSecondaryTipId = 47;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
     */
     
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (PageTemplateMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_PageTemplate_MainSettings");
      } else
      if (PageTemplateDefaultPageNameDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_PageTemplate_DefaultPageName");
      }
    }
    
    /// <summary>
    /// Adjust the number of pixels for the drag and drop
    /// based on the language of the user.
    /// </summary>
    /// <param name="asOwner"></param>
    /// <returns>int</returns>
    public static int GetLayoutTableTop(AActivitySpace asOwner)
    {
      String strLang = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       asOwner));
      int nLayoutTop = LAYOUTTABLE_TOP;
      if (strLang.Equals("ja"))
      {
        nLayoutTop+=9;
      } else
      if (strLang.Equals("zh"))
      {
        nLayoutTop+=9;
      } else
      if (strLang.Equals("ko"))
      {
        nLayoutTop+=4;
      } else
      if (strLang.Equals("fr"))
      {
        nLayoutTop+=2;
      } else
      if (strLang.Equals("de"))
      {
        nLayoutTop+=2;
      } else
      if (strLang.Equals("en"))
      {
        nLayoutTop+=0;
      } else
      if (strLang.Equals("it"))
      {
        nLayoutTop+=0;
      } else
      if (strLang.Equals("pt"))
      {
        nLayoutTop+=0;
      } else
      if (strLang.Equals("es"))
      {
        nLayoutTop+=0;
      }
      // DCA - check if the page is going to print any errors, adjust the layout position
      // TODO-MJD : this doesn't work.
      if (((ErrorModel) asOwner.GetModel(ErrorModel.STR_MVC_CLASS_NAME)).GetErrors().MoveNext())
      {
        nLayoutTop+=40;
      }
      return nLayoutTop;
    }
  }
}