using System;
// Framework Imports
using com.plumtree.portalpages.common.editpage;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.pagetemplate
{
  /// <author>MichaelD</author>
  public class PageTemplateMainDP : EditorDP
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageTemplateMain";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(558, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1682, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      //      This is where you print out the plug-in view.
      // This will add some empty space between the two views
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).Display());
      if (!((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
      {
        views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutAlternateView.STR_MVC_CLASS_NAME).Display());
        }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from PlumtreeDP need
    /// to implement.  The method should add whatever HTML the child class wants to
    /// use the DisplayJavaScript and add it to the head.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#DisplayJavaScriptFromChild()"></seealso>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection result = base.DisplayJavaScriptFromChild();
      if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != ((PageTemplateModel) m_asOwner.GetModel(PageTemplateModel.STR_MVC_CLASS_NAME)).GetObjectID())
      {
        result.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());
        if (((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
        {
          // DCA - We're going to use the drag and drop layout, set the layout table position
          ((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).SetLayoutTablePosition(PageTemplateEditorAS.GetLayoutTableTop(m_asOwner),
           PageTemplateEditorAS.LAYOUTTABLE_LEFT);
          result.AddInnerHTMLElement(((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
          } else
        {
          result.AddInnerHTMLElement(((PageLayoutAlternateView) m_asOwner.GetView(PageLayoutAlternateView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
          }
      } else
      {
        HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        myScript.AddInnerHTMLString("\n" + "function " + PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT + "()\n" + "{\n" + "\treturn true;\n" + "};\n");
        result.AddInnerHTMLElement(myScript);
      }
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLAfterForm()
     */
     
    public override HTMLElementCollection DisplayHTMLAfterForm()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      if (((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
      {
        HTMLTable myTable = new HTMLTable();
        myTable.SetOnSelectStart("return false");
        collection.AddInnerHTMLElement(myTable);
        myTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        HTMLTableRow myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        HTMLTableCell myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME).Display());
        }
      collection.AddInnerHTMLElement(base.DisplayHTMLAfterForm());
      return collection;
    }
  }
}