using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.inherit;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.interpreter;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.pagetemplate
{
  /// <author>michaeld</author>
  public class PageTemplateModel : ObjEditorModel,IObjEditorModelRO
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageTemplate";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageTemplateModel();
    }
    
    /// <summary>
    /// Run Page Type Job after store 
    /// </summary>
    private bool m_bRunPageTypeJob = false;
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
      if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != m_nObjectID)
      {
        int[][] annPortletOrder = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetColumnOrder();
        for (int i = PortletColumnConstants.NARROW_ONE.ToInt();i <= PortletColumnConstants.NARROW_TWO.ToInt();
        i++)
        {
          ((IPTPageTemplate) m_ptObject).AssignGadgetsEx(annPortletOrder[i],
           i);
        }
        int nFreeFormID = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).FreeFormToBeRemove();
        if (nFreeFormID != -1)
        {
          ((IPTPageTemplate) m_ptObject).RemoveGadget(nFreeFormID);
        }
        if (((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetHasFreeFormPortlet())
        {
          try
          {
            ((IPTPageTemplate) m_ptObject).AddGadgetEx(((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetFreeFormPortletID(),
             -1);
          }
          // DCA - already added freeform gadget
          catch (Exception e)
          {
          }
        }
        // DCA - Don't really have to do anything
        if (m_bRunPageTypeJob)
        {
          ((IPTScheduledOperation) ((IPTPageTemplate) m_ptObject)).ScheduleImmediateJob();
          }
      }
    }
    
    /// <summary>
    /// Initializes IPTProperty with the property type member  variable just
    /// before we store the object in the DB. Also sets 2 other values to
    /// default.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != m_nObjectID)
      {
        // Get the settings back from the plug-in Model and sets them on the Object before the Framework stores it.
        // Set page type
        int nPageType = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetPageType();
        if (nPageType != ((IPTPageTemplate) m_ptObject).GetPageType())
        {
          ((IPTPageTemplate) m_ptObject).SetPageType(nPageType);
          if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
          {
            // Run job for each page that uses this page template to change its page type
            //  and move its gadgets to the correct column.
            ((IPTPageTemplate) m_ptObject).SetJobType(PT_PAGE_TEMPLATE_JOB_TYPES.PT_PAGE_TEMPLATE_JOB_PROPAGATE_PAGETYPE);
            m_bRunPageTypeJob = true;
          }
        }
      }
      ((LocNamesModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME)).Finish();
      }
    
    /// <summary>
    /// Initializes the property type member variable with  the one from
    /// IPTProperty in Edit mode and the default  value in create mode.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      int nTableHeight;
      IASQueryResult ptqrPortlets = null;
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        ASQueryResultWrapper qrw = new ASQueryResultWrapper(((IPTPageTemplate) m_ptObject).QueryGadgets());
        ptqrPortlets = qrw;
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        } else
      {
        // MJD - This is the default default page name
        ((IPTPageTemplate) m_ptObject).SetDefaultPageName(m_asOwner.GetString(559,
         "ptmsgs_portaladminmsgs"));
        // MJD - This is the default page type.
        // BT: Use default portlet layout if portlet layouts are enabled.
        if (LayoutService.getChooserInstance().GetPortletLayoutsEnabled(m_asOwner))
        {
          // adaptive layout stores a negative value in the page type (negative value of a webservice layout id)
          ((IPTPageTemplate) m_ptObject).SetPageType(-PT_INTRINSICS.PT_WEBSERVICE_DEFAULT_PORTLET_LAYOUT);
          } else
        {
          ((IPTPageTemplate) m_ptObject).SetPageType(PageTypeConstants.TWO_COLUMN_NARROW_WIDE);
          }
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      if (browser.IsNetscape4())
      {
        nTableHeight = 800;
      } else
      {
        nTableHeight = 400;
      }
      ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetOpenerClassID(PT_CLASSIDS.PT_PAGETEMPLATE_ID);
      ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetOpenerObjectID(m_nObjectID);
      ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetAllowFreeFormSection(true);
      ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn((IPTPageTemplate) m_ptObject,
       nTableHeight, ptqrPortlets, m_Session);
      StartDefaultPageNamesList();
      StartPages();
    }
    // END ***************** helper methods *****************
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerClassID()"></seealso>
    public virtual int GetOpenerClassID()
    {
      return PT_CLASSIDS.PT_PAGETEMPLATE_ID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerCommunityID()"></seealso>
    public virtual int GetOpenerCommunityID()
    {
      return -1;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerObjectID()"></seealso>
    public virtual int GetOpenerObjectID()
    {
      return m_nObjectID;
    }
    
    /// <summary>
    /// Gets the selected gadget ids as an int array.
    /// </summary>
    /// <returns>int[] anPortletID</returns>
    public virtual XPSortedDictionary GetSelectedPortlets()
    {
      return ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetSelectedPortlets();
      }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(PageTemplateMainDP.STR_MVC_CLASS_NAME))
      {
        if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != m_nObjectID)
        {
          ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
          }
      } else
      if (_sPageName.Equals(PageTemplateDefaultPageNameDP.STR_MVC_CLASS_NAME))
      {
        ((LocNamesModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME)).SaveSection(_htFormData);
        }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to start the localized names  and description list.
    /// </summary>
    public virtual void StartDefaultPageNamesList()
    {
      LocNamesModel model = ((LocNamesModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME));
      model.InitializeNameDescEditor(((IPTPageTemplate) m_ptObject).GetDefaultPageLocalizable(),
       21);
      model.SetIsNoDescriptions(true);
      model.SetPopUpDisplayPageName(DefaultPageNamePopUpDP.STR_MVC_CLASS_NAME);
      model.SetNameLabel(m_asOwner.GetString(2728, "ptmsgs_portaladminmsgs"));
      }
    
    /// <summary>
    /// Helper method to start the Pages List.
    /// </summary>
    private void StartPages()
    {
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        InheritListModel inheritModel = ((InheritListModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_PAGES));
        inheritModel.InitializeInheritList(m_asOwner.GetString(3052, ResourceConstants.PORTALADMINMSGS),
         PT_CLASSIDS.PT_PAGE_ID, 67);
        inheritModel.SetEmptyListMessages(m_asOwner.GetString(3053, ResourceConstants.PORTALADMINMSGS),
         "");
        //     Use the method bellow to set the icon to display on each row.
        //     (By default there will be no icon.)
        // TODO-MJD : need new icon
        inheritModel.SetDefaultRowIcon(PTImageType.ICON_MYPAGE);
        // Add inherited pages.
        inheritModel.SetDefaultObjects(m_Session, PT_CLASSIDS.PT_PAGE_ID,
         m_nObjectID, PT_PROPIDS.PT_PROPID_PAGES_PAGETEMPLATEID, PT_PROPIDS.PT_PROPID_PAGES_INHERITPAGETEMPLATE);
        } else
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, PageTemplatePagesDP.STR_MVC_CLASS_NAME);
        }
    }
  }
}