using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.portlet
{
  /// <author>
  /// adolfoc 
  /// This class is used to automatically identify and display the
  /// appropriate views based on the list of views in the PortletData
  /// This should help avoid mistakes with forgetting to display
  /// javascript and missing spacers, etc.
  /// </author>
  public abstract class PPluginDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portlet.PPluginDP");
    
    /// <summary>
    /// Returns the name of the Help Topic to be used for this
    /// page.
    /// </summary>
    /// <returns></returns>
    public abstract String GetPluginHelpTopic();
    
    /// <summary>
    /// Returns an ordered list of the views for this page, in this mode.
    /// </summary>
    public abstract XPArrayList GetOrderedViewList(int nPMode);
    
    /// <summary>
    /// Determines whether a specific view is enabled in the suggested mode.
    /// </summary>
    public virtual bool IsEnabled(int nPMode, String strViewName)
    {
      XPArrayList xpalPViews = GetOrderedViewList(nPMode);
      IXPEnumerator xpEnumPSubModels = xpalPViews.GetEnumerator();
      while (xpEnumPSubModels.MoveNext())
      {
        String strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();
        if (0 == strSubModelKeyCurrent.CompareTo(strViewName))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      PortletModel myModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      XPArrayList xpalPViews = GetOrderedViewList(myModel.GetPMode());
      IXPEnumerator xpEnumPSubModels = xpalPViews.GetEnumerator();
      while (xpEnumPSubModels.MoveNext())
      {
        String strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();
        try
        {
          EditorView pSubViewCurrent = (EditorView) m_asOwner.GetView(strSubModelKeyCurrent);
          views.AddInnerHTMLElement(pSubViewCurrent.Display());
          views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        }
        catch (Exception e)
        {
          log.Error(e, GetName() + "::PageDisplay() The following error occured when trying to display the HTML for Section (" + strSubModelKeyCurrent + ").");
          throw new XPException(m_asOwner.GetString(617, "ptmsgs_portaladminmsgs"),
           e);
        }
      }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#DisplayJavaScriptFromChild()"></seealso>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection result = base.DisplayJavaScriptFromChild();
      if (null == result)
      {
        result = new HTMLScriptCollection();
      }
      PortletModel myModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      XPArrayList xpalPViews = GetOrderedViewList(myModel.GetPMode());
      IXPEnumerator xpEnumPSubModels = xpalPViews.GetEnumerator();
      while (xpEnumPSubModels.MoveNext())
      {
        String strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();
        try
        {
          EditorView pSubViewCurrent = (EditorView) m_asOwner.GetView(strSubModelKeyCurrent);
          HTMLScript currentScript = pSubViewCurrent.DisplayJavascript();
          if (null != currentScript)
          {
            result.AddInnerHTMLElement(currentScript);
          }
        }
        catch (Exception e)
        {
          log.Error(e, GetName() + "::PageDisplay() The following error occured when trying to display the Javascript for Section (" + strSubModelKeyCurrent + ").");
          throw new XPException(m_asOwner.GetString(617, "ptmsgs_portaladminmsgs"),
           e);
        }
      }
      return result;
    }
  }
}