using System;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.portlet
{
  /// <summary>
  /// This class implements the HTML to print out the Editor header.
  /// This View is printed out by EditorDP.
  /// Editor Views should NOT extend this class.
  /// They should extend EditorView instead.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class PortletEditorHeaderView : EditorHeaderView
  {
    
    /// <summary>
    /// Object Name for AS 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PortletEditorHeader";
    // HTML Object names.
    
    /// <summary>
    /// HTMLID for the NEXT button 
    /// </summary>
    public const String HTMLBUTTON_EDITOR_NEXT = "in_bu_Next";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletEditorHeaderView();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.FormHeaderView#AddHeaderButtons()"></seealso>
    protected override HTMLElement AddHeaderButtons()
    {
      HTMLImg myImage;
      HTMLInput myInput;
      PTConstruct myConstruct;
      // Begin Header buttons table
      HTMLTable mySubTable = new HTMLTable();
      mySubTable.SetBorder("0");
      mySubTable.SetCellPadding("5");
      mySubTable.SetCellSpacing("0");
      // button table 1st Row
      HTMLTableRow mySubRow = new HTMLTableRow();
      mySubTable.AddInnerHTMLElement(mySubRow);
      HTMLTableCell mySubCell = new HTMLTableCell();
      mySubRow.AddInnerHTMLElement(mySubCell);
      mySubCell.SetHeight("20");
      mySubCell.SetAlign("right");
      mySubCell.SetVAlign("middle");
      mySubCell.SetNoWrap(true);
      // JF- Only display the done button if the it's not read-only mode.
      if (!((IEditorModelRO) m_model).GetIsEditorReadOnly())
      {
        // AGC- This is really the only thing that's different from the
        // super implementation.
        // Next button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_EDITOR_NEXT,
         "");
        myInput.SetValue(m_asOwner.GetString(1856, "ptmsgs_portaladminmsgs"));
        myInput.SetOnClick("goToPage(\'" + m_asOwner.GetName() + "\', \'" + MainDP.STR_MVC_CLASS_NAME + "\', \'\'); return false;");
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        mySubCell.AddInnerHTMLElement(myInput);
        mySubCell.AddInnerHTMLString(SPACE);
        // Done button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_EDITOR_FINISH,
         "");
        mySubCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(38, "ptmsgs_infrastructure"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        myInput.SetOnClick("postToSelf(" + EditorRepostControl.POSTTOSELF_ACTION_FINISH + "); return false;");
        mySubCell.AddInnerHTMLString(SPACE);
      }
      // Cancel button
      myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_EDITOR_CANCEL,
       "");
      mySubCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(m_asOwner.GetString(39, "ptmsgs_infrastructure"));
      myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
      myInput.SetOnClick("postToSelf(" + EditorRepostControl.POSTTOSELF_ACTION_CANCEL + "); return false;");
      mySubCell = new HTMLTableCell();
      mySubRow.AddInnerHTMLElement(mySubCell);
      mySubCell.SetWidth("1");
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetWidth("1");
      myImage.SetHeight("1");
      myImage.SetBorder("0");
      mySubCell.AddInnerHTMLElement(myImage);
      return mySubTable;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      return base.Display();
    }
  }
}