using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.portlet.plugins;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.browsing.objectselection.portlets;
using com.plumtree.portalpages.browsing.portletpreview;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.portlet
{
  /// <author>adolfoc</author>
  public class PortletModel : ObjEditorModel,IPortletModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portlet.PortletModel");
    public const String STR_MVC_CLASS_NAME = "Portlet";
    
    /// <summary>
    /// These static variables are used in determining what UI to display and how to initialize
    /// the portlet object.
    /// </summary>
    public static readonly String HTTPGP_CLSID = PT_PROVIDER_CLSIDS.PT_REMOTEPORTLET_PROVIDER;
    public static readonly String IGP_CLSID = PT_PROVIDER_CLSIDS.PT_INTRINSICPORTLET_PROVIDER;
    public const String PORTLET_CLSID = "{C73FD37D-3A81-43f0-9463-C55AF23236BE}";
    public const String PORTLET_TEMPLATE_CLSID = "{B940496F-E658-4ba0-A111-E87AC40BB6BD}";
    // An invalid mode. It should never be returned unless this editor is seriously messed up.
    
    /// <summary>
    /// The following static members define the possible modes this editor can be in.
    /// </summary>
    public const int PMODE_INVALID = -1;
    // The mode the editor starts up when started in CREATE_MODE.
    public const int PMODE_PRECREATE = 0;
    // The mode used when the portlet is being created from scratch.
    public const int PMODE_CREATE = 1;
    // The mode used when the portlet is being created from a portlet template.
    public const int PMODE_CREATE_FROMTEMPLATE = 2;
    // The mode used when we are editing a portlet.
    public const int PMODE_EDIT = 3;
    
    /// <summary>
    /// Query String to determine if freeform templates should be shown 
    /// </summary>
    public const String QS_SHOWFREEFORM = "ShowFreeForm";
    
    /// <summary>
    /// Query String to determine if freeform templates should be shown 
    /// </summary>
    public const String QS_SHOWHEADERFOOTER = "ShowHeaderFooter";
    
    /// <summary>
    /// Web Service ID for intrinsic Community Links portlet *
    /// </summary>
    public const int WSID_COMMUNITYLINKS = 2;
    
    /// <summary>
    /// This member maintains a registry of page names that extend
    /// PPluginDP. We must remember to enable and disable these pages
    /// when the appropriate updates occur.
    /// </summary>
    protected XPArrayList m_xalPPluginDPs;
    
    /// <summary>
    /// This member maintains a registry of Plugin model keys that support
    /// the IWSSubModel interface. We must remember to exercise the IWSSubModel
    /// interface on them when the appropriate updates occur.
    /// </summary>
    protected XPArrayList m_xalPSubModels;
    
    /// <summary>
    /// This member contains wether the portlet being created is for a community (it is
    /// not always present). It is used when creating a new portlet from a
    /// template. It is false if no value was passed in.
    /// </summary>
    private bool m_bForCommunity = false;
    
    /// <summary>
    /// This member holds the CLASSID of the object we will be created from. It
    /// can either be the classid for WebServices or for Portlet Templates.
    /// </summary>
    private int m_nCreatorClassID = -1;
    
    /// <summary>
    /// This member holds the object ID of the object we will be created from. It
    /// is used with m_nCreatorClassID to initialize ourselves either from the
    /// tree popup (Admin view) or the PSelectTemplate page.
    /// </summary>
    private int m_nCreatorID = -1;
    
    /// <summary>
    /// This member defines the current mode of the PortletEditor (as per the above enumeration);
    /// When this member is changed, we must send an update to all of our pages and views.
    /// </summary>
    private int m_nPMode;
    public PortletModel() : base()
    {
      m_xalPPluginDPs = new XPArrayList();
      m_xalPSubModels = new XPArrayList();
      m_nPMode = PMODE_INVALID;
    }
    public virtual void AddSendToOthersButtonToHelpBanner(PTConstruct myHelpBanner)
    {
      try
      {
        IPTGadget ptPortlet = (IPTGadget) GetObject();
        if ((EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType()) && (GetPortletType() == PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL) && ((ptPortlet.GetAlignment() == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW) || (ptPortlet.GetAlignment() == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE)))
        {
          // Send to Others Link
          PTConstruct buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SEND_TO_OTHERS,
           true, this.m_asOwner);
          ElementName eName = PTButtonType.SEND_TO_OTHERS.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE);
          // "Send To Others"
          buttonConstruct.ReplaceNestedElementsWithHTMLString(eName, m_asOwner.GetString(640,
           "ptmsgs_portalcommonmsgs"));
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(640,
           "ptmsgs_portalcommonmsgs"));
          HTMLAnchor myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.SEND_TO_OTHERS.ANCHOR_ELEMENT_NAME);
          ASURL asurl = new ASURL(m_asOwner);
          asurl.SetLinkGetSpaceIfCached(PortletSelectionEditorAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
          asurl.SetDisplayPage(PortletInvitationPopupDP.STR_MVC_CLASS_NAME);
          asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationID,
           XPConvert.ToString(GetObjectID()));
          asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationName,
           m_ptObject.GetLocalizedName());
          String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'" + asurl.GetURLAsString() + "\', \'SendToOthers\', \'250\',\'600\'); return false;");
          //myAnchor.AddInnerHTMLString(_ui_SendToOthers);
          myHelpBanner.AddElementToNestedElement(PTBannerType.BANNER_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
           myAnchor);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PortletEditorAS::GetHelpBanner The following error occured when trying to get the help banner: " + e.Message);
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletModel();
    }
    
    /// <summary>
    /// Calculates whether or not the "mandatory" column should be displayed on
    /// the security tab.  We should display the mandatory column if the gadget
    /// is not a template AND it is a narrow or wide portlet.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public virtual void DetermineWhetherToDisplayMandatoryColumnOnSecurityPage()
    {
      int nAlignment = GetPortletSize();
      int nPortletType = GetPortletType();
      if (((nAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW) || (nAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE)) && (nPortletType == PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL))
      {
        ObjectSecurityModel modelSecurity = (ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB);
        modelSecurity.SetSupportMandatoryColumn(ObjectSecurityModel.MANDCOL_REGULAR);
        PriorityDropDownModel modelPriority = (PriorityDropDownModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN);
        modelPriority.SetSupportMandatoryColumn(true);
      } else
      {
        ObjectSecurityModel modelSecurity = (ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB);
        modelSecurity.SetSupportMandatoryColumn(ObjectSecurityModel.MANDCOL_NONE);
        PriorityDropDownModel modelPriority = (PriorityDropDownModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN);
        modelPriority.SetSupportMandatoryColumn(false);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()"></seealso>
    public override void DoTaskBeforeStore()
    {
      base.DoTaskBeforeStore();
      PreStorePSubModels();
      return;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnStartEditor(_htFormData)"></seealso>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    //MES-CR: I don't really get this- if the editor is just starting, how would we
    //	have form data?
    //AGC-CR: Data passed into the editor on start.
    {
      base.DoTaskOnStartEditor(_htFormData);
      try
      {
        switch (GetEditorType()){
        case EditorStartControl.EDITOR_START_FLAG_EDIT:
        m_nPMode = PMODE_EDIT;
        UpdatePages();
        InitPSubModels();
        UpdatePSubModels();
        DetermineWhetherToDisplayMandatoryColumnOnSecurityPage();
        break;
        case EditorStartControl.EDITOR_START_FLAG_CREATE:
        // AGC- This initialization is temporary, just to avoid spurious
        // errors. Since the object is likely to be replaced, we'll be
        // reinitializing it later. At that point, we'll know what
        // WebService to use (and thus what provider CLSID). Whee.
        ((IPTGadget) m_ptObject).Initialize(HTTPGP_CLSID);
        // AGC- We determine what mode we're in depending on whether we're
        // a template or not - which is in turn determined by the name of the
        // Activity space that we belong to.
        if (0 == PortTempPortletEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
        {
          m_nPMode = PMODE_CREATE;
          // AGC- This may not strictly be necessary, but it's a good idea.
          // NOTE: This must be done through the IPTGadgetTemplate interface or
          // there will be an error.
          ((IPTGadgetTemplate) m_ptObject).SetGadgetType(PT_GADGET_TYPES.PT_GADGETTYPE_TEMPLATE);
          } else
        if ((m_nCreatorClassID <= 0) || (m_nCreatorID <= 0))
        {
          m_nPMode = PMODE_PRECREATE;
          m_asOwner.SetCurrentPage(m_asOwner.GetPage(PreCreateDP.STR_MVC_CLASS_NAME));
          if (!m_bForCommunity)
          {
            // AGC- This is an error case. Either the CreatorID/CLASSID
            // must be set or this must be for a community. We should note the error, but continue in PRECREATE mode (the
            // best we're gonna get).=
            log.Error("PortletData::DoTaskOnStartEditor() Either you must use this editor for a Community Portlet OR (not exclusive) CREATORID AND CREATORCLASSID must be set in order to use this editor.");
            }
        } else
        {
          // AGC- The Creator ID and CLASSID were passed in. We must create ourselves.
          if (m_nCreatorClassID == PT_CLASSIDS.PT_WEBSERVICE_ID)
          {
            // If the classID is the WebService ID, we can do nothing ( create as usual). The
            // WebService selection view on the MainDP will collect the object ID from m_nCreatorID.
            m_nPMode = PMODE_CREATE;
          } else
          if (m_nCreatorClassID == PT_CLASSIDS.PT_GADGETTEMPLATE_ID)
          {
            // If the classID is the Portlet Template ID, we must recreate our m_ptObject based on
            // template (much like PChooseModel or PSelectTemplateModel do).
            SetEditedObject(CreateObjectFromTemplate(m_nCreatorID));
            m_nPMode = PortletModel.PMODE_CREATE_FROMTEMPLATE;
          } else
          {
            // AGC- Something is seriously wrong. This editor only knows how to
            // create itself from an existing WebService or PortletTemplate.
            // Best we can do is try to go to PRE_CREATE mode and pray for the best.
            m_nPMode = PMODE_CREATE;
            log.Error("PortletData::DoTaskOnStartEditor() CREATORCLASSID is not WebService or Portlet Template! Going to PreCreateMode");
            }
        }
        UpdatePages();
        InitPSubModels();
        UpdatePSubModels();
        // this must be called AFTER we set m_intPortletSize and m_intGadgetType
        DetermineWhetherToDisplayMandatoryColumnOnSecurityPage();
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        break;
        default:
        m_nPMode = PMODE_INVALID;
        log.Warn("PortletData::DoTaskOnStartEditor: Invalid start flag passed into editor. Setting PMODE INVALID!");
        break;
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PortletData::DoTaskOnStartEditor - Unable to initialize editor from server: " + e.Message);
        }
    }
    public virtual bool IsForCommunity()
    {
      return m_bForCommunity;
    }
    public override int GetFolderID()
    {
      return m_nFolderID;
    }
    // Helper Functions
    public virtual int GetPortletType()
    {
      PortletSettingsModel mPortletSettings = (PortletSettingsModel) m_asOwner.GetModel(PortletEditorAS.Storage_PortletSettingsView);
      return mPortletSettings.GetPortletType();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the nPMode.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetPMode()
    {
      return m_nPMode;
    }
    public virtual int GetPortletSize()
    {
      PortletSettingsModel mPortletSettings = (PortletSettingsModel) m_asOwner.GetModel(PortletEditorAS.Storage_PortletSettingsView);
      return mPortletSettings.GetPortletSize();
    }
    public virtual String GetProviderCLSID()
    {
      SelectWebServiceModel mSelectWebService = (SelectWebServiceModel) m_asOwner.GetModel(PortletEditorAS.Storage_SelectWebServiceView);
      return XPStringUtility.ToUpperCase(mSelectWebService.GetWSObject().GetProviderCLSID());
      }
    public virtual IPTWebService GetWebService()
    {
      SelectWebServiceModel mSelectWebService = (SelectWebServiceModel) m_asOwner.GetModel(PortletEditorAS.Storage_SelectWebServiceView);
      return mSelectWebService.GetWSObject();
    }
    public virtual bool IsTemplate()
    {
      PortletSettingsModel mPortletSettings = (PortletSettingsModel) m_asOwner.GetModel(PortletEditorAS.Storage_PortletSettingsView);
      return (PT_GADGET_TYPES.PT_GADGETTYPE_TEMPLATE == mPortletSettings.GetPortletType());
      }
    public virtual bool IsMandatory()
    {
      // Templates cannot be mandatory.
      if (IsTemplate())
      {
        return false;
      }
      // reopen the object (this is called after the object has been stored)
      IPTGadget ptPortlet = (IPTGadget) m_ptObject;
      IPTQueryResult ptQR = ptPortlet.QueryMandatoryGroups();
      return (null != ptQR && 0 < ptQR.RowCount());
    }
    public virtual void PreStorePSubModels()
    {
      // AGC- Only store those views that are active in our current mode!
      IXPEnumerator xpEnumPPluginDPs = m_xalPPluginDPs.GetEnumerator();
      // Walk through all of the pages
      while (xpEnumPPluginDPs.MoveNext())
      {
        PPluginDP pPluginDPCurrent = (PPluginDP) m_asOwner.GetPage((String) xpEnumPPluginDPs.GetCurrent());
        XPArrayList xpalModelsCurrent = pPluginDPCurrent.GetOrderedViewList(m_nPMode);
        IXPEnumerator xpEnumPSubModels = xpalModelsCurrent.GetEnumerator();
        // Walk through each view on each page
        while (xpEnumPSubModels.MoveNext())
        {
          String strSubModelKeyCurrent = "";
          strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();
          IPSubModel wsSubModelCurrent = (IPSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
          // Tell the buggers to prepare for the end times
          wsSubModelCurrent.DoTaskBeforePStore();
        }
      }
    }
    // ***************************************** SubModel Management ********************************8
    // ************************************ IPSubModel methods ***************************************
    
    /// <summary>
    /// This method is used to register a new PPluginDP with this WebService main model. This is done
    /// so that plugin pages can be hidden and shown automatically depending on the PMODE.
    /// </summary>
    public virtual void RegisterPPage(String strDPName)
    {
      try
      {
        IDisplayPage myIDP = m_asOwner.GetPage(strDPName);
        PPluginDP myPPDP = null;
        try
        {
          myPPDP = (PPluginDP) myIDP;
          myPPDP.IsEnabled(m_nPMode, "");
        }
        catch (Exception e)
        {
          log.Error(e, "PortletData::RegisterPPage(\"" + strDPName + "\") - Attempted to register page that doesn\'t extend PPluginDP. Error:" + e.Message);
          }
        if (null == myPPDP)
        {
          log.Error("PortletData::RegisterPPage(\"" + strDPName + "\") - Attempted to register null PPluginDP. Error:");
          } else
        {
          m_xalPPluginDPs.Add(strDPName);
        }
      }
      catch (Exception e)
      {
        log.Error("PortletData::RegisterPPage(\"" + strDPName + "\") - Could not register page. Error:" + e.Message);
        }
    }
    
    /// <summary>
    /// This method is used to register a new submodel with this WebService main model. This is done
    /// so that submodels can have access to the Remote Server base URL which is necessary for them
    /// to display. All submodels that are registered must support the IPSubModel interface.
    /// </summary>
    public virtual void RegisterPSubModel(String strPluginModelStorageName)
    {
      try
      {
        IModel imSubModel = m_asOwner.GetModel(strPluginModelStorageName);
        IPSubModel wsSubModel = null;
        try
        {
          wsSubModel = (IPSubModel) imSubModel;
        }
        catch (Exception e)
        {
          log.Error(e, "PortletData::RegisterPSubModel(\"" + strPluginModelStorageName + "\") - Attempted to register model that doesn\'t support IPSubModel. Error:" + e.Message);
          }
        if (null == wsSubModel)
        {
          log.Error("PortletData::RegisterPSubModel(\"" + strPluginModelStorageName + "\") - Attempted to register null IPSubModel. Error:");
          } else
        {
          m_xalPSubModels.Add(strPluginModelStorageName);
        }
      }
      catch (Exception e)
      {
        log.Error("PortletData::RegisterPSubModel(\"" + strPluginModelStorageName + "\") - Could not register model. Error:" + e.Message);
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      IDisplayPage myDP = m_asOwner.GetPage(_sPageName);
      PPluginDP myPortletDP = null;
      try
      {
        //AGC - try to cast to
        myPortletDP = (PPluginDP) myDP;
      }
      catch (Exception e)
      {
        // Didn't work. It's someone else's page. Just return.
        return nPageStatus;
      }
      // Just double checking.
      if (null == myPortletDP)
      {
        return nPageStatus;
      }
      XPArrayList xpalViews = myPortletDP.GetOrderedViewList(GetPMode());
      IXPEnumerator xpEnumSubModels = xpalViews.GetEnumerator();
      while (xpEnumSubModels.MoveNext())
      {
        String strSubModelKeyCurrent = (String) xpEnumSubModels.GetCurrent();
        try
        {
          IPSubModel pSubModelCurrent = (IPSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
          int nLocalStatus = ((EditorHelperModel) pSubModelCurrent).SaveSection(_htFormData);
          if (EditorRepostControl.PAGE_STATUS_VALID != nLocalStatus)
          {
            nPageStatus = nLocalStatus;
          }
        }
        catch (Exception e)
        {
          log.Error(GetName() + "::SavePage(" + _sPageName + ") The following error occured when trying to Save the Section(" + strSubModelKeyCurrent + "): " + e.Message);
          }
      }
      // this must be called AFTER we set m_intPortletSize and m_intGadgetType
      DetermineWhetherToDisplayMandatoryColumnOnSecurityPage();
      return nPageStatus;
    }
    // *************************************** Persistence ******************************************8
    
    /// <summary>
    /// Reset the portlet object we are editing to this new one. This will require some special processing
    /// as some of our framework needs to be updated along with our own submodels.
    /// Note* This call can only be called from CREATE mode and will do nothing if called in any other mode.
    /// </summary>
    public virtual void SetEditedObject(IPTGadget ptPortlet)
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        m_ptObject = (IPTObject) ptPortlet;
      } else
      {
        return;
      }
      // We must reinitialize the framework. These calls are made by our super class in StartEditor. If
      // the super class changes, this section should be updated.
      // Init common pages
      base.StartLocNamesList();
      base.StartSecurityList();
      base.StartObjectProp();
      // Perform Editor specific tasks. This will also reinitialize our submodels for us.
      // These calls are similar to those made in DoTaskOnStartEditor.
      UpdatePages();
      InitPSubModels();
      UpdatePSubModels();
      DetermineWhetherToDisplayMandatoryColumnOnSecurityPage();
    }
    // We need not bother calling Update on our models. We know that the PMODE will be probably
    // be changed soon and that will do it for us.
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ObjEditorModel#SetMemberVariablesFromQS(XPHashtable)"></seealso>
    public override void SetMemberVariablesFromQS(XPHashtable _htFormData)
    {
      base.SetMemberVariablesFromQS(_htFormData);
      // Community ID
      m_bForCommunity = PortletModelHelper.GetFormCheckboxBool(_htFormData,
       PTPortlets.PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY);
      m_nCreatorClassID = PortletModelHelper.GetFormElementInt(_htFormData,
       PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_CLASSID, -1);
      m_nCreatorID = PortletModelHelper.GetFormElementInt(_htFormData, PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_ID,
       -1);
    }
    
    /// <summary>
    /// Sets the nPMode.
    /// </summary>
    /// <param name="nPMode">The nPMode to set</param>
    public virtual void SetPMode(int nPMode)
    {
      m_nPMode = nPMode;
      // AGC- Don't forget to hide/show all of our pages based on the new information...
      UpdatePages();
      // AGC- The views should be told as well... just in case they care...
      UpdatePSubModels();
    }
    public virtual void UpdatePSubModels()
    {
      try
      {
        IXPEnumerator xpEnumPSubModels = m_xalPSubModels.GetEnumerator();
        while (xpEnumPSubModels.MoveNext())
        {
          String strSubModelKeyCurrent = "";
          try
          {
            strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();
            IPSubModel pSubModelCurrent = (IPSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
            pSubModelCurrent.DoTaskOnWebServiceUpdate(GetWebService());
            pSubModelCurrent.DoTaskOnPModeUpdate(GetPMode());
          }
          catch (Exception e)
          {
            log.Error("PortletData::UpdatePSubModels() Unknown Error updating PSubModel (" + strSubModelKeyCurrent + ")." + e.Message);
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PortletData::UpdatePSubModels() Unknown Error." + e.Message);
        }
    }
    public virtual void UpdatePages()
    {
      // Automatically hide empty pages and show pages with information
      try
      {
        // Hide and show the appropriate frameworks pages.
        // Hide the security page in create mode
        if (IsForCommunity())
        {
          switch (m_nPMode){
          case PMODE_PRECREATE:
          //PMODE_INVALID:
          case -1:
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, LocNamesDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          break;
          case PMODE_CREATE_FROMTEMPLATE:
          case PMODE_CREATE:
          // When creating from the community page, you shouldn't
          // show the security editor - the parent community editor
          // will reset the security (security inherited from the community)
          // upon store. Any changes you would make in the security editor
          // would be lost anyway.
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, LocNamesDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          break;
          case PMODE_EDIT:
          default:
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, LocNamesDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          break;
          }
        } else
        {
          switch (m_nPMode){
          case PMODE_PRECREATE:
          //PMODE_INVALID:
          case -1:
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, LocNamesDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          break;
          case PMODE_CREATE_FROMTEMPLATE:
          case PMODE_CREATE:
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, LocNamesDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          break;
          case PMODE_EDIT:
          default:
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, LocNamesDP.STR_MVC_CLASS_NAME);
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          break;
          }
        }
        ((EditorAS) m_asOwner).GetLeftMenu().HideSubMenu((m_nPMode == PMODE_PRECREATE),
         0);
        ((EditorAS) m_asOwner).GetLeftMenu().HideSubMenu((m_nPMode == PMODE_PRECREATE),
         1);
        // Hide and show our plugin pages and views.
        IXPEnumerator xpEnumPPluginDPs = m_xalPPluginDPs.GetEnumerator();
        while (xpEnumPPluginDPs.MoveNext())
        {
          try
          {
            String strDPNameCurrent = (String) xpEnumPPluginDPs.GetCurrent();
            PPluginDP pPluginDPCurrent = (PPluginDP) m_asOwner.GetPage(strDPNameCurrent);
            XPArrayList xpalViews = pPluginDPCurrent.GetOrderedViewList(m_nPMode);
            int nNumViews = xpalViews.GetSize();
            if (0 >= nNumViews)
            {
              ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, strDPNameCurrent);
              } else
            {
              ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, strDPNameCurrent);
              }
          }
          catch (Exception e)
          {
            log.Error(e, "PortletData::UpdatePSubModels() Unknown Error updating PSubModel." + e.Message);
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PortletData::UpdatePSubModels() Unknown Error." + e.Message);
        }
    }
    private void InitPSubModels()
    {
      try
      {
        IXPEnumerator xpEnumPSubModels = m_xalPSubModels.GetEnumerator();
        while (xpEnumPSubModels.MoveNext())
        {
          String strSubModelKeyCurrent = "";
          try
          {
            strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();
            IPSubModel pSubModelCurrent = (IPSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
            pSubModelCurrent.InitPModel((IPTGadget) m_ptObject);
          }
          catch (Exception e)
          {
            log.Error("PortletData::InitPSubModels() Unknown Error initializing PSubModel (" + strSubModelKeyCurrent + ")." + e.Message);
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PortletData::InitPSubModels() Unknown Error." + e.Message);
        }
    }
    
    /// <summary>
    /// If this editor is invoked from a template - this function is used to create the m_ptObject from a template.
    /// </summary>
    public virtual IPTGadget CreateObjectFromTemplate(int nObjectIDOfTemplate)
    {
      try
      {
        IPTSession ptSession = GetPTSession();
        IPTGadgetTemplate ptTemplateToClone = ((IPTGadgetTemplate) ptSession.GetGadgetTemplates().Open(nObjectIDOfTemplate,
         false));
        m_nPMode = PMODE_CREATE_FROMTEMPLATE;
        m_nCreatorClassID = PT_CLASSIDS.PT_WEBSERVICE_ID;
        m_nCreatorID = ptTemplateToClone.GetWebServiceID();
        IPTGadget ptPortlet = ptTemplateToClone.CreateGadgetInstance(ptSession,
         GetFolderID(), IsForCommunity() ? 1 : 0);
        ptPortlet.SetName(XPResourceManager.FormatMessage(m_asOwner.GetString(3152,
         "ptmsgs_portaladminmsgs"), ptTemplateToClone.GetLocalizedName()));
        return ptPortlet;
      }
      catch (Exception e)
      {
        log.Error(e, "PChooseModel::CreateObjectFromTemplate(" + XPConvert.ToString(nObjectIDOfTemplate) + ") Unknown error, cannot create templated object. Error: " + e.Message);
        }
      return null;
    }
    
    /// <summary>
    /// Returns the creatorClassID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCreatorClassID()
    {
      return m_nCreatorClassID;
    }
    
    /// <summary>
    /// Returns the creatorID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCreatorID()
    {
      return m_nCreatorID;
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      base.DoTaskOnComeBackFromSubEditor();
      SelectWebServiceModel mSelectWebService = (SelectWebServiceModel) m_asOwner.GetModel(PortletEditorAS.Storage_SelectWebServiceView);
      String strIntrinsicPortletClass = mSelectWebService.GetIntrinsicPortletClass();
      String strSubSpaceKey = strIntrinsicPortletClass + IntrinsicPortletPrefsUtils.SUBSPACE_KEY_SUFFIX;
      if (m_asOwner.GetSubSpaceExists(strSubSpaceKey))
      {
        m_asOwner.DeleteSubSpace(strSubSpaceKey);
      }
    }
    
    /// <summary>
    /// Helper method to check the current user rights to this Object Editor.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    /// <returns>boolean</returns>
    protected override bool CheckEditorAccess(XPHashtable _htFormData)
    {
      String[] values = (String[]) _htFormData.GetElement(QS_SHOWFREEFORM);
      if (values != null)
      {
        ((PSelectTemplateModel) m_asOwner.GetModel(PortletEditorAS.Storage_PSelectTemplateView)).SetShowFreeForm(true);
        }
      values = (String[]) _htFormData.GetElement(QS_SHOWHEADERFOOTER);
      if (values != null)
      {
        ((PSelectTemplateModel) m_asOwner.GetModel(PortletEditorAS.Storage_PSelectTemplateView)).SetShowHeaderAndFooter(true);
        }
      return base.CheckEditorAccess(_htFormData);
    }
  }
}