using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.portlet;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.admin.editors.portlet.plugins
{
  /// <author>AdolfoC</author>
  public class PChooseModel : EditorHelperModel,IPChooseModelRO,IPSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portlet.plugins.PChooseModel");
    public const String STR_MVC_CLASS_NAME = "PortletChooseSelectionModel";
    
    /// <summary>
    /// This member defines a static string used to identify when m_htFormData
    /// has been initialized.
    /// </summary>
    public const String DEFAULTDATA = "Default Data";
    
    /// <summary>
    /// Name of template (null means nothing selected)
    /// </summary>
    protected String m_strTemplateName = null;
    
    /// <summary>
    /// The Portlet Mode to continue the editor in (either create, or create from template).
    /// </summary>
    protected int m_nNextPMode;
    
    /// <summary>
    /// The portlet template that is currently chosen.
    /// </summary>
    protected int m_nTemplateObjectID = 0;
    
    /// <summary>
    /// This member contains form data sent to this control (used for the Tree control, mostly).
    /// </summary>
    private XPHashtable m_htFormData;
    public PChooseModel() : base()
    {
      m_nNextPMode = PortletModel.PMODE_INVALID;
      m_htFormData = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PChooseModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()"></seealso>
    public virtual void DoTaskBeforePStore()
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnPModeUpdate(int nNewWSMode)
    {
    }
    // AGC- This view initiates PMode changes - it generally does not consume them.
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String,String)"></seealso>
    public virtual void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
    {
    }
    // AGC- This view doesn't care - in fact it is unlikely that this view will ever
    // experience this method being called.
    
    /// <summary>
    /// This function actually commits the changes that forces our editor into
    /// the normal create or create from template modes. It is called by the
    /// Portlet Repost Control if "Done" is clicked during PRECREATE mode.
    /// </summary>
    public virtual void FinalizeCreation()
    {
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (PortletModel.PMODE_CREATE_FROMTEMPLATE == m_nNextPMode)
      {
        // Replace the PTObject the we all use with a new one generated from the template. This 
        // will force the reinitialization of all of our views.
        mParentModel.SetEditedObject(mParentModel.CreateObjectFromTemplate(m_nTemplateObjectID));
        }
      mParentModel.SetPMode(m_nNextPMode);
    }
    
    /// <seealso cref="com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)"></seealso>
    public virtual String GetData(String name)
    {
      String[] values = (String[]) m_htFormData.GetElement(name);
      if ((values == null) || (values.Length <= 0))
      {
        return DEFAULTDATA;
      }
      return values[0];
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the mode that this editor will be changed to when the user clicks finish.
    /// </summary>
    public virtual int GetNextPMode()
    {
      return m_nNextPMode;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ITemplateChooserModelRO#GetObjectIDOfTemplate()"></seealso>
    public virtual int GetObjectIDOfTemplate()
    {
      return this.m_nTemplateObjectID;
    }
    // BEGIN ***************** save DP methods ***************** 
    
    /// <summary>
    /// Returns the name value from m_strPortletTemplateTreeData.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetPortletTemplateName()
    {
      if (m_strTemplateName == null)
      {
        return "";
      }
      return m_strTemplateName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)"></seealso>
    public virtual void InitPModel(IPTGadget ptPortlet)
    {
    }
    // AGC- There is nothing to initialize - this view is only used to create objects.
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromTree()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(PortletEditorAS.PTTREE_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(PortletEditorAS.PTTREE_SUBSPACE);
          ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList itemList = treeModel.GetSelectedItems();
          log.Error("Tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
          TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
          if (item == null)
          {
            log.Error("Tree selected item null");
          } else
          {
            m_nTemplateObjectID = item.m_nObjectID;
            m_strTemplateName = item.GetName();
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PChooseModel::RefreshItemFromTree: Unknown error refreshing tree. e: " + e.Message);
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // Make sure we're in the correct PMODE - the user might have hit the back button
      // or something odd like that. We should never be saved outside of PRECREATE mode.
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (PortletModel.PMODE_PRECREATE != mParentModel.GetPMode())
      {
        mParentModel.SetPMode(PortletModel.PMODE_PRECREATE);
      }
      // Store our form data for later use - especially for use in the tree control.
      int nSize = _htFormData.GetSize();
      IXPEnumerator xpKeys = _htFormData.GetKeys();
      for (int i = 0;i < nSize;i++)
      {
        xpKeys.MoveNext();
        m_htFormData.PutElement((String) xpKeys.GetCurrent(), (String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
        }
      RefreshItemFromTree();
      // AGC- We only allow the user to choose "Create From Scratch" if they are not
      // calling from a community editor.
      if (!mParentModel.IsForCommunity())
      {
        String[] data;
        data = (String[]) _htFormData.GetElement(PChooseSelectionView.HTMLRADIO_PORTLET_CREATEFROM);
        if ((null != data) && !(0 == data.Length))
        {
          try
          {
            m_nNextPMode = XPConvert.ToInteger(data[0]);
          }
          catch (Exception e)
          {
            log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Suppress Title Bar checkbox. Using 0 instead.");
            }
        }
      } else
      {
        m_nNextPMode = PortletModel.PMODE_CREATE_FROMTEMPLATE;
      }
      switch (m_nNextPMode){
      case PortletModel.PMODE_CREATE:
      return RepostControl.PAGE_STATUS_VALID;
      goto case PortletModel.PMODE_CREATE_FROMTEMPLATE;
      case PortletModel.PMODE_CREATE_FROMTEMPLATE:
      if (0 < m_nTemplateObjectID)
      {
        return RepostControl.PAGE_STATUS_VALID;
      } else
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_asOwner.GetString(561, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(561,
         "ptmsgs_portaladminmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      goto case PortletModel.PMODE_INVALID;
      case PortletModel.PMODE_INVALID:
      default:
      break;
      }
      return RepostControl.PAGE_STATUS_INVALID;
    }
  }
}