using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.portlet;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.portlet.plugins
{
  /// <author>AdolfoC</author>
  public class PSelectTemplateModel : EditorHelperModel,IPSelectTemplateModelRO,
  IPSubModel
  {
    public const String STR_MVC_CLASS_NAME = "PSelectTemplateModel";
    
    /// <summary>
    /// This member defines a static string used to identify when m_htFormData
    /// has been initialized.
    /// </summary>
    public const String DEFAULTDATA = "Default Data";
    
    /// <summary>
    /// The portlet template that is currently chosen.
    /// </summary>
    protected int m_nTemplateObjectID = 0;
    
    /// <summary>
    /// Determines if freeform templates should be shown.
    /// </summary>
    protected bool m_bShowFreeForm = false;
    
    /// <summary>
    /// Determines if header and footer templates should be shown.
    /// </summary>
    protected bool m_bShowHeaderAndFooter = false;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PSelectTemplateModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()"></seealso>
    public virtual void DoTaskBeforePStore()
    {
    }
    // AGC- Thankfully, this model/view has nothing to do before store. It's job is over shortly
    // after the object is created.
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnPModeUpdate(int nNewWSMode)
    {
    }
    // AGC- This model/view initiates PMode changes - it generally does not consume them.
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String,String)"></seealso>
    public virtual void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
    {
    }
    // AGC- This model/view doesn't care - in fact it is unlikely that this view will ever
    // experience this method being called.
    
    /// <summary>
    /// This function actually commits the changes that forces our editor into
    /// the normal create or create from template modes. It is called by the
    /// Portlet Repost Control if "Done" is clicked during PRECREATE mode.
    /// </summary>
    public virtual void FinalizeCreation()
    {
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      // Replace the PTObject the we all use with a new one generated from the template. This 
      // will force the reinitialization of all of our views.
      mParentModel.SetEditedObject(mParentModel.CreateObjectFromTemplate(m_nTemplateObjectID));
      mParentModel.SetPMode(PortletModel.PMODE_CREATE_FROMTEMPLATE);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ITemplateChooserModelRO#GetObjectIDOfTemplate()"></seealso>
    public virtual int GetObjectIDOfTemplate()
    {
      return this.m_nTemplateObjectID;
    }
    // BEGIN ***************** save DP methods ***************** 
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)"></seealso>
    public virtual void InitPModel(IPTGadget ptPortlet)
    {
    }
    // AGC- There is nothing to initialize - this view is only used to create objects.
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // Make sure we're in the correct PMODE - the user might have hit the back button
      // or something odd like that. We should never be saved outside of PRECREATE mode.
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (PortletModel.PMODE_PRECREATE != mParentModel.GetPMode())
      {
        return RepostControl.PAGE_STATUS_VALID;
      }
      int nValid = RepostControl.PAGE_STATUS_VALID;
      m_nTemplateObjectID = PortletModelHelper.GetFormElementInt(_htFormData,
       PSelectTemplateView.HTMLRADIO_PORTLET_CREATEFROM, 0);
      nValid = PortletModelHelper.ValidateIntegerRange(m_nTemplateObjectID,
       m_asOwner, m_asOwner.GetString(561, "ptmsgs_portaladminmsgs"), nValid,
       1, -1);
      // We shouldn't go about trying to finalize unless we've got a valid template object id.
      // Bad things will happen otherwise.
      if (RepostControl.PAGE_STATUS_VALID == nValid)
      {
        // AGC- Now, we're in the right mode, and we're ready for action. - let's boogie.
        FinalizeCreation();
      }
      return nValid;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.plugins.IPSelectTemplateModelRO#GetAvailableTemplates()"></seealso>
    public virtual PTObjectManagerQueryWrapper GetAvailableTemplates()
    {
      PortletModel mParent = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      IPTSession ptSession = mParent.GetPTSession();
      IPTObjectManager ptObjectManagers = (IPTObjectManager) ptSession.GetObjectManagers(PT_CLASSIDS.PT_GADGETTEMPLATE_ID);
      PTObjectManagerQueryWrapper omqr = new PTObjectManagerQueryWrapper(ptObjectManagers);
      Object[][] arptqf = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_ACCESSLEVEL,
       PT_FILTEROPS.PT_FILTEROP_GTE, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
      //omqr.SimpleQuery(-1, PT_PROPIDS.PT_PROPID_NAME);
      omqr.Query(-1, -1, null, arptqf);
      return omqr;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.plugins.IPSelectTemplateModelRO#GetPortletTemplateID()"></seealso>
    public virtual int GetPortletTemplateID()
    {
      return m_nTemplateObjectID;
    }
    public virtual bool GetShowFreeForm()
    {
      return m_bShowFreeForm;
    }
    public virtual void SetShowFreeForm(bool bShowFreeForm)
    {
      m_bShowFreeForm = bShowFreeForm;
    }
    public virtual bool GetShowHeaderAndFooter()
    {
      return m_bShowHeaderAndFooter;
    }
    public virtual void SetShowHeaderAndFooter(bool bShowHeaderAndFooter)
    {
      m_bShowHeaderAndFooter = bShowHeaderAndFooter;
    }
  }
}