using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.portlet;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.portlet.plugins
{
  /// <author>adolfoc</author>
  public class PSelectTemplateView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portlet.plugins.PSelectTemplateView");
    public const String STR_MVC_CLASS_NAME = "PSelectTemplateView";
    
    /// <summary>
    /// The HTMLID for each template to be selected from 
    /// </summary>
    public const String HTMLRADIO_PORTLET_CREATEFROM = "in_ra_PTCreateFrom";
    
    /// <summary>
    /// A simple boolean for doing row coloring. 
    /// </summary>
    protected bool m_bRowColor = true;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PSelectTemplateView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        result.AddInnerHTMLElement(GetHeaderView(m_asOwner.GetString(1848,
         "ptmsgs_portaladminmsgs")));
        // Containing Table
        myTable = PortletViewHelper.AddListTable(result);
        int nResultCount = DisplayObjectList(myTable, ((IPSelectTemplateModelRO) m_model).GetAvailableTemplates());
        if (nResultCount <= 0)
        {
          PortletViewHelper.AddSimpleLabel(myTable, 5, m_asOwner.GetString(1849,
           "ptmsgs_portaladminmsgs"));
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PChooseSelectionView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(563, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns a collection of rows and what not that can be added to a table. 
    /// </summary>
    public virtual int DisplayObjectList(HTMLTable parentTable, IASQueryResult ptQRtoDisplay)
    {
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      int nMaxCount = ptQRtoDisplay.GetCount();
      int nNotShown = 0;
      for (int nRowIndex = 0;nRowIndex < nMaxCount;nRowIndex++)
      {
        int nAlignment = PortletViewHelper.GetQRValueAsInt(ptQRtoDisplay,
         nRowIndex, PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
        if (((nAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER || nAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER) && !((IPSelectTemplateModelRO) m_model).GetShowHeaderAndFooter()) || (nAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM && !((IPSelectTemplateModelRO) m_model).GetShowFreeForm()))
        {
          nNotShown++;
        } else
        {
          myRow = PortletViewHelper.AddRow(parentTable);
          // Add Radio Button
          int nObjectID = PortletViewHelper.GetQRValueAsInt(ptQRtoDisplay,
           nRowIndex, PT_PROPIDS.PT_PROPID_OBJECTID);
          bool bSelected = (nObjectID == ((IPSelectTemplateModelRO) m_model).GetPortletTemplateID());
          myCell = PortletViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
          myCell.AddInnerHTMLElement(PortletViewHelper.MakeSimpleRadio("",
           HTMLRADIO_PORTLET_CREATEFROM, XPConvert.ToString(nObjectID), bSelected,
           ""));
          myCell.SetWidth("20");
          PortletViewHelper.SetRowColor(myCell, m_bRowColor);
          // Icon
          String strProvCLSID = PortletViewHelper.GetQRValueAsString(ptQRtoDisplay,
           nRowIndex, PT_PROPIDS.PT_PROPID_GADGET_PROVIDERCLSID);
          myCell = PortletViewHelper.AddIconCell(myRow, CommonHTMLStrings.ONE,
           PT_CLASSIDS.PT_GADGETTEMPLATE_ID, strProvCLSID, strLangID);
          // Do the alternate color line thingy.
          PortletViewHelper.SetRowColor(myCell, m_bRowColor);
          // Name
          String strName = PortletViewHelper.GetQRValueAsString(ptQRtoDisplay,
           nRowIndex, PT_PROPIDS.PT_PROPID_NAME);
          String strDesc = PortletViewHelper.GetQRValueAsString(ptQRtoDisplay,
           nRowIndex, PT_PROPIDS.PT_PROPID_DESCRIPTION);
          myCell = PortletViewHelper.AddLabelCell(myRow, CommonHTMLStrings.THREE,
           strName);
          HTMLSpan mySpan = PortletViewHelper.AddSpanToCell(myCell);
          mySpan.AddInnerHTMLElement(new HTMLBr());
          mySpan.AddInnerHTMLEncodedString(strDesc);
          // Do the alternate color line thingy.
          PortletViewHelper.SetRowColor(myCell, m_bRowColor);
          m_bRowColor = !m_bRowColor;
        }
      }
      return nMaxCount - nNotShown;
    }
  }
}