using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.portlet;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.portlet.plugins
{
  /// <author>adolfoc</author>
  public class PortletSettingsModel : EditorHelperModel,IPortletSettingsModelRO,
  IPSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portlet.plugins.PortletSettingsModel");
    public const String STR_MVC_CLASS_NAME = "PortletSettingsModel";
    
    /// <summary>
    /// Our portlet, passed to us in InitPModel
    /// </summary>
    protected IPTGadget m_ptPortlet = null;
    
    /// <summary>
    /// Determines whether the gadget is a personal, community or template type
    /// gadget. Can be one of the enums from PT_GADGET_TYPES. (SettingsView)
    /// </summary>
    private int m_intPortletType;
    
    /// <summary>
    /// The size "Narrow" or "Wide" for this
    /// Portlet (SettingsView)
    /// </summary>
    private int m_intPortletSize;
    
    /// <summary>
    /// true or false whether or not this portlet should suppress the title bar.
    /// (SettingsView)
    /// </summary>
    private bool m_bSuppressTitleBar = false;
    public PortletSettingsModel() : base()
    {
      m_intPortletType = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;
      m_intPortletSize = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW;
    }
    // Helper funcs
    public virtual void ChangePortletAlignment(XPHashtable form)
    {
      String[] data = (String[]) form.GetElement(PortletSettingsView.HTMLRADIO_GADGET_ALIGNMENT);
      if ((null != data) && !(0 == data.Length))
      {
        m_intPortletSize = XPConvert.ToInteger(data[0]);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletSettingsModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()"></seealso>
    public virtual void DoTaskBeforePStore()
    {
      m_ptPortlet.SetSuppressTitleBar(m_bSuppressTitleBar);
      // Settings Section
      switch (m_intPortletSize){
      case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NONE):
      case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW):
      case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE):
      case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER):
      case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER):
      case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM):
      m_ptPortlet.SetAlignment(m_intPortletSize);
      break;
      default:
      m_ptPortlet.SetAlignment(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NONE);
      log.Warn("PortletSettingsModel::DoTaskBeforePStore - Received an invalid Portlet Size. Using PT_GADGETALIGN_NONE instead");
      break;
      }
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (!mParentModel.IsTemplate())
      {
        switch (m_intPortletType){
        case (PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL):
        case (PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY):
        m_ptPortlet.SetGadgetType(m_intPortletType);
        break;
        default:
        m_ptPortlet.SetGadgetType(PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL);
        m_intPortletType = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;
        log.Warn("PortletSettingsModel::DoTaskBeforePStore - Received an invalid PortletType. Using PT_GADGETTYPE_PERSONAL instead");
        break;
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnPModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String,String)"></seealso>
    public virtual void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
    {
    }
    
    /// <summary>
    /// Returns the m_intTemplate.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetPortletType()
    {
      return m_intPortletType;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // Getters and Setters
    
    /// <summary>
    /// Returns the m_intPortletSize.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetPortletSize()
    {
      return m_intPortletSize;
    }
    
    /// <summary>
    /// Returns the m_intSuppressTitleBar.
    /// </summary>
    /// <returns>int</returns>
    public virtual bool GetSuppressTitleBar()
    {
      return m_bSuppressTitleBar;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)"></seealso>
    public virtual void InitPModel(IPTGadget ptPortlet)
    {
      m_ptPortlet = ptPortlet;
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      switch (mParentModel.GetPMode()){
      case PortletModel.PMODE_CREATE:
      break;
      case PortletModel.PMODE_CREATE_FROMTEMPLATE:
      default:
      m_intPortletSize = ptPortlet.GetAlignment();
      m_bSuppressTitleBar = ptPortlet.GetSuppressTitleBar();
      break;
      }
      // AGC- this must be called, even during CREATE in order to determine whether
      // or not we are a template.
      m_intPortletType = ptPortlet.GetGadgetType();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(PortletSettingsView.HTMLCHECKBOX_SUPPRESS_TITLE_BAR);
      if ((null != data) && !(0 == data.Length))
      {
        try
        {
          SetSuppressTitleBar(XPConvert.ToBoolean(data[0]));
        }
        catch (Exception e)
        {
          log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Suppress Title Bar checkbox. Using 0 instead.");
          SetSuppressTitleBar(false);
        }
      } else
      {
        SetSuppressTitleBar(false);
      }
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (!mParentModel.IsTemplate())
      {
        data = (String[]) _htFormData.GetElement(PortletSettingsView.HTMLRADIO_GADGET_TYPE);
        if ((null != data) && !(0 == data.Length))
        {
          try
          {
            SetTemplate(XPConvert.ToInteger(data[0]));
          }
          catch (Exception e)
          {
            log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Template checkbox. Using 0 instead.");
            SetTemplate(0);
          }
        }
      }
      data = (String[]) _htFormData.GetElement(PortletSettingsView.HTMLRADIO_GADGET_ALIGNMENT);
      if ((null != data) && !(0 == data.Length))
      {
        try
        {
          SetPortletSize(XPConvert.ToInteger(data[0]));
        }
        catch (Exception e)
        {
          log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Portlet Size select. Using 0 instead.");
          SetPortletSize(0);
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Sets the m_intPortletSize.
    /// </summary>
    /// <param name="m_intPortletSize">The m_intPortletSize to set</param>
    public virtual void SetPortletSize(int intPortletSize)
    {
      this.m_intPortletSize = intPortletSize;
    }
    
    /// <summary>
    /// Sets the m_intSuppressTitleBar.
    /// </summary>
    /// <param name="m_intSuppressTitleBar">The m_intSuppressTitleBar to set</param>
    public virtual void SetSuppressTitleBar(bool bSuppressTitleBar)
    {
      this.m_bSuppressTitleBar = bSuppressTitleBar;
    }
    
    /// <summary>
    /// Sets the m_intTemplate.
    /// </summary>
    /// <param name="m_intTemplate">The m_intTemplate to set</param>
    public virtual void SetTemplate(int intPortletType)
    {
      this.m_intPortletType = intPortletType;
    }
  }
}