using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.portlet;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.portlet.plugins
{
  /// <author>adolfoc</author>
  public class PortletSettingsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portlet.plugins.PortletSettingsView");
    public const String STR_MVC_CLASS_NAME = "PortletSettingsView";
    // HTML Object names.
    public const String HTMLSCRIPT_RADIO_ONCHANGE_FUNCTION = "OnRadioButtonChange";
    public const String HTMLRADIO_GADGET_TYPE = "in_ra_GadgetType";
    public const String HTMLRADIO_GADGET_ALIGNMENT = "in_ra_GadgetAlignment";
    public const String HTMLCHECKBOX_SUPPRESS_TITLE_BAR = "in_cb_SuppressTitleBar";
    public const String HTMLSELECT_PORTLET_SIZE = "in_se_PortletSize";
    public const String HTMLHIDDEN_TABMODE = "in_hi_TabMode";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletSettingsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      IPortletSettingsModelRO mModel = (IPortletSettingsModelRO) base.m_model;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(570,
         "ptmsgs_portaladminmsgs")));
      }
      catch (Exception e)
      {
        log.Warn("PortletSettingsView.java: Unable to get the header view.");
        }
      IPortletModelRO mParentModel = (IPortletModelRO) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      int nPortletSize = mModel.GetPortletSize();
      // if we're in edit mode, and this is a header, footer, or free-form, then don't
      // let the user change the portlet size.
      // AGC- This is also true in create from template mode. Made a minor change.
      // AGC - Also, if we're editing a template, we never allow the user to change
      // The portlet size.
      if (((PortletModel.PMODE_EDIT == mParentModel.GetPMode()) || (PortletModel.PMODE_CREATE_FROMTEMPLATE == mParentModel.GetPMode())) && ((nPortletSize == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER) || (nPortletSize == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER) || (nPortletSize == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM) || (mParentModel.IsTemplate())))
      {
        DrawReadOnly(result);
      } else
      {
        DrawChangeable(result);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      try
      {
        script.AddInnerHTMLString("function " + HTMLSCRIPT_RADIO_ONCHANGE_FUNCTION + "(strID)  \n" + "{\n" + "document." + "mainform." + HTMLHIDDEN_TABMODE + ".value = strID;" + "\n" + "postToSelf(" + PortletRepostControl.POSTTOSELF_ACTION_CHANGE_TAB + ")" + "\n" + "}\n");
        }
      catch (Exception e)
      {
        log.Error("Error writing javascript.");
      }
      return script;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
    
    /// <param name="myTable"></param>
    /// <param name="label"></param>
    /// <param name="radioID"></param>
    /// <param name="radioValue"></param>
    /// <throws>HTMLException</throws>
    protected virtual void AddRadioButtonRow(HTMLTable myTable, String strSelectedVal,
     String label, String radioID, String radioValue, bool bTabChange)
    {
      bool bChecked = (strSelectedVal.Equals(radioValue));
      String strOnChange = "";
      if (bTabChange)
      {
        //AGC- Build a simple Radio, but give it the change-tab function and a dark BG if selected.
        strOnChange = HTMLSCRIPT_RADIO_ONCHANGE_FUNCTION + "(\'" + radioID + "\'); return false;";
        HTMLTableRow myRow = PortletViewHelper.AddSimpleRadio(myTable, 4,
         label, radioID, radioValue, bChecked, strOnChange);
        if (bChecked)
        {
          myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);
        } else
        {
          myRow.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        }
      } else
      {
        //AGC- Build a simple Radio without functions or anything, but make the text wrappable.
        HTMLTableRow myRow = PortletViewHelper.AddRow(myTable);
        PortletViewHelper.AddLeftMargin(myRow, 4);
        HTMLTableCell myCell = PortletViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        myCell.AddInnerHTMLElement(PortletViewHelper.MakeSimpleRadio("", radioID,
         radioValue, bChecked, ""));
        myCell = PortletViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE,
         label);
        myCell.SetNoWrap(false);
        PortletViewHelper.AddRightMargin(myRow, 4);
      }
    }
    protected virtual HTMLTable CreateDescriptionTable(String strLabel, String strDesc,
     PTImageType image, bool bMargins)
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      int nColumnCount = 1;
      if (bMargins)
      {
        nColumnCount = 3;
      }
      myTable = PortletViewHelper.MakeTable();
      if (bMargins)
      {
        PortletViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.THREE);
      }
      myRow = PortletViewHelper.AddRow(myTable);
      PortletViewHelper.AddLeftMargin(myRow, nColumnCount);
      myCell = PortletViewHelper.AddImageCell(myRow, CommonHTMLStrings.ONE,
       m_asOwner, image);
      PortletViewHelper.AddRightMargin(myRow, nColumnCount);
      // Spacer Row
      PortletViewHelper.AddEmptyRow(myTable, XPConvert.ToString(nColumnCount));
      // Description
      myRow = PortletViewHelper.AddRow(myTable);
      PortletViewHelper.AddLeftMargin(myRow, nColumnCount);
      myCell = PortletViewHelper.AddLabelAndTextCell(myRow, CommonHTMLStrings.ONE,
       strLabel, strDesc);
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      PortletViewHelper.AddRightMargin(myRow, nColumnCount);
      if (bMargins)
      {
        PortletViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.THREE);
      }
      return myTable;
    }
    
    /// <returns>HTMLTable</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTable CreateRegularPortletSection()
    {
      IPortletSettingsModelRO mModel = (IPortletSettingsModelRO) base.m_model;
      HTMLTable myTable;
      HTMLTableRow myRow;
      myTable = PortletViewHelper.MakeTable();
      myTable.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
      String strType = XPConvert.ToString(mModel.GetPortletType());
      PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (!mParentModel.IsTemplate())
      {
        if (mParentModel.GetCreatorID() != PortletModel.WSID_COMMUNITYLINKS)
        {
          AddRadioButtonRow(myTable, strType, m_asOwner.GetString(575, "ptmsgs_portaladminmsgs"),
           HTMLRADIO_GADGET_TYPE, XPConvert.ToString(PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL),
           false);
        } else
        {
          strType = XPConvert.ToString(PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY);
          }
        AddRadioButtonRow(myTable, strType, m_asOwner.GetString(576, "ptmsgs_portaladminmsgs"),
         HTMLRADIO_GADGET_TYPE, XPConvert.ToString(PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY),
         false);
        // AGC- Spacer Row
        PortletViewHelper.AddEmptyRow(myTable, "4");
      }
      myRow = PortletViewHelper.AddRow(myTable);
      //// Left Margin
      PortletViewHelper.AddEmptyCell(myRow, "1");
      //// Template Checkbox
      PortletViewHelper.AddSimpleCheckbox(myTable, 4, m_asOwner.GetString(577,
       "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_SUPPRESS_TITLE_BAR, "1", ((IPortletSettingsModelRO) base.m_model).GetSuppressTitleBar(),
       "");
      // 4th row ends
      // AGC- Bottom Margin
      PortletViewHelper.AddEmptyRow(myTable, "4");
      return myTable;
    }
    
    /// <returns>HTMLTable</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTable CreateSetPortletModeSection()
    {
      IPortletSettingsModelRO mModel = (IPortletSettingsModelRO) base.m_model;
      IPortletModelRO mParentModel = (IPortletModelRO) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      HTMLTable myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder("0");
      myTable.SetCellPadding("10");
      myTable.SetCellSpacing("0");
      myTable.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
      String strAlignment = XPConvert.ToString(mModel.GetPortletSize());
      AddRadioButtonRow(myTable, strAlignment, m_asOwner.GetString(581, "ptmsgs_portaladminmsgs"),
       HTMLRADIO_GADGET_ALIGNMENT, XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW),
       true);
      AddRadioButtonRow(myTable, strAlignment, m_asOwner.GetString(580, "ptmsgs_portaladminmsgs"),
       HTMLRADIO_GADGET_ALIGNMENT, XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE),
       true);
      // if we're in create mode, then let then header, footer, and freeform
      // if we're in edit mode, then we won't get this far, because in edit mode, if it's
      // a header, footer, or free-form, then we return at the top of this view.
      if (PortletModel.PMODE_CREATE == mParentModel.GetPMode() && !IsCommunityPortlet())
      {
        AddRadioButtonRow(myTable, strAlignment, m_asOwner.GetString(578,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_GADGET_ALIGNMENT, XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER),
         true);
        AddRadioButtonRow(myTable, strAlignment, m_asOwner.GetString(579,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_GADGET_ALIGNMENT, XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER),
         true);
        AddRadioButtonRow(myTable, strAlignment, m_asOwner.GetString(583,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_GADGET_ALIGNMENT, XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM),
         true);
      }
      return myTable;
    }
    
    /// <summary>
    /// Returns whether we are editing a portlet for a community, or for the full
    /// admin folders. This changes whether or not the user is allowed to select
    /// Freeform, Header and footer modes.
    /// </summary>
    /// <returns>boolean</returns>
    protected virtual bool IsCommunityPortlet()
    {
      IPortletModelRO mParentModel = (IPortletModelRO) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
      if (mParentModel.IsForCommunity())
      {
        return true;
      }
      return false;
    }
    protected virtual void DrawChangeable(HTMLElementCollection result)
    {
      HTMLInput myInput;
      String TABLE_WIDTH = "150";
      try
      {
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_TABMODE,
         "");
        result.AddInnerHTMLElement(myInput);
        HTMLTable outer = WSViewHelper.AddListTable(result);
        outer.SetCellPadding("0");
        outer.SetCellSpacing("0");
        outer.SetBorder("0");
        HTMLTableRow outerRow = new HTMLTableRow();
        HTMLTableCell leftCell = new HTMLTableCell();
        HTMLTableCell rightCell = new HTMLTableCell();
        HTMLBr br = new HTMLBr();
        outer.AddInnerHTMLElement(outerRow);
        outerRow.AddInnerHTMLElement(leftCell);
        outerRow.AddInnerHTMLElement(rightCell);
        outer.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        leftCell.SetWidth(TABLE_WIDTH);
        leftCell.AddInnerHTMLElement(CreateSetPortletModeSection());
        leftCell.SetVAlign(CommonHTMLStrings.TOP);
        leftCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        //HTMLElement table = null;
        int nAlignment = ((IPortletSettingsModelRO) m_model).GetPortletSize();
        HTMLTable descTable = null;
        HTMLTable selTable = null;
        switch (nAlignment){
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW:
        descTable = CreateDescriptionTable("", m_asOwner.GetString(585, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_NARROW, false);
        selTable = CreateRegularPortletSection();
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE:
        descTable = CreateDescriptionTable("", m_asOwner.GetString(587, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_WIDE, false);
        selTable = CreateRegularPortletSection();
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER:
        descTable = CreateDescriptionTable("", m_asOwner.GetString(589, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_BAN, false);
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER:
        descTable = CreateDescriptionTable("", m_asOwner.GetString(591, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_FOOTER, false);
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM:
        descTable = CreateDescriptionTable("", m_asOwner.GetString(593, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_FREEFORM, false);
        break;
        }
        rightCell.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);
        rightCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        rightCell.AddInnerHTMLElement(descTable);
        if (null != selTable)
        {
          rightCell.AddInnerHTMLElement(br);
          rightCell.AddInnerHTMLElement(br);
          rightCell.AddInnerHTMLElement(br);
          rightCell.AddInnerHTMLElement(selTable);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PortletSettingsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(571, "ptmsgs_portaladminmsgs"),
         e);
      }
    }
    protected virtual void DrawReadOnly(HTMLElementCollection result)
    {
      try
      {
        IPortletSettingsModelRO mModel = (IPortletSettingsModelRO) base.m_model;
        int nPortletSize = mModel.GetPortletSize();
        switch (nPortletSize){
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW:
        result.AddInnerHTMLElement(CreateDescriptionTable(m_asOwner.GetString(584,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(585, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_NARROW, true));
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE:
        result.AddInnerHTMLElement(CreateDescriptionTable(m_asOwner.GetString(586,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(587, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_WIDE, true));
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER:
        result.AddInnerHTMLElement(CreateDescriptionTable(m_asOwner.GetString(588,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(589, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_BAN, true));
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER:
        result.AddInnerHTMLElement(CreateDescriptionTable(m_asOwner.GetString(590,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(591, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_FOOTER, true));
        break;
        case PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM:
        result.AddInnerHTMLElement(CreateDescriptionTable(m_asOwner.GetString(592,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(593, "ptmsgs_portaladminmsgs"),
         PTImageType.TEMPLATE_PORTLET_FREEFORM, true));
        break;
        }
      }
      catch (Exception e)
      {
        log.Warn("PortletSettingsView.java: Unable to create the table that states the portlet size.");
        }
    }
  }
}