using System;
// Plumtree Server Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.portletbundle
{
  /// <author>michaeld</author>
  public class PortletBundleEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.portletbundle.PortletBundleEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GadgetBundleEditor";
    
    /// <summary>
    /// SelectPTObject Model 
    /// </summary>
    public const String strStorageSelectPTObject = "SelectPTObject";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.portletbundle.PortletBundleEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletBundleEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (PortletBundleDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns>String strEditorTitle</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(380, "ptmsgs_portaladminmsgs");
      }
      return (XPResourceManager.FormatMessage(GetString(2612, "ptmsgs_portaladminmsgs"),
       GetObjectName()));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (PortletBundleRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PortletBundleModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      RegisterPage(new PortletBundleMainDP());
      log.Info("PortletBundleEditorAS::Constructor: Register display pages succesful");
      RegisterView(PortletBundleDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(PortletBundleRepostControl.STR_MVC_CLASS_NAME, myModel);
      log.Info("PortletBundleEditorAS::Constructor: Register controls succesful");
      // Register the select PTObject list as a plug-in section
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageSelectPTObject);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel mySelectPTObjectModel = GetModel(strStorageSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageSelectPTObject,
       mySelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectPTObject,
       mySelectPTObjectModel);
      // Set default page
      SetCurrentPage(PortletBundleMainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(383, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PortletBundleMainDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1858, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 51;
          int iTipId = 52;
          int iSecondaryTipId = 53;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
     */
     
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (PortletBundleMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_PortletBundle_MainSettings");
      }
    }
  }
}