using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.portletbundle
{
  /// <author>michaeld</author>
  public class PortletBundleModel : ObjEditorModel,IEditorModelRO
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GadgetBundle";
    
    /// <summary>
    /// Repost Action: From Tree 
    /// </summary>
    public const int POSTTOSELF_ACTION_RETURN_FROM_TREE = 32;
    
    /// <summary>
    /// Old Selected Objects 
    /// </summary>
    private XPSortedDictionary m_xpsdOldSelectedObjects;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletBundleModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored. Add and remove portlets from
    /// the portlet bundle.
    /// </summary>
    public override void DoTaskAfterStore()
    {
      PTGrowableSortedArrayWrapper aSelectedObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(PortletBundleEditorAS.strStorageSelectPTObject)).GetItems();
      Object oObjectID;
      for (int i = 0;i < aSelectedObjectValues.GetCount();i++)
      {
        oObjectID = aSelectedObjectValues.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
        if (m_xpsdOldSelectedObjects.ContainsKey(oObjectID))
        {
          m_xpsdOldSelectedObjects.RemoveElement(oObjectID);
        } else
        {
          ((IPTGadgetBundle) m_ptObject).AddGadgetEx(XPConvert.ToInteger(oObjectID));
          }
      }
      IXPEnumerator xpeKeys = m_xpsdOldSelectedObjects.GetKeys();
      while (xpeKeys.MoveNext())
      {
        ((IPTGadgetBundle) m_ptObject).RemoveGadget(XPConvert.ToInteger(xpeKeys.GetCurrent()));
        }
    }
    
    /// <summary>
    /// Initializes IPTProperty with the property type member  variable just
    /// before we store the object in the DB. Also sets 2 other values to
    /// default.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
    }
    
    /// <summary>
    /// Initializes the property type member variable with  the one from
    /// IPTProperty in Edit mode and the default  value in create mode.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      StartSelectPTObject();
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        } else
      {
        // ***CHANGE_HERE SECURITY PAGE*** Hide the security page in edit mode
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // BEGIN ***************** helper methods *****************
    // END ***************** helper methods *****************
    // BEGIN ***************** save DP methods *****************
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(PortletBundleMainDP.STR_MVC_CLASS_NAME))
      {
        // if this is the display page where you have your select ptobject you need to
        // call the associated saveSection method.
        ((SelectPTObjectModel) m_asOwner.GetModel(PortletBundleEditorAS.strStorageSelectPTObject)).SaveSection(_htFormData);
        }
      return nPageStatus;
    }
    
    /// <summary>
    /// Takes a query result of portlets and sets up the member variables from
    /// it.
    /// </summary>
    /// <param name="IASQueryResult">asqrPortlets</param>
    /// <returns>Object[][]</returns>
    private Object[][] SetupPortlets(IASQueryResult asqrPortlets)
    {
      int nPortletCount;
      if (null == asqrPortlets)
      {
        nPortletCount = 0;
      } else
      {
        nPortletCount = asqrPortlets.GetCount();
      }
      Object[][] arrReturn = new Object[nPortletCount][];
      m_xpsdOldSelectedObjects = new XPSortedDictionary();
      for (int i = 0;i < nPortletCount;i++)
      {
        arrReturn[i] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
        arrReturn[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_GADGET_ID;
        arrReturn[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = asqrPortlets.GetFields(i,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        arrReturn[i][SelectPTObjectModel.EXPLIST_COL_STRING] = (String) asqrPortlets.GetFields(i,
         PT_PROPIDS.PT_PROPID_NAME);
        // Setup Old Selected Gadgets
        m_xpsdOldSelectedObjects.PutElement(arrReturn[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID],
         "");
      }
      return arrReturn;
    }
    // END ***************** save DP methods *****************
    //***** Private methods
    
    /// <summary>
    /// Helper method to start the Selected Object List.
    /// </summary>
    private void StartSelectPTObject()
    {
      SelectPTObjectModel selectPTmodel = ((SelectPTObjectModel) m_asOwner.GetModel(PortletBundleEditorAS.strStorageSelectPTObject));
      /* Initialize the Select PTObject list.
       _sSectionTitle: Main title.
       _sSectionSubTitle: Sub title.
       _imgAddIcon: Icon for the add action.
       _sAddLabel: Text to display next to the add icon.
       _arrObjectClassIDs Class ID of the Objects displayed on the list.
       _nListKey: In case you have multiple Expandable Lists on
       the same DP, they should have a different key
       (otherwise, just set it to 1).
       */
       
      selectPTmodel.InitializeSelectPTObject(m_asOwner.GetString(390, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(391, "ptmsgs_portaladminmsgs"), PTImageType.ICON_PORTLET,
       m_asOwner.GetString(392, "ptmsgs_portaladminmsgs"), new int[]{PT_CLASSIDS.PT_GADGET_ID},
       1);
      //     Use the method bellow to set the icon to display on each row.
      //     (By default there will be no icon.)
      selectPTmodel.SetDefaultRowIcon(PTImageType.ICON_PORTLET);
      selectPTmodel.SetTreeTitle(m_asOwner.GetString(392, "ptmsgs_portaladminmsgs"));
      selectPTmodel.SetTreeSubTitle(m_asOwner.GetString(1859, "ptmsgs_portaladminmsgs"));
      selectPTmodel.SetEmptyListMessages(m_asOwner.GetString(393, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(394, "ptmsgs_portaladminmsgs"));
      selectPTmodel.SetTreeQueryFilter(PT_CLASSIDS.PT_GADGET_ID, PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT,
       new int[]{PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW, PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE});
      // Setup initial portlets
      IASQueryResult asqrPortlets = null;
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        asqrPortlets = new ASQueryResultWrapper(((IPTGadgetBundle) m_ptObject).QueryGadgets(null));
        }
      Object[][] arrDefaultPortlets = SetupPortlets(asqrPortlets);
      // Add default rows.
      selectPTmodel.SetDefaultObjects(arrDefaultPortlets);
    }
  }
}