using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.profilesource
{
  /// <summary>
  /// The main display page for the profile source editor
  /// </summary>
  /// <author>Mike Jahr</author>
  public class MainDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "ProfileSourceMain";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(622, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1683, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      IProfileSourceModelRO model = (IProfileSourceModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName);
      if (model.IsPartnerSupported())
      {
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(AuthPartnerView.STR_MVC_CLASS_NAME)).Display());
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      }
      // mj: display the clear history view
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ProfileSourceEditorAS.strMainView)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // aj: display the unique key chooser
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(UniqueKeyChooserView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // mj: display the membership list
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ProfileSourceEditorAS.strStorageSelectPTObject)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // ***CHANGE_HERE SELECTPTOBJECT*** Display JavaScripts for the Select PTObject list.
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(ProfileSourceEditorAS.strStorageSelectPTObject).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(UniqueKeyChooserView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
  }
}