using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.common.setjob;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.profilesource
{
  public abstract class ProfileSourceEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.profilesource.ProfileSourceEditorAS");
    
    /// <summary>
    /// Unique Key Chooser Tree 
    /// </summary>
    public const String strUniqueKeyTree_SUBSPACE = "PSUniqueKeyTreeSubSpace";
    
    /// <summary>
    /// SelectPTObject storage 
    /// </summary>
    public const String strStorageSelectPTObject = "SelectPTObjectGroups";
    public const String strMainView = "MainView";
    public const String strPTMultiColumnList = "PTProfSrcMultiColList";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.profilesource.ProfileSourceEditorAS";
    
    /// <summary>
    /// Gets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(623, "ptmsgs_portaladminmsgs");
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2614, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (ProfileSourceRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // aj: bug 24020 - add dependencies view
      RegisterView(ProfileSourceDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register the select PTObject list as a plug-in section
      RegisterModel(ProfileSourceSelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageSelectPTObject);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel mySelectPTObjectModel = GetModel(strStorageSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageSelectPTObject,
       mySelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectPTObject,
       mySelectPTObjectModel);
      //Register the PTMulticolumnlist for the property map
      //Register the model, view and control for the property map list
      RegisterModel(PTMultiColumnListModel.STR_MVC_CLASS_NAME, strPTMultiColumnList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myMultiColumnListModel = GetModel(strPTMultiColumnList);
      RegisterView(PTMultiColumnListView.STR_MVC_CLASS_NAME, strPTMultiColumnList,
       myMultiColumnListModel);
      RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, strPTMultiColumnList,
       myMultiColumnListModel);
      // Register Views
      RegisterView(AuthPartnerView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ClearHistoryView.STR_MVC_CLASS_NAME, strMainView, myModel);
      RegisterView(UniqueKeyChooserView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(ProfileSourceRepostControl.STR_MVC_CLASS_NAME, myModel);
      // mj: register set job stuff
      // Register classes for the set job and for the object owner
      RegisterModel(SetJobModel.STR_MVC_CLASS_NAME);
      RegisterControl(SetJobRepostControl.STR_MVC_CLASS_NAME, GetModel(SetJobModel.STR_MVC_CLASS_NAME));
      RegisterView(ObjectOwnerView.STR_MVC_CLASS_NAME, GetModel(SetJobModel.STR_MVC_CLASS_NAME));
      // Register classes for Job selector
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
       GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
       GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 54;
          int iTipId = 55;
          int iSecondaryTipId = 56;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <summary>
    /// Registers DisplayPages for the editor, including the custom
    /// display pages in the given array. Inits the left nav menu.
    /// </summary>
    protected virtual void RegisterPages(IDisplayPage[] arrDPs)
    {
      // mj: register dps
      RegisterPage(new MainDP());
      RegisterPage(new PropertyMapDP());
      RegisterPage(new SetJobDP());
      // mj: set default page
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      // mj: set left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(625, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      for (int i = 0;(arrDPs != null) && (i < arrDPs.Length);i++)
      {
        RegisterPage(arrDPs[i]);
        m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, arrDPs[i].GetName());
      }
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PropertyMapDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SetJobDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1863, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      }
    // END Sub menu "Standard Settings"
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (PropertyMapDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_ProfileSource_PropertyMap");
      } else
      if (SetJobDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_SetJob");
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (ProfileSourceDependenciesView.STR_MVC_CLASS_NAME);
    }
  }
}