using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.admin.editors.profilesource
{
  /// <summary>
  /// Model for the Profile Source Membership expandable list.
  /// This overrides SelectPTObjectModel because we want to first
  /// sort by Groups then by Users, rather than to have them all
  /// mixed together.  Much of this code is taken from ObjectSecurityModel.
  /// </summary>
  /// <author>JenniferSu</author>
  public class ProfileSourceSelectPTObjectModel : SelectPTObjectModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.profilesource.ProfileSourceSelectPTObjectModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ProfileSourceMembership";
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ProfileSourceSelectPTObjectModel();
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING};
      // JF- Sort array
      // The group membership list is always sorted by class id descending as a primary sort (we always want to see all the groups 
      // together and then all the users).
      int[][] arrSort = new int[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_CLASSID;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
      // JF- Then by default the user will first see the list sorted by object name.
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_STRING;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null bellow)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Reverses the sort of all the sorted columns.
    /// </summary>
    public override void ReverseCurrentSort()
    {
      int[][] arrSort = m_saData.GetSort();
      // JF- Get the current sort.
      // JF- We need to reverse the 2 columns: class ID and the other one (name or privilege)
      for (int i = 0;i < arrSort.Length;i++)
      {
        int nCurrentDirection = arrSort[i][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION];
        // JF- The new direction is the oposite of the previous direction.
        if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == nCurrentDirection)
        {
          arrSort[i][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
          } else
        {
          arrSort[i][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
          }
      }
      m_saData.Sort(arrSort);
    }
    
    /// <summary>
    /// Gets the column ID back from the form data and resort
    /// the array by that column ID, ascending.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void SortByColumn(XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_COLUMNID);
      // JF- First we need to get back the column ID from the form data.
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && (0 != aDataValue.Length))
        {
          try
          {
            int nColumnID = XPConvert.ToInteger(aDataValue[0]);
            // JF- We create a new sort array
            int[][] arrSort = new int[2][];
            for (int j2c_index = 0;j2c_index < 2;j2c_index++)
            {
              arrSort[j2c_index] = new int[2];
            }
            // JF- The membership list is always sorted by class ID first (group first and then users)
            arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_CLASSID;
            arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
            // JF- Then by the other propID that we got from the form: name or privilege
            arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = nColumnID;
            arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
            // JF- Finally we resort the array
            m_saData.Sort(arrSort);
          }
          catch (Exception e)
          {
            log.Error("ProfileSourceSelectPTObjectModel::SortByColumn An exception occured" + " when trying to resort the array by column with ID: " + aDataValue[0]);
            }
        }
      }
    }
    
    /// <summary>
    /// Returns the column ID of the primary sorted column.
    /// (the array can be sorted by multiple columns)
    /// </summary>
    /// <returns>int</returns>
    public override int GetMainColumnSort()
    {
      int[][] arrSort = m_saData.GetSort();
      // JF- For the membership list, row 0 is sorted by class ID but in the UI it will 
      // look like it's sorted by name or privilege because there is no column for class ID.
      // This is why we return the value of row 1 bellow.
      return arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID];
    }
    
    /// <summary>
    /// Returns the sort direction of the primary sorted column.
    /// </summary>
    /// <returns>int</returns>
    public override int GetMainColumnSortDirection()
    {
      int[][] arrSort = m_saData.GetSort();
      // JF- For the membership list, row 0 is sorted by class ID but in the UI it will 
      // look like it's sorted by name or privilege because there is no column ofr class ID.
      // This is why we return the value of row 1 bellow.
      return arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION];
    }
  }
}