using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.server;
using WSViewHelper=com.plumtree.portalpages.admin.editors.webservice.WSViewHelper;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using StartTreeControl=com.plumtree.portaluiinfrastructure.tree.StartTreeControl;
using TreeAS=com.plumtree.portaluiinfrastructure.tree.TreeAS;
using ASConstants=com.plumtree.uiinfrastructure.activityspace.ASConstants;
using ASURL=com.plumtree.uiinfrastructure.activityspace.ASURL;
using com.plumtree.uiinfrastructure.editor;
using AFormDP=com.plumtree.uiinfrastructure.form.AFormDP;
using UIConstructFactory=com.plumtree.uiinfrastructure.htmlconstructs.UIConstructFactory;
using TreeConstants=com.plumtree.uiinfrastructure.tree.TreeConstants;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.profilesource
{
  public class UniqueKeyChooserView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.profilesource.UniqueKeyChooser");
    
    /// <summary>
    /// Class name for the view.
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UniqueKeyChooser";
    
    /// <summary>
    /// Form elements in this view.
    /// </summary>
    public const String RADIO_UNIQUEKEY = "in_ra_uniqukey";
    
    /// <summary>
    /// Values for the radio buttons.
    /// </summary>
    public const int USER_UNIQUE_NAME = 0;
    public const int USER_AUTH_NAME = 1;
    public const int USER_PROP = 2;
    
    /// <summary>
    /// Private Strings that is the function name for the repost javascript called
    /// when the tree control returns.
    /// </summary>
    private const String JSREPOST_UNIQUEKEY_FUNC = "frmRepostUniqueKeyViewChosen";
    private const String JSREPOST_UNIQUEKEY_FUNC_INPUT = "frmSetDataUniqueKeyViewChosen";
    private const String JS_SHOW_TREE_PICKER = "showPropertyTreePicker";
    
    /// <summary>
    /// Need a hidden attribute for both the tree picker space and selected prop.
    /// </summary>
    public const String HTMLHIDDEN_UNIQUEKEY_PROPERTY_SPACE = "in_hi_uniquekey_prop_space";
    public const String HTMLHIDDEN_UNIQUEKEY_PROPERTY_SELECTED = "in_hi_uniquekey_prop_selected";
    public const String HTML_TREE_PICKER_SPAN = "uniqueKeyPickerSpan";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UniqueKeyChooserView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLTable myTable;
      HTMLSpan mySpan;
      result.AddInnerHTMLString("\n");
      result.AddInnerHTMLElement(new HTMLComment("Begin: Unique Name Chooser"));
      result.AddInnerHTMLString("\n");
      result.AddInnerHTMLElement(GetHeaderView(m_asOwner.GetString(2889, ResourceConstants.PORTALADMINMSGS)));
      // aj: we want a 2-column table (one for radio, one for description)
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.FIVE);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      myCell.SetColSpan(CommonHTMLStrings.TWO);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.AddInnerHTMLString(m_asOwner.GetString(2890, ResourceConstants.PORTALADMINMSGS));
      int nCurrChoice = ((IProfileSourceModelRO) m_model).GetUniqueKey();
      int nCurrPropID = 0;
      if (nCurrChoice <= 0)
      {
        switch (nCurrChoice){
        case (PT_PROFILE_UNIQUE_KEYS.USER_UNIQUE_NAME):
        nCurrChoice = USER_UNIQUE_NAME;
        break;
        case (PT_PROFILE_UNIQUE_KEYS.USER_AUTHENTICATION_NAME):
        nCurrChoice = USER_AUTH_NAME;
        break;
        default:
        nCurrChoice = USER_UNIQUE_NAME;
        break;
        }
      } else
      {
        nCurrPropID = nCurrChoice;
        nCurrChoice = USER_PROP;
      }
      DisplayRadioForUniqueKeyChoices(myTable, USER_UNIQUE_NAME, nCurrChoice,
       m_asOwner.GetString(2891, ResourceConstants.PORTALADMINMSGS), m_asOwner.GetString(2892,
       ResourceConstants.PORTALADMINMSGS), false, false);
      DisplayRadioForUniqueKeyChoices(myTable, USER_AUTH_NAME, nCurrChoice,
       m_asOwner.GetString(2893, ResourceConstants.PORTALADMINMSGS), m_asOwner.GetString(2894,
       ResourceConstants.PORTALADMINMSGS), false, false);
      DisplayRadioForUniqueKeyChoices(myTable, USER_PROP, nCurrChoice, m_asOwner.GetString(2895,
       ResourceConstants.PORTALADMINMSGS), m_asOwner.GetString(2896, ResourceConstants.PORTALADMINMSGS),
       false, true);
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_UNIQUEKEY_PROPERTY_SELECTED,
       XPConvert.ToString(nCurrPropID), "");
      myInput.SetValue(XPConvert.ToString(nCurrPropID));
      result.AddInnerHTMLString("\n");
      result.AddInnerHTMLElement(new HTMLComment("End: Unique Name Chooser"));
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Displays a single row with a radio box in the left column, and title/description
    /// in the right column.  If bAddPropTree is selected, a link to choose a property
    /// from a tree is also added.  You can only have a property tree in one row in this
    /// view.
    /// </summary>
    /// <param name="myTable">- table to put the row in</param>
    /// <param name="nValue">- the value of the radio box</param>
    /// <param name="nChecked">- the value of the currently selected radio box</param>
    /// <param name="sSubHeader">- the title you'd like on the description</param>
    /// <param name="sDescription">- the description of the choice</param>
    /// <param name="needbreak">- should a break be added after the row?</param>
    /// <param name="bAddPropTree">- should a property tree be added to the row?</param>
    protected virtual void DisplayRadioForUniqueKeyChoices(HTMLTable myTable,
     int nValue, int nChecked, String sSubHeader, String sDescription, bool needbreak,
     bool bAddPropTree)
    {
      // aj: add a new row
      HTMLTableRow myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myTable.AddInnerHTMLElement(myRow);
      // aj: add the radio to the first cell
      HTMLTableCell myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("15");
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.RADIO, RADIO_UNIQUEKEY,
       XPConvert.ToString(nValue), "");
      myInput.SetValue(XPConvert.ToString(nValue));
      myInput.SetChecked(nChecked == nValue);
      String strOnClick = JS_SHOW_TREE_PICKER + "(" + nValue + ");";
      myInput.SetOnClick(strOnClick);
      myCell.AddInnerHTMLElement(myInput);
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      // aj: add the description to the second cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      HTMLSpan mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.AddInnerHTMLString(sSubHeader);
      myCell.AddInnerHTMLElement(new HTMLBr());
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      mySpan.AddInnerHTMLString(sDescription);
      if (bAddPropTree)
      {
        mySpan.AddInnerHTMLElement(new HTMLBr());
        AddPropertyTreePicker(mySpan);
      }
      if (needbreak)
      {
        myCell.AddInnerHTMLElement(new HTMLBr());
      }
    }
    private void AddPropertyTreePicker(HTMLSpan mySpan)
    {
      // aj: hidden space id for the tree
      String strRemoteServerSpaceID = ((IProfileSourceModelRO) m_model).GetUniqueKeyPickerSpaceID();
      mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_UNIQUEKEY_PROPERTY_SPACE,
       strRemoteServerSpaceID));
      // aj: JS for the tree picker popup
      String strOnClick = JSREPOST_UNIQUEKEY_FUNC_INPUT + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_UNIQUEKEY_PROPERTY_SPACE + "); return false;";
      // aj: the link to choose a property
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      HTMLSpan myUniquePickerSpan = new HTMLSpan();
      myUniquePickerSpan.SetID(HTML_TREE_PICKER_SPAN);
      mySpan.AddInnerHTMLElement(myUniquePickerSpan);
      HTMLAnchor myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
      myAnchor.SetOnClick(strOnClick);
      String sPropName = ((IProfileSourceModelRO) m_model).GetUniqueKeyPropertyName();
      if (sPropName != null && sPropName.Length > 0)
      {
        //aj: the property name should be displayed
        myUniquePickerSpan.AddInnerHTMLString(m_asOwner.GetString(2899, ResourceConstants.PORTALADMINMSGS));
        myUniquePickerSpan.AddInnerHTMLString(SPACE);
        myAnchor.AddInnerHTMLString(sPropName);
      } else
      {
        // aj: the prop image and "Choose Property" text should be displayed
        HTMLImg myImage = GetImage(PTImageType.ICON_PROPERTY);
        myAnchor.AddInnerHTMLElement(myImage);
        myAnchor.AddInnerHTMLString(m_asOwner.GetString(2897, ResourceConstants.PORTALADMINMSGS));
        }
      myUniquePickerSpan.AddInnerHTMLElement(myAnchor);
      // aj: hidden attribute that will store the selected propid from the picker
      int nCurrChoice = ((IProfileSourceModelRO) m_model).GetUniqueKey();
      int nCurrPropID = 0;
      if (nCurrChoice <= 0)
      {
        switch (nCurrChoice){
        case (PT_PROFILE_UNIQUE_KEYS.USER_UNIQUE_NAME):
        nCurrChoice = USER_UNIQUE_NAME;
        break;
        case (PT_PROFILE_UNIQUE_KEYS.USER_AUTHENTICATION_NAME):
        nCurrChoice = USER_AUTH_NAME;
        break;
        default:
        nCurrChoice = USER_UNIQUE_NAME;
        break;
        }
      } else
      {
        nCurrPropID = nCurrChoice;
        nCurrChoice = USER_PROP;
      }
      mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_UNIQUEKEY_PROPERTY_SELECTED,
       XPConvert.ToString(nCurrPropID)));
      if (nCurrPropID == 0)
      {
        myUniquePickerSpan.SetStyle("display: none");
      }
    }
    public override HTMLScript DisplayJavascript()
    {
      String strFormName = AFormDP.HTMLFORM_NAME;
      // The URL to open a new remote property tree
      ASURL pPropertyTree = new ASURL(m_asOwner);
      pPropertyTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      pPropertyTree.SetSubSpaceKey(ProfileSourceEditorAS.strUniqueKeyTree_SUBSPACE);
      pPropertyTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      pPropertyTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      pPropertyTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      pPropertyTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      pPropertyTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      pPropertyTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
       strFormName);
      pPropertyTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       HTMLHIDDEN_UNIQUEKEY_PROPERTY_SPACE);
      pPropertyTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       JSREPOST_UNIQUEKEY_FUNC);
      pPropertyTree.AddControlArgument(StartTreeControl.DISPLAYED_ITEMS, ((IProfileSourceModelRO) m_model).GetUserProperties());
      pPropertyTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, ((IProfileSourceModelRO) m_model).GetUniqueKey());
      pPropertyTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(2897,
       ResourceConstants.PORTALADMINMSGS));
      pPropertyTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(2898,
       ResourceConstants.PORTALADMINMSGS));
      pPropertyTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));
      // The url to open a previously opened remote folder tree
      // This needs to have the SpaceID added to it.
      ASURL oldRemoteServerTree = new ASURL(m_asOwner);
      oldRemoteServerTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      oldRemoteServerTree.IsSubSpace();
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_UNIQUEKEY_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(ProfileSourceRepostControl.POSTTOSELF_ACTION_SIMPLEREPOST).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Open remote folder tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JSREPOST_UNIQUEKEY_FUNC_INPUT).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(pPropertyTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(oldRemoteServerTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // aj: display/don't display the picker link
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JS_SHOW_TREE_PICKER).Append("(myChoice)\n");
        sb.Append("{\n");
        sb.Append("\t\tvar obj = document.getElementById(\'").Append(HTML_TREE_PICKER_SPAN).Append("\');\n");
        sb.Append("\t\tif(myChoice == ").Append(USER_PROP).Append(") {\n");
        sb.Append("\t\t\tobj.style[\'display\'] = \'inline\';\n");
        //			sb.Append("			alert('meeps!');\n");
        sb.Append("\t\t} else {\n");
        sb.Append("\t\t\tobj.style[\'display\'] = \'none\';\n");
        sb.Append("\t\t}\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element: " + he.Message);
        }
      return result;
    }
    protected virtual HTMLImg GetImage(PTImageType type)
    {
      try
      {
        PTConstruct myConstruct = UIConstructFactory.GetConstruct(type, true,
         this.m_asOwner);
        HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();
        //			myImg.SetAlt(alt);
        myImg.SetBorder("0");
        //			myImg.SetWidth(w);
        //			myImg.SetHeight(h);
        return myImg;
      }
      catch (Exception e)
      {
        log.Error("UniqueKeyChooserView.GetImage couldn\'t get image: " + e.Message);
        throw new XPException(m_asOwner.GetString(112, ResourceConstants.PORTALADMINMSGS) + " (Image)",
         e);
      }
    }
  }
}