using System;
using com.plumtree.portaluiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// Read-only interface for property model.
  /// </summary>
  /// <author>josephc</author>
  public interface IPropModelRO : IObjEditorModelRO
  {
    
    /// <summary>
    /// Return pick list validation function
    /// </summary>
    /// <returns>Pick list validation function</returns>
    String GetManagedPicklistValidationFunction();
    
    /// <summary>
    /// Returns name of database table used for pick table
    /// </summary>
    /// <returns>Name of database table used for pick table</returns>
    String GetPickTable();
    
    /// <summary>
    /// Returns pick table types (PT_PICKTABLE_TYPES)
    /// </summary>
    /// <returns>Pick type</returns>
    int GetPickType();
    
    /// <summary>
    /// Returns property type (PT_PROPERTY_TYPES)
    /// </summary>
    /// <returns>Property type</returns>
    int GetPropertyType();
    
    /// <summary>
    /// Returns reference class
    /// </summary>
    /// <returns>Reference class</returns>
    int GetReferenceClass();
    
    /// <summary>
    /// Returns true if property is always a card property
    /// </summary>
    /// <returns>True if property is always a card property</returns>
    bool IsAlwaysCardProperty();
    
    /// <summary>
    /// Returns true if property is a card property
    /// </summary>
    /// <returns>True if property is a card property</returns>
    bool IsCardProperty();
    
    /// <summary>
    /// Returns true if property is mandatory
    /// </summary>
    /// <returns>True if property is mandatory</returns>
    bool IsMandatory();
    
    /// <summary>
    /// Returns true if property is multi-valued
    /// </summary>
    /// <returns>True if property is multi-valued</returns>
    bool IsMultiValued();
    
    /// <summary>
    /// Returns true if property is searchable
    /// </summary>
    /// <returns>True if property is searchable</returns>
    bool IsSearchable();
    
    /// <summary>
    /// Returns true if property is an URL
    /// </summary>
    /// <returns>True if property is an URL</returns>
    bool IsURL();
    
    /// <summary>
    /// Returns true if property is visible
    /// </summary>
    /// <returns>True if property is visible</returns>
    bool IsVisible();
    
    /// <summary>
    /// Returns true if property is read-only
    /// </summary>
    /// <returns>True if property is read-only</returns>
    bool IsReadOnly();
  }
}