using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// Main display page for property editor
  /// </summary>
  /// <author>josephc</author>
  public class MainDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.property.MainDP");
    
    /// <summary>
    /// Class name for MainDP 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropMain";
    
    /// <summary>
    /// JavaScript function name for managed picklist validation 
    /// </summary>
    public const String JAVASCRIPT_VALIDATE_MANAGEDPICKLIST = "PropValidateManagedPicklist";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(655, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      IPropModelRO asModel = (IPropModelRO) m_asOwner.GetModel(PropModel.STR_MVC_CLASS_NAME);
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SettingsView.STR_MVC_CLASS_NAME)).Display());
      if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF != asModel.GetPropertyType() && PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != asModel.GetPropertyType())
      {
        switch (asModel.GetPickType()){
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST:
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PropEditorAS.strPickListValuesList)).Display());
        break;
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PickTableView.STR_MVC_CLASS_NAME)).Display());
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PropEditorAS.strPickTableColumnList)).Display());
        break;
        default:
        break;
        }
      }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    /// <throws>XPException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(PropEditorAS.strPickListValuesList).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(PropEditorAS.strPickTableColumnList).DisplayJavascript());
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb;
      IPropModelRO asModel = (IPropModelRO) m_asOwner.GetModel(PropModel.STR_MVC_CLASS_NAME);
      String sJSFunctionName = asModel.GetManagedPicklistValidationFunction();
      try
      {
        // Validate Managed Picklist function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JAVASCRIPT_VALIDATE_MANAGEDPICKLIST).Append("(cardID)\n");
        sb.Append("{\n");
        sb.Append("  if (null != document.").Append(EditorDP.HTMLFORM_NAME).Append(".").Append(SettingsView.HTMLSELECT_PICKTYPE).Append(")\n");
        sb.Append("  {\n");
        sb.Append("    if (\"").Append(PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST).Append("\" == document.").Append(EditorDP.HTMLFORM_NAME).Append(".").Append(SettingsView.HTMLSELECT_PICKTYPE).Append(".value) \n");
        sb.Append("    {\n");
        sb.Append("       return ").Append(sJSFunctionName).Append("();\n");
        sb.Append("    }\n");
        sb.Append("  }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        myScripts.AddInnerHTMLElement(myScript);
      }
      catch (HTMLException he)
      {
        log.Error(he, "DirEditDP::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        throw new XPException(m_asOwner.GetString(653, "ptmsgs_portaladminmsgs"),
         he);
      }
      return myScripts;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1685, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
  }
}