using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// Model for pick list values list plugin.  This model is required for validation of
  /// pick list values.
  /// </summary>
  /// <author>josephc</author>
  public class PickListValuesListModel : GrowableListModel,IGrowableListModelRO
  {
    
    /// <summary>
    /// Class name for PickListValuesListModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PickListValuesList";
    
    /// <summary>
    /// Property type 
    /// </summary>
    private int m_nPropType;
    
    /// <summary>
    /// Creates a new PickListValuesListModel object.
    /// </summary>
    public PickListValuesListModel() : base()
    {
      m_nPropType = PT_PROPERTY_TYPES.PT_PROPTYPE_INVALID;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PickListValuesListModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Sets the property type, and removes all rows in the list.
    /// </summary>
    /// <param name="_nPropType">Property type</param>
    public virtual void ResetPickList(int _nPropType)
    {
      m_nPropType = _nPropType;
      m_saData.ClearArray();
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(GrowableListView.HTMLINPUT_ITEM) + _nRowIndex;
      String[] aDataValue;
      // JF- For each input text posted by the form, we get the value back 
      // and set the new value in the array.
      if (_htFormData.ContainsKey(sDataKey))
      {
        aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && !(0 == aDataValue.Length))
        {
          String strValue = aDataValue[0];
          try
          {
            // TODO: Currently we will save the value even if it is invalid.  Currently, server-side validation
            // only takes place when page is changed or editor is finished.
            _saData.SetItem(_nRowIndex, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT,
             strValue);
            // TODO: Validate value by attempting to convert it into an object. An exception will be thrown if the
            // string is invalid and cannot be converted.  Ideally this would be called before we set the value in
            // the list.
            ObjPropModel.GetPropValueFromString(strValue, m_nPropType);
          }
          catch (Exception e)
          {
            String strErrorMsg = m_asOwner.GetString(1864, "ptmsgs_portaladminmsgs") + strValue;
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             strErrorMsg, strErrorMsg);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            return RepostControl.PAGE_STATUS_INVALID;
          }
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}