using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// View for entering database table name for a pick table
  /// </summary>
  /// <author>josephc</author>
  public class PickTableView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.property.PickTableView");
    
    /// <summary>
    /// Class name for PickTableView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PickTableView";
    
    /// <summary>
    /// Input name for pick table 
    /// </summary>
    public const String HTMLINPUT_PICKTABLE = "in_tx_PickTable";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PickTableView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      try
      {
        String strPickTable = ((IPropModelRO) m_model).GetPickTable();
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(657,
         "ptmsgs_portaladminmsgs")));
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding(CommonHTMLStrings.FIVE);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell.SetWidth("150");
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.AddInnerHTMLString(m_asOwner.GetString(658, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_PICKTABLE,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetMaxLength(32);
        myInput.SetSize(50);
        if (null != strPickTable)
        {
          myInput.SetValue(strPickTable);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "PickTableView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(656, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}