using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// Activity space for property editor
  /// </summary>
  /// <author>josephc</author>
  public class PropEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.property.PropEditorAS");
    
    /// <summary>
    /// Class name for PropEditorAS 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropEditor";
    
    /// <summary>
    /// Class name 
    /// </summary>
    private const String sClassName = "com.plumtree.portalpages.admin.editors.property.PropEditorAS";
    
    /// <summary>
    /// Storage name for growable pick list values 
    /// </summary>
    public const String strPickListValuesList = "PickListValuesList";
    
    /// <summary>
    /// Storage name for pick table columns 
    /// </summary>
    public const String strPickTableColumnList = "PickTableColumnList";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PropEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (PropDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(659, "ptmsgs_portaladminmsgs");
      } else
      {
        return XPResourceManager.FormatMessage(GetString(660, "ptmsgs_portaladminmsgs"),
         GetObjectName());
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (PropRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PropModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      RegisterPage(new MainDP());
      // Register Views
      RegisterView(SettingsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(PickTableView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(PropDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(PropRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Picklist Growable list
      RegisterModel(PickListValuesListModel.STR_MVC_CLASS_NAME, strPickListValuesList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myPickListValuesListModel = GetModel(strPickListValuesList);
      RegisterView(GrowableListView.STR_MVC_CLASS_NAME, strPickListValuesList,
       myPickListValuesListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strPickListValuesList,
       myPickListValuesListModel);
      // PickTree Column List
      RegisterModel(PickTreeColumnsListModel.STR_MVC_CLASS_NAME, strPickTableColumnList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myPickTreeColumnList = GetModel(strPickTableColumnList);
      RegisterView(MultiColumnListView.STR_MVC_CLASS_NAME, strPickTableColumnList,
       myPickTreeColumnList);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strPickTableColumnList,
       myPickTreeColumnList);
      // Default page
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(661, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(2187, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 57;
          int iTipId = 58;
          int iSecondaryTipId = 59;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <summary>
    /// Set the help page for this editor. 
    /// </summary>
    /// <param name="page"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)"></seealso>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("pt_property_mainsettings");
      }
    }
  }
}