using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.server.treeiterator;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// Model for property editor
  /// </summary>
  /// <author>josephc</author>
  public class PropModel : ObjEditorModel,IPropModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.property.PropModel");
    
    /// <summary>
    /// Class name for PropModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropModel";
    
    /// <summary>
    /// Property object 
    /// </summary>
    private IPTProperty m_ptProperty = null;
    
    /// <summary>
    /// Managed list validation function 
    /// </summary>
    private String m_strManagedListValidation = "";
    
    /// <summary>
    /// Pick table 
    /// </summary>
    private String m_strPickTable = null;
    
    /// <summary>
    /// True if property is always card property 
    /// </summary>
    private bool m_bAlwaysCardProp = false;
    
    /// <summary>
    /// True if property is card property 
    /// </summary>
    private bool m_bCardProp = true;
    
    /// <summary>
    /// True if property is mandatory 
    /// </summary>
    private bool m_bMandatory = false;
    
    /// <summary>
    /// True if property is multi-valued 
    /// </summary>
    private bool m_bMultiValued = false;
    
    /// <summary>
    /// True if property is searchable 
    /// </summary>
    private bool m_bSearchable = false;
    
    /// <summary>
    /// True if proeprty is an URL 
    /// </summary>
    private bool m_bURL = false;
    
    /// <summary>
    /// True if property is visible 
    /// </summary>
    private bool m_bVisible = true;
    
    /// <summary>
    /// True if property is read only 
    /// </summary>
    private bool m_bReadOnly = false;
    
    /// <summary>
    /// Property pick type 
    /// </summary>
    private int m_nPickType;
    
    /// <summary>
    /// Reference class 
    /// </summary>
    private int m_nReferenceClass = -1;
    
    /// <summary>
    /// Property type 
    /// </summary>
    private int m_nPropType;
    
    /// <summary>
    /// Key for growable pick list value list 
    /// </summary>
    private const int m_nPickListValueListKey = 1;
    
    /// <summary>
    /// Key for growable pick table column list 
    /// </summary>
    private const int m_nPickTableColListKey = 2;
    
    /// <summary>
    /// Temporary pick list property for validating unmanaged dropdowns and picktrees 
    /// </summary>
    private IPTProperty m_tempPickListProperty = null;
    
    /// <summary>
    /// Creates a new PropModel object.
    /// </summary>
    public PropModel()
    {
      m_nPickType = PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE;
      m_nPropType = PT_PROPERTY_TYPES.PT_PROPTYPE_STRING;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PropModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
      // Store the Managed PickList values
      if (PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST == m_nPickType)
      {
        SaveManagedPickListValues();
      }
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      // Property Type (only in CREATE mode)
      if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
      {
        m_ptProperty.Initialize(m_nPropType);
      }
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_HREF,
       (m_bURL ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_REFCLASS,
       m_nReferenceClass);
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_ISCARDPROP,
       (m_bCardProp ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_VISIBLE,
       (m_bVisible ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_READONLYVALUE,
       (m_bReadOnly ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MANDATORY,
       (m_bMandatory ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_SEARCHABLE,
       (m_bSearchable ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MULTIVALUED,
       (m_bMultiValued ? 1 : 0));
      m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE,
       (m_nPickType));
      switch (m_nPickType){
      case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
      case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
      {
        m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLE,
         m_strPickTable);
        // Save pick columns and sort columns
        Object[][] pickTableColumns = ((PickTreeColumnsListModel) m_asOwner.GetModel(PropEditorAS.strPickTableColumnList)).GetListValues();
        m_ptProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLECOLS,
         pickTableColumns);
        break;
      }
      default:
      break;
      }
    }
    
    /// <summary>
    /// Code to perform tasks specific to Property Editor
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      m_ptProperty = (IPTProperty) m_ptObject;
      Object[][] arPickTableColumns = null;
      // Retrieve current settings only in EDIT mode
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        try
        {
          // Value type
          m_nPropType = m_ptProperty.GetType();
          // URL
          if (PT_PROPERTY_TYPES.PT_PROPTYPE_STRING == m_nPropType)
          {
            m_bURL = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_HREF));
            } else
          {
            m_bURL = false;
          }
          // Reference class
          if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == m_nPropType)
          {
            m_nReferenceClass = m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_REFCLASS);
            } else
          {
            m_nReferenceClass = -1;
          }
          // Card property
          if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF != m_nPropType)
          {
            m_bCardProp = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_ISCARDPROP));
            } else
          {
            // Card prop must be set to false, because reference types cannot be used with cards
            m_bCardProp = false;
          }
          // Visible
          m_bVisible = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_VISIBLE));
          // Read-only
          m_bReadOnly = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_READONLYVALUE));
          // Mandatory
          if (m_bVisible && !m_bReadOnly)
          {
            m_bMandatory = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MANDATORY));
            } else
          {
            m_bMandatory = false;
          }
          // Searchable
          if (m_bVisible)
          {
            m_bSearchable = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_SEARCHABLE));
            } else
          {
            m_bSearchable = false;
          }
          // Multivalued
          m_bMultiValued = (1 == m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MULTIVALUED));
          // Picktype
          if ((PT_PROPERTY_TYPES.PT_PROPTYPE_REF != m_nPropType) && (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != m_nPropType))
          {
            m_nPickType = m_ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE);
            // Update pick table and pick columns
            switch (m_nPickType){
            case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
            case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
            {
              // Load pick table
              m_strPickTable = m_ptProperty.GetCharacteristicsAsString(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLE);
              // Load pick columns
              arPickTableColumns = m_ptProperty.GetCharacteristicsAsObject2DArray(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLECOLS);
              goto default;
            }
            default:
            break;
            }
          } else
          {
            m_nPickType = PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE;
            m_strPickTable = null;
          }
        }
        catch (Exception e)
        {
          log.Error(e, STR_MVC_CLASS_NAME + "::DoTaskOnStartEditor(): Unable to retrieve current settings:: " + e.Message);
          }
      } else
      {
        // Create mode
        if (this.m_asOwner.IsSubSpace())
        {
          m_bAlwaysCardProp = true;
        } else
        {
          m_bAlwaysCardProp = false;
        }
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      StartPickListValuesList();
      StartPickTableColList(arPickTableColumns);
    }
    
    /// <summary>
    /// Return pick list validation function
    /// </summary>
    /// <returns>Pick list validation function</returns>
    public virtual String GetManagedPicklistValidationFunction()
    {
      return m_strManagedListValidation;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns name of database table used for pick table
    /// </summary>
    /// <returns>Name of database table used for pick table</returns>
    public virtual String GetPickTable()
    {
      return m_strPickTable;
    }
    
    /// <summary>
    /// Returns pick table types (PT_PICKTABLE_TYPES)
    /// </summary>
    /// <returns>Pick type</returns>
    public virtual int GetPickType()
    {
      return m_nPickType;
    }
    
    /// <summary>
    /// Returns property type (PT_PROPERTY_TYPES)
    /// </summary>
    /// <returns>Property type</returns>
    public virtual int GetPropertyType()
    {
      return m_nPropType;
    }
    
    /// <summary>
    /// Returns reference class
    /// </summary>
    /// <returns>Reference class</returns>
    public virtual int GetReferenceClass()
    {
      return m_nReferenceClass;
    }
    
    /// <summary>
    /// Returns true if property is always a card property
    /// </summary>
    /// <returns>True if property is always a card property</returns>
    public virtual bool IsAlwaysCardProperty()
    {
      return m_bAlwaysCardProp;
    }
    
    /// <summary>
    /// Returns true if property is a card property
    /// </summary>
    /// <returns>True if property is a card property</returns>
    public virtual bool IsCardProperty()
    {
      return m_bCardProp || m_bAlwaysCardProp;
    }
    
    /// <summary>
    /// Returns true if property is mandatory
    /// </summary>
    /// <returns>True if property is mandatory</returns>
    public virtual bool IsMandatory()
    {
      return m_bMandatory;
    }
    
    /// <summary>
    /// Returns true if property is multi-valued
    /// </summary>
    /// <returns>True if property is multi-valued</returns>
    public virtual bool IsMultiValued()
    {
      return m_bMultiValued;
    }
    
    /// <summary>
    /// Returns true if property is searchable
    /// </summary>
    /// <returns>True if property is searchable</returns>
    public virtual bool IsSearchable()
    {
      return m_bSearchable;
    }
    
    /// <summary>
    /// Returns true if property is an URL
    /// </summary>
    /// <returns>True if property is an URL</returns>
    public virtual bool IsURL()
    {
      return m_bURL;
    }
    
    /// <summary>
    /// Returns true if property is visible
    /// </summary>
    /// <returns>True if property is visible</returns>
    public virtual bool IsVisible()
    {
      return m_bVisible;
    }
    
    /// <summary>
    /// Returns true if property is read-only
    /// </summary>
    /// <returns>True if property is read-only</returns>
    public virtual bool IsReadOnly()
    {
      return m_bReadOnly;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        int nMainPageStatus = SaveMainPage(_htFormData);
        if (RepostControl.PAGE_STATUS_INVALID == nMainPageStatus)
        {
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
        int nPickListValueListStatus = ((PickListValuesListModel) m_asOwner.GetModel(PropEditorAS.strPickListValuesList)).SaveSection(_htFormData);
        if (RepostControl.PAGE_STATUS_INVALID == nPickListValueListStatus)
        {
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
        int nPickTableColumnListStatus = ((MultiColumnListModel) m_asOwner.GetModel(PropEditorAS.strPickTableColumnList)).SaveSection(_htFormData);
        if (RepostControl.PAGE_STATUS_INVALID == nPickTableColumnListStatus)
        {
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
        switch (m_nPickType){
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
        case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
        {
          if (null == m_strPickTable)
          {
            // If this is the first time we have selected to have an unmanaged picklist/picktree
            // then the pick table will be null because we haven't set it yet. In this case
            // we don't want to validate values.
            break;
          }
          // Lazy initialization of temporary property. We only want to create temporary property if we want to validate pick table values.
          if (null == m_tempPickListProperty)
          {
            m_tempPickListProperty = (IPTProperty) m_Session.GetProperties().Create(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
            m_tempPickListProperty.Initialize(m_nPropType);
          }
          m_tempPickListProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE,
           m_nPickType);
          m_tempPickListProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLE,
           m_strPickTable);
          // Get pick columns and sort columns
          Object[][] pickTableColumns = ((PickTreeColumnsListModel) m_asOwner.GetModel(PropEditorAS.strPickTableColumnList)).GetListValues();
          m_tempPickListProperty.SetCharacteristics(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTABLECOLS,
           pickTableColumns);
          bool bErrorOccurred = false;
          try
          {
            IPTPickListEditor ptPickList = m_tempPickListProperty.GetPickList();
            if (null == ptPickList)
            {
              bErrorOccurred = true;
            } else
            {
              // Get tree iterator from pick list
              IPTTreeIterator ptTreeIterator = (IPTTreeIterator) ptPickList.GetInterfaces("IPTTreeIterator");
              ObjPropModel.ValidateTree(ptTreeIterator, 0);
            }
          }
          catch (PTException e)
          {
            bErrorOccurred = true;
          }
          if (bErrorOccurred)
          {
            String strType;
            if (PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST == m_nPickType)
            {
              // Unmanaged dropdown
              strType = m_asOwner.GetString(684, "ptmsgs_portaladminmsgs");
              } else
            {
              // Tree
              strType = m_asOwner.GetString(683, "ptmsgs_portaladminmsgs");
              }
            String strErrorMsg = XPResourceManager.FormatMessage(m_asOwner.GetString(2671,
             "ptmsgs_portaladminmsgs"), strType);
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             strErrorMsg, strErrorMsg);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            nPageStatus = RepostControl.PAGE_STATUS_INVALID;
          }
          break;
        }
        default:
        break;
        }
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to start the growable list for pick list values list.
    /// </summary>
    public virtual void StartPickListValuesList()
    {
      PickListValuesListModel myPickListValuesList = (PickListValuesListModel) m_asOwner.GetModel(PropEditorAS.strPickListValuesList);
      // TODO: is there an image for this?
      myPickListValuesList.InitializeGrowableList(m_asOwner.GetString(673,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(674, "ptmsgs_portaladminmsgs"),
       PTImageType.ICON_VALUE, m_asOwner.GetString(669, "ptmsgs_portaladminmsgs"),
       m_nPickListValueListKey);
      //Set the property type
      myPickListValuesList.ResetPickList(m_nPropType);
      myPickListValuesList.SetEnableMoveRowActions(true);
      // Retrieve current picklist values only in EDIT mode
      if ((EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType()) && (PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST == m_nPickType))
      {
        String[] arValues;
        IPTPickListEditor ptPickList = (IPTPickListEditor) m_ptProperty.GetPickList();
        IPTTreeIterator ptTreeIterator = (IPTTreeIterator) ptPickList.GetInterfaces("IPTTreeIterator");
        Object[][] childNodes = (Object[][]) ptTreeIterator.Children(0, -1);
        if (null != childNodes)
        {
          int numChildren = childNodes[0].Length;
          arValues = new String[numChildren];
          for (int i = 0;i < numChildren;i++)
          {
            String childName = (String) childNodes[PT_TREE_ITERATOR_CHILD_INFO.PT_TREE_ITERATOR_CHILD_INFO_NAME][i];
            arValues[i] = childName;
          }
          myPickListValuesList.AddRowsToList(arValues);
        }
      }
      myPickListValuesList.SetEmptyListMessages(m_asOwner.GetString(672, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(671, "ptmsgs_portaladminmsgs"));
      myPickListValuesList.SetEnableMoveRowActions(true);
      // Add validation function
      m_strManagedListValidation = ((GrowableListModel) myPickListValuesList).SetClientValidationType(GrowableListModel.CLIENT_VALIDATION_TYPE_NON_EMPTY_STRING,
       m_asOwner.GetString(670, "ptmsgs_portaladminmsgs"));
      MainDP myListDP = (MainDP) m_asOwner.GetPage(MainDP.STR_MVC_CLASS_NAME);
      myListDP.AddToValidationFunction(MainDP.JAVASCRIPT_VALIDATE_MANAGEDPICKLIST);
      }
    
    /// <summary>
    /// Helper method to start the multi-column list for pick table column list.
    /// </summary>
    /// <param name="arPickTableColumns">Array of pick table columns</param>
    public virtual void StartPickTableColList(Object[][] arPickTableColumns)
    {
      PickTreeColumnsListModel myModel = (PickTreeColumnsListModel) m_asOwner.GetModel(PropEditorAS.strPickTableColumnList);
      myModel.SetNumColumns(PT_PICKTABLE_COLUMNS.PT_PICKTABLE_COLUMN_INVALID);
      // Initialize the multi column list
      String[] arPickTableColumnNames = new String[PT_PICKTABLE_COLUMNS.PT_PICKTABLE_COLUMN_INVALID];
      arPickTableColumnNames[0] = m_asOwner.GetString(676, "ptmsgs_portaladminmsgs");
      arPickTableColumnNames[1] = m_asOwner.GetString(678, "ptmsgs_portaladminmsgs");
      myModel.InitializeMultiColumnList(m_asOwner.GetString(677, "ptmsgs_portaladminmsgs"),
       arPickTableColumnNames, PTImageType.ICON_URL, m_asOwner.GetString(669,
       "ptmsgs_portaladminmsgs"), m_nPickTableColListKey);
      // Use the method below to set the value to populate a newly created input text.
      // (By default it will be a null array, so it MUST be initialized.
      String[] arPickTableColumnDefaults = new String[PT_PICKTABLE_COLUMNS.PT_PICKTABLE_COLUMN_INVALID];
      arPickTableColumnDefaults[0] = "";
      arPickTableColumnDefaults[1] = "";
      myModel.SetDefaultValue(arPickTableColumnDefaults);
      myModel.SetEmptyListMessages(m_asOwner.GetString(675, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(667, "ptmsgs_portaladminmsgs"));
      myModel.SetEnableMoveRowActions(true);
      myModel.SetPickType(m_nPickType);
      //Get the name value pairs from the model in edit mode and populate them in here
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        // Add pick and sort columns
        if (null != arPickTableColumns)
        {
          myModel.AddRowsToList(arPickTableColumns);
        }
      } else
      {
        myModel.ClearColumns();
      }
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveMainPage(XPHashtable _htFormData)
    {
      int nRetVal = RepostControl.PAGE_STATUS_VALID;
      String[] data;
      // Value type
      data = (String[]) _htFormData.GetElement(SettingsView.HTMLSELECT_PROPTYPE);
      if ((null != data) && !(0 == data.Length))
      {
        int nPropType = XPConvert.ToInteger(data[0]);
        // If the property type has been changed, then reset the pick list.
        if (m_nPropType != nPropType)
        {
          m_nPropType = nPropType;
          // Update pick list values list model
          ((PickListValuesListModel) m_asOwner.GetModel(PropEditorAS.strPickListValuesList)).ResetPickList(m_nPropType);
          }
      } else
      {
        log.Warn("PropEditorModel::SaveMainPage Property Type was not in Query String.");
        }
      // URL
      if (PT_PROPERTY_TYPES.PT_PROPTYPE_STRING == m_nPropType)
      {
        data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_URL);
        m_bURL = ((null != data) && !(0 == data.Length));
      }
      // Reference class
      if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == m_nPropType)
      {
        data = (String[]) _htFormData.GetElement(SettingsView.HTMLSELECT_REFCLASS);
        if ((null != data) && !(0 == data.Length))
        {
          m_nReferenceClass = XPConvert.ToInteger(data[0]);
        }
      }
      // Card property
      if (m_bAlwaysCardProp)
      {
        m_bCardProp = true;
      } else
      {
        if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF != m_nPropType)
        {
          data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_CARDPROP);
          m_bCardProp = ((null != data) && !(0 == data.Length));
        } else
        {
          // Card prop must be set to false, because reference types cannot be used with cards
          m_bCardProp = false;
        }
      }
      // Visible
      data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_VISIBLE);
      m_bVisible = ((null != data) && !(0 == data.Length));
      // Read-only
      data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_READONLY);
      m_bReadOnly = ((null != data) && !(0 == data.Length));
      // Mandatory
      if (m_bVisible && !m_bReadOnly)
      {
        data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_MANDATORY);
        m_bMandatory = ((null != data) && !(0 == data.Length));
      } else
      {
        m_bMandatory = false;
      }
      // Searchable
      if (m_bVisible)
      {
        data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_SEARCHABLE);
        m_bSearchable = ((null != data) && !(0 == data.Length));
      }
      // Multi-valued
      data = (String[]) _htFormData.GetElement(SettingsView.HTMLCHECKBOX_MULTIVALUED);
      m_bMultiValued = ((null != data) && !(0 == data.Length));
      // Pick type
      if ((PT_PROPERTY_TYPES.PT_PROPTYPE_REF != m_nPropType) && (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != m_nPropType))
      {
        data = (String[]) _htFormData.GetElement(SettingsView.HTMLSELECT_PICKTYPE);
        if ((null != data) && !(0 == data.Length))
        {
          int nNewPickType = XPConvert.ToInteger(data[0]);
          // If pick type changed, then reset the columns
          if (nNewPickType != m_nPickType)
          {
            // PickTable columns
            PickTreeColumnsListModel myModel = (PickTreeColumnsListModel) m_asOwner.GetModel(PropEditorAS.strPickTableColumnList);
            myModel.SetPickType(nNewPickType);
            myModel.ClearColumns();
          }
          m_nPickType = nNewPickType;
        }
      }
      // PickTable
      switch (m_nPickType){
      case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
      case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
      {
        data = (String[]) _htFormData.GetElement(PickTableView.HTMLINPUT_PICKTABLE);
        if ((null != data) && (0 != data.Length))
        {
          if ((null != data[0]) && (0 != data[0].Length))
          {
            m_strPickTable = data[0];
          } else
          {
            // raise error to display to user
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             m_asOwner.GetString(668, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(668,
             "ptmsgs_portaladminmsgs"));
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            return RepostControl.PAGE_STATUS_INVALID;
          }
        }
        break;
      }
      default:
      m_strPickTable = null;
      break;
      }
      return nRetVal;
    }
    
    /// <summary>
    /// Save managed pick list values
    /// </summary>
    private void SaveManagedPickListValues()
    {
      IPTPickListEditor ptPickList = (IPTPickListEditor) m_ptProperty.GetPickList();
      ptPickList.RemoveAll();
      String[] aGrowableArrayValues = ((PickListValuesListModel) m_asOwner.GetModel(PropEditorAS.strPickListValuesList)).GetListValues();
      // Create array of 3 columns and maxRow rows
      int maxRow = aGrowableArrayValues.Length;
      Object[][] picklistActionArray = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        picklistActionArray[j2c_index] = new Object[maxRow];
      }
      // Add new items to action array
      for (int currentRow = 0;currentRow < maxRow;currentRow++)
      {
        String picklistValue = aGrowableArrayValues[currentRow];
        Object picklistSortOrder = currentRow;
        picklistActionArray[PT_EDIT_PICKLIST_COLS.PT_EDIT_PICKLIST_ACTION][currentRow] = PT_EDIT_PICKLIST_ACTIONS.PT_EDIT_PICKLIST_ACTION_ADD;
        picklistActionArray[PT_EDIT_PICKLIST_COLS.PT_EDIT_PICKLIST_DATA][currentRow] = picklistValue;
        picklistActionArray[PT_EDIT_PICKLIST_COLS.PT_EDIT_PICKLIST_SORTDATA][currentRow] = picklistSortOrder;
        }
      ptPickList.SetItems(picklistActionArray);
    }
  }
}