using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// Repost control for property editor
  /// </summary>
  public class PropRepostControl : ObjEditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.property.PropRepostControl");
    
    /// <summary>
    /// Class name for PropRepostControl 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropRepost";
    public const int POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS = 8;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PropRepostControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Perform repost action for property editor. Also calls repost action for pick list
    /// values growable list and pick table column list.
    /// </summary>
    /// <param name="_nAction"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.RepostControl#PerformAction(int)"></seealso>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      ((ExpListControl) m_asOwner.GetControl(PropEditorAS.strPickListValuesList)).PerformRepostAction(_nAction,
       m_htFormData);
      ((ExpListControl) m_asOwner.GetControl(PropEditorAS.strPickTableColumnList)).PerformRepostAction(_nAction,
       m_htFormData);
    }
    
    /// <summary>
    /// Get the current page name and call the save method on the model. Overrides the default
    /// behavior of SaveCurrentPage so that server-side validation is always enabled
    /// instead of only on change of page or finish of editor.
    /// </summary>
    protected override void SaveCurrentPage()
    {
      // We always save the data on the page except on cancel.
      if (POSTTOSELF_ACTION_CANCEL != m_nAction)
      {
        // JF- Get back the page name from the form.
        String[] data = (String[]) m_htFormData.GetElement(ASConstants.PAGE_INPUT);
        if (data == null)
        {
          data = (String[]) m_htFormData.GetElement(ASConstants.PAGE);
        }
        if (data == null)
        {
          log.Error("RepostControl::SaveCurrentPage The page name has not been posted by the form.");
          throw new XPException("Unexpected error when trying to save the current page.");
          }
        if ((0 != data.Length) && (null != data[0]))
        {
          // JF- Save the page
          m_nPageStatus = m_model.SavePage(data[0], m_htFormData);
          switch (m_nAction){
          case POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS:
          {
            UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication());
            log.Info("RepostControl::SaveCurrentPage Just cleared all errors on UIErrorHandler " + "because this is not a Finish or Change Page action.");
            break;
          }
          default:
          break;
          }
          // JIC - Enable server side validate for all actions
          /*
           // JF- Only enable server validation when the user is changing page or finishing the Editor.
           if ((POSTTOSELF_ACTION_GOTOPAGE != m_nAction) &&
           (POSTTOSELF_ACTION_FINISH != m_nAction))
           {
           UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(),
           m_asOwner.GetApplication());
           
           
           log.Info("RepostControl::SaveCurrentPage Just cleared all errors on UIErrorHandler " +
           "because this is not a Finish or Change Page action.");
           
           }
           */
           
          log.Debug("RepostControl::SaveCurrentPage Saving page: " + data[0]);
          } else
        {
          log.Warn("RepostControl::SaveCurrentPage The page name value is invalid. The page will not be saved.");
          }
      }
    }
  }
}