using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.property
{
  /// <summary>
  /// View for property settings
  /// </summary>
  /// <author>josephc</author>
  public class SettingsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.property.SettingsView");
    
    /// <summary>
    /// Class name for SettingsView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropSettings";
    
    /// <summary>
    /// Select for property type 
    /// </summary>
    public const String HTMLSELECT_PROPTYPE = "in_se_PropType";
    
    /// <summary>
    /// Select for reference class 
    /// </summary>
    public const String HTMLSELECT_REFCLASS = "in_se_RefClass";
    
    /// <summary>
    /// Select for pick type 
    /// </summary>
    public const String HTMLSELECT_PICKTYPE = "in_se_PickType";
    
    /// <summary>
    /// Checkbox for visible property 
    /// </summary>
    public const String HTMLCHECKBOX_VISIBLE = "in_cb_visible";
    
    /// <summary>
    /// Checkbox for read-only property 
    /// </summary>
    public const String HTMLCHECKBOX_READONLY = "in_cb_readonly";
    
    /// <summary>
    /// Checkbox for card property 
    /// </summary>
    public const String HTMLCHECKBOX_CARDPROP = "in_cb_cardprop";
    
    /// <summary>
    /// Checkbox for mandatory property 
    /// </summary>
    public const String HTMLCHECKBOX_MANDATORY = "in_cb_mandatory";
    
    /// <summary>
    /// Checkbox for searchable property 
    /// </summary>
    public const String HTMLCHECKBOX_SEARCHABLE = "in_cb_searchable";
    
    /// <summary>
    /// Checkbox for URL property 
    /// </summary>
    public const String HTMLCHECKBOX_URL = "in_cb_url";
    
    /// <summary>
    /// Checkbox for multi-valued property 
    /// </summary>
    public const String HTMLCHECKBOX_MULTIVALUED = "in_cb_multivalued";
    
    /// <summary>
    /// Array of different pick table types 
    /// </summary>
    private static int[] m_arPickTableType = new int[]{PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE,
     PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST, PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST,
     PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE};
    
    /// <summary>
    /// Array of property type 
    /// </summary>
    private static int[] m_arPropertyTypes = new int[]{PT_PROPERTY_TYPES.PT_PROPTYPE_STRING,
     PT_PROPERTY_TYPES.PT_PROPTYPE_LONG, PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE,
     PT_PROPERTY_TYPES.PT_PROPTYPE_DATE, PT_PROPERTY_TYPES.PT_PROPTYPE_REF,
     PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED};
    
    /// <summary>
    /// Array of pick table type names 
    /// </summary>
    private String[] m_arPickTableTypeNames;
    
    /// <summary>
    /// Array of property type names 
    /// </summary>
    private String[] m_arPropertyNames;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SettingsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      IPropModelRO iModelRO = (IPropModelRO) m_model;
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableRow myRow;
      try
      {
        bool bIsAlwaysCardProp = iModelRO.IsAlwaysCardProperty();
        bool bIsCardProp = iModelRO.IsCardProperty();
        int nPropType = iModelRO.GetPropertyType();
        bool bIsURL = iModelRO.IsURL();
        int nPickType = iModelRO.GetPickType();
        bool bIsSearchable = iModelRO.IsSearchable();
        bool bIsVisible = iModelRO.IsVisible();
        bool bIsMandatory = iModelRO.IsMandatory();
        bool bIsMultivalued = iModelRO.IsMultiValued();
        bool bIsReadOnly = iModelRO.IsReadOnly();
        bool bIsEncrypted = (PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED == nPropType);
        if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == nPropType)
        {
          bIsAlwaysCardProp = true;
        }
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2015,
         "ptmsgs_portaladminmsgs")));
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding(CommonHTMLStrings.FIVE);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        // Value type
        myRow = GetPropertyTypeRow(nPropType);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsURL, m_asOwner.GetString(2026, "ptmsgs_portaladminmsgs"),
         HTMLCHECKBOX_URL, m_asOwner.GetString(2021, "ptmsgs_portaladminmsgs"),
         PT_PROPERTY_TYPES.PT_PROPTYPE_STRING != nPropType, false);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsCardProp, m_asOwner.GetString(2020,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_CARDPROP, null, bIsAlwaysCardProp,
         false);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsVisible, m_asOwner.GetString(2034,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_VISIBLE, null, false, true);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsReadOnly, m_asOwner.GetString(2269,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_READONLY, null, false, true);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsSearchable, m_asOwner.GetString(2033,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_SEARCHABLE, null, !bIsVisible || bIsEncrypted,
         false);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsMandatory, m_asOwner.GetString(2022,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_MANDATORY, null, !bIsVisible || bIsReadOnly,
         false);
        myTable.AddInnerHTMLElement(myRow);
        myRow = GetCharacteristicsRow(bIsMultivalued, m_asOwner.GetString(2023,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_MULTIVALUED, null, bIsEncrypted,
         false);
        myTable.AddInnerHTMLElement(myRow);
        if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF != nPropType && PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != nPropType)
        {
          myRow = GetPickTypeSelectRow(nPickType);
          myTable.AddInnerHTMLElement(myRow);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "SettingsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(2014, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns a table row for the current property characteristic.
    /// </summary>
    /// <param name="bChecked">True if checkbox is to be checked</param>
    /// <param name="strDescription">Description of characteristic</param>
    /// <param name="strInputName">Input name of characteristic</param>
    /// <param name="bReadOnlyMode">Disabled mode</param>
    /// <returns>Table row for property characteristic</returns>
    /// <throws>HTMLException</throws>
    private HTMLTableRow GetCharacteristicsRow(bool bChecked, String strDescription,
     String strInputName, String strCharacteristicLabel, bool bDisableInput,
     bool bOnClickReposts)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      myCell.SetWidth("150");
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      if (null != strCharacteristicLabel)
      {
        myCell.AddInnerHTMLString(strCharacteristicLabel);
      }
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, strInputName, "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetChecked(bChecked);
      myInput.SetDisabled(bDisableInput);
      if (bOnClickReposts)
      {
        myInput.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + PropRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS + ");");
        }
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      mySpan.AddInnerHTMLString(strDescription);
      return myRow;
    }
    
    /// <summary>
    /// Returns a table row for selecting the pick type of the property
    /// </summary>
    /// <param name="nPickType">Pick type characteristic of property</param>
    /// <returns>Table row for selecting the pick type</returns>
    /// <throws>HTMLException</throws>
    private HTMLTableRow GetPickTypeSelectRow(int nPickType)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLSelect mySelect;
      HTMLOption myOption;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      myCell.SetWidth("150");
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      myCell.AddInnerHTMLString(m_asOwner.GetString(2024, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      // Pick type select
      mySelect = new HTMLSelect(HTMLSELECT_PICKTYPE, "");
      mySelect.SetOnChange(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + PropRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS + ");");
      myCell.AddInnerHTMLElement(mySelect);
      // Initialize pick table type names
      if (null == m_arPickTableTypeNames)
      {
        m_arPickTableTypeNames = new String[]{m_asOwner.GetString(2017, "ptmsgs_portaladminmsgs"),
         m_asOwner.GetString(2016, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2019,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2018, "ptmsgs_portaladminmsgs")};
        }
      // Drop down for pick table types
      for (int i = 0;i < m_arPickTableType.Length;i++)
      {
        myOption = new HTMLOption(XPConvert.ToString(m_arPickTableType[i]));
        mySelect.AddInnerHTMLElement(myOption);
        myOption.SetSelected(m_arPickTableType[i] == nPickType);
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_arPickTableTypeNames[i]);
      }
      return myRow;
    }
    
    /// <summary>
    /// Returns a table row for selecting the type of the property
    /// </summary>
    /// <param name="nPropType">Property type</param>
    /// <returns>Table row for selecting the type of the property</returns>
    /// <throws>HTMLException</throws>
    private HTMLTableRow GetPropertyTypeRow(int nPropType)
    {
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSelect mySelect;
      HTMLOption myOption;
      HTMLSpan mySpan;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      myCell.SetWidth("150");
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      myCell.AddInnerHTMLString(m_asOwner.GetString(2025, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      IPropModelRO iModelRO = (IPropModelRO) m_model;
      bool bCreateMode = (EditorStartControl.EDITOR_START_FLAG_CREATE == iModelRO.GetEditorType());
      if (bCreateMode)
      {
        // Initialize array of property names
        if (null == m_arPropertyNames)
        {
          m_arPropertyNames = new String[]{m_asOwner.GetString(2031, "ptmsgs_portaladminmsgs"),
           m_asOwner.GetString(2029, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2028,
           "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2027, "ptmsgs_portaladminmsgs"),
           m_asOwner.GetString(2030, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2834,
           "ptmsgs_portaladminmsgs")};
        }
        // Show dropdown for selecting property type
        mySelect = new HTMLSelect(HTMLSELECT_PROPTYPE, "");
        mySelect.SetOnChange(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + PropRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS + ");");
        for (int i = 0;i < m_arPropertyTypes.Length;i++)
        {
          myOption = new HTMLOption(XPConvert.ToString(m_arPropertyTypes[i]));
          mySpan = new HTMLSpan();
          myOption.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
          mySpan.AddInnerHTMLString(m_arPropertyNames[i]);
          mySelect.AddInnerHTMLElement(myOption);
          myOption.SetSelected(m_arPropertyTypes[i] == nPropType);
        }
        myCell.AddInnerHTMLElement(mySelect);
        if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == nPropType)
        {
          int nRefClassID = iModelRO.GetReferenceClass();
          // Get the list of all the classes in the system
          ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
          int[] arAllClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs(PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage());
          // Show dropdown for reference class
          mySelect = new HTMLSelect(HTMLSELECT_REFCLASS, "");
          myCell.AddInnerHTMLElement(mySelect);
          for (int i = 0;i < arAllClassIDs.Length;i++)
          {
            myOption = new HTMLOption(XPConvert.ToString(arAllClassIDs[i]));
            mySpan = new HTMLSpan();
            myOption.AddInnerHTMLElement(mySpan);
            mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
            mySpan.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(arAllClassIDs[i],
             strLangID));
            mySelect.AddInnerHTMLElement(myOption);
            myOption.SetSelected(arAllClassIDs[i] == nRefClassID);
          }
        }
      } else
      {
        // show text
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        switch (nPropType){
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
        myCell.AddInnerHTMLString(m_asOwner.GetString(2027, "ptmsgs_portaladminmsgs"));
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
        myCell.AddInnerHTMLString(m_asOwner.GetString(2029, "ptmsgs_portaladminmsgs"));
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
        myCell.AddInnerHTMLString(m_asOwner.GetString(2028, "ptmsgs_portaladminmsgs"));
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
        myCell.AddInnerHTMLString(m_asOwner.GetString(2031, "ptmsgs_portaladminmsgs"));
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:
        myCell.AddInnerHTMLString(m_asOwner.GetString(2834, "ptmsgs_portaladminmsgs"));
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
        {
          int nRefClassID = iModelRO.GetReferenceClass();
          // Get the list of all the classes in the system
          ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
          String strClassName = ptClassTypeDescManager.GetClassTypeLocalizedName(nRefClassID,
           strLangID);
          myCell.AddInnerHTMLString(m_asOwner.GetString(2030, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLString("(");
          myCell.AddInnerHTMLEncodedString(strClassName);
          myCell.AddInnerHTMLString(")");
          break;
        }
        default:
        break;
        }
      }
      return myRow;
    }
  }
}