using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
namespace com.plumtree.portalpages.admin.editors.propertymap
{
  /// <author>OlegS</author>
  public class Property
  {
    // property representation internally stored in the model
    internal XPArrayList attributes;
    internal bool added = false;
    internal bool deleted = false;
    internal bool edited = false;
    internal bool mandatory = false;
    internal bool modified = false;
    internal int id = 0;
    
    /// <summary>
    /// Creates a new Property object.
    /// </summary>
    /// <param name="ptMap"></param>
    /// <param name="id"></param>
    /// <param name="ptSession"></param>
    public Property(IPTPropertyMap ptMap, int id, IPTSession ptSession)
    {
      attributes = new XPArrayList();
      this.id = id;
      // get mapped attributes
      Object[] names = (Object[]) ptMap.GetMappedFieldNames(id);
      for (int i = 0;(names != null) && (i < names.Length);i++)
      {
        Object[] names2 = (Object[]) names[i];
        for (int j = 0;j < names2.Length;j++)
        {
          attributes.Add((String) names2[j]);
        }
      }
      // get mandatory flag
      PTObjectManagerQueryWrapper omqr = new PTObjectManagerQueryWrapper(ptSession.GetProperties());
      omqr.QuerySingleObject(id);
      if (omqr.GetCount() == 1)
      {
        Object v = omqr.GetFields(0, PT_PROPIDS.PT_PROPID_PROP_MANDATORY);
        mandatory = ((v != null) && (XPConvert.ToInteger(v) == 1));
      }
    }
    
    /// <summary>
    /// Creates a new Property object.
    /// </summary>
    /// <param name="ptMap"></param>
    /// <param name="id"></param>
    /// <param name="ptSession"></param>
    /// <param name="added"></param>
    public Property(IPTPropertyMap ptMap, int id, IPTSession ptSession, bool added) : this(ptMap,
     id, ptSession)
    {
      this.added = added;
    }
    
    /// <returns></returns>
    public virtual bool IsAdded()
    {
      return added;
    }
    
    /// <param name="index"></param>
    /// <returns></returns>
    public virtual String GetAttribute(int index)
    {
      return (index < GetNumberOfAttributes()) ? (String) attributes.GetElement(index) : null;
      }
    
    /// <returns></returns>
    public virtual Object[][] GetAttributes()
    {
      int na = GetNumberOfAttributes();
      Object[][] a = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        a[j2c_index] = new Object[na];
      }
      for (int i = 0;i < na;i++)
      {
        a[0][i] = GetAttribute(i);
      }
      return a;
    }
    
    /// <returns></returns>
    public virtual bool IsDeleted()
    {
      return deleted;
    }
    
    /// <returns></returns>
    public virtual int GetId()
    {
      return id;
    }
    
    /// <returns></returns>
    public virtual bool IsInEditMode()
    {
      return edited;
    }
    
    /// <returns></returns>
    public virtual bool IsMandatory()
    {
      return mandatory;
    }
    
    /// <returns></returns>
    public virtual bool IsModified()
    {
      return modified;
    }
    
    /// <returns></returns>
    public virtual int GetNumberOfAttributes()
    {
      return attributes.GetSize();
    }
    
    /// <param name="s"></param>
    public virtual void ReplaceAttributes(String s)
    {
      attributes.Clear();
      for (XPStringTokenizer i = new XPStringTokenizer(s, ",");i.HasMoreTokens();
      )
      {
        String si = i.GetNextToken();
        attributes.Add(XPStringUtility.Trim(si));
      }
      modified = true;
    }
  }
}