using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.propertymap
{
  /// <author>$author$</author>
  public class PropertyMapEditorModel : GbObjEditorModel,IPropertyMapEditorModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.propertymap.PropertyMapEditorModel");
    public const String STR_MVC_CLASS_NAME = "PropertyMapEditor";
    internal static int s_wherePropertiesLive = 0;
    public String m_lastTreeSpaceId = null;
    // set just before SaveMainPage() from PropertyMapEditorRepostControl.SetRepostAction() hook
    public int m_nAction;
    // member variables
    protected int m_nGlobalObjectID;
    protected XPArrayList m_ActionData = null;
    protected XPHashtable m_properties;
    protected bool m_sortAscending = true;
    public PropertyMapEditorModel() : base()
    {
      m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
      m_nGlobalObjectID = PT_GLOBALOBJECTS.PT_GLOBAL_PROPERTYMAP;
      m_properties = new XPHashtable();
    }
    
    /// <summary>
    /// That method is called by the EditorStartControl.
    /// It creates the global object and puts it in m_ptGlobalObject.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      // JF- First we check the user access rights
      if (!m_Session.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      if (!m_Session.GetSessionInfo().CheckCurrentUserIsAdmin())
      {
        return false;
      }
      // Set global object ID with values from QS.
      SetMemberVariablesFromQS(_htFormData);
      try
      {
        // JF- We open the Global Obejct with the ID provided in the QS.
        m_ptGlobalObject = m_Session.OpenGlobalObject(m_nGlobalObjectID, false);
        }
      catch (Exception e)
      {
        log.Error(e, "GbObjEditorModel::CheckEditorAccessAndStart Unable to create Global Object with ID: " + m_nGlobalObjectID + ". The following exception occured: " + e.Message);
        throw new XPException(m_asOwner.GetString(152, "ptmsgs_portalinfrastructure"),
         e);
      }
      StartMigrationHistory();
      DoTaskOnStartEditor(_htFormData);
      return true;
    }
    
    /// <returns></returns>
    public virtual String GetLastTreeSpaceId()
    {
      return m_lastTreeSpaceId;
    }
    // interface IPropertyMapEditorModelRO
    public virtual int GetNumProperties()
    {
      return m_properties.GetSize();
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    public virtual bool IsPropertyAdded(int propId)
    {
      return GetProperty(propId).IsAdded();
    }
    
    /// <param name="propId"></param>
    /// <param name="index"></param>
    /// <returns></returns>
    public virtual String GetPropertyAttribute(int propId, int index)
    {
      return GetProperty(propId).GetAttribute(index);
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    public virtual bool IsPropertyDeleted(int propId)
    {
      return GetProperty(propId).IsDeleted();
    }
    
    /// <returns></returns>
    public virtual Object[] GetPropertyIDs()
    {
      IXPEnumerator iv;
      int sz = 0;
      for (iv = m_properties.GetElements();iv.MoveNext();)
      {
        Property p = (Property) iv.GetCurrent();
        if (!p.IsDeleted())
        {
          sz++;
        }
      }
      Object[] a = new Object[sz];
      int n = 0;
      iv = m_properties.GetElements();
      for (IXPEnumerator ik = m_properties.GetKeys();ik.MoveNext();)
      {
        iv.MoveNext();
        Property p = (Property) iv.GetCurrent();
        if (!p.IsDeleted())
        {
          a[n++] = ik.GetCurrent();
        }
      }
      return a;
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    public virtual bool IsPropertyInEditMode(int propId)
    {
      return GetProperty(propId).IsInEditMode();
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    public virtual bool IsPropertyMandatory(int propId)
    {
      return GetProperty(propId).IsMandatory();
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    public virtual bool IsPropertyModified(int propId)
    {
      return GetProperty(propId).IsModified();
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    public virtual int GetPropertyNumberOfAttributes(int propId)
    {
      return GetProperty(propId).GetNumberOfAttributes();
    }
    
    /// <returns></returns>
    public virtual bool GetSortAscending()
    {
      return m_sortAscending;
    }
    // Strings to localize.
    // logging
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PropertyMapEditorModel();
    }
    
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      IPTPropertyMap ptMap = GetMap();
      Object[] ids = (Object[]) ptMap.GetMappedProperties();
      for (int i = 0;i < ids.Length;i++)
      {
        Object[] ids2 = (Object[]) ids[i];
        for (int j = 0;j < ids2.Length;j++)
        {
          int id = XPConvert.ToInteger(ids2[j]);
          m_properties.PutElement(ids2[j], new Property(ptMap, id, m_Session));
          }
      }
    }
    public override void Finish()
    {
      try
      {
        // propagate changes to the map object
        IPTPropertyMap ptMap = GetMap();
        IXPEnumerator values = m_properties.GetElements();
        while (values.MoveNext())
        {
          Property p = (Property) values.GetCurrent();
          if (p.IsDeleted())
          {
            if (!p.IsAdded())
            {
              ptMap.RemovePropertyFromMap(p.GetId());
            }
          } else
          if (p.IsAdded() || p.IsModified())
          {
            ptMap.SetMappedFieldNames(p.GetId(), p.GetAttributes());
          }
        }
        // Set the migration status to approved if the checkbox was checked
        ((IMigrationHistoryModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).StoreMigrationStatus(PT_CLASSIDS.PT_GLOBALOBJECT_ID,
         m_nGlobalObjectID);
        // store
        IPTServerContext ptSC = (IPTServerContext) ptMap.GetInterfaces("IPTServerContext");
        ptSC.LockObject();
        ptSC.Store();
        ptSC.UnlockObject();
      }
      catch (Exception e)
      {
        log.Error(e, "PropertyMapEditorModel::Finish Unable to store the object. The following exception occured: " + e.Message);
        throw new XPException(m_asOwner.GetString(718, "ptmsgs_portaladminmsgs"),
         e);
      }
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // repost actions
    public virtual void OnAdd()
    {
      for (IXPEnumerator i = m_ActionData.GetEnumerator();i.MoveNext();)
      {
        int id = XPConvert.ToInteger(i.GetCurrent());
        AddProperty(id);
      }
    }
    public virtual void OnDel()
    {
      for (IXPEnumerator i = m_ActionData.GetEnumerator();i.MoveNext();)
      {
        int id = XPConvert.ToInteger(i.GetCurrent());
        DeleteProperty(id);
        if (id == -1)
        {
          // delete all
          break;
        }
      }
    }
    
    /// <param name="propId"></param>
    public virtual void OnEdit(int propId)
    // toggle edit mode
    {
      Property p = (Property) GetProperty(propId);
      p.edited = !p.edited;
    }
    public virtual void OnSort()
    {
      m_sortAscending = !m_sortAscending;
    }
    
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      TraceHelper.Trace("SavePage(" + _sPageName + ")");
      TraceHelper.TraceQueryString(_htFormData);
      int result = RepostControl.PAGE_STATUS_VALID;
      if (_sPageName.Equals(PropertyMapEditorMainDP.STR_MVC_CLASS_NAME))
      {
        result = SaveMainPage(_htFormData);
      } else
      if (_sPageName.Equals(MigrationHistoryPluginDP.STR_MVC_CLASS_NAME))
      {
        result = ((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      return result;
    }
    
    /// <returns></returns>
    public virtual int WherePropertiesLive()
    {
      if (s_wherePropertiesLive == 0)
      {
        s_wherePropertiesLive = PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER;
        PTObjectManagerQueryWrapper omqr = new PTObjectManagerQueryWrapper(m_Session.GetProperties());
        omqr.SimpleQuery();
        int x = 0;
        for (int i = 0;i < omqr.GetCount();i++)
        {
          int id = XPConvert.ToInteger(omqr.GetFields(i, PT_PROPIDS.PT_PROPID_FOLDERID));
          int y = id;
          if (x == 0)
          {
            x = y;
          } else
          {
            if (x != y)
            {
              // more than one folder - use root (later: find "rootmost" common)
              break;
            }
          }
        }
        if (x != 0)
        {
          s_wherePropertiesLive = x;
        }
      }
      return s_wherePropertiesLive;
    }
    
    /// <returns></returns>
    protected virtual int GetAction()
    {
      return m_nAction;
    }
    
    /// <param name="propId"></param>
    /// <returns></returns>
    protected virtual Property GetProperty(int propId)
    {
      return (Property) m_properties.GetElement(propId);
    }
    
    /// <param name="id"></param>
    protected virtual void AddProperty(int id)
    {
      try
      {
        Object key = id;
        if (!m_properties.ContainsKey((key)))
        {
          m_properties.PutElement(key, new Property(GetMap(), id, m_Session,
           true));
        } else
        {
          Property p = (Property) GetProperty(id);
          p.deleted = false;
        }
      }
      catch (Exception e)
      {
        log.Error(e, GetName() + ": Failed to add property - " + e.Message);
        throw new XPException(m_asOwner.GetString(717, "ptmsgs_portaladminmsgs") + 3,
         e);
      }
    }
    protected virtual void ClearActionData()
    {
      if (m_ActionData == null)
      {
        m_ActionData = new XPArrayList();
      } else
      {
        m_ActionData.Clear();
      }
    }
    
    /// <param name="id"></param>
    protected virtual void DeleteProperty(int id)
    {
      try
      {
        if (id == -1)
        {
          for (IXPEnumerator i = m_properties.GetElements();i.MoveNext();
          )
          {
            Property p = (Property) i.GetCurrent();
            /* bug 21012: why should we disable mandatory properties?  User should
             * be able to remove any property... for now... NOTE: We may need to
             * revist this someday.
             */
             
            //					if ((p != null) && !p.IsMandatory())
            if (p != null)
            {
              p.deleted = true;
            }
          }
        } else
        {
          Property p = (Property) m_properties.GetElement(id);
          /* bug 21012: why should we disable mandatory properties?  User should
           * be able to remove any property... for now... NOTE: We may need to
           * revist this someday.
           */
           
          //				if ((p != null) && !p.IsMandatory())
          if (p != null)
          {
            p.deleted = true;
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, GetName() + ": Failed to remove property - " + e.Message);
        throw new XPException(m_asOwner.GetString(717, "ptmsgs_portaladminmsgs") + 4,
         e);
      }
    }
    
    /// <param name="_htFormData"></param>
    protected virtual void ExtractActionData_AttributesFromInputs(XPHashtable _htFormData)
    {
      ClearActionData();
      IXPEnumerator keys = _htFormData.GetKeys();
      IXPEnumerator values = _htFormData.GetElements();
      while (keys.MoveNext())
      {
        values.MoveNext();
        String key = (String) keys.GetCurrent();
        if (XPStringUtility.StartsWith(key, PropertyMapEditorMainView.HTMLTEXT_PROPEDIT))
        {
          //fixing j2c translation error -mgs
          String sHtmlText_PropEdit = PropertyMapEditorMainView.HTMLTEXT_PROPEDIT;
          String s = XPStringUtility.Substring(key, sHtmlText_PropEdit.Length);
          int propId = XPConvert.ToInteger(s);
          Property p = (Property) GetProperty(propId);
          if (p != null)
          {
            String[] val = (String[]) values.GetCurrent();
            p.ReplaceAttributes(val[0]);
          }
        }
      }
    }
    
    /// <param name="o"></param>
    protected virtual void ExtractActionData_PropertiesFromCheckboxes(Object o)
    {
      ClearActionData();
      String[] sa = (String[]) o;
      for (int i = 0;(sa != null) && (i < sa.Length);i++)
      {
        int id;
        try
        {
          id = XPConvert.ToInteger(sa[i]);
        }
        catch (Exception e)
        {
          continue;
        }
        m_ActionData.Add(id);
      }
    }
    protected virtual void ExtractActionData_PropertiesFromTree()
    {
      ClearActionData();
      XPArrayList lst = TreeHelper.GetSelection(m_asOwner, PropertyMapEditorMainView.PROPTREESPACE);
      for (IXPEnumerator i = lst.GetEnumerator();i.MoveNext();)
      {
        int id = XPConvert.ToInteger(i.GetCurrent());
        m_ActionData.Add(id);
      }
    }
    
    /// <param name="o"></param>
    /// <returns></returns>
    protected virtual bool ExtractOneBoolElement(Object o)
    {
      String[] sa = (String[]) o;
      return ((sa == null) || (sa.Length < 1) || (XPStringUtility.CharAt(sa[0],
       0) != '1')) ? false : true;
    }
    
    /// <param name="o"></param>
    /// <returns></returns>
    protected virtual String ExtractOneElement(Object o)
    {
      String[] sa = (String[]) o;
      return ((sa == null) || (sa.Length < 1)) ? null : sa[0];
    }
    // implementation
    protected virtual IPTPropertyMap GetMap()
    {
      return (IPTPropertyMap) GetGlobalObject();
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveMainPage(XPHashtable _htFormData)
    {
      switch (GetAction()){
      default:
      if (!(GetAction() >= 1000))
      {
        break;
      }
      goto case 
      // else fall through - it's edit toggle
      PropertyMapEditorRepostControl.POSTTOSELF_ACTION_FINISH;
      case PropertyMapEditorRepostControl.POSTTOSELF_ACTION_FINISH:
      ExtractActionData_AttributesFromInputs(_htFormData);
      break;
      case PropertyMapEditorRepostControl.ACTION_ADD:
      ExtractActionData_PropertiesFromTree();
      m_lastTreeSpaceId = ExtractOneElement(_htFormData.GetElement(PropertyMapEditorMainView.HTMLHIDDEN_SPACEID));
      break;
      case PropertyMapEditorRepostControl.ACTION_DEL:
      ExtractActionData_PropertiesFromCheckboxes(_htFormData.GetElement(PropertyMapEditorMainView.HTMLCHECKBOX_PROPERTY));
      break;
      case PropertyMapEditorRepostControl.ACTION_SORT:
      ClearActionData();
      break;
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <returns></returns>
    public virtual String makeListOfAlreadyShown()
    {
      String clsid = XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID);
      Object[] ids = GetPropertyIDs();
      XPStringBuilder sb = new XPStringBuilder(100);
      char sep = (char) 0;
      for (int i = 0;i < ids.Length;i++)
      {
        if (sep == 0)
        {
          sep = ',';
        } else
        {
          sb.Append(sep);
        }
        sb.Append(clsid).Append(',').Append(ids[i]);
      }
      sb.Append(',').Append(clsid).Append(',').Append(XPConvert.ToString(PT_INTRINSICS.PT_PROPERTY_DOCUMENTTYPEID));
      return sb.ToString();
    }
  }
}