using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.remoteserver
{
  /// <author>adolfoc</author>
  public class AssocWebServicesView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.remoteserver.AssocWebServicesView");
    public const String STR_MVC_CLASS_NAME = "AssocWebServicesView";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <summary>
    /// A simple boolean for determining wether the next row should be grey or not.
    /// </summary>
    private bool m_bRowColor = true;
    public AssocWebServicesView() : base()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AssocWebServicesView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(720,
         "ptmsgs_portaladminmsgs")));
        // Containing Table
        myTable = RSViewHelper.AddListTable(result);
        //mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_asOwner.GetString(722, "ptmsgs_portaladminmsgs")));
        // The headers:
        String[] arsHeaders = new String[4];
        arsHeaders[0] = "";
        arsHeaders[1] = m_asOwner.GetString(722, "ptmsgs_portaladminmsgs");
        arsHeaders[2] = m_asOwner.GetString(723, "ptmsgs_portaladminmsgs");
        arsHeaders[3] = m_asOwner.GetString(1869, "ptmsgs_portaladminmsgs");
        RSViewHelper.AddSimpleTableHeader(myTable, arsHeaders);
        // rows 2-x begin - The table itself.
        IASQueryResult ptQRAssocWebServices = ((IRemoteServerModelRO) m_model).GetAssocWebServices();
        if ((null == ptQRAssocWebServices) || (ptQRAssocWebServices.GetCount() <= 0))
        {
          myRow = RSViewHelper.AddRow(myTable);
          RSViewHelper.AddTextCell(myRow, CommonHTMLStrings.THREE, m_asOwner.GetString(725,
           "ptmsgs_portaladminmsgs"));
        } else
        {
          DisplayObjectList(myTable, ptQRAssocWebServices);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "AssocWebServicesView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(721, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns a collection of rows and what not that can be added to a table. 
    /// </summary>
    public virtual void DisplayObjectList(HTMLTable parentTable, IASQueryResult ptQRtoDisplay)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      int nCLASSID = PT_CLASSIDS.PT_WEBSERVICE_ID;
      int nMaxCount = ptQRtoDisplay.GetCount();
      RemoteServerModel mParent = (RemoteServerModel) m_asasParent.GetModel(RemoteServerModel.STR_MVC_CLASS_NAME);
      IPTSession ptSession = mParent.GetPTSession();
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      for (int nRowIndex = 0;nRowIndex < nMaxCount;nRowIndex++)
      {
        myRow = RSViewHelper.AddRow(parentTable);
        // Add Class description
        String strProvCLSID = RSViewHelper.GetQRValueAsString(ptQRtoDisplay,
         nRowIndex, PT_PROPIDS.PT_PROPID_GADGET_PROVIDERCLSID);
        // Icon
        myCell = RSViewHelper.AddIconCell(myRow, CommonHTMLStrings.ONE, nCLASSID,
         strProvCLSID, strLangID);
        // Do the alternate color line thingy.
        RSViewHelper.SetRowColor(myCell, m_bRowColor);
        // Name
        int nObjectID = RSViewHelper.GetQRValueAsInt(ptQRtoDisplay, nRowIndex,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        int nFolderID = RSViewHelper.GetQRValueAsInt(ptQRtoDisplay, nRowIndex,
         PT_PROPIDS.PT_PROPID_FOLDERID);
        String strName = RSViewHelper.GetQRValueAsString(ptQRtoDisplay, nRowIndex,
         PT_PROPIDS.PT_PROPID_NAME);
        // Name
        myCell = RSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE, "");
        mySpan = RSViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        mySpan.AddInnerHTMLElement(RSViewHelper.MakeEditObjectLink(nCLASSID,
         nObjectID, strName, m_asOwner));
        mySpan.AddInnerHTMLString(SPACE);
        // AGC- Add the Description on the following line.
        // Description
        Object objValue = ptQRtoDisplay.GetFields(nRowIndex, PT_PROPIDS.PT_PROPID_DESCRIPTION);
        String strDesc = "";
        if (null != objValue)
        {
          strDesc = XPConvert.ToString(objValue);
        }
        if ((null != strDesc) && (strDesc.Length > 0))
        {
          mySpan = RSViewHelper.AddSpanToCell(myCell);
          mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
          mySpan.AddInnerHTMLElement(new HTMLBr());
          mySpan.AddInnerHTMLEncodedString(strDesc);
        }
        // Do the alternate color line thingy.
        RSViewHelper.SetRowColor(myCell, m_bRowColor);
        // Path
        String strPath = RSViewHelper.GetAdminFolderPath(ptSession, nFolderID);
        myCell = RSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        mySpan = RSViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
        mySpan.AddInnerHTMLEncodedString(strPath);
        mySpan.AddInnerHTMLString(SPACE);
        // Do the alternate color line thingy.
        RSViewHelper.SetRowColor(myCell, m_bRowColor);
        // Type
        myCell = RSViewHelper.AddTypeCell(myRow, CommonHTMLStrings.ONE, nCLASSID,
         strProvCLSID, strLangID);
        // Do the alternate color line thingy.
        RSViewHelper.SetRowColor(myCell, m_bRowColor);
        m_bRowColor = !m_bRowColor;
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}