using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.editors.remoteserver
{
  /// <summary>
  /// Activity Space for Remote Server Objects. A Remote Server
  /// is the root object that defines the network location of a remote
  /// server machine. Remote Servers can host Web Services and other
  /// remote  services.
  /// </summary>
  /// <author>adolfoc</author>
  public class RemoteServerEditorAS : ObjEditorAS
  {
    
    /// <summary>
    /// The Object Name of the Remote Server Editor 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RemoteServerEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RemoteServerEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (RemoteServerDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()"></seealso>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(727, "ptmsgs_portaladminmsgs");
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2615, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostAS#GetRepostControlName()"></seealso>
    public override String GetRepostControlName()
    {
      return (RemoteServerRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      // Get and initialize my data model.
      m_strModelName = RemoteServerModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      RegisterPage(new MainDP());
      RegisterPage(new AssociatedObjectsDP());
      // Register Views
      RegisterView(RemoteServerPropsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(AssocWebServicesView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(RemoteServerDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls - I'm assuming I need a Repost control.		
      RegisterControl(RemoteServerRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Default page
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      // Sub menu "Edit Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(729, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AssociatedObjectsDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1879, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      }
    // END Sub menu "Standard Settings"
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (AssociatedObjectsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_RemoteServer_AssociatedObjects");
      } else
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_RemoteServer_MainSettings");
      }
    }
  }
}