using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.remoteserver
{
  /// <author>
  /// adolfoc
  /// This Section represents the remote server
  /// properties section of the Remote Server Editor.
  /// This Section is used in MainDP.
  /// </author>
  public class RemoteServerPropsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.remoteserver.RemoteServerPropsView");
    public const String STR_MVC_CLASS_NAME = "RemoteServerPropsView";
    // HTML Object names.
    // ***CHANGE_HERE*** Declare some constants for each
    //        HTML object you are using in the display method
    // ***COMMENT_1*** You should follow the HTMLElements naming standards:
    //       <select> starts with in_se
    //       <input button> starts with in_bu
    //       <input text> starts with in_tx
    //       <input checkbox> starts with in_cb
    //       <input radio> starts with in_ra
    //       <textarea> starts with in_ta
    public const String HTMLINPUT_BASE_URL = "in_tx_BaseURL";
    public const String HTMLRADIO_BASE_AUTH_TYPE = "in_ra_AuthType";
    public const String HTMLINPUT_LOGIN_NAME = "in_tx_LoginName";
    public const String HTMLINPUT_PASSWORD = "in_pw_Password";
    public const String HTMLINPUT_PASSWORD_CONFIRM = "in_pw_Password2";
    public const String HTMLBUTTON_REPOST = "in_bu_repost";
    public const String HTMLTEXTAREA_PUBLICKEY = "in_ta_publicKey";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RemoteServerPropsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      int COLUMNS = 7;
      try
      {
        IRemoteServerModelRO modelRO = (IRemoteServerModelRO) m_model;
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(734,
         "ptmsgs_portaladminmsgs")));
        // Containing Table
        myTable = RSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
        // 2nd row begins
        myRow = RSViewHelper.AddRow(myTable);
        RSViewHelper.AddSimpleEditBox(myTable, COLUMNS, m_asOwner.GetString(736,
         "ptmsgs_portaladminmsgs"), "", modelRO.GetBaseURL(), HTMLINPUT_BASE_URL);
        // Middle Spacer
        RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
        // Radio Category Label
        RSViewHelper.AddSimpleLabel(myTable, COLUMNS, m_asOwner.GetString(737,
         "ptmsgs_portaladminmsgs"));
        // Base URL Auth Type Radio Selection
        int intCurrentAuthType = modelRO.GetAuthType();
        RSViewHelper.AddSimpleRadio(myTable, -COLUMNS, m_asOwner.GetString(738,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_BASE_AUTH_TYPE, XPConvert.ToString(RemoteServerModel.AUTHTYPE_NONE),
         (RemoteServerModel.AUTHTYPE_NONE == intCurrentAuthType));
        RSViewHelper.AddSimpleRadio(myTable, -COLUMNS, m_asOwner.GetString(739,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_BASE_AUTH_TYPE, XPConvert.ToString(RemoteServerModel.AUTHTYPE_USER),
         (RemoteServerModel.AUTHTYPE_USER == intCurrentAuthType));
        RSViewHelper.AddSimpleRadio(myTable, -COLUMNS, m_asOwner.GetString(740,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_BASE_AUTH_TYPE, XPConvert.ToString(RemoteServerModel.AUTHTYPE_ADMIN),
         (RemoteServerModel.AUTHTYPE_ADMIN == intCurrentAuthType));
        //// Login and Password for Admin Radio selection.
        myRow = RSViewHelper.AddRow(myTable);
        RSViewHelper.AddLeftMargin(myRow, COLUMNS);
        RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        RSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(741,
         "ptmsgs_portaladminmsgs"));
        RSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.ONE, ((IRemoteServerModelRO) m_model).GetLoginName(),
         HTMLINPUT_LOGIN_NAME, 15);
        RSViewHelper.AddRightMargin(myRow, COLUMNS);
        myRow = RSViewHelper.AddRow(myTable);
        RSViewHelper.AddLeftMargin(myRow, COLUMNS);
        RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        RSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(742,
         "ptmsgs_portaladminmsgs"));
        RSViewHelper.AddPasswordBoxCell(myRow, CommonHTMLStrings.ONE, RemoteServerModel.NULL_PASSWORD,
         HTMLINPUT_PASSWORD, 15);
        RSViewHelper.AddRightMargin(myRow, COLUMNS);
        myRow = RSViewHelper.AddRow(myTable);
        RSViewHelper.AddLeftMargin(myRow, COLUMNS);
        RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        RSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(951,
         "ptmsgs_portaladminmsgs"));
        RSViewHelper.AddPasswordBoxCell(myRow, CommonHTMLStrings.ONE, RemoteServerModel.NULL_PASSWORD,
         HTMLINPUT_PASSWORD_CONFIRM, 15);
        RSViewHelper.AddRightMargin(myRow, COLUMNS);
        // spacer -jas
        RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
        // label for public key -jas
        RSViewHelper.AddSimpleLabel(myTable, COLUMNS, m_asOwner.GetString(3054,
         "ptmsgs_portaladminmsgs"));
        // text area for remote server public key -jas
        myRow = RSViewHelper.AddRow(myTable);
        int nMiddleColumns = RSViewHelper.AddLeftMargin(myRow, COLUMNS);
        RSViewHelper.AddTextAreaCell(myRow, XPConvert.ToString(nMiddleColumns),
         modelRO.GetPublicKey(), HTMLTEXTAREA_PUBLICKEY);
        RSViewHelper.AddRightMargin(myRow, COLUMNS);
        // 6th row begins (bottom margin)
        RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
      }
      // 6th row ends
      catch (Exception e)
      {
        log.Error(e, "RemoteServerPropsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(735, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}