using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.savedsearch
{
  /// <author>
  /// joseq
  /// This is the expandable list view that displays collab project names.  It extends ExpListView
  /// so that we can override what the add method does (which is open the project picker from collab)
  /// </author>
  public class CollabExpListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.community.PageListView");
    public const String STR_MVC_CLASS_NAME = "CollabExpListView";
    
    /// <summary>
    /// HTML ELLEMENTS constants 
    /// </summary>
    public const String HTMLINPUT_HI_SELECTEDIDS = "in_hi_selectedIDs";
    
    /// <summary>
    /// javascript function constants 
    /// </summary>
    public const String JAVASCRIPT_CHOOSEPROJECTS = "chooseProject";
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO, int)
     */
     
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public override Object Create()
    {
      return new CollabExpListView();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(com.plumtree.xpshared.htmlelements.HTMLTableRow)"></seealso>
    protected override void AddHTMLToActionBar(HTMLTableRow _row)
    {
      base.AddHTMLToActionBar(_row);
      HTMLTableCell myCell = new HTMLTableCell();
      _row.AddInnerHTMLElement(myCell);
      // Hidden input for selectedIds.
      HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, HTMLINPUT_HI_SELECTEDIDS,
       HTMLINPUT_HI_SELECTEDIDS);
      input.SetValue("");
      myCell.AddInnerHTMLElement(input);
      // Hidden input for selectedNames.
      input = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, "in_hi_selectedNames",
       "in_hi_selectedNames");
      input.SetValue("");
      myCell.AddInnerHTMLElement(input);
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
     
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script = base.DisplayJavascript();
      try
      {
        String gwurl_CollabBase = ((ICollabExpListModelRO) m_model).GetCollabBaseURL(true);
        XPStringBuilder sb = new XPStringBuilder(300);
        sb.Append("function " + JAVASCRIPT_CHOOSEPROJECTS + "()\n");
        sb.Append("{\n");
        sb.Append("   var url = \'" + gwurl_CollabBase + "/do/selector/project?selectorCallback=setProject&selectedIDs=\';\n");
        sb.Append("   window.open(url,\'\'," + "\'width=350,height=350,resizable=1,status=0,toolbar=0,menubar=0,scrollbars=1,location=0\');\n");
        sb.Append("}\n");
        sb.Append("\nfunction setProject(id, name)\n");
        sb.Append("{\n");
        sb.Append("  document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_HI_SELECTEDIDS + ".value = id;\n");
        sb.Append("  document." + AFormDP.HTMLFORM_NAME + "." + "in_hi_selectedNames" + ".value = name;\n");
        sb.Append("  " + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + ");\n");
        sb.Append("}\n");
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "SavSrchSettingsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException("Unable to dispaly Javascript for CollabExpListView",
         e);
      }
      return script;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForAddAction()
     */
     
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      myAddIcon.SetAlt("");
      myAddIcon.SetAlign("absmiddle");
      // Object icon
      myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.AddInnerHTMLString(SPACE);
      myAnchor.SetOnClick(JAVASCRIPT_CHOOSEPROJECTS + "(); return false;");
      myAnchor.AddInnerHTMLElement(myAddIcon);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // get the project name
      String sObjectName = (String) _saData.GetItem(_nRowIndex, CollabExpListModel.EXPLIST_COL_NAME);
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      HTMLImg spacerImage = (HTMLImg) myConstruct.GetHTMLElement();
      spacerImage.SetAlt("---");
      spacerImage.SetWidth(CommonHTMLStrings.FIVE);
      spacerImage.SetBorder("0");
      myCell.AddInnerHTMLElement(spacerImage);
      myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sObjectName));
      return myCell;
    }
  }
}