using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.savedsearch
{
  /// <author>
  /// joseq
  /// The purpose of this class is to simply extend SelectPTObjectView to remove the delete button
  /// and use a different javascript when creating our objects -portlets.  our portlets are 
  /// auto-magically created and added to the list.  Then portlet can then be edited via the edit links.
  /// </author>
  public class PortletSelectView : SelectPTObjectView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portalpages.admin.editors.savedsearch.PortletSelectView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SQPortletSelect";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletSelectView();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
     
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script = base.DisplayJavascript();
      // Create new object
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("AutoCreateNew") + "(varURL)\n");
      sb.Append(" {\n");
      ISavedSearchModelRO sqModel = (ISavedSearchModelRO) m_asOwner.GetModel(SavedSearchModel.STR_MVC_CLASS_NAME);
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == sqModel.GetEditorType())
      {
        sb.Append("    if(confirm(\'").Append(m_asOwner.GetString(3067, ResourceConstants.PORTALADMINMSGS)).Append("\'))\n");
        sb.Append("    {\n");
        sb.Append("        " + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + SavedSearchRepostControl.ACTION_CREATE_PORTLET + ");\n");
        sb.Append("    }\n");
      } else
      {
        sb.Append("    " + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + SavedSearchRepostControl.ACTION_CREATE_PORTLET + ");\n");
        }
      sb.Append(" }\n");
      script.AddInnerHTMLString(sb.ToString());
      return script;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForDeleteAction()
     */
     
    protected override HTMLTableCell GetHTMLForDeleteAction()
    {
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(com.plumtree.xpshared.htmlelements.HTMLTableRow)
     */
     
    protected override void AddHTMLToActionBar(HTMLTableRow _myRow)
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myCreateIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      ISelectPTObjectModelRO myROModel = (ISelectPTObjectModelRO) m_model;
      Object[][] arrCreateNewInfo = (Object[][]) myROModel.GetCreateNewInfo();
      // We are only displaying the create new button if we have rights to create portlets and
      // have all the required info and also if the tree is single select, we only display it 
      // if the list is empty.
      if (((IPortletSelectModelRO) m_model).CanCreatePortlet() && (null != arrCreateNewInfo) && (XPConvert.ToBoolean(myROModel.GetTreeMultiSelect()) || (0 == myROModel.GetReadOnlyItems().GetCount())))
      {
        for (int i = 0;i < arrCreateNewInfo.Length;i++)
        {
          int nClassID = XPConvert.ToInteger(arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_CLASSID]);
          String sEditorASName = (String) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_ASNAME];
          ASURL myURL = ((ISelectPTObjectModelRO) m_model).GetCreateNewURL(nClassID,
           sEditorASName);
          myCell = new HTMLTableCell();
          _myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("25");
          myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
          myCell.SetNoWrap(true);
          // Create new icon
          myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
           true, this.m_asOwner);
          myCreateIcon = (HTMLImg) myConstruct.GetHTMLElement();
          myCreateIcon.SetAlt("");
          myCreateIcon.SetAlign("absmiddle");
          // object icon
          myConstruct = UIConstructFactory.GetConstruct((PTImageType) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_ICON],
           true, this.m_asOwner);
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          myImage.SetAlt("");
          myImage.SetAlign("absmiddle");
          myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          myAnchor.AddInnerHTMLString(SPACE);
          myAnchor.SetOnClick(((ISelectPTObjectModelRO) m_model).GetUniqueString("AutoCreateNew") + "(\'" + myURL.GetURLAsString() + "\'); return false;");
          myAnchor.AddInnerHTMLElement(myCreateIcon);
          myAnchor.AddInnerHTMLElement(myImage);
          mySpan = new HTMLSpan();
          myAnchor.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
          // Create label
          mySpan.AddInnerHTMLString((String) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_LABEL]);
          mySpan.AddInnerHTMLString(SPACE);
          mySpan.AddInnerHTMLString(SPACE);
          myCell.AddInnerHTMLElement(myAnchor);
        }
      }
    }
  }
}