using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.documentlanguage;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.savedsearch
{
  /// <author>MikeS</author>
  public class SavedSearchEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.savedsearch.SavedSearchEditorAS");
    public const String STR_MVC_CLASS_NAME = "SavedSearchEditor";
    public const String SEARCHCONSTRAINTSVIEW = "SrchConstraints";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.savedsearch.SavedSearchEditorAS";
    public const String strCardLanguagePlugInKey = "CardEditorCardLanguagePlugIn";
    
    /// <summary>
    /// Select collab folders storage name 
    /// </summary>
    public const String STR_MVC_SELECT_COLLAB_PROJECT = "SelectCollabProjectEditor";
    
    /// <summary>
    /// Select display properties storage name 
    /// </summary>
    public const String STR_MVC_SELECT_DISPLAY_PROPS = "SelectDisplayPropsEditor";
    
    /// <summary>
    /// Select display properties storage name 
    /// </summary>
    public const String STR_MVC_SELECT_PORTLETS = "SelectPortletsEditor";
    
    /// <summary>
    /// Select display properties storage name 
    /// </summary>
    public const String STR_MVC_SELECT_CONTENT = "SelectContentFilterEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SavedSearchEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (SavedSearchDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from AFormDP can override
    /// if they like.  The method provides a hook into the head so that DP's can add javascript.
    /// Simply override and return and HTMLScript.  Also, it is best to return the results of the
    /// DisplayJavaScript functions from the appropriate views.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()">Override this method to Display javascript from child IViews</seealso>
    /// <returns>HTMLScriptCollection the Javascript from the Child IViews</returns>
    public override HTMLScriptCollection DisplayCommonJavaScript()
    {
      HTMLScriptCollection scripts = base.DisplayCommonJavaScript();
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
      scripts.AddInnerHTMLElement(script);
      return scripts;
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return (GetString(762, "ptmsgs_portaladminmsgs"));
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2616, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SavedSearchRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SavedSearchModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      SavSrchMainDP mainDP = new SavSrchMainDP();
      mainDP.AddToValidationFunction(SavSrchMainDP.UPDATE_ALERT_JS);
      RegisterPage(mainDP);
      // Register Views
      RegisterView(SavSrchFilterView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SnapshotQueryRangeView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SnapshotKDConstraintsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SnapshotADConstraintsView.STR_MVC_CLASS_NAME, myModel);
      //		RegisterView(SearchConstraintsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SavedSearchDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(SavedSearchRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Card Language Plug-In
      RegisterModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myCardLanguagePlugInModel = GetModel(strCardLanguagePlugInKey);
      RegisterView(CardLanguagePlugInView.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey,
       myCardLanguagePlugInModel);
      RegisterControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME,
       strCardLanguagePlugInKey, myCardLanguagePlugInModel);
      RegisterPage(new SavSrchResultDP());
      RegisterView(SavSrchResultsView.STR_MVC_CLASS_NAME, myModel);
      RegisterPage(new ResultFormatDP());
      RegisterView(ResultFormatView.STR_MVC_CLASS_NAME, myModel);
      //****** Register classes for select collab Folder
      RegisterModel(CollabExpListModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_COLLAB_PROJECT);
      IModel myCollabListModel = GetModel(STR_MVC_SELECT_COLLAB_PROJECT);
      RegisterView(CollabExpListView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_COLLAB_PROJECT,
       myCollabListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_COLLAB_PROJECT,
       myCollabListModel);
      //****** Register classes for display property selector
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_PROPS);
      IModel myDisplayPropSelectModel = GetModel(STR_MVC_SELECT_DISPLAY_PROPS);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_PROPS,
       myDisplayPropSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_PROPS,
       myDisplayPropSelectModel);
      //****** Register classes for portlet selector
      RegisterPage(new PortletListDP());
      RegisterModel(PortletSelectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PORTLETS);
      IModel myPortletSelectModel = GetModel(STR_MVC_SELECT_PORTLETS);
      RegisterView(PortletSelectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PORTLETS,
       myPortletSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PORTLETS,
       myPortletSelectModel);
      //****** Register classes for content filter selector
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_CONTENT);
      IModel myContentSelectModel = GetModel(STR_MVC_SELECT_CONTENT);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_CONTENT,
       myContentSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_CONTENT,
       myContentSelectModel);
      // Default page
      SetCurrentPage(SavSrchMainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(764, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SavSrchMainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, ResultFormatDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SavSrchResultDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PortletListDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1882, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 63;
          int iTipId = 64;
          int iSecondaryTipId = 65;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SavSrchMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SavedSearch_MainSettings");
      } else
      if (ResultFormatDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SavedSearch_SavedSearchResultFormat");
      } else
      if (SavSrchResultDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SavedSearch_SavedSearchResultPreview");
      } else
      if (PortletListDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SavedSearch_SnapshotPortletList");
      }
    }
  }
}