using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.savedsearch
{
  /// <author>
  /// joseq
  /// This view displays query constraints for knowledge directory folders & documents
  /// </author>
  public class SnapshotKDConstraintsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.savedsearch.SnapshotKDConstraintsView");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SnapshotKDConstraints";
    
    /// <summary>
    /// html KD folders checkbox 
    /// </summary>
    public const String HTMLINPUT_KD_FOLDERS_CB = "in_cb_KD_Folders";
    
    /// <summary>
    /// html KD documents checkbox 
    /// </summary>
    public const String HTMLINPUT_KD_DOCUMENTS_CB = "in_cb_KD_Documents";
    
    /// <summary>
    /// javascript to check constraints 
    /// </summary>
    public const String JAVASCRIPT_CHECK_CONSTRAINTS = "CheckKDConstraints";
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public override Object Create()
    {
      return new SnapshotKDConstraintsView();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
     */
     
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      /* common html elements */
      HTMLTable mainTable;
      HTMLTableRow mainRow;
      HTMLTableCell mainCell;
      HTMLInput mainInput;
      HTMLSpan mySpan;
      try
      {
        int nKDTypes = ((ISavedSearchModelRO) m_model).GetKDTypes();
        /* view header */
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2991,
         ResourceConstants.PORTALADMINMSGS)));
        /* outermost table */
        mainTable = new HTMLTable();
        result.AddInnerHTMLElement(mainTable);
        mainTable.SetWidth("100%");
        mainTable.SetBorder("0");
        mainTable.SetCellPadding("15");
        mainTable.SetCellSpacing("0");
        mainRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(mainRow);
        mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        /* inner table */
        mainTable = new HTMLTable();
        mainCell.AddInnerHTMLElement(mainTable);
        mainTable.SetWidth("100%");
        mainTable.SetBorder("0");
        mainTable.SetCellPadding("2");
        mainTable.SetCellSpacing("0");
        /* 2 cell rows: section title, checkbox + checkbox title */
        mainRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(mainRow);
        mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        /* section title */
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell.SetNoWrap(true);
        mySpan = new HTMLSpan();
        mainCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2986, ResourceConstants.PORTALADMINMSGS));
        /* KD Folders checkbox */
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        mainInput = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE, HTMLINPUT_KD_FOLDERS_CB,
         m_asOwner.GetString(2987, ResourceConstants.PORTALADMINMSGS));
        mainCell.AddInnerHTMLElement(mainInput);
        mainInput.AddInnerHTMLString(m_asOwner.GetString(2987, ResourceConstants.PORTALADMINMSGS));
        mainInput.SetChecked(0 != (nKDTypes & SavedSearchModel.KDTYPES_FOLDERS));
        mainInput.SetValue(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
        mainInput.SetOnClick(JAVASCRIPT_CHECK_CONSTRAINTS + "(this);");
        /* KD Documents checkbox */
        mainRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(mainRow);
        mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        mainInput = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE, HTMLINPUT_KD_DOCUMENTS_CB,
         m_asOwner.GetString(2988, ResourceConstants.PORTALADMINMSGS));
        mainCell.AddInnerHTMLElement(mainInput);
        mainInput.AddInnerHTMLString(m_asOwner.GetString(2988, ResourceConstants.PORTALADMINMSGS));
        mainInput.SetChecked(0 != (nKDTypes & SavedSearchModel.KDTYPES_DOCUMENTS));
        mainInput.SetValue(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
        mainInput.SetOnClick(JAVASCRIPT_CHECK_CONSTRAINTS + "(this);");
        /* folder list section */
        AddEmptyRowToTable(mainTable, "20");
        /* row+cell+table to hold folder list html */
        mainRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(mainRow);
        mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell.SetColSpan("3");
        mainTable = new HTMLTable();
        mainCell.AddInnerHTMLElement(mainTable);
        mainTable.SetWidth("100%");
        mainTable.SetBorder("0");
        mainTable.SetCellPadding("0");
        mainTable.SetCellSpacing("0");
        mainTable.SetStyleClass(PTStyleClass.CUSTOMAPP_BORDER);
        /* subtitle row */
        mainRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(mainRow);
        mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2989,
         ResourceConstants.PORTALADMINMSGS)));
        /* list row */
        mainRow = new HTMLTableRow();
        mainTable.AddInnerHTMLElement(mainRow);
        mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        mainCell = new HTMLTableCell();
        mainRow.AddInnerHTMLElement(mainCell);
        mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        SavSrchMainDP myMainDP = (SavSrchMainDP) m_asOwner.GetPage(SavSrchMainDP.STR_MVC_CLASS_NAME);
        myMainDP.DisplayFolderList(mainCell, PT_CLASSIDS.PT_CATALOGFOLDER_ID);
        }
      catch (Exception e)
      {
        log.Error(e, "SnapshotKDConstraintsView::Display. Error displaying HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(2990, ResourceConstants.PORTALADMINMSGS),
         e);
      }
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
     
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb;
      // JavaScript to check kd constraints selections
      sb = new XPStringBuilder(300);
      sb.Append("function " + JAVASCRIPT_CHECK_CONSTRAINTS + "(elem)\n");
      sb.Append("{\n");
      sb.Append("   var kdFolder = document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_KD_FOLDERS_CB + ";\n");
      sb.Append("   var kdDocs = document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_KD_DOCUMENTS_CB + ";\n");
      sb.Append("\t  \n");
      sb.Append("   if (!kdFolder.checked && !kdDocs.checked)\n");
      sb.Append("\t  {\n");
      sb.Append("     alert(\"" + m_asOwner.GetString(3136, ResourceConstants.PORTALADMINMSGS) + "\");\n");
      sb.Append("     elem.checked = !elem.checked;\n");
      sb.Append("\t\treturn false;\n");
      sb.Append("\t  }\n");
      sb.Append("\t  \n");
      sb.Append("   return true;\n");
      sb.Append("}\n");
      myScript.AddInnerHTMLString(sb.ToString());
      return myScript;
    }
  }
}