using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This interface is implemented by SubPortalModel.
  /// It contains all the read-only mothods of SubPortalModel.
  /// The Views only have access to the interface.
  /// </summary>
  /// <author>Julie Fournier</author>
  public interface ISubPortalModelRO : IObjEditorModelRO
  {
    
    /// <summary>
    /// Returns the home Community ID.
    /// </summary>
    /// <returns>int</returns>
    int GetHomeCommunityID();
    
    /// <summary>
    /// Returns the home Community Name.
    /// </summary>
    /// <returns>String</returns>
    String GetHomeCommunityName();
    
    /// <summary>
    /// Returns the home Folder ID.
    /// </summary>
    /// <returns>int</returns>
    int GetHomeFolderID();
    
    /// <summary>
    /// Returns the home Folder Name.
    /// </summary>
    /// <returns>String</returns>
    String GetHomeFolderName();
    
    /// <summary>
    /// Return the ASURL object going to the Community Editor as a sub Editor.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor.
    /// If we are going to a new sub Editor, the key can be null and
    /// we will just pass in the default key. If we are going back to an
    /// existing sub Editor, it should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    ASURL GetASURLToCommunity(String _sSubSpaceKey);
    
    /// <summary>
    /// Return the ASURL object going to the Folder Editor as a sub Editor.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor.
    /// If we are going to a new sub Editor, the key can be null and
    /// we will just pass in the default key. If we are going back to an
    /// existing sub Editor, it should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    ASURL GetASURLToFolder(String _sSubSpaceKey);
    
    /// <summary>
    /// Returns the The type of subportal access (MyPages, Communities, Knowledge Directory) supported
    /// by this subportal.  Valid values are any mask combination of PT_SUBPORTAL_ACCESSTYPES
    /// Defaults to communities
    /// </summary>
    /// <returns>int</returns>
    int GetAccessType();
    
    /// <summary>
    /// Returns the subspace ID used by the tree control.  This is used to ensure
    /// that trees that already exist in memory are reused instead of recreated.
    /// </summary>
    /// <returns>String</returns>
    String GetCommSubSpaceID();
    
    /// <summary>
    /// Returns the first page ID based on the page type specifiede.  If the page type is
    /// PT_SUBPORTAL_COMMUNITIES_ACCESS, then the first page ID will be the Community ID that
    /// is set to appear as default.  An analogous result will occur with Directory.  In the
    /// case MyPages, this function will throw an error, because the Users will always be
    /// referred to their main MyPage
    /// </summary>
    /// <returns>int</returns>
    int GetDefaultFirstPage();
    
    /// <summary>
    /// Returns which page the users will see upon logging in to the subportal: a MyPage, a
    /// Community, or a Directory page.  Valid values are enumerated in PT_SUBPORTAL_ACCESS_TYPES.
    /// </summary>
    /// <returns>int</returns>
    int GetDefaultFirstPageType();
    
    /// <summary>
    /// Returns the subspace ID used by the Folder tree control.  This is used to ensure
    /// that trees that already exist in memory are reused instead of recreated.
    /// </summary>
    /// <returns>String</returns>
    String GetFolderSubSpaceID();
    
    /// <summary>
    /// Returns the Footer ID.  If the specified Footer ID doesn't exist, the UI will revert to
    /// the default banner, which cannot be deleted.
    /// </summary>
    /// <returns>int</returns>
    int GetFooterID();
    
    /// <summary>
    /// Returns the header ID.  If the specified Header ID doesn't exist, the UI will revert to
    /// the default banner, which cannot be deleted.
    /// </summary>
    /// <returns>int</returns>
    int GetHeaderID();
    
    /// <summary>
    /// Returns the Stylesheet name.
    /// </summary>
    /// <returns>String</returns>
    String GetStyleSheet();
    
    /// <summary>
    /// Returns the available Stylesheet names.
    /// </summary>
    /// <returns>IXPDictionary</returns>
    IXPDictionary GetStyleSheetOptions();
    
    /// <summary>
    /// Returns true if the subportal has a PTGuestLogin associated to it, 
    /// or false otherwise.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetIsNewGuestLogin();
    
    /// <summary>
    /// Returns the Guest Username.
    /// </summary>
    /// <returns>String</returns>
    String GetGuestUserName();
    
    /// <summary>
    /// Returns the Guest User ID.
    /// </summary>
    /// <returns>int</returns>
    int GetGuestUserID();
    
    /// <summary>
    /// Returns the subspace ID used by the guest tree.  This is used to ensure
    /// that trees that already exist in memory are reused instead of recreated.
    /// </summary>
    /// <returns>String</returns>
    String GetGuestTreeSubSpaceID();
    
    /// <summary>
    /// Returns the Guest Redirect To Login setting.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetGuestRedirectToLogin();
    
    /// <summary>
    /// Returns the Redirect On Logout setting.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetRedirectOnLogout();
    
    /// <summary>
    /// Returns the SSO Vendor setting of the subportal if it exists or the
    /// default SSO Vendor setting from PTConfig.xml if the subportal has 
    /// no SSO Vendor setting set.
    /// </summary>
    /// <returns>int</returns>
    int GetSSOVendor();
    
    /// <summary>
    /// Return the default SSO Vendor setting from PTConfig.xml.
    /// </summary>
    /// <returns>int</returns>
    int GetDefaultSSOVendor();
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    String GetName();
    
    /// <summary>
    /// Returns the Navigation scheme for the subportal.  Valid values are enumerated in
    /// PT_NAVIGATION_SCHEMES.
    /// </summary>
    /// <returns>int</returns>
    int GetNavigationScheme();
    
    /// <summary>
    /// Returns what related resources are accessible to users of this subportal.  The value
    /// is any mask combination of PT_RELATED_RESOURCES_ACCESS_TYPES.
    /// </summary>
    /// <returns>int</returns>
    int GetRelatedResourcesAccessTypes();
    
    /// <returns>whether or not layouts are enabled for this subportal.</returns>
    bool GetLayoutEnabled();
    
    /// <returns>The list of Layout Options selected for this subportal.</returns>
    String GetLayoutOptions();
    
    /// <summary>
    /// Returns whether a newly created folder resides in the unclassified area
    /// of the object admin hierarchy
    /// </summary>
    /// <returns>boolean</returns>
    bool GetFolderUnclassified();
    
    /// <summary>
    /// Return the ASURL object going to the Admin Folder Editor as a sub Editor.
    /// </summary>
    /// <param name="_sSubSpaceKey">
    /// Key for the sub Editor. If we are going to a new
    /// sub Editor, the key can be null and  we will just pass in the
    /// default key. If we are going back to an  existing sub Editor, it
    /// should be the sub Editor key.
    /// </param>
    /// <returns>ASURL</returns>
    ASURL GetASURLToAdminFolder(String _sSubSpaceKey);
  }
}