using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This Section represents a section of the Edit Subportal Layout page
  /// of the SubPortal Editor.
  /// This Section is printed out by SubPortalLayoutDP.
  /// </summary>
  public class LayoutView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.subportal.LayoutView");
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubPortalLayout";
    // HTML Object names.
    //       <select> starts with in_se
    //       <input button> starts with in_bu
    //       <input text> starts with in_tx
    //       <input checkbox> starts with in_cb
    //       <input radio> starts with in_ra
    //       <textarea> starts with in_ta
    
    /// <summary>
    /// Enable Layouts checkbox 
    /// </summary>
    public const String HTMLCHECKBOX_LAYOUTS = "in_cb_layout";
    
    /// <summary>
    /// Layouts Dropdowns 
    /// </summary>
    public const String HTMLSELECT_LAYOUTS = "in_se_layout";
    
    /// <summary>
    /// LayoutOptions Id Prefix 
    /// </summary>
    private const String LAYOUTOPTIONS_PREFIX = "alui_adaptive_page_layouts_";
    
    /// <summary>
    /// Portlet LayoutOptions Id Prefix 
    /// </summary>
    private const String LAYOUTOPTIONS_PORTLET_PREFIX = "alui_adaptive_portlet_layouts_";
    
    /// <summary>
    /// internal data - this shadoes the m_Model data in EditorView, but is the right type. *
    /// </summary>
    private ISubPortalModelRO m_SubPortalModel;
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        // ** Enable Layouts **
        // Adaptive Layout Mode
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(3203,
         "ptmsgs_portaladminmsgs")));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // instruction row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        myCell.SetColSpan("2");
        myCell.SetHeight("25");
        myRow.AddInnerHTMLElement(myCell);
        // Please select if this Experience Definition should enable adaptive layouts for users in this Experience Definition. This setting will not be available if adaptive layouts are disabled in the portal configuration files.
        myCell.AddInnerHTMLString(m_asOwner.GetString(3204, "ptmsgs_portaladminmsgs"));
        // "Enable Layouts" checkbox
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("1%");
        myCell.SetAlign("center");
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_LAYOUTS,
         
        // Enable Adaptive Layout Mode
        m_asOwner.GetString(3205, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue("1");
        myInput.SetChecked(m_SubPortalModel.GetLayoutEnabled());
        // OnChange Event Handler to Enable/Disable Layout Options
        myInput.SetOnChange("toggleLayouts(this.checked);");
        if (!LayoutService.getChooserInstance().GetPageLayoutsEnabled(m_asOwner))
        {
          // This means layouts are disabled globally (in the portal config file),
          // so we shouldn't let users edit anything layout related.
          myInput.SetDisabled(true);
        }
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("99%");
        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
        // Enable Adaptive Layout Mode
        mySpan.AddInnerHTMLString(m_asOwner.GetString(3205, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(mySpan);
      }
      catch (Exception e)
      {
        log.Error(e, "LoginSettingsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(2820, "ptmsgs_portaladminmsgs"),
         e);
      }
      // Getting the Layout Options set previously
      String[] _Options = null;
      if ((m_SubPortalModel.GetLayoutOptions() != null) && (XPStringUtility.Compare(m_SubPortalModel.GetLayoutOptions(),
       "") != 0))
      {
        // TODO CR DLH: This code should be in the model, not the view. (Use SubPortalUtils.Convert... method).
        // Tokenizing the Concatenated String
        XPStringTokenizer st = new XPStringTokenizer(m_SubPortalModel.GetLayoutOptions(),
         ",");
        _Options = new String[st.GetTokenCount()];
        int l = 0;
        while (st.HasMoreTokens())
        {
          _Options[l] = st.GetNextToken();
          l++;
        }
      }
      Object[] modes = Layouts.GetAllLayouts().ToArray();
      ILayoutChooser chooser = LayoutService.getChooserInstance();
      result.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Display Page Layout Chooser
      // Display Page Layout Chooser Header
      result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(3208,
       "ptmsgs_portaladminmsgs")));
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      // Display Page Layout Chooser Description
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("99%");
      mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
      // Description Text
      mySpan.AddInnerHTMLString(m_asOwner.GetString(3209, "ptmsgs_portaladminmsgs"));
      myCell.AddInnerHTMLElement(mySpan);
      // Layout Chooser selection
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      bool bPageLayoutsDisabled = !m_SubPortalModel.GetLayoutEnabled() || !LayoutService.getChooserInstance().GetPageLayoutsEnabled(m_asOwner);
      // A combined index for both page and portlet layouts.
      int index = 0;
      // Add all the page layouts first, then the portlet layouts in a second table.
      for (int i = 0;i < modes.Length;i++)
      {
        Layouts _layout = ((Layouts) modes[i]);
        if (_layout.GetLayoutType() == Layouts.LAYOUT_TYPE.PAGE_TYPE)
        {
          AddLayoutSelector(_layout, index, _Options, bPageLayoutsDisabled,
           LAYOUTOPTIONS_PREFIX, myTable, chooser);
          index++;
        }
      }
      result.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Display Portlet Layout Chooser
      // Display Portlet Layout Chooser Header
      result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(3222,
       "ptmsgs_portaladminmsgs")));
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      // Display Portlet Layout Chooser Description
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("99%");
      mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
      // Description Text
      mySpan.AddInnerHTMLString(m_asOwner.GetString(3223, "ptmsgs_portaladminmsgs"));
      myCell.AddInnerHTMLElement(mySpan);
      // Layout Chooser selection
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      bool bPortletLayoutsDisabled = !LayoutService.getChooserInstance().GetPortletLayoutsEnabled(m_asOwner);
      // Add the portlet layout(s)
      for (int i = 0;i < modes.Length;i++)
      {
        Layouts _layout = ((Layouts) modes[i]);
        if (_layout.GetLayoutType() == Layouts.LAYOUT_TYPE.PORTLET_TYPE)
        {
          // index is a combined index for both page and portlet layouts.
          AddLayoutSelector(_layout, index, _Options, bPortletLayoutsDisabled,
           LAYOUTOPTIONS_PORTLET_PREFIX, myTable, chooser);
          index++;
        }
      }
      return result;
    }
    
    /// <summary>
    /// This helper method adds a layout title and dropdown to an HTML table.
    /// </summary>
    /// <param name="_layout">The layout to add.</param>
    /// <param name="_index">The index in the table for the layout.</param>
    /// <param name="_strOptions">The options string</param>
    /// <param name="_myTable">The table to add the dropdown to.</param>
    /// <param name="_chooser">The layout chooser.</param>
    public virtual void AddLayoutSelector(Layouts _layout, int _index, String[] _strOptions,
     bool _bDisabled, String _strPrefix, HTMLTable _myTable, ILayoutChooser _chooser)
    {
      IPTQueryResult _wsList = _chooser.GetAvailableWebServices(_layout, m_asOwner);
      if (_wsList.RowCount() > 0)
      {
        HTMLTableRow myRow = new HTMLTableRow();
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        _myTable.AddInnerHTMLElement(myRow);
        HTMLTableCell myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell.SetWidth("200");
        myRow.AddInnerHTMLElement(myCell);
        int _id = _layout.GetExternalizedStringID();
        // TODO: CR DLH: This is incorrect.  ": " should be part of the i18n string, as it
        // may differ from language to language.
        myCell.AddInnerHTMLString(m_asOwner.GetString(_id, "ptmsgs_portaladminmsgs") + ": ");
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        HTMLSelect layoutSelect = new HTMLSelect(HTMLSELECT_LAYOUTS, _strPrefix + _index);
        layoutSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        layoutSelect.SetDisabled(_bDisabled);
        myCell.AddInnerHTMLElement(layoutSelect);
        HTMLOption styleOption = null;
        if (_layout.GetLayoutType() == Layouts.LAYOUT_TYPE.PORTLET_TYPE)
        {
          // Portlet layouts have a special disabled mode (-1) that is on by default.
          // NOTE: Upgraded XDs will not have this option, so this will be selected by
          // default since it is the first item in the dropdown.
          String _optVal = _layout.GetWebServiceFolderID() + ":-1";
          styleOption = new HTMLOption(_optVal);
          // "Override Disabled"
          styleOption.AddInnerHTMLString(m_asOwner.GetString(3224, "ptmsgs_portaladminmsgs"));
          layoutSelect.AddInnerHTMLElement(styleOption);
        }
        bool bOptionSelected = false;
        HTMLOption defaultOption = null;
        for (int j = 0;j < _wsList.RowCount();j++)
        {
          String _optVal = _layout.GetWebServiceFolderID() + ":" + _wsList.ItemAsInt(j,
           PT_PROPIDS.PT_PROPID_OBJECTID);
          styleOption = new HTMLOption(_optVal);
          // Setting Option Selected if it was previously selected
          if (_strOptions != null)
          {
            for (int k = 0;k < _strOptions.Length;k++)
            {
              if (_strOptions[k].Equals(_optVal))
              {
                styleOption.SetSelected(true);
                bOptionSelected = true;
                break;
              }
            }
          }
          styleOption.AddInnerHTMLString(_wsList.ItemAsString(j, PT_PROPIDS.PT_PROPID_NAME));
          layoutSelect.AddInnerHTMLElement(styleOption);
          // DCA - save the default option for later use
          if (_layout.GetDefaultWebServiceID() == _wsList.ItemAsInt(j, PT_PROPIDS.PT_PROPID_OBJECTID))
          {
            defaultOption = styleOption;
          }
        }
        // DCA - if nothing was selected, select the default
        if (!bOptionSelected && _layout.GetLayoutType() != Layouts.LAYOUT_TYPE.PORTLET_TYPE)
        {
          defaultOption.SetSelected(true);
        }
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LayoutView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_SubPortalModel = (ISubPortalModelRO) model;
    }
    
    /// <summary>
    /// Returns Java Script for that Section.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      // This method enable/disables the page layouts, but not the portlet layouts.
      XPStringBuilder _jsMethod = new XPStringBuilder();
      _jsMethod.Append("function toggleLayouts(val) { \n");
      _jsMethod.Append("var arrLayouts = document.getElementsByTagName(\'SELECT\'); \n");
      _jsMethod.Append("for (i =0 ; i < arrLayouts.length ; i++) { \n");
      _jsMethod.Append("if(arrLayouts[i].id.match(\'" + LAYOUTOPTIONS_PREFIX + "\') != null ) \n");
      _jsMethod.Append("{ \n");
      _jsMethod.Append("arrLayouts[i].disabled = !val; \n");
      _jsMethod.Append("} \n");
      _jsMethod.Append("}\n ");
      _jsMethod.Append("\n } \n");
      myScript.AddInnerHTMLString(_jsMethod.ToString());
      return myScript;
    }
  }
}