using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This Section represents a section of the Choose Navigation Design page
  /// of the SubPortal Editor.
  /// This Section is printed out by SubPortalNavDP.
  /// </summary>
  /// <author>JohnH</author>
  public class NavigationView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.subportal.NavigationView");
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubPortalNavigation";
    // HTML Object names.
    //       <select> starts with in_se
    //       <input button> starts with in_bu
    //       <input text> starts with in_tx
    //       <input checkbox> starts with in_cb
    //       <input radio> starts with in_ra
    //       <textarea> starts with in_ta
    public const String HTMLRADIO_NAVIGATION = "in_ra_Navigation";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new NavigationView();
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display NavigationView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(892,
         "ptmsgs_portaladminmsgs")));
        String sLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // 1st Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
        myCell = new HTMLTableCell();
        //myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetColSpan("2");
        myCell.SetHeight("25");
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLString(m_asOwner.GetString(890, ResourceConstants.PORTALADMINMSGS));
        myCell.AddInnerHTMLElement(new HTMLP());
        // Warning about layout mode
        myCell.AddInnerHTMLString(m_asOwner.GetString(3206, ResourceConstants.PORTALADMINMSGS));
        //1st row end
        //2nd row begin
        XPArrayList navTypes = NavManager.INSTANCE.GetNavTypesAsSortedArray();
        //int k = 0;
        int index = 0;
        for (index = 0;index < navTypes.GetSize();++index)
        {
          INavTypes thisNav = (INavTypes) navTypes.GetElement(index);
          //row begin
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          //if ((k % 2) == 1)
          //{
          myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
          //}
          //else
          //{
          //	myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
          //}
          //++k;
          myCell = new HTMLTableCell();
          myCell.SetWidth("1%");
          myCell.SetAlign("center");
          myRow.AddInnerHTMLElement(myCell);
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_NAVIGATION,
           XPConvert.ToString(thisNav.GetName(sLang)));
          myInput.SetValue(XPConvert.ToString(thisNav.GetID()));
          if (((ISubPortalModelRO) m_model).GetNavigationScheme() == thisNav.GetID())
          {
            myInput.SetChecked(true);
          }
          myCell.AddInnerHTMLElement(myInput);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("99%");
          mySpan = new HTMLSpan();
          mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
          mySpan.AddInnerHTMLString(thisNav.GetName(sLang));
          myCell.AddInnerHTMLElement(mySpan);
          myCell.AddInnerHTMLElement(new HTMLBr());
          mySpan = new HTMLSpan();
          mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
          mySpan.AddInnerHTMLString(thisNav.GetScope(sLang));
          myCell.AddInnerHTMLElement(mySpan);
        }
        //Row End
        myComment = new HTMLComment("End: Display NavigationView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        // ***CHANGE_HERE*** Update the error messages (log and exception).
        log.Error(e, "NavigationView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(897, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    // ***CHANGE_HERE*** Update the class name bellow.
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}