using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.adminfolder;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This class overrides the view class for SelectPTObjectView to accomodate
  /// selecting an admin folder parent before executing the create action on the
  /// toolbar.
  /// </summary>
  /// <author>John Hogan</author>
  public class SelectAdminFolderView : SelectPTObjectView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.subportal.SelectAdminFolderView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SelectAdminFolderView";
    
    /// <summary>
    /// The select existing admin folder tree subspace 
    /// </summary>
    public const String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";
    
    /// <summary>
    /// The admin folder parent selection tree subspace 
    /// </summary>
    public const String HTMLHIDDEN_ADMINFOLDER_SPACE = "in_hi_AdminFolderSpaceID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SelectAdminFolderView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      // The URL to open a new tree for SELECTING a folder
      ASURL myNewTree = new ASURL(m_asOwner);
      myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myNewTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(SelectPTObjectModel.SUBSPACE_KEY_SELECTTREE));
      myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
      myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, ((ISelectPTObjectModelRO) m_model).GetTreeMultiSelect());
      myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetTreeLeafType()));
      myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       ((ISelectPTObjectModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID));
      myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, ((ISelectPTObjectModelRO) m_model).GetUniqueString("OnReturnFromTree"));
      myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       ((ISelectPTObjectModelRO) m_model).GetObjectClassIDs());
      myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, ((ISelectPTObjectModelRO) m_model).GetSelectedItems());
      myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetAccessLevel()));
      if (null != ((ISelectPTObjectModelRO) m_model).GetTreeTitle())
      {
        myNewTree.AddControlArgument(StartTreeControl.TITLE, ((ISelectPTObjectModelRO) m_model).GetTreeTitle());
        }
      if (null != ((ISelectPTObjectModelRO) m_model).GetTreeSubTitle())
      {
        myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, ((ISelectPTObjectModelRO) m_model).GetTreeSubTitle());
        }
      if (!("").Equals(((ISelectPTObjectModelRO) m_model).GetHiddenObjects()))
      {
        myNewTree.AddControlArgument(StartTreeControl.HIDDEN_ITEMS, ((ISelectPTObjectModelRO) m_model).GetHiddenObjects());
        }
      if (!("").Equals(((ISelectPTObjectModelRO) m_model).GetTreeQueryFilter()))
      {
        myNewTree.AddControlArgument(StartTreeControl.QUERY_FILTER, ((ISelectPTObjectModelRO) m_model).GetTreeQueryFilter());
        }
      if (0 < ((ISelectPTObjectModelRO) m_model).GetCommunityFolderID())
      {
        myNewTree.AddControlArgument(StartTreeControl.COMMUNITY_MODE, AObjectTreeModel.THISCOMMUNITY);
        myNewTree.AddControlArgument(StartTreeControl.COMMUNITY_FOLDER_ID,
         ((ISelectPTObjectModelRO) m_model).GetCommunityFolderID());
      }
      // The url to open a previously opened server user tree
      // This needs to have the SpaceID added to it.
      ASURL myOldTree = new ASURL(m_asOwner);
      myOldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myOldTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
      myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, ((ISelectPTObjectModelRO) m_model).GetSelectedItems());
      myOldTree.IsSubSpace();
      // The URL to display the tree for selecting a parent folder we'll use in CREATING an admin folder
      ASURL createFolderTree = new ASURL(m_asOwner);
      createFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      createFolderTree.SetSubSpaceKey(SubPortalAS.ADMINFOLDERTREE_SUBSPACE);
      createFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      createFolderTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      createFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      createFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFCOMPOSITESELECT));
      createFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, 
      //Client side submit mode
      XPConvert.ToString(TreeConstants.N_JAVASCRIPTSUBMIT));
      createFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
       AFormDP.HTMLFORM_NAME);
      createFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       ((ISelectPTObjectModelRO) m_model).GetUniqueString(HTMLHIDDEN_ADMINFOLDER_SPACE));
      createFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       
      // this is what the tree will call on finish
      "CreateAdminFolder");
      createFolderTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1889,
       "ptmsgs_portaladminmsgs"));
      createFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
       m_asOwner.GetString(1888, "ptmsgs_portaladminmsgs"));
      createFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        // Open admin folder tree function for choosing a parent
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append("ChooseParent").Append("()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(createFolderTree.GetURLAsString()).Append("\', \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "SelectAdminFolderView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException(m_asOwner.GetString(888, "ptmsgs_portaladminmsgs"),
         e);
      }
      try
      {
        // Open Tree function
        XPStringBuilder sb = new XPStringBuilder(200);
        sb.Append("function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("OpenTree") + "(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\', \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(myOldTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // On return from Tree function
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("OnReturnFromTree") + "()");
        sb.Append(" {");
        sb.Append(" \tpostToSelf(\'" + ((ISelectPTObjectModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "\');");
        sb.Append(" }");
        myScript.AddInnerHTMLString(sb.ToString());
        //Create new admin folder
        // JF- The helper method below will return the right URL. We don't need to figure out
        // if it's a cached sub Editor or no.
        ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(AdminFolderEditorAS.STR_MVC_CLASS_NAME,
         AdminFolderEditorAS.STR_MVC_CLASS_NAME, EditorStartControl.EDITOR_START_FLAG_CREATE,
         ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));
        sb = new XPStringBuilder(200);
        sb.Append("function CreateAdminFolder(myArray)\n");
        sb.Append("{\n");
        sb.Append("  if ((myArray) && (myArray.length > 0)) {\n");
        sb.Append("    window.open(\'").Append(myPopUpURL.GetURLAsString()).Append(LinkConstants.AMPERSAND).Append(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID).Append(", \'PopUpCreateMode\', \'location=no,menubar=no,height=600,width=800\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // Edit object
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((ISelectPTObjectModelRO) m_model).GetUniqueString("EditObject") + "(varURL,varIndex)");
        sb.Append(" {");
        sb.Append("    window.open(varURL,\'PopUpEditMode\' + varIndex,\'location=no,menubar=no,scrollbars,height=600,width=800\');\n");
        sb.Append(" }");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "SelectPTObjectView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <summary>
    /// Empty method that sub classes can averride to add
    /// actions to the action bar (like a create object action).
    /// </summary>
    /// <param name="_myRow">Action bar row object.</param>
    /// <throws>Exception</throws>
    protected override void AddHTMLToActionBar(HTMLTableRow _myRow)
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myCreateIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      ISelectPTObjectModelRO myROModel = (ISelectPTObjectModelRO) m_model;
      Object[][] arrCreateNewInfo = (Object[][]) myROModel.GetCreateNewInfo();
      // JF- We are only displaying the create new buttons if we have all the required info
      // and also if the tree is single select, we only display it if the list is empty.
      if ((null != arrCreateNewInfo) && (XPConvert.ToBoolean(myROModel.GetTreeMultiSelect()) || (0 == myROModel.GetReadOnlyItems().GetCount())))
      {
        for (int i = 0;i < arrCreateNewInfo.Length;i++)
        {
          myCell = new HTMLTableCell();
          _myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("25");
          myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(SPACE);
          // Create new icon
          myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
           true, this.m_asOwner);
          myCreateIcon = (HTMLImg) myConstruct.GetHTMLElement();
          myCreateIcon.SetAlt("");
          myCreateIcon.SetAlign("absmiddle");
          // Create new icon
          myConstruct = UIConstructFactory.GetConstruct((PTImageType) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_ICON],
           true, this.m_asOwner);
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          myImage.SetAlt("");
          myImage.SetAlign("absmiddle");
          myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick("ChooseParent(); return false;");
          myAnchor.AddInnerHTMLElement(myCreateIcon);
          myAnchor.AddInnerHTMLElement(myImage);
          mySpan = new HTMLSpan();
          myAnchor.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
          // Create label
          mySpan.AddInnerHTMLString((String) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_LABEL]);
          mySpan.AddInnerHTMLString(SPACE);
          mySpan.AddInnerHTMLString(SPACE);
          myCell.AddInnerHTMLElement(myAnchor);
          myCell.AddInnerHTMLString(SPACE);
          // hidden input with the tree space ID
          myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ((ISelectPTObjectModelRO) m_model).GetUniqueString(HTMLHIDDEN_ADMINFOLDER_SPACE),
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetValue(SubPortalAS.ADMINFOLDERTREE_SUBSPACE);
        }
      }
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      if (((ISelectPTObjectModelRO) m_model).GetEnableMoveRowActions())
      {
        result.AddInnerHTMLElement(base.GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}