using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,  and
  /// Controls created for the SubPortal Editor. This class can also be used to
  /// get any of those objects back with  the class name.
  /// </summary>
  /// <author>JohnH</author>
  public class SubPortalAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.subportal.SubPortalAS");
    
    /// <summary>
    /// Unique identifier for this activity space class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubPortalEditor";
    
    /// <summary>
    /// Unique identifier for the Header SelectPTObject plug-in 
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_SELECT_HEADER = "SelectPTObjectHeader";
    
    /// <summary>
    /// Unique identifier for the Footer SelectPTObject plug-in 
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_SELECT_FOOTER = "SelectPTObjectFooter";
    
    /// <summary>
    /// Unique identifier for the Folder SelectPTObject plug-in 
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_SELECT_FOLDER = "SelectPTObjectFolder";
    //public static final String STR_MVC_SITEMAP_PLUGIN = "SiteMapFolderPlugIn";
    
    /// <summary>
    /// sub-space key for Communities tree 
    /// </summary>
    public const String strCOMMTREE_SUBSPACE = "SubPortalCommTreeSubSpace";
    
    /// <summary>
    /// sub-space key for Folders tree 
    /// </summary>
    public const String strFOLDERTREE_SUBSPACE = "SubPortalFolderTreeSubSpace";
    
    /// <summary>
    /// sub-space key for the Admin folder tree 
    /// </summary>
    public const String ADMINFOLDERTREE_SUBSPACE = "SubPortalAdminFolderSubSpace";
    private static String sClassName = "com.plumtree.portalpages.admin.editors.subportal.SubPortalAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SubPortalAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        //Return the main title of the Editor in create mode.
        return (GetString(899, "ptmsgs_portaladminmsgs"));
      } else
      {
        //Return the main title of the Editor in edit mode.
        return (XPResourceManager.FormatMessage(GetString(2620, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (SubPortalDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <returns></returns>
    public override String GetRepostControlName()
    {
      return (SubPortalRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SubPortalModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(SubPortalModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      // Features DP
      RegisterPage(new SubPortalFeaturesDP());
      // Banner DP
      RegisterPage(new SubPortalBannerDP());
      //Navigation DP
      SubPortalNavDP navDP = new SubPortalNavDP();
      RegisterPage(navDP);
      navDP.AddToValidationFunction(SiteMapFolderPlugInView.JAVASCRIPT_CHECKNAVLINKNAME);
      // Login Settings DP
      SubPortalLoginDP loginDP = new SubPortalLoginDP();
      RegisterPage(loginDP);
      // add validation function for guest user selection
      loginDP.AddToValidationFunction("CheckGuest");
      // Layout DP
      RegisterPage(new SubPortalLayoutDP());
      // Register Views
      RegisterView(FeaturesView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(NavigationView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SubPortalDependenciesView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(StylesheetView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(LoginSettingsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(LayoutView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(SubPortalRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      SetCurrentPage(SubPortalFeaturesDP.STR_MVC_CLASS_NAME);
      // Register plug-in sections
      // Sitemap link plug-in
      RegisterModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      IModel mySiteMapPluginModel = GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      //Register the display page
      RegisterPage(new SiteMapCreateWebLinkDP());
      //The Site map folder views
      RegisterView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
      RegisterView(SiteMapCreateWebLinkView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
      //The site map folder control
      RegisterControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
      //SelectPTObject Plug-Ins
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_HEADER);
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOOTER);
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOLDER);
      IModel mySelectPTHeaderModel = GetModel(STR_MVC_STORAGE_NAME_SELECT_HEADER);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_HEADER,
       mySelectPTHeaderModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_HEADER,
       mySelectPTHeaderModel);
      IModel mySelectPTFooterModel = GetModel(STR_MVC_STORAGE_NAME_SELECT_FOOTER);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOOTER,
       mySelectPTFooterModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOOTER,
       mySelectPTFooterModel);
      IModel mySelectPTObjectModel = GetModel(STR_MVC_STORAGE_NAME_SELECT_FOLDER);
      RegisterView(SelectAdminFolderView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOLDER,
       mySelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOLDER,
       mySelectPTObjectModel);
      //Sets left nav menu
      // Set the left nav menu using StartNewSubMenu and AddLinkToSubMenu.
      // BEGIN Sub menu "Edit Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(901, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalFeaturesDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalBannerDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalNavDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalLoginDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalLayoutDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Edit Settings"
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1890, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 66;
          int iTipId = 67;
          int iSecondaryTipId = 68;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()">Sets the help links for the subportal editor</seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SubPortalFeaturesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Subportal_MainSettings");
      } else
      if (SubPortalBannerDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Subportal_HeaderandFooter");
      } else
      if (SubPortalNavDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Subportal_NavigationOptions");
      } else
      if (SiteMapCreateWebLinkDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SelectLinks_WebPages");
      } else
      if (SubPortalLoginDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Subportal_LoginSettings");
      } else
      if (SubPortalLayoutDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Subportal_Layout");
      }
    }
  }
}