using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the Banner & Footer page of the SubPortal Editor.
  /// </summary>
  /// <author>JohnH</author>
  public class SubPortalBannerDP : EditorDP
  {
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubPortalBanner";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(902, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1652, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the Choose Header & Filter page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // Stylesheet drop-down selector
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(StylesheetView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Header & footer selectors
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER).DisplayJavascript());
      return myScripts;
    }
  }
}
// ***CHANGE_HERE*** This method is optional. 
//      You can implement it if you want to display some HTML in the head.
//		If that method exists the framework will automatically call it
//      and the HTML returned will get displayed in the head tag.
//      WARNING: META and LINK tags only should be returned.
/*public HTMLElementCollection DisplayHTMLinHEAD() throws HTMLException
 {
 HTMLElementCollection myHTMLinHead = new HTMLElementCollection();
 // ***CHANGE_HERE*** Add your HTML to the myHTMLinHead HTML collection.
 
 return(myHTMLinHead);
 }*/
 
// ***CHANGE_HERE*** This method is optional. 
//      You can implement it if you want to display some HTML after 
//      the BODY tag and before the FORM tag.
//		If that method exists, the framework will automatically call it.
//      E.g.: DIV tags should go in that method.
/*public HTMLElementCollection DisplayHTMLBeforeForm() throws HTMLException
 {
 HTMLElementCollection myHTMLBeforeForm = new HTMLElementCollection();
 // ***CHANGE_HERE*** Add your HTML to the myHTMLBeforeForm HTML collection.
 
 return(myHTMLBeforeForm);
 }*/
 
