using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This is class is used to edit the guest user and login settings
  /// of the SubPortal.
  /// </summary>
  /// <author>William Adjie-Winoto</author>
  public class SubPortalLoginDP : EditorDP
  {
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubPortalLogin";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(2803, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2807, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the Choose Header & Filter page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // Stylesheet drop-down selector
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LoginSettingsView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(LoginSettingsView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
  }
}