using System;
// UI Imports
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.subportal
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to the SubPortal Editor (other than
  /// "change page", "finish" and "cancel" actions).
  /// </summary>
  /// <author>JohnH</author>
  public class SubPortalRepostControl : ObjEditorRepostControl
  {
    
    /// <summary>
    /// The unique identifier for this class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SubPortalRepost";
    
    /// <summary>
    /// The submit action for the Community picking tree 
    /// </summary>
    public const int POSTTOSELF_ACTION_COMMTREESUBMIT = 40;
    
    /// <summary>
    /// The submit action for the folder picking tree 
    /// </summary>
    public const int POSTTOSELF_ACTION_FOLDERTREESUBMIT = 41;
    
    /// <summary>
    /// The submit action for the guest picking tree 
    /// </summary>
    public const int POSTTOSELF_ACTION_GUESTTREESUBMIT = 42;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SubPortalRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      // You need to call the PerformRepostAction on the plug-in control
      ((SiteMapFolderPlugInControl) m_asOwner.GetControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
       m_htFormData);
      // You need to call the PerformRepostAction on the select ptHeader control
      ((ExpListControl) m_asOwner.GetControl(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER)).PerformRepostAction(_nAction,
       m_htFormData);
      // You need to call the PerformRepostAction on the select ptFooter control
      ((ExpListControl) m_asOwner.GetControl(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER)).PerformRepostAction(_nAction,
       m_htFormData);
      //Now for the folder picker
      ((ExpListControl) m_asOwner.GetControl(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).PerformRepostAction(_nAction,
       m_htFormData);
      switch (_nAction){
      case POSTTOSELF_ACTION_COMMTREESUBMIT:
      ((SubPortalModel) m_model).RefreshItemFromTree(0);
      break;
      case POSTTOSELF_ACTION_FOLDERTREESUBMIT:
      ((SubPortalModel) m_model).RefreshItemFromTree(1);
      break;
      case POSTTOSELF_ACTION_GUESTTREESUBMIT:
      ((SubPortalModel) m_model).RefreshSelectedGuestFromTree();
      break;
      case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_SAVELINKS:
      ClosePopUpDP closeWebLinkDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      HTMLScript scriptWebLink = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      scriptWebLink.AddInnerHTMLString("window.opener.document." + AFormDP.HTMLFORM_NAME + ".submit();\n");
      closeWebLinkDP.SetScript(scriptWebLink);
      closeWebLinkDP.SetToClose(true);
      Redirect redirect = new Redirect();
      redirect.SetLinkGetCachedSpace(m_asOwner);
      redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      SetRedirect(redirect);
      break;
      }
    }
  }
}