using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.user
{
  /// <summary>
  /// This class implements the mobile device authentication view for the user editor
  /// </summary>
  /// <author>SudhaS</author>
  public class DevicesView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.user.DevicesView");
    
    /// <summary>
    /// The unique name for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UsrDevices";
    
    /// <summary>
    /// The user name input box 
    /// </summary>
    public const String HTMLINPUT_USR_NAME = "in_tx_CreateUsrName";
    
    /// <summary>
    /// The password input box 
    /// </summary>
    public const String HTMLINPUT_PSSWRD = "in_pw_CreatePassword";
    
    /// <summary>
    /// The confirm password input box 
    /// </summary>
    public const String HTMLINPUT_CNFRM_PSSWRD = "in_pw_ConfirmPassword";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DevicesView();
    }
    
    /// <summary>
    /// Displays the HTML for the class
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(940,
         "ptmsgs_portaladminmsgs")));
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("20%");
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLString(m_asOwner.GetString(942, "ptmsgs_portaladminmsgs"));
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_USR_NAME, "This is an input");
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetSize(20);
        myInput.SetValue(((IUserModelRO) m_model).GetUserMobileName());
        myCell.AddInnerHTMLElement(myInput);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("20%");
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLString(m_asOwner.GetString(943, "ptmsgs_portaladminmsgs"));
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.PASSWORD, HTMLINPUT_PSSWRD,
         "Password");
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetSize(20);
        myInput.SetValue(((IUserModelRO) m_model).GetUserMobilePsswrd());
        myCell.AddInnerHTMLElement(myInput);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("20%");
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLString(m_asOwner.GetString(944, "ptmsgs_portaladminmsgs"));
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myInput = new HTMLInput(HTMLInputTypes.PASSWORD, HTMLINPUT_CNFRM_PSSWRD,
         "Password");
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetSize(20);
        myInput.SetValue(((IUserModelRO) m_model).GetUserMobilePsswrd());
        myCell.AddInnerHTMLElement(myInput);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      }
      catch (Exception e)
      {
        log.Error(e, "DevicesView::Display The following error occured when trying to display the HTML: ");
        throw new XPException(m_asOwner.GetString(941, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Displays the javascript for the class
    /// </summary>
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript;
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        myScript = new HTMLScript("text/javaScript");
        // The JavaScript bellow checks if the Property Name is empty.
        sb.Append("function CheckNames()\n");
        sb.Append("{\n");
        sb.Append("  if (document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value != document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_CNFRM_PSSWRD + ".value)\n");
        sb.Append("  {\n");
        sb.Append("     alert(\"" + m_asOwner.GetString(2171, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("     return false;\n");
        sb.Append("  }\n");
        //sb.Append("  }\n" );
        sb.Append("  return true;\n");
        sb.Append("}\n");
        sb.Append("function CheckMinLength()\n");
        sb.Append("{\n");
        sb.Append("  if ((document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value.length < 5) && ");
        sb.Append("      (document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value.length >= 0) && ");
        sb.Append("      (document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_USR_NAME + ".value.length > 0))\n");
        sb.Append("  {\n");
        sb.Append("      alert(\"" + m_asOwner.GetString(2172, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("      return false;\n");
        sb.Append("  }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        sb.Append("function CheckMinUserNameLength()\n");
        sb.Append("{\n");
        sb.Append("  if ((document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value.length >= 5) &&");
        sb.Append("\t\t (document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_USR_NAME + ".value.length == 0))\n");
        sb.Append("  {\n");
        sb.Append("      alert(\"" + m_asOwner.GetString(2174, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("      return false;\n");
        sb.Append("  }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
        sb.Append("function CheckNotWhitespace()\n");
        sb.Append("{\n");
        sb.Append("  if (" + strJSUtilVersionPrefix + "PTStringUtil.isAllWhitespace(document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value))\n");
        sb.Append("  {\n");
        sb.Append("      alert(\"" + m_asOwner.GetString(2173, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("      return false;\n");
        sb.Append("  }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        sb.Append("function CheckUsernameIsNumeric()\n");
        sb.Append("{\n");
        sb.Append("  if (document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_USR_NAME + ".value.length > 0)");
        sb.Append("\t {\n");
        sb.Append("  \tif (!" + strJSUtilVersionPrefix + "PTNumberUtil.isPositiveInteger(document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_USR_NAME + ".value))\n");
        sb.Append("\t \t{\n");
        sb.Append("      \talert(\"" + m_asOwner.GetString(2189, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("      \treturn false;\n");
        sb.Append("  \t}\n");
        sb.Append("\t }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        sb.Append("function CheckPasswordIsNumeric()\n");
        sb.Append("{\n");
        sb.Append("  if (!IsPasswordString(document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value))\n");
        sb.Append("\t {\n");
        sb.Append("  \tif (!" + strJSUtilVersionPrefix + "PTNumberUtil.isPositiveInteger(document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_PSSWRD + ".value))\n");
        sb.Append("\t \t{\n");
        sb.Append("     \talert(\"" + m_asOwner.GetString(2190, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("      \treturn false;\n");
        sb.Append("  \t}\n");
        sb.Append("  }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        sb.Append("function IsPasswordString(strIn)\n");
        sb.Append("{\n");
        sb.Append("\t\tvar i;\n");
        sb.Append("\t\tfor (i = 0; i < strIn.length; ++i)\n");
        sb.Append("\t\t{\n");
        sb.Append("\t\t\tif (strIn.charAt(i) != \"*\")\n");
        sb.Append("         {\n");
        sb.Append("\t\t\t\treturn(false);\n");
        sb.Append("         }\n");
        sb.Append("      }\n");
        sb.Append("\t\t return(true);\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "LoginView::DisplayJavascript The following error occured when trying to display the JavaScript: ");
        throw new XPException("test", e);
      }
      return (myScript);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}