using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.user
{
  /// <summary>
  /// This Section contains the HTML for the dependencies page.
  /// </summary>
  /// <author>SudhaS</author>
  public class UserDependenciesView : ObjDependenciesView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.user.UserDependenciesView");
    //Member variables
    private CreatedHelper m_chHelper = null;
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserDependencies";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserDependenciesView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_chHelper = new CreatedHelper(parent, (UserModel) model);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()"></seealso>
    protected override HTMLElementCollection GetHTMLForDependencies()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      int intParentFolderID = ((ObjEditorModel) m_model).GetFolderID();
      try
      {
        if (PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES == intParentFolderID)
        {
          //This is a default profile
          m_chHelper.displayEmptyRow(result);
          //fixed string concatenation				m_chHelper.displayTextRow(result, m_asOwner.GetString(635, "ptmsgs_portalcommonmsgs") + m_asOwner.GetString(2282, "ptmsgs_portaladminmsgs"), null);
          m_chHelper.displayTextRow(result, m_asOwner.GetString(695, "ptmsgs_portalcommonmsgs"),
           null);
          m_chHelper.displayTextRow(result, -1, m_asOwner.GetString(2282,
           "ptmsgs_portaladminmsgs") + ":", ((ObjEditorModel) m_model).GetObjectName());
          //Get the folder
          IPTSession mySession = ((ObjEditorModel) m_model).GetPTSession();
          IPTUser myUser = (IPTUser) ((ObjEditorModel) m_model).GetObject();
          int intAuthSourceID = myUser.GetAuthenticationSourceID();
          if (0 != intAuthSourceID)
          {
            IPTAuthSource myAuthSource;
            myAuthSource = (IPTAuthSource) mySession.GetAuthSources().Open(intAuthSourceID,
             false);
            int intNewUserFolderID = myAuthSource.GetNewUserFolderID();
            if (intNewUserFolderID > 0)
            {
              IPTAdminFolder myFolder = mySession.GetAdminCatalog().OpenAdminFolder(intNewUserFolderID,
               false);
              String strFolderPath = myFolder.GetPath();
              m_chHelper.displayTextRow(result, m_asOwner.GetString(2285,
               "ptmsgs_portaladminmsgs") + strFolderPath, null);
            }
          }
        } else
        {
          //Display the standard success message
          m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2281,
           "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(),
           ((ObjEditorModel) m_model).GetParentFolderPath());
          ISelectPTObjectModelRO myUserModel = (ISelectPTObjectModelRO) m_asOwner.GetModel(UserEditorAS.strStorageSelectPTObject);
          IPTGrowableSortedArrayWrapperRO aUserGrowable = myUserModel.GetReadOnlyItems();
          if (aUserGrowable.GetCount() == 1)
          {
            //Inform the user and display the edit link
            m_chHelper.displayTextRow(result, m_asOwner.GetString(2283, "ptmsgs_portaladminmsgs"),
             null);
            m_chHelper.beginList(result);
            m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(PT_CLASSIDS.PT_USER_ID,
             null, ((IUserModelRO) m_model).GetObjectID(), m_asOwner.GetString(2284,
             "ptmsgs_portaladminmsgs"), m_asOwner, IPTOpenerConstants.OPENER_MODE_EDIT,
             null, true));
          }
        }
      }
      //Display the standard warning if everyone has access to this object
      //m_chHelper.displayEveryoneWarning(result, (UserModel) m_model, m_asOwner.GetString(2281, "ptmsgs_portaladminmsgs"));
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t display ObjMgrHeaderView");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(2286, "ptmsgs_portaladminmsgs") + e, "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return result;
    }
  }
}