using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.user
{
  /// <author>SudhaS</author>
  public class UserEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.user.UserEditorAS");
    public const String STR_MVC_CLASS_NAME = "UserEditor";
    public const String strStorageSelectPTObject = "SelectUserPTObject";
    public const String strDynamicMembershipSelectPTObject = "DynamicMembershipSelectPTObject";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.user.UserEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (UserDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return GetString(955, "ptmsgs_portaladminmsgs");
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(2617, "ptmsgs_portaladminmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (UserRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = UserModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Get back the Model we just registered because we need it to register the Section and the Control
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageSelectPTObject);
      IModel mySelectPTObjectModel = GetModel(strStorageSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageSelectPTObject,
       mySelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectPTObject,
       mySelectPTObjectModel);
      // Dynamic Membership view registration
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strDynamicMembershipSelectPTObject);
      IModel myDynamicMembershipSelectPTObjectModel = GetModel(strDynamicMembershipSelectPTObject);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strDynamicMembershipSelectPTObject,
       myDynamicMembershipSelectPTObjectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strDynamicMembershipSelectPTObject,
       myDynamicMembershipSelectPTObjectModel);
      // Register DisplayPages
      //RegisterPage(new MainDP());
      MainDP mainDP = new MainDP();
      RegisterPage(mainDP);
      DevicesDP devicesDP = new DevicesDP();
      RegisterPage(devicesDP);
      // Register Views
      RegisterView(LoginView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(DevicesView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(UserDependenciesView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(UserRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Default page
      SetCurrentPage(mainDP);
      //		int nUserID = ((IPTSession) this.GetUserSession()).GetSessionInfo().GetCurrentUserID();
      // Main DP
      mainDP.AddToValidationFunction("CheckNames");
      devicesDP.AddToValidationFunction("CheckNames");
      mainDP.AddToValidationFunction("CheckMinUserNameLength");
      mainDP.AddToValidationFunction("CheckUsernameNotWhitespace");
      devicesDP.AddToValidationFunction("CheckMinUserNameLength");
      devicesDP.AddToValidationFunction("CheckUsernameIsNumeric");
      devicesDP.AddToValidationFunction("CheckPasswordIsNumeric");
      devicesDP.AddToValidationFunction("CheckMinLength");
      mainDP.AddToValidationFunction("CheckMaxLength");
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(958, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, DevicesDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1905, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 69;
          int iTipId = 70;
          int iSecondaryTipId = 71;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_User_MainSettings");
      } else
      if (DevicesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_User_MobileDeviceAuthentication");
      }
    }
  }
}