using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.user
{
  /// <author>SudhaS</author>
  public class UserModel : ObjEditorModel,IUserModelRO
  {
    public const String STR_MVC_CLASS_NAME = "User";
    private const String PASSWORD = "********";
    protected String m_sSetting1;
    protected String m_sSetting2;
    protected String m_strMobilePassword = "";
    protected String m_strMobileUsr = "";
    protected String m_strInitialMobileUsr = "";
    protected String m_strPassword = null;
    protected String m_strConfirmPassword = null;
    protected String m_strUserName = "";
    protected String m_strInitialUserName = "";
    protected String m_strInitialEncryptedPassword = "";
    protected int m_nUserType;
    protected int[] m_aExistingGroups;
    protected bool m_bDisabled = false;
    protected bool m_bDeleteGroups = false;
    // This tells us that we need to set the Last Password Change property after saving.
    protected bool m_bPasswordChanged = false;
    // This tells us that we need to make the user's password a one-time password  by
    // expiring it.
    // This is always false by default, and we don't store it in the DB.
    protected bool m_bExpirePassword = false;
    protected bool m_bExpirePasswordEnabled = false;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
      //int n_UserID = ((IPTServerContext) m_ptObject).GetObjectID();
      IPTServerContext ptscUser = (IPTServerContext) m_ptObject;
      int nUserID = ptscUser.GetObjectID();
      IPTObjectManager ptomUserGroup = m_Session.GetUserGroups();
      PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(UserEditorAS.strStorageSelectPTObject)).GetItems();
      for (int i = 0;i < aSelectPTObjectValues.GetCount();i++)
      {
        int nGroupObjID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i,
         SelectPTObjectModel.EXPLIST_COL_OBJECTID));
        if (nGroupObjID != PT_INTRINSICS.PT_USERGROUP_EVERYONE)
        {
          IPTUserGroup ptUserGroup = (IPTUserGroup) ptomUserGroup.Open(nGroupObjID,
           false);
          int[] userIDs = new int[]{nUserID};
          ptUserGroup.AddUsers(userIDs);
        }
      }
      if (m_aExistingGroups != null)
      {
        //SS - If the user has clicked the delete button then this flag will be true
        if (m_bDeleteGroups)
        {
          RemoveUserFromGroups(aSelectPTObjectValues, nUserID);
        }
      }
      if (!EditingInDefaultProfilesFolder())
      {
        if (!m_bDisabled)
        {
          ((IPTUser) m_ptObject).SetLockedStatus(false);
        } else
        {
          ((IPTUser) m_ptObject).SetLockedStatus(true);
        }
      } else
      {
        if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
        {
          // WilliamA - Don't lock if the user type is Guest
          if (PT_USER_TYPES.PT_USER_TYPE_GUEST != m_nUserType)
          {
            ((IPTUser) m_ptObject).SetLockedStatus(true);
          }
        }
      }
      // We need to set the Last Password Changed property after storing the user, since we have to reopen the user.
      if (m_bExpirePassword && m_bExpirePasswordEnabled)
      {
        m_bExpirePassword = false;
        // This method sets the user's last password change time way back in the past
        // so it will be expired.
        ExpirePassword(nUserID);
      } else
      if (m_bPasswordChanged)
      {
        m_bPasswordChanged = false;
        SetPasswordChangedTime(XPSystem.GetCurrentTimeMilliSec(), nUserID);
        }
    }
    
    /// <summary>
    /// This helper method sets the Last Password Change property to the
    /// specified time.  This is necessary if password expiration is turned
    /// on.
    /// </summary>
    /// <param name="_lTime">The time to set</param>
    /// <param name="_ptEditedUser">The user being edited.</param>
    protected virtual void SetPasswordChangedTime(long _lTime, int _nUserID)
    {
      // No one has edit acccess on the Password Last Change property, so we need
      // to impersonate the edited user to bypass the security check.
      IPTSession impersonatedSession = m_Session.ImpersonateUser(_nUserID);
      // Reopen the user and props objects so that they use the newly impersonated session.
      IPTUser editedUser = (IPTUser) impersonatedSession.GetUsers().Open(_nUserID,
       false);
      IPTObjectProperties props = editedUser.GetObjectProperties();
      Object[][] propdata = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        propdata[j2c_index] = new Object[1];
      }
      propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_PROPERTYID][0] = PT_INTRINSICS.PT_PASSWORD_LAST_CHANGED;
      propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_VALUE][0] = _lTime;
      props.SetPropertyData(propdata);
    }
    
    /// <summary>
    /// This helper method expires the user's password so they will have to change it the
    /// next time they log in.
    /// </summary>
    /// <param name="_ptEditedUser">The user being edited.</param>
    public virtual void ExpirePassword(int _nUserID)
    {
      IPTServerConfigSettings config = (IPTServerConfigSettings) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      // This is a cached value, so it should be quick
      int nPasswordExpiration = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION);
      long lPasswordExpiration = XPConvert.ToLong(nPasswordExpiration);
      // We have to cast everything to long here to make sure we don't accidentally get into integer multiplication
      // and have our values wrap.
      long msPasswordExpiration = lPasswordExpiration * (long) (1000 * 60 * 60 * 24);
      // Set time to now - a lot
      SetPasswordChangedTime((XPSystem.GetCurrentTimeMilliSec() - (msPasswordExpiration * 10)),
       _nUserID);
    }
    private void RemoveUserFromGroups(PTGrowableSortedArrayWrapper _aSelectPTObjectValues,
     int _nUserID)
    {
      bool bFound = false;
      IPTObjectManager ptomUserGroup = m_Session.GetUserGroups();
      for (int i = 0;i < m_aExistingGroups.Length;i++)
      {
        int nCurrAddedValue = XPConvert.ToInteger(m_aExistingGroups[i]);
        for (int j = 0;j < _aSelectPTObjectValues.GetCount();j++)
        {
          int nCurrExistingValue = XPConvert.ToInteger(_aSelectPTObjectValues.GetItem(j,
           SelectPTObjectModel.EXPLIST_COL_OBJECTID));
          if (nCurrExistingValue == nCurrAddedValue)
          {
            bFound = true;
          }
        }
        if (!bFound)
        {
          IPTUserGroup ptUserGroup = (IPTUserGroup) ptomUserGroup.Open(nCurrAddedValue,
           false);
          int[] userIDs = new int[]{_nUserID};
          ptUserGroup.RemoveUsers(userIDs);
        }
        bFound = false;
      }
    }
    
    /// <summary>
    /// Code executed before the object is stored.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
      IPTServerContext ptscUser = (IPTServerContext) m_ptObject;
      //SS - Is the user in Edit mode?
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        //SS - If so we want to store the password.  We set the name
        //regardless of whether it has changed or not. 
        //ptscUser.LockObject();
        ((IPTUser) m_ptObject).SetLoginName(m_strUserName);
        //ptscUser.UnlockObject();
        if (m_strMobileUsr.Length > 0)
        {
          //ptscUser.LockObject();
          if (XPStringUtility.CompareIgnoreCase(m_strMobileUsr, m_strInitialMobileUsr) != 0)
          {
            ((IPTUser) m_ptObject).SetNumericUserName(m_strMobileUsr);
          }
          if (m_strMobilePassword.Length > 0)
          {
            ptscUser.LockObject();
            ((IPTUser) m_ptObject).SetNumericPassword(m_strMobilePassword);
            ptscUser.UnlockObject();
          }
        }
        //SS - If the password has not changed it (m_strPassword) will be null, in which
        //case we will not want to store it.
        if (m_strPassword != null)
        {
          if (!EditingInDefaultProfilesFolder() && IsPlumtreeAuthSource())
          {
            ptscUser.LockObject();
            ((IPTUser) m_ptObject).SetPassword(m_strPassword);
            ptscUser.UnlockObject();
            // Mark that we need to set the LastPasswordChange property later.
            m_bPasswordChanged = true;
          }
        }
      } else
      {
        if (!EditingInDefaultProfilesFolder() && IsPlumtreeAuthSource())
        {
          if (m_strPassword != null)
          {
            ((IPTUser) m_ptObject).SetPassword(m_strPassword);
            // Mark that we need to set the LastPasswordChange property later.
            m_bPasswordChanged = true;
          }
        }
        ((IPTUser) m_ptObject).SetLoginName(m_strUserName);
        if (m_strMobileUsr.Length > 0)
        {
          ((IPTUser) m_ptObject).SetNumericUserName(m_strMobileUsr);
          ((IPTUser) m_ptObject).SetNumericPassword(m_strMobilePassword);
          }
        // WilliamA - on CREATE mode save the guest/non-guest checkbox
        ((IPTUser) m_ptObject).SetUserType(m_nUserType);
      }
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      StartSelectPTObject();
      StartDynamicMembershipsSelectPTObject();
      if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      if (GetFolderID() == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
      {
        m_bForceSavedInSuppliedFolder = true;
      } else
      {
        if (m_Session.GetSessionInfo().GetCurrentUserID() != PT_INTRINSICS.PT_USER_SYSADMIN)
        {
          MainDP mainDP = (MainDP) m_asOwner.GetPage(MainDP.STR_MVC_CLASS_NAME);
          mainDP.AddToValidationFunction("CheckMinLength");
          mainDP.AddToValidationFunction("CheckNotWhitespace");
        }
      }
      //devicesDP.AddToValidationFunction("CheckNotWhitespace");
      ((ILocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME)).SetNameLabel(m_asOwner.GetString(417,
       "ptmsgs_portalinfrastructure"));
      if (((IPTUser) m_ptObject).GetAuthenticationSourceID() == PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE)
      {
        // non-native users can't expire their passwords.
        // NOTE: Is this editor only for non-native users?
        IPTServerConfigSettings config = (IPTServerConfigSettings) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         false);
        // This is a cached value, so it should be quick
        int nPasswordExpiration = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION);
        m_bExpirePasswordEnabled = (nPasswordExpiration > 0);
      }
    }
    
    /// <returns></returns>
    public virtual bool GetDisabled()
    {
      return m_bDisabled;
    }
    
    /// <returns></returns>
    public virtual String GetLoginName()
    {
      return m_strUserName;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual String GetPassword()
    {
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        return PASSWORD;
      }
      if (m_strPassword == null)
      {
        return "";
      }
      return m_strPassword;
    }
    
    /// <returns></returns>
    public virtual String GetUserMobileName()
    {
      return m_strMobileUsr;
    }
    
    /// <returns></returns>
    public virtual String GetUserMobilePsswrd()
    {
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        if (m_strMobileUsr.Equals(""))
        {
          return "";
        } else
        {
          return PASSWORD;
        }
      }
      if (m_strMobilePassword.Equals(""))
      {
        return "";
      } else
      {
        return PASSWORD;
      }
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SaveDevicesPage(XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(DevicesView.HTMLINPUT_PSSWRD);
      if (data != null)
      {
        if (!PASSWORD.Equals(data[0]))
        {
          m_strMobilePassword = data[0];
        }
      }
      data = (String[]) _htFormData.GetElement(DevicesView.HTMLINPUT_USR_NAME);
      if (data != null)
      {
        m_strMobileUsr = data[0];
        Object[][] ptqfNumericUsrName = null;
        if (!m_strMobileUsr.Equals(""))
        {
          ptqfNumericUsrName = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_USER_NUMUSERNAME,
           PT_FILTEROPS.PT_FILTEROP_IN, new Object[]{m_strMobileUsr});
          //Object[][] ptqfNumericUsrName = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_USER_NUMUSERNAME,
          //		PT_FILTEROPS.PT_FILTEROP_IN, m_strMobileUsr);
          IPTQueryResult ptqrUsers = m_Session.GetUsers().Query(PT_PROPIDS.PT_PROPID_USER_NUMUSERNAME | PT_PROPIDS.PT_PROPID_OBJECTID,
           -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, ptqfNumericUsrName);
          //SS - How do I tell the user the mobile name has already been taken?
          if (ptqrUsers.RowCount() > 0)
          {
            if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
            {
              if (XPStringUtility.CompareIgnoreCase(m_strInitialMobileUsr,
               m_strMobileUsr) != 0)
              {
                UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
                 null, m_asOwner.GetString(2410, "ptmsgs_portaladminmsgs"),
                 m_asOwner.GetString(2410, "ptmsgs_portaladminmsgs"));
                UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
                 m_asOwner.GetApplication());
                return (RepostControl.PAGE_STATUS_INVALID);
              }
            } else
            if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
            {
              UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
               null, m_asOwner.GetString(2410, "ptmsgs_portaladminmsgs"),
               m_asOwner.GetString(2410, "ptmsgs_portaladminmsgs"));
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
              return (RepostControl.PAGE_STATUS_INVALID);
            }
          }
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SaveMainPage(XPHashtable _htFormData)
    {
      String[] data;
      // WilliamA - Check guest/non-guest checkbox on CREATE mode
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
      {
        data = (String[]) _htFormData.GetElement(LoginView.HTMLINPUT_CHECKBOX_GUEST_NAME);
        // guest account checkbox is checked
        if (null != data)
        {
          m_nUserType = PT_USER_TYPES.PT_USER_TYPE_GUEST;
        } else
        {
          m_nUserType = PT_USER_TYPES.PT_USER_TYPE_REGULAR;
        }
      }
      data = (String[]) _htFormData.GetElement(LoginView.HTMLINPUT_PASSWORD_NAME);
      if (!EditingInDefaultProfilesFolder() && !EditingGuestUser())
      {
        if (IsPlumtreeAuthSource() && !PASSWORD.Equals(data[0]))
        {
          m_strPassword = data[0];
        }
        data = (String[]) _htFormData.GetElement(LoginView.HTMLINPUT_CHECKBOX_DISABLE_NAME);
        if (data == null)
        {
          m_bDisabled = false;
        } else
        {
          m_bDisabled = true;
        }
      }
      // Expire Password checkbox
      data = (String[]) _htFormData.GetElement(LoginView.HTMLINPUT_CHECKBOX_EXPIRE_PASSWORD_NAME);
      if (data == null)
      {
        m_bExpirePassword = false;
      } else
      {
        m_bExpirePassword = true;
      }
      // aj: bug 43715 - make sure we only check confirm password when we are
      //     not in the default profiles folder and not dealing with a guest... 
      if (!EditingInDefaultProfilesFolder() && !EditingGuestUser())
      {
        data = (String[]) _htFormData.GetElement(LoginView.HTMLINPUT_CONFIRM_PASSWORD_NAME);
        if (IsPlumtreeAuthSource() && !PASSWORD.Equals(data[0]))
        {
          SetConfirmPassword(data[0]);
        }
      }
      data = (String[]) _htFormData.GetElement(LoginView.HTMLINPUT_LOGIN_NAME);
      if (data != null)
      {
        m_strUserName = data[0];
        Object[][] ptqfUsrLoginName = null;
        //SS - Create a query filter (with the user name) that will be used to tell
        //whether that user name already exists
        if (!m_strUserName.Equals(""))
        {
          // aj: bug 43052, loginname should not be allowed to contain '/' or '\' characters
          //     if the user is created against the plumtree auth source...
          if (((IPTUser) m_ptObject).GetAuthenticationSourceID() == PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE)
          {
            int nCharIndex = XPStringUtility.IndexOf(m_strUserName, '/');
            nCharIndex+=XPStringUtility.IndexOf(m_strUserName, '\\');
            if (nCharIndex != -2)
            {
              // aj: one or the other must exist in our string, throw an error
              UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
               null, m_asOwner.GetString(3171, ResourceConstants.PORTALADMINMSGS),
               m_asOwner.GetString(3171, ResourceConstants.PORTALADMINMSGS));
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
              return (RepostControl.PAGE_STATUS_INVALID);
            }
          }
          // aj: check to see if the login name has been taken yet...
          ptqfUsrLoginName = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_USER_LOGINNAME,
           PT_FILTEROPS.PT_FILTEROP_IN, new Object[]{m_strUserName});
          IPTQueryResult ptqrUsers = m_Session.GetUsers().Query(PT_PROPIDS.PT_PROPID_USER_LOGINNAME | PT_PROPIDS.PT_PROPID_OBJECTID,
           -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, ptqfUsrLoginName);
          //SS - Tell the user the loginname has already been taken
          if (ptqrUsers.RowCount() > 0)
          {
            if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
            {
              if (XPStringUtility.CompareIgnoreCase(m_strUserName, m_strInitialUserName) != 0)
              {
                UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
                 null, m_asOwner.GetString(2409, "ptmsgs_portaladminmsgs"),
                 m_asOwner.GetString(2409, "ptmsgs_portaladminmsgs"));
                UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
                 m_asOwner.GetApplication());
                return (RepostControl.PAGE_STATUS_INVALID);
              }
            } else
            if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
            {
              UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
               null, m_asOwner.GetString(2409, "ptmsgs_portaladminmsgs"),
               m_asOwner.GetString(2409, "ptmsgs_portaladminmsgs"));
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
              return (RepostControl.PAGE_STATUS_INVALID);
            }
          }
        }
        if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
        {
          if (XPStringUtility.CompareIgnoreCase(m_ptObject.GetName(), m_strInitialUserName) == 0)
          {
            if (XPStringUtility.CompareIgnoreCase(m_strUserName, "") != 0)
            {
              m_ptObject.SetName(m_strUserName);
            }
          }
        } else
        if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
        {
          if (XPStringUtility.CompareIgnoreCase(m_strUserName, "") != 0)
          {
            m_ptObject.SetName(m_strUserName);
          }
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        // ***EXAMPLE*** Server validation - get back the status from SaveMainPage
        nPageStatus = SaveMainPage(_htFormData);
      } else
      if (_sPageName.Equals(DevicesDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SaveDevicesPage(_htFormData);
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to start the Select PTObject List.
    /// </summary>
    public virtual void StartSelectPTObject()
    {
      SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(UserEditorAS.strStorageSelectPTObject);
      // ***CHANGE_HERE SELECTPTOBJECT*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _sSectionSubTitle: Sub title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(964,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(965, "ptmsgs_portaladminmsgs"),
       PTImageType.ICON_GROUP, m_asOwner.GetString(966, "ptmsgs_portaladminmsgs"),
       new int[]{PT_CLASSIDS.PT_USERGROUP_ID}, 2);
      // ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
      //     Use the method bellow to set the icon to display on each row.
      //     (By default there will be no icon.)
      mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_GROUP);
      Object[][] oRows = null;
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
      {
        oRows = InitializeCreateMode(mySelectPTObjectModel);
      } else
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        oRows = InitializeEditMode(mySelectPTObjectModel);
        m_aExistingGroups = new int[oRows.Length];
        for (int i = 0;i < oRows.Length;i++)
        {
          m_aExistingGroups[i] = XPConvert.ToInteger(oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]);
          }
      }
      mySelectPTObjectModel.SetDefaultObjects(oRows);
      // JF- The Everyone group cannot be removed from any user.
      int[][] arrReadOnlyObjects = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrReadOnlyObjects[j2c_index] = new int[2];
      }
      arrReadOnlyObjects[0][SelectPTObjectModel.READ_ONLY_ROW_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
      arrReadOnlyObjects[0][SelectPTObjectModel.READ_ONLY_ROW_OBJECTID] = PT_INTRINSICS.PT_USERGROUP_EVERYONE;
      mySelectPTObjectModel.SetReadOnlyObjects(arrReadOnlyObjects);
      mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(2147, "ptmsgs_portaladminmsgs"));
      mySelectPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(2188, "ptmsgs_portaladminmsgs"));
      }
    //((SelectPTObjectModel) m_as	Owner.GetModel(UserEditorAS.m_strStorageSelectPTObject)).
    //	SetTreeLeafType(ITreeModelRO.N_COMPOSITESELECT);
    public virtual void StartDynamicMembershipsSelectPTObject()
    {
      SelectPTObjectModel myDynamicMembershipSelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(UserEditorAS.strDynamicMembershipSelectPTObject);
      // Initialize the Select PTObject list.
      //		 _sSectionTitle Main title.
      //		 _sSectionSubTitle Sub title
      //		 _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //		 _nListKey In case you have multiple Expandable Lists on
      myDynamicMembershipSelectPTObjectModel.InitializeReadOnlySelectPTObject(m_asOwner.GetString(2729,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(965, "ptmsgs_portaladminmsgs"),
       new int[]{PT_CLASSIDS.PT_USERGROUP_ID, PT_CLASSIDS.PT_USER_ID}, 5);
      // set the message and instructions to display when the list is empty.
      myDynamicMembershipSelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(2730,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2731, "ptmsgs_portaladminmsgs"));
      // set icon for groups
      myDynamicMembershipSelectPTObjectModel.SetRowIconByClassID(PT_CLASSIDS.PT_USERGROUP_ID,
       PTImageType.ICON_GROUP);
      // aj: if we're in EDIT mode, then we should
      //     load the dynamic group memberships
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        IPTUser pUser = (IPTUser) m_ptObject;
        IPTQueryResult ptQRDynUsers = pUser.QueryDirectGroups(true, false);
        int nNumDynMemberships = 0;
        if (null != ptQRDynUsers)
        {
          nNumDynMemberships = ptQRDynUsers.RowCount();
        }
        // initialize building of data for SelectPTObject
        int nDynGroupID;
        String sDynGroupName;
        Object[][] arDynMemberships = new Object[nNumDynMemberships][];
        for (int j2c_index = 0;j2c_index < nNumDynMemberships;j2c_index++)
        {
          arDynMemberships[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
          }
        // add dynamic memberships to data
        for (int ii = 0;ii < nNumDynMemberships;ii++)
        {
          // retrieve from query results
          nDynGroupID = ptQRDynUsers.ItemAsInt(ii, PT_PROPIDS.PT_PROPID_OBJECTID);
          sDynGroupName = ptQRDynUsers.ItemAsString(ii, PT_PROPIDS.PT_PROPID_NAME);
          // build array for SelectPTObject
          arDynMemberships[ii][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
          arDynMemberships[ii][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = nDynGroupID;
          arDynMemberships[ii][SelectPTObjectModel.EXPLIST_COL_STRING] = sDynGroupName;
          }
        // load data into SelectPTObject storage
        ((SelectPTObjectModel) m_asOwner.GetModel(UserEditorAS.strDynamicMembershipSelectPTObject)).SetDefaultObjects(arDynMemberships);
        }
    }
    
    /// <param name="mySelectPTObjectModel"></param>
    /// <returns></returns>
    protected virtual Object[][] InitializeCreateMode(SelectPTObjectModel mySelectPTObjectModel)
    {
      IPTObjectManager ptomUserGroup = m_Session.GetUserGroups();
      IPTUserGroup ptUserGroup = (IPTUserGroup) ptomUserGroup.Open(PT_INTRINSICS.PT_USERGROUP_EVERYONE,
       false);
      Object[][] oRows = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
        }
      oRows[0][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = mySelectPTObjectModel.m_nNextIndex;
      mySelectPTObjectModel.m_nNextIndex++;
      oRows[0][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
      oRows[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = PT_INTRINSICS.PT_USERGROUP_EVERYONE;
      oRows[0][SelectPTObjectModel.EXPLIST_COL_STRING] = ptUserGroup.GetLocalizedName();
      return (oRows);
    }
    
    /// <param name="mySelectPTObjectModel"></param>
    /// <returns></returns>
    protected virtual Object[][] InitializeEditMode(SelectPTObjectModel mySelectPTObjectModel)
    {
      IPTQueryResult ptqrInGroups = ((IPTUser) m_ptObject).QueryDirectGroups(false,
       true);
      Object[][] oRows = new Object[ptqrInGroups.RowCount()][];
      for (int j2c_index = 0;j2c_index < ptqrInGroups.RowCount();j2c_index++)
      {
        oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
        }
      for (int i = 0;i < ptqrInGroups.RowCount();i++)
      {
        oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = mySelectPTObjectModel.m_nNextIndex;
        mySelectPTObjectModel.m_nNextIndex++;
        oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
        oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = ptqrInGroups.ItemAsInt(i,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] = ptqrInGroups.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_NAME);
      }
      //m_strPassword = PASSWORD;
      m_bDisabled = ((IPTUser) m_ptObject).GetLockedStatus();
      m_strUserName = ((IPTUser) m_ptObject).GetLoginName();
      m_strInitialUserName = m_strUserName;
      m_strMobileUsr = ((IPTUser) m_ptObject).GetNumericUserName();
      m_strInitialMobileUsr = m_strMobileUsr;
      m_strInitialEncryptedPassword = ((IPTUser) m_ptObject).GetEncryptedPassword();
      m_nUserType = ((IPTUser) m_ptObject).GetUserType();
      return (oRows);
    }
    
    /// <summary>
    /// We need this to know if we're locking the password and locking setting in
    /// the editor
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.user.IUserModelRO#EditingInDefaultProfilesFolder()"></seealso>
    public virtual bool EditingInDefaultProfilesFolder()
    {
      return (m_ptObject.GetAdminFolderID() == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.user.IUserModelRO#EditingGuestUser()"></seealso>
    public virtual bool EditingGuestUser()
    {
      // Is the user that is being edited/created the guest user?
      // WilliamA - Change guest user detection for multiple-guest-user support
      return (PT_USER_TYPES.PT_USER_TYPE_GUEST == m_nUserType);
    }
    
    /// <summary>
    /// Return true if the user is locked.
    /// </summary>
    /// <returns></returns>
    public virtual bool EditingLockedAccount()
    {
      return ((IPTUser) m_ptObject).GetLockedStatus();
    }
    
    /// <summary>
    /// Returns whether the guest account type is editable.
    /// </summary>
    /// <returns></returns>
    public virtual bool UserTypeEditable()
    {
      return (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType());
      }
    public virtual bool IsCurrentUserAdministrator()
    {
      // TODO: This should probably check for users in the administrator
      // group, rather than the default administrator user only.  However,
      // this is only used to show/hide the required '*'s on the form, so it's
      // not a big deal either way.
      // Is the user who is currently logged on
      // (not the user that is being edited/created)
      // the administrator?
      return (m_Session.GetSessionInfo().GetCurrentUserID() == PT_INTRINSICS.PT_USER_SYSADMIN);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.user.IUserModelRO#IsPlumtreeAuthSource()"></seealso>
    public virtual bool IsPlumtreeAuthSource()
    {
      IPTUser ptUser = (IPTUser) m_ptObject;
      return (PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE == ptUser.GetAuthenticationSourceID());
      }
    public virtual void SetDeleteGroups()
    {
      m_bDeleteGroups = true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.user.IUserModelRO#GetAuthUsername()
     */
     
    public virtual String GetAuthUsername()
    {
      return (((IPTUser) m_ptObject).GetAuthenticationUser());
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.user.IUserModelRO#GetUniqueUsername()
     */
     
    public virtual String GetUniqueUsername()
    {
      return (((IPTUser) m_ptObject).GetUniqueAuthName());
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.user.IUserModelRO#IsRemoteUser()
     */
     
    public virtual bool IsRemoteUser()
    {
      return (((IPTUser) m_ptObject).GetAuthenticationSourceID() != PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE);
      }
    
    /// <summary>
    /// Return the confirm password variable. START_FLAG is set return the 
    /// default password string.
    /// </summary>
    /// <returns>String confirm password</returns>
    public virtual String GetConfirmPassword()
    {
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT)
      {
        return PASSWORD;
      }
      if (m_strConfirmPassword == null)
      {
        return "";
      }
      return m_strConfirmPassword;
    }
    
    /// <summary>
    /// Sets the confirm password vairable.
    /// </summary>
    /// <returns>String confirm password</returns>
    public virtual void SetConfirmPassword(String _confirmPassword)
    {
      m_strConfirmPassword = _confirmPassword;
    }
    
    /// <summary>
    /// Returns <c>true</c> if the password is supposed
    /// to be set to expired when this editor finishes.  Otherwise,
    /// <c>false</c> is returned.
    /// </summary>
    /// <returns>
    /// boolean indicating whether or not the password should
    /// be set to expired
    /// </returns>
    public virtual bool GetExpirePassword()
    {
      return m_bExpirePassword;
    }
    
    /// <summary>
    /// Returns <c>true</c> if the Expire Password feature
    /// is enabled for this editor.  Otherwise,
    /// <c>false</c> is returned.
    /// </summary>
    /// <returns>
    /// boolean indicating whether or not the Expire Password
    /// feature is enabled
    /// </returns>
    public virtual bool GetExpirePasswordEnabled()
    {
      return m_bExpirePasswordEnabled;
    }
  }
}