using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.userinfopropmap;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.expandablelist.template;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.userprofilemanager
{
  /// <author>JHQ</author>
  /// <author>
  /// jennifersu
  /// The main activity space for the user profile manager.  It registers the
  /// classes for the user profile 'community', and the
  /// user information property map.
  /// </author>
  public class UsrProfMgrEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.userprofilemanager.UsrProfMgrEditorAS");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserProfileManagerEditor";
    
    /// <summary>
    /// pop up constants used for keying pop up display pages 
    /// </summary>
    public const String POPUP_KEY = "_popup";
    public const String RENAME_KEY = "_rename";
    private const String sClassName = "com.plumtree.portalpages.admin.editors.userprofilemanager.UsrProfMgrEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UsrProfMgrEditorAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      return (GetString(967, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (UsrProfMgrRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public virtual void InitClosePopup()
    {
      // display page that closes popups
      HTMLScript openerScript = new HTMLScript("text/javaScript");
      try
      {
        openerScript.AddInnerHTMLString("window.opener." + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + UsrProfMgrRepostControl.POSTTOSELF_ACTION_ONRETURN_FROM_SUBEDITOR + ");");
        }
      catch (Exception e)
      {
        log.Error(e, "UsrProfMgrEditorAS::Init The following error occured when trying to initialize the activity space: " + e.Message);
        }
      ClosePopUpDP closePopUp = new ClosePopUpDP();
      closePopUp.SetScript(openerScript);
      RegisterPage(closePopUp, ClosePopUpDP.STR_MVC_CLASS_NAME + POPUP_KEY);
      }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public virtual void InitTips()
    {
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 72;
          int iTipId = 73;
          int iSecondaryTipId = 74;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    
    /// <summary>
    /// Registers all the user profile community classes for this Activity Space.
    /// </summary>
    public virtual void InitProfileCommunityObjects(int _subMenuID)
    {
      RegisterModel(CommunityEditorModel.STR_MVC_CLASS_NAME);
      IModel commModel = GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME);
      RegisterControl(UsrProfCommRepostControl.STR_MVC_CLASS_NAME, commModel);
      // --- COMMUNITY PAGES objects
      UsrProfCommPagesDP myPage = new UsrProfCommPagesDP();
      RegisterPage(myPage);
      // Default page
      SetCurrentPage(myPage);
      m_mEditorMenu.AddLinkToSubMenu(_subMenuID, UsrProfCommPagesDP.STR_MVC_CLASS_NAME);
      RegisterView(UsrProfDisableSiteMapView.STR_MVC_CLASS_NAME, DisableSiteMapView.STR_MVC_CLASS_NAME,
       commModel);
      // Register the page list as a plug-in section
      RegisterModel(PageListModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_PAGE_LIST);
      // Get back the Model we just registered because we need 
      // it to register the view and the Control
      IModel myPageListModel = GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST);
      RegisterView(PageListView.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_PAGE_LIST,
       myPageListModel);
      RegisterControl(PageListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_PAGE_LIST,
       myPageListModel);
      // Register the community template selector as a plug-in section
      RegisterModel(CommunityTemplateSelectorModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myCommunityTemplateSelectorModel = GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR);
      RegisterView(TemplateListView.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR,
       myCommunityTemplateSelectorModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR,
       myCommunityTemplateSelectorModel);
      // --- BANNER, HEADER and FOOTER objects
      RegisterPage(new HeaderAndFooterSelectorDP());
      m_mEditorMenu.AddLinkToSubMenu(_subMenuID, HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME);
      RegisterView(HeaderAndFooterSelectorView.STR_MVC_CLASS_NAME, commModel);
      RegisterControl(HeaderAndFooterRepostControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_HEADER_AND_FOOTER_SELECTOR,
       commModel);
      // --- DEPENDENCY VIEW
      RegisterView(CommunityDependenciesView.STR_MVC_CLASS_NAME, commModel);
      // The following go under the standard settings section
      int stdSettingsMenu = m_mEditorMenu.StartNewSubMenu(GetString(2187,
       "ptmsgs_portaladminmsgs"));
      // --- SECURITY
      ((ObjectSecurityModel) GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetLeftNavString(GetString(221,
       "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(stdSettingsMenu, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      // --- MIGRATION HISTORY AND STATUS
      m_mEditorMenu.AddLinkToSubMenu(stdSettingsMenu, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // --- register the following objects because our repost control, 
      //   UsrProfMgrRepostControl calls CommunityEditorRepostControl
      //   and that control calls these models and controls.  in our AS
      //   these won't actually do be used for anything
      IModel myTempModel;
      // --- CommunityGroups list/create page
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST);
      myTempModel = GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST,
       myTempModel);
      //		RegisterPage(new CommunityEditorCommGroupDP());
      //		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,CommunityEditorAS.m_strRegIDCommGroups, mySelectPTObjectModel);
      // --- Subcommunity list/create page
      RegisterModel(CommunityEditorSubcommunityModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST);
      myTempModel = GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST,
       myTempModel);
      //		RegisterPage(new CommunityEditorSubcommunityDP());
      //		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,m_strRegIDSubCommunities, mySelectPTObjectModel);
      // --- COMMUNITY PORTLETS
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST);
      myTempModel = GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST,
       myTempModel);
      RegisterPage(new CommunityEditorCommPortletDP());
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST,
       myTempModel);
      m_mEditorMenu.AddLinkToSubMenu(_subMenuID, CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME);
      }
    
    /// <summary>
    /// Registers all the user info property map classes for this Activity Space.
    /// </summary>
    public virtual void InitUserInfoPropMapObjects(int _subMenuID)
    {
      // --- USER INFO PROPERTY MAP OBJECTS
      RegisterModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
      RegisterPage(new MainDP());
      RegisterControl(UserInfoPropMapRepostControl.STR_MVC_CLASS_NAME, GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME));
      // --- USER INFO PROPERTY PLUG-IN OBJECTS
      RegisterModel(UserInfoPropMapListModel.STR_MVC_CLASS_NAME, UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN);
      // userinfoprop plug-in model's control and view
      IModel plugInModel = GetModel(UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN);
      RegisterView(PTMultiColumnListView.STR_MVC_CLASS_NAME, UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN,
       plugInModel);
      RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN,
       plugInModel);
      // --- add the userinfo main dp to submenu
      m_mEditorMenu.AddLinkToSubMenu(_subMenuID, MainDP.STR_MVC_CLASS_NAME);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()"></seealso>
    public override String GetDependenciesViewName()
    {
      return (CommunityDependenciesView.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      /* set the main model name and call super class's init */
      m_strModelName = UsrProfMgrModel.STR_MVC_CLASS_NAME;
      base.Init();
      /* get the main model and repost control and register them */
      IModel myModel = GetModel(m_strModelName);
      RegisterControl(UsrProfMgrRepostControl.STR_MVC_CLASS_NAME, myModel);
      /* register the profile layout sections and objects */
      //		InitLayoutPages(myModel);
      // id for the user profile community & prop info submenu
      int editSettingsMenu = m_mEditorMenu.StartNewSubMenu(GetString(383,
       "ptmsgs_portaladminmsgs"));
      /* initialize the user profile community objects */
      InitProfileCommunityObjects(editSettingsMenu);
      /* initialize the user info property map objects */
      InitUserInfoPropMapObjects(editSettingsMenu);
      /* initialize the close popup objects */
      InitClosePopup();
      /* initialize tips */
      InitTips();
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from AFormDP can
    /// override if they like.  The method provides a hook into the head so
    /// that DP's can add javascript. Simply override and return and
    /// HTMLScript.  Also, it is best to return the results of the
    /// DisplayJavaScript functions from the appropriate views.
    /// </summary>
    /// <returns>HTMLScriptCollection the Javascript from the Child IViews</returns>
    /// <throws>
    /// HTMLException If error occurs while creating or populating
    /// HTML Elements.
    /// </throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()">Override this method to Display javascript from child IViews</seealso>
    public override HTMLScriptCollection DisplayCommonJavaScript()
    {
      HTMLScriptCollection scripts = base.DisplayCommonJavaScript();
      HTMLScript script = new HTMLScript("text/javascript");
      script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
      scripts.AddInnerHTMLElement(script);
      script = new HTMLScript("text/javascript");
      scripts.AddInnerHTMLElement(script);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n").Append("function ").Append(CommunityEditorAS.JS_ALERTSAVEFORPREFS_FUNC).Append("()").Append("{\n").Append("\t\tif ( confirm(\'").Append(GetString(1228,
       "ptmsgs_portalbrowsingmsgs")).Append("\') )\n").Append("\t\t{\n").Append("\t\t\treturn true;").Append("\t\t}\n").Append("\t\treturn false;").Append("}\n");
      script.AddInnerHTMLString(sb.ToString());
      return scripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (UsrProfCommPagesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_UserProfileManager_ProfilePages");
      } else
      if (HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_Community_HeaderandFooter");
      } else
      if (CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_Community_ThisCommunitysPortlets");
      } else
      if (MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_MigrationHistoryandStatus");
      } else
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_UserProfileManager_UserInformationPropertyMap");
        }
    }
  }
}