using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.ptutilities.userinfopropmap;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.userprofilemanager
{
  /// <author>JHQ</author>
  /// <author>
  /// jennifersu
  /// This is the main model for the user profile manager.  Because the user
  /// profile manager encompasses multiple activity spaces and models, this model
  /// does not extend any particular model (i.e. CommunityEditorModel).  Instead,
  /// it calls those models' methods directly.  The models called within here are:
  /// CommunityEditorModel, PageListModel, and UserInfoPropMapModel
  /// </author>
  public class UsrProfMgrModel : ObjEditorModel,IUsrProfMgrModelRO,IMigrationModelRO,
  IDescriptionModelRO
  {
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserProfileManager";
    //	private XPArrayList m_newObjectKeys = new XPArrayList();
    
    /// <summary>
    /// array of new object ids 
    /// </summary>
    private String m_propsDisplayString = "";
    //	private XPArrayList m_listOfGlobalUserProps;
    public const int PT_ACCESS_LIST_ENTRY_READWRITE = 0;
    
    /// <summary>
    /// Server object: Plumtree Session 
    /// </summary>
    protected IPTSession m_Session;
    
    /// <summary>
    /// Flag to know if the current user has system administration activity rights.
    /// We need it to know when to display the migration checkbox.
    /// </summary>
    protected bool m_bIsSysAdmin;
    
    /// <summary>
    /// Object migration status 
    /// </summary>
    private int m_nMigrationStatus;
    public UsrProfMgrModel() : base()
    {
      m_nMigrationStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE;
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()"></seealso>
    public override void Cancel()
    {
      base.Cancel();
      /* cancel usr profile community */
      ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).Cancel();
      /* init user info property map model */
      UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
      propMapModel.Cancel();
    }
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      InitIsSysAdminFlag();
      // --- start the user profile community editor */
      CommunityEditorModel commModel = (CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME);
      commModel.SetEditorType(EditorStartControl.EDITOR_START_FLAG_EDIT);
      _htFormData.PutElement(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, new String[]{"" + PT_CLASSIDS.PT_COMMUNITY_ID});
      _htFormData.PutElement(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID, new String[]{"" + PT_INTRINSICS.PT_PROFILE_COMMUNITY});
      _htFormData.PutElement(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID, new String[]{"" + PT_INTRINSICS.PT_ADMIN_FOLDER_PROFILECOMMUNITY});
      _htFormData.PutElement(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER,
       new String[]{XPConvert.ToString(true)});
      if (!commModel.CheckEditorAccessAndStart(_htFormData))
      {
        return false;
      }
      // --- modify the pagelist's strings so that it reads "user profile" vs
      //  "community"
      PageListModel myPageListModel = (PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST);
      myPageListModel.SetSectionTitle(m_asOwner.GetString(2195, "ptmsgs_portaladminmsgs"));
      myPageListModel.SetAddLabel(m_asOwner.GetString(2356, "ptmsgs_portaladminmsgs"));
      // --- start the user info property map editor
      UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
      if (!propMapModel.CheckEditorAccessAndStart(_htFormData))
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(995, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(996,
         "ptmsgs_portaladminmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return false;
      }
      // --- for our proposes, we do not need the mandatory column
      ((ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetSupportMandatoryColumn(ObjectSecurityModel.MANDCOL_NONE);
      ((PriorityDropDownModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN)).SetSupportMandatoryColumn(false);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UsrProfMgrModel();
    }
    
    /// <summary>
    /// Code executed in finish.
    /// </summary>
    public override void Finish()
    {
      /* finish user profile community model */
      ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).Finish();
      /* finish user info property map model */
      UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
      propMapModel.Finish();
    }
    
    /// <summary>
    /// Returns the value of the m_bIsSysAdmin member variable.
    /// </summary>
    /// <returns>boolean</returns>
    public override bool GetIsSysAdmin()
    {
      return m_bIsSysAdmin;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      // Get the Session object from the associated AS.
      m_Session = (IPTSession) parent.GetUserSession();
    }
    
    /// <summary>
    /// Returns true if the object description cannot be set/changed from the Editor.
    /// This is here mainly because ObjEditor has this method and the
    /// locNamesPrimaryNameView uses this to determine whether or not to display
    /// the description field and js validation.  For our proposes, we will
    /// always display the discription field.  So this will always return false.
    /// </summary>
    /// <returns>boolean</returns>
    public override bool IsDescriptionDisabled()
    {
      return false;
    }
    
    /// <summary>
    /// Returns true if the migration has already been approved for the current
    /// object.
    /// </summary>
    /// <returns>boolean</returns>
    public override bool IsMigrationApproved()
    {
      if (PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED == m_nMigrationStatus)
      {
        return true;
      } else
      {
        return false;
      }
    }
    
    /// <summary>
    /// Helper method to save the migration status checkbox.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMigrationStatus(XPHashtable _htFormData)
    {
      if (_htFormData.ContainsKey(MigrationHistoryView.HTMLCHECKBOX_MIGRATION))
      {
        m_nMigrationStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED;
        } else
      {
        m_nMigrationStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE;
        }
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      /* save page on user profile community */
      if (RepostControl.PAGE_STATUS_INVALID == ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).SavePage(_sPageName,
       _htFormData))
      {
        return RepostControl.PAGE_STATUS_INVALID;
      }
      /* save page for user info property map model */
      UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
      if (RepostControl.PAGE_STATUS_INVALID == propMapModel.SavePage(_sPageName,
       _htFormData))
      {
        return RepostControl.PAGE_STATUS_INVALID;
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Helper method to determine activity rights.
    /// </summary>
    protected virtual bool CheckActivityRight()
    {
      return m_Session.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_PROFILE_LAYOUT);
      }
    
    /// <summary>
    /// Helper method to init the isSysAdmin flag.
    /// </summary>
    protected override void InitIsSysAdminFlag()
    {
      m_bIsSysAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin(m_Session);
      }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnChangePage(java.lang.String, java.lang.String)
     */
     
    public override void DoTaskOnChangePage(String _sNewSpaceName, String _sNewPageName)
    {
      base.DoTaskOnChangePage(_sNewSpaceName, _sNewPageName);
      /* finish user profile community model */
      ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskOnChangePage(_sNewSpaceName,
       _sNewPageName);
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnComeBackFromSubEditor()
     */
     
    public override void DoTaskOnComeBackFromSubEditor()
    {
      base.DoTaskOnComeBackFromSubEditor();
      /* finish user profile community model */
      ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskOnComeBackFromSubEditor();
      }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskAfterStore()
     */
     
    public override void DoTaskAfterStore()
    {
      base.DoTaskAfterStore();
      /* finish user profile community model */
      ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskAfterStore();
      }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()
     */
     
    public override void DoTaskBeforeStore()
    {
      base.DoTaskBeforeStore();
      /* finish user profile community model */
      ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStore();
      }
    
    /// <summary>
    /// if the property display string is empty than that means that no
    /// properties were mapped to user objects via the global object properties
    /// map.
    /// </summary>
    /// <returns>boolean if displaystring is blank.</returns>
    public virtual bool IsPropertiesMapEmpty()
    {
      return m_propsDisplayString.Equals("");
    }
  }
}