using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice
{
  /// <author>adolfoc</author>
  public class AdvURLSettingsDP : WSPluginDP
  {
    
    /// <summary>
    /// Class Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AdvURLSettingsDP";
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetAllPossibleViews()"></seealso>
    public override XPArrayList GetAllPossibleViews()
    {
      XPArrayList xpWSViews = new XPArrayList();
      xpWSViews.Add(WebServiceEditorAS.strStorage_HelpURLPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_RemoteConfigPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_RemoteMigrationPluginView);
      return xpWSViews;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(1185, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(3235, "ptmsgs_portaladminmsgs"),
       m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetOrderedViewList(int)"></seealso>
    public override XPArrayList GetOrderedViewList(int nWSMode)
    {
      XPArrayList xpWSViews = new XPArrayList();
      switch (nWSMode){
      case WebServiceModel.WSMODE_PORTLET:
      xpWSViews.Add(WebServiceEditorAS.strStorage_HelpURLPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_RemoteConfigPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_RemoteMigrationPluginView);
      break;
      case WebServiceModel.WSMODE_PAGELET:
      xpWSViews.Add(WebServiceEditorAS.strStorage_HelpURLPluginView);
      // TODO: Do we need the remote migration view?
      break;
      case WebServiceModel.WSMODE_INTRINSIC_PORTLET:
      break;
      case WebServiceModel.WSMODE_AWS:
      case WebServiceModel.WSMODE_PWS:
      case WebServiceModel.WSMODE_MWS:
      // AGC- Note, the XUI URL used to be on this page, but it has been
      // moved to the AdvSettings page in order to shorten the number of pages.
      break;
      case WebServiceModel.WSMODE_CWS:
      case WebServiceModel.WSMODE_SWS:
      xpWSViews.Add(WebServiceEditorAS.strStorage_XUIURLPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_RemoteConfigPluginView);
      break;
      case WebServiceModel.WSMODE_NONE:
      default:
      break;
      }
      return xpWSViews;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetPluginHelpTopic()
     */
     
    public override String GetPluginHelpTopic()
    {
      WebServiceModel mParentModel = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      switch (mParentModel.GetWSMode()){
      case WebServiceModel.WSMODE_PORTLET:
      return "PT_WebService_Portlet_Remote_AdvancedURLSettings";
      goto case WebServiceModel.WSMODE_PAGELET;
      case WebServiceModel.WSMODE_PAGELET:
      return "PT_WebService_Pagelet_AdvancedURLSettings";
      goto case WebServiceModel.WSMODE_CWS;
      case WebServiceModel.WSMODE_CWS:
      return "PT_WebService_Crawler_AdvancedURLSettings";
      goto case WebServiceModel.WSMODE_SWS;
      case WebServiceModel.WSMODE_SWS:
      return "PT_WebService_Search_AdvancedURLSettings";
      goto case WebServiceModel.WSMODE_INTRINSIC_PORTLET;
      case WebServiceModel.WSMODE_INTRINSIC_PORTLET:
      case WebServiceModel.WSMODE_AWS:
      case WebServiceModel.WSMODE_PWS:
      case WebServiceModel.WSMODE_MWS:
      case WebServiceModel.WSMODE_NONE:
      default:
      break;
      }
      return null;
    }
  }
}