using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice
{
  /// <author>adolfoc</author>
  public class HTTPConfigDP : WSPluginDP
  {
    //MES- CR: Doesn't match class name
    //AGC- CR-Response: Same deal, I was getting name collision, so I changed it.
    //  The name is arbitrary as long as it is reasonably unique.    
    public const String STR_MVC_CLASS_NAME = "WebServiceHTTPConfigDP";
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetAllPossibleViews()"></seealso>
    public override XPArrayList GetAllPossibleViews()
    {
      XPArrayList xpWSViews = new XPArrayList();
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayCachingPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
      return xpWSViews;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(1188, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1671, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetOrderedViewList(int)"></seealso>
    public override XPArrayList GetOrderedViewList(int nWSMode)
    {
      XPArrayList xpWSViews = new XPArrayList();
      switch (nWSMode){
      case WebServiceModel.WSMODE_PORTLET:
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayCachingPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
      break;
      case WebServiceModel.WSMODE_PAGELET:
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayCachingPluginView);
      //xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
      // rob: This view is not displayed in Pagelet WS editors but we add a hardcoded gateway prefix
      // to all pagelet WS so we need this view in the list so that the GW prefix model will save its data.
      // The view is hidden by adding special case logic in WSPluginDP.PageDisplay
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
      break;
      case WebServiceModel.WSMODE_AWS:
      case WebServiceModel.WSMODE_PWS:
      case WebServiceModel.WSMODE_MWS:
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
      break;
      case WebServiceModel.WSMODE_INTRINSIC_PORTLET:
      break;
      case WebServiceModel.WSMODE_CWS:
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
      break;
      case WebServiceModel.WSMODE_SWS:
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
      xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
      break;
      case WebServiceModel.WSMODE_NONE:
      default:
      break;
      }
      return xpWSViews;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetPluginHelpTopic()
     */
     
    public override String GetPluginHelpTopic()
    {
      WebServiceModel mParentModel = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      switch (mParentModel.GetWSMode()){
      case WebServiceModel.WSMODE_PORTLET:
      return "PT_WebService_Portlet_Remote_HTTPConfiguration";
      goto case WebServiceModel.WSMODE_PAGELET;
      case WebServiceModel.WSMODE_PAGELET:
      return "PT_WebService_Pagelet_HTTPConfiguration";
      goto case WebServiceModel.WSMODE_CWS;
      case WebServiceModel.WSMODE_CWS:
      return "PT_WebService_Crawler_HTTPConfiguration";
      goto case WebServiceModel.WSMODE_SWS;
      case WebServiceModel.WSMODE_SWS:
      return "PT_WebService_Search_HTTPConfiguration";
      goto case WebServiceModel.WSMODE_AWS;
      case WebServiceModel.WSMODE_AWS:
      case WebServiceModel.WSMODE_PWS:
      case WebServiceModel.WSMODE_MWS:
      return "PT_WebService_httpconfiguration";
      goto case WebServiceModel.WSMODE_INTRINSIC_PORTLET;
      case WebServiceModel.WSMODE_INTRINSIC_PORTLET:
      case WebServiceModel.WSMODE_NONE:
      default:
      break;
      }
      return null;
    }
  }
}