using System;
using com.plumtree.server;
namespace com.plumtree.portalpages.admin.editors.webservice
{
  /// <author>
  /// adolfoc
  /// This interface must be implemented by any plugin model that wishes to receive
  /// updates from the WebServiceModel. Each plugin model must also be registered with
  /// the WebServiceModel using
  /// WebServiceModel.RegisterWSSubModel(String strPluginModelStorageName).
  /// </author>
  public interface IWSSubModel
  {
    
    /// <summary>
    /// Sub models are expected to store themselves to the ptWebService object passed in
    /// in InitWSModel during this call.
    /// </summary>
    void DoTaskBeforeWSStore();
    
    /// <summary>
    /// Called when the Remote Server is changed. This is mostly used to update the base-url
    /// displayed before URL edit boxes.
    /// </summary>
    void DoTaskOnRemoteServerUpdate(String strRemoteServerID, String strRemoteServerName,
     String strRemoteServerBaseURL);
    
    /// <summary>
    /// Called when the Web Service type is changed.
    /// </summary>
    void DoTaskOnWSModeUpdate(int nNewWSMode);
    
    /// <summary>
    /// This returns the name of the client-side validation function that the model
    /// wants added to the page-level validation funtion. Models return null or "" if
    /// they don't have a validation function.
    /// </summary>
    String GetValidationFunction();
    
    /// <summary>
    /// Initializes the sub-model. Provides an opportunity for the submodel to
    /// load it's state from the WebService.
    /// </summary>
    void InitWSModel(IPTWebService ptWebService);
  }
}