using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice.plugins;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.editors.webservice
{
  /// <author>adolfoc</author>
  public class WebServiceModel : ObjEditorModel,IWebServiceModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.WebServiceModel");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "WebService";
    //The WSType hasn't been chosen yet. // In the current UI this is not used, but it could be revived in the future.
    
    /// <summary>
    /// The additional display modes this WebService Editor can be in. This mostly depends
    /// on the Web Service Type.
    /// </summary>
    public const int WSMODE_NONE = 0;
    //Portlet Mode
    public const int WSMODE_PORTLET = 2;
    // Intrinsic Portlet Mode
    public const int WSMODE_INTRINSIC_PORTLET = 3;
    //AuthSourceWS Mode
    public const int WSMODE_AWS = 4;
    //CrawlerWS Mode
    public const int WSMODE_CWS = 5;
    //SearchWS Mode 
    public const int WSMODE_SWS = 6;
    //ProfileWS Mode
    public const int WSMODE_PWS = 7;
    //MigrationWS Mode
    public const int WSMODE_MWS = 8;
    //Ensemble Pagelet Mode
    public const int WSMODE_PAGELET = 9;
    
    /// <summary>
    /// The remote server ID passed into this editor. - Used in create mode to
    /// pre-assign us a Remote server object.
    /// </summary>
    private int m_intRemoteServerIDPassedIn = 0;
    
    /// <summary>
    /// This member maintains a registry of page names that extend
    /// WSPluginDP. We must remember to enable and disable these pages
    /// when the appropriate updates occur.
    /// </summary>
    internal XPArrayList m_xalWSPluginDPs;
    
    /// <summary>
    /// This member maintains a registry of Plugin model keys that support
    /// the IWSSubModel interface. We must remember to exercise the IWSSubModel
    /// interface on them when the appropriate updates occur.
    /// </summary>
    internal XPArrayList m_xalWSSubModels;
    
    /// <summary>
    /// This member defines the current mode of the WSEditor (as per the above enumeration);
    /// When this member is changed, we must send an update to all of our pages and views.
    /// </summary>
    private int m_nWSMode;
    public WebServiceModel() : base()
    {
      m_xalWSPluginDPs = new XPArrayList();
      m_xalWSSubModels = new XPArrayList();
      m_nWSMode = WSMODE_NONE;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new WebServiceModel();
    }
    // **************************************** Persistence ******************************************
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()"></seealso>
    public override void DoTaskBeforeStore()
    {
      base.DoTaskBeforeStore();
      // Make sure that the provider info property bag set to the correct format.
      IPTWebService ptWebService = (IPTWebService) m_ptObject;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      switch (GetWSMode()){
      case WSMODE_INTRINSIC_PORTLET:
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT,
       AExtensibilityConstants.PT_PROPBAG_FORMAT_INTRINSICGADGET_INIT);
      goto default;
      // TODO: Shouldn't this break here?  Otherwise we'll always wind up
      // with the non-intrinsic format.  Unless the 1st write always wins.
      // Either way, this should have a break.
      default:
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT,
       AExtensibilityConstants.PT_PROPBAG_FORMAT_HTTPGADGET_INIT);
      break;
      }
      // All of our sub models store their own data.... yippee!
      PreStoreWSSubModels();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnStartEditor(_htFormData)"></seealso>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      base.DoTaskOnStartEditor(_htFormData);
      try
      {
        String strWSType = WSModelHelper.WSTYPE_HTTPGP;
        // In create mode, we set our editor mode based on the 
        // activity space name that created us.
        if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
        {
          //AGC- Let's choose our mode based on the name of our ActivitySpace.
          if (0 == AuthWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_AWS;
            strWSType = WSModelHelper.WSTYPE_AWS;
          } else
          if (0 == CrawlWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_CWS;
            strWSType = WSModelHelper.WSTYPE_CWS;
          } else
          if (0 == IntrPortWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_INTRINSIC_PORTLET;
            strWSType = WSModelHelper.WSTYPE_IGP;
          } else
          if (0 == ProfileWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_PWS;
            strWSType = WSModelHelper.WSTYPE_PWS;
          } else
          if (0 == RemPortWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_PORTLET;
            strWSType = WSModelHelper.WSTYPE_HTTPGP;
          } else
          if (0 == RemPageletWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_PAGELET;
            strWSType = WSModelHelper.WSTYPE_HTTPPAGELET;
            // Lookup the ID of the Ensemble Remote Server.
            // All remote pagelet web services share the same remote server that
            // points to the base Ensemble install.  We need to set this on the
            // web service, since the user will not be allowed to change/select it.
            // The code at the end of the create block will set it for us.
            m_intRemoteServerIDPassedIn = GetEnsembleRemoteServer();
            // This method sets various required pagelet settings, such as always
            // sending the csp-login token.
            SetupPageletSettings();
          } else
          if (0 == SearchWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_SWS;
            strWSType = WSModelHelper.WSTYPE_SWS;
          } else
          if (0 == MWSWebServiceEditorAS.STR_MVC_CLASS_NAME.CompareTo(m_asOwner.GetName()))
          {
            m_nWSMode = WSMODE_MWS;
            strWSType = WSModelHelper.WSTYPE_MWS;
          }
          IPTWebService ptWebService = (IPTWebService) m_ptObject;
          ptWebService.SetProviderCLSID(strWSType);
          if (m_intRemoteServerIDPassedIn > 0)
          {
            //AGC- Attempt to set the Remote Server ID that was passed to us.
            ptWebService.SetRemoteServerID(m_intRemoteServerIDPassedIn);
          }
        } else
        {
          IPTWebService ptWebService = (IPTWebService) m_ptObject;
          String strProviderID = ptWebService.GetProviderCLSID();
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_HTTPGP))
          {
            m_nWSMode = WebServiceModel.WSMODE_PORTLET;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_HTTPPAGELET))
          {
            m_nWSMode = WebServiceModel.WSMODE_PAGELET;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_IGP))
          {
            m_nWSMode = WebServiceModel.WSMODE_INTRINSIC_PORTLET;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_AWS))
          {
            m_nWSMode = WebServiceModel.WSMODE_AWS;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_PWS))
          {
            m_nWSMode = WebServiceModel.WSMODE_PWS;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_CWS))
          {
            m_nWSMode = WebServiceModel.WSMODE_CWS;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_SWS))
          {
            m_nWSMode = WebServiceModel.WSMODE_SWS;
          } else
          if (0 == strProviderID.CompareTo(WSModelHelper.WSTYPE_MWS))
          {
            m_nWSMode = WebServiceModel.WSMODE_MWS;
          }
        }
        if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
        {
          ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
          }
        UpdatePages();
        InitWSSubModels();
        UpdateWSSubModels();
        if (m_nWSMode == WSMODE_PAGELET)
        {
          // For remote pagelets, we want to show that the Web Service is based off the
          // Ensemble remote server, but we don't want to let users change it.
          RemoteServerPluginModel remoteServerModel = (RemoteServerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemoteServerPluginView);
          remoteServerModel.SetIsReadOnly(true);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::DoTaskOnStartEditor - Unable to initialize editor from server.");
        }
    }
    // ************************************ Basic Model Settings *************************************
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the nWSMode.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetWSMode()
    {
      return m_nWSMode;
    }
    public virtual String GetWSObjectTitle()
    {
      String s = null;
      switch (GetWSMode()){
      // Remote Portlet
      case WSMODE_PORTLET:
      s = m_asOwner.GetString(2375, "ptmsgs_portaladminmsgs");
      break;
      // Remote Pagelet
      case WSMODE_PAGELET:
      s = m_asOwner.GetString(3234, "ptmsgs_portaladminmsgs");
      break;
      // Intrinsic Portlet
      case WSMODE_INTRINSIC_PORTLET:
      s = m_asOwner.GetString(2371, "ptmsgs_portaladminmsgs");
      break;
      // Authentication
      case WSMODE_AWS:
      s = m_asOwner.GetString(2374, "ptmsgs_portaladminmsgs");
      break;
      // Crawler
      case WSMODE_CWS:
      s = m_asOwner.GetString(2376, "ptmsgs_portaladminmsgs");
      break;
      // Search
      case WSMODE_SWS:
      s = m_asOwner.GetString(2372, "ptmsgs_portaladminmsgs");
      break;
      // Profile
      case WSMODE_PWS:
      s = m_asOwner.GetString(2373, "ptmsgs_portaladminmsgs");
      break;
      // Migration
      case WSMODE_MWS:
      s = m_asOwner.GetString(0, "ptmsgs_provUIMWS");
      break;
      // Unknown
      default:
      s = m_asOwner.GetString(1544, "ptmsgs_portaladminmsgs");
      break;
      }
      return s;
    }
    public virtual String GetWSObjectMiniHelp()
    {
      String s = null;
      switch (GetWSMode()){
      // Specify the Remote Server that will host this Web Service.
      case WSMODE_PORTLET:
      s = m_asOwner.GetString(2382, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Remote Server that will host this Web Service.
      case WSMODE_PAGELET:
      s = m_asOwner.GetString(3233, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Portlet Class Identifier for this Web Service.
      case WSMODE_INTRINSIC_PORTLET:
      s = m_asOwner.GetString(2378, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Remote Server that will host this Web Service and any additional settings required.
      case WSMODE_AWS:
      s = m_asOwner.GetString(2381, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Container and Document URL settings.
      case WSMODE_CWS:
      s = m_asOwner.GetString(2383, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Remote Server that will host this Web Service.
      case WSMODE_SWS:
      s = m_asOwner.GetString(2379, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Remote Server that will host this Web Service.
      case WSMODE_PWS:
      s = m_asOwner.GetString(2380, "ptmsgs_portaladminmsgs");
      break;
      // Specify the Remote Server that will host this Web Service.
      case WSMODE_MWS:
      s = m_asOwner.GetString(2381, "ptmsgs_portaladminmsgs");
      break;
      }
      return s;
    }
    // ************************************ Getters and Setters *************************************
    
    /// <summary>
    /// Returns the arraylist of views that are registered IWSSubModels...
    /// </summary>
    public virtual XPArrayList GetWSViews()
    {
      return m_xalWSSubModels;
    }
    // ************************************ IWSSubModel methods ***************************************
    
    /// <summary>
    /// This method is used to register a new WSPluginDP with this WebService main model. This is done
    /// so that plugin pages can be hidden and shown automatically depending on the WSMODE.
    /// </summary>
    public virtual void RegisterWSPage(String strDPName)
    {
      try
      {
        IDisplayPage myIDP = m_asOwner.GetPage(strDPName);
        WSPluginDP myWSPDP = null;
        try
        {
          myWSPDP = (WSPluginDP) myIDP;
          myWSPDP.InitPluginDP();
        }
        catch (Exception e)
        {
          log.Error(e, "WebServiceModel::RegisterWSPage(\"" + strDPName + "\") - Attempted to register page that doesn\'t extend WSPluginDP.");
          }
        if (null == myWSPDP)
        {
          log.Error("WebServiceModel::RegisterWSPage(\"" + strDPName + "\") - Attempted to register null WSPluginDP. Error:");
          } else
        {
          m_xalWSPluginDPs.Add(strDPName);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::RegisterWSPage(\"" + strDPName + "\") - Could not register page.");
        }
    }
    
    /// <summary>
    /// This method is used to register a new submodel with this WebService main model. This is done
    /// so that submodels can have access to the Remote Server base URL which is necessary for them
    /// to display. All submodels that are registered must support the IWSSubModel interface.
    /// </summary>
    public virtual void RegisterWSSubModel(String strPluginModelStorageName)
    {
      try
      {
        IModel imSubModel = m_asOwner.GetModel(strPluginModelStorageName);
        IWSSubModel wsSubModel = null;
        try
        {
          wsSubModel = (IWSSubModel) imSubModel;
        }
        catch (Exception e)
        {
          log.Error(e, "WebServiceModel::RegisterWSSubModel(\"" + strPluginModelStorageName + "\") - Attempted to register model that doesn\'t support IWSSubModel.");
          }
        if (null == wsSubModel)
        {
          log.Error("WebServiceModel::RegisterWSSubModel(\"" + strPluginModelStorageName + "\") - Attempted to register null IWSSubModel. Error:");
          } else
        {
          m_xalWSSubModels.Add(strPluginModelStorageName);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::RegisterWSSubModel(\"" + strPluginModelStorageName + "\") - Could not register model.");
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      //MES- CR: If the status is now invalid, can we return without going through the models?
      //AGC- CR-Response: Note, we still need to update the local variables with any changed information.
      //        It would be very strange if users found that all of the settings they changed on a page
      //        revert to their original values if any single setting is incorrect.    	
      IDisplayPage myDP = m_asOwner.GetPage(_sPageName);
      WSPluginDP myWSDP = null;
      try
      {
        //AGC - try to cast to WSPluginDP
        myWSDP = (WSPluginDP) myDP;
      }
      catch (Exception e)
      {
        // Didn't work. It's someone else's page. Just return.  No need to log an error.
        return nPageStatus;
      }
      // Just double checking.
      if (null == myWSDP)
      {
        return nPageStatus;
      }
      //AGC- CR-Response: Note, we assume that the views and their associated Models have the same storage key
      //     (this is a necessary part of the automated view-model framework). If the following code
      //     looks strange (using views to enumerate models) that's why. 
      XPArrayList xpalWSViews = myWSDP.GetOrderedViewList(GetWSMode());
      IXPEnumerator xpEnumWSSubModels = xpalWSViews.GetEnumerator();
      while (xpEnumWSSubModels.MoveNext())
      {
        String strSubModelKeyCurrent = (String) xpEnumWSSubModels.GetCurrent();
        try
        {
          IWSSubModel wsSubModelCurrent = (IWSSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
          int nLocalStatus = ((EditorHelperModel) wsSubModelCurrent).SaveSection(_htFormData);
          if (EditorRepostControl.PAGE_STATUS_VALID != nLocalStatus)
          {
            nPageStatus = nLocalStatus;
          }
        }
        catch (Exception e)
        {
          log.Error(e, GetName() + "::SavePage(" + _sPageName + ") An error occured when trying to Save the Section(" + strSubModelKeyCurrent + ").");
          }
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Sets the nWSMode.
    /// </summary>
    /// <param name="nWSMode">The nWSMode to set</param>
    public virtual void SetWSMode(int nWSMode)
    {
      m_nWSMode = nWSMode;
      // AGC- Don't forget to hide/show all of our pages based on the new information...
      UpdatePages();
      // AGC- The views should be told as well... just in case they care...
      UpdateWSSubModels();
    }
    public virtual void UpdateWSSubModels()
    {
      try
      {
        IXPEnumerator xpEnumWSSubModels = m_xalWSSubModels.GetEnumerator();
        while (xpEnumWSSubModels.MoveNext())
        {
          String strSubModelKeyCurrent = "";
          try
          {
            strSubModelKeyCurrent = (String) xpEnumWSSubModels.GetCurrent();
            IWSSubModel wsSubModelCurrent = (IWSSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
            wsSubModelCurrent.DoTaskOnRemoteServerUpdate(XPConvert.ToString(GetRemoteServerObjectID()),
             GetRemoteServerName(), GetRemoteServerBaseURL());
            wsSubModelCurrent.DoTaskOnWSModeUpdate(GetWSMode());
          }
          catch (Exception e)
          {
            log.Error(e, "WebServiceModel::UpdateWSSubModels() Unknown Error updating WSSubModel (" + strSubModelKeyCurrent + ").");
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::UpdateWSSubModels() Unknown Error.");
        }
    }
    
    /// <summary>
    /// This method sets various required pagelet settings, such as always
    /// sending the csp-login token.
    /// </summary>
    protected virtual void SetupPageletSettings()
    {
      // NOTE: This entire method is copied from AdvSettingsPluginModel.DoTaskBeforeWSStore
      // and just sets different default settings for pagelets.
      IPTWebService ptWebService = (IPTWebService) m_ptObject;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      // TODO: token timeout should still be a setting.
      ptProviderInfo.Write(AExtensibilityConstants.PTC_HTTPGADGET_LOGINTOKENVALID,
       5);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDPAGEID,
       false);
      // The pagelet API in Ensemble requires the csp-login token for authentication.
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDLOGINTOKEN,
       true);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDCOMMUNITYACL,
       false);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDTIMEZONE,
       false);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSACLIMPORT,
       false);
      // TODO: Do we support mirroring?  Does this mean load-balancing?
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSMIRRORING,
       false);
      // TODO: Do we support shared settings?
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTP_SESSION_TYPE,
       false);
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SENDSUBPORTALID,
       false);
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SENDALIGNMENT,
       false);
      ptWebService.SetCardSubmitType(0);
    }
    
    /// <returns>the Object ID of the Ensemble Remote Server.</returns>
    protected virtual int GetEnsembleRemoteServer()
    {
      int nID = EnsembleHelperService.getInstance().GetRemoteServerID(m_Session);
      if (nID <= 0)
      {
        // The Ensemble remote server is not installed on this machine.
        throw new XPIllegalStateException("Pagelet Web Services require the Ensemble Remote Server " + "to be present.  Please upload the Ensemble .pte file.");
        }
      return nID;
    }
    private String GetRemoteServerBaseURL()
    {
      return ((RemoteServerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemoteServerPluginView)).GetRemoteServerBaseURL();
      }
    private String GetRemoteServerName()
    {
      return ((RemoteServerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemoteServerPluginView)).GetRemoteServerName();
      }
    private long GetRemoteServerObjectID()
    {
      return ((RemoteServerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemoteServerPluginView)).GetRemoteServerObjectID();
      }
    private void InitWSSubModels()
    {
      try
      {
        IXPEnumerator xpEnumWSSubModels = m_xalWSSubModels.GetEnumerator();
        while (xpEnumWSSubModels.MoveNext())
        {
          String strSubModelKeyCurrent = "";
          try
          {
            strSubModelKeyCurrent = (String) xpEnumWSSubModels.GetCurrent();
            IWSSubModel wsSubModelCurrent = (IWSSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
            wsSubModelCurrent.InitWSModel((IPTWebService) m_ptObject);
          }
          catch (Exception e)
          {
            log.Error(e, "WebServiceModel::InitWSSubModels() Unknown Error initializing WSSubModel (" + strSubModelKeyCurrent + ").");
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::InitWSSubModels() Unknown Error.");
        }
    }
    private void PreStoreWSSubModels()
    {
      try
      {
        // AGC- Only store those views that are active in our current mode!
        IXPEnumerator xpEnumWSPluginDPs = m_xalWSPluginDPs.GetEnumerator();
        // Walk through all of the pages
        while (xpEnumWSPluginDPs.MoveNext())
        {
          WSPluginDP wsPluginDPCurrent = (WSPluginDP) m_asOwner.GetPage((String) xpEnumWSPluginDPs.GetCurrent());
          XPArrayList xpalModelsCurrent = wsPluginDPCurrent.GetOrderedViewList(m_nWSMode);
          IXPEnumerator xpEnumWSSubModels = xpalModelsCurrent.GetEnumerator();
          // Walk through each view on each page
          while (xpEnumWSSubModels.MoveNext())
          {
            String strSubModelKeyCurrent = "";
            try
            {
              strSubModelKeyCurrent = (String) xpEnumWSSubModels.GetCurrent();
              IWSSubModel wsSubModelCurrent = (IWSSubModel) m_asOwner.GetModel(strSubModelKeyCurrent);
              // Tell the buggers to prepare for the end times
              wsSubModelCurrent.DoTaskBeforeWSStore();
            }
            catch (Exception e)
            {
              log.Error(e, "WebServiceModel::PreStoreWSSubModels() Unknown Error updating WSSubModel (" + strSubModelKeyCurrent + ").");
              }
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::PreStoreWSSubModels() Unknown Error.");
        }
    }
    private void UpdatePages()
    {
      // Automatically hide empty pages and show pages with information
      try
      {
        IXPEnumerator xpEnumWSPluginDPs = m_xalWSPluginDPs.GetEnumerator();
        while (xpEnumWSPluginDPs.MoveNext())
        {
          try
          {
            String strDPNameCurrent = (String) xpEnumWSPluginDPs.GetCurrent();
            WSPluginDP wsPluginDPCurrent = (WSPluginDP) m_asOwner.GetPage(strDPNameCurrent);
            XPArrayList xpalViews = wsPluginDPCurrent.GetOrderedViewList(m_nWSMode);
            int nNumViews = xpalViews.GetSize();
            if (0 >= nNumViews)
            {
              ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, strDPNameCurrent);
              } else
            {
              ((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, strDPNameCurrent);
              }
          }
          catch (Exception e)
          {
            log.Error(e, "WebServiceModel::UpdateWSSubModels() Unknown Error updating WSSubModel.");
            }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "WebServiceModel::UpdateWSSubModels() Unknown Error.");
        }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.ObjEditorModel#SetMemberVariablesFromQS(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override void SetMemberVariablesFromQS(XPHashtable _htFormData)
    {
      base.SetMemberVariablesFromQS(_htFormData);
      m_intRemoteServerIDPassedIn = WSModelHelper.GetFormElementInt(_htFormData,
       PTWebServices.QS_WS_REMOTE_SERVER, m_intRemoteServerIDPassedIn);
    }
  }
}