using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.admin.editors.webservice.credvaulttree
{
  /// <author>JosephS</author>
  public class CredVaultRefreshTreeControl : RefreshTreeControl
  {
    
    /// <summary>
    /// name of the refresh tree control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CredVaultRefreshTree";
    
    /// <summary>
    /// A separator character used when encoding CredVault arguments. *
    /// </summary>
    private static String CREDVAULT_SEPARATORCHAR = ",";
    
    /// <summary>
    /// An encoding character used to encode/decode CredVaults *
    /// </summary>
    private static String CREDVAULT_ESCAPECHAR = "!";
    
    /// <summary>
    /// A Query String argument name - used for setting the selected USerInfos. 
    /// </summary>
    public const String SELECTED_CREDVAULTS = "SelectCredVault";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CredVaultRefreshTreeControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      Redirect rResult = base.CheckActionSecurityAndExecute(arguments);
      String[] sValues;
      // Object ids to select
      sValues = (String[]) arguments.GetElement(SELECTED_CREDVAULTS);
      if (sValues != null)
      {
        ((CredVaultTreeModel) m_asModel).SetCredVaultsToSelect(StringToCredVaults(sValues[0]));
        }
      // Now load the bugger.
      ((CredVaultTreeModel) m_asModel).LoadCredVault();
      return rResult;
    }
    
    /// <summary>
    /// Used for transferring Userinfo's via QueryString argument. Encodes an
    /// array of user info strings into a string usable as a QueryString
    /// argument.
    /// </summary>
    /// <param name="arsCredVaults"></param>
    /// <returns>String</returns>
    public static String CredVaultsToString(String[] arsCredVaults)
    {
      String strResult = "";
      for (int nIndex = 0;nIndex < arsCredVaults.Length;nIndex++)
      {
        if (0 != nIndex)
        {
          strResult+=CREDVAULT_SEPARATORCHAR;
        }
        strResult+=EscapeCredVault(arsCredVaults[nIndex]);
      }
      return strResult;
    }
    
    /// <summary>
    /// User for transferring Userinfo's via Query String. Decodes a string of
    /// userinfo's separated by tokens into an array of Userinfo's. Avoids
    /// mistaken tokens by using an escape character.
    /// </summary>
    /// <param name="strCredVaultData"></param>
    /// <returns>XPArrayList</returns>
    public static XPArrayList StringToCredVaults(String strCredVaultData)
    {
      XPStringTokenizer xpstUnEscape = new XPStringTokenizer(strCredVaultData,
       CREDVAULT_SEPARATORCHAR);
      XPArrayList xpalResult = new XPArrayList();
      while (xpstUnEscape.HasMoreTokens())
      {
        String strCurrentCredVault = xpstUnEscape.GetNextToken();
        // AGC- if the end of strCurrentCredVault is the escape char, then
        // we should remove the escape char and add the next token. We must continue
        // doing this until we find an un-escaped token.
        while (0 == CREDVAULT_ESCAPECHAR.CompareTo(XPStringUtility.Substring(strCurrentCredVault,
         strCurrentCredVault.Length - CREDVAULT_ESCAPECHAR.Length)))
        {
          // Remove the escape char and add back the original character (removed by the tokenizer).			
          strCurrentCredVault = XPStringUtility.Substring(strCurrentCredVault,
           0, strCurrentCredVault.Length - CREDVAULT_ESCAPECHAR.Length) + CREDVAULT_SEPARATORCHAR;
          // Could always be the last item in the string. Must check for more tokens.
          if (xpstUnEscape.HasMoreTokens())
          {
            // There's another token. Tack them together. 
            strCurrentCredVault = strCurrentCredVault + xpstUnEscape.GetNextToken();
            }
        }
        // AGC- We've finally regenerated the original userinfo. Add it to 
        // the results.
        xpalResult.Add(strCurrentCredVault);
      }
      return xpalResult;
    }
    
    /// <summary>
    /// Escapes a single userinfo string to avoid collision with the separator
    /// character used in StringToCredVaults and CredVaultsToString.
    /// </summary>
    /// <param name="strIn"></param>
    /// <returns>String</returns>
    private static String EscapeCredVault(String strIn)
    {
      String strReplacement = CREDVAULT_ESCAPECHAR + CREDVAULT_SEPARATORCHAR;
      String strResult = GeneralHelpers.Replace(strIn, CREDVAULT_SEPARATORCHAR,
       strReplacement);
      return strResult;
    }
    public static String CredVaultToStringJS(String strUnique, String strFormPrefix)
    {
      String strReplacement = CREDVAULT_ESCAPECHAR + CREDVAULT_SEPARATORCHAR;
      XPStringBuilder xpsbResult = new XPStringBuilder(400);
      xpsbResult.Append("function CredVaultArgFromExpList").Append(strUnique).Append("()\n");
      xpsbResult.Append("{\n");
      xpsbResult.Append("  var frm = document.").Append(AFormDP.HTMLFORM_NAME).Append(";\n");
      xpsbResult.Append("  var len = frm.elements.length;\n");
      xpsbResult.Append("  var i = 0;\n");
      xpsbResult.Append("  var sItemPrefix = \'").Append(strFormPrefix).Append(strUnique).Append("\';\n");
      xpsbResult.Append("  var result = \'\';\n");
      xpsbResult.Append("  for(i=0 ; i<len ; i++)\n");
      xpsbResult.Append("  {\n");
      xpsbResult.Append("    if (frm.elements[i].name.substr(0, sItemPrefix.length) == sItemPrefix)\n");
      xpsbResult.Append("    {\n");
      xpsbResult.Append("      var current = frm.elements[i].value\n");
      xpsbResult.Append("      current = current.replace(\'").Append(CREDVAULT_SEPARATORCHAR).Append("\', \'").Append(strReplacement).Append("\');\n");
      xpsbResult.Append("      if (0 != result.length)\n");
      xpsbResult.Append("      {\n");
      xpsbResult.Append("         result = result + \',\' + current;\n");
      xpsbResult.Append("      } else {\n");
      xpsbResult.Append("         result = current;\n");
      xpsbResult.Append("      }\n");
      xpsbResult.Append("    } \n");
      xpsbResult.Append("  }\n");
      xpsbResult.Append("  result = \'&SelectCredVault=\' + result;\n");
      xpsbResult.Append("  return result;\n");
      xpsbResult.Append("}\n");
      return xpsbResult.ToString();
    }
    public static String CredVaultToStringJSFunc(String strUnique)
    {
      return "CredVaultArgFromExpList" + strUnique + "()";
    }
  }
}