using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.treeiterator;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.credvaulttree
{
  /// <summary>
  /// This version of the tree allows for browsing and
  /// selecting of objects with no hierarchical structure
  /// </summary>
  /// <author>JosephS</author>
  public class CredVaultTreeModel : ATreeModel,ITreeModel,ITreeModelRO,IRepostModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     typeof(CredVaultTreeModel));
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CredVaultTree";
    
    /// <summary>
    /// Tree iterator 
    /// </summary>
    protected IPTTreeIterator m_ptIterator = null;
    
    /// <summary>
    /// Storage for the list of all known credential vaults. This is used in order to
    /// get the CredVault string based on the index into this array (the index is
    /// used in place of an object ID to uniquely identify each User Info).
    /// </summary>
    protected XPArrayList m_xpalKnownCredVaults;
    protected XPArrayList m_xpalSelected;
    public CredVaultTreeModel() : base()
    {
      m_xpalKnownCredVaults = new XPArrayList();
      m_xpalSelected = new XPArrayList();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CredVaultTreeModel();
    }
    
    /// <summary>
    /// This is called when a node is expanded.  Since User Info
    /// is a flat list, there will be no recursive thoughts here.  This simply
    /// retrieves all the User Info available to the user and puts it on
    /// the tree as leaf items.
    /// </summary>
    /// <param name="bExpand">expands the branch</param>
    /// <param name="nNodeID">the uniqueid for this node</param>
    public override void ExpandNode(bool bExpand, int nNodeID)
    {
      base.ExpandNode(bExpand, nNodeID);
      // Always expand the dummy title to show all rights
      TreeCompositeNode node = (TreeCompositeNode) m_Root.GetNode(nNodeID);
      node.m_bExpanded = true;
      // Populate with Profile Sections
      try
      {
        // open the CV -jas
        IPTProfilePage ptCredentialVault = (IPTProfilePage) ((IPTSession) m_asOwner.GetUserSession()).GetProfilePages().Open(PT_INTRINSICS.PT_PROFILE_PAGE_CREDENTIAL_VAULT,
         false);
        // get the list of sections, put them in a hash -jas
        Object[] arrSections = ptCredentialVault.GetChildSections();
        XPHashtable mapSections = new XPHashtable();
        for (int i = 0;i < arrSections.Length;i++)
        {
          mapSections.PutElement(arrSections[i], null);
        }
        IPTObjectManager ptSectionManager = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();
        // I get all the profile sections, then filter them myself using the hash.  This is because the list is
        //	stored in a property bag and thus not queryable.  I don't expect a large volume of profile sections
        //	so I'm hoping this won't be a major issue. -jas
        ASQueryResultWrapper query = new ASQueryResultWrapper(ptSectionManager.SimpleQuery(-1,
         PT_PROPIDS.PT_PROPID_NAME));
        TreeLeafNode myLeaf;
        int nNumCredVaults = query.GetCount();
        // A stored array of User infos. We need this in order to be able to 
        // uniquely identify each CredVault with an integer (rather than re-write the whole
        // damn Tree to support indexing by string).
        m_xpalKnownCredVaults = new XPArrayList();
        for (int nMapIndex = 0;nMapIndex < nNumCredVaults;nMapIndex++)
        {
          int ObjectID = (int) query.GetFields(nMapIndex, PT_PROPIDS.PT_PROPID_OBJECTID);
          // only show sections that belong to the CV -jas
          if (mapSections.ContainsKey(ObjectID))
          {
            String strCurrentCredVault = XPConvert.ToString(query.GetFields(nMapIndex,
             PT_PROPIDS.PT_PROPID_NAME));
            // AGC- we need to keep track of the mapped items so we can do
            // selection properly.	        	
            int nCurrentCredVaultIndex = m_xpalKnownCredVaults.Add(strCurrentCredVault);
            myLeaf = new TreeLeafNode(GetNextUniqueID());
            myLeaf.SetName(strCurrentCredVault);
            myLeaf.m_nObjectID = XPConvert.ToInteger(ObjectID);
            //AGC- Not Used.
            myLeaf.m_nClassID = PT_CLASSIDS.PT_PROFILESECTION_ID;
            myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_LOCKBOX).GetHTMLElement();
            // TODOCR: donh myLeaf.GetName() returns the name truncated to 50,
            // and myLeaf.GetEncodedName() returns it truncated and HTMLEncoded
            // The data is stored in the encoded format, so GetEncodedName
            // is faster than GetName().  The truncation may cause problems
            // here.
            if (m_xpalSelected.Contains(myLeaf.GetName()))
            {
              myLeaf.m_bSelected = true;
              m_xpmSelectedItems.PutElement(myLeaf.m_nClassID + "," + myLeaf.m_nObjectID,
               myLeaf);
            }
            node.AddLeafChild(myLeaf);
          }
        }
      }
      catch (Exception ex)
      {
        log.Error("CredVaultTreeModel::Expand Node Unable to load lockbox tree.  The following exception occured: " + ex);
        throw new XPException(m_asOwner.GetString(2870, "ptmsgs_portaladminmsgs"),
         ex);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the list of CredVault strings that the Tree knows about (is
    /// displaying).
    /// </summary>
    /// <returns>XPArrayList</returns>
    public virtual XPArrayList GetTreeCredVaults()
    {
      return m_xpalKnownCredVaults;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
    }
    
    /// <summary>
    /// Initializes and begins the loading of the tree.
    /// </summary>
    public virtual void LoadCredVault()
    {
      // Root is simply a dummy title
      m_Root = new TreeCompositeNode(GetNextUniqueID());
      m_Root.SetName(m_asOwner.GetString(2871, "ptmsgs_portaladminmsgs"));
      if (!m_bShowRoot)
      {
        ExpandNode(true, m_Root.m_nTreeNodeID);
      }
    }
    
    /// <summary>
    /// If there are multiple class ids, determine which
    /// ones to display.  For User Info, we only
    /// have 1 class id, so this method is unimplemented.
    /// </summary>
    /// <param name="nIDs">determines which classids to display</param>
    public override void SetClassIDsToDisplay(int[] nIDs)
    {
    }
    // User Info do not need this currently.
    
    /// <summary>
    /// Determines what items in the tree are to be displayed.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToDisplay(int[])"></seealso>
    /// <param name="nIDs">determines which nodes are not hidden.</param>
    public override void SetObjectIDsToDisplay(int[] nIDs)
    {
    }
    
    /// <summary>
    /// Determines what items in the tree are hidden.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToHide(int[])"></seealso>
    /// <param name="nIDs">determines which nodes are hidden</param>
    public override void SetObjectIDsToHide(int[] nIDs)
    {
    }
    // User Info do not need this currently.
    
    /// <summary>
    /// Determines what items in the tree are selected.
    /// </summary>
    /// <param name="nIDs">determines which nodes are selected</param>
    public override void SetObjectIDsToSelect(int[] nIDs)
    {
    }
    // AGC- Not used by User Info
    
    /// <summary>
    /// Sets the userinfos that are currently selected.
    /// </summary>
    /// <param name="arsCredVaults"></param>
    public virtual void SetCredVaultsToSelect(XPArrayList xpalCredVaults)
    {
      ClearSelectedItems();
      m_xpalSelected = xpalCredVaults;
    }
    
    /// <summary>
    /// Sets the userinfos that are currently selected.
    /// </summary>
    /// <param name="arsCredVaults"></param>
    public virtual void SetCredVaultsToSelect(String[] arsCredVaults)
    {
      SetCredVaultsToSelect(WSModelHelper.StringArrayToXPArray(arsCredVaults));
      }
  }
}