using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AWSSettingsPluginModel : EditorHelperModel,IAWSSettingsPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "AWSSettingsPlugin";
    
    /// <summary>
    /// This mask is used by our view to send time data to us in units that we
    /// support.
    /// </summary>
    public static readonly int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES | PTDurationCombo.DISPLAYSECONDS;
    
    /// <summary>
    /// This is the default soap timeout for Authentication - 30 seconds.
    /// </summary>
    public const long DEFAULT_AUTH_SOAP_TIMEOUT = 30 * 1000;
    
    /// <summary>
    /// This is the default soap timeout for Synchronization - 5 minutes.
    /// </summary>
    public const long DEFAULT_SYNC_SOAP_TIMEOUT = 5 * 60 * 1000;
    
    /// <summary>
    /// Timeout information for Authentication.
    /// </summary>
    protected PTDuration m_ptdAuthSOAPTimeout;
    
    /// <summary>
    /// Timeout information for Synchronization.
    /// </summary>
    protected PTDuration m_ptdSyncSOAPTimeout;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// The location of the Authentication URL for this Web Service.
    /// </summary>
    private String m_strAuthURL = "";
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// The location of the Synchronization URL for this Web Service.
    /// </summary>
    private String m_strSyncURL = "";
    public AWSSettingsPluginModel() : base()
    {
      m_ptdAuthSOAPTimeout = new PTDuration(DEFAULT_AUTH_SOAP_TIMEOUT, NMASK_SUPPORTED_UNITS);
      m_ptdSyncSOAPTimeout = new PTDuration(DEFAULT_SYNC_SOAP_TIMEOUT, NMASK_SUPPORTED_UNITS);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AWSSettingsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPAWS_AUTHURL,
       m_strAuthURL);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPAWS_SYNCURL,
       m_strSyncURL);
      // aj: persist the auth timeout seperately from the sync timeout
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPAWS_AUTH_TIMEOUT,
       m_ptdAuthSOAPTimeout.GetMilliseconds());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
       m_ptdSyncSOAPTimeout.GetMilliseconds());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <summary>
    /// The location of the Authentication URL for this Web Service.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetAuthURL()
    {
      return m_strAuthURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <summary>
    /// Returns timeout setting for Authentication.
    /// </summary>
    /// <returns>PTDuration</returns>
    public virtual PTDuration GetAuthDuration()
    {
      return m_ptdAuthSOAPTimeout;
    }
    
    /// <summary>
    /// Returns timeout setting for Synchronization.
    /// </summary>
    /// <returns>PTDuration</returns>
    public virtual PTDuration GetSyncDuration()
    {
      return m_ptdSyncSOAPTimeout;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// The location of the Synchronization URL for this Web Service.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSyncURL()
    {
      return m_strSyncURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return AWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      SetAuthURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPAWS_AUTHURL,
       m_strAuthURL));
      SetSyncURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPAWS_SYNCURL,
       m_strSyncURL));
      // aj: load the timeouts seperately
      m_ptdAuthSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PTC_HTTPAWS_AUTH_TIMEOUT, m_ptdAuthSOAPTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
      m_ptdSyncSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT, m_ptdSyncSOAPTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetAuthURL(WSModelHelper.GetFormElementString(_htFormData, AWSSettingsPluginView.HTMLINPUT_AUTH_URL,
       GetAuthURL()));
      SetSyncURL(WSModelHelper.GetFormElementString(_htFormData, AWSSettingsPluginView.HTMLINPUT_SYNC_URL,
       GetSyncURL()));
      // aj: we want to detect bad stuff with a negative timeout default
      PTDuration ptdDefault = new PTDuration(-1L, NMASK_SUPPORTED_UNITS);
      // aj: grab the two timeouts from the form data
      m_ptdAuthSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       AWSSettingsPluginView.HTMLINPUT_AUTH_TIMEOUT_DURATION, AWSSettingsPluginView.HTMLSELECT_AUTH_TIMEOUT_UNITS,
       ptdDefault);
      m_ptdSyncSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       AWSSettingsPluginView.HTMLINPUT_SYNC_TIMEOUT_DURATION, AWSSettingsPluginView.HTMLSELECT_SYNC_TIMEOUT_UNITS,
       ptdDefault);
      int nValid = RepostControl.PAGE_STATUS_VALID;
      if ((null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        // AGC- Validation: When the BaseURL is not set, we must validate both that the URLS are non empty, and that
        // the ones that are non-empty are valid URLs. We cannot do this through concatenation (too bad).
        nValid = WSModelHelper.ValidateNonEmptyString(m_strAuthURL + m_strSyncURL,
         m_asOwner, m_asOwner.GetString(1047, "ptmsgs_portaladminmsgs"), nValid);
        if ((null != m_strAuthURL) && (m_strAuthURL.Length > 0))
        {
          nValid = WSModelHelper.ValidateIsURLString(m_strAuthURL, m_asOwner,
           m_asOwner.GetString(1916, "ptmsgs_portaladminmsgs"), nValid);
        }
        if ((null != m_strSyncURL) && (m_strSyncURL.Length > 0))
        {
          nValid = WSModelHelper.ValidateIsURLString(m_strSyncURL, m_asOwner,
           m_asOwner.GetString(1917, "ptmsgs_portaladminmsgs"), nValid);
        }
      } else
      {
        // AGC- Validation: Either the AuthURL or the SyncURL must be set, so we can validate this be checking that the concat is non-empty.		
        nValid = WSModelHelper.ValidateNonEmptyString(m_strAuthURL + m_strSyncURL,
         m_asOwner, m_asOwner.GetString(1047, "ptmsgs_portaladminmsgs"), nValid);
        }
      // aj: verify the two timeouts
      //	a) auth should be between 1 second and 5 minutes
      //	b) sync should be between 1 second and 360 minutes ( 6 hours)
      nValid = WSModelHelper.ValidateDurationRange(m_ptdAuthSOAPTimeout, m_asOwner,
       m_asOwner.GetString(1918, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 90);
      nValid = WSModelHelper.ValidateDurationRange(m_ptdSyncSOAPTimeout, m_asOwner,
       m_asOwner.GetString(3133, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 60 * 6);
      return nValid;
    }
    
    /// <summary>
    /// The location of the Authentication  URL for this Web Service.
    /// </summary>
    public virtual void SetAuthURL(String strAuthURL)
    {
      m_strAuthURL = XPStringUtility.Trim(strAuthURL);
    }
    
    /// <summary>
    /// The location of the Synchronization URL for this Web Service.
    /// </summary>
    public virtual void SetSyncURL(String strSyncURL)
    {
      m_strSyncURL = XPStringUtility.Trim(strSyncURL);
    }
  }
}