using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AWSSettingsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.AWSSettingsPluginView");
    public const String STR_MVC_CLASS_NAME = "AWSSettingsPluginView";
    
    /// <summary>
    /// Seperate URLs for sync vs. auth.
    /// </summary>
    public const String HTMLINPUT_AUTH_URL = "in_tx_AuthURL";
    public const String HTMLINPUT_SYNC_URL = "in_tx_SyncURL";
    
    /// <summary>
    /// Authentication timeout & units.
    /// </summary>
    public const String HTMLINPUT_AUTH_TIMEOUT_DURATION = "in_tx_AuthTimeout";
    public const String HTMLSELECT_AUTH_TIMEOUT_UNITS = "in_se_AuthTimeoutUnits";
    
    /// <summary>
    /// Synchronization timeout & units.
    /// </summary>
    public const String HTMLINPUT_SYNC_TIMEOUT_DURATION = "in_tx_SyncTimeout";
    public const String HTMLSELECT_SYNC_TIMEOUT_UNITS = "in_se_SyncTimeoutUnits";
    
    /// <summary>
    /// The name of our validation function. This must be added by the Page to the
    /// page level validation function. See WSPluginDP for details.
    /// </summary>
    public const String VALIDATION_FUNCTION_NAME = "IsValidAWSSettings";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AWSSettingsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1049,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 1st row ends
        // 2nd row begins
        String strBaseURL = ((IAWSSettingsPluginModelRO) m_model).GetBaseURL();
        //////// Auth URL
        String strDefault = ((IAWSSettingsPluginModelRO) m_model).GetAuthURL();
        WSViewHelper.AddSimpleEditBox(myTable, 5, m_asOwner.GetString(1050,
         "ptmsgs_portaladminmsgs"), strBaseURL, strDefault, HTMLINPUT_AUTH_URL);
        //////// Auth URL Timeout
        PTDuration ptdDefault = ((IAWSSettingsPluginModelRO) m_model).GetAuthDuration();
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(1052,
         ResourceConstants.PORTALADMINMSGS), HTMLINPUT_AUTH_TIMEOUT_DURATION,
         HTMLSELECT_AUTH_TIMEOUT_UNITS, ptdDefault, m_asOwner);
        //////// Sync URL
        strDefault = ((IAWSSettingsPluginModelRO) m_model).GetSyncURL();
        WSViewHelper.AddSimpleEditBox(myTable, 5, m_asOwner.GetString(1051,
         "ptmsgs_portaladminmsgs"), strBaseURL, strDefault, HTMLINPUT_SYNC_URL);
        //////// Sync URL Timeout
        ptdDefault = ((IAWSSettingsPluginModelRO) m_model).GetSyncDuration();
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(3134,
         ResourceConstants.PORTALADMINMSGS), HTMLINPUT_SYNC_TIMEOUT_DURATION,
         HTMLSELECT_SYNC_TIMEOUT_UNITS, ptdDefault, m_asOwner);
        //Spacer Row
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 6th row (spacer row)
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1048, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(400);
      try
      {
        sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
        sb.Append("{\n");
        WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
        if (WebServiceModel.WSMODE_AWS == mParent.GetWSMode())
        {
          sb.Append(WSViewHelper.ValidateNumericInputJS(WSPluginDP.HTMLFORM_NAME,
           AWSSettingsPluginView.HTMLINPUT_AUTH_TIMEOUT_DURATION, m_asOwner.GetString(1053,
           "ptmsgs_portaladminmsgs")));
        }
        sb.Append(" \treturn true;\n");
        sb.Append("}\n\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he.GetMessage());
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}