using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AddSettingsPluginModel : EditorHelperModel,IAddSettingsPluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AddSettingsPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// URL to the Administrative Prefs (AdditionalSettingsView) 
    /// </summary>
    private String m_strDisabledMessage = "";
    
    /// <summary>
    /// Radio item that chooses whether this WebService is enabled or not
    /// (AdditionalSettingsView)
    /// </summary>
    private bool m_bEnabledRadio = true;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AddSettingsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      m_ptWebService.SetDisabledMessage(GetDisabledMessage());
      m_ptWebService.SetEnabled(GetEnabled());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <summary>
    /// Returns the m_strDisabledMessage.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetDisabledMessage()
    {
      return m_strDisabledMessage;
    }
    
    /// <summary>
    /// Returns the m_nEnabledRadio.
    /// </summary>
    /// <returns>int</returns>
    public virtual bool GetEnabled()
    {
      return m_bEnabledRadio;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      // Initialize ourselves
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == mParent.GetEditorType())
      {
        String strDefaultDisabledMessage = m_asOwner.GetString(2510, "ptmsgs_portaladminmsgs");
        switch (mParent.GetWSMode()){
        case WebServiceModel.WSMODE_AWS:
        strDefaultDisabledMessage = m_asOwner.GetString(2505, "ptmsgs_portaladminmsgs");
        break;
        case WebServiceModel.WSMODE_CWS:
        strDefaultDisabledMessage = m_asOwner.GetString(2506, "ptmsgs_portaladminmsgs");
        break;
        case WebServiceModel.WSMODE_INTRINSIC_PORTLET:
        case WebServiceModel.WSMODE_PORTLET:
        strDefaultDisabledMessage = m_asOwner.GetString(2507, "ptmsgs_portaladminmsgs");
        break;
        case WebServiceModel.WSMODE_PWS:
        strDefaultDisabledMessage = m_asOwner.GetString(2508, "ptmsgs_portaladminmsgs");
        break;
        case WebServiceModel.WSMODE_SWS:
        strDefaultDisabledMessage = m_asOwner.GetString(2509, "ptmsgs_portaladminmsgs");
        break;
        case WebServiceModel.WSMODE_NONE:
        default:
        break;
        }
        SetDisabledMessage(strDefaultDisabledMessage);
      } else
      {
        SetDisabledMessage(ptWebService.GetDisabledMessage());
      }
      SetEnabled(ptWebService.GetEnabled());
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetEnabled(WSModelHelper.GetFormCheckboxBool(_htFormData, AddSettingsPluginView.HTMLRADIO_ENABLED));
      SetDisabledMessage(WSModelHelper.GetFormElementString(_htFormData, AddSettingsPluginView.HTMLINPUT_DISABLED_TEXT,
       m_strDisabledMessage));
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Sets the m_strDisabledMessage.
    /// </summary>
    /// <param name="strDisabledMessage">The strDisabledMessage to set</param>
    public virtual void SetDisabledMessage(String strDisabledMessage)
    {
      //MES- CR: Is there any max length for the disabled message?
      //AGC- This is enforced by the maxlength set on the UI input.    	
      if (null == strDisabledMessage)
      {
        m_strDisabledMessage = "";
      } else
      {
        m_strDisabledMessage = XPHttpUtility.HtmlEncode(strDisabledMessage);
        }
    }
    
    /// <summary>
    /// Sets the m_nEnabledRadio. Value must be WS_ENABLED or WS_DISABLED (will
    /// silently set value to WS_DISABLED if out of range.
    /// </summary>
    /// <param name="nEnabledRadio">The nEnabledRadio to set</param>
    public virtual void SetEnabled(bool bEnabledRadio)
    {
      m_bEnabledRadio = bEnabledRadio;
    }
  }
}