using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.admin.editors.webservice.userinfotree;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AddUserInfoPluginModel : GrowableListModel,IAddUserInfoPluginModelRO,
  IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.AddUserInfoPluginModel");
    public const String STR_MVC_CLASS_NAME = "AddUserInfoPluginModel";
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_NAME_SELECTTREE = "SelectActivityRightsTree";
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_CLASSID = 1;
    
    /// <summary>
    /// This column contains the Object IDs.
    /// </summary>
    public const int EXPLIST_COL_OBJECTID = 2;
    
    /// <summary>
    /// This is the String that we doisplay in the list.
    /// E.g.: Object name or folder path.
    /// </summary>
    public const int EXPLIST_COL_STRING = 3;
    // AGC- Should be "Add Blank User Info"
    
    /// <summary>
    /// Every Growable list used within an editor must have a unique ID. It just
    /// so happens that it is easy to accidentally collide (since the unique ID's
    /// are set to 0 and 1 a lot). I'm going to give myself an offset, so that I
    /// am less likely to collide with someone else's unique ID). It doesn't really
    /// matter what this number is, as long as no one else chooses the same one for
    /// another ExpList.
    /// </summary>
    private const int m_nUniqueIDOffset = 696;
    
    /// <summary>
    /// Tree Space ID. The first time the ID is empty and a new AS is opened,
    /// but after that, we save the ID and the same tree AS is reopened each time. 
    /// </summary>
    protected String m_sTreeSpaceID = "";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AddUserInfoPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // In order to not overwrite the hard coded values (since they're not
      // displayed in this view) we must pick them out of the property bag and
      // add them back in.
      XPArrayList xpalUserInfoList = WSModelHelper.GetHardcodedUserInfo(ptProviderInfo);
      // Now, we add the new values.
      String[] aGrowableArrayValues = GetListValues();
      // Turn this into an Object array so that we can store it.			
      for (int nIndex = 0;nIndex < aGrowableArrayValues.Length;nIndex++)
      {
        String strNewValue = aGrowableArrayValues[nIndex];
        if (0 < XPStringUtility.Trim(strNewValue).Length)
        {
          // AGC- Warning... We're doing a trim here. I think it is valid, but
          // it is worth noting.
          xpalUserInfoList.Add(XPStringUtility.Trim(strNewValue));
        }
        log.Debug("Adding UserInfo array value: " + aGrowableArrayValues[nIndex]);
        }
      ptProviderInfo.Write(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERINFO,
       xpalUserInfoList.ToArray());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the list of Userinfo's retrieved from the Tree. (Returns an
    /// empty array if the tree has not been initialized).
    /// </summary>
    /// <returns>XPArrayList</returns>
    public virtual XPArrayList GetSelectedItemsFromTree()
    {
      XPArrayList xpalResult = new XPArrayList();
      UserInfoTreeAS asTree = (UserInfoTreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_NAME_SELECTTREE));
      if (null != asTree)
      {
        ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList mySelected = myTree.GetSelectedItems();
        for (int nSelectedIndex = 0;nSelectedIndex < mySelected.GetSize();
        nSelectedIndex++)
        {
          String strCurrentUserInfo = ((TreeLeafNode) mySelected.GetElement(nSelectedIndex)).GetName();
          xpalResult.Add(strCurrentUserInfo);
        }
      }
      return xpalResult;
    }
    
    /// <summary>
    /// Returns tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetTreeSpaceID()
    {
      return m_sTreeSpaceID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <summary>
    /// Searches the current list of GetListValues for strItem.
    /// Returns true if strItem is found. (Does a case sensitive
    /// comparison).
    /// </summary>
    /// <param name="strItem"></param>
    /// <returns>boolean</returns>
    public virtual bool InCurrentList(String strItem)
    {
      String[] arsList = GetListValues();
      for (int nIndex = 0;nIndex < arsList.Length;nIndex++)
      {
        String strCurrent = arsList[nIndex];
        if (0 == strCurrent.CompareTo(strItem))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      String strPrefListAddLabel = "";
      strPrefListAddLabel = m_asOwner.GetString(1031, "ptmsgs_portaladminmsgs");
      InitializeGrowableList(m_asOwner.GetString(1910, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(1030, "ptmsgs_portaladminmsgs"), PTImageType.ICON_USER,
       strPrefListAddLabel, m_nUniqueIDOffset);
      SetDefaultValue("");
      SetDeleteIcon(PTImageType.ACTION_DELETE);
      // Get our state from the ptObject.
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // Get only the non-hard-coded stuff. The hard-coded stuff will be edited in
      // a different view.		
      //MES- CR: Why have the "AddUserInfoPluginModel" qualifier here?
      //AGC- Because the little bastard is static - you're not supposed to call statics
      //		on an instance because it'll break the .NET jump (I think).		
      XPArrayList xpalUserInfo = WSModelHelper.GetNonHardcodedUserInfo(ptProviderInfo);
      String[] astrUserInfoList = new String[xpalUserInfo.GetSize()];
      for (int nIndex = 0;nIndex < xpalUserInfo.GetSize();nIndex++)
      {
        // Copy the list to a String array readable by the ExpList framework.
        astrUserInfoList[nIndex] = XPConvert.ToString(xpalUserInfo.GetElement(nIndex));
        }
      AddRowsToList(astrUserInfoList);
      // Add an extra, empty string for the sake of aesthetics... Any empty 
      // items will be ignored when we store.
      String[] arBlank = {""};
      AddRowsToList(arBlank);
    }
    
    /// <summary>
    /// Clear the list and add all the values from the tree.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      SaveTreeID(_htFormData);
      UserInfoTreeAS asTree = (UserInfoTreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_NAME_SELECTTREE));
      // AGC- We should remember all of the items that the tree doesn't
      // know about before clearing the array. We will add them back later.
      XPArrayList xpalUserInfosToRemember = new XPArrayList();
      String[] arsCurrentValues = GetListValues();
      XPArrayList xpalTreeHandledUserInfos = new XPArrayList();
      if (null != asTree)
      {
        UserInfoTreeModel myTree = (UserInfoTreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
        xpalTreeHandledUserInfos = myTree.GetTreeUserInfos();
      }
      // Write down all of the Userinfos the tree isn't explicitly handling.
      for (int nIndex = 0;nIndex < arsCurrentValues.Length;nIndex++)
      {
        String strCurrentUserInfo = arsCurrentValues[nIndex];
        if (!xpalTreeHandledUserInfos.Contains(strCurrentUserInfo))
        {
          xpalUserInfosToRemember.Add(strCurrentUserInfo);
        }
      }
      // AGC- We clear the array before we start adding the selected items from the tree.
      base.GetItems().ClearArray();
      // AGC- Beware of weird behavior. What happens if the user adds a userinfo by hand that
      // the tree should know about?
      // IF a new User Info were added by hand in this method (the AddRows method), then the 
      // user might wind up vexed! The user info would be identified as a userinfo that the
      // tree controls, but since it wouldn't be selected in the tree, it would be immediately
      // deleted (weird).
      // Fortunately, AddRowsOnRepost will only add either a blank row (the plain Add button is 
      // clicked) or userinfos selected from the tree (no problemo). The call that will change
      // userinfo's added by hand is ModifyRow.  
      // Now add in the items the tree is handling.
      XPArrayList xpalItemsFromTree = GetSelectedItemsFromTree();
      for (int nSelectedIndex = 0;nSelectedIndex < xpalItemsFromTree.GetSize();
      nSelectedIndex++)
      {
        String strCurrentUserInfo = (String) xpalItemsFromTree.GetElement(nSelectedIndex);
        if (!InCurrentList(strCurrentUserInfo))
        {
          AddRowsToList(new String[]{strCurrentUserInfo});
        }
      }
      // Now add back the items the tree didn't handle.
      for (int nSelectedUnhandledIndex = 0;nSelectedUnhandledIndex < xpalUserInfosToRemember.GetSize();
      nSelectedUnhandledIndex++)
      {
        String strCurrentUserInfo = (String) xpalUserInfosToRemember.GetElement(nSelectedUnhandledIndex);
        if (!InCurrentList(strCurrentUserInfo))
        {
          AddRowsToList(new String[]{strCurrentUserInfo});
        }
      }
      base.AddRowsOnRepost(_htFormData);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)"></seealso>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      base.DeleteRowsOnRepost(_htFormData);
      String[] arList = GetListValues();
      // Add an extra, empty string for the sake of aesthetics... Any empty 
      // items will be ignored when we store.
      if ((null == arList) || (0 >= arList.Length))
      {
        String[] arBlank = {""};
        AddRowsToList(arBlank);
      }
    }
    
    /// <summary>
    /// Helper method to save the Tree ID on repost.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    protected virtual void SaveTreeID(XPHashtable _htFormData)
    {
      // JF- We save the tree ID only if we don't already have it.
      if (("").Equals(m_sTreeSpaceID) && _htFormData.ContainsKey(GetUniqueString(AddUserInfoPluginView.HTMLINPUT_TREEASID)))
      {
        String[] data = (String[]) _htFormData.GetElement(GetUniqueString(AddUserInfoPluginView.HTMLINPUT_TREEASID));
        if ((null != data) && !(0 == data.Length))
        {
          m_sTreeSpaceID = data[0];
        }
      }
    }
  }
}