using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice.userinfotree;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AddUserInfoPluginView : GrowableListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.AddUserInfoPluginView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AddUserInfoPluginView";
    
    /// <summary>
    /// HTML Object names 
    /// </summary>
    public const String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AddUserInfoPluginView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      // The URL to open a new tree
      ASURL myNewTree = new ASURL(m_asOwner);
      // Tree creation and binding
      myNewTree.SetLinkCreateNewSpace(UserInfoTreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myNewTree.SetSubSpaceKey(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(AddUserInfoPluginModel.SUBSPACE_NAME_SELECTTREE));
      myNewTree.SetControl(UserInfoStartTreeControl.STR_MVC_CLASS_NAME);
      // Tree configuration
      myNewTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
      myNewTree.AddControlArgument(AStartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      myNewTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
       ((IAddUserInfoPluginModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID));
      myNewTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL, ((IAddUserInfoPluginModelRO) m_model).GetUniqueString("OnReturnFromTree"));
      myNewTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
      //		myNewTree.AddControlArgument(UserInfoRefreshTreeControl.SELECTED_USERINFOS,
      //			UserInfoRefreshTreeControl.UserInfosToString(((AddUserInfoPluginModel)m_model).GetListValues()));
      // AGC- Commented out until I figure out how to fix selection.
      /*        myNewTree.AddControlArgument(UserInfoStartTreeControl.SELECTED_ITEMS,
       ((IAddUserInfoPluginModelRO)m_model).GetSelectedItems());
       */
       
      myNewTree.AddControlArgument(AStartTreeControl.TITLE, m_asOwner.GetString(2537,
       "ptmsgs_portaladminmsgs"));
      // The url to open a previously opened server user tree
      // This needs to have the SpaceID added to it.
      ASURL myOldTree = new ASURL(m_asOwner);
      myOldTree.SetLinkCreateNewSpace(UserInfoTreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myOldTree.SetControl(UserInfoRefreshTreeControl.STR_MVC_CLASS_NAME);
      //		myOldTree.AddControlArgument(UserInfoRefreshTreeControl.SELECTED_USERINFOS,
      //			UserInfoRefreshTreeControl.UserInfosToString(((AddUserInfoPluginModel)m_model).GetListValues()));
      XPStringBuilder sb;
      try
      {
        String strControlAppend = UserInfoRefreshTreeControl.UserInfoToStringJSFunc(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(""));
        // Open Tree function
        sb = new XPStringBuilder(200);
        sb.Append("function " + ((IAddUserInfoPluginModelRO) m_model).GetUniqueString("OpenTree") + "(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\' + ").Append(strControlAppend).Append(", \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(myOldTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value + ").Append(strControlAppend).Append(", \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // On return from Tree function
        sb = new XPStringBuilder(200);
        sb.Append(" function " + ((IAddUserInfoPluginModelRO) m_model).GetUniqueString("OnReturnFromTree") + "()");
        sb.Append(" {");
        sb.Append(" \tpostToSelf(\'" + ((IAddUserInfoPluginModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "\');");
        sb.Append(" }");
        sb.Append(UserInfoRefreshTreeControl.UserInfoToStringJS(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(""),
         HTMLINPUT_ITEM));
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "SelectActivityRightsView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(com.plumtree.xpshared.htmlelements.HTMLTableRow)"></seealso>
    protected override void AddHTMLToActionBar(HTMLTableRow _myRow)
    {
      base.AddHTMLToActionBar(_myRow);
      _myRow.AddInnerHTMLElement(GetHTMLForAddUserInfoAction());
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAddUserInfoAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // Add icon
      HTMLImg myAddIcon;
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      myAddIcon.SetAlt("");
      myAddIcon.SetAlign("absmiddle");
      // Object icon
      myConstruct = UIConstructFactory.GetConstruct(((IAddUserInfoPluginModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      // mj: replaced the following line with a blank constructur and SetOnClick()
      // myAnchor = new HTMLAnchor(
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(((IAddUserInfoPluginModelRO) m_model).GetUniqueString("OpenTree") + "(document." + AFormDP.HTMLFORM_NAME + "." + ((IAddUserInfoPluginModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID) + ");");
      myAnchor.AddInnerHTMLElement(myAddIcon);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(m_asOwner.GetString(1911, "ptmsgs_portaladminmsgs"));
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(SPACE);
      // hidden input with the tree space ID
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ((IAddUserInfoPluginModelRO) m_model).GetUniqueString(HTMLINPUT_TREEASID),
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((IAddUserInfoPluginModelRO) m_model).GetTreeSpaceID());
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddIcon;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
       true, this.m_asOwner);
      myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
      myAddIcon.SetAlt("");
      myAddIcon.SetAlign("absmiddle");
      // Object icon
      myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.AddInnerHTMLString(SPACE);
      myAnchor.SetOnClick("postToSelf(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "\'); return false;");
      myAnchor.AddInnerHTMLElement(myAddIcon);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      return myCell;
    }
  }
}