using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AdvSettingsPluginModel : EditorHelperModel,IAdvSettingsPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "AdvSettingsPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// Whether or not this CWS (CWS only) supports file path submission.
    /// </summary>
    private bool m_bCardSubmitFilePath = false;
    
    /// <summary>
    /// Whether or not this CWS (CWS only) supports Remote UI submission.
    /// </summary>
    private bool m_bCardSubmitRemoteUI = false;
    
    /// <summary>
    /// Whether or not this CWS (CWS only) supports Remote UI submission.
    /// </summary>
    private bool m_bSupportsDocUpload = false;
    
    /// <summary>
    /// Whether or not to send the Community ACL to the portlet.
    /// </summary>
    private bool m_bSendCommunityACL = false;
    
    /// <summary>
    /// Whether or not to send the Login Token to the portlet.
    /// </summary>
    private bool m_bSendLoginToken = false;
    
    /// <summary>
    /// Whether or not to send the PageID to the portlet.
    /// </summary>
    private bool m_bSendPageID = false;
    
    /// <summary>
    /// Whether or not to send the Timezone to the portlet.
    /// </summary>
    private bool m_bSendTimezone = true;
    
    /// <summary>
    /// Whether or not to send the Locale to the portlet.
    /// </summary>
    private bool m_bSendLocale = true;
    
    /// <summary>
    /// Whether or not this web service supports mirroring.
    /// </summary>
    private bool m_bSupportsMirroring = false;
    
    /// <summary>
    /// Whether or not this web service supports ACL Import.
    /// </summary>
    private bool m_bSupportsACLImport = false;
    // A reasonable timeout I assume...
    
    /// <summary>
    /// Token duration (in minutes) for the Login Token
    /// </summary>
    private int m_nTokenTimeout = 5;
    
    /// <summary>
    /// Whether or not portlets created from this web service should show refresh button.
    /// </summary>
    private bool m_bRefreshButton = false;
    
    /// <summary>
    /// Whether or not portlets created from this web service should share sessions with other portlets
    /// on the same remote server.
    /// </summary>
    private bool m_bSharedSession = false;
    
    /// <summary>
    /// Whether or not to send subportalID to portlet.
    /// </summary>
    private bool m_bSendSubportalID = false;
    
    /// <summary>
    /// Whether or not to send portlet aligntment to portlet.
    /// </summary>
    private bool m_bSendAlignment = false;
    
    /// <summary>
    /// WSMode setting. We use this to determine which checkboxes to display
    /// and store.
    /// </summary>
    private int m_nWSMode;
    public AdvSettingsPluginModel() : base()
    {
      m_nWSMode = WebServiceModel.WSMODE_NONE;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AdvSettingsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      ptProviderInfo.Write(AExtensibilityConstants.PTC_HTTPGADGET_LOGINTOKENVALID,
       m_nTokenTimeout);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDPAGEID,
       m_bSendPageID);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDLOGINTOKEN,
       m_bSendLoginToken);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDCOMMUNITYACL,
       m_bSendCommunityACL);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDTIMEZONE,
       m_bSendTimezone);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSACLIMPORT,
       m_bSupportsACLImport);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSMIRRORING,
       m_bSupportsMirroring);
      int nCardSubmitType = 0;
      if (m_bCardSubmitFilePath)
      {
        nCardSubmitType|=PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_SIMPLE;
        }
      if (m_bCardSubmitRemoteUI)
      {
        nCardSubmitType|=PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_ADVANCED;
        }
      if (m_bSupportsDocUpload)
      {
        nCardSubmitType|=PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD;
        }
      // AGC- add or remove the locale string from the list of User prefs. But ONLY IN SWS MODE
      // ONLY SWS MODE!!!
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      if (WebServiceModel.WSMODE_SWS == mParent.GetWSMode())
      {
        XPArrayList xpalUserPrefs = null;
        try
        {
          xpalUserPrefs = WSModelHelper.ObjectArrayToXPArray(ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS));
          }
        catch (Exception e)
        {
        }
        //AGC- This likely means that this has never been set in the propertybag.
        // That's fine.
        if (null == xpalUserPrefs)
        {
          xpalUserPrefs = new XPArrayList();
        }
        if (!m_bSendLocale)
        {
          int nLocaleIndex = xpalUserPrefs.IndexOf(AExtensibilityConstants.PTC_STRLOCALE);
          if ((nLocaleIndex >= 0) && (nLocaleIndex < xpalUserPrefs.GetSize()))
          {
            xpalUserPrefs.RemoveAt(nLocaleIndex);
          }
        } else
        {
          if (!xpalUserPrefs.Contains(AExtensibilityConstants.PTC_STRLOCALE))
          {
            xpalUserPrefs.Add(AExtensibilityConstants.PTC_STRLOCALE);
          }
        }
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS,
         xpalUserPrefs);
      }
      m_ptWebService.SetCardSubmitType(nCardSubmitType);
      // Set refresh button.
      int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();
      if (m_bRefreshButton)
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_REFRESH;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_REFRESH;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTP_SESSION_TYPE,
       m_bSharedSession);
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SENDSUBPORTALID,
       m_bSendSubportalID);
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SENDALIGNMENT,
       m_bSendAlignment);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
      m_nWSMode = nNewWSMode;
    }
    
    /// <summary>
    /// Whether or not to support card submission via file path (CWS Only).
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetCardSubmitFilePath()
    {
      return m_bCardSubmitFilePath;
    }
    
    /// <summary>
    /// Whether or not to support card submission via remote UI (CWS Only).
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetCardSubmitRemoteUI()
    {
      return m_bCardSubmitRemoteUI;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Whether or not to send a community ACL to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendCommunityACL()
    {
      return m_bSendCommunityACL;
    }
    
    /// <summary>
    /// Whether or not to send a login token to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendLoginToken()
    {
      return m_bSendLoginToken;
    }
    
    /// <summary>
    /// Whether or not to send a pageid to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendPageID()
    {
      return m_bSendPageID;
    }
    
    /// <summary>
    /// Whether or not to send a timezone to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendTimezone()
    {
      return m_bSendTimezone;
    }
    
    /// <summary>
    /// Whether or not to send a locale to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendLocale()
    {
      return m_bSendLocale;
    }
    
    /// <summary>
    /// Whether or not this web service supports folder mirroring
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSupportsMirroring()
    {
      return m_bSupportsMirroring;
    }
    
    /// <summary>
    /// Whether or not this web service supports Document Upload
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSupportsUpload()
    {
      return m_bSupportsDocUpload;
    }
    
    /// <summary>
    /// Whether or not this web service supports ACL Import
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSupportsACLImport()
    {
      return m_bSupportsACLImport;
    }
    
    /// <summary>
    /// The duration of the timeout token (in minutes)
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetTokenTimeout()
    {
      return m_nTokenTimeout;
    }
    
    /// <summary>
    /// Whether or not portlets from this web service should show the refresh button
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetRefreshButton()
    {
      return m_bRefreshButton;
    }
    
    /// <summary>
    /// Whether each portlet has its own HTTP session, or shares sessions with other portlets on the same remote server
    /// </summary>
    /// <returns>int</returns>
    public virtual bool GetSharedSession()
    {
      return m_bSharedSession;
    }
    
    /// <summary>
    /// Whether to send subportal id to portlets.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendSubportalID()
    {
      return m_bSendSubportalID;
    }
    
    /// <summary>
    /// Whether to send alignment to portlets.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetSendAlignment()
    {
      return m_bSendAlignment;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <summary>
    /// Returns our current WS display mode from the WebServiceModel.WSMODE enumeration.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetWSMode()
    {
      return m_nWSMode;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      m_nTokenTimeout = WSModelHelper.PBReadInt(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_LOGINTOKENVALID,
       m_nTokenTimeout);
      m_bSendPageID = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDPAGEID,
       m_bSendPageID);
      m_bSendLoginToken = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDLOGINTOKEN,
       m_bSendLoginToken);
      m_bSendCommunityACL = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDCOMMUNITYACL,
       m_bSendCommunityACL);
      m_bSupportsACLImport = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSACLIMPORT,
       m_bSupportsACLImport);
      m_bSupportsMirroring = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_SUPPORTSMIRRORING,
       m_bSupportsMirroring);
      int nCardSubmitType = ptWebService.GetCardSubmitType();
      m_bCardSubmitFilePath = (PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_SIMPLE == (PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_SIMPLE & nCardSubmitType));
      m_bCardSubmitRemoteUI = (PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_ADVANCED == (PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_ADVANCED & nCardSubmitType));
      m_bSupportsDocUpload = (PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD == (PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD & nCardSubmitType));
      //MES- CR: This comment would be clearer if you pointed out that SendTimezone was a new feature for 5.0
      //AGC- RCR: Why should I, when you are so eloquently doing so for me?
      // AGC- This case is a little different. If we are reading an upgraded object, it won't have this item set. We want it to be set
      // by default... but not for newly created objects. We are assuming that if we are in edit mode and the setting isn't set, we are
      // editing an upgraded object. We are assuming that if the value is missing from the property bag, the propertybag will return either
      // null or the empty string.
      // Default if the setting is incorrect or missing from the propertybag.
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == ((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetEditorType())
      {
        m_bSendTimezone = true;
      } else
      {
        m_bSendTimezone = false;
      }
      m_bSendTimezone = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_SENDTIMEZONE,
       m_bSendTimezone);
      XPArrayList xpalUserPrefs = null;
      try
      {
        xpalUserPrefs = WSModelHelper.ObjectArrayToXPArray(ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS));
        }
      catch (Exception e)
      {
      }
      //AGC- This likely means that this has never been set in the propertybag.
      // That's fine. Note that this means we default to TRUE (intended).
      if (null != xpalUserPrefs)
      {
        if (!xpalUserPrefs.Contains(AExtensibilityConstants.PTC_STRLOCALE))
        {
          m_bSendLocale = false;
        }
      }
      m_bRefreshButton = ((m_ptWebService.GetSupportsPersonalization() & PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_REFRESH) > 0);
      m_bSharedSession = WSModelHelper.PBReadBool(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTP_SESSION_TYPE,
       m_bSharedSession);
      m_bSendSubportalID = WSModelHelper.PBReadBool(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SENDSUBPORTALID,
       m_bSendSubportalID);
      m_bSendAlignment = WSModelHelper.PBReadBool(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SENDALIGNMENT,
       m_bSendAlignment);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // These settings should be checked for all types of Web Services.
      SetTokenTimeout(WSModelHelper.GetFormElementInt(_htFormData, AdvSettingsPluginView.HTMLINPUT_LOGINTOKEN_TIMEOUT,
       GetTokenTimeout()));
      m_bRefreshButton = WSModelHelper.GetFormCheckboxBool(_htFormData, AdvSettingsPluginView.HTMLCHECKBOX_REFRESH_BUTTON);
      // Pagelet mode doesn't use most of these settings, so don't try to update them.
      // They are either not displayed in the UI or displayed as disabled, so checking them
      // will look like they are unchecked, which will write over the defaults.
      if (m_nWSMode != WebServiceModel.WSMODE_PAGELET)
      {
        SetSendPageID(WSModelHelper.GetFormCheckboxBool(_htFormData, AdvSettingsPluginView.HTMLCHECKBOX_SEND_PAGEID));
        m_bSendLoginToken = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SEND_LOGINTOKEN);
        m_bSendCommunityACL = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SEND_COMMUNITYACL);
        m_bSendTimezone = WSModelHelper.GetFormCheckboxBool(_htFormData, AdvSettingsPluginView.HTMLCHECKBOX_SEND_TIMEZONE);
        m_bCardSubmitFilePath = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_CARDSUBMIT_FILEPATH);
        m_bCardSubmitRemoteUI = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_CARDSUBMIT_REMOTEUI);
        m_bSupportsDocUpload = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_CARDSUBMIT_UPLOAD);
        m_bSendLocale = WSModelHelper.GetFormCheckboxBool(_htFormData, AdvSettingsPluginView.HTMLCHECKBOX_SEND_LOCALE);
        m_bSupportsACLImport = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SUPPORTSACLIMPORT);
        m_bSupportsMirroring = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SUPPORTSMIRRORING);
        m_bSharedSession = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SHARED_SESSION);
        m_bSendSubportalID = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SEND_SUBPORTALID);
        m_bSendAlignment = WSModelHelper.GetFormCheckboxBool(_htFormData,
         AdvSettingsPluginView.HTMLCHECKBOX_SEND_ALIGNMENT);
      }
      // the send page id option should always be enabled for pagelets since ensemble uses it as a context id
      // the checkbox is locked in the ui so user cannot uncheck it
      if (m_nWSMode == WebServiceModel.WSMODE_PAGELET)
      {
        SetSendPageID(true);
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Whether or not to send a pageid to the portlet.
    /// </summary>
    public virtual void SetSendPageID(bool bSendPageID)
    {
      m_bSendPageID = bSendPageID;
    }
    
    /// <summary>
    /// The duration of the timeout token (in minutes)
    /// </summary>
    public virtual void SetTokenTimeout(int nTokenTimeout)
    {
      m_nTokenTimeout = nTokenTimeout;
    }
  }
}