using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AdvSettingsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.AdvSettingsPluginView");
    public const String STR_MVC_CLASS_NAME = "AdvSettingsPluginView";
    public const String HTMLCHECKBOX_SEND_PAGEID = "in_cb_SendPageID";
    public const String HTMLCHECKBOX_SEND_LOGINTOKEN = "in_cb_SendLoginToken";
    public const String HTMLCHECKBOX_SEND_LOCALE = "in_cb_SendLocale";
    public const String HTMLCHECKBOX_SEND_COMMUNITYACL = "in_cb_SendCommACL";
    public const String HTMLCHECKBOX_SEND_TIMEZONE = "in_cb_SendTimezone";
    public const String HTMLCHECKBOX_CARDSUBMIT_FILEPATH = "in_cb_CardSubmitFilePath";
    public const String HTMLCHECKBOX_CARDSUBMIT_REMOTEUI = "in_cb_CardSubmitRemoteUI";
    public const String HTMLCHECKBOX_SUPPORTSMIRRORING = "in_cb_SupportMirror";
    public const String HTMLCHECKBOX_SUPPORTSACLIMPORT = "in_cb_SupportACLImport";
    public const String HTMLINPUT_LOGINTOKEN_TIMEOUT = "in_tx_LoginTimeout";
    public const String HTMLCHECKBOX_CARDSUBMIT_UPLOAD = "in_cb_CardSubmitUpload";
    public const String HTMLCHECKBOX_REFRESH_BUTTON = "in_cb_RefreshButton";
    public const String HTMLCHECKBOX_SHARED_SESSION = "in_cb_SharedSession";
    public const String HTMLCHECKBOX_SEND_SUBPORTALID = "in_cb_SendSubportalID";
    public const String HTMLCHECKBOX_SEND_ALIGNMENT = "in_cb_SendAlingment";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AdvSettingsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      // NOTE: this view has a lot of logic in it for what to display for each
      // WS type.  Maybe it would be cleaner if this was all in the model and
      // there was one method that could return if any piece of data was on, off,
      // or disabled.
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLInput myInput;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1033,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 1st row ends
        // 2nd row
        IAdvSettingsPluginModelRO modelRO = (IAdvSettingsPluginModelRO) m_model;
        int nWSMode = modelRO.GetWSMode();
        switch (nWSMode){
        case WebServiceModel.WSMODE_PORTLET:
        DrawCheckBox(myTable, HTMLCHECKBOX_SEND_COMMUNITYACL, "1", m_asOwner.GetString(1036,
         "ptmsgs_portaladminmsgs"), modelRO.GetSendCommunityACL());
        DrawCheckBox(myTable, HTMLCHECKBOX_SEND_PAGEID, "1", m_asOwner.GetString(1034,
         "ptmsgs_portaladminmsgs"), modelRO.GetSendPageID());
        break;
        case WebServiceModel.WSMODE_PAGELET:
        // Always send page id for pagelet since Ensemble uses it as a context id
        // advsettingspluginmodel always stores this option as true
        DrawCheckBox(myTable, HTMLCHECKBOX_SEND_PAGEID, "1", m_asOwner.GetString(1034,
         "ptmsgs_portaladminmsgs"), true, true);
        break;
        case WebServiceModel.WSMODE_CWS:
        DrawCheckBox(myTable, HTMLCHECKBOX_CARDSUBMIT_FILEPATH, "1", m_asOwner.GetString(1038,
         "ptmsgs_portaladminmsgs"), modelRO.GetCardSubmitFilePath());
        DrawCheckBox(myTable, HTMLCHECKBOX_CARDSUBMIT_REMOTEUI, "1", m_asOwner.GetString(1039,
         "ptmsgs_portaladminmsgs"), modelRO.GetCardSubmitRemoteUI());
        DrawCheckBox(myTable, HTMLCHECKBOX_CARDSUBMIT_UPLOAD, "1", m_asOwner.GetString(2626,
         "ptmsgs_portaladminmsgs"), modelRO.GetSupportsUpload());
        DrawCheckBox(myTable, HTMLCHECKBOX_SUPPORTSMIRRORING, "1", m_asOwner.GetString(1913,
         "ptmsgs_portaladminmsgs"), modelRO.GetSupportsMirroring());
        DrawCheckBox(myTable, HTMLCHECKBOX_SUPPORTSACLIMPORT, "1", m_asOwner.GetString(1914,
         "ptmsgs_portaladminmsgs"), modelRO.GetSupportsACLImport());
        break;
        case WebServiceModel.WSMODE_SWS:
        DrawCheckBox(myTable, HTMLCHECKBOX_SEND_LOCALE, "1", m_asOwner.GetString(1912,
         "ptmsgs_portaladminmsgs"), modelRO.GetSendLocale());
        break;
        case WebServiceModel.WSMODE_AWS:
        case WebServiceModel.WSMODE_NONE:
        default:
        break;
        }
        // Add the timezone checkbox.  This is for everything except pagelets.
        if (nWSMode != WebServiceModel.WSMODE_PAGELET)
        {
          DrawCheckBox(myTable, HTMLCHECKBOX_SEND_TIMEZONE, "1", m_asOwner.GetString(1037,
           "ptmsgs_portaladminmsgs"), modelRO.GetSendTimezone());
        }
        // If this is a pagelet, then the login token will be pre-selected and
        // the UI checkbox should be greyed out read only.
        bool bTokenDisabled = (nWSMode == WebServiceModel.WSMODE_PAGELET);
        DrawCheckBox(myTable, HTMLCHECKBOX_SEND_LOGINTOKEN, "1", m_asOwner.GetString(1035,
         "ptmsgs_portaladminmsgs"), modelRO.GetSendLoginToken(), bTokenDisabled);
        // Show the Login Token in minutes.
        myRow = WSViewHelper.AddRow(myTable);
        // Left Margin
        WSViewHelper.AddEmptyCell(myRow, "1");
        myCell = WSViewHelper.AddEmptyCell(myRow, "1");
        myCell.SetWidth("30");
        // The label.
        myCell = WSViewHelper.AddCell(myRow, "1");
        mySpan = WSViewHelper.AddSpanToCell(myCell);
        // AGC- All of these spaces are just for an indent.
        mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_asOwner.GetString(1040,
         "ptmsgs_portaladminmsgs")) + SPACE + SPACE);
        // The actual input			
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_LOGINTOKEN_TIMEOUT,
         "");
        //This is a number input box, so set the size = 3
        myInput.SetSize(3);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        String strSetDuration = XPConvert.ToString(modelRO.GetTokenTimeout());
        if ((null != strSetDuration) && (0 != strSetDuration.Length))
        {
          myInput.SetValue(strSetDuration);
        }
        mySpan.AddInnerHTMLElement(myInput);
        // Add the refresh button checkbox at the end, only if it's a portlet or pagelet -jas
        if ((nWSMode == WebServiceModel.WSMODE_PORTLET) || (nWSMode == WebServiceModel.WSMODE_PAGELET))
        {
          DrawCheckBox(myTable, HTMLCHECKBOX_REFRESH_BUTTON, "1", m_asOwner.GetString(2732,
           "ptmsgs_portaladminmsgs"), modelRO.GetRefreshButton());
        }
        // Add the shared session checkbox at the end, only if it's a portlet -jas
        if (nWSMode == WebServiceModel.WSMODE_PORTLET)
        {
          DrawCheckBox(myTable, HTMLCHECKBOX_SHARED_SESSION, "1", m_asOwner.GetString(2733,
           "ptmsgs_portaladminmsgs"), modelRO.GetSharedSession());
        }
        // Add the send subportal ID checkbox. This is for all types of web services except for pagelets.
        if (nWSMode != WebServiceModel.WSMODE_PAGELET)
        {
          DrawCheckBox(myTable, HTMLCHECKBOX_SEND_SUBPORTALID, "1", m_asOwner.GetString(2832,
           "ptmsgs_portaladminmsgs"), modelRO.GetSendSubportalID());
        }
        // Add the portlet alignment checkbox. This is only for portlets.
        if (nWSMode == WebServiceModel.WSMODE_PORTLET)
        {
          DrawCheckBox(myTable, HTMLCHECKBOX_SEND_ALIGNMENT, "1", m_asOwner.GetString(2833,
           "ptmsgs_portaladminmsgs"), modelRO.GetSendAlignment());
        }
        // Right Margin
        WSViewHelper.AddSpacerCell(myRow, "1");
        WSViewHelper.AddEmptyCell(myRow, "1");
        // last row (spacer row)
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML.");
        throw new XPException(m_asOwner.GetString(1032, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
    // Helper Function:
    private void DrawCheckBox(HTMLTable myTable, String strHTTP, String strValue,
     String strUI, bool bChecked)
    {
      WSViewHelper.AddSimpleCheckbox(myTable, 5, strUI, strHTTP, strValue,
       bChecked, "");
    }
    private void DrawCheckBox(HTMLTable myTable, String strHTTP, String strValue,
     String strUI, bool bChecked, bool bDisabled)
    {
      WSViewHelper.AddSimpleCheckbox(myTable, 5, strUI, strHTTP, strValue,
       bChecked, "", bDisabled);
    }
  }
}