using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class AssocObjectsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.AssocObjectsPluginView");
    public const String STR_MVC_CLASS_NAME = "AssocObjectsPluginView";
    
    /// <summary>
    /// List of CLASSIDs to display in the associated objects view
    /// </summary>
    internal int[] m_arnCLASSIDSToDisplay;
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <summary>
    /// A simple boolean for determining wether the next row should be grey or not.
    /// </summary>
    private bool m_bRowColor = true;
    public AssocObjectsPluginView() : base()
    {
      m_arnCLASSIDSToDisplay = new int[]{PT_CLASSIDS.PT_GADGET_ID, PT_CLASSIDS.PT_GADGETTEMPLATE_ID,
       PT_CLASSIDS.PT_AUTHSOURCE_ID, PT_CLASSIDS.PT_DATASOURCE_ID, PT_CLASSIDS.PT_FEDERATEDPORTAL_ID,
       PT_CLASSIDS.PT_PROFILESOURCE_ID};
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AssocObjectsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1042,
         "ptmsgs_portaladminmsgs")));
        // Containing Table
        myTable = WSViewHelper.AddListTable(result);
        // row 1 begins - The header for the object table.			
        //mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_asOwner.GetString(722, "ptmsgs_portaladminmsgs")));
        // The headers:
        String[] arsHeaders = new String[4];
        arsHeaders[0] = "";
        arsHeaders[1] = m_asOwner.GetString(1043, "ptmsgs_portaladminmsgs");
        arsHeaders[2] = m_asOwner.GetString(1044, "ptmsgs_portaladminmsgs");
        arsHeaders[3] = m_asOwner.GetString(1915, "ptmsgs_portaladminmsgs");
        WSViewHelper.AddSimpleTableHeader(myTable, arsHeaders);
        // rows 2-x begin - The table itself.
        int nItemsDisplayed = 0;
        for (int nIndex = 0;nIndex < m_arnCLASSIDSToDisplay.Length;nIndex++)
        {
          int nCLASSID = m_arnCLASSIDSToDisplay[nIndex];
          IASQueryResult ptQRAssocWebServices = ((IAssocObjectsPluginModelRO) m_model).GetAssocObjects(nCLASSID);
          if ((null != ptQRAssocWebServices) && (ptQRAssocWebServices.GetCount() > 0))
          {
            nItemsDisplayed+=DisplayObjectList(myTable, ptQRAssocWebServices,
             nCLASSID);
          }
        }
        if (nItemsDisplayed <= 0)
        {
          myRow = WSViewHelper.AddRow(myTable);
          WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.THREE, m_asOwner.GetString(1046,
           "ptmsgs_portaladminmsgs"));
        }
      }
      catch (Exception e)
      {
        log.Error(e, "AssocWebServicesView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1041, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns a collection of rows and what not that can be added to a table. 
    /// </summary>
    public virtual int DisplayObjectList(HTMLTable parentTable, IASQueryResult ptQRtoDisplay,
     int nCLASSID)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      int nMaxCount = ptQRtoDisplay.GetCount();
      WebServiceModel mParent = (WebServiceModel) m_asasParent.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      IPTSession ptSession = mParent.GetPTSession();
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      for (int nRowIndex = 0;nRowIndex < nMaxCount;nRowIndex++)
      {
        myRow = WSViewHelper.AddRow(parentTable);
        // Add Class description			
        String strProvCLSID = WSViewHelper.GetQRValueAsString(ptQRtoDisplay,
         nRowIndex, PT_PROPIDS.PT_PROPID_GADGET_PROVIDERCLSID);
        // Icon
        myCell = WSViewHelper.AddIconCell(myRow, CommonHTMLStrings.ONE, nCLASSID,
         strProvCLSID, strLangID);
        // Do the alternate color line thingy.
        WSViewHelper.SetRowColor(myCell, m_bRowColor);
        int nObjectID = WSViewHelper.GetQRValueAsInt(ptQRtoDisplay, nRowIndex,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        int nFolderID = WSViewHelper.GetQRValueAsInt(ptQRtoDisplay, nRowIndex,
         PT_PROPIDS.PT_PROPID_FOLDERID);
        String strPath = WSViewHelper.GetAdminFolderPath(ptSession, nFolderID);
        String strName = WSViewHelper.GetQRValueAsString(ptQRtoDisplay, nRowIndex,
         PT_PROPIDS.PT_PROPID_NAME);
        // Name
        myCell = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE, "");
        mySpan = WSViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        mySpan.AddInnerHTMLElement(WSViewHelper.MakeEditObjectLink(nCLASSID,
         nObjectID, strName, m_asOwner));
        mySpan.AddInnerHTMLString(SPACE);
        // AGC- Add the Description on the following line.
        // Description
        Object objValue = ptQRtoDisplay.GetFields(nRowIndex, PT_PROPIDS.PT_PROPID_DESCRIPTION);
        String strDesc = "";
        if (null != objValue)
        {
          strDesc = XPConvert.ToString(objValue);
        }
        if ((null != strDesc) && (strDesc.Length > 0))
        {
          mySpan = WSViewHelper.AddSpanToCell(myCell);
          mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
          mySpan.AddInnerHTMLElement(new HTMLBr());
          mySpan.AddInnerHTMLEncodedString(strDesc);
        }
        // Do the alternate color line thingy.
        WSViewHelper.SetRowColor(myCell, m_bRowColor);
        // Path
        myCell = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        mySpan = WSViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
        mySpan.AddInnerHTMLEncodedString(strPath);
        mySpan.AddInnerHTMLString(SPACE);
        // Do the alternate color line thingy.
        WSViewHelper.SetRowColor(myCell, m_bRowColor);
        // Type
        myCell = WSViewHelper.AddTypeCell(myRow, CommonHTMLStrings.ONE, nCLASSID,
         strProvCLSID, strLangID);
        // Do the alternate color line thingy.
        WSViewHelper.SetRowColor(myCell, m_bRowColor);
        m_bRowColor = !m_bRowColor;
      }
      return nMaxCount;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}