using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.security;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class BasicAuthPluginModel : EditorHelperModel,IBasicAuthPluginModelRO,
  IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.BasicAuthPluginModel");
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "BasicAuth";
    
    /// <summary>
    /// The following static strings are used by the Section as values returned by
    /// the Authentication Type radio buttons. The HTMLRADIO_BASE_AUTH_TYPE
    /// input must return one and only one of these strings. The value of these
    /// strings is irrelevant - they merely must be unique and URL/HTML safe.
    /// </summary>
    public const int AUTHTYPE_REMOTE_SERVER = 0;
    public const int AUTHTYPE_USER = 1;
    public const int AUTHTYPE_ADMIN = 2;
    public const int AUTHTYPE_LOCKBOX = 3;
    
    /// <summary>
    /// This response variable gets us the Basic Auth Settings 
    /// </summary>
    public const String HTMLRADIO_BASE_AUTH_TYPE = "in_ra_BaseAuthType";
    
    /// <summary>
    /// This response variable gets us the Login Name 
    /// </summary>
    public const String HTMLINPUT_LOGIN_NAME = "in_tx_LoginName";
    
    /// <summary>
    /// This response variable gets us the Password 
    /// </summary>
    public const String HTMLINPUT_PASSWORD = "in_pw_Password";
    
    /// <summary>
    /// This string is used in lieu of returning the actual password to the
    /// client. If this string is unchanged - we will assume that the client
    /// has not changed the password and not reset it.
    /// </summary>
    public const String NULL_PASSWORD = "************";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor 
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// This member contains our Login Name 
    /// </summary>
    private String m_strLoginName = "";
    
    /// <summary>
    /// This member is used in determining whether the login name has changed
    /// (if the object was edited, say). We use this in order to determine when
    /// to blank the password when the object is edited.
    /// </summary>
    private String m_strOriginalLoginName = "";
    
    /// <summary>
    /// This member contains our Password 
    /// </summary>
    private String m_strPassword = "";
    
    /// <summary>
    /// This member contains our Basic Auth settings 
    /// </summary>
    private int m_intAuthTypeRadio;
    public BasicAuthPluginModel() : base()
    {
      m_intAuthTypeRadio = AUTHTYPE_REMOTE_SERVER;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new BasicAuthPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // Set the Authentication Info
      switch (m_intAuthTypeRadio){
      case AUTHTYPE_USER:
      case AUTHTYPE_LOCKBOX:
      ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME);
      ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD);
      // aj: AUTHTYPE_USER => PlumtreeExtensiblity.BASIC_AUTH_TYPE_PORTAL_AUTH (1)
      //     AUTHTYPE_LOCKBOX => PlumtreeExtensbility.BASIC_AUTH_TYPE_LOCKBOX_AUTH (2)
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
       ((m_intAuthTypeRadio == AUTHTYPE_USER) ? (1) : (2)));
      break;
      case AUTHTYPE_ADMIN:
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
       0);
      // Make sure we don't overwrite any existing password if it (and the Login Name)
      // wasn't changed.
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME,
       m_strLoginName);
      if ((0 != NULL_PASSWORD.CompareTo(m_strPassword)) || ((0 == NULL_PASSWORD.CompareTo(m_strPassword)) && (0 != m_strLoginName.CompareTo(m_strOriginalLoginName))))
      {
        // AGC- Don't forget to cipher the bastard...
        //MES- CR: Need to handle the case where user changed username but not password- decrypt the old
        //	password and re-encrypt with new username.
        IXPCrypto xpcpPass = XPCrypto.GetInstance(XPCryptoType.AES_128);
        if (0 == NULL_PASSWORD.CompareTo(m_strPassword))
        {
          String strOldCryptedPassword = WSModelHelper.PBReadString(ptProviderInfo,
           AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD,
           "");
          if (strOldCryptedPassword.Length > 0)
          {
            m_strPassword = xpcpPass.Decrypt(strOldCryptedPassword, m_strOriginalLoginName);
            }
        }
        String strCryptPass = xpcpPass.Encrypt(m_strPassword, m_strLoginName);
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD,
         strCryptPass);
      }
      break;
      //AUTHTYPE_NONE
      default:
      ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME);
      ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
       0);
      break;
      }
      // If this object is ever accessed again before this model goes away, we want to
      // make sure that the original login name is updated correctly.
      m_strOriginalLoginName = WSModelHelper.PBReadString(ptProviderInfo,
       AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME, "");
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <summary>
    /// Returns the strAuthTypeRadio.
    /// </summary>
    /// <returns>String</returns>
    public virtual int GetAuthType()
    {
      return m_intAuthTypeRadio;
    }
    
    /// <summary>
    /// Returns the strLoginName. Note that there is no getter for the Password
    /// (it is never sent back to the client).
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetLoginName()
    {
      return m_strLoginName;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      if (null != ptProviderInfo)
      {
        m_strLoginName = "";
        m_strOriginalLoginName = "";
        m_strPassword = "";
        m_intAuthTypeRadio = AUTHTYPE_REMOTE_SERVER;
        if (EditorStartControl.EDITOR_START_FLAG_CREATE != ((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetEditorType())
        {
          m_strLoginName = WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME,
           m_strLoginName);
          m_strOriginalLoginName = m_strLoginName;
          m_strPassword = NULL_PASSWORD;
          int nGetSendUserAuth = WSModelHelper.PBReadInt(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
           0);
          // aj: 1 => PlumtreeExtensibility.BASIC_AUTH_TYPE_PORTAL_AUTH
          //     2 => PlumtreeExtensibility.BASIC_AUTH_TYPE_LOCKBOX_AUTH
          if (nGetSendUserAuth == 1)
          {
            m_strLoginName = "";
            m_strOriginalLoginName = "";
            m_intAuthTypeRadio = AUTHTYPE_USER;
          } else
          if (nGetSendUserAuth == 2)
          {
            m_strLoginName = "";
            m_strOriginalLoginName = "";
            m_intAuthTypeRadio = AUTHTYPE_LOCKBOX;
          } else
          if ((null == m_strLoginName) || (0 >= m_strLoginName.Length))
          {
            m_intAuthTypeRadio = AUTHTYPE_REMOTE_SERVER;
          } else
          {
            m_intAuthTypeRadio = AUTHTYPE_ADMIN;
          }
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      SetLoginName(WSModelHelper.GetFormElementString(_htFormData, HTMLINPUT_LOGIN_NAME,
       GetLoginName()));
      SetPassword(WSModelHelper.GetFormElementString(_htFormData, HTMLINPUT_PASSWORD,
       m_strPassword));
      SetAuthType(WSModelHelper.GetFormElementInt(_htFormData, HTMLRADIO_BASE_AUTH_TYPE,
       GetAuthType()));
      // Validation
      if (AUTHTYPE_ADMIN == m_intAuthTypeRadio)
      {
        return WSModelHelper.ValidateLoginPassword(m_strLoginName, m_strPassword,
         NULL_PASSWORD, m_asOwner, m_asOwner.GetString(1054, "ptmsgs_portaladminmsgs"),
         RepostControl.PAGE_STATUS_VALID);
      }
      // aj: if we're using lock box auth, we need to make
      //     sure a lockbox is selected...
      if (m_intAuthTypeRadio == AUTHTYPE_LOCKBOX)
      {
        // aj: first check if the model exists
        bool bModelExists = m_asOwner.GetModelExists(WebServiceEditorAS.strStorage_CredentialVaultPluginView);
        int nLockBoxID = 0;
        // aj: if the model exists, get the lock box id
        if (bModelExists)
        {
          nLockBoxID = ((ICredentialVaultPluginModelRO) m_asOwner.GetModel(WebServiceEditorAS.strStorage_CredentialVaultPluginView)).GetLockboxObjectID();
          }
        // aj: if either the lockbox didn't exist, or the lockbox is not choosen, 
        //     then we can raise an error here...
        nPageStatus = WSModelHelper.ValidateBool(nLockBoxID != 0, m_asOwner,
         m_asOwner.GetString(2973, ResourceConstants.PORTALADMINMSGS), nPageStatus);
        }
      return nPageStatus;
    }
    
    /// <summary>
    /// Sets the strAuthTypeRadio.
    /// </summary>
    /// <param name="intAuthTypeRadio">The strAuthTypeRadio to set</param>
    public virtual void SetAuthType(int intAuthTypeRadio)
    {
      // We must receive one of the Radio value strings above (AUTHTYPE_REMOTE_SERVER, 
      // ...USER, ...LOCKBOX or ...ADMIN). These will determine what gets stored in the 
      // Remote Server object.
      switch (intAuthTypeRadio){
      case AUTHTYPE_REMOTE_SERVER:
      case AUTHTYPE_USER:
      case AUTHTYPE_ADMIN:
      case AUTHTYPE_LOCKBOX:
      this.m_intAuthTypeRadio = intAuthTypeRadio;
      break;
      default:
      log.Error("BasicAuthSettingsPluginModel::SetAuthType(" + intAuthTypeRadio + ") an invalid AuthType was received. The Authtype will be set to REMOTE SERVER.");
      break;
      }
    }
    
    /// <summary>
    /// Sets the strLoginName.
    /// </summary>
    /// <param name="strLoginName">The strLoginName to set</param>
    public virtual void SetLoginName(String strLoginName)
    {
      this.m_strLoginName = strLoginName;
    }
    
    /// <summary>
    /// Sets the strPassword. Note that there is no getter for the Password.
    /// </summary>
    /// <param name="strPassword">The strPassword to set</param>
    public virtual void SetPassword(String strPassword)
    {
      if (XPStringUtility.Compare(NULL_PASSWORD, strPassword) != 0)
      {
        this.m_strPassword = strPassword;
      }
    }
  }
}