using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class BasicAuthPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.BasicAuthPluginView");
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "BasicAuthPluginView";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new BasicAuthPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      int COLUMNS = 7;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1055,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
        // Radio Category Label
        WSViewHelper.AddSimpleLabel(myTable, COLUMNS, m_asOwner.GetString(1057,
         "ptmsgs_portaladminmsgs"));
        // Base URL Auth Type Radio Selection
        int intCurrentAuthType = (((IBasicAuthPluginModelRO) m_model).GetAuthType());
        WSViewHelper.AddSimpleRadio(myTable, COLUMNS, m_asOwner.GetString(1058,
         "ptmsgs_portaladminmsgs"), BasicAuthPluginModel.HTMLRADIO_BASE_AUTH_TYPE,
         XPConvert.ToString(BasicAuthPluginModel.AUTHTYPE_REMOTE_SERVER),
         (BasicAuthPluginModel.AUTHTYPE_REMOTE_SERVER == intCurrentAuthType));
        WebServiceModel modelParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
        switch (modelParent.GetWSMode()){
        case WebServiceModel.WSMODE_AWS:
        case WebServiceModel.WSMODE_PWS:
        break;
        default:
        WSViewHelper.AddSimpleRadio(myTable, COLUMNS, m_asOwner.GetString(1059,
         "ptmsgs_portaladminmsgs"), BasicAuthPluginModel.HTMLRADIO_BASE_AUTH_TYPE,
         XPConvert.ToString(BasicAuthPluginModel.AUTHTYPE_USER), (BasicAuthPluginModel.AUTHTYPE_USER == intCurrentAuthType));
        break;
        }
        if (modelParent.GetWSMode() == WebServiceModel.WSMODE_PORTLET)
        {
          WSViewHelper.AddSimpleRadio(myTable, COLUMNS, m_asOwner.GetString(2972,
           "ptmsgs_portaladminmsgs"), BasicAuthPluginModel.HTMLRADIO_BASE_AUTH_TYPE,
           XPConvert.ToString(BasicAuthPluginModel.AUTHTYPE_LOCKBOX), (BasicAuthPluginModel.AUTHTYPE_LOCKBOX == intCurrentAuthType));
          }
        WSViewHelper.AddSimpleRadio(myTable, COLUMNS, m_asOwner.GetString(1060,
         "ptmsgs_portaladminmsgs"), BasicAuthPluginModel.HTMLRADIO_BASE_AUTH_TYPE,
         XPConvert.ToString(BasicAuthPluginModel.AUTHTYPE_ADMIN), (BasicAuthPluginModel.AUTHTYPE_ADMIN == intCurrentAuthType));
        //// Login and Password for Admin Radio selection.
        myRow = WSViewHelper.AddRow(myTable);
        WSViewHelper.AddLeftMargin(myRow, COLUMNS);
        WSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        WSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        WSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(1061,
         "ptmsgs_portaladminmsgs"));
        WSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.ONE, ((IBasicAuthPluginModelRO) m_model).GetLoginName(),
         BasicAuthPluginModel.HTMLINPUT_LOGIN_NAME, 15);
        WSViewHelper.AddRightMargin(myRow, COLUMNS);
        myRow = WSViewHelper.AddRow(myTable);
        WSViewHelper.AddLeftMargin(myRow, COLUMNS);
        WSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        WSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
        WSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(1062,
         "ptmsgs_portaladminmsgs"));
        WSViewHelper.AddPasswordBoxCell(myRow, CommonHTMLStrings.ONE, BasicAuthPluginModel.NULL_PASSWORD,
         BasicAuthPluginModel.HTMLINPUT_PASSWORD, 15);
        WSViewHelper.AddRightMargin(myRow, COLUMNS);
        // last row begins (Bottom Margin)
        WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1056, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}