using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class CWSSettingsPluginModel : EditorHelperModel,ICWSSettingsPluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CWSSettings";
    
    /// <summary>
    /// This mask is used by our view to send time data to us in units that we
    /// support.
    /// </summary>
    public static readonly int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES | PTDurationCombo.DISPLAYSECONDS;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// URL to this Web Service (To be combined with the BaseURL from the Remote Server)
    /// (RemoteServerPluginView) 
    /// </summary>
    private String m_strContainerURL = "";
    
    /// <summary>
    /// Document URL to this Web Service (To be combined with the BaseURL from the Remote Server)
    /// (RemoteServerPluginView) 
    /// </summary>
    private String m_strDocumentURL = "";
    
    /// <summary>
    /// Upload URL to this Web Service (To be combined with the BaseURL from the Remote Server)
    /// (RemoteServerPluginView) 
    /// </summary>
    private String m_strUploadURL = "";
    
    /// <summary>
    /// Timeout information.
    /// </summary>
    protected PTDuration m_ptdSOAPTimeout;
    protected PTDuration m_ptdGatewayTimeout;
    public CWSSettingsPluginModel() : base()
    {
      m_ptdSOAPTimeout = new PTDuration(300000, NMASK_SUPPORTED_UNITS);
      m_ptdGatewayTimeout = new PTDuration(20000, NMASK_SUPPORTED_UNITS);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CWSSettingsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT,
       AExtensibilityConstants.PT_PROPBAG_FORMAT_HTTPGADGET_INIT);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_CONTAINERURL,
       GetContainerURL());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_DOCUMENTURL,
       GetDocumentURL());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL,
       GetUploadURL());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
       m_ptdSOAPTimeout.GetMilliseconds());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT,
       m_ptdGatewayTimeout.GetMilliseconds());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <summary>
    /// Returns the CWS Container URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetContainerURL()
    {
      return m_strContainerURL;
    }
    
    /// <summary>
    /// Returns the CWS Document URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetDocumentURL()
    {
      return m_strDocumentURL;
    }
    
    /// <summary>
    /// Returns the CWS Document URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetUploadURL()
    {
      return m_strUploadURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return CWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      SetContainerURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_CONTAINERURL,
       m_strContainerURL));
      SetDocumentURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_DOCUMENTURL,
       m_strDocumentURL));
      SetUploadURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL,
       m_strUploadURL));
      m_ptdSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT, m_ptdSOAPTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
      m_ptdGatewayTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT, m_ptdGatewayTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetContainerURL(WSModelHelper.GetFormElementString(_htFormData, CWSSettingsPluginView.HTMLINPUT_CONTAINER_URL,
       GetContainerURL()));
      SetDocumentURL(WSModelHelper.GetFormElementString(_htFormData, CWSSettingsPluginView.HTMLINPUT_DOCUMENT_URL,
       GetDocumentURL()));
      SetUploadURL(WSModelHelper.GetFormElementString(_htFormData, CWSSettingsPluginView.HTMLINPUT_UPLOAD_URL,
       GetUploadURL()));
      m_ptdSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       CWSSettingsPluginView.HTMLINPUT_TIMEOUT_SOAPDURATION, CWSSettingsPluginView.HTMLSELECT_TIMEOUT_SOAPUNITS,
       m_ptdSOAPTimeout);
      m_ptdGatewayTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       CWSSettingsPluginView.HTMLINPUT_TIMEOUT_GATEWAYDURATION, CWSSettingsPluginView.HTMLSELECT_TIMEOUT_GATEWAYUNITS,
       m_ptdGatewayTimeout);
      int nValid = RepostControl.PAGE_STATUS_VALID;
      if ((null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strContainerURL, m_asOwner,
         m_asOwner.GetString(1919, "ptmsgs_portaladminmsgs"), nValid);
        nValid = WSModelHelper.ValidateIsURLString(m_strDocumentURL, m_asOwner,
         m_asOwner.GetString(1919, "ptmsgs_portaladminmsgs"), nValid);
      } else
      {
        nValid = WSModelHelper.ValidateNonEmptyString(m_strContainerURL, m_asOwner,
         m_asOwner.GetString(1072, "ptmsgs_portaladminmsgs"), nValid);
        nValid = WSModelHelper.ValidateNonEmptyString(m_strDocumentURL, m_asOwner,
         m_asOwner.GetString(1072, "ptmsgs_portaladminmsgs"), nValid);
      }
      nValid = WSModelHelper.ValidateDurationRange(m_ptdSOAPTimeout, m_asOwner,
       m_asOwner.GetString(1920, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 90);
      nValid = WSModelHelper.ValidateDurationRange(m_ptdGatewayTimeout, m_asOwner,
       m_asOwner.GetString(1921, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 90);
      return nValid;
    }
    
    /// <summary>
    /// Sets the CWS Container URL
    /// </summary>
    /// <param name="strWebServiceURL">The m_strWebServiceURL to set</param>
    public virtual void SetContainerURL(String strWebServiceURL)
    {
      m_strContainerURL = strWebServiceURL;
    }
    
    /// <summary>
    /// Sets the CWS Document URL
    /// </summary>
    /// <param name="strWebServiceURL">The m_strWebServiceURL to set</param>
    public virtual void SetDocumentURL(String strWebServiceURL)
    {
      m_strDocumentURL = strWebServiceURL;
    }
    
    /// <summary>
    /// Sets the CWS Document URL
    /// </summary>
    /// <param name="strWebServiceURL">The m_strWebServiceURL to set</param>
    public virtual void SetUploadURL(String strWebServiceURL)
    {
      m_strUploadURL = strWebServiceURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetGatewayDuration()"></seealso>
    public virtual PTDuration GetGatewayDuration()
    {
      return m_ptdGatewayTimeout;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetSOAPDuration()"></seealso>
    public virtual PTDuration GetSOAPDuration()
    {
      return m_ptdSOAPTimeout;
    }
  }
}