using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class ChooseWSTypePluginModel : EditorHelperModel,IChooseWSTypePluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ChooseWSTypePlugin";
    
    /// <summary>
    /// The following publics should be used by views to Get or Set
    /// enabled-ness.
    /// </summary>
    public const int WS_ENABLED = 1;
    public const int WS_DISABLED = 0;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// Radio item value that contains the WebService type.
    /// The actual provider CLSID to be stored in the WebService object.
    /// </summary>
    private String m_strWebServiceID = "";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ChooseWSTypePluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      // Store ourselves
      // Don't ever store a WStype that is the DEBUG_ME type -- even if we were in
      // debug mode. Bad idea.
      m_ptWebService.SetProviderCLSID(m_strWebServiceID);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
      SetWSTypeFromMode(nNewWSMode);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IChooseWSTypePluginModelRO#GetWSMode()"></seealso>
    public virtual int GetWSMode()
    {
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      return mParent.GetEditorType();
    }
    
    /// <summary>
    /// Returns the m_strWebServiceID. The actual CLSID of the WebServiceType.
    /// </summary>
    /// <returns>int</returns>
    public virtual String GetWSType()
    {
      return m_strWebServiceID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      // Initialize ourselves
      m_strWebServiceID = XPStringUtility.Trim(XPStringUtility.ToUpperCase(m_ptWebService.GetProviderCLSID()));
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(ChooseWSTypePluginView.HTMLRADIO_WSTYPE);
      if ((null != data) && !(0 == data.Length))
      {
        SetWSType(data[0]);
      }
      // AGC- This view should never be open when we store. Since this view should
      // never be shown except for during developer testing, we don't need to post
      // an error either.
      return RepostControl.PAGE_STATUS_INVALID;
    }
    
    /// <summary>
    /// Sets the m_nWebServiceType. Value must be a WSMODE_* as defined
    /// in WebServiceModel.
    /// </summary>
    /// <param name="nWSType">The Web Service Type to set</param>
    public virtual void SetWSType(String strWSType)
    {
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      if ((null == strWSType) || (0 == strWSType.Length))
      {
        m_strWebServiceID = "";
        // Initialize our parent model to the appropriate mode.
        mParent.SetWSMode(WebServiceModel.WSMODE_NONE);
        return;
      } else
      {
        // AGC- we don't really need to set this - this value will
        // be immediately reset in DoTaskOnWSModeUpdate... but for
        // clarity and safety's sakes, we'll set it anyway.
        m_strWebServiceID = XPStringUtility.ToUpperCase(strWSType);
      }
      // Initialize our parent model to the appropriate mode.
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_HTTPGP))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_PORTLET);
      } else
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_IGP))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_INTRINSIC_PORTLET);
      } else
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_AWS))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_AWS);
      } else
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_PWS))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_PWS);
      } else
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_CWS))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_CWS);
      } else
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_SWS))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_SWS);
      } else
      if (0 == m_strWebServiceID.CompareTo(WSModelHelper.WSTYPE_MWS))
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_MWS);
      } else
      {
        mParent.SetWSMode(WebServiceModel.WSMODE_NONE);
      }
    }
    
    /// <summary>
    /// Set the WSType based on the new mode... This does not update the WebServiceModel.
    /// </summary>
    public virtual void SetWSTypeFromMode(int nNewWSMode)
    {
      switch (nNewWSMode){
      case WebServiceModel.WSMODE_PORTLET:
      m_strWebServiceID = WSModelHelper.WSTYPE_HTTPGP;
      break;
      case WebServiceModel.WSMODE_INTRINSIC_PORTLET:
      m_strWebServiceID = WSModelHelper.WSTYPE_IGP;
      break;
      case WebServiceModel.WSMODE_AWS:
      m_strWebServiceID = WSModelHelper.WSTYPE_AWS;
      break;
      case WebServiceModel.WSMODE_PWS:
      m_strWebServiceID = WSModelHelper.WSTYPE_PWS;
      break;
      case WebServiceModel.WSMODE_CWS:
      m_strWebServiceID = WSModelHelper.WSTYPE_CWS;
      break;
      case WebServiceModel.WSMODE_SWS:
      m_strWebServiceID = WSModelHelper.WSTYPE_SWS;
      break;
      case WebServiceModel.WSMODE_MWS:
      m_strWebServiceID = WSModelHelper.WSTYPE_MWS;
      break;
      case WebServiceModel.WSMODE_NONE:
      default:
      m_strWebServiceID = "";
      break;
      }
    }
  }
}