using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class ChooseWSTypePluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.ChooseWSTypePluginView");
    public const String STR_MVC_CLASS_NAME = "ChooseWSTypePluginView";
    public const String HTMLRADIO_WSTYPE = "in_ra_WebServiceID";
    // This string need not be localized - it will only be used for developer debugging.
    public const String _DebugLabel = "Show all possible settings (UI DEBUG MODE ONLY - This does not create a valid Web Service)";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ChooseWSTypePluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLSpan mySpan;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1063,
         "ptmsgs_portaladminmsgs")));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("1");
        myTable.SetCellSpacing("0");
        myTable.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
        // 1st row (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "4");
        // 2nd row 
        myRow = WSViewHelper.AddRow(myTable);
        //// Left Margin
        WSViewHelper.AddEmptyCell(myRow, "1");
        //// Label
        myCell = WSViewHelper.AddCell(myRow, "2");
        myCell.SetVAlign("top");
        mySpan = WSViewHelper.AddSpanToCell(myCell);
        mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_asOwner.GetString(1065,
         "ptmsgs_portaladminmsgs")));
        //// Right Margin
        WSViewHelper.AddEmptyCell(myRow, "1");
        // 3rd - Xth rows
        String strWSTypeChecked = (((IChooseWSTypePluginModelRO) m_model).GetWSType());
        AddRadioToTable(myTable, m_asOwner.GetString(1066, "ptmsgs_portaladminmsgs"),
         WSModelHelper.WSTYPE_HTTPGP, strWSTypeChecked);
        AddRadioToTable(myTable, m_asOwner.GetString(1067, "ptmsgs_portaladminmsgs"),
         WSModelHelper.WSTYPE_IGP, strWSTypeChecked);
        AddRadioToTable(myTable, m_asOwner.GetString(1068, "ptmsgs_portaladminmsgs"),
         WSModelHelper.WSTYPE_CWS, strWSTypeChecked);
        AddRadioToTable(myTable, m_asOwner.GetString(1069, "ptmsgs_portaladminmsgs"),
         WSModelHelper.WSTYPE_AWS, strWSTypeChecked);
        AddRadioToTable(myTable, m_asOwner.GetString(1071, "ptmsgs_portaladminmsgs"),
         WSModelHelper.WSTYPE_SWS, strWSTypeChecked);
        AddRadioToTable(myTable, m_asOwner.GetString(1070, "ptmsgs_portaladminmsgs"),
         WSModelHelper.WSTYPE_PWS, strWSTypeChecked);
        WSViewHelper.AddEmptyRow(myTable, "4");
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1064, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
    // Helper Function
    private void AddRadioToTable(HTMLTable myTable, String strLabel, String strValue,
     String strCheckedValue)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myRow = WSViewHelper.AddRow(myTable);
      //// Left Margin
      WSViewHelper.AddEmptyCell(myRow, "1");
      // radio
      myCell = WSViewHelper.AddCell(myRow, "1");
      mySpan = WSViewHelper.AddSpanToCell(myCell);
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_SIMPLEREPOST).Append(");");
      myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_WSTYPE, "");
      myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
      myInput.SetOnClick(sb.ToString());
      mySpan.AddInnerHTMLElement(myInput);
      myInput.SetValue(strValue);
      // text label
      myCell = WSViewHelper.AddCell(myRow, "1");
      mySpan = WSViewHelper.AddSpanToCell(myCell);
      myCell.SetNoWrap(false);
      mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strLabel));
      if (0 == strValue.CompareTo(strCheckedValue))
      {
        myInput.SetChecked(true);
      } else
      {
        myInput.SetChecked(false);
      }
      //// Right Margin
      WSViewHelper.AddEmptyCell(myRow, "1");
    }
  }
}