using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>josephs</author>
  public class CredentialVaultPluginModel : EditorHelperModel,ICredentialVaultPluginModelRO,
  IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     typeof(CredentialVaultPluginModel));
    public const String STR_MVC_CLASS_NAME = "CredentialVaultPlugin";
    
    /// <summary>
    /// This member defines a static string used to identify when m_htFormData
    /// has been initialized.
    /// </summary>
    public const String DEFAULTDATA = "Default Data";
    // Name of template (null means nothing selected)
    protected String m_strLockboxName = null;
    // Object ID of template (0 means nothing selected)
    
    /// <summary>
    /// Tree Data for the Remote Server for this Web Service (Remote Server)
    /// </summary>
    protected int m_nLockboxObjectID = 0;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// This member contains form data sent to this control (used for the Tree control, mostly).
    /// </summary>
    private XPHashtable m_htFormData;
    public CredentialVaultPluginModel() : base()
    {
      m_htFormData = new XPHashtable();
    }
    
    /// <summary>
    /// This method clears the selected items from the tree.
    /// </summary>
    public virtual void ClearLockbox()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE);
          ATreeModel treeModel = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
          treeModel.ClearSelectedItems();
        }
        m_nLockboxObjectID = 0;
        m_strLockboxName = "";
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unable to clear Lockbox.");
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CredentialVaultPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      // store settings to the provider info property bag -jas
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_LOCKBOX_ID, m_nLockboxObjectID);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)"></seealso>
    public virtual String GetData(String name)
    {
      String[] values = (String[]) m_htFormData.GetElement(name);
      if (values == null)
      {
        return DEFAULTDATA;
      }
      return values[0];
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the name of the Remote Server
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetLockboxName()
    {
      return m_strLockboxName;
    }
    
    /// <summary>
    /// Returns the name of the Remote Server
    /// </summary>
    /// <returns>String</returns>
    public virtual int GetLockboxObjectID()
    {
      return m_nLockboxObjectID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(IPTWebService)"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      // read settings from provider info -jas
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      m_nLockboxObjectID = WSModelHelper.PBReadInt(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_LOCKBOX_ID,
       m_nLockboxObjectID);
      if (0 != m_nLockboxObjectID)
      {
        // read the name -jas
        try
        {
          IPTObjectManager ptSectionManager = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();
          IPTProfileSection ptSection = (IPTProfileSection) ptSectionManager.Open(m_nLockboxObjectID,
           false);
          m_strLockboxName = ptSection.GetLocalizedName();
        }
        catch (Exception e)
        {
          log.Warn(e, "Unable to access Lockbox object: " + e.Message);
        }
      }
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromTree()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE);
          ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList itemList = treeModel.GetSelectedItems();
          if (itemList.GetSize() > 0)
          {
            TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
            if (item == null)
            {
              log.Error("Tree selected item null");
            } else
            {
              m_nLockboxObjectID = item.m_nObjectID;
              m_strLockboxName = item.GetName();
            }
          }
        }
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error RefreshItemFromTree.");
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // Store our form data for later use - especially for use in the tree control.
      int nSize = _htFormData.GetSize();
      IXPEnumerator xpKeys = _htFormData.GetKeys();
      for (int i = 0;i < nSize;i++)
      {
        xpKeys.MoveNext();
        m_htFormData.PutElement((String) xpKeys.GetCurrent(), (String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
        }
      RefreshItemFromTree();
      return RepostControl.PAGE_STATUS_VALID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ICredentialVaultPluginModelRO#IsRemoteServerSecure()
     */
     
    public virtual bool IsRemoteServerSecure()
    {
      // TODO Auto-generated method stub
      return true;
    }
  }
}