using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.admin.editors.webservice.credvaulttree;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This view allows you to choose the Credential Vault used
  /// by this Web Service
  /// </summary>
  /// <author>josephs</author>
  public class CredentialVaultPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     typeof(CredentialVaultPluginView));
    
    /// <summary>
    /// The object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CredentialVaultPluginView";
    
    /// <summary>
    /// Private String that is the function name for the repost javascript called
    /// when the tree control returns
    /// </summary>
    private const String JSREPOST_CREDVAULT_FUNC = "frmRepostRemoteViewChosen";
    private const String JSREPOST_CREDVAULT_FUNC_INPUT = "frmSetDataRemoteViewChosen";
    private const String JSREPOST_CREDVAULTREMOVE_FUNC = "frmRepostRemoteViewRemoved";
    // HTML Object names.
    public const String HTMLHIDDEN_CREDVAULT_SPACE = "in_hi_CredVaultSpace";
    public const String HTMLHIDDEN_CREDVAULT_SELECTED = "in_hi_CredVaultSelected";
    public const String HTMLBUTTON_CREDVAULT_REMOVE = "in_bu_RemoveCredVault";
    private AActivitySpace m_asasParent;
    private ICredentialVaultPluginModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CredentialVaultPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLSpan mySpan;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2872,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 1st row ends
        bool bIsSecureRemoteServer = m_model.IsRemoteServerSecure();
        String strInstructions = m_asOwner.GetString(bIsSecureRemoteServer ? 2970 : 3055,
         ResourceConstants.PORTALADMINMSGS);
        // 1st - A - row begins (Insructions)
        myRow = WSViewHelper.AddRow(myTable);
        WSViewHelper.AddLeftMargin(myRow, 5);
        WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.FIVE, strInstructions);
        WSViewHelper.AddRightMargin(myRow, 5);
        // 1st - A - row ends
        if (bIsSecureRemoteServer)
        {
          // 1st - B - row begins (Spacer)
          WSViewHelper.AddEmptyRow(myTable, "5");
          // 1st - B - row ends
          // 2nd row begins
          myRow = WSViewHelper.AddRow(myTable);
          //// Left Margin
          WSViewHelper.AddLeftMargin(myRow, 5);
          ////// Don't forget to HTMLEncode this stuff..... Important!			
          String strCredentialVaultName = m_model.GetLockboxName();
          bool bValidCredentialVault = true;
          myCell = WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE,
           m_asOwner.GetString(2874, "ptmsgs_portaladminmsgs"));
          if ((null == strCredentialVaultName) || (0 >= strCredentialVaultName.Length))
          {
            strCredentialVaultName = m_asOwner.GetString(2876, "ptmsgs_portaladminmsgs");
            bValidCredentialVault = false;
            myCell = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE,
             strCredentialVaultName);
          } else
          {
            myCell = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE,
             strCredentialVaultName);
          }
          // common opener does not support lockboxes
          /*				HTMLAnchor rsLink = (HTMLAnchor)WSViewHelper.MakeEditObjectLink(PT_CLASSIDS.PT_PROFILESECTION_ID, m_model.GetLockboxObjectID(), strCredentialVaultName, m_asOwner);
           myCell = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
           HTMLSpan rsOpenerSpan = WSViewHelper.AddSpanToCell(myCell);
           rsOpenerSpan.AddInnerHTMLElement(rsLink);	*/
           
          mySpan = WSViewHelper.AddSpanToCell(myCell);
          mySpan.AddInnerHTMLString(SPACE);
          ////// Actual Tree Control
          // Hidden input for the Space ID for the tree.  That way if you hit the folder
          // tree link twice, it will open the same tree both times.
          String strCredentialVaultSpaceID = m_model.GetData(HTMLHIDDEN_CREDVAULT_SPACE);
          if (strCredentialVaultSpaceID.Equals(CredentialVaultPluginModel.DEFAULTDATA))
          {
            mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_CREDVAULT_SPACE,
             ""));
          } else
          {
            mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_CREDVAULT_SPACE,
             strCredentialVaultSpaceID));
          }
          String strOnClick = JSREPOST_CREDVAULT_FUNC_INPUT + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_CREDVAULT_SPACE + "); return false;";
          String strOnClickRemove = JSREPOST_CREDVAULTREMOVE_FUNC + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_CREDVAULT_SPACE + "); return false;";
          mySpan.AddInnerHTMLString(SPACE);
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(m_asOwner.GetString(1140,
           "ptmsgs_portaladminmsgs"), strOnClick));
          // Add a remove button if the remote server is non-null.
          if (bValidCredentialVault)
          {
            mySpan.AddInnerHTMLString(SPACE);
            mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(m_asOwner.GetString(1141,
             "ptmsgs_portaladminmsgs"), strOnClickRemove, HTMLBUTTON_CREDVAULT_REMOVE));
            }
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_CREDVAULT_SELECTED,
           m_model.GetData(HTMLHIDDEN_CREDVAULT_SELECTED)));
          // Right Margin
          WSViewHelper.AddRightMargin(myRow, 5);
        }
        // last row
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(2873, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      String strFormName = AFormDP.HTMLFORM_NAME;
      // The URL to open a new remote folder tree
      ASURL newCredentialVaultTree = new ASURL(m_asOwner);
      // Tree configuration
      //		myNewTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
      //		myNewTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
      //			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      //		myNewTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
      //			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      //		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
      //			AFormDP.HTMLFORM_NAME);
      //		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
      //			((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
      //				HTMLINPUT_TREEASID));
      //		myNewTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
      //			((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
      //				"OnReturnFromTree"));
      //		myNewTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
      // Tree creation and binding
      newCredentialVaultTree.SetLinkCreateNewSpace(CredVaultTreeAS.STR_MVC_CLASS_NAME,
       m_asasParent);
      newCredentialVaultTree.SetSubSpaceKey(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE);
      //		myNewTree.SetSubSpaceKey(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
      //				AddUserInfoPluginModel.SUBSPACE_NAME_SELECTTREE));
      newCredentialVaultTree.SetControl(CredVaultStartTreeControl.STR_MVC_CLASS_NAME);
      //		newCredentialVaultTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      newCredentialVaultTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
       XPConvert.ToString(false));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.SELECT_MODE,
       XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
       XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
       strFormName);
      newCredentialVaultTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       HTMLHIDDEN_CREDVAULT_SPACE);
      newCredentialVaultTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       JSREPOST_CREDVAULT_FUNC);
      newCredentialVaultTree.AddControlArgument(StartTreeControl.SHOW_ROOT,
       XPConvert.ToString(false));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(2875,
       "ptmsgs_portaladminmsgs"));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
       m_asOwner.GetString(2877, "ptmsgs_portaladminmsgs"));
      //		newCredentialVaultTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
      //			XPConvert.ToString(PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID));
      // The url to open a previously opened remote folder tree
      // This needs to have the SpaceID added to it.
      ASURL oldCredentialVaultTree = new ASURL(m_asOwner);
      oldCredentialVaultTree.SetLinkCreateNewSpace(CredVaultTreeAS.STR_MVC_CLASS_NAME,
       m_asasParent);
      oldCredentialVaultTree.IsSubSpace();
      oldCredentialVaultTree.SetControl(CredVaultRefreshTreeControl.STR_MVC_CLASS_NAME);
      //		myOldTree.AddControlArgument(UserInfoRefreshTreeControl.SELECTED_USERINFOS,
      //			UserInfoRefreshTreeControl.UserInfosToString(((AddUserInfoPluginModel)m_model).GetListValues()));
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_CREDVAULT_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_REMOTE_VIEW_CHOSEN).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_CREDVAULTREMOVE_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_CRED_VAULT_REMOVED).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Open remote folder tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JSREPOST_CREDVAULT_FUNC_INPUT).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(newCredentialVaultTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(oldCredentialVaultTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element: " + he.Message);
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
      m_model = (ICredentialVaultPluginModelRO) model;
    }
  }
}