using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>JaneD</author>
  public class DebugConfigPluginModel : EditorHelperModel,IDebugConfigPluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "WSDebugConfigPluginModel";
    
    /// <summary>
    /// Is http request tracing enabled? 
    /// </summary>
    private bool m_bHttpRequestTracingOn = false;
    
    /// <summary>
    /// Is http response tracing enabled? 
    /// </summary>
    private bool m_bHttpResponseTracingOn = false;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DebugConfigPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_HTTP_REQUEST_TRACE_ENABLED,
       GetHTTPRequestTracingOn());
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_HTTP_RESPONSE_TRACE_ENABLED,
       GetHTTPResponseTracingOn());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    // do nothing
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    //do nothing
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      //do nothing
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      m_bHttpRequestTracingOn = WSModelHelper.PBReadBool(ptProviderInfo, PlumtreeExtensibility.PT_HTTP_REQUEST_TRACE_ENABLED,
       m_bHttpRequestTracingOn);
      m_bHttpResponseTracingOn = WSModelHelper.PBReadBool(ptProviderInfo,
       PlumtreeExtensibility.PT_HTTP_RESPONSE_TRACE_ENABLED, m_bHttpResponseTracingOn);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      m_bHttpRequestTracingOn = WSModelHelper.GetFormCheckboxBool(_htFormData,
       DebugConfigPluginView.HTMLRADIO_HTTPREQUEST);
      m_bHttpResponseTracingOn = WSModelHelper.GetFormCheckboxBool(_htFormData,
       DebugConfigPluginView.HTMLRADIO_HTTPRESPONSE);
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IDebugConfigPluginModelRO#GetHTTPRequestTracingOn()"></seealso>
    public virtual bool GetHTTPRequestTracingOn()
    {
      return m_bHttpRequestTracingOn;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IDebugConfigPluginModelRO#GetHTTPResponseTracingOn()"></seealso>
    public virtual bool GetHTTPResponseTracingOn()
    {
      return m_bHttpResponseTracingOn;
    }
  }
}