using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>JaneD</author>
  public class DebugConfigPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.DebugConfigPluginView");
    public const String STR_MVC_CLASS_NAME = "DebugConfigPluginView";
    public const String HTMLRADIO_HTTPREQUEST = "in_ra_HttpRequest";
    public const String HTMLRADIO_HTTPRESPONSE = "in_ra_HttpResponse";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DebugConfigPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      int COLUMNS = 7;
      try
      {
        // heading
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2936,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "7");
        // get the values for tracing from the model
        bool bHttpRequestTracing = (((IDebugConfigPluginModelRO) m_model).GetHTTPRequestTracingOn());
        bool bHttpResponseTracing = (((IDebugConfigPluginModelRO) m_model).GetHTTPResponseTracingOn());
        // Row with request tracing
        HTMLTableRow myRow = WSViewHelper.AddRow(myTable);
        // add margin on the left
        WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        // add label
        WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(2937,
         "ptmsgs_portaladminmsgs"));
        // add spacing
        HTMLTableCell myCell = WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetWidth("20%");
        // add radio box "enabled"
        myCell = WSViewHelper.AddCell(myRow, null);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.AddInnerHTMLElement(WSViewHelper.MakeSimpleRadio(m_asOwner.GetString(2939,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_HTTPREQUEST, CommonHTMLStrings.ONE,
         bHttpRequestTracing, ""));
        // more spacing...
        myCell = WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetWidth("5%");
        // add radio box "disabled"
        myCell = WSViewHelper.AddCell(myRow, null);
        myCell.AddInnerHTMLElement(WSViewHelper.MakeSimpleRadio(m_asOwner.GetString(2940,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_HTTPREQUEST, CommonHTMLStrings.ZERO,
         !bHttpRequestTracing, ""));
        // spacing at the end
        WSViewHelper.AddSpacerCell(myRow, CommonHTMLStrings.ONE);
        // Row with response tracing
        myRow = WSViewHelper.AddRow(myTable);
        // add margin on the left
        WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        // add label
        WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(2938,
         "ptmsgs_portaladminmsgs"));
        // add spacing
        myCell = WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetWidth("20%");
        // add radio box "enabled"
        myCell = WSViewHelper.AddCell(myRow, null);
        myCell.AddInnerHTMLElement(WSViewHelper.MakeSimpleRadio(m_asOwner.GetString(2939,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_HTTPRESPONSE, CommonHTMLStrings.ONE,
         bHttpResponseTracing, ""));
        // more spacing...
        myCell = WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetWidth("5%");
        // add radio box "disabled"
        myCell = WSViewHelper.AddCell(myRow, null);
        myCell.AddInnerHTMLElement(WSViewHelper.MakeSimpleRadio(m_asOwner.GetString(2940,
         "ptmsgs_portaladminmsgs"), HTMLRADIO_HTTPRESPONSE, CommonHTMLStrings.ZERO,
         !bHttpResponseTracing, ""));
        // spacing at the end
        WSViewHelper.AddSpacerCell(myRow, CommonHTMLStrings.ONE);
        // 6th row (spacer row)
        WSViewHelper.AddEmptyRow(myTable, "7");
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1090, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}