using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This view allows you to choose the Remote Server used
  /// by this Web Service
  /// </summary>
  /// <author>adolfoc</author>
  public class DebugPortletPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.DebugPortletPluginView");
    
    /// <summary>
    /// The object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DebugPortletPluginView";
    
    /// <summary>
    /// Private String that is the function name for the repost javascript called
    /// when the tree control returns
    /// </summary>
    private const String JSREPOST_PORTLET_FUNC = "frmRepostPortletChosen";
    private const String JSREPOST_PORTLET_FUNC_INPUT = "frmSetDataPortletChosen";
    private const String JSREPOST_PORTLETREMOVE_FUNC = "frmRepostPortletRemoved";
    // HTML Object names.
    public const String HTMLHIDDEN_PORTLET_SPACE = "in_hi_PortletSpace";
    public const String HTMLHIDDEN_PORTLET_SELECTED = "in_hi_PortletSelected";
    public const String HTMLBUTTON_PORTLET_REMOVE = "in_bu_RemovePortlet";
    private AActivitySpace m_asasParent;
    private IDebugPortletPluginModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DebugPortletPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLSpan mySpan;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(3023,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "6");
        // 1st row ends
        // 2nd row begins
        myRow = WSViewHelper.AddRow(myTable);
        //// Left Margin
        WSViewHelper.AddLeftMargin(myRow, 6);
        int iPortletID = m_model.GetPortletID();
        bool bTraceForAllPortlets = (iPortletID == 0);
        myCell = WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(3024,
         "ptmsgs_portaladminmsgs"));
        if (bTraceForAllPortlets)
        {
          myCell = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE,
           m_asOwner.GetString(3025, "ptmsgs_portaladminmsgs"));
        } else
        {
          // add remote server opener link
          HTMLAnchor rsLink = (HTMLAnchor) WSViewHelper.MakeEditObjectLink(PT_CLASSIDS.PT_GADGET_ID,
           m_model.GetPortletID(), m_model.GetPortletName(), m_asOwner);
          myCell = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
          HTMLSpan rsOpenerSpan = WSViewHelper.AddSpanToCell(myCell);
          rsOpenerSpan.AddInnerHTMLElement(rsLink);
        }
        mySpan = WSViewHelper.AddSpanToCell(myCell);
        mySpan.AddInnerHTMLString(SPACE);
        ////// Actual Tree Control
        // Hidden input for the Space ID for the tree.  That way if you hit the folder
        // tree link twice, it will open the same tree both times.
        String strPortletSpaceID = m_model.GetData(HTMLHIDDEN_PORTLET_SPACE);
        if (strPortletSpaceID.Equals(DebugPortletPluginModel.DEFAULTDATA))
        {
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_PORTLET_SPACE,
           ""));
        } else
        {
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_PORTLET_SPACE,
           strPortletSpaceID));
        }
        String strOnClick = JSREPOST_PORTLET_FUNC_INPUT + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_PORTLET_SPACE + "); return false;";
        String strOnClickRemove = JSREPOST_PORTLETREMOVE_FUNC + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_PORTLET_SPACE + "); return false;";
        mySpan.AddInnerHTMLString(SPACE);
        mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(m_asOwner.GetString(3026,
         "ptmsgs_portaladminmsgs"), strOnClick));
        // Add a remove button if the remote server is non-null.
        if (!bTraceForAllPortlets)
        {
          mySpan.AddInnerHTMLString(SPACE);
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(m_asOwner.GetString(3027,
           "ptmsgs_portaladminmsgs"), strOnClickRemove, HTMLBUTTON_PORTLET_REMOVE));
          }
        mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_PORTLET_SELECTED,
         m_model.GetData(HTMLHIDDEN_PORTLET_SELECTED)));
        // Right Margin
        WSViewHelper.AddRightMargin(myRow, 6);
        // 2nd row ends			
        // 3rd Row - Path info.
        myRow = WSViewHelper.AddRow(myTable);
        //// Left Margin
        WSViewHelper.AddLeftMargin(myRow, 6);
        // 4th row begins
        WSViewHelper.AddEmptyRow(myTable, "6");
      }
      // 4th row ends
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(3030, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      String strFormName = AFormDP.HTMLFORM_NAME;
      // The URL to open a new remote folder tree
      ASURL newDebugPortletTree = new ASURL(m_asOwner);
      newDebugPortletTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
       m_asasParent);
      newDebugPortletTree.SetSubSpaceKey(WebServiceEditorAS.strTREE_SECOND_SUBSPACE);
      newDebugPortletTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      newDebugPortletTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      newDebugPortletTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
       XPConvert.ToString(false));
      newDebugPortletTree.AddControlArgument(StartTreeControl.SELECT_MODE,
       XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      newDebugPortletTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
       XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      newDebugPortletTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
       strFormName);
      newDebugPortletTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       HTMLHIDDEN_PORTLET_SPACE);
      newDebugPortletTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       JSREPOST_PORTLET_FUNC);
      newDebugPortletTree.AddControlArgument(StartTreeControl.QUERY_FILTER,
       XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID) + "," + XPConvert.ToString(PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID) + "," + XPConvert.ToString(m_model.GetWebServiceID()));
      newDebugPortletTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(3028,
       "ptmsgs_portaladminmsgs"));
      newDebugPortletTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
       m_asOwner.GetString(3029, "ptmsgs_portaladminmsgs"));
      newDebugPortletTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
      // The url to open a previously opened remote folder tree
      // This needs to have the SpaceID added to it.
      ASURL oldDebugPortletTree = new ASURL(m_asOwner);
      oldDebugPortletTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
       m_asasParent);
      oldDebugPortletTree.IsSubSpace();
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_PORTLET_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_REMOTE_VIEW_CHOSEN).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_PORTLETREMOVE_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_DEBUG_PORTLET_REMOVED).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Open remote folder tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JSREPOST_PORTLET_FUNC_INPUT).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(newDebugPortletTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(oldDebugPortletTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element: " + he.Message);
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
      m_model = (IDebugPortletPluginModelRO) model;
    }
  }
}