using System;
using com.plumtree.openfoundation.util;
using OpenLogService=com.plumtree.openlog.OpenLogService;
using OpenLogger=com.plumtree.openlog.OpenLogger;
using com.plumtree.portalpages.admin.editors.webservice;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
using com.plumtree.server;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using ATreeAS=com.plumtree.uiinfrastructure.tree.ATreeAS;
using ATreeModel=com.plumtree.uiinfrastructure.tree.ATreeModel;
using ITreeModelRO=com.plumtree.uiinfrastructure.tree.ITreeModelRO;
using TreeLeafNode=com.plumtree.uiinfrastructure.tree.TreeLeafNode;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>JaneD</author>
  public class DebugUserPluginModel : EditorHelperModel,IDebugUserPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "DebugUserPlugin";
    
    /// <summary>
    /// This member defines a static string used to identify when m_htFormData
    /// has been initialized.
    /// </summary>
    public const String DEFAULTDATA = "Default Data";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.DebugUserPluginModel");
    
    /// <summary>
    /// This member contains form data sent to this control (used for the Tree control, mostly).
    /// </summary>
    private XPHashtable m_htFormData;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// User id of the user for which the debug tracing is turned on.
    /// Zero means no user selected (i.e. tracing on for ALL users). 
    /// </summary>
    private int m_nUserID = 0;
    
    /// <summary>
    /// User name of the user for which the debug tracing is turned on.
    /// If this is null, that means no user is selected (i.e. tracing on for ALL users).
    /// </summary>
    private String m_strUserName = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DebugUserPluginModel();
    }
    public DebugUserPluginModel() : base()
    {
      m_htFormData = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_DEBUG_USER_ID,
       m_nUserID);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      m_nUserID = WSModelHelper.PBReadInt(ptProviderInfo, PlumtreeExtensibility.PT_DEBUG_USER_ID,
       m_nUserID);
      UpdateUserName();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // Store our form data for later use - especially for use in the tree control.
      int nSize = _htFormData.GetSize();
      IXPEnumerator xpKeys = _htFormData.GetKeys();
      for (int i = 0;i < nSize;i++)
      {
        xpKeys.MoveNext();
        m_htFormData.PutElement((String) xpKeys.GetCurrent(), (String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
        }
      RefreshItemFromTree();
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromTree()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE);
          ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList itemList = treeModel.GetSelectedItems();
          if (itemList.GetSize() > 0)
          {
            TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
            if (item == null)
            {
              log.Error("Tree selected item null");
            } else
            {
              m_nUserID = item.m_nObjectID;
              m_strUserName = item.GetName();
            }
          }
        }
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error RefreshItemFromTree.");
      }
    }
    
    /// <summary>
    /// Returns the user id of the user for which debugging is turned on.
    /// If it returns 0, that means debugging should be turned on for ALL users.
    /// </summary>
    /// <returns></returns>
    public virtual int GetUserID()
    {
      return m_nUserID;
    }
    
    /// <summary>
    /// Returns the user name of the user for which debugging is turned on.
    /// If it returns null, that means debugging should be turned on for ALL users.
    /// </summary>
    /// <returns></returns>
    public virtual String GetUserName()
    {
      return m_strUserName;
    }
    
    /// <seealso cref="com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)"></seealso>
    public virtual String GetData(String name)
    {
      String[] values = (String[]) m_htFormData.GetElement(name);
      if (values == null)
      {
        return DEFAULTDATA;
      }
      return values[0];
    }
    
    /// <summary>
    /// This method clears the selected items from the tree.
    /// </summary>
    public virtual void ClearUser()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE);
          ATreeModel treeModel = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
          treeModel.ClearSelectedItems();
        }
        m_nUserID = 0;
        m_strUserName = null;
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error ClearUser.");
      }
    }
    
    /// <summary>
    /// Set the name of the user internally.
    /// </summary>
    private void UpdateUserName()
    {
      if (m_nUserID == 0)
      {
        m_strUserName = null;
        return;
      }
      try
      {
        IPTSession ptSession = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();
        IPTUser ptUser = (IPTUser) ptSession.GetUsers().Open(m_nUserID, false);
        m_strUserName = ptUser.GetLocalizedName();
      }
      catch (Exception e)
      {
        log.Warn(e, "DebugUserPluginModel::UpdateUserName - Unable to access user object. Continuing with no user selected: " + e.Message);
        }
    }
  }
}