using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.constants;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// Simple wrapper of the MultiColumnListModel with an extension
  /// for the IWSSubModel.  This second model is necessary for this
  /// model to be used in the WS Plugin architecture.
  /// </summary>
  /// <author>akashj</author>
  public class FormLoginFieldsPluginModel : MultiColumnListModel,IFormLoginFieldsPluginModelRO,
  IWSSubModel
  {
    // commenting out because this logger is never used. maybe it will be some day - CVN
    // private static OpenLogger log = OpenLogService.GetLogger(
    //		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
    //		"com.plumtree.portalpages.admin.editors.webservice.plugins.FormLoginFieldsPluginModel");
    public const String STR_MVC_CLASS_NAME = "FormLoginFieldsPlugin";
    // aj: column constants for the lists
    public const int COLUMN_NAMES = 0;
    public const int COLUMN_VALUES = 1;
    public const int NUM_COLUMNS = 2;
    // aj: the web service we are operating on
    private IPTWebService m_ptWebService = null;
    // aj: arbitrary choice, just can't conflict with an offset that someone else
    //     uses in another expandable list...
    private const int m_nUniqueIDOffset = 5151;
    // aj: default is an empty array
    private static readonly String[] m_arrDefaultValues = {"", ""};
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public override Object Create()
    {
      return new FormLoginFieldsPluginModel();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(com.plumtree.server.IPTWebService)
     */
     
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      // aj: setup the labels and columns
      String strFieldsListAddLabel = m_asOwner.GetString(2946, ResourceConstants.PORTALADMINMSGS);
      String[] strColumnNames = {m_asOwner.GetString(2947, ResourceConstants.PORTALADMINMSGS),
       m_asOwner.GetString(2948, ResourceConstants.PORTALADMINMSGS)};
      // aj: call the internal init function
      InitializeMultiColumnList(m_asOwner.GetString(2949, ResourceConstants.PORTALADMINMSGS),
       strColumnNames, PTImageType.ICON_VALUE, strFieldsListAddLabel, m_nUniqueIDOffset);
      SetDefaultValue(m_arrDefaultValues);
      SetDeleteIcon(PTImageType.ACTION_DELETE);
      // aj: load the provider arrays, we'll put the values we
      //     have here into the list...
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      Object[] aNameList = ptProviderInfo.ReadAsObject1DArray(PlumtreeExtensibility.PT_PROPBAG_FORM_FIELD_NAMES_ARRAY);
      Object[] aValuesList = ptProviderInfo.ReadAsObject1DArray(PlumtreeExtensibility.PT_PROPBAG_FORM_FIELD_VALUES_ARRAY);
      // aj: only continue if the arrays are consistent
      if (aNameList != null && aValuesList != null && aNameList.Length == aValuesList.Length)
      {
        int nLength = aNameList.Length;
        String[][] astrNameValueList = new String[NUM_COLUMNS][];
        for (int j2c_index = 0;j2c_index < NUM_COLUMNS;j2c_index++)
        {
          astrNameValueList[j2c_index] = new String[nLength];
        }
        for (int nIndex = 0;nIndex < nLength;nIndex++)
        {
          astrNameValueList[COLUMN_NAMES][nIndex] = XPConvert.ToString(aNameList[nIndex]);
          astrNameValueList[COLUMN_VALUES][nIndex] = XPConvert.ToString(aValuesList[nIndex]);
          }
        AddRowsToList(astrNameValueList);
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
     */
     
    public virtual void DoTaskBeforeWSStore()
    {
      Object[][] aGrowableArrayValues = GetListValues();
      XPArrayList aNameList = new XPArrayList();
      XPArrayList aValueList = new XPArrayList();
      // Turn this into an Object array so that we can store it.			
      for (int nIndex = 0;nIndex < aGrowableArrayValues[0].Length;nIndex++)
      {
        String strFieldName = XPConvert.ToString(aGrowableArrayValues[COLUMN_NAMES][nIndex]);
        String strFieldValue = XPConvert.ToString(aGrowableArrayValues[COLUMN_VALUES][nIndex]);
        // AGC- Warning... We're doing a trim here. I think it is valid, but
        // it is worth noting.
        strFieldName = XPStringUtility.Trim(strFieldName);
        strFieldValue = XPStringUtility.Trim(strFieldValue);
        // aj: only named fields should be persisted
        if (0 < strFieldName.Length)
        {
          aNameList.Add(strFieldName);
          aValueList.Add(strFieldValue);
        }
      }
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_FORM_FIELD_NAMES_ARRAY,
       aNameList.ToArray());
      ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_FORM_FIELD_VALUES_ARRAY,
       aValueList.ToArray());
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(java.lang.String, java.lang.String, java.lang.String)
     */
     
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    // aj: NOP
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
     */
     
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    // aj: NOP
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
     */
     
    public virtual String GetValidationFunction()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.growablelist.IGrowableListModelRO#GetAlertMessage()
     */
     
    public virtual String GetAlertMessage()
    {
      // no message needed because validation type is NONE -jas
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.growablelist.IGrowableListModelRO#GetClientValidationType()
     */
     
    public virtual int GetClientValidationType()
    {
      return GrowableListModel.CLIENT_VALIDATION_TYPE_NONE;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
     */
     
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nPageStatus = base.SaveSection(_htFormData);
      // aj: report explist problems first
      if (nPageStatus != RepostControl.PAGE_STATUS_VALID)
      {
        return nPageStatus;
      }
      // aj: main validation we want to do is that we have at least a name
      //     for each row - fields are optional
      bool bHasData = false;
      Object[][] aGrowableArrayValues = GetListValues();
      int nLength = aGrowableArrayValues[0].Length;
      for (int i = 0;i < nLength;i++)
      {
        // aj: does the first entry in the array actually contain anything?
        String sFormName = XPConvert.ToString(aGrowableArrayValues[COLUMN_NAMES][i]);
        String sFormField = XPConvert.ToString(aGrowableArrayValues[COLUMN_VALUES][i]);
        // aj: only if the field is non-empty, check the name...
        if (sFormField != null && sFormField.Length > 0)
        {
          nPageStatus = WSModelHelper.ValidateNonEmptyString(sFormName, m_asOwner,
           m_asOwner.GetString(2950, ResourceConstants.PORTALADMINMSGS), nPageStatus);
          bHasData = true;
        }
      }
      // aj: secondary - if we have at least one row, then we need to ensure that
      //     we also have a login form and url in the FormLoginPluginModel
      if (bHasData)
      {
        String sLoginURL = ((IFormLoginPluginModelRO) m_asOwner.GetModel(WebServiceEditorAS.strStorage_FormLoginPluginView)).GetLoginURL();
        String sPostURL = ((IFormLoginPluginModelRO) m_asOwner.GetModel(WebServiceEditorAS.strStorage_FormLoginPluginView)).GetPostURL();
        // aj: make sure the form login plugin model stuff is OK
        nPageStatus = WSModelHelper.ValidateIsURLString(sLoginURL, m_asOwner,
         m_asOwner.GetString(2951, ResourceConstants.PORTALADMINMSGS), nPageStatus);
        nPageStatus = WSModelHelper.ValidateIsURLString(sPostURL, m_asOwner,
         m_asOwner.GetString(2951, ResourceConstants.PORTALADMINMSGS), nPageStatus);
        }
      return nPageStatus;
    }
  }
}