using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>akashj</author>
  public class FormLoginPluginModel : EditorHelperModel,IFormLoginPluginModelRO,
  IWSSubModel
  {
    // commenting out becasue this logger is never used. maybe it will be some day - CVN
    //	private static OpenLogger log = OpenLogService.GetLogger(
    //		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
    //		"com.plumtree.portalpages.admin.editors.webservice.plugins.FormLoginPluginModel");
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "FormLogin";
    
    /// <summary>
    /// URLs - login and post 
    /// </summary>
    public const String HTMLINPUT_LOGINURL = "in_tx_LoginURL";
    public const String HTMLINPUT_POSTURL = "in_tx_PostURL";
    
    /// <summary>
    /// Form Fields - username and password 
    /// </summary>
    public const String HTMLINPUT_USERNAME_FIELD_NAME = "in_tx_UsernameFieldName";
    public const String HTMLINPUT_PASSWORD_FIELD_NAME = "in_tx_PasswordFieldName";
    
    /// <summary>
    /// Radio - credential type to be sent (see constants below) 
    /// </summary>
    public const String HTMLRADIO_CREDENTIAL_TYPE = "in_ra_CredentialType";
    
    /// <summary>
    /// the mvars related to various field in the view 
    /// </summary>
    private String m_sLoginURL;
    private String m_sPostURL;
    private int m_nCredentialType;
    private String m_sPasswordFieldName;
    private String m_sUsernameFieldName;
    
    /// <summary>
    /// constants 
    /// </summary>
    public const int CREDENTIAL_TYPE_NONE = 0;
    public const int CREDENTIAL_TYPE_PORTAL_AUTH = 1;
    public const int CREDENTIAL_TYPE_LOCKBOX_AUTH = 2;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor 
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    public FormLoginPluginModel() : base()
    {
      m_nCredentialType = CREDENTIAL_TYPE_NONE;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new FormLoginPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // aj: thanks to save page, we know that we have a login url, or we are not using
      //     form based login.  given the two cases, the logic below simply looks for
      //     a login url - if none is specified, we clear all the prop bag settings
      //     and exit.  if one is specified, we persist it appropriately.
      // aj: always remove these two fields, we'll re-populate them below if necessary
      ptProviderInfo.Remove(PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_PASSWORD_FIELD);
      ptProviderInfo.Remove(PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_USERNAME_FIELD);
      // aj: make sure we have a login form URL.  if not, then
      //     we need to ignore the other things (remove from prop bag)
      if (m_sLoginURL.Length > 0)
      {
        WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_LOGIN_URL,
         m_sLoginURL);
        WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_POST_URL,
         m_sPostURL);
        WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_TYPE,
         m_nCredentialType);
        if (m_nCredentialType != CREDENTIAL_TYPE_NONE)
        {
          WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_PASSWORD_FIELD,
           m_sPasswordFieldName);
          WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_USERNAME_FIELD,
           m_sUsernameFieldName);
        }
      } else
      {
        // aj: remove all vals from the prop bag
        ptProviderInfo.Remove(PlumtreeExtensibility.PT_PROPBAG_FORM_LOGIN_URL);
        ptProviderInfo.Remove(PlumtreeExtensibility.PT_PROPBAG_FORM_POST_URL);
        ptProviderInfo.Remove(PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_TYPE);
        }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IFormLoginPluginModelRO#GetLoginURL()
     */
     
    public virtual String GetLoginURL()
    {
      return m_sLoginURL;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IFormLoginPluginModelRO#GetPostURL()
     */
     
    public virtual String GetPostURL()
    {
      return m_sPostURL;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IFormLoginPluginModelRO#GetCredentialType()
     */
     
    public virtual int GetCredentialType()
    {
      return m_nCredentialType;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IFormLoginPluginModelRO#GetPasswordFieldName()
     */
     
    public virtual String GetPasswordFieldName()
    {
      return m_sPasswordFieldName;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IFormLoginPluginModelRO#GetUsernameFieldName()
     */
     
    public virtual String GetUsernameFieldName()
    {
      return m_sUsernameFieldName;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      if (null != ptProviderInfo)
      {
        m_sLoginURL = "";
        m_sPostURL = "";
        m_nCredentialType = CREDENTIAL_TYPE_NONE;
        m_sPasswordFieldName = "";
        m_sUsernameFieldName = "";
        if (EditorStartControl.EDITOR_START_FLAG_CREATE != ((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetEditorType())
        {
          m_sLoginURL = WSModelHelper.PBReadString(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_LOGIN_URL,
           m_sLoginURL);
          m_sPostURL = WSModelHelper.PBReadString(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_POST_URL,
           m_sPostURL);
          m_nCredentialType = WSModelHelper.PBReadInt(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_TYPE,
           m_nCredentialType);
          m_sPasswordFieldName = WSModelHelper.PBReadString(ptProviderInfo,
           PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_PASSWORD_FIELD,
           m_sPasswordFieldName);
          m_sUsernameFieldName = WSModelHelper.PBReadString(ptProviderInfo,
           PlumtreeExtensibility.PT_PROPBAG_FORM_CREDENTIAL_USERNAME_FIELD,
           m_sUsernameFieldName);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      // aj: save all our fields
      m_sLoginURL = WSModelHelper.GetFormElementString(_htFormData, HTMLINPUT_LOGINURL,
       m_sLoginURL);
      m_sPostURL = WSModelHelper.GetFormElementString(_htFormData, HTMLINPUT_POSTURL,
       m_sPostURL);
      m_nCredentialType = WSModelHelper.GetFormElementInt(_htFormData, HTMLRADIO_CREDENTIAL_TYPE,
       m_nCredentialType);
      m_sPasswordFieldName = WSModelHelper.GetFormElementString(_htFormData,
       HTMLINPUT_PASSWORD_FIELD_NAME, m_sPasswordFieldName);
      m_sUsernameFieldName = WSModelHelper.GetFormElementString(_htFormData,
       HTMLINPUT_USERNAME_FIELD_NAME, m_sUsernameFieldName);
      // aj: VALIDATION!
      if (m_nCredentialType != CREDENTIAL_TYPE_NONE)
      {
        nPageStatus = WSModelHelper.ValidateNonEmptyString(m_sPasswordFieldName,
         m_asOwner, m_asOwner.GetString(2941, ResourceConstants.PORTALADMINMSGS),
         nPageStatus);
        nPageStatus = WSModelHelper.ValidateNonEmptyString(m_sUsernameFieldName,
         m_asOwner, m_asOwner.GetString(2942, ResourceConstants.PORTALADMINMSGS),
         nPageStatus);
        // aj: if we're using lock box auth, we need to make
        //     sure a lockbox is selected...
        if (m_nCredentialType == CREDENTIAL_TYPE_LOCKBOX_AUTH)
        {
          // aj: first check if the model exists
          bool bModelExists = m_asOwner.GetModelExists(WebServiceEditorAS.strStorage_CredentialVaultPluginView);
          int nLockBoxID = 0;
          // aj: if the model exists, get the lock box id
          if (bModelExists)
          {
            nLockBoxID = ((ICredentialVaultPluginModelRO) m_asOwner.GetModel(WebServiceEditorAS.strStorage_CredentialVaultPluginView)).GetLockboxObjectID();
            }
          // aj: if either the lockbox didn't exist, or the lockbox is not choosen, 
          //     then we can raise an error here...
          nPageStatus = WSModelHelper.ValidateBool(nLockBoxID != 0, m_asOwner,
           m_asOwner.GetString(2945, ResourceConstants.PORTALADMINMSGS), nPageStatus);
          }
      } else
      {
        // aj: if type == NONE, then clear the field names
        m_sPasswordFieldName = "";
        m_sUsernameFieldName = "";
      }
      // aj: if either the login URL or the POST URL has something in it, then we 
      //     need to make sure both field are populated
      if (m_sLoginURL.Length > 0 || m_sPostURL.Length > 0 || m_nCredentialType != CREDENTIAL_TYPE_NONE)
      {
        nPageStatus = WSModelHelper.ValidateIsURLString(m_sLoginURL, m_asOwner,
         m_asOwner.GetString(2944, ResourceConstants.PORTALADMINMSGS), nPageStatus);
        nPageStatus = WSModelHelper.ValidateIsURLString(m_sPostURL, m_asOwner,
         m_asOwner.GetString(2943, ResourceConstants.PORTALADMINMSGS), nPageStatus);
        }
      return nPageStatus;
    }
  }
}