using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class GatewayCachingPluginModel : EditorHelperModel,IGatewayCachingPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "GatewayCachingPlugin";
    
    /// <summary>
    /// This mask is used by our view to send time data to us in units that we
    /// support.
    /// </summary>
    public static readonly int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYDAYS | PTDurationCombo.DISPLAYHOURS | PTDurationCombo.DISPLAYMINUTES | PTDurationCombo.DISPLAYSECONDS;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// Suppress Errors information.
    /// </summary>
    private bool m_bSuppressErrors = true;
    
    /// <summary>
    /// Timeout information.
    /// </summary>
    protected PTDuration m_ptdMinCache;
    protected PTDuration m_ptdMaxCache;
    public GatewayCachingPluginModel() : base()
    {
      m_ptdMinCache = new PTDuration(0, NMASK_SUPPORTED_UNITS);
      m_ptdMaxCache = new PTDuration(1000 * 60 * 60 * 24 * 20, NMASK_SUPPORTED_UNITS);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GatewayCachingPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      //AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
      // the propertybag as SECONDS.
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MINC,
       m_ptdMinCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS));
      //AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
      // the propertybag as SECONDS.
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MAXC,
       m_ptdMaxCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS));
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_HIDEERR,
       m_bSuppressErrors);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return GatewayCachingPluginView.VALIDATION_FUNCTION_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      //AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
      // the propertybag as SECONDS.
      m_ptdMinCache = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MINC, m_ptdMinCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS)),
       PTDurationCombo.DISPLAYSECONDS, NMASK_SUPPORTED_UNITS);
      //AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
      // the propertybag as SECONDS.
      m_ptdMaxCache = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MAXC, m_ptdMaxCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS)),
       PTDurationCombo.DISPLAYSECONDS, NMASK_SUPPORTED_UNITS);
      m_bSuppressErrors = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_HIDEERR,
       m_bSuppressErrors);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      m_ptdMinCache = WSModelHelper.GetFormElementDuration(_htFormData, GatewayCachingPluginView.HTMLINPUT_MINCACHE_DURATION,
       GatewayCachingPluginView.HTMLSELECT_MINCACHE_UNITS, m_ptdMinCache);
      m_ptdMaxCache = WSModelHelper.GetFormElementDuration(_htFormData, GatewayCachingPluginView.HTMLINPUT_MAXCACHE_DURATION,
       GatewayCachingPluginView.HTMLSELECT_MAXCACHE_UNITS, m_ptdMaxCache);
      //AGC- Because these are checkboxes, we want to make sure that if they are not set, we return false - hence the false in thefollowing statements.
      m_bSuppressErrors = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewayCachingPluginView.HTMLCHECKBOX_SUPRESS_ERRORS);
      int nValid = RepostControl.PAGE_STATUS_VALID;
      nValid = WSModelHelper.ValidateDurationRange(m_ptdMinCache, m_asOwner,
       m_asOwner.GetString(1922, "ptmsgs_portaladminmsgs"), nValid, 0, 1000 * 60 * 60 * 24 * 20);
      nValid = WSModelHelper.ValidateDurationRange(m_ptdMaxCache, m_asOwner,
       m_asOwner.GetString(1923, "ptmsgs_portaladminmsgs"), nValid, 0, 1000 * 60 * 60 * 24 * 20);
      nValid = WSModelHelper.ValidateBool((m_ptdMinCache.GetMilliseconds() <= m_ptdMaxCache.GetMilliseconds()),
       m_asOwner, m_asOwner.GetString(1924, "ptmsgs_portaladminmsgs"), nValid);
      return nValid;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayCachingPluginModelRO#SuppressErrorsChecked()"></seealso>
    public virtual bool SuppressErrorsChecked()
    {
      return m_bSuppressErrors;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayCachingPluginModelRO#GetMaxCacheDuration()"></seealso>
    public virtual PTDuration GetMaxCacheDuration()
    {
      return m_ptdMaxCache;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayCachingPluginModelRO#GetMinCacheDuration()"></seealso>
    public virtual PTDuration GetMinCacheDuration()
    {
      return m_ptdMinCache;
    }
  }
}