using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class GatewayCachingPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.GatewayCachingPluginView");
    public const String STR_MVC_CLASS_NAME = "GatewayCachingPluginView";
    
    /// <summary>
    /// The name of our validation function. This must be added by the Page to the
    /// page level validation function. See WSPluginDP for details.
    /// </summary>
    public const String VALIDATION_FUNCTION_NAME = "IsValidGatewayCache";
    public const String HTMLINPUT_MINCACHE_DURATION = "in_tx_MinCache";
    public const String HTMLSELECT_MINCACHE_UNITS = "in_se_MinCacheUnits";
    public const String HTMLINPUT_MAXCACHE_DURATION = "in_tx_MaxCache";
    public const String HTMLSELECT_MAXCACHE_UNITS = "in_se_MaxCacheUnits";
    public const String HTMLCHECKBOX_SUPRESS_ERRORS = "in_cb_SuppressErrors";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GatewayCachingPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1082,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // Last row begins
        WSViewHelper.AddEmptyRow(myTable, "5");
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(1083,
         "ptmsgs_portaladminmsgs"), HTMLINPUT_MINCACHE_DURATION, HTMLSELECT_MINCACHE_UNITS,
         ((IGatewayCachingPluginModelRO) m_model).GetMinCacheDuration(), m_asOwner);
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(1084,
         "ptmsgs_portaladminmsgs"), HTMLINPUT_MAXCACHE_DURATION, HTMLSELECT_MAXCACHE_UNITS,
         ((IGatewayCachingPluginModelRO) m_model).GetMaxCacheDuration(), m_asOwner);
        WSViewHelper.AddSimpleCheckbox(myTable, 5, m_asOwner.GetString(1085,
         "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_SUPRESS_ERRORS, CommonHTMLStrings.ONE,
         ((IGatewayCachingPluginModelRO) m_model).SuppressErrorsChecked(),
         "");
        // Last row begins
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1081, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(300);
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      try
      {
        sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
        sb.Append("{\n");
        if (WebServiceModel.WSMODE_CWS == mParent.GetWSMode())
        {
          sb.Append(WSViewHelper.ValidateNumericInputJS(WSPluginDP.HTMLFORM_NAME,
           HTMLINPUT_MINCACHE_DURATION, m_asOwner.GetString(1086, "ptmsgs_portaladminmsgs")));
          sb.Append(WSViewHelper.ValidateNumericInputJS(WSPluginDP.HTMLFORM_NAME,
           HTMLINPUT_MAXCACHE_DURATION, m_asOwner.GetString(1087, "ptmsgs_portaladminmsgs")));
          }
        sb.Append(" \treturn true;\n");
        sb.Append("}\n\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he.Message);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}