using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class GatewayPrefixPluginView : MultiColumnListView
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GatewayPrefixPluginView";
    // the names of the form elements -jas
    public static readonly String HTMLINPUT_URL = HTMLINPUT_ITEM + "0";
    public const String HTMLCHECKBOX_REFRESH = "in_cb_item1";
    // note that these are 1-based, whereas the similar constants are 0-based, 
    // for uiinfrastructure reasons I don't entirely fathom -jas
    private const int COLUMN_URL = 1;
    private const int COLUMN_REFRESH_FLAG = 2;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GatewayPrefixPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(IPTGrowableSortedArrayWrapperRO,int)"></seealso>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // write out the remote server base URL -jas
      String strBaseURL = ((IGatewayPrefixPluginModelRO) m_model).GetBaseURL();
      String strURL = XPConvert.ToString(_saData.GetItem(_nRowIndex, COLUMN_URL));
      int nInputSize = 80;
      if (0 < strBaseURL.Length)
      {
        // don't show the prefix if the URL is absolute -jas
        if (!ModelHelper.CheckIsURLString(strURL))
        {
          myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strBaseURL) + SPACE);
          nInputSize = 60;
        }
      }
      // input text
      IMultiColumnListModelRO modelMCL = (IMultiColumnListModelRO) m_model;
      myInput = new HTMLInput(HTMLInputTypes.TEXT, modelMCL.GetUniqueString(HTMLINPUT_URL) + _nRowIndex,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      myInput.SetValue(XPConvert.ToString(_saData.GetItem(_nRowIndex, COLUMN_URL)));
      myInput.SetMaxLength("100");
      myInput.SetSize(XPConvert.ToString(nInputSize));
      // begin 2nd column -jas
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      // add the refresh checkbox -jas
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, modelMCL.GetUniqueString(HTMLCHECKBOX_REFRESH) + _nRowIndex,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetValue(CommonHTMLStrings.ONE);
      String strChecked = XPConvert.ToString(_saData.GetItem(_nRowIndex, COLUMN_REFRESH_FLAG));
      myInput.SetChecked(strChecked != "");
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}