using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.server;
using EditorHelperModel=com.plumtree.uiinfrastructure.editor.EditorHelperModel;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// Model for editing advanced gateway settings.
  /// </summary>
  /// <author>josephs</author>
  public class GatewaySettingsPluginModel : EditorHelperModel,IWSSubModel,
  IGatewaySettingsPluginModelRO
  {
    public const String STR_MVC_CLASS_NAME = "GatewaySettingsPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    /*
     * The settings this plugin manages. -jas
     */
     
    private bool m_bUseHostedDisplayMode = false;
    private bool m_bTransformJS = false;
    private bool m_bTransformCSS = false;
    
    /// <summary>
    /// Whether or not to send a timezone to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetUseHostedDisplayMode()
    {
      return m_bUseHostedDisplayMode;
    }
    
    /// <summary>
    /// Whether or not to send a timezone to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetTransformJS()
    {
      return m_bTransformJS;
    }
    
    /// <summary>
    /// Whether or not to send a timezone to the portlet.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetTransformCSS()
    {
      return m_bTransformCSS;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public override Object Create()
    {
      return new GatewaySettingsPluginModel();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override int SaveSection(XPHashtable _htFormData)
    {
      m_bUseHostedDisplayMode = WSModelHelper.GetFormCheckboxBool(_htFormData,
       GatewaySettingsPluginView.HTMLCHECKBOX_HOSTED_DISPLAY_MODE);
      m_bTransformJS = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewaySettingsPluginView.HTMLCHECKBOX_TRANSFORM_JAVASCRIPT);
      m_bTransformCSS = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewaySettingsPluginView.HTMLCHECKBOX_TRANSFORM_CSS);
      return RepostControl.PAGE_STATUS_VALID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
     */
     
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // set the flags -jas
      int nGatewaySettings = 0;
      if (m_bUseHostedDisplayMode)
      {
        nGatewaySettings|=PlumtreeExtensibility.GATEWAY_FLAGS_HOSTED_DISPLAY_MODE;
        }
      if (m_bTransformJS)
      {
        nGatewaySettings|=PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_JAVASCRIPT;
        }
      if (m_bTransformCSS)
      {
        nGatewaySettings|=PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_CSS;
        }
      WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_GATEWAY_FLAGS,
       nGatewaySettings);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(java.lang.String, java.lang.String, java.lang.String)
     */
     
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
     */
     
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
     */
     
    public virtual String GetValidationFunction()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(com.plumtree.server.IPTWebService)
     */
     
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // read the flags -jas
      int nGatewaySettings = WSModelHelper.PBReadInt(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_GATEWAY_FLAGS,
       0);
      m_bUseHostedDisplayMode = (nGatewaySettings & PlumtreeExtensibility.GATEWAY_FLAGS_HOSTED_DISPLAY_MODE) > 0;
      m_bTransformJS = (nGatewaySettings & PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_JAVASCRIPT) > 0;
      m_bTransformCSS = (nGatewaySettings & PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_CSS) > 0;
      }
  }
}