using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class HTTPSettingsPluginModel : EditorHelperModel,IHTTPSettingsPluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "WSHTTPSettingsPluginModel";
    
    /// <summary>
    /// This mask is used by our view to send time data to us in units that we
    /// support.
    /// </summary>
    public static readonly int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES | PTDurationCombo.DISPLAYSECONDS;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// URL to this Web Service (To be combined with the BaseURL from the Remote Server)
    /// (RemoteServerPluginView) 
    /// </summary>
    private String m_strPortletURL = "";
    
    /// <summary>
    /// Timeout information.
    /// </summary>
    protected PTDuration m_ptdPortletTimeout;
    protected PTDuration m_ptdGatewayTimeout;
    public HTTPSettingsPluginModel() : base()
    {
      m_ptdPortletTimeout = new PTDuration(5000, NMASK_SUPPORTED_UNITS);
      m_ptdGatewayTimeout = new PTDuration(20000, NMASK_SUPPORTED_UNITS);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new HTTPSettingsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT,
       AExtensibilityConstants.PT_PROPBAG_FORMAT_HTTPGADGET_INIT);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_URL,
       GetPortletURL());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_TIMEOUT,
       m_ptdPortletTimeout.GetMilliseconds());
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT,
       m_ptdGatewayTimeout.GetMilliseconds());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IHTTPSettingsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the m_strWebServiceURL. Value must be WS_ENABLED or WS_DISABLED
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetPortletURL()
    {
      return m_strPortletURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return HTTPSettingsPluginView.VALIDATION_FUNCTION_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      SetPortletURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_URL,
       GetPortletURL()));
      m_ptdPortletTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_TIMEOUT, m_ptdPortletTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
      m_ptdGatewayTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT, m_ptdGatewayTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetPortletURL(WSModelHelper.GetFormElementString(_htFormData, HTTPSettingsPluginView.HTMLINPUT_PORTLET_URL,
       GetPortletURL()));
      m_ptdPortletTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       HTTPSettingsPluginView.HTMLINPUT_TIMEOUT_DURATION, HTTPSettingsPluginView.HTMLSELECT_TIMEOUT_UNITS,
       m_ptdPortletTimeout);
      m_ptdGatewayTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       HTTPSettingsPluginView.HTMLINPUT_TIMEOUT_GATEWAYDURATION, HTTPSettingsPluginView.HTMLSELECT_TIMEOUT_GATEWAYUNITS,
       m_ptdGatewayTimeout);
      int nValid = RepostControl.PAGE_STATUS_VALID;
      // Skip the URL check when in Pagelet Portlet Editor, the URL text box isn't displayed there
      if (!RemPageletWSWebServiceEditorAS.STR_MVC_CLASS_NAME.Equals(m_asOwner.GetName()))
      {
        if ((null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
        {
          nValid = WSModelHelper.ValidateIsURLString(m_strPortletURL, m_asOwner,
           m_asOwner.GetString(1925, "ptmsgs_portaladminmsgs"), nValid);
        } else
        {
          nValid = WSModelHelper.ValidateNonEmptyString(m_strPortletURL, m_asOwner,
           m_asOwner.GetString(1093, "ptmsgs_portaladminmsgs"), nValid);
        }
      }
      nValid = WSModelHelper.ValidateDurationRange(m_ptdPortletTimeout, m_asOwner,
       m_asOwner.GetString(1926, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 90);
      nValid = WSModelHelper.ValidateDurationRange(m_ptdGatewayTimeout, m_asOwner,
       m_asOwner.GetString(1927, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 90);
      return nValid;
    }
    
    /// <summary>
    /// Sets the m_strWebServiceURL.
    /// </summary>
    /// <param name="strWebServiceURL">The m_strWebServiceURL to set</param>
    public virtual void SetPortletURL(String strWebServiceURL)
    {
      this.m_strPortletURL = strWebServiceURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetGatewayDuration()"></seealso>
    public virtual PTDuration GetGatewayDuration()
    {
      return m_ptdGatewayTimeout;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetSOAPDuration()"></seealso>
    public virtual PTDuration GetPortletDuration()
    {
      return m_ptdPortletTimeout;
    }
  }
}