using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This model is used to store the activity space for portlet help pages.
  /// </summary>
  /// <author>josephc</author>
  public class IntrinsicHelpSpacePluginModel : EditorHelperModel,IIntrinsicHelpSpacePluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// Class name for IntrinsicHelpSpacePluginModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "IntrinsicHelpSpacePlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor 
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// Intrinsic portlet help activity space 
    /// </summary>
    private String m_strHelpURL = "";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new IntrinsicHelpSpacePluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_HELP_URL,
       m_strHelpURL);
      int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();
      if ((null == m_strHelpURL) || (0 >= XPStringUtility.Trim(m_strHelpURL).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_HELPPAGE;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_HELPPAGE;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <summary>
    /// Gets the intrinsic portlet help URL
    /// </summary>
    /// <returns>Intrinsic portlet URL</returns>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IIntrinsicHelpSpacePluginModelRO#GetHelpURL()"></seealso>
    public virtual String GetHelpURL()
    {
      return m_strHelpURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      SetHelpURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_HELP_URL,
       m_strHelpURL));
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetHelpURL(WSModelHelper.GetFormElementString(_htFormData, IntrinsicHelpSpacePluginView.HTMLINPUT_HELP_SPACE,
       m_strHelpURL));
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Sets the help URL.
    /// </summary>
    /// <param name="strHelpURL">Activity space for help</param>
    public virtual void SetHelpURL(String strHelpURL)
    {
      m_strHelpURL = strHelpURL;
    }
  }
}