using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// Model for setting portlet class identifier.
  /// </summary>
  /// <author>josephc</author>
  public class IntrinsicPortletWSSettingsPluginModel : EditorHelperModel,IIntrinsicPortletWSSettingsPluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// Class name for IntrinsicPortletWSSettingsPluginModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "IntrinsicPortletWSSettingsPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor 
    /// </summary>
    private IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// Portlet class identifier 
    /// </summary>
    private String m_strPortletClassIdentifier = "";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new IntrinsicPortletWSSettingsPluginModel();
    }
    
    /// <summary>
    /// Store the property bag format for intrinsic portlets as well as the
    /// portlet class identifier into the provider info property bag for
    /// intrinsic portlet web services.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT,
       AExtensibilityConstants.PT_PROPBAG_FORMAT_INTRINSICGADGET_INIT);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_CLASSID,
       m_strPortletClassIdentifier);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the portlet class identifier
    /// </summary>
    /// <returns>Portlet class identifier</returns>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IIntrinsicPortletWSSettingsPluginModelRO#GetPortletClassIdentifier()"></seealso>
    public virtual String GetPortletClassIdentifier()
    {
      return m_strPortletClassIdentifier;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return IntrinsicPortletWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
      }
    
    /// <summary>
    /// Load the portlet class identifier from provider info property bag of web
    /// service object.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      SetPortletClassIdentifier(WSModelHelper.PBReadString(ptProviderInfo,
       AExtensibilityConstants.PTC_I_GADGET_CLASSID, GetPortletClassIdentifier()));
      }
    
    /// <summary>
    /// Valdiates that the specified portlet model and view exist and have been loaded by
    /// dynamic discovery.
    /// </summary>
    /// <returns>int</returns>
    private int ValidatePortletClassIdentifier()
    {
      // Verify that the portlet class identifier is valid.
      IModel portletModel = ASManager.INSTANCE.GetModel(m_strPortletClassIdentifier);
      IView portletView = ASManager.INSTANCE.GetView(m_strPortletClassIdentifier);
      // If the model or view cannot be retrieved using the portlet class identifier, then
      // it must be invalid.  Controls are optional so we don't check to see if the control exists.
      if ((null == portletModel) || (null == portletView))
      {
        String strErrorMsg = XPResourceManager.FormatMessage(m_asOwner.GetString(1104,
         "ptmsgs_portaladminmsgs"), m_strPortletClassIdentifier);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         strErrorMsg, strErrorMsg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Save the portlet class identifier.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetPortletClassIdentifier(WSModelHelper.GetFormElementString(_htFormData,
       IntrinsicPortletWSSettingsPluginView.HTMLINPUT_PORTLET_CLASS_IDENTIFIER,
       m_strPortletClassIdentifier));
      return ValidatePortletClassIdentifier();
    }
    
    /// <summary>
    /// Set the portlet class identifier
    /// </summary>
    /// <param name="strPortletClassIdentifier">Portlet class identifier</param>
    public virtual void SetPortletClassIdentifier(String strPortletClassIdentifier)
    {
      m_strPortletClassIdentifier = strPortletClassIdentifier;
    }
  }
}