using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// Section for setting portlet class identifier.
  /// </summary>
  /// <author>josephc</author>
  public class IntrinsicPortletWSSettingsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.IntrinsicPortletWSSettingsPluginView");
    
    /// <summary>
    /// Class name for IntrinsicPortletWSSettingsPluginView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "IntrinsicPortletWSSettingsPlugin";
    
    /// <summary>
    /// Input for portlet class identifier 
    /// </summary>
    public const String HTMLINPUT_PORTLET_CLASS_IDENTIFIER = "in_tx_PortletClassIdentifier";
    
    /// <summary>
    /// The name of our validation function. This must be added by the Page to
    /// the page level validation function. See WSPluginDP for details.
    /// </summary>
    public const String VALIDATION_FUNCTION_NAME = "IsValidIntrinsicPortletWSSettings";
    
    /// <summary>
    /// Our parent Activity space. 
    /// </summary>
    private AActivitySpace m_asParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new IntrinsicPortletWSSettingsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        IIntrinsicPortletWSSettingsPluginModelRO iModelRO = (IIntrinsicPortletWSSettingsPluginModelRO) m_model;
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1107,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);
        // 1st row ends
        // 2nd row begins
        WSViewHelper.AddSimpleEditBox(myTable, 5, m_asOwner.GetString(1106,
         "ptmsgs_portaladminmsgs"), null, iModelRO.GetPortletClassIdentifier(),
         HTMLINPUT_PORTLET_CLASS_IDENTIFIER);
        // last row (spacer row)
        WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1105, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asParent = parent;
    }
  }
}