using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This model is used to store whether the intrinsic web service contains Profile data.
  /// </summary>
  /// <author>jennifersu</author>
  public class IntrinsicProfilePluginModel : EditorHelperModel,IIntrinsicProfilePluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// Class name for IntrinsicProfilePluginModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "IntrinsicProfilePlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor 
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    internal bool m_bIsUserProfile = false;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new IntrinsicProfilePluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();
      if (!m_bIsUserProfile)
      {
        nSupportsPersonalization&=~PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE;
        } else
      {
        nSupportsPersonalization|=PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      // TODO CR not used, commenting out.
      // int nPersonalization = m_ptWebService.GetSupportsPersonalization();
      if (0 != (ptWebService.GetSupportsPersonalization() & PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE))
      {
        m_bIsUserProfile = true;
      }
    }
    //
    //		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
    //
    //		SetHelpURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_HELP_URL, m_strHelpURL));
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      //		SetHelpURL(WSModelHelper.GetFormElementString(_htFormData, IntrinsicHelpSpacePluginView.HTMLINPUT_HELP_SPACE, m_strHelpURL));
      //
      m_bIsUserProfile = WSModelHelper.GetFormCheckboxBool(_htFormData, IntrinsicProfilePluginView.HTMLINPUT_PROFILE);
      return RepostControl.PAGE_STATUS_VALID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IIntrinsicProfilePluginModelRO#ContainsProfileData()
     */
     
    public virtual bool ContainsProfileData()
    {
      return m_bIsUserProfile;
    }
    
    /// <param name="nSupportsPersonalization"></param>
    /// <param name="strPrefsSpace"></param>
    /// <param name="nPortletPersonalizationRole"></param>
    /// <returns></returns>
    private int UpdatePersonalizationFlag(int nSupportsPersonalization, int nPortletPersonalizationRole)
    {
      if (!m_bIsUserProfile)
      {
        nSupportsPersonalization&=~nPortletPersonalizationRole;
      } else
      {
        nSupportsPersonalization|=nPortletPersonalizationRole;
      }
      return nSupportsPersonalization;
    }
  }
}