using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This plugin view is used to configure intrinsic portlets to be User Profile.
  /// </summary>
  /// <author>jennifersu</author>
  public class IntrinsicProfilePluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.IntrinsicProfilePluginView");
    
    /// <summary>
    /// Class name for IntrinsicProfilePluginView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "IntrinsicProfilePlugin";
    public const String HTMLINPUT_PROFILE = "in_cb_Profile";
    
    /// <summary>
    /// Our parent Activity space. 
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new IntrinsicProfilePluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2701,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);
        // 1st row ends
        // 2nd row begins
        bool bIsUserProfile = ((IIntrinsicProfilePluginModelRO) m_model).ContainsProfileData();
        WSViewHelper.AddSimpleCheckbox(myTable, 4, m_asOwner.GetString(2702,
         "ptmsgs_portaladminmsgs"), HTMLINPUT_PROFILE, "1", bIsUserProfile,
         null);
        //TODO: OBSOLETE string 1102
        // last row (spacer row)
        WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1101, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}