using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This plugin view is used to show user, community, and admin preference spaces. 
  /// The model will determine what type of preference should be shown.
  /// </summary>
  /// <author>josephc</author>
  public class IntrinsicUserPrefsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.IntrinsicUserPrefsPluginView");
    
    /// <summary>
    /// Class name for IntrinsicUserPrefsPluginView 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "IntrinsicUserPrefsPluginView";
    
    /// <summary>
    /// Input for user portlet preferences space 
    /// </summary>
    public const String HTMLINPUT_USER_PREFS_SPACE = "in_tx_UserPrefsSpace";
    
    /// <summary>
    /// Input for community portlet preferences space 
    /// </summary>
    public const String HTMLINPUT_COMMUNITY_PREFS_SPACE = "in_tx_CommunityPrefsSpace";
    
    /// <summary>
    /// Input for admin portlet preferences space 
    /// </summary>
    public const String HTMLINPUT_ADMIN_PREFS_SPACE = "in_tx_AdminPrefsSpace";
    
    /// <summary>
    /// Input for admin portlet template preferences space 
    /// </summary>
    public const String HTMLINPUT_TEMPLT_ADMIN_PREFS_SPACE = "in_tx_TemplAdminPrefsSpace";
    
    /// <summary>
    /// Our parent Activity space. 
    /// </summary>
    private AActivitySpace m_asParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new IntrinsicUserPrefsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        switch (((IIntrinsicUserPrefsPluginModelRO) m_model).GetPrefMode()){
        case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1115,
         "ptmsgs_portaladminmsgs")));
        myTable = GetDisplayAsTable();
        result.AddInnerHTMLElement(myTable);
        break;
        case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1113,
         "ptmsgs_portaladminmsgs")));
        myTable = GetDisplayAsTable();
        result.AddInnerHTMLElement(myTable);
        break;
        case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1114,
         "ptmsgs_portaladminmsgs")));
        myTable = GetDisplayAsTable();
        result.AddInnerHTMLElement(myTable);
        break;
        }
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1110, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <summary>
    /// This method is called by Display() to display the HTML for entering the activity space
    /// of the portlet preferences.
    /// </summary>
    /// <returns>HTML for portlet preferences.</returns>
    /// <throws>XPException Throws exception if HTML could not be generated.</throws>
    public virtual HTMLTable GetDisplayAsTable()
    {
      HTMLTable myTable;
      try
      {
        myTable = WSViewHelper.MakeTable();
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);
        // 1st row ends
        // 2nd row 
        String strDefault = ((IIntrinsicUserPrefsPluginModelRO) m_model).GetPrefsSpace();
        String strTempltDefault = ((IIntrinsicUserPrefsPluginModelRO) m_model).GetTemplatePrefsSpace();
        switch (((IIntrinsicUserPrefsPluginModelRO) m_model).GetPrefMode()){
        case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:
        WSViewHelper.AddSimpleEditBox(myTable, 4, m_asOwner.GetString(1109,
         "ptmsgs_portaladminmsgs"), null, strDefault, HTMLINPUT_COMMUNITY_PREFS_SPACE);
        break;
        case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:
        WSViewHelper.AddSimpleEditBox(myTable, 4, m_asOwner.GetString(1112,
         "ptmsgs_portaladminmsgs"), null, strDefault, HTMLINPUT_USER_PREFS_SPACE);
        break;
        case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:
        WSViewHelper.AddSimpleEditBox(myTable, 4, m_asOwner.GetString(1108,
         "ptmsgs_portaladminmsgs"), null, strDefault, HTMLINPUT_ADMIN_PREFS_SPACE);
        WSViewHelper.AddSimpleEditBox(myTable, 4, m_asOwner.GetString(1111,
         "ptmsgs_portaladminmsgs"), null, strTempltDefault, HTMLINPUT_TEMPLT_ADMIN_PREFS_SPACE);
        break;
        }
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1110, "ptmsgs_portaladminmsgs"),
         e);
      }
      return myTable;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asParent = parent;
    }
  }
}