using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>Jennifer Sun</author>
  public class MWSSettingsPluginModel : EditorHelperModel,IMWSSettingsPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "MWSSettingsPlugin";
    
    /// <summary>
    /// This mask is used by our view to send time data to us in units that we
    /// support.
    /// </summary>
    public static readonly int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES | PTDurationCombo.DISPLAYSECONDS;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// The location of the Migration URL for this Web Service.
    /// </summary>
    private String m_strMigrationURL = "";
    
    /// <summary>
    /// Timeout information.
    /// </summary>
    protected PTDuration m_ptdSOAPTimeout;
    public MWSSettingsPluginModel() : base()
    {
      m_ptdSOAPTimeout = new PTDuration(30000, NMASK_SUPPORTED_UNITS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MWSSettingsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPMWS_MWSURL,
       m_strMigrationURL);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
       m_ptdSOAPTimeout.GetMilliseconds());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// The location of the Migration URL for this Web Service.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetMigrationURL()
    {
      return m_strMigrationURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return MWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      SetMigrationURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPMWS_MWSURL,
       m_strMigrationURL));
      m_ptdSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(ptProviderInfo,
       AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT, m_ptdSOAPTimeout.GetMilliseconds()),
       NMASK_SUPPORTED_UNITS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetMigrationURL(WSModelHelper.GetFormElementString(_htFormData, MWSSettingsPluginView.HTMLINPUT_MIGRATION_URL,
       GetMigrationURL()));
      m_ptdSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
       MWSSettingsPluginView.HTMLINPUT_TIMEOUT_DURATION, MWSSettingsPluginView.HTMLSELECT_TIMEOUT_UNITS,
       m_ptdSOAPTimeout);
      int nValid = RepostControl.PAGE_STATUS_VALID;
      if ((null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strMigrationURL, m_asOwner,
         m_asOwner.GetString(2829, "ptmsgs_portaladminmsgs"), nValid);
      } else
      {
        nValid = WSModelHelper.ValidateNonEmptyString(m_strMigrationURL, m_asOwner,
         m_asOwner.GetString(2830, "ptmsgs_portaladminmsgs"), nValid);
      }
      nValid = WSModelHelper.ValidateDurationRange(m_ptdSOAPTimeout, m_asOwner,
       m_asOwner.GetString(1929, "ptmsgs_portaladminmsgs"), nValid, 1000,
       1000 * 60 * 90);
      return nValid;
    }
    
    /// <summary>
    /// The location of the Synchronization URL for this Web Service.
    /// </summary>
    public virtual void SetMigrationURL(String strMigrationURL)
    {
      m_strMigrationURL = XPStringUtility.Trim(strMigrationURL);
    }
    
    /// <summary>
    /// Returns timeout setting.
    /// </summary>
    /// <returns>PTDuration</returns>
    public virtual PTDuration GetDuration()
    {
      return m_ptdSOAPTimeout;
    }
  }
}