using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>Jennifer Sun</author>
  public class MWSSettingsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.MWSSettingsPluginView");
    public const String STR_MVC_CLASS_NAME = "MWSSettingsPluginView";
    public const String HTMLINPUT_MIGRATION_URL = "in_tx_MigrationURL";
    public const String HTMLINPUT_TIMEOUT_DURATION = "in_tx_Timeout";
    public const String HTMLSELECT_TIMEOUT_UNITS = "in_se_TimeoutUnits";
    
    /// <summary>
    /// The name of our validation function. This must be added by the Page to the
    /// page level validation function. See WSPluginDP for details.
    /// </summary>
    public const String VALIDATION_FUNCTION_NAME = "IsValidMWSSettings";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MWSSettingsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2826,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 1st row ends
        // 2nd row begins
        String strBaseURL = ((IMWSSettingsPluginModelRO) m_model).GetBaseURL();
        String strDefault = ((IMWSSettingsPluginModelRO) m_model).GetMigrationURL();
        WSViewHelper.AddSimpleEditBox(myTable, 5, m_asOwner.GetString(2827,
         "ptmsgs_portaladminmsgs"), strBaseURL, strDefault, HTMLINPUT_MIGRATION_URL);
        //Spacer Row
        WSViewHelper.AddEmptyRow(myTable, "5");
        //////// Portal Timeout
        PTDuration ptdDefault = ((IMWSSettingsPluginModelRO) m_model).GetDuration();
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(1125,
         "ptmsgs_portaladminmsgs"), HTMLINPUT_TIMEOUT_DURATION, HTMLSELECT_TIMEOUT_UNITS,
         ptdDefault, m_asOwner);
        // 6th row (spacer row)
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(2828, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(300);
      try
      {
        sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
        sb.Append("{\n");
        WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
        if (WebServiceModel.WSMODE_MWS == mParent.GetWSMode())
        {
          sb.Append(WSViewHelper.ValidateNumericInputJS(WSPluginDP.HTMLFORM_NAME,
           MWSSettingsPluginView.HTMLINPUT_TIMEOUT_DURATION, m_asOwner.GetString(1126,
           "ptmsgs_portaladminmsgs")));
        }
        sb.Append(" \treturn true;\n");
        sb.Append("}\n\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he.Message);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}