using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.portlets.intrinsicpageletparamprefeditor;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>rozhang</author>
  public class PageletParamsMapPluginModel : EditorHelperModel,IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.PageletParamsMapPluginModel");
    public const String STR_MVC_CLASS_NAME = "PageletParamsMapPlugin";
    // Input name prefix
    public const String INPUTNAME_USER = "in_cb_user";
    public const String INPUTNAME_COMM = "in_cb_comm";
    public const String INPUTNAME_ADMIN = "in_cb_admin";
    protected bool m_hasUserPrefs = false;
    protected bool m_hasCommunityPrefs = false;
    protected bool m_hasAdminPrefs = false;
    protected String m_prevPageletId = null;
    protected String[] m_paramNames = null;
    protected String[] m_paramDescriptions = null;
    
    /// <summary>
    /// list with names of parameters mapped to each preference type *
    /// </summary>
    protected XPArrayList m_userParams = null;
    protected XPArrayList m_commParams = null;
    protected XPArrayList m_adminParams = null;
    
    /// <summary>
    /// list with descriptions of parameters mapped to each preference type *
    /// </summary>
    protected XPArrayList m_userParamDescs = new XPArrayList();
    protected XPArrayList m_commParamDescs = new XPArrayList();
    protected XPArrayList m_adminParamDescs = new XPArrayList();
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(com.plumtree.server.IPTWebService)"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag provInfo = m_ptWebService.GetProviderInfo();
      // load stored names (if any)
      Object[] userParams = provInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER);
      if (userParams != null && userParams.Length > 0)
      {
        m_hasUserPrefs = true;
      }
      Object[] commParams = provInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM);
      if (commParams != null && commParams.Length > 0)
      {
        m_hasCommunityPrefs = true;
      }
      Object[] adminParams = provInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN);
      if (adminParams != null && adminParams.Length > 0)
      {
        m_hasAdminPrefs = true;
      }
      m_userParams = ConvertObjectArrayToList(userParams);
      m_commParams = ConvertObjectArrayToList(commParams);
      m_adminParams = ConvertObjectArrayToList(adminParams);
    }
    // we don't need to load the parameter descriptions since they get stored whenever the mappings are stored 
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable formData)
    {
      m_userParams.Clear();
      m_commParams.Clear();
      m_adminParams.Clear();
      String[] paramNames = GetPageletParameterNames();
      String[] paramDescs = GetPageletParameterDescriptions();
      // for each parameter name, go through the submitted form and see which parameters
      // have what preference types checked
      // add parameter name and description to mapped preference type 
      for (int i = 0;i < paramNames.Length;i++)
      {
        String currParamName = paramNames[i];
        String currParamDesc = paramDescs[i];
        if (formData.ContainsKey(INPUTNAME_USER + i))
        {
          m_hasUserPrefs = true;
          m_userParams.Add(currParamName);
          m_userParamDescs.Add(currParamDesc);
        }
        if (formData.ContainsKey(INPUTNAME_COMM + i))
        {
          m_hasCommunityPrefs = true;
          m_commParams.Add(currParamName);
          m_commParamDescs.Add(currParamDesc);
        }
        if (formData.ContainsKey(INPUTNAME_ADMIN + i))
        {
          m_hasAdminPrefs = true;
          m_adminParams.Add(currParamName);
          m_adminParamDescs.Add(currParamDesc);
        }
      }
      return EditorRepostControl.PAGE_STATUS_VALID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()">Based on what preference types were mapped to, set/remove edit prefs url as necessary</seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      int suppPersonalizationMask = m_ptWebService.GetSupportsPersonalization();
      // same as for all prefs type, figures out the pref type from the context
      String strPrefsURL = IntrinsicPrefsEditorForPageletParametersAS.STR_MVC_CLASS_NAME;
      if (m_hasUserPrefs)
      {
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_PREFS_SPACE,
         strPrefsURL);
        suppPersonalizationMask = suppPersonalizationMask | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER;
        } else
      {
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_PREFS_SPACE,
         "");
        suppPersonalizationMask = suppPersonalizationMask & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER;
        }
      if (m_hasCommunityPrefs)
      {
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_COMMUNITYPREFS_SPACE,
         strPrefsURL);
        suppPersonalizationMask = suppPersonalizationMask | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER;
        } else
      {
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_COMMUNITYPREFS_SPACE,
         "");
        suppPersonalizationMask = suppPersonalizationMask & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER;
        }
      if (m_hasAdminPrefs)
      {
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_ADMINPREFS_SPACE,
         strPrefsURL);
        suppPersonalizationMask = suppPersonalizationMask | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR;
        } else
      {
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_ADMINPREFS_SPACE,
         "");
        suppPersonalizationMask = suppPersonalizationMask & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR;
        }
      // store the parameter mappings to object properties
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER,
       m_userParams);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM,
       m_commParams);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN,
       m_adminParams);
      // store parameter descriptions too, used on preference pages
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER_DESCS,
       m_userParamDescs);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM_DESCS,
       m_commParamDescs);
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN_DESCS,
       m_adminParamDescs);
      m_ptWebService.SetSupportsPersonalization(suppPersonalizationMask);
      }
    public override void CleanupTempData()
    {
      return;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public override void CleanupAllData()
    {
      return;
    }
    
    /// <summary>
    /// Checks if different pagelet was selected inside the webservice editor
    /// </summary>
    /// <returns></returns>
    public virtual bool IsUsingNewPagelet()
    {
      RemotePageletPickerPluginModel pageletModel = (RemotePageletPickerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemotePageletPickerView);
      String pagelet = pageletModel.GetSelectedPageletName();
      bool isNew;
      // m_prevPageletId is null when editor is loaded
      if (m_prevPageletId == null)
      {
        // store first pagelet id
        m_prevPageletId = pagelet;
        isNew = false;
      } else
      if (m_prevPageletId.Equals(pagelet))
      {
        isNew = false;
      } else
      {
        // store new pagelet id
        m_prevPageletId = pagelet;
        isNew = true;
      }
      return isNew;
    }
    
    /// <summary>
    /// Get supported parameter names
    /// </summary>
    /// <returns></returns>
    public virtual String[] GetPageletParameterNames()
    {
      RemotePageletPickerPluginModel pageletModel = (RemotePageletPickerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemotePageletPickerView);
      m_paramNames = pageletModel.GetPageletParameterNames();
      return m_paramNames;
    }
    
    /// <summary>
    /// Get supported parameter descriptions
    /// </summary>
    /// <returns></returns>
    public virtual String[] GetPageletParameterDescriptions()
    {
      RemotePageletPickerPluginModel pageletModel = (RemotePageletPickerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemotePageletPickerView);
      m_paramDescriptions = pageletModel.GetPageletParameterDescriptions();
      return m_paramDescriptions;
    }
    
    /// <summary>
    /// Checks if a parameter is mapped to user preference
    /// </summary>
    /// <param name="paramName">Name of pagelet parameter</param>
    /// <returns></returns>
    public virtual bool IsMappedToUserPrefs(String paramName)
    {
      return m_userParams.Contains(paramName);
    }
    
    /// <summary>
    /// Checks if a parameter is mapped to community preference
    /// </summary>
    /// <param name="paramName">Name of pagelet parameter</param>
    /// <returns></returns>
    public virtual bool IsMappedToCommPrefs(String paramName)
    {
      return m_commParams.Contains(paramName);
    }
    
    /// <summary>
    /// Checks if a parameter is mapped to admin preference
    /// </summary>
    /// <param name="paramName">Name of pagelet parameter</param>
    /// <returns></returns>
    public virtual bool IsMappedToAdminPrefs(String paramName)
    {
      return m_adminParams.Contains(paramName);
    }
    
    /// <summary>
    /// Helper function 
    /// </summary>
    /// <param name="o"></param>
    /// <returns></returns>
    protected virtual XPArrayList ConvertObjectArrayToList(Object[] o)
    {
      if (o == null)
      {
        return new XPArrayList();
      }
      XPArrayList list = new XPArrayList();
      if (o != null && o.Length > 0)
      {
        for (int i = 0;i < o.Length;i++)
        {
          list.Add(o[i]);
        }
      }
      return list;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(java.lang.String,java.lang.String,java.lang.String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      // Don't need to do anything
      return;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int newWSMode)
    {
      // Don't need to do anything
      return;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      // Don't need to do anything
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageletParamsMapPluginModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}