using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>rozhang</author>
  public class PageletParamsMapPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.PageletParamsMapPluginView");
    public const String STR_MVC_CLASS_NAME = "PageletParamsMapPluginView";
    public const String INPUTNAME_USER = "in_cb_user";
    public const String INPUTNAME_COMM = "in_cb_comm";
    public const String INPUTNAME_ADMIN = "in_cb_admin";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable headerTable;
      HTMLTableRow headerRow;
      HTMLTableCell headerCell;
      HTMLSpan headerSpan;
      HTMLComment myComment = new HTMLComment("Begin: Display PageletParamsMapPluginView");
      result.AddInnerHTMLElement(myComment);
      HTMLTable outerTable = new HTMLTable();
      outerTable.SetWidth("100%");
      outerTable.SetCellSpacing("5");
      outerTable.SetCellPadding("5");
      HTMLTableRow outerRow = new HTMLTableRow();
      HTMLTableCell outerCell = new HTMLTableCell();
      outerCell.SetAlign("center");
      result.AddInnerHTMLElement(outerTable);
      outerTable.AddInnerHTMLElement(outerRow);
      outerRow.AddInnerHTMLElement(outerCell);
      headerTable = new HTMLTable();
      outerCell.AddInnerHTMLElement(headerTable);
      headerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      headerTable.SetBorder(CommonHTMLStrings.ZERO);
      headerTable.SetCellPadding(CommonHTMLStrings.FIVE);
      headerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      headerRow = new HTMLTableRow();
      headerTable.AddInnerHTMLElement(headerRow);
      headerRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
      headerCell = new HTMLTableCell();
      headerRow.AddInnerHTMLElement(headerCell);
      headerCell.SetColSpan(CommonHTMLStrings.THREE);
      headerCell.SetHeight("20");
      headerSpan = new HTMLSpan();
      headerCell.AddInnerHTMLElement(headerSpan);
      headerSpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
      // Edit Preferences
      headerSpan.AddInnerHTMLString(m_asOwner.GetString(3272, ResourceConstants.PORTALADMINMSGS));
      headerRow = new HTMLTableRow();
      headerTable.AddInnerHTMLElement(headerRow);
      // start displaying prefs
      DisplayMappingGrid(outerCell);
      myComment = new HTMLComment("End: Display PageletParamsMapPluginView");
      result.AddInnerHTMLElement(myComment);
      return result;
    }
    
    /// <param name="result"></param>
    /// <param name="paramNames"></param>
    protected virtual void DisplayMappingGrid(HTMLElement result)
    {
      HTMLTable prefsTable = TaskAPIUIHTML.CreateTable(result, 2, 2, CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      prefsTable.SetID("paramTable");
      HTMLTableRow headRow = TaskAPIUIHTML.CreateTableRow(prefsTable, PTStyleClass.LIST_SORT_HEADER_BG);
      // Preference Name
      HTMLTableCell headName = TaskAPIUIHTML.CreateTableCell(headRow, PTStyleClass.LIST_SORT_HEADER.GetStyleName(),
       20, "40%");
      headName.AddInnerHTMLString(m_asOwner.GetString(3284, ResourceConstants.PORTALADMINMSGS));
      // Headers for each preference type
      TaskAPIUIHTML.CreateTableCell(headRow, m_asOwner.GetString(3273, ResourceConstants.PORTALADMINMSGS),
       PTStyleClass.LIST_SORT_HEADER, 20, "15%");
      TaskAPIUIHTML.CreateTableCell(headRow, m_asOwner.GetString(3274, ResourceConstants.PORTALADMINMSGS),
       PTStyleClass.LIST_SORT_HEADER, 20, "15%");
      TaskAPIUIHTML.CreateTableCell(headRow, m_asOwner.GetString(3276, ResourceConstants.PORTALADMINMSGS),
       PTStyleClass.LIST_SORT_HEADER, 20, "15%");
      PageletParamsMapPluginModel model = (PageletParamsMapPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_PageletParamMapPluginView);
      String[] paramNames = model.GetPageletParameterNames();
      String[] paramDescs = model.GetPageletParameterDescriptions();
      bool newPagelet = model.IsUsingNewPagelet();
      // display a message if this pagelet does not use any parameters
      if (paramNames.Length == 0)
      {
        // String: This pagelet does not use any pagelet parameters.
        String noParamMsg = m_asOwner.GetString(3282, ResourceConstants.PORTALADMINMSGS);
        HTMLTableRow paramTopRow = TaskAPIUIHTML.CreateTableRow(prefsTable,
         PTStyleClass.LIST_ITEM_TWO_BG);
        HTMLTableCell cell = TaskAPIUIHTML.CreateTableCell(paramTopRow, noParamMsg,
         PTStyleClass.LIST_ITALIC_TEXT, 20, "100%");
        cell.SetColSpan("4");
      }
      // Display parameter name, description and checkboxes for the preference type
      for (int i = 0;i < paramNames.Length;i++)
      {
        String paramName = paramNames[i];
        String paramDesc = paramDescs[i];
        // name and description cell
        HTMLTableRow paramTopRow = TaskAPIUIHTML.CreateTableRow(prefsTable,
         (i % 2 == 0) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG);
        HTMLTableCell paramNameCell = TaskAPIUIHTML.CreateTableCell(paramTopRow,
         paramName, PTStyleClass.LIST_SUBHEAD, 20, "15%");
        // for selenium test
        paramNameCell.SetID("paramName" + i);
        paramNameCell.AddInnerHTMLString("<br/>");
        HTMLSpan descSpan = TaskAPIUIHTML.CreateSpanToCell(paramNameCell,
         PTStyleClass.LIST_TEXT, paramDesc);
        // Check box for user pref
        HTMLTableCell paramUser = TaskAPIUIHTML.CreateTableCell(paramTopRow,
         PTStyleClass.LIST_TEXT, 20, "15%");
        paramUser.SetAlign("center");
        HTMLInput userCB = TaskAPIUIHTML.CreateInputToCell(paramUser, HTMLInputTypes.CHECKBOX_TYPE,
         PageletParamsMapPluginModel.INPUTNAME_USER + i, "");
        // don't need to check anything if a new pagelet was selected
        if (!newPagelet)
        {
          userCB.SetChecked(model.IsMappedToUserPrefs(paramName));
        }
        // Check box for comm pref
        HTMLTableCell paramComm = TaskAPIUIHTML.CreateTableCell(paramTopRow,
         PTStyleClass.LIST_TEXT, 20, "15%");
        paramComm.SetAlign("center");
        HTMLInput commCB = TaskAPIUIHTML.CreateInputToCell(paramComm, HTMLInputTypes.CHECKBOX_TYPE,
         PageletParamsMapPluginModel.INPUTNAME_COMM + i, "");
        // don't need to check anything if a new pagelet was selected
        if (!newPagelet)
        {
          commCB.SetChecked(model.IsMappedToCommPrefs(paramName));
        }
        // Check box for admin pref
        HTMLTableCell paramAdmin = TaskAPIUIHTML.CreateTableCell(paramTopRow,
         PTStyleClass.LIST_TEXT, 20, "15%");
        paramAdmin.SetAlign("center");
        HTMLInput adminCB = TaskAPIUIHTML.CreateInputToCell(paramAdmin, HTMLInputTypes.CHECKBOX_TYPE,
         PageletParamsMapPluginModel.INPUTNAME_ADMIN + i, "");
        // don't need to check anything if a new pagelet was selected
        if (!newPagelet)
        {
          adminCB.SetChecked(model.IsMappedToAdminPrefs(paramName));
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorView#Create()"></seealso>
    public override Object Create()
    {
      return new PageletParamsMapPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorView#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}