using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.expandablelist.growablelist;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.server.impl.core.common;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class PrefsListPluginModel : GrowableListModel,IPrefsListPluginModelRO,
  IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.PrefsListPluginModel");
    public const String STR_MVC_CLASS_NAME = "PrefsListPlugin";
    
    /// <summary>
    /// These values specify whether this model is used to set community
    /// preferences or user preferences. The call to SetPrefMode can be used
    /// to set this when the model is initialized. GetPrefMode can be used to
    /// get which mode this model is in.
    /// </summary>
    public const int PLPM_PREFMODE_USERPREFS = 0;
    public const int PLPM_PREFMODE_COMMUNITYPREFS = 1;
    public const int PLPM_PREFMODE_SESSIONPREFS = 2;
    
    /// <summary>
    /// Every Growable list used within an editor must have a unique ID. It just
    /// so happens that it is easy to accidentally collide (since the unique ID's
    /// are set to 0 and 1 a lot). I'm going to give myself an offset, so that I
    /// am less likely to collide with someone else's unique ID). It doesn't really
    /// matter what this number is, as long as no one else chooses the same one for
    /// another ExpList.
    /// </summary>
    private const int m_nUniqueIDOffset = 666;
    
    /// <summary>
    /// NOT Localized String: This string must be blank! 
    /// </summary>
    public const String _PrefsListMainTitle = "";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    private int m_nPrefMode = 0;
    
    /// <summary>
    /// WSMode setting. We use this to determine which checkboxes to display
    /// and store.
    /// </summary>
    private int m_nWSMode;
    public PrefsListPluginModel() : base()
    {
      m_nWSMode = WebServiceModel.WSMODE_NONE;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PrefsListPluginModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)"></seealso>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      base.DeleteRowsOnRepost(_htFormData);
      String[] arList = GetListValues();
      if ((null == arList) || (0 >= arList.Length))
      {
        // Add an extra, empty string for the sake of aesthetics... Any empty 
        // items will be ignored when we store.
        String[] arBlank = {""};
        AddRowsToList(arBlank);
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      String[] aGrowableArrayValues = GetListValues();
      XPArrayList aPrefsList = new XPArrayList();
      // Preference values will be encoded using this XP String Builder. Hopefully pref value
      // names are under 100 characters.
      XPStringBuilder sEncodedPrefValue;
      // Turn this into an Object array so that we can store it.			
      for (int nIndex = 0;nIndex < aGrowableArrayValues.Length;nIndex++)
      {
        String strNewValue = aGrowableArrayValues[nIndex];
        if (0 < XPStringUtility.Trim(strNewValue).Length)
        {
          // AGC- Warning... We're doing a trim here. I think it is valid, but
          // it is worth noting.
          // JD- Let's also percent-U encode the preference name here.
          sEncodedPrefValue = new XPStringBuilder(strNewValue.Length + 10);
          CharsetConverter.WSTR2PercentU(XPStringUtility.Trim(strNewValue),
           sEncodedPrefValue);
          aPrefsList.Add(sEncodedPrefValue.ToString());
        }
        log.Debug("Prefslist array value: " + aGrowableArrayValues[nIndex]);
        }
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      switch (m_nPrefMode){
      case PLPM_PREFMODE_USERPREFS:
      // AGC- Do not un-set the locale string from the list of User prefs. But ONLY IN SWS MODE
      // ONLY SWS MODE!!! In SWS Mode the AdvSettingsPluginView handles the existance of the
      // strLocale pref based on a checkbox.
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      if (WebServiceModel.WSMODE_SWS == mParent.GetWSMode())
      {
        bool bStrLocaleWasSet = false;
        XPArrayList xpalOldPrefs = null;
        try
        {
          xpalOldPrefs = WSModelHelper.ObjectArrayToXPArray(ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS));
          }
        catch (Exception e)
        {
        }
        //AGC- This likely means that this has never been set in the propertybag.
        // That's fine.
        if (null != xpalOldPrefs)
        {
          if (xpalOldPrefs.Contains(AExtensibilityConstants.PTC_STRLOCALE))
          {
            bStrLocaleWasSet = true;
          }
        }
        // If the checkbox set strLocale - then don't remove strLocale. If the
        // user added strLocale in by hand, however, we will always add it (notice that
        // when we draw the prefs list in SWS mode, we don't add strLocale). This means
        // that next time the user opens the Editor, strLocale will not show up in our list,
        // but the checkbox will be set. This is weird behavior, but better than the alternatives.				
        if ((bStrLocaleWasSet) && (!aPrefsList.Contains(AExtensibilityConstants.PTC_STRLOCALE)))
        {
          aPrefsList.Add(AExtensibilityConstants.PTC_STRLOCALE);
        }
      }
      ptProviderInfo.Write(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS,
       aPrefsList.ToArray());
      break;
      case PLPM_PREFMODE_COMMUNITYPREFS:
      ptProviderInfo.Write(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_COMMUNITYPREFS,
       aPrefsList.ToArray());
      break;
      case PLPM_PREFMODE_SESSIONPREFS:
      ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SESSIONPREFS,
       aPrefsList.ToArray());
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
      m_nWSMode = nNewWSMode;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This method checks whether this model is used to set community
    /// preferences or user preferences. SetPrefMode can be used
    /// to set this when the model is initialized. GetPrefMode can be used to
    /// get which mode this model is in.
    /// </summary>
    public virtual int GetPrefMode()
    {
      return m_nPrefMode;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <summary>
    /// Returns our current WS display mode from the WebServiceModel.WSMODE enumeration.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetWSMode()
    {
      return m_nWSMode;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      String strPrefListAddLabel = "";
      String strPrefListMainTitle = _PrefsListMainTitle;
      switch (m_nPrefMode){
      case PLPM_PREFMODE_USERPREFS:
      strPrefListAddLabel = m_asOwner.GetString(1119, "ptmsgs_portaladminmsgs");
      strPrefListMainTitle = m_asOwner.GetString(1116, "ptmsgs_portaladminmsgs");
      break;
      case PLPM_PREFMODE_COMMUNITYPREFS:
      strPrefListAddLabel = m_asOwner.GetString(1120, "ptmsgs_portaladminmsgs");
      strPrefListMainTitle = m_asOwner.GetString(1117, "ptmsgs_portaladminmsgs");
      break;
      case PLPM_PREFMODE_SESSIONPREFS:
      strPrefListAddLabel = m_asOwner.GetString(2798, "ptmsgs_portaladminmsgs");
      strPrefListMainTitle = m_asOwner.GetString(2799, "ptmsgs_portaladminmsgs");
      break;
      }
      InitializeGrowableList(strPrefListMainTitle, 
      //m_asOwner.GetString(1118, "ptmsgs_portaladminmsgs") would make user and community the same, difference is appreciated by iecontrol (otherwise it'll rely on the 666 id or the order of user and community)
      strPrefListMainTitle, PTImageType.ICON_PREFS, strPrefListAddLabel, m_nPrefMode + m_nUniqueIDOffset);
      SetDefaultValue("");
      SetDeleteIcon(PTImageType.ACTION_DELETE);
      // Get our state from the ptObject.
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      Object[] aPrefsList;
      switch (m_nPrefMode){
      case PLPM_PREFMODE_USERPREFS:
      aPrefsList = ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS);
      // AGC- Do not show the locale string in the list of User prefs. But ONLY IN SWS MODE
      // ONLY SWS MODE!!! In SWS Mode the AdvSettingsPluginView handles the existance of the
      // strLocale pref based on a checkbox.
      WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
      if (WebServiceModel.WSMODE_SWS == mParent.GetWSMode())
      {
        XPArrayList xpalPrefsList = WSModelHelper.ObjectArrayToXPArray(aPrefsList);
        if ((null != xpalPrefsList) && (xpalPrefsList.GetSize() > 0))
        {
          int nLocaleIndex = xpalPrefsList.IndexOf(AExtensibilityConstants.PTC_STRLOCALE);
          if ((nLocaleIndex >= 0) && (nLocaleIndex < xpalPrefsList.GetSize()))
          {
            xpalPrefsList.RemoveAt(nLocaleIndex);
          }
        }
        aPrefsList = xpalPrefsList.ToArray();
      }
      break;
      case PLPM_PREFMODE_COMMUNITYPREFS:
      aPrefsList = ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_COMMUNITYPREFS);
      break;
      case PLPM_PREFMODE_SESSIONPREFS:
      default:
      aPrefsList = ptProviderInfo.ReadAsObject1DArray(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SESSIONPREFS);
      break;
      }
      if ((null != aPrefsList) && (aPrefsList.Length > 0))
      {
        String[] astrPrefsList = new String[aPrefsList.Length];
        XPStringBuilder xpsbDecodedPrefName;
        for (int nIndex = 0;nIndex < aPrefsList.Length;nIndex++)
        {
          //CSP decode pref name
          String strPrefName = XPConvert.ToString(aPrefsList[nIndex]);
          xpsbDecodedPrefName = new XPStringBuilder(strPrefName.Length + 10);
          CharsetConverter.PercentUtoBSTR(strPrefName, xpsbDecodedPrefName);
          astrPrefsList[nIndex] = xpsbDecodedPrefName.ToString();
        }
        AddRowsToList(astrPrefsList);
      }
      // Add an extra, empty string for the sake of aesthetics... Any empty 
      // items will be ignored when we store.
      String[] arBlank = {""};
      AddRowsToList(arBlank);
    }
    
    /// <summary>
    /// This method specifies whether this model is used to set community
    /// preferences or user preferences. SetPrefMode can be used
    /// to set this when the model is initialized. GetPrefMode can be used to
    /// get which mode this model is in.
    /// </summary>
    public virtual void SetPrefMode(int nPrefMode)
    {
      m_nPrefMode = nPrefMode;
    }
  }
}