using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class RemoteConfigPluginModel : EditorHelperModel,IRemoteConfigPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "RemoteConfigPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// The location of the Configuration URLs for this Web Service.
    /// </summary>
    private String m_strRemoteConfigURLAdmin = "";
    
    /// <summary>
    /// The location of the Configuration URLs for this Web Service.
    /// </summary>
    private String m_strRemoteConfigURLUser = "";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RemoteConfigPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_CONFIGURL_ADMIN,
       m_strRemoteConfigURLAdmin);
      if ((null == m_strRemoteConfigURLAdmin) || (0 >= XPStringUtility.Trim(m_strRemoteConfigURLAdmin).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_ADMIN;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_ADMIN;
        }
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_CONFIGURL_USER,
       m_strRemoteConfigURLUser);
      if ((null == m_strRemoteConfigURLUser) || (0 >= XPStringUtility.Trim(m_strRemoteConfigURLUser).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PERSONAL;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PERSONAL;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <summary>
    /// The location of the Configuration URL for this Web Service.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetConfigURLAdmin()
    {
      return m_strRemoteConfigURLAdmin;
    }
    
    /// <summary>
    /// The location of the Configuration URL for this Web Service.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetConfigURLUser()
    {
      return m_strRemoteConfigURLUser;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      SetConfigURLAdmin(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_CONFIGURL_ADMIN,
       m_strRemoteConfigURLAdmin));
      SetConfigURLUser(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_CONFIGURL_USER,
       m_strRemoteConfigURLUser));
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nValid = RepostControl.PAGE_STATUS_VALID;
      SetConfigURLAdmin(WSModelHelper.GetFormElementString(_htFormData, RemoteConfigPluginView.HTMLINPUT_CONFIGURL_ADMIN,
       m_strRemoteConfigURLAdmin));
      SetConfigURLUser(WSModelHelper.GetFormElementString(_htFormData, RemoteConfigPluginView.HTMLINPUT_CONFIGURL_USER,
       m_strRemoteConfigURLUser));
      if ((null != m_strRemoteConfigURLAdmin && !m_strRemoteConfigURLAdmin.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strRemoteConfigURLAdmin,
         m_asOwner, m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
        }
      if ((null != m_strRemoteConfigURLUser && !m_strRemoteConfigURLUser.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strRemoteConfigURLUser,
         m_asOwner, m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
        }
      return nValid;
    }
    
    /// <summary>
    /// The location of the Configuration URL for this Web Service.
    /// </summary>
    public virtual void SetConfigURLAdmin(String strRemoteConfig)
    {
      m_strRemoteConfigURLAdmin = strRemoteConfig;
    }
    
    /// <summary>
    /// The location of the Configuration URL for this Web Service.
    /// </summary>
    public virtual void SetConfigURLUser(String strRemoteConfig)
    {
      m_strRemoteConfigURLUser = strRemoteConfig;
    }
  }
}