using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class RemoteMigrationPluginModel : EditorHelperModel,IRemoteMigrationPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "RemoteMigrationPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// The location of the Help URL for this Web Service.
    /// </summary>
    private String m_strRemoteMigration = "";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RemoteMigrationPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_MIGRATIONURL,
       m_strRemoteMigration);
      int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();
      if ((null == m_strRemoteMigration) || (0 >= XPStringUtility.Trim(m_strRemoteMigration).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_MIGRATION;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_MIGRATION;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// The location of the Help URL for this Web Service.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetRemoteMigrationURL()
    {
      return m_strRemoteMigration;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      SetRemoteMigrationURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_MIGRATIONURL,
       m_strRemoteMigration));
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nValid = RepostControl.PAGE_STATUS_VALID;
      SetRemoteMigrationURL(WSModelHelper.GetFormElementString(_htFormData,
       RemoteMigrationPluginView.HTMLINPUT_REMOTEMIGRATION_URL, m_strRemoteMigration));
      if ((null != m_strRemoteMigration && !m_strRemoteMigration.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strRemoteMigration, m_asOwner,
         m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
      }
      return nValid;
    }
    
    /// <summary>
    /// The location of the Help URL for this Web Service.
    /// </summary>
    public virtual void SetRemoteMigrationURL(String strRemoteMigration)
    {
      m_strRemoteMigration = strRemoteMigration;
    }
  }
}