using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.restconsumerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>rozhang</author>
  public class RemotePageletPickerPluginModel : EditorHelperModel,IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     typeof(RemotePageletPickerPluginModel));
    public const String STR_MVC_CLASS_NAME = "RemotePageletPicker";
    public const String INPUTNAME_SELECTEDLIB = "in_hi_selpageletlib";
    public const String INPUTNAME_SELECTEDPAGELET = "in_hi_selpagelet";
    protected IPTWebService m_webService = null;
    protected bool m_ensembleServerValid = true;
    protected EnsemblePageletRestData[] m_pagelets = null;
    protected XPHashtable m_libCollection = new XPHashtable();
    protected XPHashtable m_pageletData = new XPHashtable();
    protected String[] m_libNames = null;
    // store portlet community preferences names, used by PageletPAramsMapPluginModel
    protected String[] m_pageletParamNames = null;
    protected String[] m_pageletParamDescriptions = null;
    protected String m_selectedLibraryName = null;
    protected String m_selectedPageletName = null;
    protected String m_selectedPageletDesc = null;
    protected int m_selectedLibIndex = -1;
    protected String m_selectedPageletId = "";
    
    /// <summary>
    /// Loads stored data and retrieves list of pagelets from ensemble
    /// This method is called once editor is started  
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(com.plumtree.server.IPTWebService)"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      // this method is called in all webservice editors, not just remote pagelets, don't do anything unless
      // we are in a remote pagelet webservice editor
      if (!RemPageletWSWebServiceEditorAS.STR_MVC_CLASS_NAME.Equals(m_asOwner.GetName()))
      {
        return;
      }
      m_webService = ptWebService;
      // first load the stored library and pagelet name
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      m_selectedLibraryName = WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY,
       "");
      m_selectedPageletName = WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_NAME,
       "");
      // now get the list of pagelets from ensemble rest api
      IPTSession session = (IPTSession) m_asOwner.GetUserSession();
      EnsembleRestAPIService service = new EnsembleRestAPIService();
      EnsemblePageletRestData[] pagelets = null;
      try
      {
        pagelets = service.GetAllPageletsFromRest(session);
        if (pagelets == null)
        {
          HandleUIError(m_asOwner.GetString(3237, ResourceConstants.PORTALADMINMSGS));
          m_ensembleServerValid = false;
          return;
        }
      }
      catch (XPException e)
      {
        if (e is RestConnectFailedException)
        {
          // handle when ensemble remote server is not available
          log.Error(e, "Error connecting to Ensemble REST service.");
          HandleUIError(m_asOwner.GetString(3237, ResourceConstants.PORTALADMINMSGS));
          } else
        {
          log.Error(e, "Error parsing REST Response from Ensemble.");
          HandleUIError(m_asOwner.GetString(3283, ResourceConstants.PORTALADMINMSGS));
          }
        m_ensembleServerValid = false;
        return;
      }
      m_pagelets = pagelets;
      // need to extract pagelets by library - use an arraylist for each library and add all libraries to a hashtable
      XPHashtable libCollection = new XPHashtable();
      for (int i = 0;i < pagelets.Length;i++)
      {
        EnsemblePageletRestData pagelet = pagelets[i];
        String libName = pagelet.libraryName;
        // for the stored pagelet, gets its id and description - used by the view
        if (pagelet.name.Equals(m_selectedPageletName))
        {
          m_selectedPageletId = pagelet.id + "";
          m_selectedPageletDesc = pagelet.description;
        }
        // keep a map of pagelet ids to pagelet names (need to display pagelet name)
        m_pageletData.PutElement(pagelet.id + "", pagelet);
        if (!libCollection.ContainsKey(libName))
        {
          // new library, add a new arraylist to put pagelets in
          XPArrayList newLib = new XPArrayList();
          newLib.Add(pagelet);
          libCollection.PutElement(libName, newLib);
        } else
        {
          // library already exists, add to existing arraylist 
          ((XPArrayList) libCollection.GetElement(libName)).Add(pagelet);
          }
      }
      m_libCollection = libCollection;
      // make sure we got at least one library, should really never happen
      if (m_libCollection.GetSize() < 1)
      {
        throw new XPIllegalStateException("No pagelet libraries found!");
        }
      // set the index of selected library
      String[] libNames = GetPageletLibraries();
      if ("".Equals(m_selectedLibraryName) || m_selectedLibraryName == null)
      {
        // select the first library if none is saved
        m_selectedLibIndex = 0;
        RefreshSelectedPageletLibraryName();
      } else
      {
        for (int i = 0;i < libNames.Length;i++)
        {
          if (libNames[i].Equals(m_selectedLibraryName))
          {
            m_selectedLibIndex = i;
            break;
          }
        }
      }
    }
    
    /// <summary>
    /// Save reposted page data to model
    /// Called on every page reload and before switching pages 
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // this method is called in all webservice editors, not just remote pagelets, don't do anything unless
      // we are in a remote pagelet webservice editor
      if (!RemPageletWSWebServiceEditorAS.STR_MVC_CLASS_NAME.Equals(m_asOwner.GetName()))
      {
        return EditorRepostControl.PAGE_STATUS_VALID;
      }
      if (!m_ensembleServerValid)
      {
        String strError = m_asOwner.GetString(3237, ResourceConstants.PORTALADMINMSGS);
        HandleUIError(strError);
        return EditorRepostControl.PAGE_STATUS_INVALID;
      }
      bool newLibrarySelected = false;
      int valid = EditorRepostControl.PAGE_STATUS_VALID;
      // get the selected library from the form repost
      if (_htFormData.ContainsKey(INPUTNAME_SELECTEDLIB))
      {
        String libIndex = ((String[]) _htFormData.GetElement(INPUTNAME_SELECTEDLIB))[0];
        // invalid library
        if ("".Equals(libIndex) || libIndex == null)
        {
          // should never get here
          m_selectedLibIndex = -1;
        } else
        {
          int newLibrary = XPConvert.ToInteger(libIndex);
          if (m_selectedLibIndex != newLibrary)
          {
            // we got a new library, clear the selected pagelet
            ClearSelectedPagelet();
            m_selectedLibIndex = newLibrary;
            newLibrarySelected = true;
          }
          // sets the library name
          this.RefreshSelectedPageletLibraryName();
        }
      } else
      {
        throw new XPIllegalStateException("Missing form element missing from page! Hidden input: " + INPUTNAME_SELECTEDLIB + " not found.");
        }
      // SET PAGELET
      // if new library was set, don't bother setting new portlet, we are changing library so pagelet is cleared
      if (!newLibrarySelected)
      {
        if (!_htFormData.ContainsKey(INPUTNAME_SELECTEDPAGELET))
        {
          throw new XPIllegalStateException("Missing form element missing from page! Hidden input: " + INPUTNAME_SELECTEDPAGELET + " not found.");
          }
        m_selectedPageletId = ((String[]) _htFormData.GetElement(INPUTNAME_SELECTEDPAGELET))[0];
        // if it is a change page action, validate that a valid pagelet has been selected
        String repostMode = ((String[]) _htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF))[0];
        // make sure we got a pagelet selected before allowing user to switch page, but don't peform check when just
        // reloading page for changing libraries
        if (repostMode.Equals(RepostControl.POSTTOSELF_ACTION_GOTOPAGE + "") || repostMode.Equals(RepostControl.POSTTOSELF_ACTION_FINISH + ""))
        {
          String errorString = m_asOwner.GetString(3238, ResourceConstants.PORTALADMINMSGS);
          valid = ModelHelper.ValidateInteger(m_selectedPageletId, m_asOwner,
           errorString, valid);
          if (valid == RepostControl.PAGE_STATUS_VALID)
          {
            // store the selected pagelet name in the model
            EnsemblePageletRestData pagelet = (EnsemblePageletRestData) m_pageletData.GetElement(m_selectedPageletId);
            m_selectedPageletName = pagelet.name;
            m_pageletParamNames = pagelet.prefsData.GetParameterNames();
            m_pageletParamDescriptions = pagelet.prefsData.GetParameterDescriptions();
            }
        }
      }
      return valid;
    }
    
    /// <summary>
    /// Store the library name and pagelet name in the webservice webservice property bag 
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      // don't save any data if the ensemble service is not configured properly
      if (m_ensembleServerValid)
      {
        IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_webService.GetProviderInfo();
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY,
         m_selectedLibraryName);
        WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_NAME,
         m_selectedPageletName);
      }
    }
    
    /// <summary>
    /// Sets the name of the selected library
    /// </summary>
    public virtual void RefreshSelectedPageletLibraryName()
    {
      // not initialized, invalid ensemble server
      if (m_libNames == null)
      {
        return;
      }
      m_selectedLibraryName = m_libNames[m_selectedLibIndex];
    }
    public virtual EnsemblePageletRestData[] GetPagelets()
    {
      return m_pagelets;
    }
    public virtual XPArrayList GetPageletsInCurrentLibrary()
    {
      XPArrayList pagelets = (XPArrayList) m_libCollection.GetElement(m_selectedLibraryName);
      if (pagelets == null)
      {
        return new XPArrayList();
      }
      return pagelets;
    }
    public virtual String GetSelectedLibraryName()
    {
      return m_selectedLibraryName;
    }
    public virtual int GetSelectedLibraryIndex()
    {
      return m_selectedLibIndex;
    }
    public virtual String GetSelectedPageletIndex()
    {
      return m_selectedPageletId;
    }
    public virtual String GetSelectedPageletName()
    {
      return m_selectedPageletName;
    }
    public virtual String GetSelectedPageletDescription()
    {
      return m_selectedPageletDesc;
    }
    public virtual String[] GetPageletParameterNames()
    {
      return m_pageletParamNames;
    }
    public virtual String[] GetPageletParameterDescriptions()
    {
      return m_pageletParamDescriptions;
    }
    protected virtual String ClearSelectedPagelet()
    {
      String oldPageletId = m_selectedPageletId;
      m_selectedPageletName = "";
      m_selectedPageletId = "";
      m_selectedPageletDesc = "";
      m_pageletParamNames = null;
      m_pageletParamDescriptions = null;
      return oldPageletId;
    }
    
    /// <returns></returns>
    public virtual String[] GetPageletLibraries()
    {
      if (m_libCollection == null)
      {
        return new String[]{};
      }
      String[] returnVal = null;
      if (m_libNames == null)
      {
        returnVal = new String[m_libCollection.GetSize()];
        IXPEnumerator names = m_libCollection.GetKeys();
        int count = 0;
        while (names.MoveNext())
        {
          returnVal[count] = (String) names.GetCurrent();
          count++;
        }
        m_libNames = returnVal;
      } else
      {
        returnVal = m_libNames;
      }
      return returnVal;
    }
    
    /// <param name="errorMessage"></param>
    public virtual void HandleUIError(String errorMessage)
    {
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       errorMessage, errorMessage);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(java.lang.String,java.lang.String,java.lang.String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    // This won't happen since remote servers don't change for remote pagelet webservices
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#Create()"></seealso>
    public override Object Create()
    {
      return new RemotePageletPickerPluginModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}