using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.restconsumerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  public class RemotePageletPickerPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.RemotePageletPickerPluginView");
    public const String STR_MVC_CLASS_NAME = "RemotePageletPicker";
    protected const String SELECTNAME_PAGELETLIBRARY = "in_se_libraries";
    protected const String SELECTNAME_PAGELETS = "in_se_pagelets";
    protected const String SPANNAME_LIBNAME = "libNameSpan";
    protected const String SPANNAME_PAGELETNAME = "pageletNameSpan";
    protected const String SPANNAME_PAGELETDESC = "pageletDescSpan";
    public override HTMLElement Display()
    {
      RemotePageletPickerPluginModel model = (RemotePageletPickerPluginModel) m_model;
      String sectionDesc = m_asOwner.GetString(3239, ResourceConstants.PORTALADMINMSGS);
      String sectionHeader = m_asOwner.GetString(3240, ResourceConstants.PORTALADMINMSGS);
      String libListHeader = m_asOwner.GetString(3241, ResourceConstants.PORTALADMINMSGS);
      String pageletListHeader = m_asOwner.GetString(3242, ResourceConstants.PORTALADMINMSGS);
      String selLibraryTitle = m_asOwner.GetString(3243, ResourceConstants.PORTALADMINMSGS);
      String selPageletTitle = m_asOwner.GetString(3244, ResourceConstants.PORTALADMINMSGS);
      String noPageletSelected = m_asOwner.GetString(3245, ResourceConstants.PORTALADMINMSGS);
      String noLibrarySelected = m_asOwner.GetString(3246, ResourceConstants.PORTALADMINMSGS);
      // populate list of libraries
      String[] libNames = model.GetPageletLibraries();
      String selectedLibrary = model.GetSelectedLibraryName();
      HTMLOption[] libOptions = new HTMLOption[libNames.Length];
      for (int i = 0;i < libNames.Length;i++)
      {
        libOptions[i] = new HTMLOption("lib" + i, libNames[i]);
        if (libNames[i].Equals(selectedLibrary))
        {
          libOptions[i].SetSelected(true);
        }
      }
      if (selectedLibrary == null || "".Equals(selectedLibrary))
      {
        selectedLibrary = noLibrarySelected;
      }
      // populate list of pagelets
      XPArrayList pagelets = model.GetPageletsInCurrentLibrary();
      String selectedPageletId = model.GetSelectedPageletIndex();
      HTMLOption[] pageletsOptions = new HTMLOption[pagelets.GetSize()];
      // create htmloption object from each pagelet in the current library
      for (int i = 0;i < pagelets.GetSize();i++)
      {
        String pageletId = ((EnsemblePageletRestData) pagelets.GetElement(i)).id + "";
        pageletsOptions[i] = new HTMLOption(pageletId, ((EnsemblePageletRestData) pagelets.GetElement(i)).name);
        if (pageletId.Equals(selectedPageletId))
        {
          pageletsOptions[i].SetSelected(true);
        }
      }
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLInput selLibraryInput = new HTMLInput(HTMLInputTypes.HIDDEN, RemotePageletPickerPluginModel.INPUTNAME_SELECTEDLIB,
       RemotePageletPickerPluginModel.INPUTNAME_SELECTEDLIB, "");
      selLibraryInput.SetValue(model.GetSelectedLibraryIndex() + "");
      HTMLInput selPageletInput = new HTMLInput(HTMLInputTypes.HIDDEN, RemotePageletPickerPluginModel.INPUTNAME_SELECTEDPAGELET,
       RemotePageletPickerPluginModel.INPUTNAME_SELECTEDPAGELET, "");
      selPageletInput.SetValue(model.GetSelectedPageletIndex());
      result.AddInnerHTMLElement(selLibraryInput);
      result.AddInnerHTMLElement(selPageletInput);
      // Sub header
      result.AddInnerHTMLElement(base.GetHeaderView(sectionHeader));
      HTMLTable table;
      table = WSViewHelper.AddTable(result);
      table.SetCellPadding("5");
      // 1st row - Description
      HTMLTableRow descRow = WSViewHelper.AddRow(table);
      ViewHelper.AddTextCell(descRow, "3", sectionDesc);
      descRow.SetStyleClass("dirContentBg");
      // 2nd row - Spacer
      WSViewHelper.AddEmptyRow(table, "3");
      // 3rd row - Picker Header
      HTMLTableRow headRow = WSViewHelper.AddRow(table);
      HTMLTableCell headCell1 = ViewHelper.AddCell(headRow, "1");
      headCell1.SetStyleClass("objectSubtitle");
      headCell1.AddInnerHTMLString(libListHeader);
      headCell1.SetAlign("center");
      headCell1.SetWidth("200");
      HTMLTableCell headCell2 = ViewHelper.AddCell(headRow, "1");
      headCell2.SetStyleClass("objectSubtitle");
      headCell2.AddInnerHTMLString(pageletListHeader);
      headCell2.SetAlign("center");
      headCell2.SetWidth("230");
      HTMLTableCell headCell3 = ViewHelper.AddCell(headRow, "1");
      headCell3.SetStyleClass("objectSubtitle");
      headCell3.SetAlign("center");
      headCell3.SetWidth("50%");
      // 4th row - Pickers
      HTMLTableRow pickRow = WSViewHelper.AddRow(table);
      int viewableEntries = 10;
      HTMLTableCell libCell = WSViewHelper.AddSelectBoxWithJSHandlerInColumn(pickRow,
       "", SELECTNAME_PAGELETLIBRARY, viewableEntries, "width:200px", "selectPageletLibrary();",
       libOptions, "", m_asOwner);
      libCell.SetAlign("center");
      HTMLTableCell pageletCell = WSViewHelper.AddSelectBoxWithJSHandlerInColumn(pickRow,
       "", SELECTNAME_PAGELETS, viewableEntries, "width:225px", "selectPagelet();",
       pageletsOptions, "", m_asOwner);
      pageletCell.SetAlign("center");
      HTMLTableCell selectCell = ViewHelper.AddCell(pickRow, "1");
      selectCell.SetWidth("100%");
      // Sub table with selection information
      HTMLTable selTable = WSViewHelper.MakeTable();
      selectCell.AddInnerHTMLElement(selTable);
      // display name of selected library 
      WSViewHelper.AddEmptyRow(selTable, "1");
      HTMLTableRow sellibHeadRow = WSViewHelper.AddRow(selTable);
      sellibHeadRow.SetStyleClass("objectHeaderBg");
      ViewHelper.AddLabelCell(sellibHeadRow, "2", selLibraryTitle);
      HTMLTableRow sellibNameRow = WSViewHelper.AddEmptyRow(selTable, "1");
      ViewHelper.AddReferencableLabelCell(sellibNameRow, "1", selectedLibrary,
       SPANNAME_LIBNAME);
      // display name and description of selected pagelet
      String curPageletName = model.GetSelectedPageletName();
      if ("".Equals(curPageletName) || curPageletName == null)
      {
        curPageletName = noPageletSelected;
      }
      String curPageletDesc = model.GetSelectedPageletDescription();
      WSViewHelper.AddEmptyRow(selTable, "1");
      HTMLTableRow selPagltHeadRow = WSViewHelper.AddRow(selTable);
      selPagltHeadRow.SetStyleClass("objectHeaderBg");
      ViewHelper.AddLabelCell(selPagltHeadRow, "2", selPageletTitle);
      HTMLTableRow selPagltNameRow = WSViewHelper.AddEmptyRow(selTable, "1");
      ViewHelper.AddReferencableLabelCell(selPagltNameRow, "1", curPageletName,
       SPANNAME_PAGELETNAME);
      HTMLTableRow selPagltDescRow = WSViewHelper.AddEmptyRow(selTable, "1");
      ViewHelper.AddTextCellReferencable(selPagltDescRow, "1", curPageletDesc,
       SPANNAME_PAGELETDESC);
      // 5th row - Spacer
      WSViewHelper.AddEmptyRow(table, "3");
      // have to write out the array of pagelet descriptions in the display method and not the displayjavascript method since it is
      // called before the model is initialized
      HTMLScript script = new HTMLScript("text/javaScript");
      XPStringBuilder b = new XPStringBuilder();
      b.Append("var pageletDescriptions = [\n");
      for (int i = 0;i < pagelets.GetSize();i++)
      {
        String desc = ((EnsemblePageletRestData) pagelets.GetElement(i)).description;
        if (i != 0)
        {
          b.Append(",");
        }
        b.Append("\'" + JSHelper.escapeJS(desc) + "\'\n");
      }
      b.Append("];\n");
      b.Append("\n");
      script.AddInnerHTMLString(b.ToString());
      result.AddInnerHTMLElement(script);
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder b = new XPStringBuilder();
      b.Append("function selectPageletLibrary() {\n");
      b.Append("\tvar selLib = document.getElementById(\'" + SELECTNAME_PAGELETLIBRARY + "\');\n");
      b.Append("  document.mainform." + RemotePageletPickerPluginModel.INPUTNAME_SELECTEDLIB + ".value = selLib.selectedIndex\n");
      // clear selected pagelet
      b.Append("\tvar pageletNameContainer = document.getElementById(\'" + SPANNAME_PAGELETNAME + "\');\n");
      b.Append("\tvar pageletDescContainer = document.getElementById(\'" + SPANNAME_PAGELETDESC + "\');\n");
      b.Append("\tpageletNameContainer.innerHTML = \'\';\n");
      b.Append("  pageletDescContainer.innerHTML = \'\'\n");
      b.Append("\tdocument.getElementById(\'" + SPANNAME_LIBNAME + "\').innerHTML = selLib.options[selLib.selectedIndex].innerHTML;\n");
      b.Append("  postToSelf(" + WebServiceRepostControl.POSTTOSELF_ACTION_SET_PAGELETLIBRARY + ");\n");
      b.Append("}\n");
      b.Append("function selectPagelet() {\n");
      b.Append("  var selpagelets = document.getElementById(\'" + SELECTNAME_PAGELETS + "\')\n");
      b.Append("\tvar pageletNameContainer = document.getElementById(\'" + SPANNAME_PAGELETNAME + "\');\n");
      b.Append("\tvar pageletDescContainer = document.getElementById(\'" + SPANNAME_PAGELETDESC + "\');\n");
      b.Append("  document.mainform." + RemotePageletPickerPluginModel.INPUTNAME_SELECTEDPAGELET + ".value = selpagelets.options[selpagelets.selectedIndex].value;\n");
      b.Append("\tpageletNameContainer.innerHTML = selpagelets.options[selpagelets.selectedIndex].innerHTML;\n");
      b.Append("  pageletDescContainer.innerHTML = pageletDescriptions[selpagelets.selectedIndex];\n");
      b.Append("}\n");
      b.Append("\n");
      // populate a javascript array with pagelet descriptions - display pagelet description
      // for the selected pagelet
      result.AddInnerHTMLString(b.ToString());
      return result;
    }
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public override Object Create()
    {
      return new RemotePageletPickerPluginView();
    }
  }
}