using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class RemoteServerPluginModel : EditorHelperModel,IRemoteServerPluginModelRO,
  IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.RemoteServerPluginModel");
    public const String STR_MVC_CLASS_NAME = "RemoteServerPlugin";
    
    /// <summary>
    /// This member defines a static string used to identify when m_htFormData
    /// has been initialized.
    /// </summary>
    public const String DEFAULTDATA = "Default Data";
    // Name of template (null means nothing selected)
    protected String m_strBaseURL = null;
    // Name of template (null means nothing selected)
    protected String m_strRemoteServerName = null;
    // Remote Server Section
    // Object ID of template (0 means nothing selected)
    
    /// <summary>
    /// Tree Data for the Remote Server for this Web Service (Remote Server)
    /// </summary>
    protected int m_nRemoteServerObjectID = 0;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// The following member holds a pointer to the Remote Server object that
    /// this Web Service depends on. NOTE: The Remote Server can change at any
    /// time and is NOT necessarily up-to-date. Do not use this member
    /// directly, but call GetRSObject() to get an up-to-date remote server.
    /// </summary>
    private IPTGadgetContentServer m_ptRemoteServer = null;
    
    /// <summary>
    /// This member contains form data sent to this control (used for the Tree control, mostly).
    /// </summary>
    private XPHashtable m_htFormData;
    
    /// <summary>
    /// The boolean which tells our view whether or not it should display
    /// read-only.
    /// NOTE*: The read-only feature is now disabled due to a change in functionality.
    /// Because WebServices can now run without Remote Servers, we should not
    /// block people from changing the remote server after creation. To re-enable
    /// this feature, set m_bReadOnly to 'true' on the line below.
    /// </summary>
    private bool m_bReadOnly = false;
    public RemoteServerPluginModel() : base()
    {
      m_htFormData = new XPHashtable();
    }
    
    /// <summary>
    /// This method clears the selected items from the tree.
    /// </summary>
    public virtual void ClearRemoteServer()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_SUBSPACE);
          ATreeModel treeModel = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
          treeModel.ClearSelectedItems();
        }
        m_nRemoteServerObjectID = 0;
        m_strRemoteServerName = "";
        UpdateRSObject();
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error in ClearRemoteServer.");
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RemoteServerPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      if (!m_bReadOnly)
      {
        m_ptWebService.SetRemoteServerID(m_nRemoteServerObjectID);
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)"></seealso>
    public virtual String GetData(String name)
    {
      String[] values = (String[]) m_htFormData.GetElement(name);
      if (values == null)
      {
        return DEFAULTDATA;
      }
      return values[0];
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns>Returns the base URL of the currently selected Remote Server</returns>
    public virtual String GetRemoteServerBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <summary>
    /// Returns the name of the Remote Server
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetRemoteServerName()
    {
      return m_strRemoteServerName;
    }
    
    /// <summary>
    /// Returns the name of the Remote Server
    /// </summary>
    /// <returns>String</returns>
    public virtual int GetRemoteServerObjectID()
    {
      return m_nRemoteServerObjectID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IRemoteServerPluginModelRO#GetRemoteServerPath()"></seealso>
    public virtual String GetRemoteServerPath()
    {
      IPTGadgetContentServer ptRemoteServer = UpdateRSObject();
      if (null == ptRemoteServer)
      {
        return "";
      }
      try
      {
        int nAdminFolderID = ptRemoteServer.GetAdminFolderID();
        IPTSession ptSession = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();
        IPTAdminCatalog ptAFCatalog = ptSession.GetAdminCatalog();
        //MES- CR: What happens if the folder has been deleted?  E.g. the GCS was moved while we had it open.
        //AGC- That would be odd, since deleting the folder would most likely require deleting the object we are
        //  currently editing. I think that the folder delete would not be allowed. But just in case it is,
        //  I've thrown in a try-catch to return an empty string. 		
        IPTAdminFolder ptAFParent = ptAFCatalog.OpenAdminFolder(nAdminFolderID,
         false);
        String strPath = ptAFParent.GetPath();
        return strPath;
      }
      catch (Exception e)
      {
        log.Warn(e, "WebServiceModel::GetRemoteServerPath - Unknown error retrieving folder path. Returning empty string.");
        return "";
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(IPTWebService)"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      int nRSObjectID = ptWebService.GetRemoteServerID();
      if ((((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT) || (nRSObjectID > 0))
      {
        m_nRemoteServerObjectID = nRSObjectID;
        try
        {
          UpdateRSObject();
          if (null != m_ptRemoteServer)
          {
            ((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).UpdateWSSubModels();
            } else
          {
            // AGC- We should NOT display read only.
            m_bReadOnly = false;
          }
        }
        catch (Exception e)
        {
          log.Warn(e, "WebServiceModel::DoTaskOnStartEditor - Unable to access Remote Server object. Continuing with NULL Remote Server.");
          }
      } else
      {
        m_bReadOnly = false;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IRemoteServerPluginModelRO#IsReadOnly()"></seealso>
    public virtual bool IsReadOnly()
    {
      return m_bReadOnly;
    }
    
    /// <summary>
    /// Set whether this model is read only or not.
    /// </summary>
    /// <param name="_bIsReadOnly">whether this model is read only or not.</param>
    public virtual void SetIsReadOnly(bool _bIsReadOnly)
    {
      m_bReadOnly = _bIsReadOnly;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromTree()
    {
      try
      {
        if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_SUBSPACE))
        {
          AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_SUBSPACE);
          ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList itemList = treeModel.GetSelectedItems();
          if (itemList.GetSize() > 0)
          {
            TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
            if (item == null)
            {
              log.Error("Tree selected item null");
            } else
            {
              m_nRemoteServerObjectID = item.m_nObjectID;
              m_strRemoteServerName = item.GetName();
            }
          }
        }
      }
      catch (Exception e)
      {
        // This may simply be because the tree was cancelled with no node set.
        log.Warn(e, "Unknown Error in RefreshItemFromTree.");
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      if (!m_bReadOnly)
      {
        // Store our form data for later use - especially for use in the tree control.
        int nSize = _htFormData.GetSize();
        IXPEnumerator xpKeys = _htFormData.GetKeys();
        for (int i = 0;i < nSize;i++)
        {
          xpKeys.MoveNext();
          m_htFormData.PutElement((String) xpKeys.GetCurrent(), (String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
          }
        RefreshItemFromTree();
        UpdateRSObject();
        if (null != m_ptRemoteServer)
        {
          ((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).UpdateWSSubModels();
          } else
        {
        }
      }
      //AGC- The validation code that was here was removed. Now, Webservices need not
      //have valid remote servers applied.
      return RepostControl.PAGE_STATUS_VALID;
    }
    // ************************************ Helper Functions *************************************
    
    /// <summary>
    /// Call this method instead of using m_ptRemoteServer directly. Note that
    /// this method can return NULL if there is currently no Remote Server set.
    /// </summary>
    private IPTGadgetContentServer UpdateRSObject()
    {
      if (0 >= m_nRemoteServerObjectID)
      {
        m_strBaseURL = null;
        m_strRemoteServerName = null;
        m_ptRemoteServer = null;
        return null;
      }
      try
      {
        IPTSession ptSession = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();
        if ((null == m_ptRemoteServer) || (((IPTServerContext) ((IPTObject) m_ptRemoteServer).GetInterfaces("IPTServerContext")).GetObjectID() != m_nRemoteServerObjectID))
        {
          // The 0 in the following statement tells the object manager not to lock the object.
          m_ptRemoteServer = (IPTGadgetContentServer) ptSession.GetGadgetContentServers().Open(m_nRemoteServerObjectID,
           false);
        }
      }
      catch (Exception e)
      {
        log.Warn(e, "WebServiceModel::GetRSObject - Unable to access Remote Server object. Continuing with NULL Remote Server.");
        }
      m_strBaseURL = m_ptRemoteServer.GetURL();
      m_strRemoteServerName = m_ptRemoteServer.GetLocalizedName();
      return m_ptRemoteServer;
    }
  }
}