using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <summary>
  /// This view allows you to choose the Remote Server used
  /// by this Web Service
  /// </summary>
  /// <author>adolfoc</author>
  public class RemoteServerPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.RemoteServerPluginView");
    
    /// <summary>
    /// The object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RemoteServerPluginView";
    
    /// <summary>
    /// Private String that is the function name for the repost javascript called
    /// when the tree control returns
    /// </summary>
    private const String JSREPOST_REMOTESERVER_FUNC = "frmRepostRemoteViewChosen";
    private const String JSREPOST_REMOTESERVER_FUNC_INPUT = "frmSetDataRemoteViewChosen";
    private const String JSREPOST_REMOTESERVERREMOVE_FUNC = "frmRepostRemoteViewRemoved";
    // HTML Object names.
    public const String HTMLHIDDEN_REMOTE_SERVER_SPACE = "in_hi_RemoteServerSpace";
    public const String HTMLHIDDEN_REMOTE_SERVER_SELECTED = "in_hi_RemoteServerSelected";
    public const String HTMLBUTTON_REMOTE_SERVER_REMOVE = "in_bu_RemoveRemoteServer";
    private AActivitySpace m_asasParent;
    private IRemoteServerPluginModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RemoteServerPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLSpan mySpan;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1136,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 1st row ends
        // 2nd row begins
        myRow = WSViewHelper.AddRow(myTable);
        //// Left Margin
        WSViewHelper.AddLeftMargin(myRow, 5);
        ////// Don't forget to HTMLEncode this stuff..... Important!			
        String strRemoteServerName = ((IRemoteServerPluginModelRO) m_model).GetRemoteServerName();
        bool bValidRemoteServer = true;
        myCell = WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(1138,
         "ptmsgs_portaladminmsgs"));
        if ((null == strRemoteServerName) || (0 >= strRemoteServerName.Length))
        {
          strRemoteServerName = m_asOwner.GetString(1142, "ptmsgs_portaladminmsgs");
          bValidRemoteServer = false;
          myCell = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE,
           strRemoteServerName);
        } else
        {
          // add remote server opener link
          HTMLAnchor rsLink = (HTMLAnchor) WSViewHelper.MakeEditObjectLink(PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID,
           m_model.GetRemoteServerObjectID(), strRemoteServerName, m_asOwner);
          myCell = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
          HTMLSpan rsOpenerSpan = WSViewHelper.AddSpanToCell(myCell);
          rsOpenerSpan.AddInnerHTMLElement(rsLink);
        }
        mySpan = WSViewHelper.AddSpanToCell(myCell);
        mySpan.AddInnerHTMLString(SPACE);
        ////// Actual Tree Control
        // Hidden input for the Space ID for the tree.  That way if you hit the folder
        // tree link twice, it will open the same tree both times.
        String strRemoteServerSpaceID = m_model.GetData(HTMLHIDDEN_REMOTE_SERVER_SPACE);
        if (strRemoteServerSpaceID.Equals(RemoteServerPluginModel.DEFAULTDATA))
        {
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_REMOTE_SERVER_SPACE,
           ""));
        } else
        {
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_REMOTE_SERVER_SPACE,
           strRemoteServerSpaceID));
        }
        String strOnClick = JSREPOST_REMOTESERVER_FUNC_INPUT + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_REMOTE_SERVER_SPACE + "); return false;";
        String strOnClickRemove = JSREPOST_REMOTESERVERREMOVE_FUNC + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_REMOTE_SERVER_SPACE + "); return false;";
        if (!((IRemoteServerPluginModelRO) m_model).IsReadOnly())
        {
          mySpan.AddInnerHTMLString(SPACE);
          mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(m_asOwner.GetString(1140,
           "ptmsgs_portaladminmsgs"), strOnClick));
          // Add a remove button if the remote server is non-null.
          if (bValidRemoteServer)
          {
            mySpan.AddInnerHTMLString(SPACE);
            mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(m_asOwner.GetString(1141,
             "ptmsgs_portaladminmsgs"), strOnClickRemove, HTMLBUTTON_REMOTE_SERVER_REMOVE));
            }
        }
        mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_REMOTE_SERVER_SELECTED,
         m_model.GetData(HTMLHIDDEN_REMOTE_SERVER_SELECTED)));
        // Right Margin
        WSViewHelper.AddRightMargin(myRow, 5);
        // 2nd row ends			
        // 3rd Row - Path info.
        myRow = WSViewHelper.AddRow(myTable);
        //// Left Margin
        WSViewHelper.AddLeftMargin(myRow, 5);
        //// Label "Remote Server Path"
        String strRemoteServerPath = ((IRemoteServerPluginModelRO) m_model).GetRemoteServerPath();
        if (null == strRemoteServerPath)
        {
          strRemoteServerPath = "";
        }
        WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(1139,
         "ptmsgs_portaladminmsgs"));
        WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE, strRemoteServerPath);
        //// Right Margin
        WSViewHelper.AddRightMargin(myRow, 5);
        // 4th row begins
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      // 4th row ends
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1137, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      String strFormName = AFormDP.HTMLFORM_NAME;
      // The URL to open a new remote folder tree
      ASURL newRemoteServerTree = new ASURL(m_asOwner);
      newRemoteServerTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
       m_asasParent);
      newRemoteServerTree.SetSubSpaceKey(WebServiceEditorAS.strTREE_SUBSPACE);
      newRemoteServerTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      newRemoteServerTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      newRemoteServerTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
       XPConvert.ToString(false));
      newRemoteServerTree.AddControlArgument(StartTreeControl.SELECT_MODE,
       XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      newRemoteServerTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
       XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      newRemoteServerTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
       strFormName);
      newRemoteServerTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       HTMLHIDDEN_REMOTE_SERVER_SPACE);
      newRemoteServerTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       JSREPOST_REMOTESERVER_FUNC);
      newRemoteServerTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1930,
       "ptmsgs_portaladminmsgs"));
      newRemoteServerTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
       m_asOwner.GetString(1931, "ptmsgs_portaladminmsgs"));
      newRemoteServerTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       XPConvert.ToString(PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID));
      // The url to open a previously opened remote folder tree
      // This needs to have the SpaceID added to it.
      ASURL oldRemoteServerTree = new ASURL(m_asOwner);
      oldRemoteServerTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
       m_asasParent);
      oldRemoteServerTree.IsSubSpace();
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_REMOTESERVER_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_REMOTE_VIEW_CHOSEN).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Test Server Side From Submit function
        sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JSREPOST_REMOTESERVERREMOVE_FUNC).Append("()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(").Append(WebServiceRepostControl.POSTTOSELF_ACTION_REMOTE_VIEW_REMOVED).Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
        // Open remote folder tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JSREPOST_REMOTESERVER_FUNC_INPUT).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    window.open(\'").Append(newRemoteServerTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.open(\'").Append(oldRemoteServerTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element: " + he.Message);
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
      m_model = (IRemoteServerPluginModelRO) model;
    }
  }
}