using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class SOAPEncodingPluginModel : EditorHelperModel,ISOAPEncodingPluginModelRO,
  IWSSubModel
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SOAPEncodingPlugin";
    
    /// <summary>
    /// The following publics should be used by views to Get or Set
    /// enabled-ness.
    /// </summary>
    public const int SOAPENC_RPC = 1;
    public const int SOAPENC_DOCUMENTLITERAL = 0;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// Radio item that chooses whether this WebService is enabled or not
    /// (AdditionalSettingsView)
    /// </summary>
    private int m_nEncodingRadio;
    public SOAPEncodingPluginModel() : base()
    {
      m_nEncodingRadio = SOAPENC_RPC;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SOAPEncodingPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_ENCODED,
       m_nEncodingRadio);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the m_nEncodingRadio.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetSOAPEncoding()
    {
      return m_nEncodingRadio;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      // Initialize ourselves
      SetEncoding(WSModelHelper.PBReadInt(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_ENCODED,
       m_nEncodingRadio));
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      SetEncoding(WSModelHelper.GetFormElementInt(_htFormData, SOAPEncodingPluginView.HTMLRADIO_SOAPENCODING,
       m_nEncodingRadio));
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Sets the m_nEncodingRadio. Value must be SOAPENC_RPC or SOAPENC_DOCUMENTLITERAL (will
    /// silently set value to SOAPENC_RPC if out of range.
    /// </summary>
    /// <param name="nEnabledRadio">The nEnabledRadio to set</param>
    public virtual void SetEncoding(int nEncodingRadio)
    {
      if (SOAPENC_RPC == nEncodingRadio)
      {
        this.m_nEncodingRadio = SOAPENC_RPC;
      } else
      {
        this.m_nEncodingRadio = SOAPENC_DOCUMENTLITERAL;
      }
    }
  }
}