using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class SWSSettingsPluginView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.SWSSettingsPluginView");
    
    /// <summary>
    /// This object's name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SWSSettingsPluginView";
    public const String HTMLINPUT_SEARCH_URL = "in_tx_SearchURL";
    public const String HTMLINPUT_TIMEOUT_SOAPDURATION = "in_tx_SOAPTimeout";
    public const String HTMLSELECT_TIMEOUT_SOAPUNITS = "in_se_SOAPTimeoutUnits";
    public const String HTMLINPUT_TIMEOUT_GATEWAYDURATION = "in_tx_GatewayTimeout";
    public const String HTMLSELECT_TIMEOUT_GATEWAYUNITS = "in_se_GatewayTimeoutUnits";
    
    /// <summary>
    /// The name of our validation function. This must be added by the Page to the
    /// page level validation function. See WSPluginDP for details.
    /// </summary>
    public const String VALIDATION_FUNCTION_NAME = "IsValidSWSSettings";
    
    /// <summary>
    /// Our parent Activity space.
    /// </summary>
    private AActivitySpace m_asasParent;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SWSSettingsPluginView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1153,
         "ptmsgs_portaladminmsgs")));
        myTable = WSViewHelper.AddTable(result);
        // 1st row begins (Top Margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
        // 1st row ends
        // 2 - 3rd rows
        String strBaseURL = ((ISWSSettingsPluginModelRO) m_model).GetBaseURL();
        String strDefault = ((ISWSSettingsPluginModelRO) m_model).GetSearchURL();
        WSViewHelper.AddSimpleEditBox(myTable, 5, m_asOwner.GetString(1154,
         "ptmsgs_portaladminmsgs"), strBaseURL, strDefault, HTMLINPUT_SEARCH_URL);
        // 4.5th row... spacer
        WSViewHelper.AddEmptyRow(myTable, "5");
        //////// SOAP Timeout
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(1156,
         "ptmsgs_portaladminmsgs"), HTMLINPUT_TIMEOUT_SOAPDURATION, HTMLSELECT_TIMEOUT_SOAPUNITS,
         ((ISWSSettingsPluginModelRO) m_model).GetSOAPDuration(), m_asOwner);
        //////// GATEWAY Timeout
        WSViewHelper.AddSimpleDurationCombo(myTable, 5, m_asOwner.GetString(1157,
         "ptmsgs_portaladminmsgs"), HTMLINPUT_TIMEOUT_GATEWAYDURATION, HTMLSELECT_TIMEOUT_GATEWAYUNITS,
         ((ISWSSettingsPluginModelRO) m_model).GetGatewayDuration(), m_asOwner);
        // last row (margin)
        WSViewHelper.AddEmptyRow(myTable, "5");
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1155, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(300);
      try
      {
        sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
        sb.Append("{\n");
        WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
        if (WebServiceModel.WSMODE_SWS == mParent.GetWSMode())
        {
          sb.Append(WSViewHelper.ValidateNumericInputJS(WSPluginDP.HTMLFORM_NAME,
           CWSSettingsPluginView.HTMLINPUT_TIMEOUT_SOAPDURATION, m_asOwner.GetString(1158,
           "ptmsgs_portaladminmsgs")));
          sb.Append(WSViewHelper.ValidateNumericInputJS(WSPluginDP.HTMLFORM_NAME,
           CWSSettingsPluginView.HTMLINPUT_TIMEOUT_GATEWAYDURATION, m_asOwner.GetString(1159,
           "ptmsgs_portaladminmsgs")));
        }
        sb.Append(" \treturn true;\n");
        sb.Append("}\n\n");
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he.Message);
      }
      return script;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asasParent = parent;
    }
  }
}