using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class UserInfoPluginModel : EditorHelperModel,IUserInfoPluginModelRO,
  IWSSubModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.webservice.plugins.UserInfoPluginModel");
    public const String STR_MVC_CLASS_NAME = "UserInfoPlugin";
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// The array of the currently selected user infos.
    /// </summary>
    internal XPArrayList m_xpalUserInfo;
    public UserInfoPluginModel() : base()
    {
      m_xpalUserInfo = new XPArrayList(0);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserInfoPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // In order to not overwrite the non-hard-coded values (since they're not
      // displayed in this view) we must pick them out of the property bag and
      // add them back in.
      XPArrayList xpalUserInfoListToStore = WSModelHelper.GetNonHardcodedUserInfo(ptProviderInfo);
      // Now, we add the new hard-coded values.
      // Turn this into an Object array so that we can store it.			
      for (int nIndex = 0;nIndex < m_xpalUserInfo.GetSize();nIndex++)
      {
        xpalUserInfoListToStore.Add(m_xpalUserInfo.GetElement(nIndex));
        log.Debug("Adding UserInfo array value: " + XPConvert.ToString(xpalUserInfoListToStore.GetElement(nIndex)));
        }
      ptProviderInfo.Write(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERINFO,
       xpalUserInfoListToStore.ToArray());
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      // Get our state from the ptObject.
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      // Get only the hard-coded stuff. The non-hard-coded stuff will be edited in
      // a different view.		
      m_xpalUserInfo = WSModelHelper.GetHardcodedUserInfo(ptProviderInfo);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      m_xpalUserInfo.Clear();
      // iterate through all the defined User Info constants -jas
      for (int index = 0;index < PlumtreeExtensibility.PT_USERINFO_ALL.Length;
      index++)
      {
        AddRemoveUserInfo(PlumtreeExtensibility.PT_USERINFO_ALL[index], _htFormData);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Takes in a user info string and checks to see if it is currently selected.
    /// </summary>
    public virtual bool UserInfoChecked(String strUserInfo)
    {
      return m_xpalUserInfo.Contains(strUserInfo);
    }
    // Helper functions...
    private void AddRemoveUserInfo(String strUserInfo, XPHashtable _htFormData)
    {
      String[] data = (String[]) _htFormData.GetElement(UserInfoPluginView.HTTP_USERINFO + strUserInfo);
      try
      {
        if ((null == data) || (0 >= data.Length))
        {
          m_xpalUserInfo.Remove(strUserInfo);
        } else
        {
          m_xpalUserInfo.Add(strUserInfo);
        }
      }
      catch (Exception e)
      {
        // In all likelihood, we're attempting to remove a value that isn't there...
        // big deal.
        log.Warn(e, "UserInfoPluginModel::SaveSection: Unknown error setting value. Continuing: " + e.Message);
        }
    }
  }
}