using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.editors.webservice.plugins
{
  /// <author>adolfoc</author>
  public class UserPrefsPluginModel : EditorHelperModel,IUserPrefsPluginModelRO,
  IWSSubModel
  {
    public const String STR_MVC_CLASS_NAME = "UserPrefsPlugin";
    
    /// <summary>
    /// These values specify whether this model is used to set community
    /// preferences or user preferences. The call to SetPrefMode can be used
    /// to set this when the model is initialized. GetPrefMode can be used to
    /// get which mode this model is in.
    /// </summary>
    public const int UPPM_PREFMODE_USERPREFS = 0;
    public const int UPPM_PREFMODE_COMMUNITYPREFS = 1;
    public const int UPPM_PREFMODE_ADMINPREFS = 2;
    public const int UPPM_PREFMODE_SESSIONPREFS = 3;
    
    /// <summary>
    /// The Web Service object being edited by our parent Web Service editor
    /// </summary>
    internal IPTWebService m_ptWebService = null;
    
    /// <summary>
    /// We might get the Remote Server Base URL from
    /// our parent model if it is a WebService Model. It is stored here.
    /// </summary>
    private String m_strBaseURL = "";
    
    /// <summary>
    /// Template URL to the User Prefs (WebServicePrefsView) 
    /// </summary>
    private String m_strTemplateUserPrefsURL = "";
    
    /// <summary>
    /// URL to the User Prefs (WebServicePrefsView) 
    /// </summary>
    private String m_strUserPrefsURL = "";
    private int m_nPrefMode = 0;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserPrefsPluginModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()"></seealso>
    public virtual void DoTaskBeforeWSStore()
    {
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
      String strPrefsURL = GetPrefsURL();
      String strTemplatePrefsURL = GetTemplatePrefsURL();
      int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();
      switch (m_nPrefMode){
      case UPPM_PREFMODE_USERPREFS:
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PREFSURL,
       strPrefsURL);
      if ((null == strPrefsURL) || (0 >= XPStringUtility.Trim(strPrefsURL).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      break;
      case UPPM_PREFMODE_COMMUNITYPREFS:
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_COMMUNITYPREFSURL,
       strPrefsURL);
      if ((null == strPrefsURL) || (0 >= XPStringUtility.Trim(strPrefsURL).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      break;
      case UPPM_PREFMODE_ADMINPREFS:
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_ADMINPREFSURL,
       strPrefsURL);
      if ((null == strPrefsURL) || (0 >= XPStringUtility.Trim(strPrefsURL).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR;
        }
      WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_ADMINPREFSURL_TEMPLT,
       strTemplatePrefsURL);
      if ((null == strTemplatePrefsURL) || (0 >= XPStringUtility.Trim(strTemplatePrefsURL).Length))
      {
        nSupportsPersonalization = nSupportsPersonalization & ~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINTEMPLATE;
        } else
      {
        nSupportsPersonalization = nSupportsPersonalization | PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINTEMPLATE;
        }
      m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,String,String)"></seealso>
    public virtual void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
     String strRemoteServerName, String strRemoteServerBaseURL)
    {
      m_strBaseURL = strRemoteServerBaseURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)"></seealso>
    public virtual void DoTaskOnWSModeUpdate(int nNewWSMode)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()"></seealso>
    public virtual String GetBaseURL()
    {
      return m_strBaseURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This method checks whether this model is used to set community
    /// preferences or user preferences. SetPrefMode can be used
    /// to set this when the model is initialized. GetPrefMode can be used to
    /// get which mode this model is in.
    /// </summary>
    public virtual int GetPrefMode()
    {
      return m_nPrefMode;
    }
    
    /// <summary>
    /// Returns the Admin Prefs URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetPrefsURL()
    {
      return m_strUserPrefsURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.plugins.IUserPrefsPluginModelRO#GetTemplatePrefsURL()"></seealso>
    public virtual String GetTemplatePrefsURL()
    {
      return m_strTemplateUserPrefsURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()"></seealso>
    public virtual String GetValidationFunction()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()"></seealso>
    public virtual void InitWSModel(IPTWebService ptWebService)
    {
      m_ptWebService = ptWebService;
      IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
      switch (m_nPrefMode){
      case UPPM_PREFMODE_USERPREFS:
      SetPrefsURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PREFSURL,
       m_strUserPrefsURL));
      break;
      case UPPM_PREFMODE_COMMUNITYPREFS:
      SetPrefsURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_COMMUNITYPREFSURL,
       m_strUserPrefsURL));
      break;
      case UPPM_PREFMODE_ADMINPREFS:
      SetPrefsURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_ADMINPREFSURL,
       m_strUserPrefsURL));
      SetTemplatePrefsURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_ADMINPREFSURL_TEMPLT,
       m_strTemplateUserPrefsURL));
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nValid = RepostControl.PAGE_STATUS_VALID;
      switch (m_nPrefMode){
      case UPPM_PREFMODE_COMMUNITYPREFS:
      SetPrefsURL(WSModelHelper.GetFormElementString(_htFormData, UserPrefsPluginView.HTMLINPUT_COMMUNITY_PREFS_URL,
       m_strUserPrefsURL));
      if ((null != m_strUserPrefsURL && !m_strUserPrefsURL.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strUserPrefsURL, m_asOwner,
         m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
      }
      break;
      case UPPM_PREFMODE_ADMINPREFS:
      SetPrefsURL(WSModelHelper.GetFormElementString(_htFormData, UserPrefsPluginView.HTMLINPUT_ADMIN_PREFS_URL,
       m_strUserPrefsURL));
      SetTemplatePrefsURL(WSModelHelper.GetFormElementString(_htFormData,
       UserPrefsPluginView.HTMLINPUT_TEMPLT_ADMIN_PREFS_URL, m_strTemplateUserPrefsURL));
      if ((null != m_strUserPrefsURL && !m_strUserPrefsURL.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strUserPrefsURL, m_asOwner,
         m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
      }
      if ((null != m_strTemplateUserPrefsURL && !m_strTemplateUserPrefsURL.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strTemplateUserPrefsURL,
         m_asOwner, m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
        }
      break;
      case UPPM_PREFMODE_USERPREFS:
      default:
      SetPrefsURL(WSModelHelper.GetFormElementString(_htFormData, UserPrefsPluginView.HTMLINPUT_USER_PREFS_URL,
       m_strUserPrefsURL));
      if ((null != m_strUserPrefsURL && !m_strUserPrefsURL.Equals("")) && (null == m_strBaseURL) || (m_strBaseURL.Length <= 0))
      {
        nValid = WSModelHelper.ValidateIsURLString(m_strUserPrefsURL, m_asOwner,
         m_asOwner.GetString(2625, "ptmsgs_portaladminmsgs"), nValid);
      }
      break;
      }
      return nValid;
    }
    
    /// <summary>
    /// This method specifies whether this model is used to set community
    /// preferences or user preferences. SetPrefMode can be used
    /// to set this when the model is initialized. GetPrefMode can be used to
    /// get which mode this model is in.
    /// </summary>
    public virtual void SetPrefMode(int nPrefMode)
    {
      m_nPrefMode = nPrefMode;
    }
    
    /// <summary>
    /// Sets the Admin Prefs URL
    /// </summary>
    /// <param name="strAdminPrefsURL">The Admin Prefs URL to set</param>
    public virtual void SetPrefsURL(String strPrefsURL)
    {
      this.m_strUserPrefsURL = strPrefsURL;
    }
    
    /// <summary>
    /// Sets the Template Admin Prefs URL
    /// </summary>
    /// <param name="strAdminPrefsURL">The Admin Prefs URL to set</param>
    public virtual void SetTemplatePrefsURL(String strPrefsURL)
    {
      this.m_strTemplateUserPrefsURL = strPrefsURL;
    }
  }
}