using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.xui
{
  /// <summary>
  /// This is the Display Page class for the XUI page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class XUIDP : EditorDP
  {
    
    /// <summary>
    /// Class Name for the Activity Space.
    /// </summary>
    private const String STR_MVC_CLASS_NAME = "XUI";
    
    /// <summary>
    /// ID of the XUI page printed out by this DP.
    /// </summary>
    private int m_nXUIPageID;
    
    /// <summary>
    /// ID of the XUI service within the Editor (support for multiple XUI services)
    /// </summary>
    private int m_nXUIIndex;
    
    /// <summary>
    /// Registered model name (support for multiple XUI services that need different model names)
    /// </summary>
    private String m_strModelName;
    
    /// <summary>
    /// Default Constructor.
    /// </summary>
    /// <param name="_nXUIPageID">ID of the XUI page printed out by this DP.</param>
    public XUIDP(int _nXUIPageID)
    {
      m_nXUIIndex = 0;
      m_nXUIPageID = _nXUIPageID;
      m_strModelName = XUIHelperModel.STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This constructor should be used to when multiple XUI
    /// services can exist within a single editor.
    /// The pagename will be in the format of 'XUI{XUIIndex}_{PageID}'.
    /// </summary>
    /// <param name="_nXUIIndex"></param>
    /// <param name="_nXUIPageID"></param>
    public XUIDP(int _nXUIIndex, int _nXUIPageID)
    {
      m_nXUIIndex = _nXUIIndex;
      m_nXUIPageID = _nXUIPageID;
      m_strModelName = XUIHelperModel.STR_MVC_CLASS_NAME + m_nXUIIndex;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      String sPageTitle;
      // Don't need to worry about XUI service index here, since the model is
      // for a given service.
      sPageTitle = ((IXUIHelperModelRO) m_asOwner.GetModel(m_strModelName)).GetPageTitle(m_nXUIPageID);
      return (sPageTitle);
    }
    
    /// <summary>
    /// Get the page ID
    /// </summary>
    /// <returns></returns>
    public virtual int GetPageID()
    {
      return m_nXUIPageID;
    }
    
    /// <summary>
    /// Returns the registered page name.
    /// If it's the 0th XUI service, the name is 'XUI{PageID}'.
    /// If it's not the 0th service, the name is 'XUI{XUIIndex}_{PageID}'.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      if (m_nXUIIndex == 0)
      {
        return STR_MVC_CLASS_NAME + m_nXUIPageID;
      } else
      {
        return STR_MVC_CLASS_NAME + m_nXUIIndex + "_" + m_nXUIPageID;
      }
    }
    
    /// <summary>
    /// Returns the HTML for the XUI page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      //JF- Add the Section for this XUI page.
      // The view name only contains the XUIIndex.  The view dynamically
      // shows page data for a given XUI service.
      if (m_nXUIIndex == 0)
      {
        views.AddInnerHTMLElement(((XUIView) m_asOwner.GetView(XUIView.STR_MVC_CLASS_NAME)).Display(m_nXUIPageID));
        } else
      {
        views.AddInnerHTMLElement(((XUIView) m_asOwner.GetView(XUIView.STR_MVC_CLASS_NAME + m_nXUIIndex)).Display(m_nXUIPageID));
        }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
  }
}