using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.xui;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.xui
{
  /// <summary>
  /// This is the Helper Model class for the XUI page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class XUIHelperModel : EditorHelperModel,IXUIHelperModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.xui.XUIHelperModel");
    
    /// <summary>
    /// Class Name for the Activity Space.
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "XUIHelper";
    
    /// <summary>
    /// Prefix for the XUI input param names.
    /// </summary>
    public const String XUI_INPUT_PREFIX = "XUI_";
    
    /// <summary>
    /// Integer type of value of the input.
    /// </summary>
    public const String XUI_INPUT_TYPE_INT = "integer";
    
    /// <summary>
    /// Boolean type of value of the input.
    /// </summary>
    public const String XUI_INPUT_TYPE_BOOLEAN = "boolean";
    
    /// <summary>
    /// XUI page not initialized.
    /// </summary>
    public const bool XUI_NOT_INITIALIZED = false;
    
    /// <summary>
    /// XUI page valid.
    /// </summary>
    public const bool XUI_PAGE_VALID = true;
    
    /// <summary>
    /// Property Bag of the Objects being created or edited.
    /// It contains all the settings set on the XUI pages.
    /// </summary>
    private IXPPropertyBag m_pbXUISettings;
    
    /// <summary>
    /// XUI Service object from the remote server.
    /// </summary>
    private IService m_xuiService;
    //	private int m_nServiceIndex;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new XUIHelperModel();
    }
    
    /// <summary>
    /// Finalizes and returns the property bag.
    /// Needs to be called at the end of the wizard, before we store the
    /// property bag in the object.
    /// </summary>
    /// <returns>IXPPropertyBag</returns>
    public virtual IXPPropertyBag GetFinalXUISettings()
    {
      // Bug 44211 - This new validation code added to Martok caused some issues, backing it out for now.
      //	Revisit in a future release. -jas
      //		for (int indPage = 1; indPage <= m_xuiService.GetPageCount(); indPage++)
      //		{
      //			if (!m_xuiService.Validate(indPage, m_pbXUISettings))
      //			{
      //				UIError myError = new UIError(UIErrorLevel.SERIOUS,
      //						UIErrorScope.CURRENT_USER, null, null,
      //						null);
      //							
      //				HTMLElementCollection myHTML = new HTMLElementCollection();
      //				HTMLSpan mySpan;
      //				HTMLAnchor myAnchor = null;
      //				
      //				mySpan = new HTMLSpan();
      //				myHTML.AddInnerHTMLElement(mySpan);
      //				mySpan.SetStyleClass(PTStyleClass.ALERT_SUBTITLE);
      //				mySpan.AddInnerHTMLString(m_asOwner.GetString(2635, "ptmsgs_portaladminmsgs"));
      //				
      //				String sPageName;
      //				EditorDP dpPage;
      //				
      //				if (m_nServiceIndex == 0)
      //				{
      //					sPageName = "XUI" + indPage;
      //				}
      //				else
      //				{
      //					sPageName = "XUI" + m_nServiceIndex + "_" + indPage;
      //				}
      //
      //				dpPage = (EditorDP) m_asOwner.GetPage(sPageName);
      //					
      //				myHTML.AddInnerHTMLElement(new HTMLBr());
      //				myHTML.AddInnerHTMLString("&bull;");
      //				myHTML.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      //				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      //				myAnchor.SetOnClick("goToPage('" + m_asOwner.GetName() +
      //					"', '" + sPageName + "',''); return false;");
      //				myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(dpPage.GetLeftNavString()));
      //				myHTML.AddInnerHTMLElement(myAnchor);
      //					
      //				myError.SetHTMLMessage(myHTML);			
      //				
      //				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), 
      //					m_asOwner.GetApplication());
      //
      //			}
      //		}
      m_xuiService.Finalize(m_pbXUISettings);
      return (m_pbXUISettings);
    }
    
    /// <summary>
    /// Returns the HTML for the XUI page.
    /// </summary>
    /// <param name="_nXUIPageID">ID of the page to return the HTML for.</param>
    /// <returns>String</returns>
    public virtual String GetHTMLForXUIPage(int _nXUIPageID)
    {
      String sHTML;
      Object[][] xuiParam = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        xuiParam[j2c_index] = new Object[1];
      }
      xuiParam[0][0] = "gp_sRelativeImageServerBaseURL";
      xuiParam[1][0] = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
      // aj: IServiceContent contains either:
      //	a) a String that represents a transformed SCI page
      //	b) a markup fragment array that needs to be passed through the taglib stuff
      IServiceContent pXUIContent = m_xuiService.GetContent(_nXUIPageID, m_pbXUISettings,
       xuiParam);
      if (pXUIContent.ContentIsMarkupArray())
      {
        HTMLDiv myDiv = new HTMLDiv();
        IPTState objAppDataObject = AppDataObject.GetAppDataObject(0, 0, PTConfigHelper.GetApplicationBaseURL(m_asOwner),
         m_asOwner);
        Object[][] arrMarkup = pXUIContent.GetMarkupFragment(objAppDataObject);
        myDiv.AddInnerHTMLElement(GatewayUtils.AddMarkupToSingleElement(m_asOwner,
         arrMarkup));
        sHTML = myDiv.GetDisplayString();
      } else
      {
        // aj: simple XUI content, ah the good old days
        sHTML = pXUIContent.GetXUIPage();
      }
      return sHTML;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the XUI page instructions.
    /// </summary>
    /// <param name="_nXUIPageID">ID of the page to return the instructions for.</param>
    /// <returns>String</returns>
    public virtual String GetPageInstructions(int _nXUIPageID)
    {
      return m_xuiService.GetWizardPageInstructions(_nXUIPageID);
    }
    
    /// <summary>
    /// Returns the XUI page title.
    /// </summary>
    /// <param name="_nXUIPageID">ID of the page to return the title for.</param>
    /// <returns>String</returns>
    public virtual String GetPageTitle(int _nXUIPageID)
    {
      return m_xuiService.GetWizardPageTitle(_nXUIPageID);
    }
    
    /// <summary>
    /// Returns the XUI page help page name.
    /// </summary>
    /// <param name="_nXUIPageID">ID of the page to return the help for.</param>
    /// <returns>String</returns>
    public virtual String GetHelpFileName(int _nXUIPageID)
    {
      if (null == m_xuiService)
      {
        return "PT_Submit_RemoteDocument_MainSettings";
      } else
      {
        return m_xuiService.GetWizardPageHelp(_nXUIPageID);
      }
    }
    
    /// <summary>
    /// Inits the XUI helper model.
    /// </summary>
    /// <param name="_pbXUISettings">PropertyBag to store the XUI settings</param>
    /// <param name="_xuiService">XUI Service on the remote server</param>
    public virtual void InitializeXUIHelperModel(IXPPropertyBag _pbXUISettings,
     IService _xuiService)
    {
      m_pbXUISettings = _pbXUISettings;
      m_xuiService = _xuiService;
      //		m_nServiceIndex		= 0;
      if (XUI_NOT_INITIALIZED == m_xuiService.GetInitialized())
      {
        m_xuiService.Initialize(m_pbXUISettings, XUIHelperMethods.XUI_TIMEOUT_IN_SECONDS);
        }
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nXUIPageID = -1;
      if (_htFormData.ContainsKey(XUIView.HTMLHIDDEN_XUI_PAGEID))
      {
        // JF- Retrieve the ID of the page that has just been posted.
        String[] data = (String[]) _htFormData.GetElement(XUIView.HTMLHIDDEN_XUI_PAGEID);
        try
        {
          nXUIPageID = XPConvert.ToInteger(data[0]);
          // JF- Save the settings posted by the form.
          UpdateXUISettings(_htFormData);
          int nRepostAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
          try
          {
            // JF- Get the Repost control and the repost action
            EditorRepostControl myControl = (EditorRepostControl) m_asOwner.GetControl(((AFormAS) m_asOwner).GetRepostControlName());
            nRepostAction = myControl.GetRepostAction();
          }
          catch (Exception e)
          {
            log.Error("XUIHelperModel::SaveSection The following exception " + "happened when trying to retrieve the Editor Repost Control:" + e);
            }
          if ((RepostControl.POSTTOSELF_ACTION_GOTOPAGE == nRepostAction) || (RepostControl.POSTTOSELF_ACTION_FINISH == nRepostAction) || (RepostControl.POSTTOSELF_ACTION_APPLY_CHANGES == nRepostAction))
          {
            if (XUI_PAGE_VALID == m_xuiService.Validate(nXUIPageID, m_pbXUISettings))
            {
              return (RepostControl.PAGE_STATUS_VALID);
            } else
            {
              return (RepostControl.PAGE_STATUS_INVALID);
            }
          }
        }
        catch (Exception e)
        {
          log.Error("XUIHelperModel::SaveSection Unable to save the XUI page with ID: " + data + ". The following exception happened: " + e);
          return (RepostControl.PAGE_STATUS_INVALID);
        }
      }
      return (RepostControl.PAGE_STATUS_VALID);
    }
    
    /// <summary>
    /// Saves the XUI settings posted by the form into the PropertyBag.
    /// </summary>
    /// <param name="_htFormData"></param>
    private void UpdateXUISettings(XPHashtable _htFormData)
    {
      String sKey;
      String[] aData;
      int nNextSeparatorIndex;
      String sXUIInputType;
      String sXUIInputName;
      IXPEnumerator keys = _htFormData.GetKeys();
      while (keys.MoveNext())
      {
        sKey = (String) keys.GetCurrent();
        if (XPStringUtility.StartsWith(sKey, XUI_INPUT_PREFIX))
        {
          try
          {
            aData = (String[]) _htFormData.GetElement(sKey);
            nNextSeparatorIndex = XPStringUtility.IndexOf(sKey, "_", XUI_INPUT_PREFIX.Length);
            sXUIInputType = XPStringUtility.Substring(sKey, XUI_INPUT_PREFIX.Length,
             nNextSeparatorIndex);
            sXUIInputName = XPStringUtility.Substring(sKey, nNextSeparatorIndex + 1);
            if (XPStringUtility.EqualsIgnoreCase(XUI_INPUT_TYPE_INT, sXUIInputType))
            {
              if ((null != aData[0]) && (0 != aData[0].Length))
              {
                m_pbXUISettings.Write(sXUIInputName, XPConvert.ToInteger(aData[0]));
                }
            } else
            if (XPStringUtility.EqualsIgnoreCase(XUI_INPUT_TYPE_BOOLEAN, sXUIInputType))
            {
              if (_htFormData.ContainsKey("TRUE_" + sXUIInputName))
              {
                aData = (String[]) _htFormData.GetElement("TRUE_" + sXUIInputName);
                m_pbXUISettings.Write(sXUIInputName, XPConvert.ToInteger(aData[0]));
                } else
              {
                m_pbXUISettings.Write(sXUIInputName, XPConvert.ToInteger(aData[0]));
                }
            } else
            {
              m_pbXUISettings.Write(sXUIInputName, aData[0]);
            }
          }
          catch (Exception e)
          {
            log.Error("XUIHelperModel::UpdateXUISettings The following exception " + "happened when trying to set the data with key: " + sKey + "." + e);
            }
        }
      }
    }
    
    /// <summary>
    /// If there are multiple XUI services for the editor,
    /// set the index for this model.
    /// </summary>
    /// <param name="_nIndex"></param>
    public virtual void SetServiceIndex(int _nIndex)
    {
    }
  }
}
//		m_nServiceIndex = _nIndex;
