using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.editors.xui
{
  /// <summary>
  /// This is the Section class for the XUI page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class XUIView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.editors.xui.XUIView");
    
    /// <summary>
    /// Class Name for the Activity Space.
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "XUI";
    
    /// <summary>
    /// Input name: hidden input for the XUI page ID 
    /// </summary>
    public const String HTMLHIDDEN_XUI_PAGEID = "in_hi_XUIPageID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new XUIView();
    }
    
    /// <summary>
    /// This method is not used here. Use Display(int _nXUIPageID) instead.
    /// </summary>
    /// <returns>null</returns>
    public override HTMLElement Display()
    {
      // not used
      log.Error("XUIView::Display Do NOT use this method. Use Display(int _nXUIPageID) instead.");
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the page identified by the ID in argument.
    /// </summary>
    /// <param name="_nXUIPageID"></param>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement Display(int _nXUIPageID)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      IXUIHelperModelRO myModel = (IXUIHelperModelRO) m_model;
      try
      {
        // JF- Section header
        result.AddInnerHTMLElement(base.GetHeaderView(myModel.GetPageTitle(_nXUIPageID)));
        result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        // JF- Table with instructions
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLString(myModel.GetPageInstructions(_nXUIPageID));
        // JF- Content table
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // JF- Get the HTML from the remote server and print it out.
        myCell.AddInnerHTMLString(myModel.GetHTMLForXUIPage(_nXUIPageID));
        // JF- Add the page ID as a hidden input.
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_XUI_PAGEID,
         "");
        myInput.SetValue(XPConvert.ToString(_nXUIPageID));
        myCell.AddInnerHTMLElement(myInput);
      }
      catch (Exception e)
      {
        log.Error(e, "XUIView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1198, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}