using System;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.httpmemorydebugging
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the HTTPMemoryDebug AS.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class HTTPMemoryDebugAS : PlumtreeAS
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MemoryDebug";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // DCA - call super's to check for change in navigational scheme
      base.CheckBasicAccess(strPage, strControl, bSameSpace);
      // JF- Only Sys Admins can access this page
      return PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession());
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new HTTPMemoryDebugAS();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the name of the repost control class.
    /// E.g.: PropRepostControl.GetName()
    /// </summary>
    /// <seealso cref="com.plumtree.xpshared.form.IRepostAS#GetRepostControlName()"></seealso>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      // This method is not really implemented, because this is a sample
      // form that will not be able to be submitted.
      return HTTPMemoryDebugRepostControl.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      // Model
      RegisterModel(HTTPMemoryDebugModel.STR_MVC_CLASS_NAME);
      IModel myModel = GetModel(HTTPMemoryDebugModel.STR_MVC_CLASS_NAME);
      // Display Page
      HTTPMemoryDebugDP myPage = new HTTPMemoryDebugDP();
      // set multipart encoding so that file uploads work correctly.
      myPage.SetMultiPartEncoding(true);
      myPage.SetAddMainForm(true);
      RegisterPage(myPage);
      VarPackContentDP myPopUpPage = new VarPackContentDP();
      RegisterPage(myPopUpPage);
      // View
      RegisterView(HTTPMemoryDebugView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(VarPackContentView.STR_MVC_CLASS_NAME, myModel);
      // Repost Controls
      RegisterControl(HTTPMemoryDebugRepostControl.STR_MVC_CLASS_NAME, myModel);
      }
  }
}