using System;
using com.plumtree.openfoundation.io;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.admin.httpmemorydebugging
{
  /// <summary>
  /// This is the Model class for the HTTPMemoryDebug AS. 
  /// It replements the reload Var Pack feature.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class HTTPMemoryDebugModel : IRepostModel,IVarPackModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.httpmemorydebugging.HTTPMemoryDebugModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "HTTPMemoryDebug";
    
    /// <summary>
    /// Associated  Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// ID of the var pack to reload 
    /// </summary>
    private String m_sReloadVarPackID;
    
    /// <summary>
    /// ID of the var pack to view 
    /// </summary>
    private String m_sViewContentVarPackID;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.varpack.IVarPackModelRO#GetCurrentVarPackID()"></seealso>
    public virtual String GetCurrentVarPackID()
    {
      return m_sViewContentVarPackID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.varpack.IVarPackModelRO#GetAllowVarPackReload()"></seealso>
    public virtual bool GetAllowVarPackReload()
    {
      return true;
    }
    
    /// <summary>
    /// Method reloading the var pack.
    /// </summary>
    public virtual void ReloadVarPack()
    {
      if ((null != m_sReloadVarPackID) && !("").Equals(m_sReloadVarPackID))
      {
        // JF- Get the VarPack
        IVarPack myVarPack = m_asOwner.GetApplication().GetVarPackManager().GetVariablePackage(m_sReloadVarPackID);
        // JF- Make sure we can reload it
        if ((null != myVarPack) && myVarPack.CanReloadVarPackFromUI())
        {
          myVarPack.ReloadVarPack();
        } else
        {
          log.Error("HTTPMemoryDebugModel::ReloadVarPack Couldn\'t reload Var Pack with key: " + m_sReloadVarPackID);
          }
        // JF- We are done. We reset the VarPack ID.
        m_sReloadVarPackID = null;
      }
    }
    
    /// <summary>
    /// Method to clear the AS cache.
    /// </summary>
    public virtual void ClearCache()
    {
      ASCache myCache = (ASCache) m_asOwner.GetSubSession().GetAttribute(ASConstants.SANDBOXASCACHE);
      myCache.ClearCache();
    }
    
    /// <summary>
    /// Method to reload custom.
    /// </summary>
    public virtual void ReloadDynamicLoads(IXPRequest request)
    {
      try
      {
        String strRemoteFile = request.GetRemoteFilePath();
        XPFile remoteFile = new XPFile(strRemoteFile);
        String strFileName = remoteFile.GetName();
        remoteFile = null;
        String strDynamicLoadsPath = AppWarmUp.GetSettingValueAsString(AppWarmUp.KEY_PATH_PORTAL_DYNAMIC_LOADS);
        XPFile replaceFile = new XPFile(strDynamicLoadsPath + strFileName);
        if (replaceFile.Exists())
        {
          replaceFile.Delete();
        }
        replaceFile = null;
        // we need to check this otherwise we lose our file!
        request.Save(strDynamicLoadsPath);
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error saving file.");
      }
    }
    // Bug#44025
    // Commented out because refactoring broke the build.
    //		AppWarmUp.LoadDynamicLoads();
    
    /// <summary>
    /// Method to clear unused memory.
    /// </summary>
    public virtual void ClearMemory()
    {
      XPSystem.GarbageCollect();
    }
    
    /// <summary>
    /// Method to clear unused memory and caches.
    /// </summary>
    public virtual void ClearMemoryAndCaches()
    {
      // Clear the my pages cache
      try
      {
        ((IPTSession) m_asOwner.GetUserSession()).GetMyPages().FlushMandatoryGadgetsCache();
        ((IPTCommunityManager) ((IPTSession) m_asOwner.GetUserSession()).GetCommunities()).FlushMandatoryTabsCache();
        }
      catch (Exception e)
      {
      }
      // Do nothing if cache clearing fails.
      // Clear all the other C++ caches (PTCache caches, etc.)
      try
      {
        // Pass in secret cache clearing key
        ((IPTSession) m_asOwner.GetUserSession()).GetCommunities().ClearData(-19760313);
        }
      catch (Exception e)
      {
      }
      // Do nothing if cache clearing fails
      // Garbage collect AFTER having cleared the caches
      ClearMemory();
    }
    
    /// <summary>
    /// Method reloading the current viewed var pack.
    /// </summary>
    public virtual void ReloadCurrentViewedVarPack()
    {
      m_sReloadVarPackID = m_sViewContentVarPackID;
      ReloadVarPack();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new HTTPMemoryDebugModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public virtual void Finish()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = (AActivitySpace) parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    /// <returns>int Page status for server side validation</returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      String[] data;
      if (_sPageName.Equals(HTTPMemoryDebugDP.STR_MVC_CLASS_NAME))
      {
        data = (String[]) _htFormData.GetElement(HTTPMemoryDebugView.HTMLHIDDEN_RELOAD_VARPACK_ID);
        if ((null != data) && !(0 == data.Length))
        {
          m_sReloadVarPackID = data[0];
        }
      }
      if (_sPageName.Equals(VarPackContentDP.STR_MVC_CLASS_NAME))
      {
        data = (String[]) _htFormData.GetElement(ViewVarPackControl.HTMLHIDDEN_VIEW_VARPACK_ID);
        if ((null != data) && !(0 == data.Length))
        {
          m_sViewContentVarPackID = data[0];
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual int ClearAdaptiveTagCache()
    {
      Object oMap = m_asOwner.GetApplication().GetCachingManager().GetEntry(TagState.CACHE_LIB + "." + TagState.CACHE_MAPENTRY_NAME);
      if (oMap != null)
      {
        XPHashtable cacheMap = (XPHashtable) oMap;
        cacheMap.Clear();
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}