using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.pei;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags.helper;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.httpmemorydebugging
{
  /// <summary>
  /// This View contains the HTML for the Memory debugging page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class HTTPMemoryDebugView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.httpmemorydebugging.HTTPMemoryDebugView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "HTTPMemoryDebug";
    
    /// <summary>
    /// Associated  Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// HTML Object: Reloading Dynamic Loads 
    /// </summary>
    public const String HTMLBUTTON_RELOAD_DYNAMIC_LOADS = "in_bu_Reload_Dynamic_Loads";
    
    /// <summary>
    /// HTML Object: Reloading Dynamic Loads 
    /// </summary>
    public const String HTMLFILE_RELOAD_DYNAMIC_LOADS = "in_fi_Reload_Dynamic_Loads";
    
    /// <summary>
    /// HTML Object: clear cache button 
    /// </summary>
    public const String HTMLBUTTON_CLEAR = "in_bu_Clear";
    
    /// <summary>
    /// HTML Object: Clear unused memory button 
    /// </summary>
    public const String HTMLBUTTON_CLEAR_MEMORY = "in_bu_ClearUnusedMemory";
    
    /// <summary>
    /// HTML Object: Clear unused memory and caches button 
    /// </summary>
    public const String HTMLBUTTON_CLEAR_MEMORY_AND_CACHES = "in_bu_ClearUnusedMemoryAndCaches";
    
    /// <summary>
    /// HTML Object: Clear Tag Cache 
    /// </summary>
    public const String HTMLBUTTON_CLEAR_TAGCACHE = "in_bu_ClearTagCache";
    
    /// <summary>
    /// HTML Object: hidden input for var pack ID to reload 
    /// </summary>
    public const String HTMLHIDDEN_RELOAD_VARPACK_ID = "in_hi_ReloadVarPackID";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new HTTPMemoryDebugView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement myResult = new HTMLElementCollection();
      try
      {
        ///////////////////////////////
        /// SECTION: PORTAL VERSION ///
        ///////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(2151,
         "ptmsgs_portaladminmsgs"), null, null));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForPortalVersion());
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying portal version.");
        }
        //////////////////////////////////////
        /// SECTION: RELOAD DYNAMIC LOADS  ///
        //////////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner("Reload Dynamic Loads",
         null, null));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForReloadDynamicLoads());
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying reload dynamic loads.");
        }
        ////////////////////////////////////
        /// SECTION: APPLICATION CONTENT ///
        ////////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(1961,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1962, "ptmsgs_portaladminmsgs"),
         null));
        try
        {
          // false means display PEIs and other objects.
          myResult.AddInnerHTMLElement(PEIView.GetHTMLForApplicationSection(m_asOwner,
           false));
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying application content.");
        }
        ////////////////////////////////
        /// SECTION: VARPACK CONTENT ///
        ////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(1963,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1964, "ptmsgs_portaladminmsgs"),
         null));
        try
        {
          // JF- Hidden input for the var pack ID to reload
          HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_RELOAD_VARPACK_ID,
           "");
          myResult.AddInnerHTMLElement(myInput);
          myInput.SetValue("");
          // Allow reloading of varpacks.
          myResult.AddInnerHTMLElement(VarPackView.GetHTMLForVarPackSection(m_asOwner,
           true));
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying varpack content.");
        }
        ////////////////////////////////
        /// SECTION: SESSION CONTENT ///
        ////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(1965,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1966, "ptmsgs_portaladminmsgs"),
         null));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForSessionSection(false));
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying session content.");
        }
        ///////////////////////////////////////////
        /// SECTION: PERSISTENT SESSION CONTENT ///
        ///////////////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(2697,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2698, "ptmsgs_portaladminmsgs"),
         null));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForSessionSection(true));
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying persistent session content.");
        }
        /////////////////////////////////////////////////////
        /// SECTION: SESSION ACTIVITY SPACE CACHE CONTENT ///
        /////////////////////////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(1967,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1968, "ptmsgs_portaladminmsgs"),
         m_asOwner.GetString(2678, "ptmsgs_portaladminmsgs")));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForASCacheSection());
        }
        catch (Exception e)
        {
          log.Error(e, "Error displaying session activity space cache content.");
          }
        ///////////////////////////////////////
        /// SECTION: MEMORY OPTIONS CONTENT ///
        ///////////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner(m_asOwner.GetString(2531,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2532, "ptmsgs_portaladminmsgs"),
         null));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForMemoryOptionsSection());
          }
        catch (Exception e)
        {
          log.Error(e, "Error displaying memory options content.");
        }
        ///////////////////////////////////
        /// SECTION: PAGE CONTROLS LIST ///
        ///////////////////////////////////
        myResult.AddInnerHTMLElement(GetHTMLForSectionBanner("List of Page Controls",
         "Here is the list of page controls loaded in memory.", null));
        try
        {
          myResult.AddInnerHTMLElement(GetHTMLForPageControlListSection());
          }
        catch (Exception e)
        {
          log.Error(e, "Error displaying page controls content.");
        }
      }
      catch (HTMLException he)
      {
        throw new XPException("Error displaying HTTPMemoryDebugView.", he);
        }
      return myResult;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the reloading section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetHTMLForReloadDynamicLoads()
    {
      HTMLElement myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      myTable = new HTMLTable();
      myTable.SetBorder("0");
      myTable.SetCellPadding("3");
      myTable.SetCellSpacing("0");
      myResult.AddInnerHTMLElement(myTable);
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myInput = new HTMLInput(HTMLInputTypes.FILE, HTMLFILE_RELOAD_DYNAMIC_LOADS,
       "");
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      myInput.SetSize(50);
      myCell.AddInnerHTMLElement(myInput);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_RELOAD_DYNAMIC_LOADS,
       "");
      myInput.SetValue("Reload Dynamic Loads");
      myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
      myInput.SetOnClick("ReloadDynamicLoads(); return false;");
      myCell.AddInnerHTMLElement(myInput);
      return myResult;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the Portal Version section.
    /// </summary>
    /// <returns>HTMLTable</returns>
    private HTMLTable GetHTMLForPortalVersion()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      myTable = new HTMLTable();
      myTable.SetBorder("0");
      myTable.SetWidth("100%");
      myTable.SetCellPadding("3");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      String sVersion = ((IPTSession) m_asOwner.GetUserSession()).GetVersion();
      mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(2150,
       "ptmsgs_portaladminmsgs"), sVersion));
      return myTable;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the banner and the description banner to separate each section.
    /// </summary>
    /// <param name="_sTitle"></param>
    /// <param name="_sSubTitle"></param>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetHTMLForSectionBanner(String _sTitle, String _sSubTitle,
     String _sDescription)
    {
      HTMLElement myResult = new HTMLElementCollection();
      PTConstruct cTitleBanner;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      myResult.AddInnerHTMLElement(new HTMLBr());
      myResult.AddInnerHTMLElement(new HTMLBr());
      // JF- Get the construct for the title banner
      cTitleBanner = UIConstructFactory.GetConstruct(PTBannerType.WIDE);
      cTitleBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE.TITLE_ELEMENT_NAME,
       _sTitle);
      myResult.AddInnerHTMLElement(cTitleBanner.GetHTMLElement());
      if (null != _sSubTitle)
      {
        // JF- Create the table for the sub banner (description text)
        myTable = new HTMLTable();
        myResult.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("3");
        myTable.SetCellSpacing("0");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        // display sub header message
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan.AddInnerHTMLString(_sSubTitle);
        if (null != _sDescription)
        {
          mySpan.AddInnerHTMLElement(new HTMLBr());
          mySpan.AddInnerHTMLElement(new HTMLBr());
          mySpan.AddInnerHTMLString(_sDescription);
        }
      }
      return myResult;
    }
    
    /// <summary>
    /// displays the names of the pagecontrols
    /// </summary>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetHTMLForPageControlListSection()
    {
      XPHashtable myPageControlTable;
      IXPEnumerator myPageControlEnumerator;
      HTMLBr myBr;
      HTMLElement myResult = new HTMLElementCollection();
      myBr = new HTMLBr();
      myPageControlTable = ASManager.INSTANCE.GetPageControlTable();
      myPageControlEnumerator = myPageControlTable.GetKeys();
      // print out all the keys in the page control table
      HTMLTable table = TaskAPIUIHTML.CreateTable(myResult, 0, 3, "100%");
      while (myPageControlEnumerator.MoveNext())
      {
        HTMLTableRow row = TaskAPIUIHTML.CreateTableRow(table, "");
        HTMLTableCell cell = TaskAPIUIHTML.CreateTableCell(row, "objectText");
        cell.AddInnerHTMLString(" - " + (String) myPageControlEnumerator.GetCurrent());
        }
      //			myResult.AddInnerHTMLString((String)myPageControlEnumerator.GetCurrent());
      //			myResult.AddInnerHTMLElement(myBr);
      //			myResult.AddInnerHTMLElement(myBr);
      return myResult;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the Session section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetHTMLForSessionSection(bool bShowPersistent)
    {
      HTMLElement myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLB myBold;
      IXPEnumerator sKeys;
      if (bShowPersistent)
      {
        sKeys = m_asOwner.GetPersistentSubSession().GetKeys();
      } else
      {
        sKeys = m_asOwner.GetSubSession().GetKeys();
      }
      int i = 0;
      myTable = new HTMLTable();
      myResult.AddInnerHTMLElement(myTable);
      myTable.SetBorder("0");
      myTable.SetCellPadding("3");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(m_asOwner.GetString(1969, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(m_asOwner.GetString(1970, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(m_asOwner.GetString(1971, "ptmsgs_portaladminmsgs"));
      Object oAttribute;
      while (sKeys.MoveNext())
      {
        try
        {
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(XPConvert.ToString(i));
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLEncodedString((String) sKeys.GetCurrent());
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          oAttribute = m_asOwner.GetSubSession().GetAttribute((String) sKeys.GetCurrent());
          if (oAttribute != null)
          {
            myCell.AddInnerHTMLEncodedString(XPConvert.ToString(oAttribute));
            }
        }
        catch (Exception e)
        {
          log.Error(e, "Unexpected exception when displaying session item.");
          }
        i++;
      }
      return myResult;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the ASCache section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetHTMLForASCacheSection()
    {
      HTMLElement myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLTable myNestedTable;
      HTMLTableRow myNestedRow;
      HTMLTableCell myNestedCell;
      HTMLB myBold;
      HTMLInput myInput;
      ASCache myCache = (ASCache) m_asOwner.GetSubSession().GetAttribute(ASConstants.SANDBOXASCACHE);
      IXPEnumerator asKeys = myCache.GetKeys();
      myTable = new HTMLTable();
      myResult.AddInnerHTMLElement(myTable);
      myTable.SetBorder("0");
      myTable.SetCellPadding("3");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetColSpan("3");
      myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLEAR, "");
      myInput.SetValue(m_asOwner.GetString(2149, "ptmsgs_portaladminmsgs"));
      myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
      myInput.SetOnClick("ConfirmClearCache();");
      myCell.AddInnerHTMLElement(myInput);
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(m_asOwner.GetString(1969, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(m_asOwner.GetString(1972, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(m_asOwner.GetString(1973, "ptmsgs_portaladminmsgs"));
      while (asKeys.MoveNext())
      {
        try
        {
          AActivitySpace mySpace = (AActivitySpace) myCache.GetAttribute((String) asKeys.GetCurrent());
          IXPEnumerator subASKeys = mySpace.GetSubSpacesEnumerator();
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(mySpace.GetSpaceID());
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          if (null != mySpace.GetSubSpaceKey())
          {
            // This is a sub-space
            Object[] args = {mySpace.GetName()};
            // name (subspace)
            myCell.AddInnerHTMLEncodedString(XPFormat.Format(m_asOwner.GetString(2669,
             "ptmsgs_portaladminmsgs"), args));
          } else
          {
            // This is a main space
            myCell.AddInnerHTMLEncodedString(mySpace.GetName());
          }
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myNestedTable = new HTMLTable();
          myCell.AddInnerHTMLElement(myNestedTable);
          myNestedTable.SetBorder("0");
          myNestedTable.SetCellPadding("3");
          myNestedTable.SetCellSpacing("0");
          int k = 0;
          AActivitySpace subSpace;
          while (subASKeys.MoveNext())
          {
            subSpace = (AActivitySpace) subASKeys.GetCurrent();
            myNestedRow = new HTMLTableRow();
            myNestedTable.AddInnerHTMLElement(myNestedRow);
            myNestedCell = new HTMLTableCell();
            myNestedCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myNestedRow.AddInnerHTMLElement(myNestedCell);
            myNestedCell.AddInnerHTMLString(subSpace.GetSpaceID());
            myNestedCell = new HTMLTableCell();
            myNestedCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myNestedRow.AddInnerHTMLElement(myNestedCell);
            myNestedCell.AddInnerHTMLEncodedString(subSpace.GetName());
            k++;
          }
          if (0 == k)
          {
            // There were no subspaces
            myNestedRow = new HTMLTableRow();
            myNestedTable.AddInnerHTMLElement(myNestedRow);
            myNestedCell = new HTMLTableCell();
            myNestedCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myNestedRow.AddInnerHTMLElement(myNestedCell);
            myNestedCell.SetVAlign(CommonHTMLStrings.TOP);
            myNestedCell.AddInnerHTMLString(m_asOwner.GetString(1976, "ptmsgs_portaladminmsgs"));
            }
        }
        catch (Exception e)
        {
          log.Error(e, "Unexpected exception when displaying cache item.");
          }
      }
      return myResult;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the Memory Options section.
    /// </summary>
    /// <returns>HTMLTable</returns>
    private HTMLTable GetHTMLForMemoryOptionsSection()
    {
      HTMLTable table = TaskAPIUIHTML.CreateTable(null, 0, 3, "100%");
      HTMLTableRow row = TaskAPIUIHTML.CreateTableRow(table, "");
      HTMLTableCell cell = TaskAPIUIHTML.CreateTableCell(row, "");
      HTMLInput input;
      input = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLEAR_MEMORY,
       "");
      input.SetValue(m_asOwner.GetString(2534, "ptmsgs_portaladminmsgs"));
      input.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
      input.SetOnClick("ConfirmClearUnusedMemory();");
      cell.AddInnerHTMLElement(input);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      input = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLEAR_MEMORY_AND_CACHES,
       "");
      input.SetValue(m_asOwner.GetString(2535, "ptmsgs_portaladminmsgs"));
      input.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
      input.SetOnClick("ConfirmClearCache();");
      cell.AddInnerHTMLElement(input);
      // spacer row
      row = TaskAPIUIHTML.CreateTableRow(table, "");
      cell = TaskAPIUIHTML.CreateTableCell(row, "");
      cell.AddInnerHTMLString("&nbsp");
      // tag data cache 
      row = TaskAPIUIHTML.CreateTableRow(table, "");
      cell = TaskAPIUIHTML.CreateTableCell(row, "");
      Object oMap = m_asOwner.GetApplication().GetCachingManager().GetEntry(TagState.CACHE_LIB + "." + TagState.CACHE_MAPENTRY_NAME);
      if (oMap == null)
      {
        // "There are no Adaptive Tag Data entries cache in the Application scope."
        cell.AddInnerHTMLString(m_asOwner.GetString(3278, ResourceConstants.PORTALADMINMSGS));
        } else
      {
        XPHashtable cacheMap = (XPHashtable) oMap;
        cell.AddInnerHTMLString(m_asOwner.GetString(3279, ResourceConstants.PORTALADMINMSGS) + ": " + cacheMap.GetSize());
        row = TaskAPIUIHTML.CreateTableRow(table, "");
        cell = TaskAPIUIHTML.CreateTableCell(row, "");
        // button to clear 
        input = TaskAPIUIHTML.CreateInputToCell(cell, HTMLInputTypes.BUTTON_TYPE,
         HTMLBUTTON_CLEAR_TAGCACHE, "");
        input.SetValue(m_asOwner.GetString(3280, ResourceConstants.PORTALADMINMSGS));
        input.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        input.SetOnClick("ConfirmClearTagCache();");
      }
      return table;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript;
      // The URL to open the view var pack pop-up
      ASURL myPopUp = new ASURL(m_asOwner);
      myPopUp.SetLinkGetCachedSpace(m_asOwner);
      myPopUp.SetDisplayPage(VarPackContentDP.STR_MVC_CLASS_NAME);
      myPopUp.SetControl(HTTPMemoryDebugRepostControl.STR_MVC_CLASS_NAME);
      myPopUp.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF, XPConvert.ToString(HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_VIEW_VARPACK));
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        myScript = new HTMLScript("text/javaScript");
        // JS for reloading VarPacks
        sb.Append("function ReloadVarPack(varPackID)\n");
        sb.Append("{\n");
        sb.Append("    document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_RELOAD_VARPACK_ID + ".value = varPackID;\n");
        sb.Append("    postToSelf(" + HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_RELOAD_VARPACK + ");\n");
        sb.Append("}\n");
        // JS for viewing VarPacks
        sb.Append(VarPackView.GetJSForVarPackSection(myPopUp.GetURLAsString()));
        // Clearing AS cache
        sb.Append("function ConfirmClearCache()\n");
        sb.Append("{\n");
        sb.Append("  if (confirm(\"" + m_asOwner.GetString(2162, "ptmsgs_portaladminmsgs") + "\"))\n");
        sb.Append("  {\n");
        sb.Append("    postToSelf(" + HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_CLEAR_CACHE + ");\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("function ConfirmClearUnusedMemory()\n");
        sb.Append("{\n");
        sb.Append("  if (confirm(\"" + m_asOwner.GetString(2533, "ptmsgs_portaladminmsgs") + "\"))\n");
        sb.Append("  {\n");
        sb.Append("    postToSelf(" + HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_CLEAR_MEMORY + ");\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("function ReloadDynamicLoads()\n");
        sb.Append("{\n");
        sb.Append("    if (\"\" == document." + HTTPMemoryDebugDP.HTMLFORM_NAME + "." + HTMLFILE_RELOAD_DYNAMIC_LOADS + ".value)\n");
        sb.Append("    {\n");
        //Enter a file name to upload
        sb.Append("        alert(\"" + m_asOwner.GetString(2520, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("        return false;\n");
        sb.Append("    }\n");
        sb.Append("    postToSelf(" + HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_RELOAD_DYNAMIC_LOADS + ");\n");
        sb.Append("}\n");
        // Clearing AS cache
        sb.Append("function ConfirmClearTagCache()\n");
        sb.Append("{\n");
        sb.Append("  if (confirm(\"" + m_asOwner.GetString(3281, ResourceConstants.PORTALADMINMSGS) + "\"))\n");
        sb.Append("  {\n");
        sb.Append("    postToSelf(" + HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_CLEAR_TAGCACHE + ");\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        throw XPException.GetInstance(e);
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = (AActivitySpace) parent;
    }
  }
}