using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.migrationhistory
{
  /// <summary>
  /// Model for the migration history of a single PTObject.
  /// </summary>
  /// <author>arvinds</author>
  public class MigrationHistoryModel : EditorModel,IMigrationHistoryModel,
  IMigrationHistoryModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.migrationhistory.MigrationHistoryModel");
    public const String STR_MVC_CLASS_NAME = "MigrationHistory";
    private XPArrayList m_arrList;
    private int m_nCurrentMigrationStatus;
    private bool m_bApprovedForMigration;
    public MigrationHistoryModel() : base()
    {
      m_arrList = new XPArrayList();
    }
    
    /// <summary>
    /// Modifies the object name on repost.
    /// </summary>
    public virtual void ActionOnRepost()
    {
    }
    //////////////////////////////////////////////////
    //					EditorModel methods
    /////////////////////////////////////////////////    
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      String[] asClassID = (String[]) _htFormData.GetElement(ObjEditorModel.EDITOR_QS_INT_CLASS_ID);
      String[] asObjectID = (String[]) _htFormData.GetElement(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID);
      if ((null == asClassID) || (null == asObjectID) || (0 == asClassID.Length) || (0 == asObjectID.Length) || (null == asClassID[0]) || (null == asObjectID[0]))
      {
        log.Error("could not find classID/objectID in query string.");
        return false;
      }
      int nObjectID = XPConvert.ToInteger(asObjectID[0]);
      int nClassID = XPConvert.ToInteger(asClassID[0]);
      IPTMigrationManager ptMM = (IPTMigrationManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
       false);
      m_nCurrentMigrationStatus = ptMM.QueryMigrationStatus(nClassID, nObjectID);
      IPTQueryResult ptQRHistory = ptMM.QueryMigrationHistory(nClassID, nObjectID);
      int nCount = ptQRHistory.RowCount();
      for (int i = 0;i < nCount;i++)
      {
        String strMigrationComment = ptQRHistory.ItemAsString(i, PT_PROPIDS.PT_PROPID_MIGRATION_COMMENT);
        XPDateTime xpdtMigration = ptQRHistory.ItemAsXPDateTime(i, PT_PROPIDS.PT_PROPID_MIGRATION_DATE);
        String strMigrationSourcePortalUUID = ptQRHistory.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_MIGRATION_SOURCEPORTALUUID);
        MigrationHistoryItem mhi = new MigrationHistoryItem(xpdtMigration,
         strMigrationComment, strMigrationSourcePortalUUID, m_asOwner);
        m_arrList.Add(mhi);
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public override void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationHistoryModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
    }
    
    /// <returns></returns>
    public virtual int GetCurrentMigrationStatus()
    {
      return m_nCurrentMigrationStatus;
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual MigrationHistoryItem GetHistoryItem(int _nIndex)
    {
      return (MigrationHistoryItem) m_arrList.GetElement(_nIndex);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetNumHistoryItems()
    {
      return m_arrList.GetSize();
    }
    
    /// <summary>
    /// Retrieves the flag indicating whether or not we are being
    /// hosted by another activity space, or our own.
    /// </summary>
    public virtual bool IsStandalone()
    {
      return true;
    }
    
    /// <summary>
    /// Retrieves the flag indicating whether or not to display
    /// the approval checkbox (currently only for full sysadmins)
    /// </summary>
    public virtual bool ShouldDisplayApproval()
    {
      return PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) m_asOwner.GetUserSession());
      }
    
    /// <summary>
    /// Sets the flag indicating this object has been approved for migration
    /// </summary>
    public virtual void SetApprovedForMigration(bool bApproved)
    {
      m_bApprovedForMigration = bApproved;
    }
    
    /// <summary>
    /// Retrieves the flag indicating whether the checkbox has
    /// been checked in this editor session.
    /// </summary>
    public virtual bool IsMigrationCheckboxChecked()
    {
      return m_bApprovedForMigration;
    }
    
    /// <summary>
    /// Helper method to Store the migration status on the object.
    /// </summary>
    public virtual void StoreMigrationStatus(int nClassID, int nObjectID)
    {
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return EditorRepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
    }
  }
}