using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.objmgr.popups;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This handles setting folders to delete in order to determine
  /// whether or not to offer ABO delete as a choice.
  /// </author>
  public class CheckDeleteControl : IControl
  {
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CheckDelete";
    
    /// <summary>
    /// Control argument names 
    /// </summary>
    public const String DELETEFOLDERS = "DeleteFolders";
    public const String OBJECTIDPAIRS = "ObjectIDPairs";
    
    /// <summary>
    /// internal data 
    /// </summary>
    private AActivitySpace m_asOwner;
    private IObjMgrDeleteRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      Redirect result = new Redirect();
      result.SetLinkGetCachedSpace(m_asOwner);
      bool bFolders = false;
      String[] sValues = (String[]) arguments.GetElement(DELETEFOLDERS);
      if (sValues != null)
      {
        bFolders = XPConvert.ToBoolean(sValues[0]);
      }
      m_asModel.SetFoldersForDeleteCheck(bFolders);
      sValues = (String[]) arguments.GetElement(OBJECTIDPAIRS);
      if (sValues != null)
      {
        int[] nObjectIDPairs = GeneralHelpers.ConvertToInts(sValues[0]);
        m_asModel.SetObjectsForDeleteCheck(nObjectIDPairs);
      }
      result.SetDisplayPage(ObjMgrDeleteWarningsDP.STR_MVC_CLASS_NAME);
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CheckDeleteControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (IObjMgrDeleteRO) model;
      m_asOwner = space;
    }
  }
}