using System;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>Don Hayler</author>
  public interface IObjMgrDeleteRO
  {
    
    /// <summary>
    /// This method checks if any users or groups came from an auth source other
    /// than plumtree.  This assumes that any objects to check were set on the
    /// model earlier in the request (as they will be deleted between requests).
    /// </summary>
    /// <returns>true implies objects did come from an outside auth source</returns>
    bool CheckAuthSourceForDelete();
    
    /// <summary>
    /// This method checks whether or not the user is trying to delete any page templates.
    /// </summary>
    /// <returns>true implies page templates are being deleted</returns>
    bool CheckPageTemplatesForDelete();
    
    /// <summary>
    /// This method checks whether or not the user is trying to delete any folders.
    /// </summary>
    /// <returns>true implies folders are being deleted</returns>
    void SetFoldersForDeleteCheck(bool tf);
    
    /// <summary>
    /// This method is used to set the list of folder IDs (temporary)
    /// to be checked for delete.
    /// </summary>
    /// <param name="int[]">of object class id / object id pairs.</param>
    void SetObjectsForDeleteCheck(int[] nObjectIDPairs);
    bool CheckFoldersForDelete();
  }
}