using System;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>Don Hayler</author>
  public interface IObjMgrModelRO : IModelRO
  {
    
    /// <summary>
    /// This method returns whether or not there are any job IDs to display.
    /// </summary>
    /// <returns>boolean true implies there are job ids to display.</returns>
    bool ABOJobsToDisplay();
    
    /// <summary>
    /// This method checks if any users or groups came from an auth source other
    /// than plumtree.  This assumes that any objects to check were set on the
    /// model earlier in the request (as they will be deleted between requests).
    /// </summary>
    /// <returns>true implies objects did come from an outside auth source</returns>
    bool CheckAuthSourceForDelete();
    
    /// <summary>
    /// This method checks whether or not the user is trying to delete any page templates.
    /// </summary>
    /// <returns>true implies page templates are being deleted</returns>
    bool CheckPageTemplatesForDelete();
    
    /// <summary>
    /// This method checks whether or not the user is trying to delete any folders.
    /// </summary>
    /// <returns>true implies folders are being deleted</returns>
    bool CheckFoldersForDelete();
    
    /// <summary>
    /// This method returns the job names for the supplied ABO job IDs.
    /// </summary>
    /// <param name="int[]">the ABO job IDs to get the names for.</param>
    /// <returns>String[] an array of job names for folder deletions.</returns>
    String[] GetABOJobNames(int[] nABOJobIDs);
    
    /// <summary>
    /// This method returns the job IDs for the last ABO deletes, and then clears
    /// them.
    /// </summary>
    /// <returns>int[] an array of job IDs for folder deletions.</returns>
    int[] GetABOJobIDs();
    
    /// <summary>
    /// This method returns the folder where the ABO jobs were created.
    /// </summary>
    /// <returns>String the folder name where the ABO jobs were created.</returns>
    String GetABOJobFolderName();
    
    /// <summary>
    /// This method returns the community object ID associated with the folder.
    /// </summary>
    /// <param name="int">the community folder ID to check.  -1 means check current folder</param>
    /// <returns>int the ID of the community object, -1 if error</returns>
    int GetCommunityID(int nFolderID);
    
    /// <summary>
    /// This method returns the folder ID that we were previously at.
    /// This is used to return from places like the subportal manager.
    /// </summary>
    /// <returns>int the previous folder ID.</returns>
    int GetPreviousFolderID();
    
    /// <summary>
    /// This method is used to determine whether to display the 'expand all'
    /// button or the 'collapse all' button.
    /// </summary>
    /// <returns>
    /// boolean true implies all object expanded button has
    /// been clicked.
    /// </returns>
    bool GetAreAllObjectsExpanded();
    
    /// <summary>
    /// This method returns whether or not the current folder is a community.
    /// </summary>
    /// <returns>boolean true implies is a community</returns>
    bool GetCurrentFolderIsCommunity();
    
    /// <summary>
    /// This method returns whether or not the current folder is a subportal.
    /// </summary>
    /// <returns>boolean true implies is a subportal</returns>
    bool GetCurrentFolderIsSubportal();
    
    /// <summary>
    /// This method returns an int array of the currently expanded object types.
    /// </summary>
    /// <returns>int[] the expanded object types.</returns>
    int[] GetExpandedObjectTypesArray();
    
    /// <summary>
    /// This method returns the string of currently expanded object types
    /// suitable for using in an URL.
    /// </summary>
    /// <returns>String the expanded object types.</returns>
    String GetExpandedObjectTypesString();
    
    /// <summary>
    /// This method returns the space ID of the folder select tree.
    /// </summary>
    /// <returns>String the space ID of the folder select tree</returns>
    String GetFolderTreeID();
    
    /// <summary>
    /// This method checks whether or not the current page has any objects that
    /// will be displayed for the requested classID.
    /// </summary>
    /// <param name="int">nClassID the class ID to check for</param>
    bool GetHasDisplayedObjects(int nClassID);
    
    /// <summary>
    /// This method returns a 2d query result with folder level, id, and name.
    /// </summary>
    /// <returns>IASQueryResult</returns>
    IASQueryResult GetBreadCrumbPath();
    
    /// <seealso cref="com.plumtree.portalpages.admin.objmgr.ObjMgrModel#HasAccessToCreateMenu()"></seealso>
    bool HasAccessToCreateMenu();
  }
}