using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.objmgr.popups;
using com.plumtree.portalpages.admin.ptutilities;
using com.plumtree.portalpages.admin.serversettings;
using com.plumtree.portalpages.common.createfolder;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.form.pagination;
using com.plumtree.uiinfrastructure.form.sort;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This implements the admin directory.
  /// </author>
  public class ObjMgrAS : PlumtreeAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.ObjMgrAS");
    
    /// <summary>
    /// sub-space constants 
    /// </summary>
    public const String FOLDER_TREE_SUB_SPACE_KEY = "folder";
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgr";
    
    /// <summary>
    /// The maximum length of names of objects when displayed. 
    /// </summary>
    public const int MAX_DISPLAYED_NAME_LENGTH = 50;
    public static readonly String JS_PARENT_SIMPLE_REPOST = "window.opener." + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");\n";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // Do not check server configuration if user is getting an admin redirect,
      // otherwise users will not be able to redirect from a browsing server to an
      // admin server.
      if (!AdminRedirectControl.STR_MVC_CLASS_NAME.Equals(strControl))
      {
        // Check if this server is configured to be used as an administration machine.
        // 0 means browsing, 1 means admin
        if (PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.ADMINISTRATION_SECTION,
         PTConfigConstants.IS_ADMIN_SITE_SUBSECTION, PTConfigConstants.VALUE_ATTRIBUTE,
         this) != 1)
        {
          log.Warn("Attempt to access administration on browsing only portal denied. Check the IsAdminSite " + "value in the Administration section of PTconfig.xml if this is believed to be a configuration issue.");
          return false;
        }
      }
      // DCA - call super to register nav views;
      bool bAccessAllowed = base.CheckBasicAccess(strPage, strControl, bSameSpace);
      // Check for right to access administration
      bAccessAllowed = bAccessAllowed && ((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      return bAccessAllowed;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjMgrAS();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#GetCurrentPage()"></seealso>
    public override IDisplayPage GetCurrentPage()
    {
      bool bRoot = ((IFolderModelRO) GetModel(ObjMgrModel.STR_MVC_CLASS_NAME)).InRootFolder();
      if (bRoot)
      {
        return GetPage(ObjMgrRootDP.STR_MVC_CLASS_NAME);
      } else
      {
        return GetPage(ObjMgrDP.STR_MVC_CLASS_NAME);
      }
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the name of the repost control class.
    /// </summary>
    /// <seealso cref="com.plumtree.xpshared.form.IRepostAS#GetRepostControlName()"></seealso>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return ObjMgrRepostControl.STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This method handles the ClosePopUpDP and passes everything else to the base
    /// implementation.  It adds javascript to the ClosePopUpDP that sets the selected
    /// items on the opener window (if it's a remote tree) and calls a javascript
    /// function on the opener window.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#GetPage(String)"></seealso>
    public override IDisplayPage GetPage(String pageName)
    {
      if (ClosePopUpDP.STR_MVC_CLASS_NAME.Equals(pageName))
      {
        // This is called when SimpleCardSubmitDP or CreateFolderDP is canceled.
        ClosePopUpDP result = (ClosePopUpDP) base.GetPage(pageName);
        try
        {
          HTMLScript myScript = new HTMLScript("text/javaScript");
          myScript.AddInnerHTMLString(JS_PARENT_SIMPLE_REPOST);
          result.SetScript(myScript);
        }
        catch (HTMLException he)
        {
          log.Error(he, "Error generating JS for ClosePopUpDP: " + he.Message);
          }
        return result;
      }
      return base.GetPage(pageName);
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      // ObjMgr DisplayPages
      PlumtreeDP myPage = new ObjMgrRootDP();
      myPage.SetAddMainForm(true);
      RegisterPage(myPage);
      myPage = new ObjMgrDP();
      myPage.SetAddMainForm(true);
      RegisterPage(myPage);
      // Obj Mgr popup Pages -- create folder
      RegisterPage(new CreateFolderDP());
      RegisterPage(new ClosePopUpDP());
      // Obj Mgr popup Pages -- delete warnings
      RegisterPage(new ObjMgrDeleteWarningsDP());
      RegisterPage(new ObjMgrABOLinksDP());
      // ObjMgr Model
      RegisterModel(ObjMgrModel.STR_MVC_CLASS_NAME);
      IModel myModel = GetModel(ObjMgrModel.STR_MVC_CLASS_NAME);
      //Plumtree Utilities Model
      RegisterModel(PlumtreeUtilitiesModel.STR_MVC_CLASS_NAME);
      IModel puModel = GetModel(PlumtreeUtilitiesModel.STR_MVC_CLASS_NAME);
      //Server Settings Model
      RegisterModel(ServerSettingsModel.STR_MVC_CLASS_NAME);
      IModel serverModel = GetModel(ServerSettingsModel.STR_MVC_CLASS_NAME);
      // ObjMgr Views
      RegisterView(ObjMgrBreadCrumbView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjectView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjMgrSearchView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjMgrHeaderView.STR_MVC_CLASS_NAME, myModel);
      ((ObjMgrHeaderView) GetView(ObjMgrHeaderView.STR_MVC_CLASS_NAME)).SetPUModel(puModel);
      ((ObjMgrHeaderView) GetView(ObjMgrHeaderView.STR_MVC_CLASS_NAME)).SetServerModel(serverModel);
      // Obj Mgr popup Views
      RegisterView(ObjMgrCreateFolderView.STR_MVC_CLASS_NAME, CreateFolderView.STR_VIEW_STORAGE_NAME,
       myModel);
      RegisterView(ObjMgrDeleteWarningsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjMgrABOLinksView.STR_MVC_CLASS_NAME, myModel);
      // ObjMgr Controls
      RegisterControl(ObjMgrRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(ObjMgrSettingsControl.STR_MVC_CLASS_NAME, myModel);
      // Obj Mgr popup Controls
      RegisterControl(CheckDeleteControl.STR_MVC_CLASS_NAME, myModel);
      // Sort Control
      RegisterControl(SortControl.STR_MVC_CLASS_NAME, myModel);
      // Pagination Control
      RegisterControl(PaginationControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(AdminRedirectControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(AdminLoginTokenControl.STR_MVC_CLASS_NAME, myModel);
      }
    
    /// <summary>
    /// This method returns a date time formatting object
    /// for the current user.
    /// </summary>
    /// <returns>XPDateFormat the format for the current user</returns>
    public virtual XPDateFormat GetDateFormat()
    {
      XPLocale xpLocale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(this);
      XPTimeZone xpTimeZone = PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(this);
      XPDateFormat result = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
       XPDateFormat.SHORT, xpLocale, xpTimeZone);
      return result;
    }
  }
}