using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>Don Hayler</author>
  public class ObjMgrBreadCrumbView : BreadcrumbView
  {
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgrBreadcrumb";
    
    /// <summary>
    /// object manager model (for custom path code) 
    /// </summary>
    protected IObjMgrModelRO m_asObjMgrModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjMgrBreadCrumbView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#getName()"></seealso>
    public override String GetName()
    {
      return ObjMgrBreadCrumbView.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      m_asObjMgrModel = (IObjMgrModelRO) model;
      base.Init(model, parent);
    }
    
    /// <summary>
    /// override this to provide our own links
    /// </summary>
    protected override PTBreadcrumbPath GetBreadcrumbPath()
    {
      PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();
      HTMLAnchor myAnchor;
      IASQueryResult qrPath = m_asObjMgrModel.GetBreadCrumbPath();
      int nPathCount = qrPath.GetCount();
      for (int i = 0;i < nPathCount;i++)
      {
        int nFolderID = XPConvert.ToInteger(qrPath.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
        String strFolderName = (String) qrPath.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
        String strEncodedFolderName = XPHttpUtility.HtmlEncode(strFolderName);
        if (i < (nPathCount - 1))
        {
          myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER + "(" + nFolderID + "); return false;");
          myAnchor.AddInnerHTMLString(strEncodedFolderName);
          myAnchor.SetTitle(strEncodedFolderName);
          myCrumbs.appendAnchorItem(myAnchor);
        } else
        {
          myCrumbs.appendTextItem(strEncodedFolderName);
        }
      }
      return myCrumbs;
    }
  }
}
/*
 XPStringTokenizer stPath = new XPStringTokenizer(m_asModel.GetPath(),
 "\\");
 Object[] oIDs			 = m_asModel.GetParentFolderIDs();
 
 // In the case of the root folder, there will be two oIDs even though there
 // is only one folder in stPath.  Otherwise there will be an equal number of
 // IDs and folder names.
 if (oIDs.length < stPath.GetTokenCount())
 {
 if (PTDebug.IsErrorTracingEnabled(Component.Portal_Admin))
 {
 PTDebug.Trace(Component.Portal_Admin, TraceType.Error,
 "There are more parent names (" + stPath.GetTokenCount() +
 "than ids (" + oIDs.length + ").");
 }
 
 return myCrumbs;
 }
 
 HTMLAnchor myAnchor;
 int i   = 0;
 int end = stPath.GetTokenCount();
 String strName;
 
 while (stPath.HasMoreTokens())
 {
 strName = stPath.GetNextToken();
 strName = GeneralHelpers.TruncateLongString(strName,
 ObjMgrAS.MAX_DISPLAYED_NAME_LENGTH, false);
 
 if (i < (end - 1))
 {
 myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
 myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER +
 "(" + oIDs[i++] + "); return false;");
 myAnchor.AddInnerHTMLEncodedString(strName);
 myCrumbs.appendAnchorItem(myAnchor);
 }
 else
 {
 myCrumbs.appendTextItem(XPHttpUtility.HtmlEncode(strName));
 
 // Probably not necessary -- should break out of loop after this.
 i++;
 }
 }
 
 return myCrumbs;
 */
 
