using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.defaultprofile;
using com.plumtree.portalpages.admin.objmgr.popups;
using com.plumtree.portalpages.admin.ptutilities;
using com.plumtree.portalpages.admin.sendinvitation;
using com.plumtree.portalpages.admin.serversettings;
using com.plumtree.portalpages.browsing.settings;
using com.plumtree.portalpages.common.createfolder;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.securitymatrix;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.subscribematrix;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This displays the header and action bar for the object manager.
  /// </author>
  public class ObjMgrHeaderView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.ObjMgrHeaderView");
    
    /// <summary>
    /// name of this object 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgrHeader";
    
    /// <summary>
    /// Javascript function constants 
    /// </summary>
    public const String JAVASCRIPT_SUBMIT_BY_POST = "submitNoRefresh";
    public const String JAVASCRIPT_CREATE = "create";
    public const String JAVASCRIPT_UTILITY = "utility";
    public const String JAVASCRIPT_OPEN_FOLDER = "openFolder";
    public const String JAVASCRIPT_EXPAND_TYPE = "expand";
    public const String JAVASCRIPT_DELETE = "checkDelete";
    public const String JAVASCRIPT_SECURITY = "editSecurity";
    public const String JAVASCRIPT_SUBSCRIBE = "subscribe";
    public const String JAVASCRIPT_MIGRATE = "migrateItems";
    public const String JAVASCRIPT_EDIT_FOLDER = "editFolder";
    public const String JAVASCRIPT_EDIT_PROFILE = "editProfile";
    public const String JAVASCRIPT_SEND_INVITATION = "sendInvitation";
    public const String JAVASCRIPT_RUN_ONCE = "runOnce";
    public const String JAVASCRIPT_ENABLE = "enable";
    public const String JAVASCRIPT_TREE_SUBMIT = "treeSubmit";
    public const String JAVASCRIPT_OPEN_FOLDER_TREE = "openFolderTree";
    public const String JAVASCRIPT_CHECK_FOLDERS_SELECTED = "checkFoldersSelected";
    public const String JAVASCRIPT_CHECK_SINGLE_FOLDER_SELECTED = "checkSingleFolderSelected";
    public const String JAVASCRIPT_CHECK_OBJECTS_SELECTED = "checkObjectsSelected";
    public const String JAVASCRIPT_GET_INPUT_VALUE = "getInputValue";
    public const String JAVASCRIPT_GET_FIRST_INPUT = "getFirstSelectedObject";
    public const String JAVASCRIPT_GET_FIRST_INPUT_WITH_SUBTYPE = "getFirstSelectedObject2";
    public const String JAVASCRIPT_GET_FIRST_INPUT_WITH_COUNT = "getFirstSelectedObject3";
    public const String JAVASCRIPT_GET_ONLY_INPUT = "getOnlySelectedObject";
    public const String JAVASCRIPT_GET_FOLDERS_AND_OBJECTS_SELECTED_STRING = "getFoldersAndObjectsString";
    public const String JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING = "getAllObjectsString";
    public const String JAVASCRIPT_GET_FOLDERS_SELECTED_STRING = "getFoldersString";
    public const String JAVASCRIPT_GET_OBJECT_SELECTED_STRING = "getObjectString";
    public const String JAVASCRIPT_GET_NUM_OBJECTS_SELECTED = "getNumObjectsSelected";
    public const String JAVASCRIPT_GET_NUM_OBJECT_SELECTED = "getNumObjectSelected";
    public const String JAVASCRIPT_COMMUNITY_SELECTED = "CommunitySelected";
    
    /// <summary>
    /// js constant copy tree 
    /// </summary>
    public const int TREE_TYPE_COPY = 0;
    
    /// <summary>
    /// js constant move tree 
    /// </summary>
    public const int TREE_TYPE_MOVE = 1;
    
    /// <summary>
    /// js constant max items that can be selected before we switch to a POST submit. 
    /// </summary>
    public const int MAX_SELECTED_ITEMS = 15;
    
    /// <summary>
    /// javascript variables 
    /// </summary>
    public const String JAVASCRIPT_TREE_TYPE = "varTreeType";
    
    /// <summary>
    /// HTML Form constants 
    /// </summary>
    public const String HTML_INPUT_FOLDER_TREE_ID = "in_hi_FolderTreeID";
    public const String HTML_INPUT_COMMENT = "in_hi_Comment";
    public const String HTML_INPUT_ENABLE = "in_hi_Enable";
    public const String HTML_INPUT_CREATE_SELECT = "in_se_CreateSelect";
    public const String HTML_INPUT_UTILITIES_SELECT = "in_se_UtilitiesSelect";
    public const String HTML_INPUT_FOLDERNAME = "in_hi_FolderName";
    public const String HTML_INPUT_FOLDERDESC = "in_hi_FolderDesc";
    public const String HTML_INPUT_COMMSELECTED = "in_hi_CommSelected";
    
    /// <summary>
    /// MVC components 
    /// </summary>
    private AActivitySpace m_asOwner;
    private IFolderModelRO m_asModel;
    private IObjMgrModelRO m_asObjModel;
    private IPlumtreeUtilitiesModelRO m_asPUModel;
    private IServerSettingsModelRO m_asServerModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ObjMgrHeaderView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection myGroup = new HTMLElementCollection();
      HTMLElement result = myGroup;
      HTMLImg myImg;
      HTMLAnchor myAnchor;
      PTConstruct myConstruct;
      PTConstruct myButtonConstruct;
      PTConstruct myImageConstruct;
      int nParentFolderID;
      int nCurrentFolderID;
      try
      {
        // Add hidden inputs
        AddHiddenInputs(myGroup, m_asModel, m_asObjModel);
        // Add banner
        // Folder banner
        myConstruct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
         true, this.m_asOwner);
        myConstruct.ReplaceNestedElementsWithHTMLEncodedString(PTBannerType.FOLDER.TITLE_ELEMENT_NAME,
         m_asModel.GetCurrentFolderName());
        // Open folder button
        if (m_asObjModel.GetCurrentFolderIsSubportal())
        {
          myImageConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER_SUBPORTAL_OPEN,
           true, m_asOwner);
          myImg = (HTMLImg) myImageConstruct.GetHTMLElement();
          myConstruct.ReplaceNestedElementsWithElement(PTBannerType.FOLDER.FOLDER_IMG_CONTAINER_ELEMENT_NAME,
           myImg);
        } else
        if (m_asObjModel.GetCurrentFolderIsCommunity())
        {
          myImageConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER_COMMUNITY_OPEN,
           true, m_asOwner);
          myImg = (HTMLImg) myImageConstruct.GetHTMLElement();
          myConstruct.ReplaceNestedElementsWithElement(PTBannerType.FOLDER.FOLDER_IMG_CONTAINER_ELEMENT_NAME,
           myImg);
        }
        nParentFolderID = m_asModel.GetParentFolderID();
        nCurrentFolderID = m_asModel.GetCurrentFolderID();
        if (nCurrentFolderID != PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER)
        {
          // Expand all / Collapse all button.
          if (m_asObjModel.GetAreAllObjectsExpanded() == true)
          {
            // Collapse all button
            String strCollapseAll = m_asOwner.GetString(2164, "ptmsgs_portaladminmsgs");
            myImageConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_COLLAPSE_ALL,
             true, m_asOwner);
            myImg = (HTMLImg) myImageConstruct.GetHTMLElement();
            myImg.SetAlt(strCollapseAll);
            myImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
            myAnchor = ConstructStaticHelpers.GetJavascriptAnchor("", AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + ObjMgrRepostControl.POSTTOSELF_ACTION_COLLAPSE_ALL_OBJECTS + ")");
            myAnchor.SetTitle(strCollapseAll);
            myAnchor.AddInnerHTMLElement(myImg);
            HTMLSpan myTextSpan = new HTMLSpan();
            myTextSpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
            myAnchor.AddInnerHTMLElement(myTextSpan);
            myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
             myAnchor);
          } else
          {
            // Expand all button
            String strExpandAll = m_asOwner.GetString(2163, "ptmsgs_portaladminmsgs");
            myImageConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EXPAND_ALL,
             true, m_asOwner);
            myImg = (HTMLImg) myImageConstruct.GetHTMLElement();
            myImg.SetAlt(strExpandAll);
            myImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
            myAnchor = ConstructStaticHelpers.GetJavascriptAnchor("", AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + ObjMgrRepostControl.POSTTOSELF_ACTION_EXPAND_ALL_OBJECTS + ")");
            myAnchor.SetTitle(strExpandAll);
            myAnchor.AddInnerHTMLElement(myImg);
            HTMLSpan myTextSpan = new HTMLSpan();
            myTextSpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
            myAnchor.AddInnerHTMLElement(myTextSpan);
            myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
             myAnchor);
          }
        }
        if (m_asObjModel.GetCurrentFolderIsCommunity())
        {
          // Edit This Community button
          String strEditThisCommunity = m_asOwner.GetString(1241, "ptmsgs_portaladminmsgs");
          String strOpenCommunityURL = PTOpenerLinks.GetOpenerURLOpenObjID(
          // -1 means current folder
          PT_CLASSIDS.PT_COMMUNITY_ID, m_asObjModel.GetCommunityID(-1), IOpenerConstants.OPENER_MODE_EDIT,
           m_asOwner);
          // NOTE: This should probably use a special edit_community_dir_actionbar button, but
          // that doesn't exist right now.
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR,
           true, this.m_asOwner);
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, strEditThisCommunity);
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, strEditThisCommunity);
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(strOpenCommunityURL);
          myAnchor.SetTitle(strEditThisCommunity);
          myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        } else
        {
          //	Edit This Folder button
          String strEditThisFolder = m_asOwner.GetString(2481, "ptmsgs_portaladminmsgs");
          String strEditThisFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
           ((IFolderModelRO) m_asObjModel).GetCurrentFolderID(), IPTOpenerConstants.OPENER_MODE_EDIT,
           m_asOwner);
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR,
           true, this.m_asOwner);
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, strEditThisFolder);
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, strEditThisFolder);
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(strEditThisFolderURL);
          myAnchor.SetTitle(strEditThisFolder);
          myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        // If we have a valid parent folder ID
        if (nParentFolderID != 0)
        {
          //	Go Up button
          String strGoUp = m_asOwner.GetString(1251, "ptmsgs_portaladminmsgs");
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
           true, this.m_asOwner);
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, strGoUp);
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, strGoUp);
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.ANCHOR_ELEMENT_NAME);
          myAnchor.SetOnClick(JAVASCRIPT_OPEN_FOLDER + "(" + m_asModel.GetParentFolderID() + "); return false;");
          myAnchor.SetTitle(strGoUp);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.GO_UP.TITLE_ELEMENT_NAME,
           strGoUp);
          myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        } else
        if (nCurrentFolderID == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
        {
          // Back to Administration link from the subportal and default profiles editor areas
          //	Go Up button
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
           true, this.m_asOwner);
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1236,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1236,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.ANCHOR_ELEMENT_NAME);
          AActivitySpace parentSpace = m_asOwner.GetParentSpace();
          if ((parentSpace != null) && (ObjMgrAS.STR_MVC_CLASS_NAME.Equals(parentSpace.GetName())))
          {
            // Only return you to the parent space if the parent space is admin
            ASURL parentSpaceURL = new ASURL(m_asOwner);
            parentSpaceURL.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
            myAnchor.SetHRef(parentSpaceURL.GetURLAsString());
          } else
          {
            // Otherwise go back to the normal folder heirarchy.
            myAnchor.SetOnClick(JAVASCRIPT_OPEN_FOLDER + "(" + m_asObjModel.GetPreviousFolderID() + "); return false;");
            }
          //Add the string "Back to Administration" to the button
          myButtonConstruct.AddHTMLStringToNestedElement(PTButtonType.GO_UP.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1236, "ptmsgs_portaladminmsgs") + CommonHTMLStrings.SPACE);
          myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        myGroup.AddInnerHTMLElement(myConstruct.GetHTMLElement());
        // Action banner
        myConstruct = UIConstructFactory.GetConstruct(PTBannerType.DIRECTORY_ACTION_BAR,
         true, this.m_asOwner);
        HTMLElement mySelect;
        // JF- Only display the create object menu if the current user 
        // has at least edit rights on the current admin folder.
        if (m_asObjModel.HasAccessToCreateMenu())
        {
          // Create object types select box form
          mySelect = GetCreateSelect();
          if (mySelect != null)
          {
            myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
             mySelect);
          }
        }
        // create settings utilities drop down
        mySelect = GetSettingsUtilitiesSelect();
        if (mySelect != null)
        {
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
           mySelect);
        }
        // Common untitled buttons go next to the drop downs
        // 1st extendable cell
        if (nCurrentFolderID != PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
        {
          // Move button (not displayed in sub-portal folder)
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.MOVE_DIR_ACTIONBAR,
           true, this.m_asOwner);
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1246,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1246,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.MOVE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_OPEN_FOLDER_TREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTML_INPUT_FOLDER_TREE_ID + ", " + TREE_TYPE_MOVE + "); return false;");
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        // Copy button
        myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.COPY_DIR_ACTIONBAR,
         true, this.m_asOwner);
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1247,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1247,
         "ptmsgs_portaladminmsgs"));
        myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.COPY_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(JAVASCRIPT_OPEN_FOLDER_TREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTML_INPUT_FOLDER_TREE_ID + ", " + TREE_TYPE_COPY + "); return false;");
        myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         myButtonConstruct.GetHTMLElement());
        // Delete button
        myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.DELETE_DIR_ACTIONBAR,
         true, this.m_asOwner);
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1248,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1248,
         "ptmsgs_portaladminmsgs"));
        myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.DELETE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(JAVASCRIPT_DELETE + "(); return false;");
        myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         myButtonConstruct.GetHTMLElement());
        // Security button
        myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SECURITY_DIR_ACTIONBAR,
         true, this.m_asOwner);
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1249,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1249,
         "ptmsgs_portaladminmsgs"));
        myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.SECURITY_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(JAVASCRIPT_SECURITY + "(); return false;");
        myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         myButtonConstruct.GetHTMLElement());
        // Subscribe button
        myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.BULK_ADD_DIR_ACTIONBAR,
         true, this.m_asOwner);
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(2879,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(2879,
         "ptmsgs_portaladminmsgs"));
        myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.BULK_ADD_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(JAVASCRIPT_SUBSCRIBE + "(); return false;");
        myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         myButtonConstruct.GetHTMLElement());
        // Request Migration button
        myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.MIGRATE_OBJECTS_DIR_ACTIONBAR,
         true, this.m_asOwner);
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1250,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1250,
         "ptmsgs_portaladminmsgs"));
        myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.MIGRATE_OBJECTS_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(JAVASCRIPT_MIGRATE + "(); return false;");
        myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         myButtonConstruct.GetHTMLElement());
        // Titled buttons go on the far right
        // 2nd extendable cell
        if (m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_USER_ID))
        {
          // Edit Profile button
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EDIT_DIR_ACTIONBAR,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.EDIT_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1240, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1240,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1240,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.EDIT_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_EDIT_PROFILE + "(); return false;");
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        if ((nCurrentFolderID != PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES) && (!m_asObjModel.GetCurrentFolderIsCommunity()))
        {
          // folder level argument is ignored
          if (m_asModel.GetSubFolderCount(1) > 0)
          {
            // Edit Folder button
            myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR,
             true, this.m_asOwner);
            myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
             m_asOwner.GetString(1239, "ptmsgs_portaladminmsgs"));
            ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1239,
             "ptmsgs_portaladminmsgs"));
            ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1239,
             "ptmsgs_portaladminmsgs"));
            myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
            myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(JAVASCRIPT_EDIT_FOLDER + "(); return false;");
            myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
             myButtonConstruct.GetHTMLElement());
          }
        }
        if (m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_INVITATION_ID))
        {
          // Send Invitation button
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SEND_TO_OTHERS,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.SEND_TO_OTHERS.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1242, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1242,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1242,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.SEND_TO_OTHERS.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_SEND_INVITATION + "(); return false;");
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        if (m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_JOB_ID))
        {
          // Run Once button
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SELECT,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.SELECT.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1243, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1243,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1243,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.SELECT.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_RUN_ONCE + "(); return false;");
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        if (m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_USER_ID) || m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_WEBSERVICE_ID))
        {
          // Enable button
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.ENABLE_DIR_ACTIONBAR,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.ENABLE_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1244, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1244,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1244,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.ENABLE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_ENABLE + "(true); return false;");
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
          // Disable button
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.DISABLE_DIR_ACTIONBAR,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.DISABLE_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1245, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1245,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1245,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.DISABLE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_ENABLE + "(false); return false;");
          myConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           myButtonConstruct.GetHTMLElement());
        }
        myGroup.AddInnerHTMLElement(myConstruct.GetHTMLElement());
      }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t display ObjMgrHeaderView");
        result = new HTMLElementCollection();
        result.AddInnerHTMLEncodedString("Error creating " + STR_MVC_CLASS_NAME + " Section.");
        result.AddInnerHTMLElement(new HTMLComment("Exception: " + e.Message));
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      int nCurrentFolderID = m_asModel.GetCurrentFolderID();
      int[] nClassIDs = m_asObjModel.GetExpandedObjectTypesArray();
      String typesString = m_asObjModel.GetExpandedObjectTypesString();
      bool displayedInvitation = m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_INVITATION_ID);
      bool displayedJob = m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_JOB_ID);
      bool displayedUser = m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_USER_ID);
      bool displayedWebService = m_asObjModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_WEBSERVICE_ID);
      bool aboJobsToDisplay = m_asObjModel.ABOJobsToDisplay();
      return DoDisplayJavascript(nCurrentFolderID, m_asOwner, nClassIDs, AFormDP.HTMLFORM_NAME,
       typesString, displayedInvitation, displayedJob, displayedUser, displayedWebService,
       aboJobsToDisplay);
    }
    public static HTMLScript DoDisplayJavascript(int nCurrentFolderID, AActivitySpace m_asOwner,
     int[] nClassIDs, String HTMLFORM_NAME, String typesString, bool displayedInvitation,
     bool displayedJob, bool displayedUser, bool displayedWebService, bool aboJobsToDisplay)
    {
      ASURL createFolderURL = new ASURL(m_asOwner);
      createFolderURL.SetLinkGetCachedSpace(m_asOwner);
      createFolderURL.SetDisplayPage(CreateFolderDP.STR_MVC_CLASS_NAME);
      createFolderURL.SetControl(ObjMgrRepostControl.STR_MVC_CLASS_NAME);
      createFolderURL.AddControlArgument(CreateFolderDP.QS_PARENT_FOLDER,
       nCurrentFolderID);
      XPStringBuilder sbCreateObjectURLQSArgs = new XPStringBuilder(20);
      sbCreateObjectURLQSArgs.Append(ASConstants.PARENTSPACENAME).Append("=").Append(m_asOwner.GetName());
      sbCreateObjectURLQSArgs.Append("&").Append(ASConstants.PARENTSPACEID).Append("=").Append(m_asOwner.GetSpaceID());
      sbCreateObjectURLQSArgs.Append("&").Append(IPTOpenerConstants.QS_FOLDERID).Append("=").Append(nCurrentFolderID);
      String strCreateObjectURL = OpenerLinks.GetOpenerURL(sbCreateObjectURLQSArgs.ToString(),
       IPTOpenerConstants.OPENER_MODE_CREATE, m_asOwner);
      // This must be the last argument so we can append the class ID
      strCreateObjectURL = strCreateObjectURL + "&" + IOpenerConstants.QS_OPEN + "=";
      ASURL editProfileURL = new ASURL(m_asOwner);
      editProfileURL.SetLinkCreateNewSpace(EditDefaultProfileAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      editProfileURL.SetControl(SetEditDefaultProfileControl.STR_MVC_CLASS_NAME);
      // This must be the last argument so we can append the profile ID
      editProfileURL.AddControlArgument(SetEditDefaultProfileControl.m_UserID);
      ASURL sendInvitationURL = new ASURL(m_asOwner);
      sendInvitationURL.SetLinkCreateNewSpace(SendInvitationAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      sendInvitationURL.SetControl(InvCodesListControl.STR_MVC_CLASS_NAME);
      // This must be the last argument so we can append the profile ID
      sendInvitationURL.AddControlArgument(InvCodesListModel.CONTROLARGUMENT_OBJECTID);
      // The URL to open a new folder selection tree
      ASURL newFolderTree = new ASURL(m_asOwner);
      newFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      newFolderTree.SetSubSpaceKey(ObjMgrAS.FOLDER_TREE_SUB_SPACE_KEY);
      newFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      newFolderTree.AddControlArgument(StartTreeControl.ROOT_ID, 1);
      newFolderTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, false);
      newFolderTree.AddControlArgument(AStartTreeControl.SELECT_MODE, TreeConstants.N_COMPOSITESELECT);
      newFolderTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE, TreeConstants.N_SERVERSUBMIT);
      newFolderTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
       HTMLFORM_NAME);
      newFolderTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
       HTML_INPUT_FOLDER_TREE_ID);
      newFolderTree.AddControlArgument(AStartTreeControl.SELECTED_ITEMS, PT_CLASSIDS.PT_ADMIN_FOLDER_ID + "," + nCurrentFolderID);
      newFolderTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
      newFolderTree.AddControlArgument(AStartTreeControl.TITLE, m_asOwner.GetString(1234,
       "ptmsgs_portaladminmsgs"));
      newFolderTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(1235,
       "ptmsgs_portaladminmsgs"));
      newFolderTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
       JAVASCRIPT_TREE_SUBMIT);
      newFolderTree.AddControlArgument(StartTreeControl.COMMUNITY_MODE, AObjectTreeModel.ALLCOMMUNITIES);
      // TODO: remove this and set dynamically in the javascript, if possible
      newFolderTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, true);
      ASURL deleteURL = new ASURL(m_asOwner);
      deleteURL.SetLinkGetCachedSpace(m_asOwner);
      deleteURL.SetControl(CheckDeleteControl.STR_MVC_CLASS_NAME);
      ASURL securityURL = new ASURL(m_asOwner);
      securityURL.SetLinkCreateNewSpace(SecurityMatrixEditorAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      securityURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      securityURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
      // This must be the last argument so we can append the classID,objectID string
      securityURL.AddControlArgument(MultiObjectsSecurityModel.QS_MULTI_OBJ_SECURITY_IDS);
      ASURL subscribeURL = new ASURL(m_asOwner);
      subscribeURL.SetLinkCreateNewSpace(SubscribeMatrixEditorAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      subscribeURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      subscribeURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
      // This must be the last argument so we can append the classID,objectID string
      subscribeURL.AddControlArgument(MultiObjectsSubscribeModel.QS_MULTI_OBJ_SUBSCRIBE_IDS);
      // javascript functions
      // TODO: there is too much javascript here (especially with the tree pop-up
      // javascript from the static helper).  Move it out somewhere or make it
      // static
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(10000);
      sb.Append("\n");
      // The validate function always returns true (in the submit method), so we don't
      // need to worry about resetting the form method to GET if that fails.
      sb.Append("function ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(varID)\n");
      sb.Append("{\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".method=\'POST\';\n");
      sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(varID);\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_CREATE).Append("(varType)\n");
      sb.Append("{\n");
      sb.Append("  var strURL = \'").Append(strCreateObjectURL).Append("\';\n");
      sb.Append("  var provArray = varType.split(\',\');\n");
      sb.Append("  if (provArray.length == 3) {\n");
      sb.Append("    if (provArray[2] == \'-1\') {\n");
      // remote providers
      sb.Append("      eval(\'").Append(StaticPTObjectHelpers.JAVASCRIPT_OPEN_TREE).Append("\' + provArray[0] + provArray[1] + \'()\');\n");
      sb.Append("    } else {\n");
      // native providers
      sb.Append("      window.location= strURL + provArray[0] + \'&").Append(IPTOpenerConstants.QS_PROV_ENG_NAME).Append("=\' + provArray[1];\n");
      sb.Append("    }\n");
      sb.Append("  } else if (varType == ").Append(PT_CLASSIDS.PT_ADMIN_FOLDER_ID).Append(") {\n");
      // admin folders
      sb.Append("    window.open(\'").Append(createFolderURL.GetURLAsString()).Append("\', \'_blank1\', \'location=no,menubar=no,height=180,width=400\');\n");
      sb.Append("  } else {\n");
      // normal objects
      sb.Append("    window.location= strURL + varType;\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_UTILITY).Append("(varURL)\n");
      sb.Append("{\n");
      sb.Append("  window.location = varURL;\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_OPEN_FOLDER).Append("(varFolderID)\n");
      sb.Append("{\n");
      sb.Append("  window.location= ");
      sb.Append(IPTOpenerConstants.JS_METHOD_GETOPENERURL_OPENOBJID);
      sb.Append("(");
      sb.Append(PT_CLASSIDS.PT_ADMIN_FOLDER_ID).Append(", ");
      sb.Append("varFolderID").Append(", \'");
      sb.Append("&").Append(ObjMgrSettingsControl.OBJECT_IDS).Append("=").Append(typesString).Append("\', ");
      sb.Append(IPTOpenerConstants.OPENER_MODE_VIEW);
      sb.Append(");\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_EXPAND_TYPE).Append("(varType, varbExpand)\n");
      sb.Append("{\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".").Append(ASConstants.SPACENAME_INPUT).Append(".value = \'" + m_asOwner.GetName() + "\';\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".").Append(ASConstants.SPACEID_INPUT).Append(".value = \'" + m_asOwner.GetSpaceID() + "\';\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".").Append(ASConstants.PAGE_INPUT).Append(".value = \'" + ObjMgrDP.STR_MVC_CLASS_NAME + "\';\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".").Append(ASConstants.CONTROL_INPUT).Append(".value = \'" + ObjMgrRepostControl.STR_MVC_CLASS_NAME + "\';\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrRepostControl.HTML_INPUT_EXPAND_OBJECT_ID).Append(".value = varType;\n");
      sb.Append("  document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrRepostControl.HTML_INPUT_EXPAND_BOOLEAN).Append(".value = varbExpand;\n");
      sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_EXPAND_OBJECT_TYPE).Append(");\n");
      sb.Append("}\n");
      sb.Append("\n");
      // WilliamA - Guest user can be in any folder now
      // if (nCurrentFolderID == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
      if (displayedUser)
      {
        // Edit a profile function -- there are no folders here, so we don't need the edit folder function
        sb.Append("function ").Append(JAVASCRIPT_EDIT_PROFILE).Append("()\n");
        sb.Append("{\n");
        sb.Append("  nCount = ").Append(JAVASCRIPT_GET_FIRST_INPUT_WITH_COUNT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
        sb.Append("  if (nCount > 1) {  \n");
        sb.Append("    alert(\'" + NavigationCommonHelpers.EscapeSingleQuotes(m_asOwner.GetString(3185,
         "ptmsgs_portaladminmsgs")) + "\');\n    return;\n");
        sb.Append("  }\n");
        // WilliamA - If we're in Default Profiles folder, use javascript
        // function JAVASCRIPT_GET_FIRST_INPUT;
        // otherwise need to use javascript function JAVASCRIPT_GET_FIRST_INPUT_WITH_SUBTYPE
        // since regular folders may have both guest and non-guest users.
        if (nCurrentFolderID == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
        {
          sb.Append("  nID = ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
          } else
        {
          sb.Append("  nID = ").Append(JAVASCRIPT_GET_FIRST_INPUT_WITH_SUBTYPE).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(", document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_HIDDEN_SUBTYPE).Append(PT_CLASSIDS.PT_USER_ID).Append(", 1").Append(");\n");
          }
        sb.Append("  if (nID >= 0) {\n");
        sb.Append("    alert(\'" + NavigationCommonHelpers.EscapeSingleQuotes(m_asOwner.GetString(2529,
         "ptmsgs_portaladminmsgs")) + "\');\n");
        sb.Append("    window.location = \'").Append(editProfileURL.GetURLAsString()).Append("\' + ").Append(JAVASCRIPT_GET_INPUT_VALUE).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(", nID);\n");
        sb.Append("  } else {\n");
        sb.Append("    alert(\'").Append(m_asOwner.GetString(3170, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("\n");
      }
      if (nCurrentFolderID != PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
      {
        // Edit a folder function
        sb.Append("function ").Append(JAVASCRIPT_EDIT_FOLDER).Append("()\n");
        sb.Append("{\n");
        sb.Append("  if (").Append(JAVASCRIPT_CHECK_SINGLE_FOLDER_SELECTED).Append("() == true) {\n");
        sb.Append("    ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_EDIT).Append(");\n");
        sb.Append("  } else {\n");
        sb.Append("    alert(\'").Append(m_asOwner.GetString(1226, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("\n");
      }
      if (displayedInvitation)
      {
        // Send an invitation function
        sb.Append("function ").Append(JAVASCRIPT_SEND_INVITATION).Append("()\n");
        sb.Append("{\n");
        sb.Append("  nID = ").Append(JAVASCRIPT_GET_ONLY_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_INVITATION_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
        sb.Append("  if (nID == -1) {\n");
        // no invitations selected
        sb.Append("    alert(\'").Append(m_asOwner.GetString(2554, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("  } else if (nID == -2) {\n");
        // too many invitations selected
        sb.Append("    alert(\'").Append(m_asOwner.GetString(1228, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("  } else {\n");
        sb.Append("    window.location = \'").Append(sendInvitationURL.GetURLAsString()).Append("\' + ").Append("SkipFolderPart(" + JAVASCRIPT_GET_INPUT_VALUE).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_INVITATION_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(", nID));\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("\n");
      }
      if (displayedJob)
      {
        // Run Job Once function
        sb.Append("function ").Append(JAVASCRIPT_RUN_ONCE).Append("()\n");
        sb.Append("{\n");
        sb.Append("  nID = ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_JOB_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
        sb.Append("  if (nID >= 0) {\n");
        sb.Append("    ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_RUN_ONCE).Append(");\n");
        sb.Append("  } else {\n");
        sb.Append("    alert(\'").Append(m_asOwner.GetString(1229, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("\n");
      }
      // Target folder tree variables and functions
      sb.Append("var ").Append(JAVASCRIPT_TREE_TYPE).Append(" = -1;\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_TREE_SUBMIT).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if (").Append(JAVASCRIPT_TREE_TYPE).Append(" == ").Append(TREE_TYPE_COPY).Append(") {\n");
      sb.Append("    ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_COPY).Append(");\n");
      sb.Append("  } else if (varTreeType == ").Append(TREE_TYPE_MOVE).Append(") {\n");
      sb.Append("    ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_MOVE).Append(");\n");
      sb.Append("  } else {\n");
      sb.Append("    alert(\'").Append(m_asOwner.GetString(1230, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_OPEN_FOLDER_TREE).Append("(myInput, varType)\n");
      sb.Append("{\n");
      sb.Append("  strURL = \'").Append(newFolderTree.GetURLAsString()).Append("\';\n");
      // If there are folders selected
      sb.Append("  if (").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() == true) {\n");
      // show the root admin folder in the tree
      //		sb.Append("    strURL = strURL + '").Append(ASURL.AMPERSAND).Append(AStartTreeControl.SHOW_ROOT).Append
      //			(ASURL.EQUALS).Append("true';\n");
      sb.Append("  } else if (").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() == true) {\n");
      // Otherwise hide it
      // TODO: need to be able to reset the value of showroot in the tree and set it to false, here.
      //		sb.Append("    strURL = strURL + '").Append(ASURL.AMPERSAND).Append(AStartTreeControl.SHOW_ROOT).Append
      //			(ASURL.EQUALS).Append("false';\n");
      sb.Append("  } else {\n");
      // And display an error if nothing is selected
      sb.Append("    alert(\'").Append(m_asOwner.GetString(1224, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("    return false;\n");
      sb.Append("  }\n");
      sb.Append("  ").Append(JAVASCRIPT_TREE_TYPE).Append(" = varType;\n");
      // Users cannot be copied
      sb.Append("  if (varType == ").Append(TREE_TYPE_COPY).Append(") {\n");
      sb.Append("    strTemp = ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(", ").Append(PT_CLASSIDS.PT_USER_ID).Append(");\n");
      sb.Append("    if (strTemp != \'\') {\n");
      sb.Append("    alert(\'").Append(m_asOwner.GetString(1257, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("    return false;\n");
      sb.Append("    }\n");
      sb.Append("  }\n");
      // If the tree doesn't exist yet
      sb.Append("  if (myInput.value == \'null\') {\n");
      // Open a new one
      sb.Append("    window.open(strURL, \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
      sb.Append("  } else {\n");
      // Otherwise, reopen it
      // must call starttreecontrol again because we're changing the folder structure and the tree can get confused.
      sb.Append("    window.open(strURL + \'").Append(LinkConstants.AMPERSAND).Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(", \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_DELETE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if ((").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() != true) &&\n");
      sb.Append("      (").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() != true))\n");
      sb.Append("  {\n");
      // And display an error if nothing is selected
      sb.Append("    alert(\'").Append(m_asOwner.GetString(1224, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("    return false;\n");
      sb.Append("  }\n");
      sb.Append("  window.open(\'").Append(deleteURL.GetURLAsString()).Append("&").Append(CheckDeleteControl.DELETEFOLDERS).Append("=\' + ").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() + \'").Append(LinkConstants.AMPERSAND).Append(CheckDeleteControl.OBJECTIDPAIRS).Append("=\' + ").Append(JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("(), \'_blank2\', \'location=no,menubar=no,height=250,width=350,scrollbars=yes\');\n");
      sb.Append("}\n");
      sb.Append("\n");
      // Security
      // TODO: error message if > 50 objects
      sb.Append("function ").Append(JAVASCRIPT_SECURITY).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if (").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(") != -1) {\n");
      sb.Append("    alert(\'").Append(m_asOwner.GetString(2354, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("    return false;\n");
      sb.Append("  }\n");
      sb.Append("  if ((").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() == true) || (").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() == true)) {\n");
      sb.Append("    window.open(\'").Append(securityURL.GetURLAsString()).Append("\' + ").Append(JAVASCRIPT_GET_FOLDERS_AND_OBJECTS_SELECTED_STRING).Append("(), \'_blank3\', \'location=no,menubar=no,height=600,width=800,resizable,scrollbars\');\n");
      sb.Append("  } else {\n");
      sb.Append("    alert(\'").
      // select > 1 folder or object
      Append(m_asOwner.GetString(1224, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      // Subscribe
      // TODO: error message if > 50 objects
      sb.Append("function ").Append(JAVASCRIPT_SUBSCRIBE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if (").Append("document.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMSELECTED).Append(".value == 0 & ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_GADGET_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(") < 0) {\n");
      sb.Append("    alert(\'").Append(m_asOwner.GetString(3181, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("    return false;\n");
      sb.Append("  }\n");
      sb.Append("  if ((").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() == true) || (").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() == true)) {\n");
      sb.Append("    window.open(\'").Append(subscribeURL.GetURLAsString()).Append("\' + ").Append(JAVASCRIPT_GET_FOLDERS_AND_OBJECTS_SELECTED_STRING).Append("(), \'_blank3\', \'location=no,menubar=no,height=600,width=800,resizable,scrollbars\');\n");
      sb.Append("  } else {\n");
      sb.Append("    alert(\'").
      // select > 1 folder or object
      Append(m_asOwner.GetString(1224, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      // Migrate
      sb.Append("function ").Append(JAVASCRIPT_MIGRATE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if ((").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() == true) ||\n");
      sb.Append("      (").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() == true)) {\n");
      sb.Append("    migrationcomment = window.prompt(\'").Append(m_asOwner.GetString(1237,
       "ptmsgs_portaladminmsgs")).Append("\', \'\');\n");
      // NOTE: we may need if(nn == null || nn == "null" || nn == "") for different browsers?  what if someone enters a null comment
      // null implies they cancelled the action
      sb.Append("    if (migrationcomment != null) {\n");
      sb.Append("      document.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMENT).Append(".value = migrationcomment;\n");
      sb.Append("      ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_MIGRATE).Append(");\n");
      sb.Append("    }\n");
      sb.Append("  } else {\n");
      sb.Append("    alert(\'").Append(m_asOwner.GetString(1224, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      if (aboJobsToDisplay)
      {
        ASURL linksURL = new ASURL(m_asOwner);
        linksURL.SetLinkGetCachedSpace(m_asOwner);
        linksURL.SetDisplayPage(ObjMgrABOLinksDP.STR_MVC_CLASS_NAME);
        // Automatically pop up a window with the job IDs of the ABO jobs (if there are any)
        sb.Append("window.open(\'").Append(linksURL.GetURLAsString()).Append("\', \'_blank2\', \'location=no,menubar=no,scrollbars=yes,resizable=yes,height=250,width=350\');\n");
        sb.Append("\n");
      }
      if (displayedUser || displayedWebService)
      {
        // Enable/Disable function
        sb.Append("function ").Append(JAVASCRIPT_ENABLE).Append("(varEnable)\n");
        sb.Append("{\n");
        // First check if they are disabling/enabling a Web Service
        // JAVASCRIPT_GET_FIRST_INPUT returns non-negative if an object is checked
        sb.Append("  nID = ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_WEBSERVICE_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
        // If it is a WS, set the flag for enable or disable
        sb.Append("  if (nID >= 0) {\n");
        sb.Append("    document.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_ENABLE).Append(".value = varEnable;\n");
        // If they are disabling a Web Service, prompt for a disabled Web Service comment
        sb.Append("    if (varEnable == false) {\n");
        sb.Append("      disablecomment = window.prompt(\'").Append(m_asOwner.GetString(1238,
         "ptmsgs_portaladminmsgs")).Append("\', \'\');\n");
        // null implies they cancelled the action
        sb.Append("      if (disablecomment != null) {\n");
        sb.Append("        document.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMENT).Append(".value = disablecomment;\n");
        sb.Append("      } else {\n");
        sb.Append("        document.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_ENABLE).Append(".value = null;\n");
        sb.Append("      }\n");
        sb.Append("    }\n");
        sb.Append("  }\n");
        // If it wasn't a Web Service, check if it is a User
        sb.Append("  if (nID < 0) {\n");
        sb.Append("    nID = ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(PT_CLASSIDS.PT_USER_ID).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
        sb.Append("    document.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_ENABLE).Append(".value = varEnable;\n");
        sb.Append("  }\n");
        // If a WS or User was found to be checked, submit the form.
        // Otherwise, display an error.
        sb.Append("  if (nID >= 0) {\n");
        sb.Append("    ").Append(JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_ENABLE).Append(");\n");
        sb.Append("  } else {\n");
        sb.Append("    alert(\'").Append(m_asOwner.GetString(1231, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        sb.Append("\n");
      }
      // helper functions
      sb.Append("function ").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("()\n");
      sb.Append("{\n");
      sb.Append("  return (").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrFolderViewHelper.QS_CHECKBOX).Append(") >= 0);\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_CHECK_SINGLE_FOLDER_SELECTED).Append("()\n");
      sb.Append("{\n");
      sb.Append("  return (").Append(JAVASCRIPT_GET_ONLY_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrFolderViewHelper.QS_CHECKBOX).Append(") >= 0);\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("()\n");
      sb.Append("{\n");
      if (nClassIDs.Length > 0)
      {
        // check the first class ID
        sb.Append("  if (").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(nClassIDs[0]).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(") >= 0) {\n");
        sb.Append("    return true;\n");
        // check the rest
        for (int i = 1;i < nClassIDs.Length;i++)
        {
          sb.Append("  } else if (").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(nClassIDs[i]).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(") >= 0) {\n");
          sb.Append("    return true;\n");
        }
        sb.Append("  }\n");
      }
      sb.Append("  return false;\n");
      sb.Append("}\n");
      sb.Append("\n");
      // Return the number of all objects selected
      sb.Append("function ").Append(JAVASCRIPT_GET_NUM_OBJECTS_SELECTED).Append("()\n");
      sb.Append("{\n");
      sb.Append("  nResult = 0;\n");
      // check the folders
      sb.Append("  nResult += ").Append(JAVASCRIPT_GET_NUM_OBJECT_SELECTED).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrFolderViewHelper.QS_CHECKBOX).Append(");\n");
      if (nClassIDs.Length > 0)
      {
        // check the classes
        for (int i = 0;i < nClassIDs.Length;i++)
        {
          sb.Append("  nResult += ").Append(JAVASCRIPT_GET_NUM_OBJECT_SELECTED).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(nClassIDs[i]).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(");\n");
          }
      }
      sb.Append("  return nResult;\n");
      sb.Append("}\n");
      sb.Append("\n");
      // returns the value of the selected index in the input, even if it's a single input and not
      // an array of inputs.
      sb.Append("function ").Append(JAVASCRIPT_GET_INPUT_VALUE).Append("(varMultiButton, nIndex)\n");
      sb.Append("{\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    return varMultiButton[nIndex].value;\n");
      sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked)) {\n");
      sb.Append("      return varMultiButton.value;\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      // returns the index to the first selected input, -1 if nothing is selected
      // Warning, can't use input[i].value with the result of this, because 0 can mean
      // that it is a single object, not an array.  Use GetInputValue(input, i)
      sb.Append("function ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(varMultiButton)\n");
      sb.Append("{\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
      sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
      sb.Append("        return i;\n");
      sb.Append("      }\n");
      sb.Append("    }\n");
      sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
      sb.Append("      return 0;\n");
      sb.Append("  }\n");
      sb.Append("  return -1;\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_GET_FIRST_INPUT_WITH_COUNT).Append("(varMultiButton)\n");
      sb.Append("{\n");
      sb.Append("  nSelectedCount = 0\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
      sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
      sb.Append("        nSelectedCount++;\n");
      sb.Append("      }\n");
      sb.Append("    }\n");
      sb.Append("  }\n");
      sb.Append("  return nSelectedCount;\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_GET_FIRST_INPUT_WITH_SUBTYPE);
      sb.Append("(varMultiButton, varHiddenSubTypes, requiredSubType)\n");
      sb.Append("{\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
      sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
      sb.Append("        if (varHiddenSubTypes[i].value == requiredSubType) {\n");
      sb.Append("          return i;\n");
      sb.Append("        }\n");
      sb.Append("      }\n");
      sb.Append("    }\n");
      sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
      sb.Append("    if (varHiddenSubTypes.value == requiredSubType) {\n");
      sb.Append("      return 0;\n");
      sb.Append("    }\n");
      sb.Append("  }\n");
      sb.Append("  return -1;\n");
      sb.Append("}\n");
      sb.Append("\n");
      // returns the index to the only selected input, -1 if nothing is selected or
      // -2 if more than one object is selected.
      // Warning, can't use input[i].value with the result of this, because 0 can mean
      // that it is a single object, not an array.  Use GetInputValue(input, i)
      sb.Append("function ").Append(JAVASCRIPT_GET_ONLY_INPUT).Append("(varMultiButton)\n");
      sb.Append("{\n");
      sb.Append("  result = -1;\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
      sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
      sb.Append("        if (result == -1) {\n");
      sb.Append("          result = i;\n");
      sb.Append("        } else {\n");
      sb.Append("          return -2;\n");
      sb.Append("        }\n");
      sb.Append("      }\n");
      sb.Append("    }\n");
      sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
      sb.Append("      result = 0;\n");
      sb.Append("  }\n");
      sb.Append("  return result;\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_GET_FOLDERS_AND_OBJECTS_SELECTED_STRING).Append("()\n");
      sb.Append("{\n");
      sb.Append("  strFolders = ").Append(JAVASCRIPT_GET_FOLDERS_SELECTED_STRING).Append("();\n");
      sb.Append("  strObjects = ").Append(JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("();\n");
      sb.Append("  if (strFolders == \'\') {\n");
      sb.Append("    return strObjects;\n");
      sb.Append("  } else if (strObjects == \'\') {\n");
      sb.Append("    return strFolders;\n");
      sb.Append("  } else {\n");
      sb.Append("    return strFolders + \',\' + strObjects;\n");
      sb.Append("  }\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("()\n");
      sb.Append("{\n");
      sb.Append("  strValue = \'\';\n");
      if (nClassIDs.Length > 0)
      {
        // add the string for each class ID
        for (int i = 0;i < nClassIDs.Length;i++)
        {
          sb.Append("  strTemp = ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX).Append(nClassIDs[i]).Append(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX).Append(", ").Append(nClassIDs[i]).Append(");\n");
          sb.Append("  if ((strValue != \'\') && (strTemp != \'\')) strValue += \',\';\n");
          sb.Append("  strValue += strTemp;\n");
        }
      }
      sb.Append("  return strValue;\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_GET_FOLDERS_SELECTED_STRING).Append("()\n");
      sb.Append("{\n");
      sb.Append("  return ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(document.").Append(HTMLFORM_NAME).Append(".").Append(ObjMgrFolderViewHelper.QS_CHECKBOX).Append(", ").Append(PT_CLASSIDS.PT_ADMIN_FOLDER_ID).Append(");\n");
      sb.Append("}\n");
      sb.Append("\n");
      // returns a string of classid,objectID pairs separated by commas
      sb.Append("function ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(varMultiButton, varnClassID)\n");
      sb.Append("{\n");
      sb.Append("  strResult = \'\';\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
      sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
      sb.Append("        if (strResult == \'\') {\n");
      sb.Append("          strResult = varnClassID + \',\' + SkipFolderPart(varMultiButton[i].value);\n");
      sb.Append("        } else {\n");
      sb.Append("          strResult += \',\' + varnClassID + \',\' + SkipFolderPart(varMultiButton[i].value);\n");
      sb.Append("        }\n");
      sb.Append("      }\n");
      sb.Append("    }\n");
      sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
      sb.Append("      strResult = varnClassID + \',\' + SkipFolderPart(varMultiButton.value);\n");
      sb.Append("  }\n");
      sb.Append("  return strResult;\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function SkipFolderPart(val)\n");
      sb.Append("{\n");
      sb.Append("\tif(val == null || val.indexOf(\',\') == -1)\n");
      sb.Append("\t\treturn val;\n");
      sb.Append("\telse\n");
      sb.Append("\t\treturn val.substring(0,val.indexOf(\',\'));\n");
      sb.Append("}\n");
      sb.Append("function ").Append(JAVASCRIPT_COMMUNITY_SELECTED).Append("(checkbox, num)\n");
      sb.Append("{\n");
      sb.Append("\tif (checkbox.checked) {\n");
      sb.Append("\t\tif (num > 1 || num == 0) {\n");
      sb.Append("\t\t\tdocument.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMSELECTED).Append(".value = num;\n");
      sb.Append("\t\t} else {\n");
      sb.Append("\t\t\tdocument.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMSELECTED).Append(".value++;\n");
      sb.Append("\t\t}\n");
      sb.Append("\t} else {\n");
      sb.Append("\t\tif (num > 1 || num == 0) {\n");
      sb.Append("\t\t\tdocument.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMSELECTED).Append(".value = 0;\n");
      sb.Append("\t\t} else {\n");
      sb.Append("\t\t\tdocument.").Append(HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMSELECTED).Append(".value--;\n");
      sb.Append("\t\t}\n");
      sb.Append("\t}\n");
      sb.Append("}\n");
      // returns the number of objects selected for this object type.
      sb.Append("function ").Append(JAVASCRIPT_GET_NUM_OBJECT_SELECTED).Append("(varMultiButton)\n");
      sb.Append("{\n");
      sb.Append("  nResult = 0;\n");
      sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
      sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
      sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
      sb.Append("        nResult++;\n");
      sb.Append("      }\n");
      sb.Append("    }\n");
      sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
      sb.Append("      Result = 1;\n");
      sb.Append("  }\n");
      sb.Append("  return nResult;\n");
      sb.Append("}\n");
      sb.Append("\n");
      try
      {
        // Add normal script
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create basic javascript.");
        return null;
      }
      // Only add extensible object creation javascript if we have an objmgrmodel.
      // AdminSearch also uses this javascript, but does not allow object creation,
      // and therefore does not need this javascript.  AdminSearch does not have an
      // ObjMgrModel.
      if (m_asOwner.GetModelExists(ObjMgrModel.STR_MVC_CLASS_NAME))
      {
        try
        {
          // Add special javascript for non-native extensible objects (data sources, crawlers, auth sources...)
          XPStringBuilder provStringBuilder;
          ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
          // We are ordering by language.  This does not need to be localized, because this is only
          // in java script
          int[] aClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs(PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage());
          IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
          // NOTE: portlets are a special case below.
          // Add extensible script
          for (int i = 0;i < aClassIDs.Length;i++)
          {
            int nClassID = aClassIDs[i];
            // Only some classes appear in the menu
            if ((ptClassTypeDescManager.AppearsInMainCreateNewClassMenu(nClassID)) && (ptClassTypeDescManager.HasCreateActivityRight(nClassID,
             ptSession)))
            {
              // Deal with extensible class types
              if (ptClassTypeDescManager.IsObjectExtensible(nClassID))
              {
                IProvInfo[] aProvInfos = ptClassTypeDescManager.GetRegisteredProvInfoForClassType(nClassID);
                if (aProvInfos != null)
                {
                  for (int j = 0;j < aProvInfos.Length;j++)
                  {
                    // mj: use the clsid returned by this method instead of calling GetProviderCLSID()
                    ClassIDProvCLSIDPair clsidpair = aProvInfos[j].RequiresObjectChoiceOnStart(nClassID);
                    if (clsidpair != null)
                    {
                      // Add remote js from static helper
                      provStringBuilder = StaticPTObjectHelpers.GetJavaScriptForRemoteEditor(m_asOwner,
                       nClassID, strCreateObjectURL + nClassID + LinkConstants.AMPERSAND + IPTOpenerConstants.QS_PROV_ENG_NAME + LinkConstants.EQUALS + aProvInfos[j].GetProviderEnglishName(),
                       clsidpair.GetProvCLSID(), aProvInfos[j].GetProviderEnglishName());
                      myScript.AddInnerHTMLString(provStringBuilder.ToString());
                      }
                  }
                }
              }
              // AGC- Special case for portlets.
              // NOTE: This is kind of lame and confusing, but ... oh well.  This should really be
              // a special method on the class type descriptors or something.
              if (PT_CLASSIDS.PT_GADGET_ID == nClassID)
              {
                // Add portlet js from static helper
                provStringBuilder = StaticPTObjectHelpers.GetJavaScriptForPortletEditor(m_asOwner,
                 strCreateObjectURL + PT_CLASSIDS.PT_GADGET_ID);
                myScript.AddInnerHTMLString(provStringBuilder.ToString());
                }
            }
            if (PT_CLASSIDS.PT_PAGE_ID == nClassID)
            {
              // Add page js from static helper
              provStringBuilder = StaticPTObjectHelpers.GetJavaScriptForPageEditor(m_asOwner,
               strCreateObjectURL + PT_CLASSIDS.PT_PAGE_ID);
              if (null != provStringBuilder)
              {
                myScript.AddInnerHTMLString(provStringBuilder.ToString());
                }
            }
          }
        }
        catch (HTMLException he)
        {
          log.Error(he, "Unable to create extensible javascript.");
        }
      }
      // Don't return null, just fall through and use the partially created
      // javascript and hope it works.
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IFolderModelRO) model;
      m_asObjModel = (IObjMgrModelRO) model;
      m_asOwner = parent;
    }
    
    /// <summary>
    /// Set the plumtree utilities model
    /// </summary>
    /// <param name="model">the plumtree utilities model</param>
    public virtual void SetPUModel(IModelRO model)
    {
      m_asPUModel = (IPlumtreeUtilitiesModelRO) model;
    }
    
    /// <summary>
    /// Set the server settings model
    /// </summary>
    /// <param name="model">the server settings model</param>
    public virtual void SetServerModel(IModelRO model)
    {
      m_asServerModel = (IServerSettingsModelRO) model;
    }
    
    /// <summary>
    /// Get the create drop down
    /// </summary>
    /// <returns>the drop down</returns>
    /// <throws>HTMLException </throws>
    private HTMLElement GetCreateSelect()
    {
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      int nTotalCount = 0;
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLSelect mySelect = new HTMLSelect(HTML_INPUT_CREATE_SELECT, HTML_INPUT_CREATE_SELECT);
      result.AddInnerHTMLElement(mySelect);
      mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
      mySelect.SetOnChange("if (selectedIndex > 0) " + JAVASCRIPT_CREATE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTML_INPUT_CREATE_SELECT + ".options[selectedIndex].value); selectedIndex = 0;");
      //        mySelect.SetOnMouseOut("selectedIndex = 0;");
      HTMLOption defaultOption = new HTMLOption("");
      mySelect.AddInnerHTMLElement(defaultOption);
      defaultOption.AddInnerHTMLString(m_asOwner.GetString(1232, "ptmsgs_portaladminmsgs"));
      defaultOption.SetValue("0");
      defaultOption.SetSelected(true);
      HTMLOption myOption;
      // Add all options after the default option to an HTMLElementCollection
      // so they will be sorted.
      HTMLElementCollection sortedOptions = new HTMLElementCollection();
      mySelect.AddInnerHTMLElement(sortedOptions);
      int nCurrentFolderID = m_asModel.GetCurrentFolderID();
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      if (nCurrentFolderID == PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER)
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        // If we have security rights to create folders
        if (ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_ADMINFOLDERS))
        {
          nTotalCount++;
          // just add create folder
          myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));
          sortedOptions.AddInnerHTMLElement(myOption);
          myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
           strLangID));
        }
      } else
      if (nCurrentFolderID == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        // If we have security rights to create users
        if (ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_USERS))
        {
          nTotalCount++;
          // just add users editor thingy
          myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
          sortedOptions.AddInnerHTMLElement(myOption);
          myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(PT_CLASSIDS.PT_USER_ID,
           strLangID));
        }
      } else
      if (m_asObjModel.GetCurrentFolderIsCommunity())
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        // If we have security rights to create communities
        if (ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_COMMUNITIES))
        {
          nTotalCount++;
          // create communities
          myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));
          sortedOptions.AddInnerHTMLElement(myOption);
          myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(PT_CLASSIDS.PT_COMMUNITY_ID,
           strLangID));
        }
        // If we have security rights to create groups
        if (ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_GROUPS))
        {
          nTotalCount++;
          // create groups
          myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID));
          sortedOptions.AddInnerHTMLElement(myOption);
          myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(PT_CLASSIDS.PT_USERGROUP_ID,
           strLangID));
        }
        nTotalCount++;
        // create pages
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_PAGE_ID) + ",,-1");
        sortedOptions.AddInnerHTMLElement(myOption);
        myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(PT_CLASSIDS.PT_PAGE_ID,
         strLangID));
        // If we have security rights to create portlets
        if (ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS))
        {
          nTotalCount++;
          // create portlets
          myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID) + ",,-1");
          sortedOptions.AddInnerHTMLElement(myOption);
          myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(PT_CLASSIDS.PT_GADGET_ID,
           strLangID));
        }
      } else
      {
        String strLang = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
         m_asOwner);
        int[] aClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs(strLang);
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        for (int i = 0;i < aClassIDs.Length;i++)
        {
          int nClassID = aClassIDs[i];
          // Don't show create pages in normal folders.
          if (nClassID != PT_CLASSIDS.PT_PAGE_ID)
          {
            // Only some classes appear in the menu
            // User only has rights for some classes
            if (ptClassTypeDescManager.AppearsInMainCreateNewClassMenu(nClassID) && ptClassTypeDescManager.HasCreateActivityRight(nClassID,
             ptSession))
            {
              // Deal with extensible class types
              if (ptClassTypeDescManager.IsObjectExtensible(nClassID))
              {
                IProvInfo[] aProvInfos = ptClassTypeDescManager.GetRegisteredProvInfoForClassType(nClassID);
                if (null == aProvInfos)
                {
                  log.Error("ObjMgrHeaderView::GetCreateSelect(): PTClassTypeDescManager returned null provider info for classid " + nClassID + ". Skipping this class.");
                  continue;
                }
                for (int j = 0;j < aProvInfos.Length;j++)
                {
                  if (aProvInfos[j].AppearsInMainCreateNewClassMenu(ptSession))
                  {
                    if (aProvInfos[j].RequiresObjectChoiceOnStart(nClassID) != null)
                    {
                      // -1 means requires choice
                      myOption = new HTMLOption(nClassID + "," + aProvInfos[j].GetProviderEnglishName() + ",-1");
                      } else
                    {
                      // 0 means doesn't require choice
                      myOption = new HTMLOption(nClassID + "," + aProvInfos[j].GetProviderEnglishName() + ",0");
                      }
                    sortedOptions.AddInnerHTMLElement(myOption);
                    myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(nClassID,
                     strLangID, aProvInfos[j].GetProviderEnglishName()));
                    nTotalCount++;
                  }
                }
              } else
              // AGC- deal with Portlet special case.
              if (nClassID == PT_CLASSIDS.PT_GADGET_ID)
              {
                nTotalCount++;
                myOption = new HTMLOption(XPConvert.ToString(nClassID) + ",,-1");
                sortedOptions.AddInnerHTMLElement(myOption);
                myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(nClassID,
                 strLangID));
              } else
              // Deal with non-extensible class types
              {
                nTotalCount++;
                myOption = new HTMLOption(XPConvert.ToString(nClassID));
                sortedOptions.AddInnerHTMLElement(myOption);
                myOption.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(nClassID,
                 strLangID));
              }
            }
          }
        }
      }
      return result;
    }
    
    /// <summary>
    /// Create the settings & utilities drop down
    /// </summary>
    /// <returns>the drop down</returns>
    /// <throws>HTMLException </throws>
    private HTMLElement GetSettingsUtilitiesSelect()
    {
      int nAddedCount = 0;
      HTMLSelect dropdown = new HTMLSelect(HTML_INPUT_UTILITIES_SELECT, HTML_INPUT_UTILITIES_SELECT);
      dropdown.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
      dropdown.SetOnChange("if (selectedIndex > 0) " + JAVASCRIPT_UTILITY + "(document." + AFormDP.HTMLFORM_NAME + "." + HTML_INPUT_UTILITIES_SELECT + ".options[selectedIndex].value);");
      // Defult option		
      HTMLOption defaultOption = new HTMLOption("");
      dropdown.AddInnerHTMLElement(defaultOption);
      defaultOption.AddInnerHTMLString(m_asOwner.GetString(1233, "ptmsgs_portaladminmsgs"));
      defaultOption.SetValue("0");
      defaultOption.SetSelected(true);
      // Add these to an HTMLElementCollection to sort them.
      HTMLElementCollection sortedOptionList = new HTMLElementCollection();
      dropdown.AddInnerHTMLElement(sortedOptionList);
      HTMLOption settingOption;
      ASURL myURL;
      String strControl;
      String strDP;
      String strQueryString;
      Object[] serverSettings = m_asServerModel.GetServerSettings();
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      String strLang = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       m_asOwner);
      bool bSettingsAccess = PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession);
      if (bSettingsAccess && (serverSettings != null))
      {
        for (int i = 0;i < serverSettings.Length;i++)
        {
          myURL = new ASURL(m_asOwner);
          myURL.SetLinkCreateNewSpace(((ISettings) serverSettings[i]).GetASName(),
           m_asOwner);
          strControl = ((ISettings) serverSettings[i]).GetASControlName();
          if (strControl != null)
          {
            myURL.SetControl(strControl);
          }
          strDP = ((ISettings) serverSettings[i]).GetASDPName();
          if (strDP != null)
          {
            myURL.SetDisplayPage(strDP);
          }
          strQueryString = ((ISettings) serverSettings[i]).GetASQueryString();
          if (strQueryString != null)
          {
            settingOption = new HTMLOption(myURL.GetURLAsString() + strQueryString);
            } else
          {
            settingOption = new HTMLOption(myURL.GetURLAsString());
          }
          settingOption.AddInnerHTMLString(((ISettings) serverSettings[i]).GetLinkText(strLang));
          sortedOptionList.AddInnerHTMLElement(settingOption);
          nAddedCount++;
        }
      }
      if (m_asPUModel.GetNumSettingItems() > 0)
      {
        for (int i = 0;i < m_asPUModel.GetNumSettingItems();i++)
        {
          String strText = m_asPUModel.GetSettingItemName(i);
          String strUtilityURL = m_asPUModel.GetSettingItemURL(i);
          int iActivityRight = m_asPUModel.GetActivityRightRestriction(i);
          bool bIsPluggableAdmin = m_asPUModel.IsPluggableAdmin(i);
          //if its a pluggable admin page, then its security has already been checked so display it
          //if the user is an administrator and the activity right is PT_ACTIVITY_RIGHT_NONE then display the option
          //if the user has the activity right then display the option -mgs 9/2/03
          if ((bIsPluggableAdmin) || (ptSession.GetSessionInfo().CheckCurrentUserIsAdmin() && PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE == iActivityRight) || (ptSession.GetSessionInfo().CheckForActivityRight(iActivityRight)))
          {
            settingOption = new HTMLOption(strUtilityURL);
            settingOption.AddInnerHTMLString(strText);
            sortedOptionList.AddInnerHTMLElement(settingOption);
            nAddedCount++;
          }
        }
      }
      if (nAddedCount > 0)
      {
        return dropdown;
      } else
      {
        return null;
      }
    }
    public static void AddHiddenInputs(HTMLElement myGroup, IFolderModelRO m_asModel,
     IObjMgrModelRO m_asObjModel)
    {
      // Mandatory inputs (must be filled in correctly)
      // Current folder
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_FOLDER_ID,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      myInput.SetValue(XPConvert.ToString(m_asModel.GetCurrentFolderID()));
      // Current expanded object types
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_OBJECT_IDS,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      myInput.SetValue(m_asObjModel.GetExpandedObjectTypesString());
      // Hidden input for the folder select tree Space ID.
      // That way if you hit the folder tree link twice,
      // it will open the same tree both times.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_FOLDER_TREE_ID,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      String strValue = m_asObjModel.GetFolderTreeID();
      if (strValue == null)
      {
        strValue = "";
      }
      myInput.SetValue(strValue);
      // Optional inputs (filled in by javascript)
      // Hidden input for the migration or disable comment
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_COMMENT, "");
      myGroup.AddInnerHTMLElement(myInput);
      // Hidden input for the enable/disable boolean
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_ENABLE, "");
      myGroup.AddInnerHTMLElement(myInput);
      // Expand Object ID
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_EXPAND_OBJECT_ID,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Expand value
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_EXPAND_BOOLEAN,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Folder name
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_FOLDERNAME,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Folder desc
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_FOLDERDESC,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Community Selected
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_COMMSELECTED,
       "");
      myInput.SetValue("0");
      myGroup.AddInnerHTMLElement(myInput);
    }
  }
}