using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.createfolder;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This control handles the Obj Mgr specific repost work.
  /// </author>
  public class ObjMgrRepostControl : RepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.ObjMgrRepostControl");
    
    /// <summary>
    /// Name of this control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgrRepost";
    
    /// <summary>
    /// Mandatory Form inputs 
    /// </summary>
    public const String HTML_INPUT_FOLDER_ID = "in_hi_FolderID";
    public const String HTML_INPUT_OBJECT_IDS = "in_hi_ObjectIDs";
    // an int
    
    /// <summary>
    /// Expand object types inputs 
    /// </summary>
    public const String HTML_INPUT_EXPAND_OBJECT_ID = "in_hi_ExpandObjectIDs";
    // boolean true = expand, false = collapse
    public const String HTML_INPUT_EXPAND_BOOLEAN = "in_hi_Expand";
    
    /// <summary>
    /// Repost Actions 
    /// </summary>
    public const int POSTTOSELF_ACTION_CREATE_FOLDER = 50;
    public const int POSTTOSELF_ACTION_MOVE = 51;
    public const int POSTTOSELF_ACTION_COPY = 52;
    public const int POSTTOSELF_ACTION_EDIT = 53;
    public const int POSTTOSELF_ACTION_DELETE = 54;
    public const int POSTTOSELF_ACTION_DELETE_LATER = 55;
    public const int POSTTOSELF_ACTION_RUN_ONCE = 56;
    public const int POSTTOSELF_ACTION_MIGRATE = 57;
    public const int POSTTOSELF_ACTION_ENABLE = 58;
    public const int POSTTOSELF_ACTION_EXPAND_OBJECT_TYPE = 59;
    public const int POSTTOSELF_ACTION_EXPAND_ALL_OBJECTS = 60;
    public const int POSTTOSELF_ACTION_COLLAPSE_ALL_OBJECTS = 61;
    
    /// <summary>
    /// ObjMgr Model 
    /// </summary>
    internal ObjMgrModel m_asObjMgrModel;
    
    /// <summary>
    /// This ovverrides the implementation from RepostControl for certain actions
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String sDataKey;
      String[] aDataValue;
      // Needed for Create Folder
      sDataKey = CreateFolderDP.QS_PARENT_FOLDER;
      aDataValue = (String[]) arguments.GetElement(sDataKey);
      if (aDataValue != null)
      {
        log.Info("CREATE FOLDER PARENT");
        int nFolderID = XPConvert.ToInteger(aDataValue[0]);
        m_asObjMgrModel.SetObjMgrSettings(nFolderID, new int[0]);
        return null;
      }
      return base.CheckActionSecurityAndExecute(arguments);
    }
    
    /// <summary>
    /// This method gets the selected folders from the form data
    /// </summary>
    /// <returns>int[] an array of Folder IDs</returns>
    public static int[] GetSelectedFolders(XPHashtable htFormData)
    {
      String[] sDataValue = (String[]) htFormData.GetElement(ObjMgrFolderViewHelper.QS_CHECKBOX);
      if (sDataValue != null)
      {
        int[] result = new int[sDataValue.Length];
        int nErrorsFound = 0;
        for (int i = 0;i < sDataValue.Length;i++)
        {
          try
          {
            result[i] = XPConvert.ToInteger(sDataValue[i]);
          }
          catch (Exception e)
          {
            log.Error("Unable to convert selected folder to int: " + sDataValue[i]);
            result[i] = -1;
            nErrorsFound++;
          }
        }
        // Resize array if there were errors
        if (nErrorsFound > 0)
        {
          int[] temp = new int[sDataValue.Length - nErrorsFound];
          int nIndex = 0;
          for (int i = 0;i < result.Length;i++)
          {
            if ((result[i] != -1) && (nIndex < temp.Length))
            {
              temp[nIndex] = result[i];
              nIndex++;
            }
          }
          result = temp;
        }
        return result;
      }
      return new int[0];
    }
    
    /// <summary>
    /// This method gets the selected objects (not folders) from the form data
    /// </summary>
    /// <returns>Object[][] a (2 x n) array of class ID / Object ID pairs</returns>
    public static Object[][] GetSelectedObjects(IObjMgrModelRO asObjMgrModel,
     XPHashtable htFormData)
    {
      int[] nExpandedObjectTypes = asObjMgrModel.GetExpandedObjectTypesArray();
      String[] sDataKeys = new String[nExpandedObjectTypes.Length];
      String[] sDataValue;
      Object nError = -1;
      Object[][] result;
      // Calculate the size of the array needed
      int nSize = 0;
      for (int i = 0;i < nExpandedObjectTypes.Length;i++)
      {
        sDataKeys[i] = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
        sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);
        if (sDataValue != null)
        {
          nSize+=sDataValue.Length;
        }
      }
      result = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        result[j2c_index] = new Object[nSize];
      }
      if (nSize > 0)
      {
        // populate the array
        int nIndex = 0;
        int nErrorsFound = 0;
        for (int i = 0;i < nExpandedObjectTypes.Length;i++)
        {
          sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);
          if (sDataValue != null)
          {
            for (int j = 0;j < sDataValue.Length;j++)
            {
              if (nIndex < nSize)
              {
                try
                {
                  result[0][nIndex] = nExpandedObjectTypes[i];
                  result[1][nIndex] = XPConvert.ToInteger(sDataValue[j]);
                  }
                catch (Exception e)
                {
                  log.Error("Unable to convert selected object to int: " + sDataValue[j]);
                  result[0][nIndex] = nError;
                  result[1][nIndex] = nError;
                  nErrorsFound++;
                }
                nIndex++;
              }
            }
          }
        }
        // Resize array if there were errors
        if (nErrorsFound > 0)
        {
          Object[][] temp = new Object[2][];
          for (int j2c_index = 0;j2c_index < 2;j2c_index++)
          {
            temp[j2c_index] = new Object[nSize - nErrorsFound];
          }
          nIndex = 0;
          for (int i = 0;i < result.Length;i++)
          {
            if ((!result[0][i].Equals(nError)) && (nIndex < temp.Length))
            {
              temp[0][nIndex] = result[0][i];
              temp[1][nIndex] = result[1][i];
              nIndex++;
            }
          }
          result = temp;
        }
      }
      return result;
    }
    
    /// <summary>
    /// This method gets the selected objects (not folders) from the form data
    /// </summary>
    /// <returns>XPHashtable of Integer class IDs to int[] of Object IDs</returns>
    public static XPHashtable GetSelectedObjectsMap(IObjMgrModelRO asObjMgrModel,
     XPHashtable htFormData)
    {
      XPHashtable result = new XPHashtable();
      int[] nExpandedObjectTypes = asObjMgrModel.GetExpandedObjectTypesArray();
      String[] sDataKeys = new String[nExpandedObjectTypes.Length];
      String[] sDataValue;
      int[] temp;
      int nErrorsFound;
      for (int i = 0;i < nExpandedObjectTypes.Length;i++)
      {
        sDataKeys[i] = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
        sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);
        if ((sDataValue != null) && (sDataValue.Length > 0))
        {
          temp = new int[sDataValue.Length];
          nErrorsFound = 0;
          for (int j = 0;j < sDataValue.Length;j++)
          {
            try
            {
              temp[j] = XPConvert.ToInteger(sDataValue[j]);
            }
            catch (Exception e)
            {
              log.Error("Unable to convert selected object to int: " + sDataValue[j]);
              temp[j] = -1;
              nErrorsFound++;
            }
          }
          if (nErrorsFound > 0)
          {
            int[] resize = new int[temp.Length - nErrorsFound];
            int nResizeIndex = 0;
            for (int k = 0;k < temp.Length;k++)
            {
              if ((temp[k] != -1) && (nResizeIndex < temp.Length))
              {
                resize[nResizeIndex] = temp[i];
                nResizeIndex++;
              }
            }
            temp = resize;
          }
          result.PutElement(nExpandedObjectTypes[i], temp);
        }
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjMgrRepostControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the class with the associated model and activity space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="space"></param>
    public override void Init(IModel model, AActivitySpace space)
    {
      base.Init(model, space);
      try
      {
        m_asObjMgrModel = (ObjMgrModel) model;
      }
      catch (Exception e)
      {
        log.Error(e, "Init Unable to cast the Object " + model + " to ObjMgrModel. The following exception occured.");
        // JF- No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + model + " to ObjMgrModel.",
         e);
      }
      m_asOwner = space;
    }
    
    /// <summary>
    /// Given the repost action mode, calls the associated method in the model.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      int nTargetFolderID;
      String[] sValues;
      String sComment;
      bool bRequires302Redirect = false;
      bool bClearFormDataAfterAction = false;
      switch (_nAction){
      case POSTTOSELF_ACTION_EXPAND_OBJECT_TYPE:
      ExpandObject();
      break;
      case POSTTOSELF_ACTION_EXPAND_ALL_OBJECTS:
      m_asObjMgrModel.ExpandAllObjects(true);
      break;
      case POSTTOSELF_ACTION_COLLAPSE_ALL_OBJECTS:
      m_asObjMgrModel.ExpandAllObjects(false);
      break;
      case POSTTOSELF_ACTION_EDIT:
      int[] nFolders = ObjMgrRepostControl.GetSelectedFolders(m_htFormData);
      if (nFolders.Length > 0)
      {
        // Get the first non-community folder
        int nFirstIndex = m_asObjMgrModel.GetFirstFolderIndex(nFolders);
        if (nFirstIndex >= 0)
        {
          // set redirect to folder editor
          Redirect myRedirect = new Redirect();
          myRedirect.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          myRedirect.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
          myRedirect.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID,
           PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
          myRedirect.AddControlArgument(IPTOpenerConstants.STR_QS_OBJECTID,
           nFolders[nFirstIndex]);
          SetRedirect(myRedirect);
        }
      }
      bClearFormDataAfterAction = true;
      break;
      case POSTTOSELF_ACTION_MOVE:
      nTargetFolderID = m_asObjMgrModel.GetFolderIDFromTree();
      if (nTargetFolderID != -1)
      {
        m_asObjMgrModel.MoveFolders(nTargetFolderID, ObjMgrRepostControl.GetSelectedFolders(m_htFormData));
        m_asObjMgrModel.MoveObjectsBetweenFolders(nTargetFolderID, ObjMgrRepostControl.GetSelectedObjects(m_asObjMgrModel,
         m_htFormData));
        bRequires302Redirect = true;
        bClearFormDataAfterAction = true;
      }
      break;
      case POSTTOSELF_ACTION_COPY:
      nTargetFolderID = m_asObjMgrModel.GetFolderIDFromTree();
      if (nTargetFolderID != -1)
      {
        m_asObjMgrModel.CopyFolders(nTargetFolderID, ObjMgrRepostControl.GetSelectedFolders(m_htFormData));
        m_asObjMgrModel.CopyObjectsBetweenFolders(nTargetFolderID, ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
         m_htFormData));
        bRequires302Redirect = true;
        bClearFormDataAfterAction = true;
      }
      break;
      case POSTTOSELF_ACTION_DELETE:
      m_asObjMgrModel.DeleteFolders(ObjMgrRepostControl.GetSelectedFolders(m_htFormData));
      m_asObjMgrModel.DeleteObjects(ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
       m_htFormData), false);
      bRequires302Redirect = true;
      bClearFormDataAfterAction = true;
      break;
      case POSTTOSELF_ACTION_DELETE_LATER:
      XPHashtable xpmSelectedObjects = ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
       m_htFormData);
      // Do ABO Deletes
      m_asObjMgrModel.ABODeleteFolders(ObjMgrRepostControl.GetSelectedFolders(m_htFormData));
      m_asObjMgrModel.ABODeletePageTemplates(xpmSelectedObjects);
      // Do normal deletes (true means skip page templates)
      m_asObjMgrModel.DeleteObjects(xpmSelectedObjects, true);
      bRequires302Redirect = true;
      bClearFormDataAfterAction = true;
      break;
      case POSTTOSELF_ACTION_MIGRATE:
      sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);
      if (sValues != null)
      {
        sComment = sValues[0];
      } else
      {
        sComment = "";
      }
      m_asObjMgrModel.MigrateFolders(ObjMgrRepostControl.GetSelectedFolders(m_htFormData),
       sComment);
      m_asObjMgrModel.MigrateObjects(ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
       m_htFormData), sComment);
      bRequires302Redirect = true;
      bClearFormDataAfterAction = true;
      break;
      case POSTTOSELF_ACTION_ENABLE:
      sComment = "";
      bool bEnable;
      sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_ENABLE);
      if (sValues != null)
      {
        if (!(sValues[0].Equals("null")))
        {
          try
          {
            bEnable = XPConvert.ToBoolean(sValues[0]);
          }
          catch (Exception e)
          {
            log.Error("Unable to parse boolean enable/disable value: " + sValues[0]);
            break;
          }
        } else
        {
          break;
        }
      } else
      {
        log.Error("Unable to locate boolean enable/disable value.");
        break;
      }
      if (!bEnable)
      {
        sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);
        if (sValues != null)
        {
          sComment = sValues[0];
        }
      }
      m_asObjMgrModel.EnableObjects(ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
       m_htFormData), sComment, bEnable);
      bRequires302Redirect = true;
      bClearFormDataAfterAction = true;
      break;
      case POSTTOSELF_ACTION_RUN_ONCE:
      StaticPTObjectHelpers.RunJobsOnce((int[]) ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
       m_htFormData).GetElement(PT_CLASSIDS.PT_JOB_ID), m_asOwner);
      bRequires302Redirect = true;
      bClearFormDataAfterAction = true;
      break;
      case POSTTOSELF_ACTION_CREATE_FOLDER:
      String sName = null;
      sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERNAME);
      if (sValues == null)
      {
        log.Error("Could not get folder name.");
      } else
      {
        sName = sValues[0];
      }
      String sDesc = null;
      sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERDESCRIPTION);
      if (sValues == null)
      {
        log.Error("Could not get folder description.");
      } else
      {
        sDesc = sValues[0];
      }
      m_asObjMgrModel.CreateFolder(sName, sDesc);
      Redirect repostURL = new Redirect();
      repostURL.SetLinkGetCachedSpace(m_asOwner);
      repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      SetRedirect(repostURL);
      break;
      default:
      base.PerformAction(_nAction);
      break;
      }
      if (bRequires302Redirect)
      {
        Redirect safeRedirect = new Redirect();
        safeRedirect.SetLinkGetCachedSpace(m_asOwner);
        safeRedirect.SetIsHTTPRedirect(true);
        safeRedirect.SetControl(ObjMgrSettingsControl.STR_MVC_CLASS_NAME);
        safeRedirect.AddControlArgument(ObjMgrSettingsControl.FOLDER_ID, m_asObjMgrModel.GetCurrentFolderID());
        safeRedirect.AddControlArgument(ObjMgrSettingsControl.OBJECT_IDS,
         m_asObjMgrModel.GetExpandedObjectTypesString());
        SetRedirect(safeRedirect);
      }
      if (bClearFormDataAfterAction)
      {
        m_asObjMgrModel.ClearAllSelectedObjects();
      }
    }
    
    /// <summary>
    /// Save Object Manager settings
    /// </summary>
    protected override void SaveCurrentPage()
    {
      // Set basic settings
      String[] sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_FOLDER_ID);
      if (sValues == null)
      {
        log.Info("could not find folder ID in form data.");
        base.SaveCurrentPage();
        return;
      }
      int nFolderID = XPConvert.ToInteger(sValues[0]);
      int[] nExpandedObjectTypes;
      sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_OBJECT_IDS);
      if (sValues != null)
      {
        nExpandedObjectTypes = GeneralHelpers.ConvertToInts(sValues[0]);
      } else
      {
        nExpandedObjectTypes = new int[0];
      }
      m_asObjMgrModel.SetObjMgrSettings(nFolderID, nExpandedObjectTypes);
      // Set selected object IDs
      int[] nSelectedObjectIDs;
      for (int i = 0;i < nExpandedObjectTypes.Length;i++)
      {
        sValues = (String[]) m_htFormData.GetElement(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX);
        if ((sValues != null) && (sValues.Length > 0))
        {
          nSelectedObjectIDs = new int[sValues.Length];
          for (int j = 0;j < sValues.Length;j++)
          {
            try
            {
              nSelectedObjectIDs[j] = XPConvert.ToInteger(sValues[j]);
            }
            catch (Exception e)
            {
              log.Error("Unable to convert selected item to int: " + sValues[i]);
              nSelectedObjectIDs[j] = -1;
            }
          }
          m_asObjMgrModel.SetSelectedObjects(nExpandedObjectTypes[i], nSelectedObjectIDs);
          }
      }
      base.SaveCurrentPage();
    }
    /////////////////
    // Helper methods
    /////////////////
    
    /// <summary>
    /// This method handles the expand object type action
    /// </summary>
    private void ExpandObject()
    {
      String[] sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_EXPAND_OBJECT_ID);
      if (sValues == null)
      {
        log.Error("could not find class ID to expand in form data.");
        return;
      }
      int nClassID = XPConvert.ToInteger(sValues[0]);
      sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_EXPAND_BOOLEAN);
      if (sValues == null)
      {
        log.Error("could not find expand value in query string.");
        return;
      }
      bool bExpand = XPConvert.ToBoolean(sValues[0]);
      m_asObjMgrModel.ExpandObjectType(nClassID, bExpand);
    }
  }
}