using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This implements the admin directory for the root folder.
  /// </author>
  public class ObjMgrRootDP : PlumtreeDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.ObjMgrRootDP");
    public const String STR_MVC_CLASS_NAME = "ObjMgrRoot";
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()"></seealso>
    public override String GetSubtitleForBanner()
    {
      return "";
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()"></seealso>
    public override String GetTitleForBanner()
    {
      return m_asOwner.GetString(1266, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// helper display method for PlumtreeDP
    /// Fill in the body argument with HTML to display in the page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        result.AddInnerHTMLElement(m_asOwner.GetView(ObjMgrSearchView.STR_MVC_CLASS_NAME).Display());
        result.AddInnerHTMLElement(new HTMLBr());
        result.AddInnerHTMLElement(m_asOwner.GetView(ObjMgrHeaderView.STR_MVC_CLASS_NAME).Display());
        result.AddInnerHTMLElement(m_asOwner.GetView(FolderView.STR_MVC_CLASS_NAME).Display());
        }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to build HTML for admin directory. ");
      }
      return result;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from AFormDP can override
    /// if they like.  The method provides a hook into the head so that DP's can add javascript.
    /// Simply override and return and HTMLScript.  Also, it is best to return the results of the
    /// DisplayJavaScript functions from the appropriate views.
    /// </summary>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection scripts = new HTMLScriptCollection();
      //		scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjMgrSearchView.STR_MVC_CLASS_NAME).DisplayJavascript());
      scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjMgrHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return scripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#GetRepostTypeIsPost()"></seealso>
    protected override bool GetRepostTypeIsPost()
    {
      // GET submission
      return false;
    }
  }
}