using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This method sets the basic variables for the object manager:
  /// folder ID and the list of object types to expand
  /// </author>
  public class ObjMgrSettingsControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.ObjMgrSettingsControl");
    
    /// <summary>
    /// Name of this control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgrSettings";
    
    /// <summary>
    /// Query string parameters 
    /// </summary>
    public const String FOLDER_ID = "FolderID";
    public const String OBJECT_IDS = "ObjectIDs";
    private ObjMgrModel m_asModel;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#execute(XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String[] sValues = (String[]) arguments.GetElement(FOLDER_ID);
      if (sValues == null)
      {
        log.Error("could not find folder ID in query string.");
        return null;
      }
      int nFolderID;
      try
      {
        nFolderID = XPConvert.ToInteger(sValues[0]);
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to parse folder ID: " + sValues[0]);
        return null;
      }
      int[] nExpandedObjectTypes;
      sValues = (String[]) arguments.GetElement(OBJECT_IDS);
      if (sValues != null)
      {
        nExpandedObjectTypes = GeneralHelpers.ConvertToInts(sValues[0]);
      } else
      {
        nExpandedObjectTypes = new int[0];
      }
      m_asModel.SetObjMgrSettings(nFolderID, nExpandedObjectTypes);
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ObjMgrSettingsControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (ObjMgrModel) model;
    }
  }
}