using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This displays IPTObjects.
  /// </author>
  public class ObjMgrViewHelper : IObjectViewHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.ObjMgrViewHelper");
    
    /// <summary>
    /// checkbox prefix 
    /// </summary>
    public const String HTML_OBJECT_CHECKBOX_PREFIX = "in_cb_Object";
    
    /// <summary>
    /// checkbox suffix 
    /// </summary>
    public const String HTML_OBJECT_CHECKBOX_SUFFIX = "_ID";
    
    /// <summary>
    /// hidden subtype 
    /// </summary>
    public const String HTML_OBJECT_HIDDEN_SUBTYPE = "in_hi_subtype";
    
    /// <summary>
    /// spacer image to go after text to align it correctly 
    /// </summary>
    private HTMLImg m_TextSpacerImg = null;
    
    /// <summary>
    /// spacer image to go after date strings to align them correctly 
    /// </summary>
    private HTMLImg m_DateSpacerImg = null;
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#AddObjectViewHTML()"></seealso>
    public virtual HTMLElement AddObjectViewHTML(IObjectModelRO model)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#Display508Object(int,HTMLTable,IObjectModelRO,AActivitySpace)"></seealso>
    public virtual void Display508Object(int nObjectIndex, HTMLTable tableObjects,
     IObjectModelRO model, AActivitySpace parent)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayJavascriptCollection(AActivitySpace)"></seealso>
    public virtual HTMLScriptCollection DisplayJavascriptCollection(AActivitySpace asOwner,
     IObjectModelRO model)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#GetThereAreNoItemsString(AActivitySpace)"></seealso>
    public virtual String GetThereAreNoItemsString(AActivitySpace asOwner)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayObject(int,HTMLTable,IObjectModelRO)"></seealso>
    public virtual void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
     IObjectModelRO model, AActivitySpace parent)
    {
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       parent);
      // Output objects in this folder
      log.Debug("entering objmgrviewhelper number " + nObjectIndex);
      HTMLTableRow objectRow;
      HTMLTableCell myCell;
      HTMLInput myCheckbox;
      ASURL myURL;
      HTMLAnchor myAnchor;
      HTMLImg myImg;
      HTMLSpan mySpan;
      if (m_TextSpacerImg == null)
      {
        PTConstruct myConstruct = null;
        try
        {
          myConstruct = ConstructFactory.GetConstruct(PTImageType.SPACER);
          }
        catch (Exception ex)
        {
          log.Error(ex, "Unable to construct text spacer. ");
          myConstruct = null;
        }
        if (myConstruct != null)
        {
          m_TextSpacerImg = (HTMLImg) myConstruct.GetHTMLElement();
          m_TextSpacerImg.SetHeight("13");
          m_TextSpacerImg.SetWidth("1");
        }
      }
      if (m_DateSpacerImg == null)
      {
        PTConstruct myConstruct = null;
        try
        {
          myConstruct = ConstructFactory.GetConstruct(PTImageType.SPACER);
          }
        catch (Exception ex)
        {
          log.Error(ex, "Unable to construct date spacer. ");
          myConstruct = null;
        }
        if (myConstruct != null)
        {
          m_DateSpacerImg = (HTMLImg) myConstruct.GetHTMLElement();
          m_DateSpacerImg.SetHeight("14");
          m_DateSpacerImg.SetWidth("1");
        }
      }
      Object temp = model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_NAME);
      String strFullName;
      String strName;
      if (temp != null)
      {
        strFullName = XPConvert.ToString(temp);
        strName = GeneralHelpers.TruncateLongString(strFullName, ObjMgrAS.MAX_DISPLAYED_NAME_LENGTH,
         false);
        strFullName = XPHttpUtility.HtmlEncode(strFullName);
        strName = XPHttpUtility.HtmlEncode(strName);
      } else
      {
        strFullName = "";
        strName = "";
      }
      int nClassID = model.GetObjectType();
      int nObjectID = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
       PT_PROPIDS.PT_PROPID_OBJECTID));
      String strObjectID = XPConvert.ToString(nObjectID);
      log.Debug("ObjMgrViewHelper displaying object " + strName);
      // WilliamA - add sub-type checking 
      int nSubType = model.GetObjectSubType(nObjectIndex);
      try
      {
        objectRow = new HTMLTableRow();
        tableObjects.AddInnerHTMLElement(objectRow);
        objectRow.SetStyleClass(((nRowIndex % 2) == 0) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG);
        // Input selector for object
        myCell = new HTMLTableCell();
        objectRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("20");
        myCell.SetHeight("30");
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCheckbox = new HTMLInput(HTMLInputTypes.CHECKBOX, HTML_OBJECT_CHECKBOX_PREFIX + nClassID + HTML_OBJECT_CHECKBOX_SUFFIX,
         "checkbox for object");
        myCell.AddInnerHTMLElement(myCheckbox);
        myCheckbox.SetValue(strObjectID);
        if (model.GetIsObjectSelected(nObjectID))
        {
          myCheckbox.SetChecked(true);
        }
        // WilliamA - Add subtype hidden input if necessary for the object
        if (-1 != nSubType)
        {
          HTMLInput hiddenSubType = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_OBJECT_HIDDEN_SUBTYPE + nClassID,
           "subtype of object");
          myCell.AddInnerHTMLElement(hiddenSubType);
          hiddenSubType.SetValue(XPConvert.ToString(nSubType));
        }
        // Object Image
        myCell = new HTMLTableCell();
        objectRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("20");
        myCell.SetHeight("30");
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        try
        {
          ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
          myImg = ptClassTypeDescManager.GetDefaultIconForClassType(nClassID,
           strLangID);
          myImg.SetAlt(ptClassTypeDescManager.GetClassTypeLocalizedName(nClassID,
           strLangID));
          myCell.AddInnerHTMLElement(myImg);
        }
        catch (Exception e)
        {
          log.Error(e, "Display Object: Failed to create image.");
        }
        // Name and Description
        myCell = new HTMLTableCell();
        objectRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetWidth("60%");
        myCell.SetHeight("30");
        myAnchor = new HTMLAnchor(PTOpenerLinks.GetOpenerURLOpenObjID(nClassID,
         nObjectID, IPTOpenerConstants.OPENER_MODE_EDIT, parent));
        myAnchor.SetTitle(strFullName);
        // We already encoded it
        myAnchor.AddInnerHTMLString(strName);
        myCell.AddInnerHTMLElement(myAnchor);
        if (m_TextSpacerImg != null)
        {
          myCell.AddInnerHTMLElement(m_TextSpacerImg);
        }
        myCell.AddInnerHTMLElement(new HTMLBr());
        String strDescription = (String) model.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_DESCRIPTION);
        if (strDescription != null)
        {
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
          mySpan.AddInnerHTMLEncodedString(strDescription);
        }
        XPDateFormat xpDateTimeFormat = ((ObjMgrAS) parent).GetDateFormat();
        // Jobs have different columns than everyone else
        if (nClassID == PT_CLASSIDS.PT_JOB_ID)
        {
          // Last Modified Date
          String strModifiedDate = GetDateString(model.GetObjectFields(nObjectIndex,
           PT_PROPIDS.PT_PROPID_LASTMODIFIED), xpDateTimeFormat, "last modified");
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(strModifiedDate);
          myCell.SetStyleClass(PTStyleClass.LIST_DATE_TEXT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_DateSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_DateSpacerImg);
          }
          // Created Date
          String strCreatedDate = GetDateString(model.GetObjectFields(nObjectIndex,
           PT_PROPIDS.PT_PROPID_CREATED), xpDateTimeFormat, "created");
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(strCreatedDate);
          myCell.SetStyleClass(PTStyleClass.LIST_DATE_TEXT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_DateSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_DateSpacerImg);
          }
          // Last Run Date
          String strLastRunDate = GetDateString(model.GetObjectFields(nObjectIndex,
           PT_PROPIDS.PT_PROPID_JOB_LASTRUNTIME), xpDateTimeFormat, "last run");
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(strLastRunDate);
          myCell.SetStyleClass(PTStyleClass.LIST_DATE_TEXT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_DateSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_DateSpacerImg);
          }
          // Next Run Date
          String strNextRunDate = GetDateString(model.GetObjectFields(nObjectIndex,
           PT_PROPIDS.PT_PROPID_JOB_NEXTRUNTIME), xpDateTimeFormat, "next run");
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(strNextRunDate);
          myCell.SetStyleClass(PTStyleClass.LIST_DATE_TEXT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_DateSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_DateSpacerImg);
          }
          // Job Status
          temp = model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_JOB_LASTRUNTIME_STATUS);
          String strJobStatus;
          PTStyleClass ptJobStatusStyle;
          if (temp != null)
          {
            int nIntStatus = XPConvert.ToInteger(temp);
            if (nIntStatus == PT_JOBSTATUS.PT_JOBSTATUS_FAILED)
            {
              ptJobStatusStyle = PTStyleClass.ALERT_ERROR_TEXT;
            } else
            {
              ptJobStatusStyle = PTStyleClass.LIST_TEXT;
            }
            strJobStatus = GetStatusString(nIntStatus, parent);
          } else
          {
            ptJobStatusStyle = PTStyleClass.LIST_TEXT;
            strJobStatus = "";
          }
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.SetStyleClass(ptJobStatusStyle);
          myCell.AddInnerHTMLString(strJobStatus);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_TextSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_TextSpacerImg);
          }
        } else
        {
          // Last Modified Date
          String strModifiedDate = GetDateString(model.GetObjectFields(nObjectIndex,
           PT_PROPIDS.PT_PROPID_LASTMODIFIED), xpDateTimeFormat, "last modified");
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(strModifiedDate);
          myCell.SetStyleClass(PTStyleClass.LIST_DATE_TEXT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_DateSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_DateSpacerImg);
          }
          // Created Date
          String strCreatedDate = GetDateString(model.GetObjectFields(nObjectIndex,
           PT_PROPIDS.PT_PROPID_CREATED), xpDateTimeFormat, "created");
          myCell = new HTMLTableCell();
          objectRow.AddInnerHTMLElement(myCell);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLString(strCreatedDate);
          myCell.SetStyleClass(PTStyleClass.LIST_DATE_TEXT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          myCell.SetWidth("20%");
          myCell.SetHeight("30");
          if (m_DateSpacerImg != null)
          {
            myCell.AddInnerHTMLElement(m_DateSpacerImg);
          }
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error in ObjMgrViewHelper.");
      }
      log.Debug("leaving objmgrviewhelper number " + nObjectIndex);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#SetExpandButton(HTMLAnchor)"></seealso>
    public virtual void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model)
    {
      try
      {
        anchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        anchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_EXPAND_TYPE + "(" + model.GetObjectType() + ", " + XPStringUtility.ToLowerCase(XPConvert.ToString(model.GetObjectViewIsCollapsed())) + "); return false;");
        }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to set javascript on object expand button.");
        }
    }
    
    /// <summary>
    /// This helper function translates date objects into localized
    /// date strings.
    /// </summary>
    /// <param name="Object">the date object</param>
    /// <param name="XPDateFormat">the localized date format object</param>
    /// <param name="String">
    /// the name of the date to display in an error message
    /// if the date cannot be converted correctly.
    /// </param>
    /// <returns>String the localized date string.  "" if couldn't convert object.</returns>
    public virtual String GetDateString(Object dateObject, XPDateFormat xpDateTimeFormat,
     String strDateName)
    {
      if (dateObject == null)
      {
        return "";
      }
      try
      {
        XPDateTime dtModifiedDate = (XPDateTime) dateObject;
        return xpDateTimeFormat.Format(dtModifiedDate);
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to convert " + strDateName + " date.");
      }
      return "";
    }
    
    /// <summary>
    /// This helper function translates PT_JOBSTATUS numbers into localized
    /// string values
    /// </summary>
    public virtual String GetStatusString(int intStatus, AActivitySpace asOwner)
    {
      // TODO: this should be combined with the version in the HistoryViewHelper
      // and moved to a static helper
      switch (intStatus){
      case PT_JOBSTATUS.PT_JOBSTATUS_FAILED:
      return asOwner.GetString(76, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_INPROCESS;
      case PT_JOBSTATUS.PT_JOBSTATUS_INPROCESS:
      return asOwner.GetString(77, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_INTERRUPTED;
      case PT_JOBSTATUS.PT_JOBSTATUS_INTERRUPTED:
      return asOwner.GetString(78, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_INVALID;
      case PT_JOBSTATUS.PT_JOBSTATUS_INVALID:
      return asOwner.GetString(79, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_SAVINGCHECKPOINT;
      case PT_JOBSTATUS.PT_JOBSTATUS_SAVINGCHECKPOINT:
      return asOwner.GetString(80, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_SUCCEEDED;
      case PT_JOBSTATUS.PT_JOBSTATUS_SUCCEEDED:
      return asOwner.GetString(81, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_SUSPENDED;
      case PT_JOBSTATUS.PT_JOBSTATUS_SUSPENDED:
      return asOwner.GetString(82, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_SUSPENDING;
      case PT_JOBSTATUS.PT_JOBSTATUS_SUSPENDING:
      return asOwner.GetString(83, "ptmsgs_portalcommonmsgs");
      goto case PT_JOBSTATUS.PT_JOBSTATUS_KILLREQUESTED;
      case PT_JOBSTATUS.PT_JOBSTATUS_KILLREQUESTED:
      return asOwner.GetString(633, "ptmsgs_portalcommonmsgs");
      goto default;
      default:
      return asOwner.GetString(84, "ptmsgs_portalcommonmsgs");
      break;
      }
    }
  }
}