using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.portaluiinfrastructure.tree.template;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr
{
  /// <author>
  /// Don Hayler
  /// This class contains static methods that implement IPTObject specific
  /// code that doesn't really belong in the main Object Manager classes.
  /// This includes special javascript for popping up trees before redirecting
  /// to editors (for extensible providers) and special object action code like
  /// Run Once (for Jobs).
  /// </author>
  public class StaticPTObjectHelpers
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.StaticPTObjectHelpers");
    
    /// <summary>
    /// JavaScript function names.
    /// </summary>
    public const String JAVASCRIPT_OPEN_TREE = "OpenTree";
    public const String JAVASCRIPT_START_EDITOR = "StartEditor";
    
    /// <summary>
    /// AGC- This method should be used to start the Portlet Editor (special
    /// case). It will return the JavaScript method to open the tree and the one
    /// to start the Editor.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_nClassID">Object class ID</param>
    /// <param name="_sURLToEditor">URL to start the Editor</param>
    /// <param name="_sProvClassID">Provider Class ID (CLSID)</param>
    /// <returns>XPStringBuilder</returns>
    public static XPStringBuilder GetJavaScriptForPortletEditor(AActivitySpace _asOwner,
     String _sURLToEditor)
    {
      // The URL to open a new tree
      ASURL myTree = new ASURL(_asOwner);
      myTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, _asOwner);
      myTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
      myTree.AddControlArgument(StartTreeControl.MULTI_SELECT, false);
      myTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
      myTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, TreeConstants.N_JAVASCRIPTSUBMIT);
      myTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, JAVASCRIPT_START_EDITOR + PT_CLASSIDS.PT_GADGET_ID);
      myTree.AddControlArgument(StartTreeControl.HELP_TOPIC, "PT_ChooseTemplateorWebService");
      // AGC - The filter to show only the appropriate Web Services:
      // portlet, intrinsic portlet, and pagelet
      myTree.AddControlArgument(StartTreeControl.QUERY_FILTER, XPConvert.ToString(PT_CLASSIDS.PT_WEBSERVICE_ID) + "," + XPConvert.ToString(PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID) + "," + XPConvert.ToString(WSModelHelper.WSTYPE_IGP) + "," + XPConvert.ToString(WSModelHelper.WSTYPE_HTTPGP) + "," + XPConvert.ToString(WSModelHelper.WSTYPE_HTTPPAGELET));
      // AGC- for portlets, we are displaying a tree of both Portlet Templates AND
      // Web Services of the appropriate ProviderCLSID (filtered above).
      myTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY, PT_CLASSIDS.PT_GADGETTEMPLATE_ID + "," + PT_CLASSIDS.PT_WEBSERVICE_ID);
      myTree.AddControlArgument(StartTreeControl.TITLE, _asOwner.GetString(1985,
       "ptmsgs_portaladminmsgs"));
      myTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, _asOwner.GetString(1988,
       "ptmsgs_portaladminmsgs"));
      myTree.SetSubSpaceKey(_asOwner.GetName());
      XPStringBuilder sb = new XPStringBuilder(400);
      sb.Append("\n");
      // Open Tree function
      sb.Append("function " + JAVASCRIPT_OPEN_TREE + PT_CLASSIDS.PT_GADGET_ID + "()\n");
      sb.Append("{\n");
      sb.Append("    window.open(\'").Append(myTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
      sb.Append("}\n");
      sb.Append("\n");
      // On return from Tree function
      sb.Append(" function " + JAVASCRIPT_START_EDITOR + PT_CLASSIDS.PT_GADGET_ID + "(myArray)\n");
      sb.Append(" {\n");
      sb.Append("   if ((myArray) && (myArray.length > 0)) \n");
      sb.Append("   {\n");
      // AGC- Get the CLASSID and OBJECTID of the selected object from the Tree and pass it to the Portlet Editor
      sb.Append(" \twindow.location = \'").Append(_sURLToEditor);
      sb.Append(LinkConstants.AMPERSAND).Append(PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_CLASSID).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(ATreeAS.OBJECT_CLASS_ID).Append("+ \'");
      sb.Append(LinkConstants.AMPERSAND).Append(PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_ID).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID);
      sb.Append(";\n");
      sb.Append("   }\n");
      sb.Append(" }\n");
      return sb;
    }
    
    /// <summary>
    /// MJD- This method should be used to start the Page Editor (special
    /// case). It will return the JavaScript method to open the tree and the one
    /// to start the Editor.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_sURLToEditor">URL to start the Editor</param>
    /// <returns>XPStringBuilder</returns>
    public static XPStringBuilder GetJavaScriptForPageEditor(AActivitySpace _asOwner,
     String _sURLToEditor)
    {
      ASURL myNewTree = new ASURL(_asOwner);
      myNewTree.SetLinkCreateNewSpace(TemplateTreeAS.STR_MVC_CLASS_NAME, _asOwner);
      myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
      myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
      myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, TreeConstants.N_JAVASCRIPTSUBMIT);
      myNewTree.AddControlArgument(StartTreeControl.TITLE, _asOwner.GetString(315,
       "ptmsgs_portalbrowsingmsgs"));
      myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, _asOwner.GetString(316,
       "ptmsgs_portalbrowsingmsgs"));
      myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       PT_CLASSIDS.PT_PAGETEMPLATE_ID);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, JAVASCRIPT_START_EDITOR + PT_CLASSIDS.PT_PAGE_ID);
      XPStringBuilder sb = null;
      try
      {
        sb = new XPStringBuilder(400);
        sb.Append("\n");
        // Open Tree function
        sb.Append("function " + JAVASCRIPT_OPEN_TREE + PT_CLASSIDS.PT_PAGE_ID + "()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("}\n");
        sb.Append("\n");
        // On return from Tree function
        sb.Append(" function " + JAVASCRIPT_START_EDITOR + PT_CLASSIDS.PT_PAGE_ID + "(myArray)\n");
        sb.Append(" {\n");
        sb.Append("   if ((myArray) && (myArray.length > 0)) \n");
        sb.Append("   {\n");
        // MJD- Get the CLASSID and OBJECTID of the selected object from the Tree and pass it to the Page Editor
        sb.Append(" \twindow.location = \'").Append(_sURLToEditor);
        sb.Append(LinkConstants.AMPERSAND).Append(PTPages.PAGE_EDITOR_QS_INT_PAGE_TEMPLATE_OBJECT_ID).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID).Append("+ \'");
        sb.Append(LinkConstants.AMPERSAND).Append(PTPages.PAGE_EDITOR_QS_INT_PAGE_TEMPLATE_INHERIT).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(TemplateTreeAS.INHERIT_OBJECT);
        sb.Append(";\n");
        sb.Append("   }\n");
        sb.Append(" }\n");
      }
      catch (HTMLException he)
      {
        log.Error(he, "StaticPTObjectHelpers::GetJavaScriptForPageEditor An error occured when trying to display the JavaScript.");
        }
      return sb;
    }
    
    /// <summary>
    /// MJD- This method should be used to start the Community Editor (special
    /// case). It will return the JavaScript method to open the tree and the one
    /// to start the Editor.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_sURLToEditor">URL to start the Editor</param>
    /// <returns>XPStringBuilder</returns>
    public static XPStringBuilder GetJavaScriptForCommunityEditor(AActivitySpace _asOwner,
     String _sURLToEditor)
    {
      ASURL myNewTree = new ASURL(_asOwner);
      myNewTree.SetLinkCreateNewSpace(TemplateTreeAS.STR_MVC_CLASS_NAME, _asOwner);
      myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
      myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
      myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, TreeConstants.N_JAVASCRIPTSUBMIT);
      myNewTree.AddControlArgument(StartTreeControl.TITLE, _asOwner.GetString(1877,
       "ptmsgs_portalbrowsingmsgs"));
      myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, _asOwner.GetString(1878,
       "ptmsgs_portalbrowsingmsgs"));
      myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, JAVASCRIPT_START_EDITOR + PT_CLASSIDS.PT_COMMUNITY_ID);
      XPStringBuilder sb = null;
      try
      {
        sb = new XPStringBuilder(400);
        sb.Append("\n");
        // Open Tree function
        sb.Append("function " + JAVASCRIPT_OPEN_TREE + PT_CLASSIDS.PT_COMMUNITY_ID + "()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(myNewTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("}\n");
        sb.Append("\n");
        // On return from Tree function
        sb.Append(" function " + JAVASCRIPT_START_EDITOR + PT_CLASSIDS.PT_COMMUNITY_ID + "(myArray)\n");
        sb.Append(" {\n");
        sb.Append("   if ((myArray) && (myArray.length > 0)) \n");
        sb.Append("   {\n");
        // MJD- Get the CLASSID and OBJECTID of the selected object from the Tree and pass it to the Community Editor
        sb.Append(" \twindow.location = \'").Append(_sURLToEditor);
        sb.Append(LinkConstants.AMPERSAND).Append(PTCommunities.COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID).Append("+ \'");
        sb.Append(LinkConstants.AMPERSAND).Append(PTCommunities.COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT).Append(LinkConstants.EQUALS).Append("\' + myArray[0].").Append(TemplateTreeAS.INHERIT_OBJECT);
        sb.Append(";\n");
        sb.Append("   }\n");
        sb.Append(" }\n");
      }
      catch (HTMLException he)
      {
        log.Error(he, "StaticPTObjectHelpers::GetJavaScriptForCommunityEditor An error occured when trying to display the JavaScript.");
        }
      return sb;
    }
    
    /// <summary>
    /// JF- This method should be used to start remote Editors.
    /// It will return the JavaScript method to open the tree
    /// and the one to start the Editor.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_nClassID">Object class ID</param>
    /// <param name="_sURLToEditor">URL to start the Editor</param>
    /// <param name="_sProvClassID">Provider Class ID (CLSID)</param>
    /// <returns>XPStringBuilder</returns>
    public static XPStringBuilder GetJavaScriptForRemoteEditor(AActivitySpace _asOwner,
     int _nClassID, String _sURLToEditor, String _sProvCLSID, String _sProvEngName)
    {
      // JF- Each tree has to be filtered by the provider class ID
      String sFilter = "";
      if (PT_CLASSIDS.PT_CRAWLER_ID == _nClassID)
      {
        sFilter+=(PT_CLASSIDS.PT_DATASOURCE_ID + ",");
        sFilter+=(PT_PROPIDS.PT_PROPID_DS_PROVIDERCLSID + ",");
      } else
      {
        sFilter+=(PT_CLASSIDS.PT_WEBSERVICE_ID + ",");
        sFilter+=(PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID + ",");
      }
      sFilter+=(PT_FILTEROPS.PT_FILTEROP_EQ + ",");
      sFilter+=_sProvCLSID;
      // The URL to open a new tree
      ASURL myTree = new ASURL(_asOwner);
      myTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, _asOwner);
      myTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
      myTree.AddControlArgument(StartTreeControl.MULTI_SELECT, false);
      myTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
      myTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, TreeConstants.N_JAVASCRIPTSUBMIT);
      myTree.AddControlArgument(StartTreeControl.QUERY_FILTER, sFilter);
      myTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, JAVASCRIPT_START_EDITOR + _nClassID + _sProvEngName);
      myTree.SetSubSpaceKey(_asOwner.GetName());
      // JF- For crawlers we are displaying a tree of DataSources and for the other ones, a tree of Web Services.
      if (PT_CLASSIDS.PT_CRAWLER_ID == _nClassID)
      {
        myTree.AddControlArgument(StartTreeControl.HELP_TOPIC, "PT_ChooseDataSource");
        myTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY, PT_CLASSIDS.PT_DATASOURCE_ID);
        myTree.AddControlArgument(StartTreeControl.TITLE, _asOwner.GetString(1983,
         "ptmsgs_portaladminmsgs"));
        myTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, _asOwner.GetString(1986,
         "ptmsgs_portaladminmsgs"));
      } else
      {
        // mj: set the help topic
        myTree.AddControlArgument(StartTreeControl.HELP_TOPIC, "PT_ChooseWebService");
        myTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY, PT_CLASSIDS.PT_WEBSERVICE_ID);
        myTree.AddControlArgument(StartTreeControl.TITLE, _asOwner.GetString(1984,
         "ptmsgs_portaladminmsgs"));
        myTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, _asOwner.GetString(1987,
         "ptmsgs_portaladminmsgs"));
      }
      XPStringBuilder sb = new XPStringBuilder(400);
      sb.Append("\n");
      // Open Tree function
      sb.Append("function " + JAVASCRIPT_OPEN_TREE + _nClassID + _sProvEngName + "()\n");
      sb.Append("{\n");
      sb.Append("    window.open(\'").Append(myTree.GetURLAsString()).Append("\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
      sb.Append("}\n");
      sb.Append("\n");
      // On return from Tree function
      sb.Append(" function " + JAVASCRIPT_START_EDITOR + _nClassID + _sProvEngName + "(myArray)");
      sb.Append(" {");
      sb.Append("   if ((myArray) && (myArray.length > 0)) \n");
      sb.Append("   {");
      if (PT_CLASSIDS.PT_CRAWLER_ID == _nClassID)
      {
        sb.Append(" \twindow.location = \'").Append(_sURLToEditor).Append(LinkConstants.AMPERSAND).Append(XUIHelperMethods.QS_XUI_DATASOURCE_ID).Append("=\' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID).Append(";");
        } else
      {
        sb.Append(" \twindow.location = \'").Append(_sURLToEditor).Append(LinkConstants.AMPERSAND).Append(XUIHelperMethods.QS_XUI_WEBSERVICE_ID).Append("=\' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID).Append(";");
        }
      sb.Append("   }");
      sb.Append(" }");
      return sb;
    }
    
    /// <summary>
    /// This method runs a set of jobs once.
    /// </summary>
    /// <param name="int[]">an array of the object IDs of the jobs to run.</param>
    public static void RunJobsOnce(int[] nJobIDs, AActivitySpace asOwner)
    {
      IPTSession ptSession = (IPTSession) asOwner.GetUserSession();
      if ((nJobIDs != null) && (nJobIDs.Length > 0))
      {
        for (int i = 0;i < nJobIDs.Length;i++)
        {
          try
          {
            IPTJob ptJob = (IPTJob) ptSession.GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).Open(nJobIDs[i],
             false);
            //Get the name of the job we want to run once
            String strJobName = ptJob.GetLocalizedName();
            //Clone the job to be run and retrieve its objectid
            int intNewJobID = ptSession.GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).Clone(nJobIDs[i],
             strJobName + asOwner.GetString(1989, "ptmsgs_portaladminmsgs"));
            //Open and lock the newly cloned version of the job
            ptJob = (IPTJob) ptSession.GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).Open(intNewJobID,
             true);
            //Set the delete when done property so the job will delete itself after running
            ptJob.SetDeleteWhenDone(true);
            IPTSchedule ptSchedule = ptJob.GetSchedule();
            //JH- Get a XPDateTime set to Dec 31, 1999.  This will ensure
            //that the job runs immediately regarless of any time zone or client/server time differences.
            XPCalendar myCalendar = XPCalendar.GetInstance(1999, 12, 31);
            XPDateTime xpdtNextRun = myCalendar.GetTime();
            //Set the schedule type to run once
            ptSchedule.SetScheduleType(PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE);
            //Set the start date and time
            ptJob.SetSettings(PT_JOB_SETTINGS.PT_JOB_NEXTRUNTIME, xpdtNextRun);
            ptSchedule.SetStartTimestamp(xpdtNextRun);
            //Store the job
            ptJob.Store();
            ptJob.UnlockObject();
          }
          catch (Exception e)
          {
            XPResourceManager rm = PTConfigHelper.GetResourceManager();
            String _strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
             asOwner);
            log.Error(e, XPResourceManager.FormatMessage(rm.GetString(1267,
             "ptmsgs_portaladminmsgs", _strLangID), nJobIDs[i]));
            throw new XPException(asOwner.GetString(1267, "ptmsgs_portaladminmsgs") + nJobIDs[i],
             e);
          }
        }
      }
    }
  }
}