using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr.popups
{
  /// <author>Don Hayler</author>
  public class ObjMgrABOLinksView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.popups.ObjMgrABOLinksView");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgrABOLinks";
    
    /// <summary>
    /// HTML Object names 
    /// </summary>
    public const String HTMLBUTTON_CLOSE = "in_bu_Close";
    
    /// <summary>
    /// javascript function names 
    /// </summary>
    public const String JAVASCRIPT_OPEN_JOB = "OpenJob";
    
    /// <summary>
    /// mvc objects 
    /// </summary>
    internal AActivitySpace m_asOwner;
    internal IObjMgrModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ObjMgrABOLinksView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement result = new HTMLElementCollection();
      HTMLSpan mySpan;
      HTMLTable myTable;
      HTMLInput myInput;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        // Links
        mySpan = new HTMLSpan();
        result.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        // Message stating where the ABO jobs were created.
        mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(2557,
         ResourceConstants.PORTALADMINMSGS), m_asModel.GetABOJobFolderName()));
        int[] nJobIDs = m_asModel.GetABOJobIDs();
        String[] nJobNames = m_asModel.GetABOJobNames(nJobIDs);
        for (int i = 0;i < nJobIDs.Length;i++)
        {
          if (nJobIDs[i] != -1)
          {
            mySpan.AddInnerHTMLElement(new HTMLBr());
            mySpan.AddInnerHTMLElement(ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(nJobNames[i]),
             JAVASCRIPT_OPEN_JOB + "(" + nJobIDs[i] + ")"));
          }
        }
        // Add buttons
        result.AddInnerHTMLElement(new HTMLComment("Begin: Footer buttons table"));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("10");
        // 1st Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Close button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick("window.close(); return false;");
        result.AddInnerHTMLElement(new HTMLComment("End: Footer buttons table"));
        }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create warnings.");
        result = new HTMLGenericElement(m_asOwner.GetString(1209, "ptmsgs_portaladminmsgs"));
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      ASURL myURL = new ASURL(m_asOwner);
      myURL.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME, m_asOwner);
      myURL.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
      myURL.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID, PT_CLASSIDS.PT_JOB_ID);
      // This must be last so we can append the object ID
      myURL.AddControlArgument(IPTOpenerConstants.STR_QS_OBJECTID);
      // JavaScript to open the create folder popup
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n").Append("function ").Append(JAVASCRIPT_OPEN_JOB).Append("(nID)\n").Append("{\n").Append("  window.open(\'").Append(myURL.GetURLAsString()).Append("\' + nID, \'_jobpopup\', \'\');\n").Append("}\n");
      try
      {
        // Add script
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create javascript.");
        return null;
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_asModel = (IObjMgrModelRO) model;
    }
  }
}