using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objmgr.popups
{
  /// <author>Don Hayler</author>
  public class ObjMgrDeleteWarningsView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objmgr.popups.ObjMgrDeleteWarningsView");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjMgrDeleteWarnings";
    
    /// <summary>
    /// HTML Object names 
    /// </summary>
    public const String HTMLBUTTON_APPLY_NOW = "in_bu_ApplyNow";
    
    /// <summary>
    /// Apply later button 
    /// </summary>
    public const String HTMLBUTTON_APPLY_LATER = "in_bu_ApplyLater";
    
    /// <summary>
    /// Cancel Button 
    /// </summary>
    public const String HTMLBUTTON_CANCEL = "in_bu_Cancel";
    
    /// <summary>
    /// javascript function name - deleteNowOnOpener 
    /// </summary>
    public const String JAVASCRIPT_DELETE_NOW_ON_OPENER = "deleteNowOnOpener";
    
    /// <summary>
    /// javascript function name - deleteLaterOnOpener 
    /// </summary>
    public const String JAVASCRIPT_DELETE_LATER_ON_OPENER = "deleteLaterOnOpener";
    
    /// <summary>
    /// mvc objects 
    /// </summary>
    internal AActivitySpace m_asOwner;
    internal IObjMgrDeleteRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ObjMgrDeleteWarningsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLInput myInput;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLBr myBr = new HTMLBr();
      bool bFolders = m_asModel.CheckFoldersForDelete();
      bool bPageTemplates = m_asModel.CheckPageTemplatesForDelete();
      try
      {
        //Create a banner table
        result.AddInnerHTMLElement(new HTMLComment("Begin: BANNER table"));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing("10");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(2443, "ptmsgs_portaladminmsgs"));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myRow.AddInnerHTMLElement(myCell);
        if (m_asModel.CheckAuthSourceForDelete())
        {
          myCell.AddInnerHTMLString(m_asOwner.GetString(1217, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(myBr);
          myCell.AddInnerHTMLElement(myBr);
        }
        if (bPageTemplates)
        {
          myCell.AddInnerHTMLString(m_asOwner.GetString(2168, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(myBr);
          myCell.AddInnerHTMLElement(myBr);
        }
        if (bFolders)
        {
          myCell.AddInnerHTMLString(m_asOwner.GetString(1216, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(myBr);
          myCell.AddInnerHTMLElement(myBr);
        }
        myCell.AddInnerHTMLString(m_asOwner.GetString(1215, "ptmsgs_portaladminmsgs"));
        myCell.AddInnerHTMLElement(myBr);
        myCell.AddInnerHTMLElement(myBr);
        if (bFolders || bPageTemplates)
        {
          myCell.AddInnerHTMLString(m_asOwner.GetString(1218, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(myBr);
          myCell.AddInnerHTMLElement(myBr);
        }
        result.AddInnerHTMLElement(new HTMLComment("End: BANNER table"));
        // Add buttons
        result.AddInnerHTMLElement(new HTMLComment("Begin: Footer buttons table"));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing("10");
        // 1st Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetHeight("20");
        myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        // Apply Now button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_APPLY_NOW,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1212, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick(JAVASCRIPT_DELETE_NOW_ON_OPENER + "(); return false;");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        if (bFolders || bPageTemplates)
        {
          // Apply Later button
          myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_APPLY_LATER,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetValue(m_asOwner.GetString(1213, "ptmsgs_portaladminmsgs"));
          myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          myInput.SetOnClick(JAVASCRIPT_DELETE_LATER_ON_OPENER + "(); return false;");
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        }
        // Cancel button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1214, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick("window.close(); return false;");
        result.AddInnerHTMLElement(new HTMLComment("End: Footer buttons table"));
        }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create warnings.");
        result = new HTMLGenericElement(m_asOwner.GetString(1215, "ptmsgs_portaladminmsgs"));
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      // JavaScript to open the create folder popup
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(300);
      // javascript functions
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_DELETE_NOW_ON_OPENER).Append("()\n");
      sb.Append("{\n");
      sb.Append("  opener.").Append(ObjMgrHeaderView.JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_DELETE).Append(");\n");
      sb.Append("  window.close();\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_DELETE_LATER_ON_OPENER).Append("()\n");
      sb.Append("{\n");
      sb.Append("  opener.").Append(ObjMgrHeaderView.JAVASCRIPT_SUBMIT_BY_POST).Append("(").Append(ObjMgrRepostControl.POSTTOSELF_ACTION_DELETE_LATER).Append(");\n");
      sb.Append("  window.close();\n");
      sb.Append("}\n");
      sb.Append("\n");
      try
      {
        // Add script
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to create javascript.");
        return null;
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_asModel = (IObjMgrDeleteRO) model;
    }
  }
}