using System;
using com.plumtree.portalpages.browsing.search.advanced;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portalpages.admin.objsearch
{
  /// <author>
  /// Matt Fryer
  /// This is the "Search Again" view of the admin search searchbox. Advanced Search link goes in here
  /// when we get to that.
  /// </author>
  public class AdminFollowupSearchView : IView
  {
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AdminFollowupSearchView";
    
    /// <summary>
    /// form name *
    /// </summary>
    public const String FORM_NAME = "searchform";
    public const String SEPARATOR = "&nbsp;|&nbsp;&nbsp;&nbsp;";
    
    /// <summary>
    /// localized strings 
    /// </summary>
    protected AActivitySpace m_asOwner;
    protected ISearchResultModelRO _model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new AdminFollowupSearchView();
    }
    
    /// <summary>
    /// Returns an icon and link for advanced search. The link includes a control argument that will
    /// restrict the search to the admin hierarchy and another which will cause the results to be displayed
    /// with checkboxes and a toolbar.
    /// </summary>
    /// <param name="m_asOwner"></param>
    /// <returns></returns>
    public static HTMLElement GetAdvancedAdminSearchLink(AActivitySpace m_asOwner)
    {
      // Advanced Search Link
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkCreateNewSpace(AdvancedSearchAS.STR_MVC_CLASS_NAME, m_asOwner);
      url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, com.plumtree.uiinfrastructure.editor.EditorStartControl.EDITOR_START_FLAG_MISC);
      //Setting this to 1 will cause the adv search page to come up with the top level
      // admin folder selected in the folder view.
      url.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S,
       1);
      // We want advanced search results to come up in admin mode.
      url.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, SearchPageModeHelper.ADMIN_MODE);
      // Start off with all admin types checked, but not collab or content.
      // Need to list all the searchable admin types here.. sort of a pain
      String objtypeKey = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S;
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGETTEMPLATE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_AUTHSOURCE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_FILTER_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_SAVEDSEARCH_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_DATASOURCE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_DOCUMENTTYPE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_CRAWLER_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_INVITATION_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_FEDERATEDPORTAL_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGETBUNDLE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PAGETEMPLATE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_JOB_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PAGE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_SUBPORTAL_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_WEBSERVICE_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_EXTOPERATION_ID));
      url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PROFILESOURCE_ID));
      HTMLImg icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED,
       true, m_asOwner).GetHTMLElement();
      icon.SetAlign("absmiddle");
      icon.SetBorder("0");
      url.AddInnerHTMLElement(icon);
      url.AddInnerHTMLString("   ");
      url.AddInnerHTMLString(m_asOwner.GetString(815, "ptmsgs_portalbrowsingmsgs"));
      HTMLElementCollection coll = new HTMLElementCollection();
      coll.AddInnerHTMLString(SEPARATOR);
      coll.AddInnerHTMLElement(url.GetURLAsHTMLElement());
      return coll;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      // If the last search failed..
      if (null != _model.GetError())
      {
        // Usually this is null. Sometimes it is an un-internationalized error message.
        return _model.GetError().GetComment();
      }
      int adminFolderID = 1;
      // Try to figure out what folder we are in
      int[] folderIDs = _model.GetAdminFolderRestrictions();
      if ((null != folderIDs) && (1 == folderIDs.Length))
      {
        adminFolderID = folderIDs[0];
      }
      HTMLElement form = AdminSearchForm.GetObjectSearchForm(m_asOwner, 
      // Give the form a unique name
      /* name= */
      FORM_NAME, 
      // When form is submitted, results appear on page SampleResultsDP of the current space
      // null, 
      AdminSearchAS.STR_MVC_CLASS_NAME, 
      //  null, 
      m_asOwner.GetSpaceID(), 
      // null, 
      AdminSearchDP.STR_MVC_CLASS_NAME, 
      // Display a prompt
      /* prompt= */
      m_asOwner.GetString(2538, "ptmsgs_portaladminmsgs"), 
      // Restrict to this folder
      /* currentAdminFolder= */
      adminFolderID, 
      // No object type restriction; type is selectable from a pulldown
      /* objectClassIDs= */
      null, 
      // Not needed if you've implemented your own view of search results
      /* makeEditLinks= */
      true, /* return complete form= */
      true, /* overrideEnclosingForm */
      false, /* additionalElements */
      GetAdvancedAdminSearchLink(m_asOwner), /* validate alert */
      true);
      return form;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      // by default, return nothing
      return null;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      _model = (ISearchResultModelRO) model;
    }
  }
}