using System;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portalpages.admin.objmgr.popups;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.portalpagesperf;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.admin.objsearch
{
  /// <summary>
  /// ActivitySpace for admin search. 
  /// </summary>
  /// <author>Matt Fryer</author>
  public class AdminSearchAS : PlumtreeAS
  {
    public const String STR_MVC_CLASS_NAME = "AdminObjSearch";
    public override Object Create()
    {
      return new AdminSearchAS();
    }
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // Check if this server is configured to be used as an administration machine.
      // 0 means browsing, 1 means admin
      if (PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.ADMINISTRATION_SECTION,
       PTConfigConstants.IS_ADMIN_SITE_SUBSECTION, PTConfigConstants.VALUE_ATTRIBUTE,
       this) != 1)
      {
        return false;
      }
      // DCA - call super to register nav views;
      base.CheckBasicAccess(strPage, strControl, bSameSpace);
      return ((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      }
    public override void Init()
    {
      base.Init();
      IntegratedSearchAS.RegisterSearchClasses(this);
      // bump up the admin search counter
      PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_ADMIN_SEARCHES);
      // Get the search model that was registered by IntegratedSearchAS
      IModel model = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
      // Initialize helper class that holds info about whether we're in browse vs. edit mode
      ((ISearchResultModel) model).SetPageMode(SearchPageModeHelper.ADMIN_MODE);
      SearchPageModeHelper pageMode = new SearchPageModeHelper();
      pageMode.Init((SearchResultModel) model, this);
      //Tell the model this is an admin object search.
      ((ISearchResultModel) model).SetPageMode(SearchPageModeHelper.ADMIN_MODE);
      // Register controls that initiate a search
      RegisterControl(AdvancedStartSearchControl.STR_MVC_CLASS_NAME, model);
      // Register control that saves a search
      RegisterControl(SaveSearchControl.STR_MVC_CLASS_NAME, model);
      // Register main DisplayPage
      RegisterPage(new AdminSearchDP());
      // Register views
      RegisterView(AdminFollowupSearchView.STR_MVC_CLASS_NAME, model);
      RegisterView(SearchBannerView.STR_MVC_CLASS_NAME, model);
      RegisterView(OrganizationView.STR_MVC_CLASS_NAME, model);
      RegisterView(SearchSummaryView.STR_MVC_CLASS_NAME, model);
      RegisterView(GroupedResultsView.STR_MVC_CLASS_NAME, model);
      RegisterView(SearchFooterView.STR_MVC_CLASS_NAME, model);
      // Set the view helper for the grouped results view
      GroupedResultsView grv = (GroupedResultsView) GetView(GroupedResultsView.STR_MVC_CLASS_NAME);
      GroupedResultsViewHelper grvHelper = new GroupedResultsViewHelper(pageMode);
      grv.SetHelper(grvHelper);
      ((SearchSummaryView) GetView(SearchSummaryView.STR_MVC_CLASS_NAME)).SetPageModeHelper(pageMode);
      ((SearchBannerView) GetView(SearchBannerView.STR_MVC_CLASS_NAME)).SetPageModeHelper(pageMode);
      // Obj Mgr popup Pages -- delete warnings
      RegisterPage(new ObjMgrDeleteWarningsDP());
      // Admin Search Model (some of the functionality of ObjMgrModel, but not all)
      RegisterModel(AdminSearchModel.STR_MVC_CLASS_NAME);
      IModel myModel = (AdminSearchModel) GetModel(AdminSearchModel.STR_MVC_CLASS_NAME);
      ((IAdminSearchModelRO) myModel).SetSearchModel((ISearchResultModelRO) model);
      // ObjMgr Views
      RegisterView(ToolbarView.STR_MVC_CLASS_NAME, myModel);
      // Obj Mgr popup Views
      RegisterView(ObjMgrDeleteWarningsView.STR_MVC_CLASS_NAME, myModel);
      // ObjMgr Controls
      RegisterControl(AdminSearchRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Obj Mgr popup Controls
      RegisterControl(CheckDeleteControl.STR_MVC_CLASS_NAME, myModel);
      this.SetHelpTopic("PT_AdministrativeObjectSearchResults");
    }
  }
}