using System;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objsearch
{
  /// <author>CraigS</author>
  public class AdminSearchForm
  {
    
    /// <summary>
    /// Static factory method to make an administrative object
    /// search box.  The method may return a complete HTMLForm
    /// or contents for some other form.
    /// If the objectClassIDs array contains any PT_CLASSID
    /// values, this form will contain the specified prompt,
    /// a folder restriction pulldown (All Folders / This Folder /
    /// This Folder plus Subfolders), a search box, and a ">>"
    /// button that submits the search.
    /// If the array is null, an object type pulldown is added
    /// as well.
    /// If returnCompleteForm is true, a complete, usable HTMLForm is
    /// returned, ready to be added to a page.
    /// If returnCompleteForm is false, an HTMLElementCollection containing
    /// contents to be added to some other form is returned.  You're
    /// responsible for making sure all the form arguments get passed
    /// to StartSearchControl in some space for which
    /// IntegratedSearchAS.RegisterSearchClasses() has been called.
    /// </summary>
    public static HTMLElement GetObjectSearchForm(AActivitySpace m_asOwner,
     String formName, String targetSpace, String targetSpaceID, String targetPage,
     String prompt, int currentAdminFolder, int[] objectClassIDs, bool makeEditLinks,
     bool returnCompleteForm, bool overrideEnclosingForm, HTMLElement additionalElements,
     bool validateAlert)
    {
      HTMLElement result = null;
      try
      {
        // Make the factory
        SearchFormFactory factory = new SearchFormFactory(formName, formName,
         m_asOwner, returnCompleteForm);
        factory.SetValidateAlert(validateAlert);
        // Set the form's target
        if (returnCompleteForm || targetSpace != null)
        {
          factory.SetTarget(targetSpace, targetSpaceID, targetPage);
        }
        // Add required constraints that should be used for ALL searches.
        // We only want portal objects..
        factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS,
         PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
        if (null != objectClassIDs)
        {
          // If class IDs were specified, these are another required constraint
          factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           objectClassIDs);
        } else
        {
          // Otherwise, all indexed object types could be options.
          factory.AddOptionalSetting("gtl", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_GADGETTEMPLATE_ID});
          factory.AddOptionalSetting("use", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_USER_ID});
          factory.AddOptionalSetting("gro", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_USERGROUP_ID});
          factory.AddOptionalSetting("aut", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_AUTHSOURCE_ID});
          factory.AddOptionalSetting("fol", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_ADMIN_FOLDER_ID});
          factory.AddOptionalSetting("fil", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_FILTER_ID});
          factory.AddOptionalSetting("sav", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_SAVEDSEARCH_ID});
          factory.AddOptionalSetting("dat", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_DATASOURCE_ID});
          factory.AddOptionalSetting("pro", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_PROPERTY_ID});
          factory.AddOptionalSetting("typ", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_DOCUMENTTYPE_ID});
          factory.AddOptionalSetting("cra", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_CRAWLER_ID});
          factory.AddOptionalSetting("gad", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_GADGET_ID});
          factory.AddOptionalSetting("inv", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_INVITATION_ID});
          factory.AddOptionalSetting("fed", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_FEDERATEDPORTAL_ID});
          factory.AddOptionalSetting("gcs", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID});
          factory.AddOptionalSetting("ctp", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID});
          factory.AddOptionalSetting("bun", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_GADGETBUNDLE_ID});
          factory.AddOptionalSetting("pgt", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_PAGETEMPLATE_ID});
          factory.AddOptionalSetting("job", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_JOB_ID});
          factory.AddOptionalSetting("com", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_COMMUNITY_ID});
          factory.AddOptionalSetting("cpg", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_PAGE_ID});
          // Site map folders (nav links and comm. knowledge dirs)
          // are not visible from admin, so shouldn't be visible
          // from search either (only visible from subportal editor
          // and community page.
          //factory.AddOptionalSetting("smf",
          //	PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
          //	new int[] { PT_CLASSIDS.PT_SITEMAPFOLDER_ID });
          factory.AddOptionalSetting("sbp", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_SUBPORTAL_ID});
          factory.AddOptionalSetting("web", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_WEBSERVICE_ID});
          factory.AddOptionalSetting("ext", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_EXTOPERATION_ID});
          factory.AddOptionalSetting("pfs", PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
           new int[]{PT_CLASSIDS.PT_PROFILESOURCE_ID});
        }
        // Add optional settings for the folder pulldown
        factory.AddOptionalSetting("thisfold", PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
         new int[]{currentAdminFolder});
        factory.AddOptionalSetting("thisfold", PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
         false);
        factory.AddOptionalSetting("subfold", PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
         new int[]{currentAdminFolder});
        factory.AddOptionalSetting("subfold", PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
         true);
        factory.AddOptionalSetting("allfold", PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
         
        // root folder
        new int[]{1});
        factory.AddOptionalSetting("allfold", PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
         true);
        if (makeEditLinks)
        {
          factory.SetPageMode(SearchPageModeHelper.ADMIN_MODE);
        }
        if ((!returnCompleteForm) && overrideEnclosingForm)
        {
          factory.OverrideEnclosingFormAndSubmitToSearchResultPage();
        }
        // Get the form guts
        result = factory.GetResult();
        HTMLTable table = new HTMLTable();
        table.SetCellSpacing("0");
        table.SetCellPadding("3");
        table.SetWidth("100%");
        result.AddInnerHTMLElement(table);
        HTMLTableRow row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG);
        table.AddInnerHTMLElement(row);
        HTMLTableCell cell;
        // Add the prompt
        if (null != prompt)
        {
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign("middle");
          cell.SetNoWrap(true);
          row.AddInnerHTMLElement(cell);
          cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
          cell.AddInnerHTMLString(prompt);
        }
        // If object types are selectable, add the type pulldown
        if (null == objectClassIDs)
        {
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign("middle");
          row.AddInnerHTMLElement(cell);
          HTMLSelect typeSelect = new HTMLSelect(factory.GetNextSelectName(),
           "");
          typeSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
          HTMLElementCollection optColl = new HTMLElementCollection();
          HTMLOption typeOption = new HTMLOption("all");
          typeOption.SetSelected(true);
          typeOption.AddInnerHTMLString(m_asOwner.GetString(209, "ptmsgs_portalinfrastructure"));
          typeSelect.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("fol");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(218, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("gtl");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(235, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("aut");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(217, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("com");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(237, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("cpg");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(505, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("ctp");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(231, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("cra");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(224, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("dat");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(221, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("typ");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(223, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("ext");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(317, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("fed");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(470, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("fil");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(219, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("gro");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(216, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("inv");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(226, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("job");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(236, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("pgt");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(233, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("pfs");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(301, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("gad");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(225, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("bun");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(232, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("gcs");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(228, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("pro");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(222, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("sav");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(220, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          // Site map folders (nav links and comm. knowledge dirs)
          // are not visible from admin, so shouldn't be visible
          // from search either (only visible from subportal editor
          // and community page.
          //typeOption = new HTMLOption("smf");
          //typeOption.AddInnerHTMLString(m_asOwner.GetString(238,
          //		"ptmsgs_portalinfrastructure"));
          //typeSelect.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("sbp");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(519, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("use");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(215, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeOption = new HTMLOption("web");
          typeOption.AddInnerHTMLString(m_asOwner.GetString(234, "ptmsgs_portalinfrastructure"));
          optColl.AddInnerHTMLElement(typeOption);
          typeSelect.AddInnerHTMLElement(optColl);
          cell.AddInnerHTMLElement(typeSelect);
        }
        // Add the folder pulldown
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign("middle");
        row.AddInnerHTMLElement(cell);
        HTMLSelect folderSelect = new HTMLSelect(factory.GetNextSelectName(),
         "");
        folderSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        // Add "all folders" option.
        HTMLOption allFoldersOption = new HTMLOption("allfold");
        allFoldersOption.AddInnerHTMLString(m_asOwner.GetString(210, "ptmsgs_portalinfrastructure"));
        folderSelect.AddInnerHTMLElement(allFoldersOption);
        // Add "this folder" option.
        HTMLOption thisFolderOption = new HTMLOption("thisfold");
        thisFolderOption.AddInnerHTMLString(m_asOwner.GetString(211, "ptmsgs_portalinfrastructure"));
        folderSelect.AddInnerHTMLElement(thisFolderOption);
        // Add "this folder plus subfolder" option.
        HTMLOption subFoldersOption = new HTMLOption("subfold");
        subFoldersOption.AddInnerHTMLString(m_asOwner.GetString(212, "ptmsgs_portalinfrastructure"));
        folderSelect.AddInnerHTMLElement(subFoldersOption);
        cell.AddInnerHTMLElement(folderSelect);
        // Add the input box
        cell = new HTMLTableCell();
        cell.SetWidth("100%");
        cell.SetHeight("25");
        cell.SetVAlign("middle");
        cell.SetNoWrap(true);
        HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT, factory.GetInputBoxName(),
         "myID");
        input.SetOnKeyDown(factory.GetInputBoxOnKeyDown());
        input.SetSize("30");
        input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        //cell.AddInnerHTMLElement(new HTMLGenericElement("&nbsp;"));
        cell.AddInnerHTMLElement(input);
        row.AddInnerHTMLElement(cell);
        // Add submit button
        //cell = new HTMLTableCell();
        //cell.SetHeight("25");
        //cell.SetVAlign("middle");
        //row.AddInnerHTMLElement(cell);
        String onclick = factory.GetAnchorOnClick();
        // If not in 508 mode
        if (null != onclick)
        {
          // the submit button is actually an HTML anchor
          HTMLAnchor submitLink = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          submitLink.SetOnClick(onclick);
          submitLink.SetPreComment(m_asOwner.GetString(293, "ptmsgs_portalinfrastructure"));
          HTMLImg button = SearchFormFactory.GetSearchButton(m_asOwner);
          //button.SetHeight("20");
          //button.SetWidth("20");
          button.SetAlign("absmiddle");
          submitLink.AddInnerHTMLElement(button);
          cell.AddInnerHTMLString("&nbsp;");
          cell.AddInnerHTMLElement(submitLink);
        } else
        {
          // In 508 mode, make a real button
          HTMLInput submitButton = new HTMLInput(HTMLInputTypes.SUBMIT, "in_su_" + formName,
           "");
          submitButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          submitButton.SetValue(m_asOwner.GetString(293, "ptmsgs_portalinfrastructure"));
          cell.AddInnerHTMLElement(submitButton);
        }
        if (additionalElements != null)
        {
          cell.AddInnerHTMLElement(additionalElements);
        }
      }
      catch (HTMLException e)
      {
        return new HTMLGenericElement(e.Message);
      }
      // Return the completed form
      return result;
    }
    
    /// <summary>
    /// Slightly simpler version of factory method; refer to comments above
    /// </summary>
    public static HTMLForm GetObjectSearchForm(AActivitySpace m_asOwner, String formName,
     String targetSpace, String targetSpaceID, String targetPage, String prompt,
     int currentAdminFolder, int[] objectClassIDs, bool validateAlert)
    {
      return (HTMLForm) GetObjectSearchForm(m_asOwner, formName, targetSpace,
       targetSpaceID, targetPage, prompt, currentAdminFolder, objectClassIDs,
       false, true, false, null, validateAlert);
    }
  }
}