using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.objcommon;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.objsearch
{
  /// <author>
  /// Matt Fryer
  /// This implements the Administrative Search Model, mostly delegating to an AdminModelHelper. 
  /// </author>
  public class AdminSearchModel : IRepostModel,IObjMgrDeleteRO,IAdminSearchModelRO
  {
    public const String STR_MVC_CLASS_NAME = "AdminSearch";
    private AActivitySpace m_asOwner = null;
    private AdminModelHelper m_helper = null;
    private ISearchResultModelRO m_searchModel = null;
    public AdminSearchModel()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
      m_helper.CleanupTempData();
    }
    public virtual bool GetHasDisplayedObjects(int classID)
    {
      return ((SearchResultModel) m_searchModel).GetHasDisplayedObjects(classID);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <summary>
    /// This method copies folders to a new folder.
    /// </summary>
    /// <param name="int">nTargetFolderID the ID of the folder to copy the folders to.</param>
    /// <param name="int[]">nFolders an array of folder IDs.</param>
    public virtual void CopyFolders(int nTargetFolderID, int[] nFolders)
    {
      m_helper.CopyFolders(nTargetFolderID, nFolders);
    }
    
    /// <summary>
    /// This method copies objects between folders.
    /// </summary>
    /// <param name="int">nFolderID the ID of the folder to copy the objects to.</param>
    /// <param name="XPHashtable">a map of Integer Class IDs to int[] arrays of object IDs.</param>
    public virtual void CopyObjectsBetweenFolders(int nFolderID, XPHashtable xpmObjects,
     int nCurrentFolderID)
    {
      m_helper.CopyObjectsBetweenFolders(nFolderID, xpmObjects, nCurrentFolderID);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new AdminSearchModel();
    }
    
    /// <summary>
    /// This method deletes folders.
    /// </summary>
    /// <param name="int[]">the folder IDs to delete</param>
    public virtual void DeleteFolders(int[] nFolders)
    {
      m_helper.DeleteFolders(nFolders);
    }
    
    /// <param name="cards"></param>
    /// <param name="folders"></param>
    public virtual void DeleteCards(int[] cards, int[] folders)
    {
      m_helper.DeleteCards(cards, folders);
    }
    public virtual void DeleteDocumentFolders(int[] documentFolders)
    {
      m_helper.DeleteDocumentFolders(documentFolders);
    }
    
    /// <param name="nPageTemplates"></param>
    public virtual void ABODeletePageTemplates(int[] nPageTemplates)
    {
      m_helper.ABODeletePageTemplates(nPageTemplates);
    }
    
    /// <summary>
    /// This method deletes objects.
    /// </summary>
    /// <param name="XPHashtable">a map of Integer Class IDs to int[] arrays of object IDs.</param>
    public virtual void DeleteObjects(XPHashtable xpmObjects, bool bABODeleteObjects)
    {
      m_helper.DeleteObjects(xpmObjects, bABODeleteObjects);
    }
    
    /// <summary>
    /// This method enables and disables users and web services.
    /// </summary>
    public virtual void EnableObjects(XPHashtable xpmObjects, String sComment,
     bool bEnable)
    {
      m_helper.EnableObjects(xpmObjects, sComment, bEnable);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public virtual void Finish()
    {
    }
    
    /// <summary>
    /// TODO: MOve some version of this to the helper.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetCommunityID()"></seealso>
    public virtual int GetCommunityID(int nFolderID)
    {
      return m_helper.GetCommunityID(nFolderID, 1);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetCurrentFolderIsCommunity()"></seealso>
    public virtual bool GetFolderIsCommunity(IPTAdminFolder folder)
    {
      return m_helper.GetFolderIsCommunity(folder);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetCurrentFolderIsSubportal()"></seealso>
    public virtual bool GetFolderIsSubportal(IPTAdminFolder folder)
    {
      return m_helper.GetFolderIsSubportal(folder);
    }
    
    /// <summary>
    /// This method gets the selected folder from the tree sub space.
    /// </summary>
    /// <returns>int the folder ID (-1 implies error)</returns>
    public virtual int GetFolderIDFromTree(String subspaceKey)
    {
      return m_helper.GetFolderIDFromTree(subspaceKey);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetFolderTreeID()"></seealso>
    public virtual String GetFolderTreeID()
    {
      return m_helper.GetFolderTreeID();
    }
    
    /// <returns></returns>
    public virtual int GetRootFolderID()
    {
      return 1;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <returns></returns>
    public virtual String GetAllObjectTypesString()
    {
      return m_helper.GetAllObjectTypesString();
    }
    
    /// <returns></returns>
    public virtual int[] GetAllObjectTypesArray()
    {
      return m_helper.GetAllObjectTypesArray();
    }
    
    /// <summary>
    /// Get the SpaceID of the parent Activity Space
    /// </summary>
    /// <returns>int m_asOwner.GetSpaceID();</returns>
    public virtual String GetSpaceID()
    {
      return m_asOwner.GetSpaceID();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_helper = new AdminModelHelper();
      m_helper.Init(parent);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.objsearch.IAdminSearchModelRO#SetSearchModel(com.plumtree.portaluiinfrastructure.search.ISearchResultModelRO)
     */
     
    public virtual void SetSearchModel(ISearchResultModelRO model)
    {
      m_searchModel = model;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.objsearch.IAdminSearchModelRO#GetSearchModel()
     */
     
    public virtual ISearchResultModelRO GetSearchModel()
    {
      return m_searchModel;
    }
    
    /// <summary>
    /// This method adds folders into the migration queue.
    /// </summary>
    public virtual void MigrateFolders(int[] nFolderIDs, String sComment)
    {
      m_helper.MigrateFolders(nFolderIDs, sComment);
    }
    
    /// <summary>
    /// This method adds objects into the migration queue.
    /// </summary>
    public virtual void MigrateObjects(XPHashtable xpmObjects, String sComment)
    {
      m_helper.MigrateObjects(xpmObjects, sComment);
    }
    
    /// <summary>
    /// This method adds objects into the migration queue.
    /// </summary>
    public virtual void MigrateObjects(int nClassID, int[] nObjects, String sComment)
    {
      m_helper.MigrateObjects(nClassID, nObjects, sComment);
    }
    
    /// <summary>
    /// This method moves folders to a new folder.
    /// </summary>
    /// <param name="int">nTargetFolderID the ID of the folder to move the folders to.</param>
    /// <param name="int[]">nFolders an array of folder IDs.</param>
    public virtual void MoveFolders(int nTargetFolderID, int[] nFolders)
    {
      m_helper.MoveFolders(nTargetFolderID, nFolders);
    }
    
    /// <param name="fromFolder"></param>
    /// <param name="cardId"></param>
    /// <param name="toFolder"></param>
    public virtual void MoveCards(int fromFolder, int cardId, int toFolder)
    {
      m_helper.MoveCards(fromFolder, cardId, toFolder);
    }
    
    /// <param name="foldersToMove"></param>
    /// <param name="targetFolder"></param>
    public virtual void MoveDocumentFolders(int[] foldersToMove, int targetFolder)
    {
      m_helper.MoveDocumentFolders(foldersToMove, targetFolder);
    }
    
    /// <param name="cardIds"></param>
    /// <param name="toFolder"></param>
    public virtual void CopyCards(int[] cardIds, int toFolder)
    {
      m_helper.CopyCards(cardIds, toFolder);
    }
    
    /// <param name="folderIDs"></param>
    /// <param name="toFolder"></param>
    public virtual void CopyDocumentFolders(int[] folderIDs, int toFolder)
    {
      m_helper.CopyDocumentFolders(folderIDs, toFolder);
    }
    
    /// <summary>
    /// This method moves objects between folders.
    /// </summary>
    /// <param name="int">nFolderID the ID of the folder to move the objects to.</param>
    /// <param name="Object[][]">nObjects an (2 x n) array of class IDs / Object IDs</param>
    public virtual void MoveObjectsBetweenFolders(int nFolderID, Object[][] nObjects,
     Object[][] nFolders)
    {
      m_helper.MoveObjectsBetweenFolders(nFolderID, nObjects, nFolders);
    }
    
    /// <param name="nObjects"></param>
    /// <param name="nFolders"></param>
    /// <param name="nFolderID"></param>
    protected virtual void DoMove(Object[][] nObjects, Object[][] nFolders,
     int nFolderID)
    {
      m_helper.DoMove(nObjects, nFolders, nFolderID);
    }
    /////////////////////////////////
    // Write methods for IRepostModel
    /////////////////////////////////
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    /// <returns>int Page status for server side validation</returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// This method sets the selected items in a Class ID
    /// </summary>
    /// <param name="int">nClassID the class ID of the selected items</param>
    /// <param name="int[]">nSelectedObjectIDs the selected object IDs</param>
    public virtual void SetSelectedObjects(int nClassID, int[] nSelectedObjectIDs)
    {
      m_helper.SetSelectedObjects(nClassID, nSelectedObjectIDs);
    }
    
    /// <param name="nFolderID"></param>
    /// <returns></returns>
    protected virtual bool CheckIsCommunityFolder(int nFolderID)
    {
      return m_helper.CheckIsCommunityFolder(nFolderID);
    }
    
    /// <summary>
    /// This method creates a job to delete folders using Asynchronous
    /// Browser Operations (ABO).
    /// </summary>
    /// <param name="int[]">the folder IDs to delete</param>
    public virtual void ABODeleteFolders(int[] nFolders)
    {
      m_helper.ABODeleteFolders(nFolders);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.objmgr.IObjMgrDeleteRO#CheckAuthSourceForDelete()
     */
     
    public virtual bool CheckAuthSourceForDelete()
    {
      return m_helper.CheckAuthSourceForDelete(-1);
    }
    
    /// <summary>
    /// This method checks whether or not the user is trying to delete any page templates.
    /// </summary>
    /// <returns>true implies page templates are being deleted</returns>
    public virtual bool CheckPageTemplatesForDelete()
    {
      return m_helper.CheckPageTemplatesForDelete();
    }
    
    /// <summary>
    /// This method checks whether or not the user is trying to delete any folders.
    /// </summary>
    /// <returns>true implies folders are being deleted</returns>
    public virtual bool CheckFoldersForDelete()
    {
      return m_helper.CheckFoldersForDelete();
    }
    
    /// <summary>
    /// This method is used to set the list of folder IDs (temporary)
    /// to be checked for delete.
    /// </summary>
    /// <param name="int[]">of object class id / object id pairs.</param>
    public virtual void SetObjectsForDeleteCheck(int[] nObjectIDPairs)
    {
      m_helper.SetObjectsForDeleteCheck(nObjectIDPairs);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.objmgr.IObjMgrDeleteRO#SetFoldersForDeleteCheck(boolean)
     */
     
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.objmgr.IObjMgrDeleteRO#SetFoldersForDeleteCheck(boolean)
     */
     
    public virtual void SetFoldersForDeleteCheck(bool tf)
    {
      m_helper.SetFoldersForDeleteCheck(tf);
    }
    
    /// <param name="folderID"></param>
    /// <returns></returns>
    public virtual String GetAdminFolderPath(int folderID)
    {
      return m_helper.GetAdminFolderPath(folderID);
    }
    
    /// <param name="key"></param>
    public virtual void RefreshResults(String key)
    {
      m_helper.RefreshResults(key);
    }
  }
}