using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.objsearch
{
  /// <author>
  /// MatthewF
  /// This control handles the Admin Search specific repost work. TODO: Note that code here is mostly from
  /// ObjMgrRepostControl and that these should be consolidated.
  /// </author>
  public class AdminSearchRepostControl : RepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objsearch.AdminSearchRepostControl");
    
    /// <summary>
    /// Name of this control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AdminSearchRepost";
    
    /// <summary>
    /// Mandatory Form inputs 
    /// </summary>
    public const String HTML_INPUT_FOLDER_ID = "in_hi_FolderID";
    public const String HTML_INPUT_OBJECT_IDS = "in_hi_ObjectIDs";
    public const String CURRENT_KEY_INPUT = "in_hi_currKey";
    // an int
    
    /// <summary>
    /// Expand object types inputs 
    /// </summary>
    public const String HTML_INPUT_EXPAND_OBJECT_ID = "in_hi_ExpandObjectIDs";
    // boolean true = expand, false = collapse
    public const String HTML_INPUT_EXPAND_BOOLEAN = "in_hi_Expand";
    
    /// <summary>
    /// Repost Actions 
    /// </summary>
    public const int POSTTOSELF_ACTION_MOVE = 51;
    public const int POSTTOSELF_ACTION_COPY = 52;
    public const int POSTTOSELF_ACTION_DELETE = 54;
    public const int POSTTOSELF_ACTION_DELETE_LATER = 55;
    public const int POSTTOSELF_ACTION_MIGRATE = 57;
    public const int POSTTOSELF_ACTION_ENABLE = 58;
    public const int POSTTOSELF_ACTION_RUN_ONCE = 56;
    public const int POSTTOSELF_ACTION_MOVE_DOCITEMS = 61;
    public const int POSTTOSELF_ACTION_COPY_DOCITEMS = 62;
    protected AdminSearchModel m_asAdminSearchModel;
    
    /// <summary>
    /// This ovverrides the implementation from RepostControl for certain actions
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      return base.CheckActionSecurityAndExecute(arguments);
    }
    
    /// <summary>
    /// This method gets the selected folders from the form data
    /// </summary>
    /// <returns>int[] an array of Folder IDs</returns>
    public static int[] GetSelectedFolders(XPHashtable htFormData, String key)
    {
      String[] sDataValue = (String[]) htFormData.GetElement(key);
      if (sDataValue != null)
      {
        int[] result = new int[sDataValue.Length];
        int nErrorsFound = 0;
        for (int i = 0;i < sDataValue.Length;i++)
        {
          try
          {
            result[i] = XPConvert.ToInteger(sDataValue[i]);
          }
          catch (Exception e)
          {
            log.Error("Unable to convert selected folder to int: " + sDataValue[i]);
            result[i] = -1;
            nErrorsFound++;
          }
        }
        // Resize array if there were errors
        if (nErrorsFound > 0)
        {
          int[] temp = new int[sDataValue.Length - nErrorsFound];
          int nIndex = 0;
          for (int i = 0;i < result.Length;i++)
          {
            if ((result[i] != -1) && (nIndex < temp.Length))
            {
              temp[nIndex] = result[i];
              nIndex++;
            }
          }
          result = temp;
        }
        return result;
      }
      return new int[0];
    }
    
    /// <summary>
    /// This method gets the selected objects (not folders) from the form data
    /// </summary>
    /// <returns>Object[][] a (2 x n) array of class ID / Object ID pairs</returns>
    public static Object[][] GetSelectedObjects(XPHashtable htFormData, bool returnObjectIDS)
    {
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      int[] arAllClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs("en");
      String[] sDataKeys = new String[arAllClassIDs.Length];
      String[] sDataValue;
      Object nError = -1;
      Object[][] result;
      // Calculate the size of the array needed
      int nSize = 0;
      for (int i = 0;i < arAllClassIDs.Length;i++)
      {
        sDataKeys[i] = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + arAllClassIDs[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
        sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);
        if (sDataValue != null)
        {
          nSize+=sDataValue.Length;
        }
      }
      result = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        result[j2c_index] = new Object[nSize];
      }
      if (nSize > 0)
      {
        // populate the array
        int nIndex = 0;
        int nErrorsFound = 0;
        for (int i = 0;i < arAllClassIDs.Length;i++)
        {
          sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);
          if (sDataValue != null)
          {
            for (int j = 0;j < sDataValue.Length;j++)
            {
              if (nIndex < nSize)
              {
                try
                {
                  int idValue;
                  int separator = XPStringUtility.IndexOf(sDataValue[j], ",");
                  if (returnObjectIDS)
                  {
                    idValue = XPConvert.ToInteger(XPStringUtility.Substring(sDataValue[j],
                     0, separator));
                  } else
                  {
                    idValue = XPConvert.ToInteger(XPStringUtility.Substring(sDataValue[j],
                     separator + 1));
                  }
                  result[0][nIndex] = arAllClassIDs[i];
                  result[1][nIndex] = idValue;
                }
                catch (Exception e)
                {
                  log.Error("Unable to convert selected object to int: " + sDataValue[j]);
                  result[0][nIndex] = nError;
                  result[1][nIndex] = nError;
                  nErrorsFound++;
                }
                nIndex++;
              }
            }
          }
        }
        // Resize array if there were errors
        if (nErrorsFound > 0)
        {
          Object[][] temp = new Object[2][];
          for (int j2c_index = 0;j2c_index < 2;j2c_index++)
          {
            temp[j2c_index] = new Object[nSize - nErrorsFound];
          }
          nIndex = 0;
          for (int i = 0;i < result.Length;i++)
          {
            if ((!result[0][i].Equals(nError)) && (nIndex < temp.Length))
            {
              temp[0][nIndex] = result[0][i];
              temp[1][nIndex] = result[1][i];
              nIndex++;
            }
          }
          result = temp;
        }
      }
      return result;
    }
    public static int[] GetSelectedCards(XPHashtable htFormData, bool returnFolders)
    {
      String[] cardVals = (String[]) htFormData.GetElement(GroupedResultsViewHelper.DOC_INPUT);
      if (cardVals == null || cardVals.Length == 0)
      {
        return new int[0];
      }
      int[] retval = new int[cardVals.Length];
      for (int i = 0;i < cardVals.Length;i++)
      {
        String val = cardVals[i];
        int separator = XPStringUtility.IndexOf(val, ",");
        if (!returnFolders)
        {
          retval[i] = XPConvert.ToInteger(XPStringUtility.Substring(val, 0,
           separator));
        } else
        {
          retval[i] = XPConvert.ToInteger(XPStringUtility.Substring(val, separator + 1));
          }
      }
      return retval;
    }
    
    /// <summary>
    /// This method gets the selected objects (not folders) from the form data
    /// </summary>
    /// <returns>XPHashtable of Integer class IDs to int[] of Object IDs</returns>
    public static XPHashtable GetSelectedObjectsMap(XPHashtable htFormData,
     bool returnObjectIDS)
    {
      XPHashtable result = new XPHashtable();
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      int[] nExpandedObjectTypes = ptClassTypeDescManager.GetOrderedListOfClassIDs("en");
      String[] sDataKeys = new String[nExpandedObjectTypes.Length];
      String[] sDataValue;
      int[] temp;
      int nErrorsFound;
      for (int i = 0;i < nExpandedObjectTypes.Length;i++)
      {
        sDataKeys[i] = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
        sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);
        if ((sDataValue != null) && (sDataValue.Length > 0))
        {
          temp = new int[sDataValue.Length];
          nErrorsFound = 0;
          for (int j = 0;j < sDataValue.Length;j++)
          {
            try
            {
              int idValue;
              int separator = XPStringUtility.IndexOf(sDataValue[j], ",");
              if (returnObjectIDS)
              {
                idValue = XPConvert.ToInteger(XPStringUtility.Substring(sDataValue[j],
                 0, separator));
              } else
              {
                idValue = XPConvert.ToInteger(XPStringUtility.Substring(sDataValue[j],
                 separator + 1));
              }
              temp[j] = idValue;
            }
            catch (Exception e)
            {
              log.Error("Unable to convert selected object to int: " + sDataValue[j]);
              temp[j] = -1;
              nErrorsFound++;
            }
          }
          if (nErrorsFound > 0)
          {
            int[] resize = new int[temp.Length - nErrorsFound];
            int nResizeIndex = 0;
            for (int k = 0;k < temp.Length;k++)
            {
              if ((temp[k] != -1) && (nResizeIndex < temp.Length))
              {
                resize[nResizeIndex] = temp[i];
                nResizeIndex++;
              }
            }
            temp = resize;
          }
          result.PutElement(nExpandedObjectTypes[i], temp);
        }
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AdminSearchRepostControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the class with the associated model and activity space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="space"></param>
    public override void Init(IModel model, AActivitySpace space)
    {
      base.Init(model, space);
      m_asAdminSearchModel = (AdminSearchModel) model;
      m_asOwner = space;
    }
    
    /// <summary>
    /// Given the repost action mode, calls the associated method in the model.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      int nTargetFolderID;
      String[] sValues;
      String sComment;
      bool bRequires302Redirect = false;
      int[] foldersarray = null;
      int[] docFolders = AdminSearchRepostControl.GetSelectedFolders(m_htFormData,
       GroupedResultsViewHelper.DOC_FOLDER_INPUT);
      int[] cards = AdminSearchRepostControl.GetSelectedCards(m_htFormData,
       false);
      int[] folders = AdminSearchRepostControl.GetSelectedCards(m_htFormData,
       true);
      switch (_nAction){
      case POSTTOSELF_ACTION_MOVE_DOCITEMS:
      String[] foldersTomove = (String[]) m_htFormData.GetElement(GroupedResultsViewHelper.DOC_FOLDER_INPUT);
      String[] docsTomove = (String[]) m_htFormData.GetElement(GroupedResultsViewHelper.DOC_INPUT);
      nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ToolbarView.FOLDER_TREE_SUB_SPACE_KEY);
      // first, check that no cards are in multiple folders before committing any changes
      bool haveDocInMultipleFolders = false;
      if (docsTomove != null && docsTomove.Length > 0)
      {
        for (int i = 0;i < docsTomove.Length;i++)
        {
          int separator = XPStringUtility.IndexOf(docsTomove[i], ",");
          int folderId = XPConvert.ToInteger(XPStringUtility.Substring(docsTomove[i],
           separator + 1));
          if (GroupedResultsViewHelper.MULTIFOLDER_CODE == folderId)
          {
            haveDocInMultipleFolders = true;
            break;
          }
        }
        if (haveDocInMultipleFolders)
        {
          SetPageStatus(RepostControl.PAGE_STATUS_INVALID);
          UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           m_asOwner.GetString(1863, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1863,
           "ptmsgs_portalbrowsingmsgs"));
          UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          bRequires302Redirect = true;
        }
      }
      if ((!haveDocInMultipleFolders) && foldersTomove != null && foldersTomove.Length > 0)
      {
        int[] folderIDS = new int[foldersTomove.Length];
        for (int i = 0;i < foldersTomove.Length;i++)
        {
          folderIDS[i] = XPConvert.ToInteger(foldersTomove[i]);
        }
        m_asAdminSearchModel.MoveDocumentFolders(folderIDS, nTargetFolderID);
        bRequires302Redirect = true;
      }
      if ((!haveDocInMultipleFolders) && docsTomove != null && docsTomove.Length > 0)
      {
        for (int i = 0;i < docsTomove.Length;i++)
        {
          int separator = XPStringUtility.IndexOf(docsTomove[i], ",");
          int docId = XPConvert.ToInteger(XPStringUtility.Substring(docsTomove[i],
           0, separator));
          int folderId = XPConvert.ToInteger(XPStringUtility.Substring(docsTomove[i],
           separator + 1));
          m_asAdminSearchModel.MoveCards(folderId, docId, nTargetFolderID);
          }
        bRequires302Redirect = true;
      }
      break;
      case POSTTOSELF_ACTION_COPY_DOCITEMS:
      String[] foldersToCopy = (String[]) m_htFormData.GetElement(GroupedResultsViewHelper.DOC_FOLDER_INPUT);
      String[] docsToCopy = (String[]) m_htFormData.GetElement(GroupedResultsViewHelper.DOC_INPUT);
      nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ToolbarView.FOLDER_TREE_SUB_SPACE_COPY_KEY);
      if (foldersToCopy != null && foldersToCopy.Length > 0)
      {
        int[] folderIDS = new int[foldersToCopy.Length];
        for (int i = 0;i < foldersToCopy.Length;i++)
        {
          folderIDS[i] = XPConvert.ToInteger(foldersToCopy[i]);
        }
        m_asAdminSearchModel.CopyDocumentFolders(folderIDS, nTargetFolderID);
        bRequires302Redirect = true;
      }
      if (docsToCopy != null && docsToCopy.Length > 0)
      {
        int[] docIDs = new int[docsToCopy.Length];
        for (int i = 0;i < docsToCopy.Length;i++)
        {
          int separator = XPStringUtility.IndexOf(docsToCopy[i], ",");
          int docId = XPConvert.ToInteger(XPStringUtility.Substring(docsToCopy[i],
           0, separator));
          docIDs[i] = docId;
        }
        m_asAdminSearchModel.CopyCards(docIDs, nTargetFolderID);
        bRequires302Redirect = true;
      }
      break;
      case POSTTOSELF_ACTION_MOVE:
      nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ObjMgrAS.FOLDER_TREE_SUB_SPACE_KEY);
      if (nTargetFolderID != -1)
      {
        foldersarray = AdminSearchRepostControl.GetSelectedFolders(m_htFormData,
         ObjMgrFolderViewHelper.QS_CHECKBOX);
        log.Debug("Hit Move with folders: ");
        for (int i = 0;i < foldersarray.Length;i++)
        {
          log.Debug("id(" + i + ") = " + foldersarray[i]);
        }
        m_asAdminSearchModel.MoveFolders(nTargetFolderID, foldersarray);
        m_asAdminSearchModel.MoveObjectsBetweenFolders(nTargetFolderID, AdminSearchRepostControl.GetSelectedObjects(m_htFormData,
         true), AdminSearchRepostControl.GetSelectedObjects(m_htFormData,
         false));
        m_asAdminSearchModel.RefreshResults(GetCurrentKey());
        bRequires302Redirect = true;
      }
      break;
      case POSTTOSELF_ACTION_COPY:
      nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ObjMgrAS.FOLDER_TREE_SUB_SPACE_KEY);
      if (nTargetFolderID != -1)
      {
        log.Debug("Hit Copy");
        m_asAdminSearchModel.CopyFolders(nTargetFolderID, AdminSearchRepostControl.GetSelectedFolders(m_htFormData,
         ObjMgrFolderViewHelper.QS_CHECKBOX));
        m_asAdminSearchModel.CopyObjectsBetweenFolders(nTargetFolderID, AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData,
         true), -1);
        m_asAdminSearchModel.RefreshResults(GetCurrentKey());
        bRequires302Redirect = true;
      }
      break;
      case POSTTOSELF_ACTION_DELETE:
      foldersarray = AdminSearchRepostControl.GetSelectedFolders(m_htFormData,
       ObjMgrFolderViewHelper.QS_CHECKBOX);
      log.Debug("Hit Delete with folders: ");
      for (int i = 0;i < foldersarray.Length;i++)
      {
        log.Debug("id(" + i + ") = " + foldersarray[i]);
      }
      m_asAdminSearchModel.DeleteFolders(foldersarray);
      XPHashtable objects = AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData,
       true);
      m_asAdminSearchModel.DeleteObjects(objects, false);
      m_asAdminSearchModel.DeleteDocumentFolders(docFolders);
      m_asAdminSearchModel.DeleteCards(cards, folders);
      m_asAdminSearchModel.RefreshResults(GetCurrentKey());
      bRequires302Redirect = true;
      break;
      case POSTTOSELF_ACTION_DELETE_LATER:
      m_asAdminSearchModel.ABODeleteFolders(AdminSearchRepostControl.GetSelectedFolders(m_htFormData,
       ObjMgrFolderViewHelper.QS_CHECKBOX));
      m_asAdminSearchModel.DeleteObjects(AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData,
       true), true);
      m_asAdminSearchModel.RefreshResults(GetCurrentKey());
      bRequires302Redirect = true;
      break;
      case POSTTOSELF_ACTION_RUN_ONCE:
      StaticPTObjectHelpers.RunJobsOnce((int[]) GetSelectedObjectsMap(m_htFormData,
       true).GetElement(PT_CLASSIDS.PT_JOB_ID), m_asOwner);
      bRequires302Redirect = true;
      break;
      case POSTTOSELF_ACTION_MIGRATE:
      sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);
      if (sValues != null)
      {
        sComment = sValues[0];
      } else
      {
        sComment = "";
      }
      m_asAdminSearchModel.MigrateObjects(XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGFOLDER_ID),
       docFolders, sComment);
      m_asAdminSearchModel.MigrateObjects(XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGCARD_ID),
       cards, sComment);
      m_asAdminSearchModel.MigrateFolders(AdminSearchRepostControl.GetSelectedFolders(m_htFormData,
       ObjMgrFolderViewHelper.QS_CHECKBOX), sComment);
      m_asAdminSearchModel.MigrateObjects(AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData,
       true), sComment);
      bRequires302Redirect = true;
      break;
      case POSTTOSELF_ACTION_ENABLE:
      sComment = "";
      bool bEnable;
      sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_ENABLE);
      if (sValues != null)
      {
        try
        {
          bEnable = XPConvert.ToBoolean(sValues[0]);
        }
        catch (Exception e)
        {
          log.Error("Unable to parse boolean enable/disable value: " + sValues[0]);
          break;
        }
      } else
      {
        log.Error("Unable to locate boolean enable/disable value.");
        break;
      }
      if (!bEnable)
      {
        sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);
        if (sValues != null)
        {
          sComment = sValues[0];
        }
      }
      m_asAdminSearchModel.EnableObjects(GetSelectedObjectsMap(m_htFormData,
       true), sComment, bEnable);
      bRequires302Redirect = true;
      break;
      default:
      base.PerformAction(_nAction);
      break;
      }
      if (bRequires302Redirect)
      {
        Redirect safeRedirect = new Redirect();
        safeRedirect.SetLinkGetCachedSpace(m_asOwner);
        safeRedirect.SetIsHTTPRedirect(true);
        safeRedirect.SetDisplayPage(GetDP());
        SetRedirect(safeRedirect);
      }
    }
    protected virtual String GetDP()
    {
      String retval = AdminSearchDP.STR_MVC_CLASS_NAME;
      if (m_htFormData != null || m_htFormData.GetElement(ASConstants.PAGE_INPUT) != null)
      {
        String[] vals = (String[]) m_htFormData.GetElement(ASConstants.PAGE_INPUT);
        if (vals != null && vals.Length > 0)
        {
          retval = vals[0];
        }
      }
      return retval;
    }
    public virtual String GetCurrentKey()
    {
      String[] vals = (String[]) m_htFormData.GetElement(CURRENT_KEY_INPUT);
      if (vals != null)
      {
        return vals[0];
      } else
      {
        return "";
      }
    }
  }
}