using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.securitymatrix;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.objsearch
{
  /// <summary>
  /// This toolbar is used by Admin Object Search and banner search when "edit-mode" is in effect.
  /// </summary>
  /// <author>MatthewF</author>
  public class ToolbarView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.objsearch.ToolbarView");
    public const String STR_MVC_CLASS_NAME = "AdminSearchToolbar";
    public const String JAVASCRIPT_OPEN_DOC_TREE = "openJSFolderTree";
    public const String JAVASCRIPT_OPEN_DOC_COPY_TREE = "openJSCopyFolderTree";
    public const String REPOST_MOVE_DOCITEMS = "repostMoveDocItems";
    public const String REPOST_COPY_DOCITEMS = "repostCopyDocItems";
    public const String JAVASCRIPT_OPEN_DOC_SECURITY = "openDocItemSecurity";
    public const String FOLDER_TREE_SUB_SPACE_KEY = "TBVSS_KEY";
    public const String FOLDER_TREE_SUB_SPACE_COPY_KEY = "TBVSS_COPY_KEY";
    public const String MY_JAVASCRIPT_DELETE = "combinedDelete";
    public const String MY_JAVASCRIPT_MIGRATE = "combinedMigrate";
    private AActivitySpace m_asOwner;
    private AdminSearchModel m_asModel;
    private String m_formName;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ToolbarView();
    }
    public virtual void addTargetsToActionBarForm(HTMLForm form)
    {
      form.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(),
       m_asOwner.GetName(), m_asOwner.IsSubSpace()));
      // Set target as the same space
      HTMLInput targetSpace = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACENAME_INPUT,
       ASConstants.SPACENAME_INPUT, "");
      targetSpace.SetValue(m_asOwner.GetName());
      form.AddInnerHTMLElement(targetSpace);
      // Add our current space ID, so the framework doesn't create
      // another instance of the space
      HTMLInput targetSpID = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACEID_INPUT,
       ASConstants.SPACEID_INPUT, "");
      targetSpID.SetValue(m_asOwner.GetSpaceID());
      form.AddInnerHTMLElement(targetSpID);
      // Set target as ReorganizationControl
      HTMLInput targetControl = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.CONTROL_INPUT,
       ASConstants.CONTROL_INPUT, "");
      targetControl.SetValue(ObjMgrRepostControl.STR_MVC_CLASS_NAME);
      form.AddInnerHTMLElement(targetControl);
      AddHiddenInputs(form, m_asModel);
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, "in_hi_PostToSelf",
       "");
      form.AddInnerHTMLElement(myInput);
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, "in_hi_page", "");
      form.AddInnerHTMLElement(myInput);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      PTConstruct bannerConstruct;
      PTConstruct buttonConstruct;
      HTMLAnchor myAnchor;
      //Folder title banner
      try
      {
        bannerConstruct = UIConstructFactory.GetConstruct(PTBannerType.DIRECTORY_ACTION_BAR);
        result.AddInnerHTMLElement(bannerConstruct.GetHTMLElement());
        //Move button
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.MOVE_DIR_ACTIONBAR,
         true, this.m_asOwner);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.MOVE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("DoMyMove(); return false;");
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(174,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(174,
         "ptmsgs_portalbrowsingmsgs"));
        bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         buttonConstruct.GetHTMLElement());
        //Copy button
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.COPY_DIR_ACTIONBAR,
         true, this.m_asOwner);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.COPY_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("DoMyCopy(); return false;");
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(175,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(175,
         "ptmsgs_portalbrowsingmsgs"));
        bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         buttonConstruct.GetHTMLElement());
        //Security button
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SECURITY_DIR_ACTIONBAR,
         true, this.m_asOwner);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.SECURITY_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("DoMySecurity(); return false;");
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(178,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(178,
         "ptmsgs_portalbrowsingmsgs"));
        bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         buttonConstruct.GetHTMLElement());
        //Bulk Add button
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.BULK_ADD_DIR_ACTIONBAR,
         true, this.m_asOwner);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.BULK_ADD_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("DoMySubscribe(); return false;");
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(2879,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(2879,
         "ptmsgs_portaladminmsgs"));
        bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         buttonConstruct.GetHTMLElement());
        //Delete button
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.DELETE_DIR_ACTIONBAR,
         true, this.m_asOwner);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.DELETE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(MY_JAVASCRIPT_DELETE + "(); return false;");
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(177,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(177,
         "ptmsgs_portalbrowsingmsgs"));
        bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         buttonConstruct.GetHTMLElement());
        // Request Migration button
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.MIGRATE_OBJECTS_DIR_ACTIONBAR,
         true, this.m_asOwner);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.MIGRATE_OBJECTS_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_MIGRATE + "(); return false;");
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(1250,
         "ptmsgs_portaladminmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(1250,
         "ptmsgs_portaladminmsgs"));
        bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
         buttonConstruct.GetHTMLElement());
        if (m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_INVITATION_ID))
        {
          // Send Invitation button
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SEND_TO_OTHERS,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.SEND_TO_OTHERS.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1242, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(1242,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(1242,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.SEND_TO_OTHERS.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_SEND_INVITATION + "(); return false;");
          bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
        }
        if (m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_JOB_ID))
        {
          // Run Once button
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SELECT,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.SELECT.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1243, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(1243,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(1243,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.SELECT.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_RUN_ONCE + "(); return false;");
          bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
        }
        if (m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_USER_ID) || m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_WEBSERVICE_ID))
        {
          // Enable button
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.ENABLE_DIR_ACTIONBAR,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.ENABLE_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1244, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(1244,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(1244,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.ENABLE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_ENABLE + "(true); return false;");
          bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
          // Disable button
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.DISABLE_DIR_ACTIONBAR,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.DISABLE_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1245, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(1245,
           "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(1245,
           "ptmsgs_portaladminmsgs"));
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.DISABLE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_ENABLE + "(false); return false;");
          bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL2_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
        }
      }
      catch (Exception e)
      {
        log.Error(e, "ToolbarView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1226, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      int nCurrentFolderID = m_asModel.GetRootFolderID();
      int[] nClassIDs = m_asModel.GetAllObjectTypesArray();
      String typesString = m_asModel.GetAllObjectTypesString();
      bool displayedInvitation = m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_INVITATION_ID);
      bool displayedJob = m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_JOB_ID);
      bool displayedUser = m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_USER_ID);
      bool displayedWebService = m_asModel.GetHasDisplayedObjects(PT_CLASSIDS.PT_WEBSERVICE_ID);
      bool aboJobsToDisplay = false;
      HTMLScript myScript = ObjMgrHeaderView.DoDisplayJavascript(nCurrentFolderID,
       m_asOwner, nClassIDs, AFormDP.HTMLFORM_NAME, typesString, displayedInvitation,
       displayedJob, displayedUser, displayedWebService, aboJobsToDisplay);
      XPStringBuilder sb = new XPStringBuilder();
      // Move docs tree
      ASURL moveDocsTree = new ASURL(m_asOwner);
      moveDocsTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      moveDocsTree.SetSubSpaceKey(FOLDER_TREE_SUB_SPACE_KEY);
      moveDocsTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      moveDocsTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      moveDocsTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      moveDocsTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      moveDocsTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
      moveDocsTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, m_formName);
      moveDocsTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(1224,
       "ptmsgs_portalbrowsingmsgs"));
      moveDocsTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1224,
       "ptmsgs_portalbrowsingmsgs"));
      moveDocsTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       REPOST_MOVE_DOCITEMS);
      moveDocsTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
      sb.Append("function ").Append(REPOST_MOVE_DOCITEMS).Append("()\n");
      sb.Append("{\n");
      sb.Append("  postToSelf(" + AdminSearchRepostControl.POSTTOSELF_ACTION_MOVE_DOCITEMS + ");\n");
      sb.Append("}\n");
      // Move docs tree
      ASURL copyDocsTree = new ASURL(m_asOwner);
      copyDocsTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      copyDocsTree.SetSubSpaceKey(FOLDER_TREE_SUB_SPACE_COPY_KEY);
      copyDocsTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      copyDocsTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      copyDocsTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
      copyDocsTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      copyDocsTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
      copyDocsTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, m_formName);
      copyDocsTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(1224,
       "ptmsgs_portalbrowsingmsgs"));
      copyDocsTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1224,
       "ptmsgs_portalbrowsingmsgs"));
      copyDocsTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       REPOST_COPY_DOCITEMS);
      copyDocsTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
      ASURL securityURL = new ASURL(m_asOwner);
      securityURL.SetLinkCreateNewSpace(SecurityMatrixEditorAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      securityURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      securityURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
      // This must be the last argument so we can append the classID,objectID string
      securityURL.AddControlArgument(MultiObjectsSecurityModel.QS_MULTI_OBJ_SECURITY_IDS);
      sb.Append("function ").Append(REPOST_COPY_DOCITEMS).Append("()\n");
      sb.Append("{\n");
      sb.Append("  postToSelf(" + AdminSearchRepostControl.POSTTOSELF_ACTION_COPY_DOCITEMS + ");\n");
      sb.Append("}\n");
      // Open server folder tree function
      sb.Append("function ").Append(JAVASCRIPT_OPEN_DOC_TREE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  var bCardsSelected = CardsSelected();\n");
      sb.Append("  var sURL = \"").Append(moveDocsTree.GetURLAsString()).Append("\";\n");
      sb.Append("  if(bCardsSelected)\n");
      sb.Append("     sURL += \"&").Append(StartTreeControl.SHOW_ROOT).Append("=0\"").Append("\n");
      sb.Append("  window.open(sURL, \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
      sb.Append("}\n");
      sb.Append("function ").Append(JAVASCRIPT_OPEN_DOC_COPY_TREE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  var bCardsSelected = CardsSelected();\n");
      sb.Append("  var sURL = \"").Append(copyDocsTree.GetURLAsString()).Append("\";\n");
      sb.Append("  if(bCardsSelected)\n");
      sb.Append("     sURL += \"&").Append(StartTreeControl.SHOW_ROOT).Append("=0\"").Append("\n");
      sb.Append("  window.open(sURL, \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
      sb.Append("}\n");
      sb.Append("function DoMyMove()\n");
      sb.Append("{\n");
      sb.Append("   var adminChecked = AdminItemsChecked();\n");
      sb.Append("   var docsChecked = DocsAndFoldersChecked();\n");
      sb.Append("\n");
      sb.Append("\n");
      sb.Append("\n");
      sb.Append("\n");
      sb.Append("  if(! docsChecked && ! adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(1679, "ptmsgs_portalbrowsingmsgs") + "\');\n");
      sb.Append("  } else if (docsChecked && adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(1680, "ptmsgs_portalbrowsingmsgs") + "\');\n");
      sb.Append("  } else if (adminChecked) {\n");
      sb.Append("      " + ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER_TREE + "(document." + m_formName + "." + ObjMgrHeaderView.HTML_INPUT_FOLDER_TREE_ID + ", " + ObjMgrHeaderView.TREE_TYPE_MOVE + ");");
      sb.Append("  } else {\n");
      sb.Append("  \t" + JAVASCRIPT_OPEN_DOC_TREE + "();\n");
      sb.Append("  };\n");
      sb.Append("}\n");
      sb.Append("function DoMyCopy()\n");
      sb.Append("{\n");
      sb.Append("   var adminChecked = AdminItemsChecked();\n");
      sb.Append("   var docsChecked = DocsAndFoldersChecked();\n");
      sb.Append("\n");
      sb.Append("  if(! docsChecked && ! adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(1681, "ptmsgs_portalbrowsingmsgs") + "\');\n");
      sb.Append("  } else if (docsChecked && adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(1682, "ptmsgs_portalbrowsingmsgs") + "\');\n");
      sb.Append("  } else if (adminChecked) {\n");
      sb.Append("      " + ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER_TREE + "(document." + "mainform" + "." + ObjMgrHeaderView.HTML_INPUT_FOLDER_TREE_ID + ", " + ObjMgrHeaderView.TREE_TYPE_COPY + ");");
      sb.Append("  } else {\n");
      sb.Append("  \t" + JAVASCRIPT_OPEN_DOC_COPY_TREE + "();\n");
      sb.Append("  };\n");
      sb.Append("}\n");
      sb.Append("function DoMySecurity()\n");
      sb.Append("{\n");
      sb.Append("   var adminChecked = AdminItemsChecked();\n");
      sb.Append("   var docsChecked = DocsAndFoldersChecked();\n");
      sb.Append("\n");
      sb.Append("  if(! docsChecked && ! adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(1683, "ptmsgs_portalbrowsingmsgs") + "\');\n");
      sb.Append("  } else if (docsChecked && adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(1684, "ptmsgs_portalbrowsingmsgs") + "\');\n");
      sb.Append("  } else if (adminChecked) {\n");
      sb.Append("      " + ObjMgrHeaderView.JAVASCRIPT_SECURITY + "(); return false;");
      sb.Append("  } else {\n");
      sb.Append("  \t" + JAVASCRIPT_OPEN_DOC_SECURITY + "();\n");
      sb.Append("  };\n");
      sb.Append("}\n");
      sb.Append("function DoMySubscribe()\n");
      sb.Append("{\n");
      sb.Append("   var adminChecked = AdminItemsChecked();\n");
      sb.Append("   var docsChecked = DocsAndFoldersChecked();\n");
      sb.Append("\n");
      sb.Append("  if(! adminChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(2880, "ptmsgs_portaladminmsgs") + "\');\n");
      sb.Append("  } else if (docsChecked) {\n");
      sb.Append("      alert(\'" + m_asOwner.GetString(2881, "ptmsgs_portaladminmsgs") + "\');\n");
      sb.Append("  } else {\n");
      // TODO-MJD : need to give alert if no community or portlets are selected
      sb.Append("      " + ObjMgrHeaderView.JAVASCRIPT_SUBSCRIBE + "(); return false;");
      sb.Append("  };\n");
      sb.Append("}\n");
      ASURL deleteURL = new ASURL(m_asOwner);
      deleteURL.SetLinkGetCachedSpace(m_asOwner);
      deleteURL.SetControl(CheckDeleteControl.STR_MVC_CLASS_NAME);
      sb.Append("function ").Append(MY_JAVASCRIPT_DELETE).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if ((AdminItemsChecked() != true) && (DocsAndFoldersChecked() != true) && (").Append(ObjMgrHeaderView.JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() != true) &&\n");
      sb.Append("      (").Append(ObjMgrHeaderView.JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() != true))\n");
      sb.Append("  {\n");
      // And display an error if nothing is selected
      sb.Append("    alert(\'").Append(m_asOwner.GetString(1224, "ptmsgs_portaladminmsgs")).Append("\');\n");
      sb.Append("    return false;\n");
      sb.Append("  }\n");
      sb.Append("  window.open(\'").Append(deleteURL.GetURLAsString()).Append("&").Append(CheckDeleteControl.DELETEFOLDERS).Append("=\' + ").Append(ObjMgrHeaderView.JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() + \'").Append(LinkConstants.AMPERSAND).Append(CheckDeleteControl.OBJECTIDPAIRS).Append("=\' + ").Append(ObjMgrHeaderView.JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("(), \'_blank2\', \'location=no,menubar=no,height=250,width=350\');\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function " + JAVASCRIPT_OPEN_DOC_SECURITY + "()\n");
      sb.Append("{\n");
      sb.Append("   var checkedStuff = GetCheckedDocsAndFoldersString();\n");
      sb.Append("    window.open(\'").Append(securityURL.GetURLAsString()).Append("\' + checkedStuff, \'_blank3\', \'location=no,menubar=no,height=600,width=800,resizable,scrollbars\');\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("function AdminItemsChecked()\n");
      sb.Append("{\n");
      sb.Append("    var fElem = document." + m_formName + ";\n");
      sb.Append("    var feLen = fElem.elements.length;\n");
      sb.Append("    for (var i = 0; i < feLen; i++) {\n");
      sb.Append("    \t   if (fElem.elements[i].name == \'" + ObjMgrFolderViewHelper.QS_CHECKBOX + "\' && fElem.elements[i].checked) {\n");
      sb.Append("            return true;\n");
      sb.Append("        }\n");
      sb.Append("    \t   if (fElem.elements[i].name.indexOf(\'" + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + "\') != -1 && fElem.elements[i].checked) {\n");
      sb.Append("            return true;\n");
      sb.Append("        }\n");
      sb.Append("    }\n");
      sb.Append("    return false;\n");
      sb.Append("}\n");
      sb.Append("function DocsAndFoldersChecked()\n");
      sb.Append("{\n");
      sb.Append("    var fElem = document." + m_formName + ";\n");
      sb.Append("    var feLen = fElem.elements.length;\n");
      sb.Append("    for (var i = 0; i < feLen; i++) {\n");
      sb.Append("    \t   if (fElem.elements[i].name == \'" + GroupedResultsViewHelper.DOC_FOLDER_INPUT + "\' && fElem.elements[i].checked) {\n");
      sb.Append("            return true;\n");
      sb.Append("        }\n");
      sb.Append("    \t   if (fElem.elements[i].name.indexOf(\'" + GroupedResultsViewHelper.DOC_INPUT + "\') != -1 && fElem.elements[i].checked) {\n");
      sb.Append("            return true;\n");
      sb.Append("        }\n");
      sb.Append("    }\n");
      sb.Append("    return false;\n");
      sb.Append("}\n");
      sb.Append("function GetCheckedDocsAndFoldersString()\n");
      sb.Append("{\n");
      sb.Append("    var fElem = document." + m_formName + ";\n");
      sb.Append("    var feLen = fElem.elements.length;\n");
      sb.Append("    var retval = null;\n");
      sb.Append("    for (var i = 0; i < feLen; i++) {\n");
      sb.Append("    \t   if (fElem.elements[i].name == \'" + GroupedResultsViewHelper.DOC_FOLDER_INPUT + "\' && fElem.elements[i].checked) {\n");
      sb.Append("            if(retval == null)\n");
      sb.Append("            \t\tretval = \'" + XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGFOLDER_ID) + ",\' + SkipFolderPart(fElem.elements[i].value);\n");
      sb.Append("            else\n");
      sb.Append("            \t\tretval += \'," + XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGFOLDER_ID) + ",\' + SkipFolderPart(fElem.elements[i].value);\n");
      sb.Append("        }\n");
      sb.Append("    \t   if (fElem.elements[i].name.indexOf(\'" + GroupedResultsViewHelper.DOC_INPUT + "\') != -1 && fElem.elements[i].checked) {\n");
      sb.Append("            if(retval == null)\n");
      sb.Append("            \t\tretval = \'" + XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGCARD_ID) + ",\' + SkipFolderPart(fElem.elements[i].value);\n");
      sb.Append("            else\n");
      sb.Append("            \t\tretval += \'," + XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGCARD_ID) + ",\' + SkipFolderPart(fElem.elements[i].value);\n");
      sb.Append("        }\n");
      sb.Append("    }\n");
      sb.Append("    return retval;\n");
      sb.Append("}\n");
      sb.Append("function CardsSelected()\n");
      sb.Append("{\n");
      sb.Append("    var fElem = document." + m_formName + ";\n");
      sb.Append("    var feLen = fElem.elements.length;\n");
      sb.Append("    for (var i = 0; i < feLen; i++) {\n");
      sb.Append("    \t   if (fElem.elements[i].name.indexOf(\'" + GroupedResultsViewHelper.DOC_INPUT + "\') != -1 && fElem.elements[i].checked) {\n");
      sb.Append("            return true;\n");
      sb.Append("        }\n");
      sb.Append("    }\n");
      sb.Append("    return false;\n");
      sb.Append("}\n");
      sb.Append("function postToSelf(varPostToSelf)\n");
      sb.Append("{\n");
      sb.Append("     document." + m_formName + ".in_hi_PostToSelf.value= varPostToSelf;\n");
      sb.Append("     document." + m_formName + ".in_hi_control.value = \'AdminSearchRepost\';\n");
      sb.Append("     document." + m_formName + "." + ASConstants.SPACEID_INPUT + ".value= \'" + m_asOwner.GetSpaceID() + "\';\n");
      sb.Append("     document." + m_formName + ".in_hi_page.value =\'" + m_asOwner.GetCurrentPage().GetName() + "\';\n");
      sb.Append("     document." + m_formName + ".in_hi_space.value =\'" + m_asOwner.GetName() + "\';\n");
      sb.Append("     document." + m_formName + "." + AdminSearchRepostControl.CURRENT_KEY_INPUT + ".value = \'" + m_asModel.GetSearchModel().GetCurrentKey() + "\';\n");
      sb.Append("     document." + m_formName + ".submit();\n");
      sb.Append("}\n");
      myScript.AddInnerHTMLString(sb.ToString());
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (AdminSearchModel) model;
      m_asOwner = parent;
    }
    public virtual void SetFormName(String name)
    {
      m_formName = name;
    }
    /*
     * TODO: Consolidate with ObjMgrHeaderView -- need model interface
     */
     
    public static void AddHiddenInputs(HTMLElement myGroup, AdminSearchModel m_asModel)
    {
      // Mandatory inputs (must be filled in correctly)
      // Current folder
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_FOLDER_ID,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      myInput.SetValue(XPConvert.ToString(m_asModel.GetRootFolderID()));
      // Current expanded object types
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_OBJECT_IDS,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      myInput.SetValue(m_asModel.GetAllObjectTypesString());
      // Hidden input for the folder select tree Space ID.
      // That way if you hit the folder tree link twice,
      // it will open the same tree both times.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrHeaderView.HTML_INPUT_FOLDER_TREE_ID,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      String strValue = m_asModel.GetFolderTreeID();
      if (strValue == null)
      {
        strValue = "";
      }
      myInput.SetValue(strValue);
      // Optional inputs (filled in by javascript)
      // Hidden input for the migration or disable comment
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrHeaderView.HTML_INPUT_COMMENT,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Hidden input for the enable/disable boolean
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrHeaderView.HTML_INPUT_ENABLE,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Expand Object ID
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_EXPAND_OBJECT_ID,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Expand value
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrRepostControl.HTML_INPUT_EXPAND_BOOLEAN,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Folder name
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrHeaderView.HTML_INPUT_FOLDERNAME,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Folder desc
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrHeaderView.HTML_INPUT_FOLDERDESC,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, AdminSearchRepostControl.CURRENT_KEY_INPUT,
       "");
      myGroup.AddInnerHTMLElement(myInput);
      // Community Selected
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjMgrHeaderView.HTML_INPUT_COMMSELECTED,
       "");
      myInput.SetValue("0");
      myGroup.AddInnerHTMLElement(myInput);
    }
  }
}