using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.activitysecurity
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Main Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>SudhaS</author>
  public class MainActivityRightsEditorAS : PTEditorAS
  {
    // ***CHANGE_HERE*** Change the name of the class.
    // ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
    //       when you are done.
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.activitysecurity.MainActivityRightsEditorAS");
    // ***CHANGE_HERE*** Set the class name.
    // ***COMMENT_1*** All the AS in Plumtree need to have a unique name.
    public const String STR_MVC_CLASS_NAME = "MainActivityRightsEditor";
    public const String strStorageActivityRightsList = "ActivityRightsList";
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.activitysecurity.MainActivityRightsEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MainActivityRightsEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      // ***CHANGE_HERE*** Return the main title of the Editor.
      return (GetString(1350, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      // ***CHANGE_HERE*** Replace MainRepostControl below with your RepostControl.
      return (MainActivityRightsRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      // ***CHANGE_HERE*** Replace MainModel below with your Model.
      m_strModelName = MainActivityRightsModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(MainActivityRightsModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      // ***CHANGE_HERE*** Register each DP of your AS.
      RegisterPage(new MainActivityRightsDP());
      // Register Controls
      // ***CHANGE_HERE*** Register each Control of your AS.
      RegisterControl(MainActivityRightsRepostControl.STR_MVC_CLASS_NAME,
       myModel);
      // Set default page
      // ***CHANGE_HERE*** Replace MainDP below with the default DP.
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(MainActivityRightsDP.STR_MVC_CLASS_NAME);
      // Sets left nav menu
      // ***CHANGE_HERE*** Set the left nav menu using StartNewSubMenu and AddLinkToSubMenu.
      // ***COMMENT_1*** If you don't want any left nav menu just remove the lines below.
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1351, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainActivityRightsDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      // ***CHANGE_HERE GROWABLELIST*** Register the Section, the Model 
      //      and the Control used by the growable array.
      RegisterModel(MainActivityRightsListModel.STR_MVC_CLASS_NAME, strStorageActivityRightsList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myActivityRightsListModel = GetModel(strStorageActivityRightsList);
      RegisterView(MainActivityRightsListView.STR_MVC_CLASS_NAME, strStorageActivityRightsList,
       myActivityRightsListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageActivityRightsList,
       myActivityRightsListModel);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 75;
          int iTipId = 76;
          int iSecondaryTipId = 77;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <summary>
    /// Set the help page for this editor. 
    /// </summary>
    /// <param name="page"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)"></seealso>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (MainActivityRightsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_ActivityManager_MainSettings");
      }
    }
  }
}