using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.activitysecurity
{
  /// <summary>
  /// This is the implementation of the Expandable List
  /// framework for the Growable Array.
  /// Is constains the HTML to display the Growable Array.
  /// It gets the data to display from GrowableListModel.
  /// </summary>
  /// <author>SudhaS</author>
  public class MainActivityRightsListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.activitysecurity.MainActivityRightsListView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ActivityRightsList";
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String HTMLINPUT_ITEM = "in_tx_Item";
    public const String HTMLHIDDEN_PROPEDITORKEY = "in_hi_PropEditorKey";
    private static int INTRINSIC_ACTIVITY_CEILING = 200;
    private static int INTRINSIC_ACTIVITY_FLOOR = 0;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MainActivityRightsListView();
    }
    
    /// <summary>
    /// Returns Java Script for goToPage function.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = null;
      myScript = new HTMLScript("text/javaScript");
      try
      {
        XPStringBuilder sb;
        sb = new XPStringBuilder(300);
        // JavaScript to sort by column	
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("SortBy") + "(varColumnID)\n");
        sb.Append("{\n");
        sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_COLUMNID) + ".value= varColumnID;\n");
        sb.Append("  postToSelf(" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_SORTBYCOLUMN) + ");\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // JavaScript to sort by column	
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("DeleteRows") + "()\n");
        sb.Append("{\n");
        sb.Append("  if(0 != " + ((IExpListModelRO) m_model).GetUniqueString("CountCheckedRows") + "()) \n");
        sb.Append("  {\n");
        sb.Append("    postToSelf(" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE) + ");\n");
        sb.Append("  }\n");
        sb.Append("  else\n");
        sb.Append("  {\n");
        sb.Append("    alert(\'" + m_asOwner.GetString(60, "ptmsgs_infrastructure") + "\');\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // JavaScript to return the number of checked rows.
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CountCheckedRows") + "()\n");
        sb.Append("{ \n");
        sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME + "; \n");
        sb.Append("  var len = frm.elements.length; \n");
        sb.Append("  var nValue = frm." + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_CHECKALL) + ".checked; \n");
        sb.Append("  var i = 0; \n");
        sb.Append("  var nTotal = 0; \n");
        sb.Append("  \n");
        sb.Append("  for(i=0 ; i<len ; i++) \n");
        sb.Append("  { \n");
        sb.Append("    if (frm.elements[i].name == \'" + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW) + "\') \n");
        sb.Append("    { \n");
        sb.Append("       if (frm.elements[i].checked) \n");
        sb.Append("       { \n");
        sb.Append("          nTotal++; \n");
        sb.Append("       } \n");
        sb.Append("    } \n");
        sb.Append("  } \n");
        sb.Append("  return (nTotal);\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // JavaScript to check all the rows
        sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CheckRows") + "()\n");
        sb.Append("{ \n");
        sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME + "; \n");
        sb.Append("  var len = frm.elements.length; \n");
        sb.Append("  var nValue = frm." + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_CHECKALL) + ".checked; \n");
        sb.Append("  var i = 0; \n");
        sb.Append("  \n");
        sb.Append("  for(i=0 ; i<len ; i++) \n");
        sb.Append("  { \n");
        sb.Append("    if (frm.elements[i].name == \'" + ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW) + "\') \n");
        sb.Append("    { \n");
        sb.Append("       frm.elements[i].checked = nValue;\n");
        sb.Append("    } \n");
        sb.Append("  } \n");
        sb.Append("}\n");
        sb.Append("function CreateProperty()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(((IMainActivityRightsListModelRO) m_model).GetASURLToProperty(null).GetURLAsString()).Append("\', \'PopUpCreateMode\', \'location=no,menubar=no,height=600,width=800, scrollbars=yes, resizable=yes\');\n");
        sb.Append("}\n");
        sb.Append("function EditProperty(varSubSpaceURL,varSubSpaceKey)\n");
        sb.Append("{\n");
        sb.Append("    window.open(varSubSpaceURL, \'PopUpEditMode\' + varSubSpaceKey, \'location=no,menubar=no,height=400,width=800\');\n");
        sb.Append("}\n");
        // Edit object
        //sb = new XPStringBuilder( 200 );
        sb.Append(" function " + ((IMainActivityRightsListModelRO) m_model).GetUniqueString("EditObject") + "(varURL)");
        sb.Append(" {");
        sb.Append("    window.open(varURL,\'PopUpEditMode\',\'location=no,menubar=no,height=600,width=800, scrollbars=yes, resizable=yes\');\n");
        sb.Append(" }");
        sb.Append("function RemoveProperty(varSubSpaceKey)\n");
        sb.Append("{\n");
        sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + HTMLHIDDEN_PROPEDITORKEY + ".value= varSubSpaceKey;\n");
        sb.Append("  postToSelf(" + MainActivityRightsRepostControl.POSTTOSELF_ACTION_REMOVEPROPERTY + ");\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        if (((IExpListModelRO) m_model).GetEnableMoveRowActions())
        {
          sb = new XPStringBuilder(300);
          // JavaScript to sort by column			
          sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("MoveRow") + "(varMoveAction, varRowIndex)\n");
          sb.Append("{\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_ROWINDEX) + ".value= varRowIndex;\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_MOVEACTION) + ".value= varMoveAction;\n");
          sb.Append("  postToSelf(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MOVEROW) + "\');\n");
          sb.Append("}\n");
          myScript.AddInnerHTMLString(sb.ToString());
        }
        String sEmptyListAlert = ((IExpListModelRO) m_model).GetAlertMessageForEmptyList();
        if (null != sEmptyListAlert)
        {
          sb = new XPStringBuilder(300);
          // JavaScript to check if the list is not empty	
          // JF- Note that this method is not called anywhere in the framework. 
          // It has to be registered as a validation function inside the Editor
          sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("CheckEmptyList") + "()\n");
          sb.Append("{\n");
          sb.Append("  \n");
          if (0 == ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
          {
            sb.Append("  alert(\"" + sEmptyListAlert + "\"); \n");
            sb.Append("  return false;\n");
          } else
          {
            sb.Append("  return true;\n");
          }
          sb.Append("}\n");
          myScript.AddInnerHTMLString(sb.ToString());
        }
      }
      catch (Exception e)
      {
        log.Error(e, "MainActivityRIghtsListView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException(m_asOwner.GetString(53, 
        //_ui_DisplayJSError
        "ptmsgs_infrastructure"), e);
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      try
      {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLTableCell myCell;
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        //myCell.SetWidth("100%");
        myCell.SetHeight("30");
        myCell.SetHeight("20");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        int nActivityID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
         MainActivityRightsListModel.EXPLIST_COL_ID));
        bool bIntrinsic = ((nActivityID < INTRINSIC_ACTIVITY_CEILING) && (nActivityID >= INTRINSIC_ACTIVITY_FLOOR));
        MainActivityRightsListModel mainActivityRightsListModel = (MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList);
        if (bIntrinsic)
        {
          mainActivityRightsListModel.SetRowIcon(PTImageType.ICON_ACTIVITY_RIGHT_INTRINSIC);
          } else
        {
          mainActivityRightsListModel.SetRowIcon(PTImageType.ICON_ACTIVITY_RIGHT_CUSTOM);
          }
        // row icon
        PTImageType imgRowIcon = ((IMainActivityRightsListModelRO) m_model).GetRowIcon();
        if (null != imgRowIcon)
        {
          myCell.AddInnerHTMLElement(GetHTMLForIcon(imgRowIcon));
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        }
        // input text
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetHeight("30");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        String strActivityName = (String) _saData.GetItem(_nRowIndex, MainActivityRightsListModel.EXPLIST_COL_NAME);
        String strActivityDesc = (String) _saData.GetItem(_nRowIndex, MainActivityRightsListModel.EXPLIST_COL_DESCRIPTION);
        String strActivityURI = (String) _saData.GetItem(_nRowIndex, MainActivityRightsListModel.EXPLIST_COL_URI);
        myCell.AddInnerHTMLString(SPACE);
        bool bDelegateRight = false;
        for (int i = 0;i < _saData.GetCount();i++)
        {
          int nDelegateCheckID = XPConvert.ToInteger(_saData.GetItem(i, MainActivityRightsListModel.EXPLIST_COL_ID));
          if (nDelegateCheckID == PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_DELEGATE_RIGHTS)
          {
            bDelegateRight = true;
          }
        }
        ASURL myURL = ((IMainActivityRightsListModelRO) m_model).GetEditObjectURL(nActivityID,
         strActivityName, strActivityDesc, strActivityURI, _nRowIndex, bDelegateRight);
        HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick(((IMainActivityRightsListModelRO) m_model).GetUniqueString("EditObject") + "(\'" + myURL.GetURLAsString() + "\',\'" + _nRowIndex + "\'); return false;");
        myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strActivityName));
        myCell.AddInnerHTMLElement(myAnchor);
        myCell.AddInnerHTMLString("<br>");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strActivityDesc));
        return result;
      }
      catch (HTMLException e)
      {
        log.Error("MainActivityRightsListView::" + e.Message);
      }
      catch (Exception e)
      {
        log.Error("MainActivityRightsListView::" + e.Message);
      }
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the checkbox on row _nRowIndex.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
    {
      HTMLTableCell myCell;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetAlign("center");
      myCell.SetVAlign("middle");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      IPTGrowableSortedArrayWrapperRO saData = ((IMainActivityRightsListModelRO) m_model).GetReadOnlyItems();
      int nActivityID = XPConvert.ToInteger(saData.GetItem(_nRowIndex, MainActivityRightsListModel.EXPLIST_COL_ID));
      bool bIntrinsic = ((nActivityID < INTRINSIC_ACTIVITY_CEILING) && (nActivityID >= INTRINSIC_ACTIVITY_FLOOR));
      // checkbox
      if (!bIntrinsic)
      {
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW),
         ((IExpListModelRO) m_model).GetDeleteIconAlt());
        myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        myInput.SetValue(XPConvert.ToString(_nRowIndex));
        myCell.AddInnerHTMLElement(myInput);
      }
      return (myCell);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the space below the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLForActionBar()
    {
      try
      {
        HTMLTable myTable;
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        myTable = new HTMLTable();
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        MainActivityRightsListModel mainActivityRightsListModel = (MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList);
        PTGrowableSortedArrayWrapper aData = mainActivityRightsListModel.GetItems();
        bool bCreateRight = false;
        for (int i = 0;i < aData.GetCount();i++)
        {
          int nActivityID = XPConvert.ToInteger(aData.GetItem(i, MainActivityRightsListModel.EXPLIST_COL_ID));
          if (nActivityID == PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_ACTIVITIES)
          {
            bCreateRight = true;
          }
        }
        // 1st Row begin (there is only one row)
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
        // Empty Cell
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        if (bCreateRight)
        {
          // Add icon cell
          myRow.AddInnerHTMLElement(GetHTMLForAddAction());
          myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
          // JF- No need to display the delete icon, if the list is empty.
          if (0 != ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
          {
            // Delete icon cell
            myRow.AddInnerHTMLElement(GetHTMLForDeleteAction());
          }
          // Add Extra HTML to the action bar (like a "create" button)
          AddHTMLToActionBar(myRow);
          // Last Empty Cell
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("100%");
          myCell.SetHeight("25");
          myCell.AddInnerHTMLString(SPACE);
        } else
        {
          //Add message to tell user that they do not have rights to create/delete an activity
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          //myCell.SetWidth("100%");
          myCell.SetHeight("25");
          myCell.AddInnerHTMLString(SPACE);
          myCell = new HTMLTableCell();
          myCell.SetWidth("100%");
          myCell.SetHeight("25");
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
          myCell.AddInnerHTMLString(m_asOwner.GetString(2368, "ptmsgs_portaladminmsgs"));
          }
        // 1st Row ends
        return myTable;
      }
      catch (HTMLException e)
      {
        log.Error("MainActivityRightsListView::" + e.Message);
      }
      catch (Exception e)
      {
        log.Error("MainActivityRightsListView::" + e.Message);
      }
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      try
      {
        HTMLTableCell myCell;
        PTConstruct myConstruct;
        HTMLImg myImage;
        HTMLImg myAddIcon;
        HTMLAnchor myAnchor;
        HTMLSpan mySpan;
        myCell = new HTMLTableCell();
        myCell.SetHeight("25");
        myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(SPACE);
        // Add icon
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
         true, this.m_asOwner);
        myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
        myAddIcon.SetAlt("");
        myAddIcon.SetAlign("absmiddle");
        // Add icon
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ACTIVITY_RIGHT,
         true, this.m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetAlign("absmiddle");
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("CreateProperty(); return false;");
        myAnchor.AddInnerHTMLElement(myAddIcon);
        myAnchor.AddInnerHTMLElement(myImage);
        mySpan = new HTMLSpan();
        myAnchor.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
        // Add label
        mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
        mySpan.AddInnerHTMLString(SPACE);
        mySpan.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLElement(myAnchor);
        myCell.AddInnerHTMLString(SPACE);
        return myCell;
      }
      catch (HTMLException e)
      {
        log.Error("MainActivityRightsListView::" + e.Message);
      }
      catch (Exception e)
      {
        log.Error("MainActivityRightsListView::" + e.Message);
      }
      return null;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetHTMLForIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
  }
}