using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.activitysecurity
{
  /// <summary>
  /// This class keeps an up-to-date state of all the settings.
  /// It contains the set and get methods for those settings.
  /// It contains the start, save and finish methods.
  /// This class is used by the Section MainView (to get the
  /// latest value of the settings to display) and by the
  /// Control MainRepostControl (to perform the repost actions).
  /// </summary>
  /// <author>SudhaS</author>
  public class MainActivityRightsModel : EditorModel,IMainActivityRightsModelRO
  {
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MainActivityRights";
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      MainActivityRightsListModel activityRightsList = (MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList);
      activityRightsList.InitializeActivityRightsList(m_asOwner.GetString(1357,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1358, "ptmsgs_portaladminmsgs"),
       PTImageType.ACTION_ADD, m_asOwner.GetString(1359, "ptmsgs_portaladminmsgs"),
       1);
      activityRightsList.SetRowIcon(PTImageType.ICON_FOLDER_OPEN);
      IPTSessionInfo ptSessionInfo = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo();
      IPTQueryResult ptqrActivityRights = ptSessionInfo.QueryActivityRights();
      Object[][] oRows = new Object[ptqrActivityRights.RowCount()][];
      for (int j2c_index = 0;j2c_index < ptqrActivityRights.RowCount();j2c_index++)
      {
        oRows[j2c_index] = new Object[MainActivityRightsListModel.EXPLIST_COL_MAX];
        }
      for (int i = 0;i < ptqrActivityRights.RowCount();i++)
      {
        oRows[i][MainActivityRightsListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = activityRightsList.m_nNextIndex;
        activityRightsList.m_nNextIndex++;
        oRows[i][MainActivityRightsListModel.EXPLIST_COL_ID] = ptqrActivityRights.ItemAsInt(i,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        oRows[i][MainActivityRightsListModel.EXPLIST_COL_NAME] = ptqrActivityRights.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_NAME);
        oRows[i][MainActivityRightsListModel.EXPLIST_COL_DESCRIPTION] = ptqrActivityRights.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_DESCRIPTION);
        oRows[i][MainActivityRightsListModel.EXPLIST_COL_URI] = ptqrActivityRights.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_ACTIVITY_URI);
      }
      activityRightsList.SetDefaultObjects(oRows);
      activityRightsList.SetEmptyListMessages(m_asOwner.GetString(1360, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(1361, "ptmsgs_portaladminmsgs"));
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MainActivityRightsModel();
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      ((MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList)).DoTaskOnComeBackFromSubEditor();
      }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      //Done for deletion purposes - first delete all rights, and then add the ones that still remain in the GrowableArray
      int[] aRowsToDelete = ((MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList)).GetRowsToDelete();
      if (aRowsToDelete != null)
      {
        RemoveGroups(aRowsToDelete);
      }
    }
    //RemoveAllGroups();
    //AddRemainingGroups();
    
    /// <param name="nActivityID"></param>
    /// <returns></returns>
    public virtual Object[] GetGroups(int nActivityID)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
       false);
      IPTQueryResult ptqrGroups = ptActivityGroups.QueryAllGroups(nActivityID);
      Object[] groups = new Object[ptqrGroups.RowCount()];
      for (int i = 0;i < ptqrGroups.RowCount();i++)
      {
        int nGroupID = ptqrGroups.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        groups[i] = nGroupID;
      }
      return groups;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_aRowsToDelete"></param>
    public virtual void RemoveGroups(int[] _aRowsToDelete)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
       false);
      for (int i = 0;i < _aRowsToDelete.Length;i++)
      {
        //ptActivityGroups.RevokeRightFromGroups(_aRowsToDelete[i], GetGroups(_aRowsToDelete[i]));
        ((IPTListManager) ptActivityGroups.GetInterfaces("IPTListManager")).DeleteItem(_aRowsToDelete[i]);
        }
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}