using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.automationserver
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,  and
  /// Controls created for the Main Editor. This class can also be used to get
  /// any of those objects back with  the class name.
  /// </summary>
  /// <author>SudhaS</author>
  public class AutomationServerEditorAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.automationserver.AutomationServerEditorAS");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AutomationServerEditor";
    
    /// <summary>
    /// Unique name for the automation server list control 
    /// </summary>
    public const String strStorageAutomationServerList = "AutomationServerList";
    
    /// <summary>
    /// Fully qualified class name 
    /// </summary>
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.automationserver.AutomationServerEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AutomationServerEditorAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(1435, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (AutomationServerRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = AutomationServerModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(AutomationServerModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new AutomationServerDP());
      RegisterPage(new AutomationServerPopUpDP());
      RegisterPage(new JobHistoriesDP());
      //Register the classes from the joblogs package
      RegisterModel(JobLogModel.STR_MVC_CLASS_NAME);
      IModel myJobLogModel = GetModel(JobLogModel.STR_MVC_CLASS_NAME);
      RegisterView(HistoryView.STR_MVC_CLASS_NAME, myJobLogModel);
      RegisterControl(JobLogRepostControl.STR_MVC_CLASS_NAME, myJobLogModel);
      // Job Log Download Page -- this needs to be registered after
      // the Job Log Model.
      RegisterPage(new JobLogDownloadDP());
      //Popup view
      RegisterView(AutomationServerPopUpView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(AutomationServerRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      SetCurrentPage(AutomationServerDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Utility Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1436, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AutomationServerDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, JobHistoriesDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      // Register AutomationServerList 
      RegisterModel(AutomationServerListModel.STR_MVC_CLASS_NAME, strStorageAutomationServerList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myAutomationServerListModel = GetModel(strStorageAutomationServerList);
      RegisterView(AutomationServerListView.STR_MVC_CLASS_NAME, strStorageAutomationServerList,
       myAutomationServerListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageAutomationServerList,
       myAutomationServerListModel);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 78;
          int iTipId = 79;
          int iSecondaryTipId = 80;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (AutomationServerDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AutomationServerManager_MainSettings");
      } else
      if (JobHistoriesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AutomationServerManager_JobHistories");
      }
    }
  }
}