using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.automationserver
{
  /// <summary>
  /// This class keeps an up-to-date state of all the settings.
  /// It contains the set and get methods for those settings.
  /// It contains the start, save and finish methods.
  /// This class is used by the Section MainView (to get the
  /// latest value of the settings to display) and by the
  /// Control MainRepostControl (to perform the repost actions).
  /// </summary>
  /// <author>SudhaS</author>
  public class AutomationServerModel : EditorModel,IAutomationServerModelRO
  {
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AutomationServer";
    protected String m_strServerName = "";
    protected String m_strServerNetAddr = "";
    protected XPDateTime m_dtDeleteDate = null;
    protected XPDateTime m_dtFromDate = null;
    protected XPDateTime m_dtToDate = null;
    protected bool m_bFromPopUp = false;
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      InitializeAutomationServerList();
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AutomationServerModel();
    }
    
    /// <summary>
    /// Executes when the user returns from the automation server popup
    /// </summary>
    public virtual void DoTaskOnComeBackFromPopUp()
    {
      int nServerLookupIndex = -1;
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTScheduler ptScheduler = ptSession.GetScheduler();
      AutomationServerListModel AutomationServerList = (AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList);
      ptScheduler.RegisterJobServer(m_strServerName, m_strServerNetAddr);
      IPTQueryResult ptqrAutomationServer = ptScheduler.QueryJobServerStatus("*");
      for (int i = 0;i < ptqrAutomationServer.RowCount();i++)
      {
        //String strTempServerName = (String) ptqrAutomationServer.Item(i, PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
        if (XPStringUtility.CompareIgnoreCase(m_strServerName, ptqrAutomationServer.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME)) == 0)
        {
          nServerLookupIndex = i;
          break;
        }
      }
      Object[] oRow = new Object[AutomationServerListModel.EXPLIST_COL_MAX];
      if (nServerLookupIndex != -1)
      {
        oRow[AutomationServerListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = AutomationServerList.m_nNextIndex;
        AutomationServerList.m_nNextIndex++;
        oRow[AutomationServerListModel.EXPLIST_COL_NAME] = ptqrAutomationServer.ItemAsString(nServerLookupIndex,
         PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
        oRow[AutomationServerListModel.EXPLIST_COL_NETADDR] = ptqrAutomationServer.ItemAsString(nServerLookupIndex,
         PT_PROPIDS.PT_PROPID_JOBSERVER_NETADDRESS);
        oRow[AutomationServerListModel.EXPLIST_COL_STATUS] = ptqrAutomationServer.ItemAsInt(nServerLookupIndex,
         PT_PROPIDS.PT_PROPID_JOBSERVER_STATUS);
        oRow[AutomationServerListModel.EXPLIST_COL_LASTUPDATE] = ptqrAutomationServer.ItemAsXPDateTime(nServerLookupIndex,
         PT_PROPIDS.PT_PROPID_JOBSERVER_LASTUPDATE);
        AutomationServerList.GetItems().AddRow(oRow);
      }
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      ((AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList)).DoTaskOnComeBackFromSubEditor();
      }
    
    /// <summary>
    /// Null implementation of parent function
    /// </summary>
    public virtual void DoTaskOnDeleteFromDate()
    {
    }
    public virtual void DoTaskOnShowNewDates()
    {
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      String[] aRowsToDelete = ((AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList)).GetRowsToDelete();
      if (aRowsToDelete != null)
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        IPTScheduler ptScheduler = ptSession.GetScheduler();
        for (int i = 0;i < aRowsToDelete.Length;i++)
        {
          ptScheduler.UnregisterJobServer(aRowsToDelete[i]);
        }
      }
    }
    //TODO:SS Get Date as it appears from calendar
    public virtual String GetFromDateAsString()
    {
      XPDateFormat df = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
       /* use portal server time zone */
      false);
      return df.Format(m_dtFromDate);
    }
    // ***CHANGE_HERE*** Update the class name below.
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual String GetToDateAsString()
    {
      XPDateFormat df = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
       /* use portal server time zone */
      false);
      return df.Format(m_dtToDate);
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SaveAutomationServer(XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int n_PageStatus = RepostControl.PAGE_STATUS_VALID;
      String[] data;
      data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NAME);
      if (data != null)
      {
        m_strServerName = data[0];
      }
      if (data == null)
      {
        data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NETADDR);
        }
      if (data != null)
      {
        m_strServerNetAddr = data[0];
      }
      if (_sPageName.Equals(JobHistoriesDP.STR_MVC_CLASS_NAME))
      {
        n_PageStatus = ((JobLogModel) m_asOwner.GetModel(JobLogModel.STR_MVC_CLASS_NAME)).SavePage(_sPageName,
         _htFormData);
      }
      return n_PageStatus;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SavePopUp(XPHashtable _htFormData)
    {
      String[] data;
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTScheduler ptScheduler = ptSession.GetScheduler();
      data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NAME);
      if (data != null)
      {
        m_strServerName = data[0];
      }
      data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NETADDR);
      if (data != null)
      {
        m_strServerNetAddr = data[0];
      }
      ptScheduler.RegisterJobServer(m_strServerName, m_strServerNetAddr);
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="_bComingFromPopup"></param>
    public virtual void SetFromPopup(bool _bComingFromPopup)
    {
      m_bFromPopUp = _bComingFromPopup;
    }
    protected virtual void InitializeAutomationServerList()
    {
      AutomationServerListModel AutomationServerList = (AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList);
      AutomationServerList.InitializeAutomationServerList(m_asOwner.GetString(1444,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1445, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(1446, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1447,
       "ptmsgs_portaladminmsgs"), PTImageType.ICON_AUTOMATION_SERVER, m_asOwner.GetString(1448,
       "ptmsgs_portaladminmsgs"), 1);
      //     Use the method below to set the icon to display on each row before the input text.
      //     (By default there will be no icon.)
      //AutomationServerList.SetRowIcon(PTImageType.ICON_FOLDER_OPEN);
      AutomationServerList.SetRowIcon(PTImageType.ICON_AUTOMATION_SERVER);
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTScheduler ptScheduler = ptSession.GetScheduler();
      IPTQueryResult ptqrAutomationServer = ptScheduler.QueryJobServerStatus("*");
      Object[][] oRows = new Object[ptqrAutomationServer.RowCount()][];
      for (int j2c_index = 0;j2c_index < ptqrAutomationServer.RowCount();
      j2c_index++)
      {
        oRows[j2c_index] = new Object[AutomationServerListModel.EXPLIST_COL_MAX];
        }
      for (int i = 0;i < ptqrAutomationServer.RowCount();i++)
      {
        oRows[i][AutomationServerListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = AutomationServerList.m_nNextIndex;
        AutomationServerList.m_nNextIndex++;
        oRows[i][AutomationServerListModel.EXPLIST_COL_NAME] = ptqrAutomationServer.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
        oRows[i][AutomationServerListModel.EXPLIST_COL_NETADDR] = ptqrAutomationServer.ItemAsString(i,
         PT_PROPIDS.PT_PROPID_JOBSERVER_NETADDRESS);
        oRows[i][AutomationServerListModel.EXPLIST_COL_STATUS] = ptqrAutomationServer.ItemAsInt(i,
         PT_PROPIDS.PT_PROPID_JOBSERVER_STATUS);
        oRows[i][AutomationServerListModel.EXPLIST_COL_LASTUPDATE] = ptqrAutomationServer.ItemAsXPDateTime(i,
         PT_PROPIDS.PT_PROPID_JOBSERVER_LASTUPDATE);
      }
      //AutomationServerList.AddPropertyToSubSpace();
      //AutomationServerList.AddPropertyToArray();
      //for (int i = 0; i < 3; i++) {
      AutomationServerList.SetDefaultObjects(oRows);
      AutomationServerList.SetEmptyListMessages(m_asOwner.GetString(1449,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1450, "ptmsgs_portaladminmsgs"));
      }
  }
}