using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.condition;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.condition
{
  /// <author>DustinA</author>
  public class RulesListModel : SelectPTObjectModel,IRulesListModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.condition.RulesListModel");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RulesListModel";
    
    /// <summary>
    /// Name of Row 
    /// </summary>
    public const int EXPLIST_OBJECTID = 1;
    
    /// <summary>
    /// Name of Row 
    /// </summary>
    public const int EXPLIST_NAME = 2;
    
    /// <summary>
    /// Name of Row 
    /// </summary>
    public const int EXPLIST_DESCRIPTION = 3;
    
    /// <summary>
    /// Action of Row 
    /// </summary>
    public const int EXPLIST_ACTIONNAME = 4;
    
    /// <summary>
    /// Action of Row 
    /// </summary>
    public const int EXPLIST_ACTIONVALUE = 5;
    public const int RULES_PAGINATION_SIZE = 15;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RulesListModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeRulesList(String _sSectionTitle, PTImageType _imgAddIcon,
     String _sAddLabel, int[] _arrObjectClassIDs, Object[][] arrExpListColInfo,
     int _nListKey)
    {
      m_arrObjectClassIDs = _arrObjectClassIDs;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_OBJECTID,
       EXPLIST_NAME, EXPLIST_DESCRIPTION, EXPLIST_ACTIONNAME, EXPLIST_ACTIONVALUE};
      // JF- Sort array
      // The growable array will always be sorted by the 1st column.
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      // DCA - kind of a hack to determine which list is being initialized
      if (SubportalRulesManagerModel.FOLDER_RULES_LIST_KEY == m_nListKey)
      {
        arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_NAME;
        } else
      {
        arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
        }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      String sEditorASName;
      EditorAS myEditorAS;
      ObjEditorModel myObjEditorModel;
      Object[] oNewRow;
      int nClassID;
      int nObjectID;
      // JF- Check if they are any newly created objects
      for (int i = 0;i < m_arrCreateNewInfo.Length;i++)
      {
        sEditorASName = (String) m_arrCreateNewInfo[i][CREATE_NEW_COL_ASNAME];
        if (m_asOwner.GetSubSpaceExists(sEditorASName))
        {
          myEditorAS = (EditorAS) m_asOwner.GetSubSpace(sEditorASName);
          myObjEditorModel = (ObjEditorModel) myEditorAS.GetModel(myEditorAS.m_strModelName);
          oNewRow = new Object[6];
          oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
          m_nNextIndex++;
          oNewRow[EXPLIST_OBJECTID] = myObjEditorModel.GetObjectID();
          oNewRow[EXPLIST_NAME] = myObjEditorModel.GetObjectName();
          oNewRow[EXPLIST_DESCRIPTION] = myObjEditorModel.GetObjectDescription();
          int nRuleAction = ((IPTExpression) myObjEditorModel.GetObject()).GetActionValue();
          IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
          oNewRow[EXPLIST_ACTIONNAME] = ptExpressionManager.GetActionValueName(ActionTypeEnum.SUBPORTAL,
           nRuleAction);
          oNewRow[EXPLIST_ACTIONVALUE] = nRuleAction;
          base.GetItems().AddRow(oNewRow);
          SubportalRulesManagerModel spRuleModel = (SubportalRulesManagerModel) m_asOwner.GetModel(SubportalRulesManagerModel.STR_MVC_CLASS_NAME);
          spRuleModel.AddNewlyCreatedObject(new int[]{myObjEditorModel.GetObjectID(),
           nRuleAction});
          m_asOwner.DeleteSubSpace(sEditorASName);
        }
      }
      // JF- Go through all the existing sub spaces and update the Object name.
      for (int i = 0;i < m_saData.GetCount();i++)
      {
        nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
        nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_OBJECTID));
        if (m_asOwner.GetSubSpaceExists(STR_MVC_CLASS_NAME + nClassID + nObjectID))
        {
          try
          {
            EditorAS mySpace = (EditorAS) m_asOwner.GetSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
            myObjEditorModel = (ObjEditorModel) mySpace.GetModel(mySpace.m_strModelName);
            int nRuleAction = ((IPTExpression) myObjEditorModel.GetObject()).GetActionValue();
            IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
            m_saData.SetItem(i, EXPLIST_NAME, myObjEditorModel.GetObjectName());
            m_saData.SetItem(i, EXPLIST_DESCRIPTION, myObjEditorModel.GetObjectDescription());
            m_saData.SetItem(i, EXPLIST_ACTIONNAME, ptExpressionManager.GetActionValueName(ActionTypeEnum.SUBPORTAL,
             nRuleAction));
            m_saData.SetItem(i, EXPLIST_ACTIONVALUE, nRuleAction);
          }
          catch (Exception e)
          {
            log.Warn("Could not retrieve the sub Space with key: " + STR_MVC_CLASS_NAME + nClassID + nObjectID);
            }
        }
        nClassID = PT_CLASSIDS.PT_SUBPORTAL_ID;
        nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_ACTIONVALUE));
        if (m_asOwner.GetSubSpaceExists(STR_MVC_CLASS_NAME + nClassID + nObjectID))
        {
          try
          {
            EditorAS mySpace = (EditorAS) m_asOwner.GetSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
            myObjEditorModel = (ObjEditorModel) mySpace.GetModel(mySpace.m_strModelName);
            m_saData.SetItem(i, EXPLIST_ACTIONNAME, myObjEditorModel.GetObjectName());
            m_asOwner.DeleteSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
            }
          catch (Exception e)
          {
            log.Warn("Could not retrieve the sub Space with key: " + STR_MVC_CLASS_NAME + nClassID + nObjectID);
            }
        }
        nClassID = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
        nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_OBJECTID));
        if (m_asOwner.GetSubSpaceExists(STR_MVC_CLASS_NAME + nClassID + nObjectID))
        {
          try
          {
            EditorAS mySpace = (EditorAS) m_asOwner.GetSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
            myObjEditorModel = (ObjEditorModel) mySpace.GetModel(mySpace.m_strModelName);
            m_saData.SetItem(i, EXPLIST_NAME, myObjEditorModel.GetObjectName());
            }
          catch (Exception e)
          {
            log.Warn("Could not retrieve the sub Space with key: " + STR_MVC_CLASS_NAME + nClassID + nObjectID);
            }
        }
      }
    }
    
    /// <summary>
    /// Returns the icon to display on each row before the
    /// input text.
    /// If the value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    public virtual PTImageType GetRowIcon()
    {
      return m_imgDefaultRowIcon;
    }
    
    /// <param name="_bEnableMoveRowActions"></param>
    public override void SetEnableMoveRowActions(bool _bEnableMoveRowActions)
    {
      base.SetEnableMoveRowActions(_bEnableMoveRowActions);
      // change back to span 1 column
      m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
    }
    
    /// <summary>
    /// Returns the URL to edit the object.
    /// </summary>
    /// <param name="_nClassID"></param>
    /// <param name="_nObjectID"></param>
    /// <param name="_sEditorASName"></param>
    /// <returns>ASURL URL to the Editor</returns>
    public virtual ASURL GetEditObjectURL(int _nClassID, int _nObjectID, String sEditorASName)
    {
      ASURL myURL = new ASURL(m_asOwner);
      // JF- For any Object in the list, the sub space key will be 
      // this Model name with the object class id and the object id.
      String sSubEditorKey = STR_MVC_CLASS_NAME + _nClassID + _nObjectID;
      if (m_asOwner.GetSubSpaceExists(sSubEditorKey))
      {
        EditorAS mySubEditor = (EditorAS) m_asOwner.GetSubSpace(sSubEditorKey);
        myURL.SetLinkGetCachedSpace(mySubEditor);
      } else
      {
        myURL.SetLinkCreateNewSpace(sEditorASName, m_asOwner);
        myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
        myURL.SetSubSpaceKey(sSubEditorKey);
        myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(_nClassID));
        myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
         XPConvert.ToString(_nObjectID));
      }
      return myURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.pagination.IPaginationModelRO#GetPaginationSize()"></seealso>
    public override int GetPaginationSize()
    {
      return RULES_PAGINATION_SIZE;
    }
  }
}