using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.adminfolder;
using com.plumtree.portalpages.admin.editors.condition;
using com.plumtree.portalpages.admin.editors.subportal;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.condition
{
  /// <author>DustinA</author>
  public class RulesListView : SelectPTObjectView
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RulesListView";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RulesListView();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // do not show rank if we're on the folder rules page
      if (m_asOwner.GetCurrentPage().GetName() != SubportalRulesManagerFolderDP.STR_MVC_CLASS_NAME)
      {
        result.AddInnerHTMLElement(GetHTMLForRankColumn(_saData, _nRowIndex));
        }
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      result.AddInnerHTMLElement(GetHTMLForActionColumn(_saData, _nRowIndex));
      // only show arrows if we're on the subportal rules page
      if (m_asOwner.GetCurrentPage().GetName() == SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME)
      {
        result.AddInnerHTMLElement(GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForRankColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLString(XPConvert.ToString(_nRowIndex + 1));
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      Object objID = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_OBJECTID);
      Object objName = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_NAME);
      Object objDescription = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_DESCRIPTION);
      // only show name as editable if we're on the subportal rules page
      if (m_asOwner.GetCurrentPage().GetName() != SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME)
      {
        int nClassID;
        String strASName;
        if (m_asOwner.GetCurrentPage().GetName() == SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME)
        {
          nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
          strASName = RuleEditorAS.STR_MVC_CLASS_NAME;
        } else
        {
          nClassID = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
          strASName = AdminFolderEditorAS.STR_MVC_CLASS_NAME;
        }
        ASURL asEditURL = ((IRulesListModelRO) m_model).GetEditObjectURL(nClassID,
         XPConvert.ToInteger(objID), strASName);
        HTMLAnchor myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
        myAnchor.SetOnClick(((IRulesListModelRO) m_model).GetUniqueString("EditObject") + "(\'" + asEditURL.GetURLAsString() + "\'," + _nRowIndex + ")");
        myAnchor.AddInnerHTMLEncodedString(XPConvert.ToString(objName));
        myCell.AddInnerHTMLElement(myAnchor);
      } else
      {
        myCell.AddInnerHTMLEncodedString(XPConvert.ToString(objName));
      }
      myCell.AddInnerHTMLElement(new HTMLBr());
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLEncodedString((String) objDescription);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForActionColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      Object objActionID = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_ACTIONVALUE);
      Object objActionName = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_ACTIONNAME);
      // only show action as editable if we're on the subportal rules page
      if (m_asOwner.GetCurrentPage().GetName() != SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME)
      {
        if (null == objActionName)
        {
          myCell.AddInnerHTMLString(m_asOwner.GetString(2853, "ptmsgs_portaladminmsgs"));
          } else
        {
          ASURL asEditURL = ((IRulesListModelRO) m_model).GetEditObjectURL(PT_CLASSIDS.PT_SUBPORTAL_ID,
           XPConvert.ToInteger(objActionID), SubPortalAS.STR_MVC_CLASS_NAME);
          HTMLAnchor myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
          myAnchor.SetOnClick(((IRulesListModelRO) m_model).GetUniqueString("EditObject") + "(\'" + asEditURL.GetURLAsString() + "\'," + _nRowIndex + ")");
          myAnchor.AddInnerHTMLEncodedString(XPConvert.ToString(objActionName));
          myCell.AddInnerHTMLElement(myAnchor);
        }
      } else
      {
        myCell.AddInnerHTMLEncodedString(XPConvert.ToString(objActionName));
        }
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the checkbox on row _nRowIndex.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
    {
      HTMLTableCell myCell;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("30");
      myCell.SetAlign("center");
      myCell.SetVAlign("middle");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      // checkbox
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, ((IRulesListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW),
       ((IRulesListModelRO) m_model).GetDeleteIconAlt());
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetValue(XPConvert.ToString(_nRowIndex));
      myCell.AddInnerHTMLElement(myInput);
      return (myCell);
    }
  }
}