using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.condition;
using com.plumtree.portaluiinfrastructure.condition;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.condition;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.condition
{
  public class SubportalRulesManagerModel : EditorModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.condition.SubportalRulesManagerModel");
    public const String STR_MVC_CLASS_NAME = "SubportalRulesManagerModel";
    public const int SUBPORTAL_RULES_LIST_KEY = 1;
    public const int GUEST_RULES_LIST_KEY = 2;
    public const int FOLDER_RULES_LIST_KEY = 3;
    private XPArrayList m_xpNewlyCreatedList;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SubportalRulesManagerModel();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#CheckEditorAccessAndStart(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override bool CheckEditorAccessAndStart(XPHashtable arg0)
    {
      m_xpNewlyCreatedList = new XPArrayList();
      if (((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SUBPORTAL_RULES_MANAGER))
      {
        // DCA - we have access rights, initialize the rules list and return true
        StartSubportalRulesList();
        StartGuestRulesList();
        StartFolderRulesList();
        return true;
      } else
      {
        return false;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#Finish()
     */
     
    public override void Finish()
    {
      IPTObjectManager ptExpressionManager = ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
      RulesListModel myPTObjectModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.SUBPORTAL_RULES_LIST);
      PTGrowableSortedArrayWrapper ptItems = myPTObjectModel.GetItems();
      XPArrayList xpOldItemList = PortalObjectsFactory.GetExpressionEngineInstance().GetExpressionList(ActionTypeEnum.SUBPORTAL);
      XPArrayList xpKeepItemList = new XPArrayList();
      int[] arExpression;
      for (int i = 0;i < ptItems.GetCount();i++)
      {
        arExpression = new int[2];
        arExpression[0] = XPConvert.ToInteger(ptItems.GetItem(i, RulesListModel.EXPLIST_OBJECTID));
        arExpression[1] = XPConvert.ToInteger(ptItems.GetItem(i, RulesListModel.EXPLIST_ACTIONVALUE));
        // set the topic pos
        IPTExpression ptExpression = (IPTExpression) ptExpressionManager.Open(arExpression[0],
         false);
        ptExpression.SetTopicPos(i + 1);
        // store object again
        ptExpression.LockObject();
        ptExpression.Store();
        ptExpression.UnlockObject();
        xpKeepItemList.Add(arExpression);
        // item made the keep list, remove from old item list or new created list
        RemoveItem(xpOldItemList, arExpression);
        RemoveItem(m_xpNewlyCreatedList, arExpression);
      }
      // old items that have been deleted from the list needs to be deleted
      for (int i = 0;i < xpOldItemList.GetSize();i++)
      {
        arExpression = (int[]) xpOldItemList.GetElement(i);
        ptExpressionManager.Delete(arExpression[0]);
      }
      // newly created items that were deleted from the list needs to be deleted
      for (int i = 0;i < m_xpNewlyCreatedList.GetSize();i++)
      {
        arExpression = (int[]) m_xpNewlyCreatedList.GetElement(i);
        ptExpressionManager.Delete(arExpression[0]);
      }
      PortalObjectsFactory.GetExpressionEngineInstance().ReorderExpressions(ActionTypeEnum.SUBPORTAL,
       xpKeepItemList);
    }
    
    /// <summary>
    /// Helper method to remove the specified item from the array list.
    /// </summary>
    /// <param name="xpItemList">- list with item</param>
    /// <param name="arItem">- item to be removed</param>
    private void RemoveItem(XPArrayList xpItemList, int[] arItem)
    {
      IXPEnumerator xpListEnum = xpItemList.GetEnumerator();
      int[] xpCurrent = null;
      while (xpListEnum.MoveNext())
      {
        xpCurrent = (int[]) xpListEnum.GetCurrent();
        if (xpCurrent[0] == arItem[0])
        {
          break;
        }
        xpCurrent = null;
      }
      if (null != xpCurrent)
      {
        xpItemList.Remove(xpCurrent);
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()
     */
     
    public override void Cancel()
    {
      // if user cancels, we need to delete all newlycreated objects
      IPTObjectManager ptExpressionManager = ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
      int[] xpCurrent;
      for (int i = 0;i < m_xpNewlyCreatedList.GetSize();i++)
      {
        xpCurrent = (int[]) m_xpNewlyCreatedList.GetElement(i);
        ptExpressionManager.Delete(xpCurrent[0]);
      }
    }
    
    /// <summary>
    /// Method to help keep track of the new objects being created.
    /// </summary>
    /// <param name="arObjectInfo">
    /// - object information needed to keep track 
    /// of new objects created
    /// </param>
    public virtual void AddNewlyCreatedObject(int[] arObjectInfo)
    {
      m_xpNewlyCreatedList.Add(arObjectInfo);
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#SavePage(java.lang.String, com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override int SavePage(String arg0, XPHashtable arg1)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Helper method to start the Select PTObject List.
    /// </summary>
    private void StartSubportalRulesList()
    {
      RulesListModel myPTObjectModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.SUBPORTAL_RULES_LIST);
      Object[][] arrExpListColInfo = new Object[4][];
      for (int j2c_index = 0;j2c_index < 4;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX;
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2847,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_WIDTH] = "4%";
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_NAME;
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2848,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_WIDTH] = "67%";
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_ACTIONNAME;
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2849,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_WIDTH] = "20%";
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[3][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_ACTIONVALUE;
      arrExpListColInfo[3][RulesListModel.EXPLIST_COLUMN_TITLE] = "";
      arrExpListColInfo[3][RulesListModel.EXPLIST_COLUMN_WIDTH] = "9%";
      arrExpListColInfo[3][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[3][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      // ***GroupList*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      myPTObjectModel.InitializeRulesList(m_asOwner.GetString(2865, "ptmsgs_portaladminmsgs"),
       null, "", new int[]{PT_CLASSIDS.PT_EXPRESSION_ID}, arrExpListColInfo,
       SUBPORTAL_RULES_LIST_KEY);
      myPTObjectModel.DisableAddButton();
      myPTObjectModel.SetEnableMoveRowActions(true);
      myPTObjectModel.EnablePagination(SubportalRulesManagerAS.SUBPORTAL_RULES_LIST);
      String[][] strParams = new String[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        strParams[j2c_index] = new String[2];
      }
      strParams[0][0] = ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID;
      strParams[0][1] = XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
      strParams[1][0] = ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER;
      strParams[1][1] = XPConvert.ToString(true);
      Object[][] arrCreateNewInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrCreateNewInfo[j2c_index] = new Object[SelectPTObjectModel.CREATE_NEW_COL_MAXWITHPARAMS];
        }
      arrCreateNewInfo[0][RulesListModel.CREATE_NEW_COL_CLASSID] = PT_CLASSIDS.PT_EXPRESSION_ID;
      arrCreateNewInfo[0][RulesListModel.CREATE_NEW_COL_ASNAME] = RuleEditorAS.STR_MVC_CLASS_NAME;
      arrCreateNewInfo[0][RulesListModel.CREATE_NEW_COL_LABEL] = m_asOwner.GetString(2866,
       "ptmsgs_portaladminmsgs");
      arrCreateNewInfo[0][RulesListModel.CREATE_NEW_COL_ICON] = PTImageType.ICON_SUBPORTAL_RULE;
      arrCreateNewInfo[0][RulesListModel.CREATE_NEW_COL_PARAMS] = strParams;
      myPTObjectModel.SetEnableCreateNew(arrCreateNewInfo);
      myPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(2867, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(2868, "ptmsgs_portaladminmsgs"));
      // Fill in the list
      PortalObjectsFactory.GetExpressionEngineInstance().LoadExpressionsLite(ActionTypeEnum.SUBPORTAL);
      XPArrayList xpItemList = PortalObjectsFactory.GetExpressionEngineInstance().GetExpressionList(ActionTypeEnum.SUBPORTAL);
      IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
      Object[] oRow;
      for (int i = 0;i < xpItemList.GetSize();i++)
      {
        int[] arExpression = (int[]) xpItemList.GetElement(i);
        try
        {
          IPTExpressionInfo ptInfo = ptExpressionManager.CachedOpenExpressionInfo(arExpression[0]);
          String strActionValueName = ptExpressionManager.GetActionValueName(ActionTypeEnum.SUBPORTAL,
           arExpression[1]);
          oRow = new Object[6];
          oRow[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = myPTObjectModel.m_nNextIndex;
          myPTObjectModel.m_nNextIndex++;
          oRow[RulesListModel.EXPLIST_OBJECTID] = arExpression[0];
          oRow[RulesListModel.EXPLIST_NAME] = ptInfo.GetName();
          oRow[RulesListModel.EXPLIST_DESCRIPTION] = ptInfo.GetDescription();
          oRow[RulesListModel.EXPLIST_ACTIONNAME] = strActionValueName;
          oRow[RulesListModel.EXPLIST_ACTIONVALUE] = arExpression[1];
          myPTObjectModel.GetItems().AddRow(oRow);
        }
        catch (Exception e)
        {
          log.Error("Could not retrieve expression with ID: " + arExpression[0] + " The following exception occured: " + e);
          }
      }
    }
    private void StartGuestRulesList()
    {
      RulesListModel myPTObjectModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.GUEST_RULES_LIST);
      Object[][] arrExpListColInfo = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX;
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2847,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_WIDTH] = "4%";
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_NAME;
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2848,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_WIDTH] = "67%";
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_ACTIONNAME;
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2887,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_WIDTH] = "20%";
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[2][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = false;
      // ***GroupList*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      myPTObjectModel.InitializeRulesList(m_asOwner.GetString(2886, "ptmsgs_portaladminmsgs"),
       null, "", new int[]{PT_CLASSIDS.PT_EXPRESSION_ID}, arrExpListColInfo,
       GUEST_RULES_LIST_KEY);
      myPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_GROUP);
      myPTObjectModel.DisableAddButton();
      myPTObjectModel.SetIsListReadOnly(true);
      myPTObjectModel.EnablePagination(SubportalRulesManagerAS.GUEST_RULES_LIST);
      myPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(2885, "ptmsgs_portaladminmsgs"),
       "");
    }
    private void StartFolderRulesList()
    {
      RulesListModel myPTObjectModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.FOLDER_RULES_LIST);
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_NAME;
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(3040,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_WIDTH] = "70%";
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = true;
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_ID] = RulesListModel.EXPLIST_ACTIONNAME;
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2849,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_WIDTH] = "30%";
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][RulesListModel.EXPLIST_COLUMN_ENABLESORT] = true;
      // ***GroupList*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      myPTObjectModel.InitializeRulesList(m_asOwner.GetString(3038, "ptmsgs_portaladminmsgs"),
       null, "", new int[]{PT_CLASSIDS.PT_EXPRESSION_ID}, arrExpListColInfo,
       FOLDER_RULES_LIST_KEY);
      myPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_GROUP);
      myPTObjectModel.DisableAddButton();
      myPTObjectModel.SetIsListReadOnly(true);
      myPTObjectModel.EnablePagination(SubportalRulesManagerAS.FOLDER_RULES_LIST);
      myPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(3041, "ptmsgs_portaladminmsgs"),
       "");
    }
    public override void DoTaskOnChangePage(String _sNewSpaceName, String _sNewPageName)
    {
      if (_sNewPageName.Equals(SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME))
      {
        PopulateGuestRulesPage();
      } else
      if (_sNewPageName.Equals(SubportalRulesManagerFolderDP.STR_MVC_CLASS_NAME))
      {
        PopulateFolderRulesPage();
      }
    }
    private void PopulateGuestRulesPage()
    {
      RulesListModel mySubportalRulesListModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.SUBPORTAL_RULES_LIST);
      RulesListModel myGuestRulesListModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.GUEST_RULES_LIST);
      myGuestRulesListModel.GetItems().ClearArray();
      Object[] oRow;
      IPTExpressionInfo ptInfo;
      IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
      IPTGuestLoginManager ptGLManager = (IPTGuestLoginManager) ((IPTSession) m_asOwner.GetUserSession()).GetGuestLogins();
      IPTGrowableSortedArrayWrapperRO rulesList = mySubportalRulesListModel.GetItems();
      for (int i = 0;i < rulesList.GetCount();i++)
      {
        ptInfo = ptExpressionManager.CachedOpenExpressionInfo(XPConvert.ToInteger(mySubportalRulesListModel.GetItems().GetItem(i,
         RulesListModel.EXPLIST_OBJECTID)));
        if (RuleApplyToGuest(ptInfo, ptExpressionManager))
        {
          IPTGuestLogin ptGuestLogin = (IPTGuestLogin) ptGLManager.OpenBySubPortalID(XPConvert.ToInteger(rulesList.GetItem(i,
           RulesListModel.EXPLIST_ACTIONVALUE)), false);
          String strGuestUserName;
          if (null == ptGuestLogin)
          {
            IPTUser ptGuest = (IPTUser) ((IPTSession) m_asOwner.GetUserSession()).GetUsers().Open(PT_INTRINSICS.PT_USER_GUEST,
             false);
            strGuestUserName = ptGuest.GetLocalizedName();
          } else
          {
            strGuestUserName = ptGuestLogin.GetGuestUserName();
          }
          oRow = new Object[6];
          oRow[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = rulesList.GetItem(i,
           SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX);
          oRow[RulesListModel.EXPLIST_OBJECTID] = rulesList.GetItem(i, RulesListModel.EXPLIST_OBJECTID);
          oRow[RulesListModel.EXPLIST_NAME] = rulesList.GetItem(i, RulesListModel.EXPLIST_NAME);
          oRow[RulesListModel.EXPLIST_DESCRIPTION] = rulesList.GetItem(i,
           RulesListModel.EXPLIST_DESCRIPTION);
          oRow[RulesListModel.EXPLIST_ACTIONNAME] = strGuestUserName;
          oRow[RulesListModel.EXPLIST_ACTIONVALUE] = rulesList.GetItem(i,
           RulesListModel.EXPLIST_ACTIONVALUE);
          myGuestRulesListModel.GetItems().AddRow(oRow);
        }
      }
    }
    
    /// <param name="ptInfo"></param>
    /// <param name="ptExpressionManager"></param>
    /// <returns></returns>
    private bool RuleApplyToGuest(IPTExpressionInfo ptInfo, IPTExpressionManager ptExpressionManager)
    {
      if (ptInfo.IsCondition())
      {
        int nCondTypeID = ptInfo.GetConditionTypeID();
        AConditionType objCondType = (AConditionType) ConditionTypeManager.GetInstance().GetHashedConditionTypes().GetElement(nCondTypeID);
        if (objCondType.GetPhaseType() == AConditionType.PHASE_TYPE_GUEST)
        {
          return true;
        } else
        {
          return false;
        }
      } else
      {
        int[] arSubExpressionIDs = ptInfo.QuerySubExpressionIDs();
        for (int i = 0;i < arSubExpressionIDs.Length;i++)
        {
          IPTExpressionInfo ptSubInfo = ptExpressionManager.CachedOpenExpressionInfo(arSubExpressionIDs[i]);
          if (!RuleApplyToGuest(ptSubInfo, ptExpressionManager))
          {
            return false;
          }
        }
        return true;
      }
    }
    private void PopulateFolderRulesPage()
    {
      RulesListModel myFolderRulesListModel = (RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.FOLDER_RULES_LIST);
      myFolderRulesListModel.GetItems().ClearArray();
      IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
      // Query for all the folders that are subportal typed
      IPTQueryResult qrFolders = ptExpressionManager.QuerySubportalTypedFolders();
      Object[] oRow;
      for (int i = 0;i < qrFolders.RowCount();i++)
      {
        int nSubportalID = qrFolders.ItemAsInt(i, PT_PROPIDS.PT_PROPID_FOLDER_FOLDERTYPE);
        String strActionValueName = "";
        try
        {
          strActionValueName = ptExpressionManager.GetActionValueName(ActionTypeEnum.SUBPORTAL,
           nSubportalID);
        }
        catch (Exception e)
        {
          log.Error("Could not retrieve name for Subportal with ID: " + nSubportalID + " The following exception occured: " + e);
          }
        oRow = new Object[6];
        oRow[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = myFolderRulesListModel.m_nNextIndex;
        myFolderRulesListModel.m_nNextIndex++;
        oRow[RulesListModel.EXPLIST_OBJECTID] = qrFolders.ItemAsObject(i,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        oRow[RulesListModel.EXPLIST_NAME] = qrFolders.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
        oRow[RulesListModel.EXPLIST_ACTIONNAME] = strActionValueName;
        oRow[RulesListModel.EXPLIST_ACTIONVALUE] = qrFolders.ItemAsObject(i,
         PT_PROPIDS.PT_PROPID_FOLDER_FOLDERTYPE);
        myFolderRulesListModel.GetItems().AddRow(oRow);
      }
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      base.DoTaskOnComeBackFromSubEditor();
      ((RulesListModel) m_asOwner.GetModel(SubportalRulesManagerAS.SUBPORTAL_RULES_LIST)).DoTaskOnComeBackFromSubEditor();
      if (m_asOwner.GetCurrentPage().GetName().Equals(SubportalRulesManagerFolderDP.STR_MVC_CLASS_NAME))
      {
        PopulateFolderRulesPage();
      }
    }
  }
}