using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager
{
  /// <author>
  /// jennifersu
  /// Credential Vault Manager Utility.  
  /// Allows admins to manage lockboxes.
  /// </author>
  public class CredentialVaultManagerAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager.CredentialVaultManagerAS");
    public const String STR_MVC_CLASS_NAME = "CredentialVaultManager";
    public const String strLockboxList = "LockboxList";
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.credentialvault.CredentialVaultManagerAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CredentialVaultManagerAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      // Credential Vault Manager
      return (GetString(2900, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (CredentialVaultManagerRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckCurrentUserIsAdmin())
      {
        return false;
      }
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = CredentialVaultManagerModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(CredentialVaultManagerModel.STR_MVC_CLASS_NAME);
      RegisterPage(new CredentialVaultManagerMainDP());
      RegisterControl(CredentialVaultManagerRepostControl.STR_MVC_CLASS_NAME,
       myModel);
      SetCurrentPage(CredentialVaultManagerMainDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1351, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CredentialVaultManagerMainDP.STR_MVC_CLASS_NAME);
      RegisterModel(LockboxListModel.STR_MVC_CLASS_NAME, strLockboxList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myLockboxListModel = GetModel(strLockboxList);
      RegisterView(LockboxListView.STR_MVC_CLASS_NAME, strLockboxList, myLockboxListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strLockboxList, myLockboxListModel);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 151;
          int iTipId = 152;
          int iSecondaryTipId = 153;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <summary>
    /// Set the help page for this editor. 
    /// </summary>
    /// <param name="page"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)"></seealso>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (CredentialVaultManagerMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_CredentialVaultManager");
      }
    }
  }
}