using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager
{
  /// <author>jennifersu</author>
  public class CredentialVaultManagerModel : EditorModel,ICredentialVaultManagerModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     "com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager.CredentialVaultManagerModel");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CredentialVaultManager";
    
    /// <summary>
    /// Loads all PTPROFILESECTIONS that belong to PTPROFILEPAGE with ID=1
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      LockboxListModel credentialVaultList = (LockboxListModel) m_asOwner.GetModel(CredentialVaultManagerAS.strLockboxList);
      // Initialize expandable list
      credentialVaultList.InitializeLockboxList(m_asOwner.GetString(2902,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1358, "ptmsgs_portaladminmsgs"),
       PTImageType.ICON_LOCKBOX, m_asOwner.GetString(2903, "ptmsgs_portaladminmsgs"),
       1);
      // Populate list with existing lockboxes
      IPTObjectManager profilePageObjMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProfilePages();
      PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(profilePageObjMgr);
      Object[][] queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
       PT_FILTEROPS.PT_FILTEROP_EQ, PT_INTRINSICS.PT_PROFILE_PAGE_CREDENTIAL_VAULT);
      omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, queryFilter);
      if (omqw.GetCount() > 0)
      {
        IPTProfilePage page = (IPTProfilePage) profilePageObjMgr.Open(PT_INTRINSICS.PT_PROFILE_PAGE_CREDENTIAL_VAULT,
         false);
        Object[] arSections = page.GetChildSections();
        IPTObjectManager profileSectionObjMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();
        Object[][] oRows = new Object[arSections.Length][];
        for (int j2c_index = 0;j2c_index < arSections.Length;j2c_index++)
        {
          oRows[j2c_index] = new Object[LockboxListModel.EXPLIST_COL_MAX];
          }
        for (int indSection = 0;indSection < arSections.Length;indSection++)
        {
          int nSectionID = XPConvert.ToInteger(arSections[indSection]);
          IPTProfileSection profileSection = (IPTProfileSection) profileSectionObjMgr.Open(nSectionID,
           false);
          oRows[indSection][LockboxListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = credentialVaultList.m_nNextIndex;
          credentialVaultList.m_nNextIndex++;
          oRows[indSection][LockboxListModel.EXPLIST_COL_ID] = nSectionID;
          oRows[indSection][LockboxListModel.EXPLIST_COL_NAME] = profileSection.GetName();
          oRows[indSection][LockboxListModel.EXPLIST_COL_DESCRIPTION] = profileSection.GetDescription();
          }
        credentialVaultList.SetDefaultObjects(oRows);
      } else
      {
        log.Error(STR_MVC_CLASS_NAME + "::CheckEditorAccessAndStart Unable to load PTProfilePage for the CredentialVaultManager.");
        String sMessage = "Unable to load PTProfilePage for the CredentialVaultManager";
        String sExceptionMessage = "Unable to load PTProfilePage for the CredentialVaultManager";
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, sMessage, null);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        throw new XPException(sExceptionMessage);
      }
      credentialVaultList.SetEmptyListMessages(m_asOwner.GetString(2904, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(2905, "ptmsgs_portaladminmsgs"));
      credentialVaultList.SetRowIcon(PTImageType.ICON_LOCKBOX);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CredentialVaultManagerModel();
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      LockboxListModel listModel = (LockboxListModel) m_asOwner.GetModel(CredentialVaultManagerAS.strLockboxList);
      listModel.DoTaskOnComeBackFromSubEditor();
      // Store the PTPROFILEPAGE
      PTGrowableSortedArrayWrapper listItems = listModel.GetItems();
      IPTObjectManager profilePageObjMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProfilePages();
      PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(profilePageObjMgr);
      Object[][] queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
       PT_FILTEROPS.PT_FILTEROP_EQ, 1);
      omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, queryFilter);
      if (omqw.GetCount() > 0)
      {
        IPTProfilePage page = (IPTProfilePage) profilePageObjMgr.Open(1, false);
        Object[] arSections = new Object[listItems.GetCount()];
        for (int indRow = 0;indRow < listItems.GetCount();indRow++)
        {
          arSections[indRow] = listItems.GetItem(indRow, LockboxListModel.EXPLIST_COL_ID);
          }
        page.SetChildSections(arSections);
        //save & unlock the PTPROFILEPAGE
        IPTServerContext ptSC = (IPTServerContext) page;
        try
        {
          // JF- Shouldn't lock the Object if this is a new one
          ptSC.LockObject();
          ptSC.Store();
        }
        catch (Exception e)
        {
          log.Error(e, STR_MVC_CLASS_NAME + "::DoTaskOnComeBackFromSubEditor Unable to store the Object.");
          String sMessage = m_asOwner.GetString(158, "ptmsgs_portalinfrastructure");
          // JF- The exception message should not be extracted.
          String sExceptionMessage = "The Portal was unable to store the Object.";
          if (e is PTException)
          {
            PTException ptex = (PTException) e;
            int iCode = ptex.GetErrorCode();
            if ((iCode == PT_RESULTCODES.PT_E_INSUFFICIENTROLEACCESS) || (iCode == PT_RESULTCODES.PT_E_ACCESSDENIED) || (iCode == PT_RESULTCODES.PT_E_CANNOTEDITREADONLY))
            {
              sMessage = m_asOwner.GetString(441, "ptmsgs_portalinfrastructure");
              sExceptionMessage = "The current user does not have sufficient rights to store this Object";
              } else
            if (iCode == PT_RESULTCODES.PT_E_OBJECTLOCKED)
            {
              sMessage = m_asOwner.GetString(442, "ptmsgs_portalinfrastructure");
              sExceptionMessage = "This Object is already locked. It cannot be stored.";
              } else
            if (iCode == PT_RESULTCODES.PT_E_OBJECTNOTLOCKED)
            {
              sMessage = m_asOwner.GetString(443, "ptmsgs_portalinfrastructure");
              sExceptionMessage = "Unable to lock this Object. It cannot be stored.";
              }
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, sMessage, null);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
          }
          throw new XPException(sExceptionMessage, e);
        }
        finally
        {
          ptSC.UnlockObject();
        }
      }
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      LockboxListModel listModel = ((LockboxListModel) m_asOwner.GetModel(CredentialVaultManagerAS.strLockboxList));
      PTObjectManagerQueryWrapper omqw;
      Object[][] queryFilter;
      // Delete any PTPROFILESECTIONS that got deleted
      int[] arDeleteIDs = listModel.m_aRowsToDelete;
      if (arDeleteIDs != null)
      {
        for (int indSection = 0;indSection < arDeleteIDs.Length;indSection++)
        {
          //Deleting a Lockbox object:
          // 1. removes the two associated Property objects from the global maps 
          // 3. and then deletes those properties 
          // 4. before deleting the Profile Section object.
          int nSectionID = arDeleteIDs[indSection];
          IPTObjectManager profileSectionObjMgr = ptSession.GetProfileSections();
          omqw = new PTObjectManagerQueryWrapper(profileSectionObjMgr);
          queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
           PT_FILTEROPS.PT_FILTEROP_EQ, nSectionID);
          omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, queryFilter);
          if (omqw.GetCount() > 0)
          {
            IPTProfileSection section = (IPTProfileSection) profileSectionObjMgr.Open(nSectionID,
             false);
            Object[] arPropIDs = section.GetChildProperties();
            IPTObjectManager propMgr = ptSession.GetProperties();
            for (int indProp = 0;indProp < arPropIDs.Length;indProp++)
            {
              int nPropID = XPConvert.ToInteger(arPropIDs[indProp]);
              propMgr.Delete(nPropID);
            }
            profileSectionObjMgr.Delete(nSectionID);
          }
        }
      }
      // Store the PTPROFILEPAGE
      PTGrowableSortedArrayWrapper listItems = listModel.GetItems();
      IPTObjectManager profilePageObjMgr = ptSession.GetProfilePages();
      omqw = new PTObjectManagerQueryWrapper(profilePageObjMgr);
      queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
       PT_FILTEROPS.PT_FILTEROP_EQ, 1);
      omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, queryFilter);
      if (omqw.GetCount() > 0)
      {
        IPTProfilePage page = (IPTProfilePage) profilePageObjMgr.Open(1, false);
        Object[] arSections = new Object[listItems.GetCount()];
        for (int indRow = 0;indRow < listItems.GetCount();indRow++)
        {
          arSections[indRow] = listItems.GetItem(indRow, LockboxListModel.EXPLIST_COL_ID);
          }
        page.SetChildSections(arSections);
        //save & unlock the PTPROFILEPAGE
        IPTServerContext ptSC = (IPTServerContext) page;
        try
        {
          // JF- Shouldn't lock the Object if this is a new one
          ptSC.LockObject();
          ptSC.Store();
        }
        catch (Exception e)
        {
          log.Error(e, STR_MVC_CLASS_NAME + "::Finish Unable to store the Object.");
          String sMessage = m_asOwner.GetString(158, "ptmsgs_portalinfrastructure");
          // JF- The exception message should not be extracted.
          String sExceptionMessage = "The Portal was unable to store the Object.";
          if (e is PTException)
          {
            PTException ptex = (PTException) e;
            int iCode = ptex.GetErrorCode();
            if ((iCode == PT_RESULTCODES.PT_E_INSUFFICIENTROLEACCESS) || (iCode == PT_RESULTCODES.PT_E_ACCESSDENIED) || (iCode == PT_RESULTCODES.PT_E_CANNOTEDITREADONLY))
            {
              sMessage = m_asOwner.GetString(441, "ptmsgs_portalinfrastructure");
              sExceptionMessage = "The current user does not have sufficient rights to store this Object";
              } else
            if (iCode == PT_RESULTCODES.PT_E_OBJECTLOCKED)
            {
              sMessage = m_asOwner.GetString(442, "ptmsgs_portalinfrastructure");
              sExceptionMessage = "This Object is already locked. It cannot be stored.";
              } else
            if (iCode == PT_RESULTCODES.PT_E_OBJECTNOTLOCKED)
            {
              sMessage = m_asOwner.GetString(443, "ptmsgs_portalinfrastructure");
              sExceptionMessage = "Unable to lock this Object. It cannot be stored.";
              }
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, sMessage, null);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
          }
          throw new XPException(sExceptionMessage, e);
        }
        finally
        {
          ptSC.UnlockObject();
        }
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}