using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.activitysecurity;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.customactivity
{
  /// <author>SudhaS</author>
  /// <author>JosephC</author>
  public class CustomActivityModel : EditorModel,ICustomActivityModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.customactivity.CustomActivityModel");
    
    /// <summary>
    /// DOCUMENT ME!
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CustomActivityModel";
    protected String m_sSetting1;
    protected String m_sSetting2;
    protected String m_strDescription = "";
    protected String m_strName = "";
    protected String m_strURI = "";
    protected String m_strOriginalName = "";
    protected String m_strOriginalURI = "";
    protected bool m_bDelegateRight = true;
    protected Object[] m_oExistingGroups = null;
    protected bool m_bNewActivity = true;
    protected bool m_bValidStore = false;
    protected int m_nActivityID = -1;
    protected int m_nRow = -1;
    private static int INTRINSIC_ACTIVITY_CEILING = 200;
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(MainActivityRightsListModel.ACTIVITY_ID);
      if (data != null)
      {
        String strID = data[0];
        m_nActivityID = XPConvert.ToInteger(strID);
      }
      data = (String[]) _htFormData.GetElement(MainActivityRightsListModel.ACTIVITY_NAME);
      if (data != null)
      {
        m_strName = data[0];
        m_strOriginalName = m_strName;
      }
      data = (String[]) _htFormData.GetElement(MainActivityRightsListModel.ACTIVITY_DESC);
      if (data != null)
      {
        m_strDescription = data[0];
      }
      data = (String[]) _htFormData.GetElement(MainActivityRightsListModel.ACTIVITY_URI);
      if (data != null)
      {
        m_strURI = data[0];
        m_strOriginalURI = m_strURI;
      }
      data = (String[]) _htFormData.GetElement(MainActivityRightsListModel.ACTIVITY_ROW);
      if (data != null)
      {
        String strRow = data[0];
        m_nRow = XPConvert.ToInteger(strRow);
      }
      data = (String[]) _htFormData.GetElement(MainActivityRightsListModel.ACTIVITY_DELEGATE);
      if (data != null)
      {
        String strDelegateRight = data[0];
        m_bDelegateRight = XPConvert.ToBoolean(strDelegateRight);
      }
      StartSelectPTObject();
      if ((EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType()) && (m_nActivityID > PT_SERVERCONSTANTS.PT_MAX_READONLYINTRINSIC_OBJECTID))
      {
        StartMigrationHistory();
      } else
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
      if (m_nActivityID != -1)
      {
        SetExistingGroups();
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CustomActivityModel();
    }
    public override void Finish()
    {
      try
      {
        if ((!m_strName.Equals("")) && (!m_strURI.Equals("")))
        {
          // If the name changed, then we validate the name.
          if (!m_strName.Equals(m_strOriginalName))
          {
            if (!ValidateUniqueName())
            {
              // Return immediately without doing anything if name is not unique.
              return;
            }
          }
          // If the URI changed, then we validate the URI.
          if (!m_strURI.Equals(m_strOriginalURI))
          {
            if (!ValidateUniqueURI())
            {
              // Return immediately without doing anything if URI is not unique.
              return;
            }
          }
          IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
          IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
           false);
          IPTListManager ptListManager = (IPTListManager) ptActivityGroups.GetInterfaces("IPTListManager");
          Object[][] activityProperties = new Object[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_INVALID][];
          for (int j2c_index = 0;j2c_index < PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_INVALID;
          j2c_index++)
          {
            activityProperties[j2c_index] = new Object[3];
          }
          activityProperties[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_PROP_NAME][0] = PT_PROPIDS.PT_PROPID_NAME;
          activityProperties[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_PROP_VALUE][0] = (String) m_strName;
          activityProperties[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_PROP_NAME][1] = PT_PROPIDS.PT_PROPID_DESCRIPTION;
          activityProperties[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_PROP_VALUE][1] = (String) m_strDescription;
          activityProperties[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_PROP_NAME][2] = PT_PROPIDS.PT_PROPID_ACTIVITY_URI;
          activityProperties[PT_EDIT_ACTIVITY_COLUMNS.PT_EDIT_ACTIVITY_PROP_VALUE][2] = (String) m_strURI;
          PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CustomActivityEditorAS.strStorageSelectPTObject)).GetItems();
          if (m_bNewActivity)
          {
            m_nActivityID = ptListManager.AddItem(activityProperties);
            if (aSelectPTObjectValues.GetCount() != 0)
            {
              Object[] groups = new Object[aSelectPTObjectValues.GetCount() - 1];
              int count = 0;
              for (int i = 0;i < aSelectPTObjectValues.GetCount();i++)
              {
                //int nGroupObjID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
                //if (nGroupObjID != PT_INTRINSICS.PT_USERGROUP_SYSADMINS) {
                int nGroupID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i,
                 SelectPTObjectModel.EXPLIST_COL_OBJECTID));
                if (nGroupID != PT_INTRINSICS.PT_USER_SYSADMIN)
                {
                  groups[count] = nGroupID;
                  count++;
                }
              }
              ptActivityGroups.GrantRightToGroups(m_nActivityID, groups);
              }
          } else
          {
            if (aSelectPTObjectValues.GetCount() > m_oExistingGroups.Length)
            {
              Object[] oAddedGroups = GetAddedGroups();
              ptActivityGroups.GrantRightToGroups(m_nActivityID, oAddedGroups);
              } else
            if (m_oExistingGroups.Length > aSelectPTObjectValues.GetCount())
            {
              Object[] oDeletedGroups = GetDeletedGroups();
              ptActivityGroups.RevokeRightFromGroups(m_nActivityID, oDeletedGroups);
              }
            if (m_nActivityID >= INTRINSIC_ACTIVITY_CEILING)
            {
              ptListManager.SetItem(m_nActivityID, activityProperties);
            }
          }
          // Set valid store to true if didn't encounter any errors.
          m_bValidStore = true;
        }
        // Set the migration status to approved if the checkbox was checked
        ((IMigrationHistoryModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).StoreMigrationStatus(PT_CLASSIDS.PT_ACTIVITY_ID,
         m_nActivityID);
      }
      catch (Exception e)
      {
        m_bValidStore = false;
        log.Error(e, "CustomActivityModel Error.");
      }
    }
    //ResetInputs();
    
    /// <summary>
    /// Validates name is unique and raises UI error if not unique.
    /// </summary>
    /// <returns>True if name is unique.</returns>
    public virtual bool ValidateUniqueName()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
       false);
      IPTListManager ptListManager = (IPTListManager) ptActivityGroups.GetInterfaces("IPTListManager");
      Object[][] queryFilter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        queryFilter[j2c_index] = new Object[1];
      }
      queryFilter[0][0] = PT_PROPIDS.PT_PROPID_NAME;
      queryFilter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      queryFilter[2][0] = m_strName;
      IPTQueryResult ptQR = ptListManager.QueryItems(PT_PROPIDS.PT_PROPID_ALL,
       0, -1, queryFilter);
      if (ptQR.RowCount() > 0)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(2631, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2631,
         "ptmsgs_portaladminmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        ((CustomActivityRepostControl) m_asOwner.GetControl(CustomActivityRepostControl.STR_MVC_CLASS_NAME)).SetPageStatus(CustomActivityRepostControl.PAGE_STATUS_INVALID);
        return false;
      }
      return true;
    }
    
    /// <summary>
    /// Validates URI is unique.
    /// </summary>
    /// <returns>True if URI is unique.</returns>
    public virtual bool ValidateUniqueURI()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
       false);
      IPTListManager ptListManager = (IPTListManager) ptActivityGroups.GetInterfaces("IPTListManager");
      Object[][] queryFilter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        queryFilter[j2c_index] = new Object[1];
      }
      queryFilter[0][0] = PT_PROPIDS.PT_PROPID_ACTIVITY_URI;
      queryFilter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      queryFilter[2][0] = m_strURI;
      IPTQueryResult ptQR = ptListManager.QueryItems(PT_PROPIDS.PT_PROPID_ALL,
       0, -1, queryFilter);
      if (ptQR.RowCount() > 0)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(2632, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2632,
         "ptmsgs_portaladminmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        ((CustomActivityRepostControl) m_asOwner.GetControl(CustomActivityRepostControl.STR_MVC_CLASS_NAME)).SetPageStatus(CustomActivityRepostControl.PAGE_STATUS_INVALID);
        return false;
      }
      return true;
    }
    
    /// <returns></returns>
    public virtual String GetActivityDescription()
    {
      return m_strDescription;
    }
    
    /// <returns></returns>
    public virtual int GetActivityID()
    {
      return m_nActivityID;
    }
    
    /// <returns></returns>
    public virtual String GetActivityName()
    {
      return m_strName;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual int GetRow()
    {
      return m_nRow;
    }
    
    /// <returns></returns>
    public virtual String GetActivityURI()
    {
      return m_strURI;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual bool GetValidStore()
    {
      return m_bValidStore;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual bool GetIsNewActivity()
    {
      return m_bNewActivity;
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    public virtual bool GetDelegateRight()
    {
      return m_bDelegateRight;
    }
    public virtual void ResetInputs()
    {
      m_strName = "";
      m_strDescription = "";
      m_strURI = "";
      m_nActivityID = -1;
      m_nRow = -1;
      m_bValidStore = false;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SaveMainPage(XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(GeneralInfoView.HTMLINPUT_CREATE_NAME);
      if (data != null)
      {
        m_strName = data[0];
      }
      data = (String[]) _htFormData.GetElement(GeneralInfoView.HTMLINPUT_CREATE_DESC);
      if (data != null)
      {
        m_strDescription = data[0];
      }
      data = (String[]) _htFormData.GetElement(GeneralInfoView.HTMLINPUT_CREATE_URI);
      if (data != null)
      {
        m_strURI = data[0];
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      //int nPageStatus = super.SavePage(_sPageName, _htFormData);
      //int nPageStatus;
      if (_sPageName.Equals(CustomActivityDP.STR_MVC_CLASS_NAME))
      {
        // ***EXAMPLE*** Server validation - get back the status from SaveMainPage
        SaveMainPage(_htFormData);
      }
      //} else if (_sPageName.equals(DevicesDP.STR_MVC_CLASS_NAME)) {
      //	nPageStatus = SaveDevicesPage(_htFormData);
      if (_sPageName.Equals(MigrationHistoryPluginDP.STR_MVC_CLASS_NAME))
      {
        ((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual void SetExistingGroups()
    {
      PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CustomActivityEditorAS.strStorageSelectPTObject)).GetItems();
      m_oExistingGroups = new Object[aSelectPTObjectValues.GetCount()];
      for (int i = 0;i < aSelectPTObjectValues.GetCount();i++)
      {
        //int nGroupObjID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
        //if (nGroupObjID != PT_INTRINSICS.PT_USERGROUP_SYSADMINS) {
        int nGroupID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i,
         SelectPTObjectModel.EXPLIST_COL_OBJECTID));
        m_oExistingGroups[i] = nGroupID;
      }
      m_bNewActivity = false;
    }
    /*
     public void RemoveAllGroups()
     {
     PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CustomActivityEditorAS.m_strStorageSelectPTObject)).GetItems();
     Object[] groups = new Object[aSelectPTObjectValues.GetCount()];
     for (int i = 0; i < aSelectPTObjectValues.GetCount(); i ++)
     {
     //int nGroupObjID = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
     //if (nGroupObjID != PT_INTRINSICS.PT_USERGROUP_SYSADMINS) {
     Integer nGroupID = (Integer)aSelectPTObjectValues.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
     groups[i] = nGroupID;
     }
     IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
     IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER, false);
     //IPTListManager ptListManager = (IPTListManager) ptActivityGroups.GetInterfaces("IPTListManager");
     ptActivityGroups.RevokeRightFromGroups(m_nActivityID, groups);
     }
     */
     
    
    /// <summary>
    /// Helper method to start the Select PTObject List.
    /// </summary>
    public virtual void StartSelectPTObject()
    {
      SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(CustomActivityEditorAS.strStorageSelectPTObject);
      // ***CHANGE_HERE SELECTPTOBJECT*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _sSectionSubTitle: Sub title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(1463,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1464, "ptmsgs_portaladminmsgs"),
       PTImageType.ICON_GROUP, m_asOwner.GetString(1465, "ptmsgs_portaladminmsgs"),
       new int[]{PT_CLASSIDS.PT_USERGROUP_ID}, 2);
      // ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
      //     Use the method bellow to set the icon to display on each row.
      //     (By default there will be no icon.)
      mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_GROUP);
      mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(1466,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1467, "ptmsgs_portaladminmsgs"));
      mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(2147, "ptmsgs_portaladminmsgs"));
      mySelectPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(2188, "ptmsgs_portaladminmsgs"));
      mySelectPTObjectModel.SetCommunityMode(AObjectTreeModel.NOCOMMUNITIES);
      // JF- The 2 lines below are only needed if you are going to enable the move row actions
      /*
       if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE) {
       oRows = new Object[1][mySelectPTObjectModel.EXPLIST_COL_MAX];
       oRows[0][mySelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer( mySelectPTObjectModel.m_nNextIndex );
       mySelectPTObjectModel.m_nNextIndex ++;
       oRows[0][mySelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_USERGROUP_ID);
       oRows[0][mySelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(PT_INTRINSICS.PT_USERGROUP_EVERYONE);
       oRows[0][mySelectPTObjectModel.EXPLIST_COL_STRING] = new String("Everyone");
       } else if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT) {
       */
       
      Object[][] oRows = null;
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      if (m_nActivityID != -1)
      {
        IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
         false);
        IPTQueryResult ptqrInGroups = ptActivityGroups.QueryAllGroups(m_nActivityID);
        oRows = new Object[ptqrInGroups.RowCount()][];
        for (int j2c_index = 0;j2c_index < ptqrInGroups.RowCount();j2c_index++)
        {
          oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
          }
        for (int i = 0;i < ptqrInGroups.RowCount();i++)
        {
          oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = mySelectPTObjectModel.m_nNextIndex;
          mySelectPTObjectModel.m_nNextIndex++;
          oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
          oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = ptqrInGroups.ItemAsObject(i,
           PT_PROPIDS.PT_PROPID_OBJECTID);
          oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] = ptqrInGroups.ItemAsString(i,
           PT_PROPIDS.PT_PROPID_NAME);
        }
      } else
      {
        IPTObjectManager ptomUserGroup = ptSession.GetUserGroups();
        IPTUserGroup ptUserGroup = (IPTUserGroup) ptomUserGroup.Open(PT_INTRINSICS.PT_USERGROUP_SYSADMINS,
         false);
        //SS - add admin group here
        oRows = new Object[1][];
        for (int j2c_index = 0;j2c_index < 1;j2c_index++)
        {
          oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
          }
        oRows[0][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = mySelectPTObjectModel.m_nNextIndex;
        mySelectPTObjectModel.m_nNextIndex++;
        oRows[0][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
        oRows[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = PT_INTRINSICS.PT_USERGROUP_SYSADMINS;
        oRows[0][SelectPTObjectModel.EXPLIST_COL_STRING] = ptUserGroup.GetLocalizedName();
        }
      mySelectPTObjectModel.SetDefaultObjects(oRows);
      //SS- The Administrator group cannot be removed from the activity right
      int[][] arrReadOnlyObjects = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrReadOnlyObjects[j2c_index] = new int[2];
      }
      arrReadOnlyObjects[0][SelectPTObjectModel.READ_ONLY_ROW_CLASSID] = PT_CLASSIDS.PT_USERGROUP_ID;
      arrReadOnlyObjects[0][SelectPTObjectModel.READ_ONLY_ROW_OBJECTID] = PT_INTRINSICS.PT_USERGROUP_SYSADMINS;
      mySelectPTObjectModel.SetReadOnlyObjects(arrReadOnlyObjects);
    }
    //}
    //}
    
    /// <returns></returns>
    protected virtual Object[] GetAddedGroups()
    {
      XPArrayList aGroups = new XPArrayList();
      PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CustomActivityEditorAS.strStorageSelectPTObject)).GetItems();
      bool bFound = false;
      for (int i = 0;i < aSelectPTObjectValues.GetCount();i++)
      {
        int nCurrAddedValue = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i,
         SelectPTObjectModel.EXPLIST_COL_OBJECTID));
        for (int j = 0;j < m_oExistingGroups.Length;j++)
        {
          int nCurrExistingValue = XPConvert.ToInteger(m_oExistingGroups[j]);
          if (nCurrExistingValue == nCurrAddedValue)
          {
            bFound = true;
          }
        }
        if (!bFound)
        {
          aGroups.Add(nCurrAddedValue);
        }
        bFound = false;
      }
      if (aGroups.IsEmpty())
      {
        return null;
      }
      return aGroups.ToArray();
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <returns>DOCUMENT_ME</returns>
    protected virtual Object[] GetDeletedGroups()
    {
      XPArrayList aGroups = new XPArrayList();
      PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CustomActivityEditorAS.strStorageSelectPTObject)).GetItems();
      bool bFound = false;
      for (int i = 0;i < m_oExistingGroups.Length;i++)
      {
        int nCurrAddedValue = XPConvert.ToInteger(m_oExistingGroups[i]);
        for (int j = 0;j < aSelectPTObjectValues.GetCount();j++)
        {
          int nCurrExistingValue = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(j,
           SelectPTObjectModel.EXPLIST_COL_OBJECTID));
          if (nCurrExistingValue == nCurrAddedValue)
          {
            bFound = true;
          }
        }
        if (!bFound)
        {
          aGroups.Add(nCurrAddedValue);
        }
        bFound = false;
      }
      if (aGroups.IsEmpty())
      {
        return null;
      }
      return aGroups.ToArray();
    }
    protected virtual void StartMigrationHistory()
    {
      ((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).InitializeHistory(PT_CLASSIDS.PT_ACTIVITY_ID,
       m_nActivityID);
    }
  }
}