using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic
{
  /// <summary>
  /// This Editor displays the plug in administration diagnostic pages.
  /// </summary>
  /// <author>DonH</author>
  public class DiagnosticPageEditorAS : PTEditorAS
  {
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.DiagnosticPageEditorAS";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     sClassName);
    public const String STR_MVC_CLASS_NAME = "diagnostic";
    
    /// <summary>
    /// Map of EditorDP names to IDiagnosticPages 
    /// </summary>
    protected XPHashtable m_DiagnosticPages = new XPHashtable();
    
    /// <summary>
    /// Tells whether or not we are switching pages and should reinitialize the page. 
    /// </summary>
    protected bool m_bChangePage = true;
    
    /// <summary>
    /// Registers all the classes of the Activity Space.
    /// </summary>
    public override void Init()
    {
      // Enable partial content display for in place refresh.
      SetIsInPlaceRefreshEnabled(true);
      m_strModelName = DiagnosticPageModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(DiagnosticPageModel.STR_MVC_CLASS_NAME);
      // Register our custom repost control
      RegisterControl(DiagnosticPageRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Sets left nav menu
      // We will add the links to this menu as we iterate over the
      // IDiagnosticPages
      // Sub menu "Diagnostic Page"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(3071, ResourceConstants.PORTALADMINMSGS));
      // Dynamic Discovery of Diagnostic Page Objects
      Object[] oaDiagnosticPages = (Object[]) GetApplication().GetCachingManager().GetEntry("DisplayDiagnosticPages");
      for (int nPage = 0;nPage < oaDiagnosticPages.Length;nPage++)
      {
        IDiagnosticPage oDiagnosticPage = (IDiagnosticPage) oaDiagnosticPages[nPage];
        EditorDP page = oDiagnosticPage.GetDiagnosticPage();
        // Map of display page to diagnostic page object
        // so we can reset tests and change hints/help.
        m_DiagnosticPages.PutElement(page.GetName(), oDiagnosticPage);
        // Register the Display Page
        RegisterPage(page);
        // Add the link for this Display Page to the left nav menu
        m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, page.GetName());
        // This allows each page to register Models, Views, and extra
        // Display pages as necessary.
        oDiagnosticPage.Init(this);
        if (nPage == 0)
        {
          // Set the default page to the first page in the xml file.
          // This needs to happen after we call Init(), because this
          // will call GetPage(), which will cause the tests to be
          // run.
          SetCurrentPage(page.GetName());
        }
      }
    }
    
    /// <summary>
    /// Helper method to return the helper repost control
    /// for this page, if any.
    /// </summary>
    /// <returns>The helper repost control, null if there isn't one.</returns>
    public virtual EditorHelperRepostControl GetPageHelperRepostControl()
    {
      IDiagnosticPage oDiagnosticPage = (IDiagnosticPage) m_DiagnosticPages.GetElement(GetCurrentPage().GetName());
      String strControlName = oDiagnosticPage.GetHelperRepostControlName();
      if (null != strControlName)
      {
        return (EditorHelperRepostControl) GetControl(strControlName);
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#GetPage(String)"></seealso>
    public override IDisplayPage GetPage(String pageName)
    {
      IDisplayPage result = base.GetPage(pageName);
      if (m_bChangePage)
      {
        IDiagnosticPage oDiagnosticPage = (IDiagnosticPage) m_DiagnosticPages.GetElement(pageName);
        // This can be null during initialization
        if (null != oDiagnosticPage)
        {
          m_bChangePage = false;
          ChangePage(oDiagnosticPage);
        }
      }
      return result;
    }
    
    /// <summary>
    /// This helper method handles the actions necessary
    /// when changing pages.  This includes running tests
    /// and setting the help and tips.
    /// </summary>
    /// <param name="_oDiagnosticPage">The new page.</param>
    protected virtual void ChangePage(IDiagnosticPage _oDiagnosticPage)
    {
      // Run the tests for the first page.
      _oDiagnosticPage.RunDiagnosticTest(this);
      // Help Topic
      SetHelpTopic(_oDiagnosticPage.GetHelpTopic());
      // TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          if (_oDiagnosticPage.HasTip())
          {
            tm.SetGeneratingClass(sClassName);
            // Tag Libraries
            tm.SetTipTitle(GetString(_oDiagnosticPage.GetTipTitleID(), ResourceConstants.TIPS));
            // Main tip
            tm.SetTip(new HTMLGenericElement(GetString(_oDiagnosticPage.GetTipID(),
             ResourceConstants.TIPS)));
            // Secondary tip
            tm.SetSecondarTip(new HTMLGenericElement(GetString(_oDiagnosticPage.GetSecondaryTipID(),
             ResourceConstants.TIPS)));
          } else
          {
            // Disable tips for this page.
            tm.DisableTips();
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    
    /// <summary>
    /// This method tells the editor to (re)initialize
    /// the next page, since we are changing pages.
    /// </summary>
    public virtual void SetChangingPage()
    {
      m_bChangePage = true;
    }
    
    /// <summary>
    /// Helper method to rerun the current test.
    /// </summary>
    public virtual void RefreshCurrentTest()
    {
      IDiagnosticPage oDiagnosticPage = (IDiagnosticPage) m_DiagnosticPages.GetElement(GetCurrentPage().GetName());
      oDiagnosticPage.RunDiagnosticTest(this);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()"></seealso>
    public override String GetEditorTitle()
    {
      return GetString(3071, ResourceConstants.PORTALADMINMSGS);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetRepostControlName()"></seealso>
    public override String GetRepostControlName()
    {
      return (DiagnosticPageRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DiagnosticPageEditorAS();
    }
  }
}