using System;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic
{
  /// <summary>
  /// This class handles common repost actions for the diagnostic page editor.
  /// </summary>
  /// <author>DonH</author>
  public class DiagnosticPageRepostControl : EditorRepostControl
  {
    
    /// <summary>
    /// Object Name for AS 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DiagnosticPageRepost";
    
    /// <summary>
    /// Repost Action: Refresh test 
    /// </summary>
    public const int POSTTOSELF_ACTION_REFRESH_TEST = 20;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorRepostControl#PerformReadOnlyAction(int)"></seealso>
    protected override void PerformReadOnlyAction(int _nAction)
    {
      base.PerformReadOnlyAction(_nAction);
      EditorHelperRepostControl pageHelperControl = ((DiagnosticPageEditorAS) m_asOwner).GetPageHelperRepostControl();
      if (null != pageHelperControl)
      {
        pageHelperControl.PerformRepostAction(_nAction, m_htFormData);
      }
      if (_nAction == POSTTOSELF_ACTION_IN_PLACE_REFRESH)
      {
        // set a flag so that display pages will show in place 
        // content instead of normal content on the next pass.
        m_asOwner.SetIsInPlaceRefreshDisplayOn(true);
      }
      if (_nAction == POSTTOSELF_ACTION_REFRESH_TEST)
      {
        // Rerun the current test.
        ((DiagnosticPageEditorAS) m_asOwner).RefreshCurrentTest();
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorRepostControl#PerformAction(int)"></seealso>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      if (m_nAction == POSTTOSELF_ACTION_GOTOPAGE)
      {
        // Tells the model to (re)init the page, since
        // we are changing it.
        ((DiagnosticPageEditorAS) m_asOwner).SetChangingPage();
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DiagnosticPageRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}