using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic
{
  /// <summary>
  /// This interface describes the components
  /// required for a Diagnostic Page in the
  /// Server Diagnostic Editor.
  /// </summary>
  public interface IDiagnosticPage
  {
    
    /// <summary>
    /// Get an instance of the Display Page for
    /// this Diagnostic Page.
    /// This page will be registered automatically.
    /// </summary>
    /// <returns>
    /// EditorDP an instance of the Display
    /// Page for this Diagnostic Page.
    /// </returns>
    EditorDP GetDiagnosticPage();
    
    /// <summary>
    /// Get the name of the EditorHelperRepostControl
    /// to execute when this page is displayed.
    /// This control needs to be registered manually
    /// in the IDiagnosticPage.Init() method.
    /// </summary>
    /// <returns>
    /// String The MVC name for the EditorHelperRepostControl
    /// to call for this page.  May be null.
    /// </returns>
    String GetHelperRepostControlName();
    
    /// <summary>
    /// This method should register any necessary
    /// Models, Views, or extra DisplayPages.
    /// I.E. _asOwner.RegisterView(), etc...
    /// This should not register the main Display Page.
    /// The main Display Page should be returned by
    /// the GetDiagnosticPage() method and will be
    /// registered automatically.
    /// </summary>
    void Init(AActivitySpace _asOwner);
    
    /// <summary>
    /// This method is called every time the user switches
    /// to this particular page.  This method should initialize
    /// or refresh the data on the page.
    /// Initializing the data should not be done in the Model.Init()
    /// method, as this is called when entering the page, and running
    /// all tests at once takes too long.
    /// </summary>
    void RunDiagnosticTest(AActivitySpace _asOwner);
    
    /// <returns>
    /// String The Help Topic for this Diagnostic Page.
    /// Null means to use the generic help page.
    /// </returns>
    String GetHelpTopic();
    
    /// <summary>
    /// This method tells the diagnostic page framework
    /// whether or not to display a tip.
    /// </summary>
    /// <returns>True implies display a tip.</returns>
    bool HasTip();
    
    /// <returns>
    /// int The tip title ID.  -1 means
    /// no tip.
    /// </returns>
    int GetTipTitleID();
    
    /// <returns>
    /// int The tip ID.  -1 means
    /// no tip.
    /// </returns>
    int GetTipID();
    
    /// <returns>
    /// int The secondary tip ID.  -1 means
    /// no tip.
    /// </returns>
    int GetSecondaryTipID();
  }
}