using System;
using com.plumtree.portalpages.common.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads
{
  /// <summary>
  /// This page handles displaying the status of the various
  /// dynamic loads in the portal.
  /// </summary>
  /// <author>DonH</author>
  public class DynamicLoadsDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "CustomObjectsDiagnostic";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()"></seealso>
    public override String GetLeftNavString()
    {
      // "Dynamic Loads"
      return m_asOwner.GetString(3072, ResourceConstants.PORTALADMINMSGS);
      }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      // Summary of the dynamically loaded UI objects currently loaded in the Portal.
      // The Custom Objects section only contains custom objects, not standard objects that come with the Portal.
      // The Dynamic Loads section contains both custom and standard objects.
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(3073, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for this Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(m_asOwner.GetView(DynamicLoadsView.STR_MVC_CLASS_NAME).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // Display JavaScript for the PEIView
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(DynamicLoadsView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}