using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.pei;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags.manager;
using com.plumtree.portaluiinfrastructure.tags.manager.taglibmanager;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads
{
  /// <summary>
  /// This view outputs a list of Dynamically loaded Objects and how many
  /// of them have been loaded in the Portal.
  /// </summary>
  /// <author>DonH</author>
  public class DynamicLoadsView : IView
  {
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.DynamicLoadsView";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     sClassName);
    public const String STR_MVC_CLASS_NAME = "CustomObjectsDiagnostic";
    protected AActivitySpace m_asOwner = null;
    protected static readonly String[] COL_WIDTHS = new String[]{"100%", "20"};
    protected String[] m_strCOL_NAMES_CUSTOM_OBJECTS;
    protected String[] m_strCOL_NAMES_DYNAMIC_LOADS;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(DisplayCustomObjects());
      result.AddInnerHTMLElement(new HTMLBr());
      result.AddInnerHTMLElement(DisplayDynamicLoads());
      return result;
    }
    protected virtual HTMLElement DisplayCustomObjects()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // "Custom Objects"
      result.AddInnerHTMLElement(GetHeaderHTML(m_asOwner.GetString(3074, ResourceConstants.PORTALADMINMSGS)));
      HTMLTable myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.TWO);
      // Column Headers
      myTable.AddInnerHTMLElement(GetHTMLForColumnHeaders(m_strCOL_NAMES_CUSTOM_OBJECTS));
      int nRowIndex = 0;
      // "Navigation Schemes"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3075,
       ResourceConstants.PORTALADMINMSGS), null, NavManager.INSTANCE.GetNumCustomNavTypes()));
      // "Activity Spaces"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3076,
       ResourceConstants.PORTALADMINMSGS), null, ASManager.INSTANCE.GetNumCustomSpaces()));
      // "Models"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3077,
       ResourceConstants.PORTALADMINMSGS), null, ASManager.INSTANCE.GetNumCustomModels()));
      // "Views"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3078,
       ResourceConstants.PORTALADMINMSGS), null, ASManager.INSTANCE.GetNumCustomViews()));
      // "Controls"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3079,
       ResourceConstants.PORTALADMINMSGS), null, ASManager.INSTANCE.GetNumCustomControls()));
      // "Page Controls"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3080,
       ResourceConstants.PORTALADMINMSGS), null, ASManager.INSTANCE.GetNumCustomPageControls()));
      ASURL tagLibURL = new ASURL(m_asOwner);
      tagLibURL.SetLinkGetSpaceIfCached(TagLibManagerAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      tagLibURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      tagLibURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
      tagLibURL.SetSubSpaceKey("taglib");
      String strTagLibURL = tagLibURL.GetURLAsString();
      // "Tag Libraries"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3081,
       ResourceConstants.PORTALADMINMSGS), strTagLibURL, TagLibManager.getInstance().GetNumCustomTagLibraries()));
      // "Tags"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3082,
       ResourceConstants.PORTALADMINMSGS), strTagLibURL, TagLibManager.getInstance().GetNumCustomTags()));
      // Get the number of custom varpacks loaded on the application
      Object oNumVarPacks = m_asOwner.GetApplication().GetCachingManager().GetEntry(AppWarmUp.APP_KEY_NUM_CUSTOM_VARPACKS);
      int nNumVarPacks = 0;
      if (null != oNumVarPacks)
      {
        nNumVarPacks = XPConvert.ToInteger(oNumVarPacks);
      }
      ASURL varPackURL = new ASURL(m_asOwner);
      varPackURL.SetLinkGetSpaceIfCached(VarPackAS.STR_MVC_CLASS_NAME, m_asOwner);
      varPackURL.SetDisplayPage(VarPackPopupDP.STR_MVC_CLASS_NAME);
      varPackURL.SetSubSpaceKey("varpack");
      // "Variable Packages"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3083,
       ResourceConstants.PORTALADMINMSGS), varPackURL.GetURLAsString(), nNumVarPacks));
      return result;
    }
    protected virtual HTMLElement DisplayDynamicLoads()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // "Dynamic Loads"
      result.AddInnerHTMLElement(GetHeaderHTML(m_asOwner.GetString(3072, ResourceConstants.PORTALADMINMSGS)));
      HTMLTable myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.TWO);
      // Column Headers
      myTable.AddInnerHTMLElement(GetHTMLForColumnHeaders(m_strCOL_NAMES_DYNAMIC_LOADS));
      int nRowIndex = 0;
      ASURL peiURL = new ASURL(m_asOwner);
      peiURL.SetLinkGetSpaceIfCached(PEIAS.STR_MVC_CLASS_NAME, m_asOwner);
      peiURL.SetDisplayPage(PEIPopupDP.STR_MVC_CLASS_NAME);
      peiURL.SetSubSpaceKey("pei");
      // "Portal Event Interfaces (PEIs)"
      myTable.AddInnerHTMLElement(GetHTMLForRow(nRowIndex++, m_asOwner.GetString(3084,
       ResourceConstants.PORTALADMINMSGS), peiURL.GetURLAsString(), GetNumLoadedPEIs(m_asOwner.GetApplication())));
      return result;
    }
    
    /// <summary>
    /// Returns the header for the View.
    /// </summary>
    /// <returns>HTMLTable</returns>
    protected virtual HTMLElement GetHeaderHTML(String _strTitle)
    {
      PTConstruct myViewBanner;
      // JF- Get the construct for the View banner
      if (m_asOwner.GetIsAccessStyleStandard())
      {
        myViewBanner = UIConstructFactory.GetConstruct(PTBannerType.OBJECT,
         true, this.m_asOwner);
        myViewBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.TITLE_ELEMENT_NAME,
         _strTitle);
        myViewBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.SUBTITLE_ELEMENT_NAME,
         "");
      } else
      {
        myViewBanner = UIConstructFactory.GetConstruct(PTBannerType.OBJECT_508,
         true, this.m_asOwner);
        myViewBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT_508.TITLE_ELEMENT_NAME,
         "&nbsp;" + _strTitle);
        myViewBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT_508.SUBTITLE_ELEMENT_NAME,
         "");
      }
      return myViewBanner.GetHTMLElement();
    }
    
    /// <summary>
    /// Returns the HTML for the column titles.
    /// </summary>
    /// <returns>HTMLTableRow</returns>
    protected virtual HTMLTableRow GetHTMLForColumnHeaders(String[] _strColNames)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      // JF- We loop through the column array and print out each one
      for (int i = 0;i < COL_WIDTHS.Length;i++)
      {
        // Row 1 - Cell i
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth(COL_WIDTHS[i]);
        myCell.SetColSpan("1");
        myCell.SetHeight("20");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.AddInnerHTMLString(_strColNames[i]);
      }
      return myRow;
    }
    
    /// <param name="_nRowIndex"></param>
    /// <param name="_strName"></param>
    /// <param name="_strURL">can be null</param>
    /// <param name="_nNumItems"></param>
    /// <returns></returns>
    protected virtual HTMLTableRow GetHTMLForRow(int _nRowIndex, String _strName,
     String _strURL, int _nNumItems)
    {
      HTMLTableRow result = new HTMLTableRow();
      SetRowStyle(result, _nRowIndex);
      // Name
      HTMLTableCell myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth(COL_WIDTHS[0]);
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      if (null == _strURL)
      {
        myCell.AddInnerHTMLString(_strName);
      } else
      {
        myCell.AddInnerHTMLElement(BuildAnchor(_strName, _strURL, true));
        }
      // Number
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth(COL_WIDTHS[1]);
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(XPConvert.ToString(_nNumItems));
      return result;
    }
    
    /// <summary>
    /// Helper method to set the style of a row.
    /// </summary>
    /// <param name="_myRow"></param>
    /// <param name="_nRowIndex"></param>
    protected virtual void SetRowStyle(HTMLTableRow _myRow, int _nRowIndex)
    {
      // Set row background
      if (0 == (_nRowIndex % 2))
      {
        _myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
      } else
      {
        _myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
      }
    }
    
    /// <summary>
    /// Helper method that creates an HTML Anchor.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <param name="_strBaseURL">The url for the page.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    public virtual HTMLAnchor BuildAnchor(String _strName, String _strURL,
     bool _bIsPopup)
    {
      HTMLAnchor myAnchor;
      if (_bIsPopup)
      {
        myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        myAnchor.SetOnClick("window.open(\'" + _strURL + "\',\'PopUpEditMode\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
        } else
      {
        myAnchor = new HTMLAnchor(_strURL);
      }
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_strCOL_NAMES_CUSTOM_OBJECTS = new String[]{
      // "Custom Object"
      m_asOwner.GetString(3085, ResourceConstants.PORTALADMINMSGS), 
      // "Number"
      m_asOwner.GetString(3087, ResourceConstants.PORTALADMINMSGS)};
      m_strCOL_NAMES_DYNAMIC_LOADS = new String[]{
      // "Dynamic Load"
      m_asOwner.GetString(3086, ResourceConstants.PORTALADMINMSGS), 
      // "Number"
      m_asOwner.GetString(3087, ResourceConstants.PORTALADMINMSGS)};
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new DynamicLoadsView();
    }
    
    /// <summary>
    /// This helper method calculates how many PEIs are loaded in the Portal.
    /// </summary>
    /// <param name="_application"></param>
    /// <returns>int The number of PEIs currently loaded in the Portal.</returns>
    public static int GetNumLoadedPEIs(IApplication _application)
    {
      CachingManager cache = _application.GetCachingManager();
      IXPEnumerator cKeys = cache.GetKeys();
      int nNumPEIs = 0;
      while (cKeys.MoveNext())
      {
        try
        {
          String sKey = (String) cKeys.GetCurrent();
          // ALL PEIs must end in "Actions"
          if (XPStringUtility.EndsWith(sKey, "Actions"))
          {
            Object[] arrPEIs = (Object[]) cache.GetEntry(sKey);
            nNumPEIs+=arrPEIs.Length;
          }
        }
        catch (Exception e)
        {
          log.Error(e, "Unable to determine the number of loaded PEIs.");
          nNumPEIs = 0;
        }
      }
      return nNumPEIs;
    }
  }
}