using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.pei
{
  /// <summary>
  /// This View displays a list of the currently loaded PEIs.
  /// </summary>
  /// <author>DonH</author>
  public class PEIView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.pei.PEIView");
    public const String STR_MVC_CLASS_NAME = "PEI";
    protected AActivitySpace m_asOwner = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      return GetHTMLForApplicationSection(m_asOwner, true);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <summary>
    /// Helper method to return the HTML for the Application section.
    /// This is also used in the HTTPMemoryDebug page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public static HTMLElement GetHTMLForApplicationSection(AActivitySpace _asOwner,
     bool _bOnlyDisplayPEIs)
    {
      HTMLElement myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLB myBold;
      myTable = new HTMLTable();
      myResult.AddInnerHTMLElement(myTable);
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(_asOwner.GetString(1969, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(_asOwner.GetString(1970, "ptmsgs_portaladminmsgs"));
      myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myBold = new HTMLB();
      myCell.AddInnerHTMLElement(myBold);
      myBold.AddInnerHTMLString(_asOwner.GetString(1971, "ptmsgs_portaladminmsgs"));
      CachingManager cache = _asOwner.GetApplication().GetCachingManager();
      IXPEnumerator cKeys = cache.GetKeys();
      int nIndex = 0;
      int nDisplayIndex = 1;
      String sKey = null;
      Object oVal = null;
      while (cKeys.MoveNext())
      {
        try
        {
          sKey = (String) cKeys.GetCurrent();
          if ((XPStringUtility.EndsWith(sKey, "Actions")) || (!_bOnlyDisplayPEIs))
          {
            oVal = cache.GetEntry(sKey);
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myCell = new HTMLTableCell();
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myRow.AddInnerHTMLElement(myCell);
            myCell.AddInnerHTMLString(XPConvert.ToString(nDisplayIndex));
            myCell = new HTMLTableCell();
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myRow.AddInnerHTMLElement(myCell);
            myCell.AddInnerHTMLEncodedString(sKey);
            myCell = new HTMLTableCell();
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myRow.AddInnerHTMLElement(myCell);
            if (XPStringUtility.EndsWith(sKey, "Actions"))
            {
              Object[] arrPEIs = (Object[]) oVal;
              if (0 != arrPEIs.Length)
              {
                for (int k = 0;k < arrPEIs.Length;k++)
                {
                  myCell.AddInnerHTMLEncodedString(XPConvert.ToString(arrPEIs[k]));
                  myCell.AddInnerHTMLElement(new HTMLBr());
                }
              } else
              {
                myCell.AddInnerHTMLEncodedString(_asOwner.GetString(2677,
                 "ptmsgs_portaladminmsgs"));
              }
              nDisplayIndex++;
            } else
            {
              myCell.AddInnerHTMLEncodedString(XPConvert.ToString(oVal));
              if (!_bOnlyDisplayPEIs)
              {
                nDisplayIndex++;
              }
            }
          }
        }
        catch (Exception e)
        {
          log.Error(e, "Unexpected exception when displaying application item " + sKey);
          }
        nIndex++;
      }
      return myResult;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PEIView();
    }
  }
}