using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.httpmemorydebugging;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks
{
  /// <summary>
  /// This View contains the HTML for the Memory debugging page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class VarPackContentView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.diagnostic.customobjects.varpacks.VarPackContentView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "VarPackContent";
    
    /// <summary>
    /// Associated read-only Model 
    /// </summary>
    private IVarPackModelRO m_model;
    
    /// <summary>
    /// Associated  Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// HTML Object: view button 
    /// </summary>
    public const String HTMLBUTTON_CLOSE = "in_bu_Close";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new VarPackContentView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLB myBold;
      HTMLSpan mySpan;
      try
      {
        VarPackManager vpManager = m_asOwner.GetApplication().GetVarPackManager();
        IVarPack myVarPack = vpManager.GetVariablePackage(m_model.GetCurrentVarPackID());
        // JF- Hidden input for the var pack ID that we are viewing view
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ViewVarPackControl.HTMLHIDDEN_VIEW_VARPACK_ID,
         "");
        myResult.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_model.GetCurrentVarPackID());
        // JF- Create the table for the sub banner (description text)
        myTable = new HTMLTable();
        myResult.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
        // display sub header message
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.DIR_HEADER);
        mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1959,
         "ptmsgs_portaladminmsgs"), m_model.GetCurrentVarPackID()));
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        if (m_model.GetAllowVarPackReload())
        {
          if (myVarPack.CanReloadVarPackFromUI())
          {
            // JF- Reload button
            myInput = new HTMLInput(HTMLInputTypes.BUTTON, VarPackView.HTMLBUTTON_RELOAD,
             "");
            myCell.AddInnerHTMLElement(myInput);
            myInput.SetValue(m_asOwner.GetString(1957, "ptmsgs_portaladminmsgs"));
            myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
            myInput.SetOnClick("postToSelf(" + HTTPMemoryDebugRepostControl.POSTTOSELF_ACTION_RELOAD_CURRENT_VIEWED_VARPACK + "); return false;");
            myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
          }
        }
        // JF- Close button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1958, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        myInput.SetOnClick("window.close(); return false;");
        // JF- Var Pack content
        myTable = new HTMLTable();
        myResult.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        if ((null != myVarPack) && (null != myVarPack.GetVarPackKeys()))
        {
          IXPEnumerator vpKeys = myVarPack.GetVarPackKeys();
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myBold = new HTMLB();
          myCell.AddInnerHTMLElement(myBold);
          myBold.AddInnerHTMLString(m_asOwner.GetString(1955, "ptmsgs_portaladminmsgs"));
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myBold = new HTMLB();
          myCell.AddInnerHTMLElement(myBold);
          myBold.AddInnerHTMLString(m_asOwner.GetString(1956, "ptmsgs_portaladminmsgs"));
          while (vpKeys.MoveNext())
          {
            Object oValue = myVarPack.GetVarPackValue((String) vpKeys.GetCurrent());
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myCell = new HTMLTableCell();
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myRow.AddInnerHTMLElement(myCell);
            myCell.AddInnerHTMLEncodedString((String) vpKeys.GetCurrent());
            myCell = new HTMLTableCell();
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myRow.AddInnerHTMLElement(myCell);
            if (null != oValue)
            {
              myCell.AddInnerHTMLEncodedString(XPConvert.ToString(oValue));
              } else
            {
              myCell.AddInnerHTMLEncodedString("null");
            }
          }
        } else
        {
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asOwner.GetString(1960, "ptmsgs_portaladminmsgs"));
          }
      }
      catch (HTMLException he)
      {
        log.Error(he, "Unexpected error when trying to display HTTPMemoryDebugVarPackContentView.");
        throw new XPException("Unexpected error when trying to display HTTPMemoryDebugVarPackContentView.",
         he);
      }
      return myResult;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return new HTMLScript("text/javaScript");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IVarPackModelRO) model;
      m_asOwner = (AActivitySpace) parent;
    }
  }
}