using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks
{
  /// <summary>
  /// This view displays the currently loaded varpacks
  /// (without a reload button).
  /// </summary>
  /// <author>DonH</author>
  public class VarPackView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.diagnostic.customobjects.varpacks.VarPackView");
    public const String STR_MVC_CLASS_NAME = "VarPackDiagnostic";
    
    /// <summary>
    /// HTML Object: view button 
    /// </summary>
    public const String HTMLBUTTON_VIEW = "in_bu_View";
    
    /// <summary>
    /// HTML Object: reload button 
    /// </summary>
    public const String HTMLBUTTON_RELOAD = "in_bu_Reload";
    protected AActivitySpace m_asOwner = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      // Do not allow reload from this page, only from
      // HTTPMemoryDebugPage.
      return GetHTMLForVarPackSection(m_asOwner, false);
    }
    
    /// <summary>
    /// Helper method to return the HTML for the Var Pack section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public static HTMLElement GetHTMLForVarPackSection(AActivitySpace _asOwner,
     bool _bAllowReload)
    {
      HTMLElement myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      myTable = new HTMLTable();
      myResult.AddInnerHTMLElement(myTable);
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      VarPackManager vpManager = _asOwner.GetApplication().GetVarPackManager();
      IXPEnumerator vpManagerKeys = vpManager.GetKeys();
      IVarPack myVarPack;
      while (vpManagerKeys.MoveNext())
      {
        try
        {
          myVarPack = vpManager.GetVariablePackage((String) vpManagerKeys.GetCurrent());
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLEncodedString(myVarPack.GetVarPackID());
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          // JF- View button
          myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_VIEW,
           "");
          myCell.AddInnerHTMLElement(myInput);
          myInput.SetValue(_asOwner.GetString(1975, "ptmsgs_portaladminmsgs"));
          myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
          myInput.SetOnClick("ViewVarPack(\'" + myVarPack.GetVarPackID() + "\'); return false;");
          if (myVarPack.CanReloadVarPackFromUI() && _bAllowReload)
          {
            myCell = new HTMLTableCell();
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myRow.AddInnerHTMLElement(myCell);
            // JF- Reload button
            myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_RELOAD,
             "");
            myCell.AddInnerHTMLElement(myInput);
            myInput.SetValue(_asOwner.GetString(1974, "ptmsgs_portaladminmsgs"));
            myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
            myInput.SetOnClick("ReloadVarPack(\'" + myVarPack.GetVarPackID() + "\'); return false;");
            }
        }
        catch (Exception e)
        {
          log.Error(e, "Unable to retrieve VarPack key.");
        }
      }
      return myResult;
    }
    
    /// <summary>
    /// This method creates the Javascript to view a VarPack.
    /// </summary>
    /// <param name="__strBaseControlURL">
    /// The URL to access the View Var Pack
    /// Control, without the var pack ID query string argument.
    /// </param>
    /// <returns>String The JavaScript to view a varpack.</returns>
    public static String GetJSForVarPackSection(String _strBaseControlURL)
    {
      XPStringBuilder sb = new XPStringBuilder(300);
      sb.Append("function ViewVarPack(varPackID)\n");
      sb.Append("{\n");
      sb.Append("    window.open(\'").Append(_strBaseControlURL).Append("&" + ViewVarPackControl.HTMLHIDDEN_VIEW_VARPACK_ID + "=\' + varPackID,").Append("\'_memorydebug\', \'location=no,menubar=no,scrollbars,resizable=yes,height=400,width=400\');\n");
      sb.Append("    \n");
      sb.Append("}\n");
      return sb.ToString();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript;
      // The URL to open the pop-up
      ASURL myPopUp = new ASURL(m_asOwner);
      myPopUp.SetLinkGetCachedSpace(m_asOwner);
      myPopUp.SetDisplayPage(VarPackContentDP.STR_MVC_CLASS_NAME);
      myPopUp.SetControl(ViewVarPackControl.STR_MVC_CLASS_NAME);
      try
      {
        myScript = new HTMLScript("text/javaScript");
        myScript.AddInnerHTMLString(GetJSForVarPackSection(myPopUp.GetURLAsString()));
        }
      catch (Exception e)
      {
        throw XPException.GetInstance(e);
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new VarPackView();
    }
  }
}