using System;
using com.plumtree.portalpages.admin.ptutilities.diagnostic;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.adaptivelayouts;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.pages
{
  /// <summary>
  /// This page displays the status of remote hosts
  /// that supply the portal with content
  /// (i.e. Portlet WebServices).
  /// </summary>
  /// <author>DustinA</author>
  public class AdaptiveLayoutsPage : IDiagnosticPage
  {
    public const String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "AdaptiveLayoutsList";
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetDiagnosticPage()"></seealso>
    public virtual EditorDP GetDiagnosticPage()
    {
      return new AdaptiveLayoutsListDP();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelperRepostControlName()"></seealso>
    public virtual String GetHelperRepostControlName()
    {
      return STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace _asOwner)
    {
      // The base model for the Diagnostic Page
      _asOwner.RegisterModel(AdaptiveLayoutsModel.STR_MVC_CLASS_NAME);
      // Register the View, Control, and the Model used by the multi column array.		
      _asOwner.RegisterModel(SortedMetaDataListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myListModel = _asOwner.GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      _asOwner.RegisterView(RefreshServerStatusListView.STR_MVC_CLASS_NAME,
       STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
      _asOwner.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST,
       myListModel);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#RunDiagnosticTest(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void RunDiagnosticTest(AActivitySpace _asOwner)
    {
      AdaptiveLayoutsModel model = (AdaptiveLayoutsModel) _asOwner.GetModel(AdaptiveLayoutsModel.STR_MVC_CLASS_NAME);
      // Reset to good state
      model.ResetModel();
      model.StartServerList();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelpTopic()"></seealso>
    public virtual String GetHelpTopic()
    {
      return "PT_Diagnostic_AdaptiveLayouts";
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#HasTip()"></seealso>
    public virtual bool HasTip()
    {
      // This diagnostic page does not have a tip.
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipTitleID()"></seealso>
    public virtual int GetTipTitleID()
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipID()"></seealso>
    public virtual int GetTipID()
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetSecondaryTipID()"></seealso>
    public virtual int GetSecondaryTipID()
    {
      return 0;
    }
  }
}