using System;
using com.plumtree.portalpages.admin.ptutilities.diagnostic;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist;
using com.plumtree.portalpages.admin.serversettings.search;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.pages
{
  /// <summary>
  /// This page displays the status of related servers,
  /// such as the Search, Automation, and Collabortion
  /// Servers.
  /// </summary>
  /// <author>DonH</author>
  public class RelatedServersPage : IDiagnosticPage
  {
    public const String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "RelatedServerList";
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetDiagnosticPage()"></seealso>
    public virtual EditorDP GetDiagnosticPage()
    {
      return new RelatedServersListDP();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelperRepostControlName()"></seealso>
    public virtual String GetHelperRepostControlName()
    {
      return STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace _asOwner)
    {
      // The base model for the Diagnostic Page
      _asOwner.RegisterModel(RelatedServersModel.STR_MVC_CLASS_NAME);
      // In case this model is used by another diagnostic page
      if (!_asOwner.GetModelExists(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME))
      {
        // Register the model used to access the search servers
        _asOwner.RegisterModel(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME);
        }
      SearchServerSettingsEditorModel searchModel = (SearchServerSettingsEditorModel) _asOwner.GetModel(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME);
      // This normally gets called by the editor framework in
      // CheckEditorAccessAndStart(), but since we are using this
      // model outside of the editor framework, we need to call
      // this manually.
      searchModel.InitializePropertyValues();
      // Register the View, Control, and the Model used by the multi column array.		
      _asOwner.RegisterModel(SortedMetaDataListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myListModel = _asOwner.GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      _asOwner.RegisterView(RefreshServerStatusListView.STR_MVC_CLASS_NAME,
       STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
      _asOwner.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST,
       myListModel);
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#RunDiagnosticTest(AActivitySpace)"></seealso>
    public virtual void RunDiagnosticTest(AActivitySpace _asOwner)
    {
      RelatedServersModel model = (RelatedServersModel) _asOwner.GetModel(RelatedServersModel.STR_MVC_CLASS_NAME);
      model.StartServerList();
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelpTopic()"></seealso>
    public virtual String GetHelpTopic()
    {
      return "PT_Diagnostic_RelatedServers";
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#HasTip()"></seealso>
    public virtual bool HasTip()
    {
      // This diagnostic page does not have a tip.
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipTitleID()"></seealso>
    public virtual int GetTipTitleID()
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipID()"></seealso>
    public virtual int GetTipID()
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetSecondaryTipID()"></seealso>
    public virtual int GetSecondaryTipID()
    {
      return 0;
    }
  }
}