using System;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.pages;
using com.plumtree.portalpages.common.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers
{
  /// <summary>
  /// This page displays the status of related servers,
  /// such as the Search, Automation, and Collabortion
  /// Servers.
  /// </summary>
  /// <author>DonH</author>
  public class RelatedServersListDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "RelatedServerDiagnostic";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()"></seealso>
    public override String GetLeftNavString()
    {
      // "Related Servers"
      return m_asOwner.GetString(3088, ResourceConstants.PORTALADMINMSGS);
      }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      // This page allows you to view and reload the tag libraries for this portal machine.
      // "The current status of Related Servers.  " +
      // "Server status is not updated when sorting.  " +
      // "To update server status, click the Refresh button."
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(3089, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for this Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(m_asOwner.GetView(RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // Display JavaScript for the search & auto servers list
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).DisplayJavascript());
      return myScripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PartialContentDisplay()"></seealso>
    public override HTMLElement PartialContentDisplay()
    {
      return m_asOwner.GetView(RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display();
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}