using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.automationserver;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.pages;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers.search;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist;
using com.plumtree.portalpages.admin.ptutilities.jobfolders;
using com.plumtree.portalpages.admin.serversettings.search;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
using GeneralHelpers=com.plumtree.uiinfrastructure.statichelpers.GeneralHelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers
{
  /// <summary>
  /// This model initializes the Server List with
  /// related servers, such as the Search,
  /// Automation, and Collaboration Servers.
  /// </summary>
  /// <author>DonH</author>
  public class RelatedServersModel : IModel,IModelRO
  {
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers.RelatedServersModel";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     sClassName);
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RelatedServers";
    protected AActivitySpace m_asOwner;
    // Server types - for SERVER_TYPE column
    public const int SERVER_TYPE_SEARCH = 0;
    public const int SERVER_TYPE_AUTOMATION = 1;
    public const int SERVER_TYPE_COLLAB = 2;
    public const int SERVER_TYPE_CONTENT = 3;
    protected XPHashtable m_htInitialPortletStatus = new XPHashtable();
    public const int PORTLET_TIMEOUT = 15000;
    
    /// <summary>
    /// Helper method to start the Server List.
    /// </summary>
    public virtual void StartServerList()
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_asOwner.GetModel(RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      model.InitializeMetaDataList(
      // List Title -- "Related Servers"
      m_asOwner.GetString(3088, ResourceConstants.PORTALADMINMSGS), new String[]{
      // Server Icon -- "Type"
      m_asOwner.GetString(3090, ResourceConstants.PORTALADMINMSGS), 
      // Server Name
      m_asOwner.GetString(3091, ResourceConstants.PORTALADMINMSGS), 
      // Status
      m_asOwner.GetString(3092, ResourceConstants.PORTALADMINMSGS)}, 
      // Width -- we use percents for the small columns because otherwise
      // the column header breaks to a new line when the sort icon is added.
      new String[]{"10%", null, "10%"}, 
      // Server Type
      // Server Name
      // Status
      // Sortable
      new bool[]{true, true, true}, 
      // Server Type
      // Server Name
      // Status
      // default sort column -- sort by type
      1, 
      // Number of total columns (Visible + Data)
      ServerStatusListView.NUM_COLS, 
      // list key
      1);
      PopulateServerList();
    }
    
    /// <summary>
    /// Helper method to populate the Server List.
    /// </summary>
    public virtual void PopulateServerList()
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_asOwner.GetModel(RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Pre populate the list (By default the list will be empty.).
      model.AddRowsToList(GetSearchServerData());
      model.AddRowsToList(GetAutomationServerData());
      Object[][] collabData = GetInstalledServerData(SERVER_TYPE_COLLAB);
      if (null != collabData)
      {
        model.AddRowsToList(collabData);
      }
      Object[][] contentData = GetInstalledServerData(SERVER_TYPE_CONTENT);
      if (null != contentData)
      {
        model.AddRowsToList(contentData);
      }
      if (RemoteHostsModel.AreAllServersOkay(model))
      {
      }
      // TODO: Resort by status with red at top
      // Set the message and instructions to display when the list is empty.
      // message: There are no Related Servers configured for this portal server.
      // instructions: Configure the Search Server or add Automation or
      // Collaboration Servers to this portal server.
      model.SetEmptyListMessages(m_asOwner.GetString(3093, ResourceConstants.PORTALADMINMSGS),
       m_asOwner.GetString(3094, ResourceConstants.PORTALADMINMSGS));
    }
    
    /// <summary>
    /// Helper method to generate the data for the Search Servers.
    /// </summary>
    /// <returns>Object[][] The Search Server data.</returns>
    protected virtual Object[][] GetSearchServerData()
    {
      // TODO: Investigate pulling this code out or Model and just using it here,
      // or refactoring it so it can be used in both places.
      SearchServerSettingsEditorModel searchModel = (SearchServerSettingsEditorModel) m_asOwner.GetModel(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME);
      // The status property bag contains information about the
      // query server, index server (if different from query
      // server) and the failover server (if defined). Depending
      // on the configuration, this page will show 1 to 3 blocks
      // of status info:
      // 1. If index server and queryserver are the same,
      //    show status for the single server.
      // 2. If they are different show status for each server
      //    separately.
      // 3. If defined, show status for the failover server.
      IXPPropertyBag statusBag = searchModel.GetStatusPropertyBag();
      // There must be at least one search server
      int nNumServers = 1;
      Object[][] strData = new Object[ServerStatusListView.NUM_COLS][];
      for (int j2c_index = 0;j2c_index < ServerStatusListView.NUM_COLS;j2c_index++)
      {
        strData[j2c_index] = new Object[nNumServers];
      }
      SearchServerStatusInfo statusInfo = new SearchServerStatusInfo(statusBag,
       "INDEXSTATUS");
      AddSearchServerToData(searchModel.GetIndexingHost(), 
      // Index Server
      m_asOwner.GetString(177, "ptmsgs_portalcommonmsgs"), 
      // 0 means first entry in index
      statusInfo, strData, 0);
      return strData;
    }
    
    /// <summary>
    /// Helper method to add the search server data to the array.
    /// </summary>
    /// <param name="_strHostName"></param>
    /// <param name="_strServerDescription"></param>
    /// <param name="_oStatus"></param>
    /// <param name="_strData"></param>
    /// <param name="nIndex"></param>
    protected virtual void AddSearchServerToData(String _strHostName, String _strServerDescription,
     SearchServerStatusInfo _oStatus, Object[][] _oData, int nIndex)
    {
      // Visible columns
      _oData[ServerStatusListView.SERVER_TYPE][nIndex] = XPConvert.ToString(SERVER_TYPE_SEARCH);
      // TODO: make the name a link to open the full search server status page
      _oData[ServerStatusListView.SERVER_NAME][nIndex] = _strHostName;
      int nStatusCode = ServerStatusListView.STATUS_RED;
      String strStatusMsg = null;
      if (_oStatus.connectStatus.Equals("OK"))
      {
        nStatusCode = ServerStatusListView.STATUS_GREEN;
        strStatusMsg = m_asOwner.GetString(1442, ResourceConstants.PORTALADMINMSGS);
        } else
      {
        strStatusMsg = m_asOwner.GetString(1443, ResourceConstants.PORTALADMINMSGS);
        }
      _oData[ServerStatusListView.SERVER_STATUS][nIndex] = XPConvert.ToString(nStatusCode);
      // Data only columns
      _oData[ServerStatusListView.SERVER_ICON][nIndex] = PTImageType.ACTION_SEARCH_BUTTON_ADVANCED;
      _oData[ServerStatusListView.SERVER_ANCHOR][nIndex] = GetSearchServerAnchor(_strHostName);
      _oData[ServerStatusListView.SERVER_DESCRIPTION][nIndex] = _strServerDescription;
      _oData[ServerStatusListView.SERVER_STATUS_MSG][nIndex] = strStatusMsg;
      _oData[ServerStatusListView.SERVER_STATUS_ERROR][nIndex] = null;
    }
    
    /// <summary>
    /// Helper method that creates an HTML Anchor to a pop-up
    /// page viewing automation server details.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    protected virtual HTMLAnchor GetSearchServerAnchor(String _strName)
    {
      ASURL searchStatusURL = new ASURL(m_asOwner);
      searchStatusURL.SetLinkGetSpaceIfCached(SearchServerStatusAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      searchStatusURL.SetDisplayPage(SearchServerStatusPopupDP.STR_MVC_CLASS_NAME);
      searchStatusURL.SetSubSpaceKey("search");
      HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("window.open(\'" + searchStatusURL.GetURLAsString() + "\',\'PopUpSearchStatus\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <summary>
    /// Helper method to generate the data for the Automation Servers.
    /// </summary>
    /// <returns>Object[][] The Automation Server data.</returns>
    protected virtual Object[][] GetAutomationServerData()
    {
      IPTScheduler ptScheduler = ((IPTSession) m_asOwner.GetUserSession()).GetScheduler();
      IPTQueryResult ptqrAutomationServer = ptScheduler.QueryJobServerStatus("*");
      Object[][] oData = new Object[ServerStatusListView.NUM_COLS][];
      for (int j2c_index = 0;j2c_index < ServerStatusListView.NUM_COLS;j2c_index++)
      {
        oData[j2c_index] = new Object[ptqrAutomationServer.RowCount()];
      }
      for (int i = 0;i < ptqrAutomationServer.RowCount();i++)
      {
        // Visible columns
        oData[ServerStatusListView.SERVER_TYPE][i] = XPConvert.ToString(SERVER_TYPE_AUTOMATION);
        String strName = ptqrAutomationServer.ItemAsString(i, PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
        oData[ServerStatusListView.SERVER_NAME][i] = strName;
        int nServerStatus = ptqrAutomationServer.ItemAsInt(i, PT_PROPIDS.PT_PROPID_JOBSERVER_STATUS);
        // Check if this server has any job folders assigned to it
        IPTQueryResult ptqrJobFolders = ptScheduler.QueryJobAssignmentsByServer(strName);
        bool bHasJobFolder = (ptqrJobFolders.RowCount() > 0);
        oData[ServerStatusListView.SERVER_STATUS][i] = ConvertServerStatus(nServerStatus,
         bHasJobFolder);
        // Data only columns
        oData[ServerStatusListView.SERVER_ICON][i] = PTImageType.ICON_AUTOMATION_SERVER;
        oData[ServerStatusListView.SERVER_ANCHOR][i] = GetAutomationServerAnchor(strName);
        // "Automation Server"
        oData[ServerStatusListView.SERVER_DESCRIPTION][i] = m_asOwner.GetString(3095,
         ResourceConstants.PORTALADMINMSGS);
        String strStatusMsg = null;
        if (nServerStatus == PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_ONLINE)
        {
          strStatusMsg = m_asOwner.GetString(1442, ResourceConstants.PORTALADMINMSGS);
          } else
        if (nServerStatus == PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_OFFLINE)
        {
          strStatusMsg = m_asOwner.GetString(1443, ResourceConstants.PORTALADMINMSGS);
          } else
        {
          strStatusMsg = m_asOwner.GetString(3198, ResourceConstants.PORTALADMINMSGS);
          }
        oData[ServerStatusListView.SERVER_STATUS_MSG][i] = strStatusMsg;
        oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = null;
        if (!bHasJobFolder)
        {
          // "Automation Server has no Job Folders assigned to it."
          oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = m_asOwner.GetString(3096,
           ResourceConstants.PORTALADMINMSGS);
        }
      }
      return oData;
    }
    
    /// <summary>
    /// Helper method that creates an HTML Anchor to a pop-up
    /// page viewing automation server details.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    protected virtual HTMLAnchor GetAutomationServerAnchor(String _strName)
    {
      ASURL myURL = new ASURL(m_asOwner);
      myURL.SetLinkCreateNewSpace(JobFoldersEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
      myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
      myURL.SetSubSpaceKey(XPHttpUtility.HtmlEncode(STR_MVC_CLASS_NAME));
      myURL.AddControlArgument(AutomationServerListModel.SERVER_NAME, _strName);
      String strURL = myURL.GetURLAsString();
      HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("window.open(\'" + strURL + "\',\'PopUpAutoServer\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <summary>
    /// This helper method converts from an Automation
    /// Server status code to a ServerList status light code.
    /// </summary>
    /// <param name="_nAutomationServerStatus">The Automation Server status code.</param>
    /// <returns>String The corresponding ServerList status light code.</returns>
    protected virtual String ConvertServerStatus(int _nAutomationServerStatus,
     bool _bHasJobFolder)
    {
      int nServerStatusLight;
      switch (_nAutomationServerStatus){
      case PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_OFFLINE:
      nServerStatusLight = ServerStatusListView.STATUS_RED;
      break;
      case PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_ONLINE:
      nServerStatusLight = ServerStatusListView.STATUS_GREEN;
      break;
      default:
      //MES- NOTE: We're showing "RED" for "unknown" status.
      //  Maybe we should choose another color for that case?
      // TODO: error?
      nServerStatusLight = ServerStatusListView.STATUS_RED;
      break;
      }
      if (!_bHasJobFolder && (nServerStatusLight == ServerStatusListView.STATUS_GREEN))
      {
        // If the server is online, but has no job folders assigned
        // to it, mark it as yellow.
        nServerStatusLight = ServerStatusListView.STATUS_YELLOW;
      }
      return XPConvert.ToString(nServerStatusLight);
    }
    
    /// <summary>
    /// Helper method to generate the data for the Collab and Content Servers.
    /// </summary>
    /// <returns>Object[][] The Collab or Content Server data.</returns>
    protected virtual Object[][] GetInstalledServerData(int _nServerType)
    {
      if ((_nServerType != SERVER_TYPE_COLLAB) && (_nServerType != SERVER_TYPE_CONTENT))
      {
        log.Warn("Ignoring illegal attempt to get installed server data for non collab/content server of server type " + _nServerType);
        return null;
      }
      Object[][] filter = null;
      int webServiceID = -1;
      if (_nServerType == SERVER_TYPE_COLLAB)
      {
        // look for collab remoteserver
        filter = GetCollabServerUUIDFilter();
        webServiceID = CollaborationHelperService.getInstance().GetWebServiceID((IPTSession) m_asOwner.GetUserSession());
        } else
      if (_nServerType == SERVER_TYPE_CONTENT)
      {
        // look for content remoteserver
        filter = GetContentServerUUIDFilter();
        webServiceID = PublisherHelperService.getInstance().GetWebServiceID((IPTSession) m_asOwner.GetUserSession());
        }
      IPTObjectManager serverObjMgr = ((IPTSession) m_asOwner.GetUserSession()).GetGadgetContentServers();
      IPTQueryResult ptqrServer = (IPTQueryResult) serverObjMgr.Query(PT_PROPIDS.PT_PROPID_NAME,
       -1, PT_PROPIDS.PT_PROPID_NAME, 0, -1, filter);
      if (ptqrServer.RowCount() < 1)
      {
        // The requested server is not installed on this machine.
        return null;
      }
      if (ptqrServer.RowCount() > 1)
      {
        // this should never happen.
        log.Warn("More than one collab or content server returned by query.  Ignoring.");
        }
      IPTGadgetContentServer server;
      try
      {
        server = (IPTGadgetContentServer) serverObjMgr.Open(ptqrServer.ItemAsInt(0,
         PT_PROPIDS.PT_PROPID_OBJECTID), false);
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to open collab/content server object.");
        return null;
      }
      /*BUG #7817807 - THE SYSTEM HEALTH MONITOR DOES NOT GATEWAY THE LINKS TO COLLABORATION OR PUBLISHER
       * fix.  Adding gateway argument to the links.
       * PublisherHelperService.java and IPublisherHelper.java were also added to fix this bug for Publisher.
       */
       
      int gatewayClassId = PT_CLASSIDS.PT_WEBSERVICE_ID;
      String gatewayedServerBaseURL = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
       /* objectID= */
      webServiceID, /* communityID= */
      0, /* pageID= */
      0, /* prefType= */
      0, /* classID= */
      gatewayClassId);
      String strServerBaseURL = server.GetURL();
      String strServerHost = RemoteHostsModel.GetHostName(strServerBaseURL);
      //creating this new string as I wanted to keep strServerHost to point to the collab and publisher links
      String gatewayedURL = "";
      /*There was a change in ASP.NET 2.0. This change causes ASP.NET 2.0 to explicitly check any symbols in the virtual
       * path in the URL when ASP.NET 2.0 validates the URL.
       * http://localhost/portal/server.pt/gateway/PTARGS_0_0_317_0_0_47/http://lmah-collab45.devnet.plumtree.com:11930/collab//do/admin/diagnostic
       * use to work in .net 1.1, but will now cause a virtual path error.
       * Here's a kb article on this issue:  http://support.microsoft.com/kb/932552
       *
       * We will manually encode the ":" in the collab and content URL so that it works for .net (java already worked)
       * */
       
      if (XPSystem.IsRunningInDotNet())
      {
        //got to find the colon string as well
        String colon = ":";
        //this encoding is of ISO-8859-1, doing string manipulation as I only want to change the colons and not the
        //entire url
        String encodedColon = "%3B";
        String encodedServerBaseURL = strServerBaseURL;
        encodedServerBaseURL = GeneralHelpers.Replace(encodedServerBaseURL,
         colon, encodedColon);
        //creating this new string as I wanted to keep strServerHost to point to the collab and publisher links
        gatewayedURL = gatewayedServerBaseURL + encodedServerBaseURL;
      } else
      {
        //This is a java portal and we don't need to encode the colon for it to gateway the server urls correctly.
        gatewayedURL = gatewayedServerBaseURL + strServerBaseURL;
      }
      Object[][] oData = new Object[ServerStatusListView.NUM_COLS][];
      for (int j2c_index = 0;j2c_index < ServerStatusListView.NUM_COLS;j2c_index++)
      {
        oData[j2c_index] = new Object[1];
      }
      // Visible columns
      oData[ServerStatusListView.SERVER_TYPE][0] = XPConvert.ToString(_nServerType);
      oData[ServerStatusListView.SERVER_NAME][0] = ptqrServer.ItemAsString(0,
       PT_PROPIDS.PT_PROPID_NAME);
      // TODO: get status
      oData[ServerStatusListView.SERVER_STATUS][0] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
      // Data only columns
      // TODO: is there a collab or content server icon?
      oData[ServerStatusListView.SERVER_ICON][0] = PTImageType.ICON_REMOTE_SERVER;
      if (_nServerType == SERVER_TYPE_COLLAB)
      {
        oData[ServerStatusListView.SERVER_ANCHOR][0] = GetCollabServerAnchor(strServerHost,
         gatewayedURL);
        // "Collaboration Server"
        oData[ServerStatusListView.SERVER_DESCRIPTION][0] = m_asOwner.GetString(3097,
         ResourceConstants.PORTALADMINMSGS);
      } else
      if (_nServerType == SERVER_TYPE_CONTENT)
      {
        oData[ServerStatusListView.SERVER_ANCHOR][0] = GetContentServerAnchor(strServerHost,
         gatewayedURL);
        // "Content Server"
        oData[ServerStatusListView.SERVER_DESCRIPTION][0] = m_asOwner.GetString(3098,
         ResourceConstants.PORTALADMINMSGS);
      }
      XPHashtable hosts = ServerStatusHelper.getInstance().GetPortletIDs(m_asOwner,
       server.GetObjectID());
      if (hosts.GetSize() > 1)
      {
        // this shouldn't happen, but can occur under strange upgrade scenarios or with multiple
        // content or collab servers.
        // We could use a string buffer here, but this is an error condition for admin users
        // only, so we don't care about performance.
        String strError = "More than one unique host found for collab or content portlets for server ID " + server.GetObjectID() + ".  Ignoring extra hosts:";
        // Log all of the problematic portlets/hosts for debug purposes.
        IXPEnumerator keys = hosts.GetKeys();
        while (keys.MoveNext())
        {
          strError+=" " + keys.GetCurrent() + " (portlet ID " + hosts.GetElement(keys.GetCurrent()) + ")";
          }
        log.Warn(strError);
        Object oKey;
        Object oValue;
        keys = hosts.GetKeys();
        if (keys.MoveNext())
        {
          // Cache the first unique host.
          oKey = keys.GetCurrent();
          oValue = hosts.GetElement(oKey);
          // Clear the hashtable and populate it with just one host
          hosts.Clear();
          hosts.PutElement(oKey, oValue);
        }
      }
      ServerStatusHelper.getInstance().GetServerStatus(m_asOwner, m_htInitialPortletStatus,
       hosts, oData, PORTLET_TIMEOUT);
      //oData[ServerStatusListView.SERVER_STATUS_MSG][0] = null;
      //oData[ServerStatusListView.SERVER_STATUS_ERROR][0] = null;
      return oData;
    }
    
    /// <summary>
    /// This helper method creates a filter array to filter
    /// for Collaboration Server's unique UUID when querying
    /// Gadget Content Servers.
    /// </summary>
    /// <returns>The collab UUID filter.</returns>
    public static Object[][] GetCollabServerUUIDFilter()
    {
      // look for collab remoteserver
      Object[][] filter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        filter[j2c_index] = new Object[1];
      }
      filter[0][0] = PT_PROPIDS.PT_PROPID_UUID;
      filter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      filter[2][0] = "{48C1B7E5-5D30-4E4E-95BE-800AD8F8CBFE}";
      return filter;
    }
    
    /// <summary>
    /// This helper method creates a filter array to filter
    /// for Content Server's unique UUID when querying
    /// Gadget Content Servers.
    /// </summary>
    /// <returns>The collab UUID filter.</returns>
    public static Object[][] GetContentServerUUIDFilter()
    {
      // look for collab remoteserver
      Object[][] filter = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        filter[j2c_index] = new Object[1];
      }
      filter[0][0] = PT_PROPIDS.PT_PROPID_UUID;
      filter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      filter[2][0] = "{CB003B29-AA89-4F29-AC61-B67AA80D0C2D}";
      return filter;
    }
    
    /// <summary>
    /// Helper method that creates an HTML Anchor to a pop-up
    /// page viewing the Collaboration Server Diagnostic Page.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <param name="_strBaseURL">The base url to the collab server.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    public static HTMLAnchor GetCollabServerAnchor(String _strName, String _strBaseURL)
    {
      String collabURL = _strBaseURL + "/do/admin/diagnostic";
      //trying to encode the URL
      HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("window.open(\'" + collabURL + "\',\'PopUpCollabDiag\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <summary>
    /// Helper method that creates an HTML Anchor to a pop-up
    /// page viewing the Content Server Diagnostic Page.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <param name="_strBaseURL">The base url to the collab server.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    public static HTMLAnchor GetContentServerAnchor(String _strName, String _strBaseURL)
    {
      String collabURL = _strBaseURL + "/console/index.jsp";
      HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("window.open(\'" + collabURL + "\',\'PopUpContentDiag\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new RelatedServersModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}