using System;
using com.plumtree.openfoundation.util;
using XPHashtable=com.plumtree.openfoundation.util.XPHashtable;
using IXPEnumerator=com.plumtree.openfoundation.util.IXPEnumerator;
using XPConvert=com.plumtree.openfoundation.util.XPConvert;
using XPResourceManager=com.plumtree.openfoundation.internationalization.XPResourceManager;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
using AppDataObject=com.plumtree.portaluiinfrastructure.statichelpers.AppDataObject;
using com.plumtree.server;
using PTException=com.plumtree.server.marshalers.PTException;
using WSModelHelper=com.plumtree.portalpages.admin.editors.webservice.WSModelHelper;
using ServerStatusListView=com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist.ServerStatusListView;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using GatewayUtils=com.plumtree.portalpages.browsing.gateway.GatewayUtils;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using OpenLogger=com.plumtree.openlog.OpenLogger;
using OpenLogService=com.plumtree.openlog.OpenLogService;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers
{
  /// <summary>
  /// Helper class for RemoteHostsModel and RelatedServersPage
  /// </summary>
  /// <author>OkanA</author>
  public class ServerStatusHelper
  {
    private static ServerStatusHelper instance = new ServerStatusHelper();
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers.ServerStatusHelper";
    private const String PROTOCOL_SEPARATOR = "://";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     sClassName);
    private ServerStatusHelper()
    {
    }
    public static ServerStatusHelper getInstance()
    {
      return instance;
    }
    
    /// <summary>
    /// This helper method retrieves the server status for given host->portlet id mappings
    /// </summary>
    /// <param name="m_asOwner"></param>
    /// <param name="initialPortletStatus"></param>
    /// <param name="hosts"></param>
    /// <param name="objectData"></param>
    /// <param name="nStatusTimeout"></param>
    /// <returns></returns>
    public virtual bool GetServerStatus(AActivitySpace m_asOwner, XPHashtable initialPortletStatus,
     XPHashtable hosts, Object[][] objectData, int nStatusTimeout)
    {
      if (hosts.GetSize() != objectData[ServerStatusListView.SERVER_STATUS_ERROR].Length)
      {
        // Simply log this.  We make sure that our array handling below can deal with this.
        log.Warn("GetServerStatus incoming hosts and output data arrays of different lengths.");
        }
      int[] portletIDs = new int[hosts.GetSize()];
      bool errorFound = false;
      IXPEnumerator hostNames = hosts.GetKeys();
      int i = 0;
      while (hostNames.MoveNext())
      {
        portletIDs[i] = XPConvert.ToInteger(hosts.GetElement(hostNames.GetCurrent()));
        i++;
      }
      // Get the temporary page used just for the diagnostic page
      // to query for the portlet content
      IPTPage diagPage = (IPTPage) ((IPTSession) m_asOwner.GetUserSession()).GetPages().Open(PT_INTRINSICS.PT_PAGE_DIAGNOSTIC,
       false);
      // Add the portlets to the page
      diagPage.AssignPortlets(portletIDs, 0);
      // Query for the page content
      // Create Application Data Object
      // 0 means not a community page
      IPTState state = AppDataObject.GetAppDataObject(0, PT_INTRINSICS.PT_PAGE_DIAGNOSTIC,
       "uri", m_asOwner, false);
      state.Add(PlumtreeExtensibility.PT_PORTLET_TIMEOUT_KEY, nStatusTimeout,
       0, true);
      state.Add(PlumtreeExtensibility.PT_RETURN_URI_KEY, m_asOwner.GetCurrentNormalizedBaseURL(),
       0, true);
      // Use Diagnostic mode here instead of runtime or preview mode, because
      // runtime mode will get cached content if there are errors with the portlets.
      // That would mask host failures forever.  Preview mode does not use
      // the cached content if there is an error, but it does still use it normally.
      // Preview mode also ignores the portlet timeout.
      IPTMyPortalGadgetContent content = diagPage.QueryPortletContent(0, PT_INTRINSICS.PT_PAGE_DIAGNOSTIC,
       state, "", PT_GADGET_MODES.PT_GADGETMODES_DIAGNOSTIC, true);
      i = 0;
      hostNames = hosts.GetKeys();
      // Check the status of each portlet (making sure that we don't go beyond
      // the end of the objectData length).
      while ((hostNames.MoveNext()) && (i < objectData[ServerStatusListView.SERVER_STATUS_ERROR].Length))
      {
        // Initialize with null
        objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = null;
        objectData[ServerStatusListView.SERVER_STATUS_ERROR][i] = null;
        int nPortletID = XPConvert.ToInteger(hosts.GetElement(hostNames.GetCurrent()));
        Object[][] objArrMarkup = null;
        try
        {
          objArrMarkup = content.GetContent(i);
        }
        catch (Exception e)
        {
          if (e is PTException)
          {
            // TODO: This switch statement shouldn't be necessary, but
            // some kinds of portlets throw exceptions (gadget_runtime_error)
            // and some use the error reporting array below.
            switch (((PTException) e).GetErrorCode()){
            case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
            {
              // Portlet timed out, might just be slow
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
              // "Timeout"
              objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3104,
               ResourceConstants.PORTALADMINMSGS);
              errorFound = true;
              break;
            }
            case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
            {
              // Portlet had a runtime error
              // This could be because the machine is down
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
              // This could be an intermittent problem.  Try again with a longer timeout
              errorFound = true;
              break;
            }
            case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
            {
              // Portlet had an HTTP error
              // This could be because the machine is down
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
              // This could be an intermittent problem.  Try again with a longer timeout
              errorFound = true;
              break;
            }
            case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
            {
              // We display disabled WebServices for info purposes.
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
              // "Disabled"
              objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3105,
               ResourceConstants.PORTALADMINMSGS);
              break;
            }
            default:
            {
              // Inconclusive
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
              // Unknown
              objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3135,
               ResourceConstants.PORTALADMINMSGS);
              errorFound = true;
              break;
            }
            }
          } else
          {
            // Inconclusive
            objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
            // Offline
            objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(1443,
             ResourceConstants.PORTALADMINMSGS);
            errorFound = true;
          }
          // TODO: Should we log this exception?
          objArrMarkup = null;
        }
        if (objArrMarkup != null)
        {
          int nlength = objArrMarkup.Length;
          if (objArrMarkup.Length == PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS)
          {
            if (!GatewayUtils.IsErrorContentArray(objArrMarkup))
            {
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_GREEN);
              // Online
              objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(1442,
               ResourceConstants.PORTALADMINMSGS);
            } else
            {
              int iErrorCode = GatewayUtils.GetErrorCode(objArrMarkup);
              // TODO: Do we need to check this?
              // if the response was received, need to make room in the array for response status, header, body
              //						boolean bResponseReceived = GatewayUtils.ResponseReceivedForErrors(objArrMarkup);
              switch (iErrorCode){
              case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
              {
                // Portlet timed out, might just be slow
                objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
                // "Timeout"
                objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3104,
                 ResourceConstants.PORTALADMINMSGS);
                errorFound = true;
                break;
              }
              case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
              {
                // Portlet had a runtime error
                // This could be because the machine is down
                objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
                String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
                if (strStatus != null)
                {
                  // "HTTP {0} error"
                  objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = XPResourceManager.FormatMessage(m_asOwner.GetString(3106,
                   ResourceConstants.PORTALADMINMSGS), strStatus);
                }
                // We do not add the error message here, because it
                // is available on the detailed web services page.
                // This could be an intermittent problem.  Try again with a longer timeout
                errorFound = true;
                break;
              }
              case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
              {
                // Portlet had an http error
                // This could be because the machine is down
                objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
                String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
                if (strStatus != null)
                {
                  // "HTTP {0} error"
                  objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = XPResourceManager.FormatMessage(m_asOwner.GetString(3106,
                   ResourceConstants.PORTALADMINMSGS), strStatus);
                }
                // We do not add the error message here, because it
                // is available on the detailed web services page.
                // This could be an intermittent problem.  Try again with a longer timeout
                errorFound = true;
                break;
              }
              case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
              {
                // We display disabled WebServices for info purposes.
                objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
                // "Disabled"
                objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3105,
                 ResourceConstants.PORTALADMINMSGS);
                break;
              }
              default:
              {
                // Inconclusive
                objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
                // Unknown
                objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3135,
                 ResourceConstants.PORTALADMINMSGS);
                errorFound = true;
                break;
              }
              }
            }
          } else
          {
            // Nothing in the markup - unclear what this means.
            objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
            // Unknown
            objectData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3135,
             ResourceConstants.PORTALADMINMSGS);
            errorFound = true;
          }
        }
        Object oInitialStatus = initialPortletStatus.GetElement(nPortletID);
        if (null != oInitialStatus)
        {
          if (XPConvert.ToInteger(oInitialStatus) == ServerStatusListView.STATUS_RED)
          {
            if (XPConvert.ToInteger(objectData[ServerStatusListView.SERVER_STATUS][i]) == ServerStatusListView.STATUS_GREEN)
            {
              // If we were red, but are now green, that still indicates a problem.
              // Set to yellow
              objectData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
              // "Failed on first attempt."
              objectData[ServerStatusListView.SERVER_STATUS_ERROR][i] = m_asOwner.GetString(3107,
               ResourceConstants.PORTALADMINMSGS);
            }
          }
        } else
        {
          // Store the initial status for next time.
          initialPortletStatus.PutElement(nPortletID, objectData[ServerStatusListView.SERVER_STATUS][i]);
          }
        i++;
      }
      return errorFound;
    }
    
    /// <summary>
    /// Returns a list of unique hosts and portlets for each host
    /// </summary>
    /// <param name="m_asOwner"></param>
    /// <param name="serverID">
    /// object id of the server to query. If serverID is passed, the method will return a portlet
    /// for this server only. If -1 is passed, it will return all unique <host, portlet> tuples.
    /// </param>
    /// <returns>hashtable of <host, portletid></returns>
    public virtual XPHashtable GetPortletIDs(AActivitySpace m_asOwner, int serverID)
    {
      XPHashtable result = new XPHashtable();
      Object[][] webServiceQueryFilter = null;
      if (serverID >= 0)
      {
        webServiceQueryFilter = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          webServiceQueryFilter[j2c_index] = new Object[2];
        }
      } else
      {
        webServiceQueryFilter = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          webServiceQueryFilter[j2c_index] = new Object[1];
        }
      }
      webServiceQueryFilter[0][0] = PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID;
      webServiceQueryFilter[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      webServiceQueryFilter[2][0] = WSModelHelper.WSTYPE_HTTPGP;
      if (serverID > 0)
      {
        webServiceQueryFilter[0][1] = PT_PROPIDS.PT_PROPID_WEBSERVICE_REMOTESERVERID;
        webServiceQueryFilter[1][1] = PT_FILTEROPS.PT_FILTEROP_EQ;
        webServiceQueryFilter[2][1] = serverID;
      }
      IPTQueryResult webServiceResults = (IPTQueryResult) ((IPTSession) m_asOwner.GetUserSession()).GetWebServices().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_WEBSERVICE_ENABLED,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, webServiceQueryFilter);
      if (webServiceResults.RowCount() < 1)
      {
        return result;
      }
      IPTQueryResult portletResults = (IPTQueryResult) ((IPTSession) m_asOwner.GetUserSession()).GetGadgets().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, null);
      for (int nWebService = 0;nWebService < webServiceResults.RowCount();
      nWebService++)
      {
        int nEnabled = webServiceResults.ItemAsInt(nWebService, PT_PROPIDS.PT_PROPID_WEBSERVICE_ENABLED);
        int nObjectID = webServiceResults.ItemAsInt(nWebService, PT_PROPIDS.PT_PROPID_OBJECTID);
        IPTWebService ptWebService = (IPTWebService) ((IPTSession) m_asOwner.GetUserSession()).GetWebServices().Open(nObjectID,
         false);
        String strUrl;
        try
        {
          strUrl = ptWebService.GetAbsoluteURL(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_URL);
          }
        catch (Exception e)
        {
          log.Error(e, "Unable to get absolute URL from Web Service " + nObjectID);
          strUrl = null;
        }
        if (null != strUrl)
        {
          String strHost = GetHostName(strUrl);
          // If there is no current match, store the webservice,
          // or, if there is a current match, and this webservice is
          // enabled (the stored one might not be), store this webservice.
          // We overwrite disabled webservices because we can't get content
          // back from them using a MyPage.  We should always use enabled
          // WebServices unless all WebServices for a host are disabled.
          // This results in the last webservice for each host being stored.
          if ((!result.ContainsKey(strHost)) || (nEnabled == 1))
          {
            // Look for a portlet that matches this web service
            for (int nPortlet = 0;nPortlet < portletResults.RowCount();nPortlet++)
            {
              if (nObjectID == portletResults.ItemAsInt(nPortlet, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID))
              {
                // Store the first portlet that matches
                result.PutElement(strHost, portletResults.ItemAsInt(nPortlet,
                 PT_PROPIDS.PT_PROPID_OBJECTID));
              }
            }
          }
        }
      }
      return result;
    }
    
    /// <summary>
    /// This method gets the normalized host name from a URL.
    /// </summary>
    /// <param name="_strURL"></param>
    /// <returns>The normalized host name.</returns>
    public static String GetHostName(String _strURL)
    {
      int nIndex = XPStringUtility.IndexOf(_strURL, PROTOCOL_SEPARATOR);
      if (nIndex != -1)
      {
        _strURL = XPStringUtility.Substring(_strURL, nIndex + PROTOCOL_SEPARATOR.Length,
         _strURL.Length);
      }
      nIndex = XPStringUtility.IndexOf(_strURL, "/");
      if (nIndex != -1)
      {
        _strURL = XPStringUtility.Substring(_strURL, 0, nIndex);
      }
      return XPStringUtility.ToLowerCase(_strURL);
    }
  }
}