using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.ptutilities.diagnostic;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.pages;
using com.plumtree.portalpages.common.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts
{
  /// <summary>
  /// This page displays status information for all remote
  /// hosts that the Portal gets content from.
  /// </summary>
  /// <author>DonH</author>
  public class RemoteHostsListDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "RemoteHostDiagnostic";
    public const String JAVASCRIPT_REFRESH = "refresh";
    public const String REFRESH_ID = "refresharea";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()"></seealso>
    public override String GetLeftNavString()
    {
      // "Remote Hosts"
      return m_asOwner.GetString(3100, ResourceConstants.PORTALADMINMSGS);
      }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      // This page allows you to view and reload the tag libraries for this portal machine.
      // "The current status of the Remote Hosts (i.e. Any host that serves a portlet).  " +
      // "Host status is not updated when sorting.  " +
      // "To update host status, click the Refresh button."
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(3101, ResourceConstants.PORTALADMINMSGS),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for this Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLDiv refreshDiv = new HTMLDiv();
      refreshDiv.SetID(REFRESH_ID);
      refreshDiv.AddInnerHTMLElement(m_asOwner.GetView(RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(refreshDiv));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // Display JavaScript for the remote hosts list
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).DisplayJavascript());
      RemoteHostsModel model = (RemoteHostsModel) m_asOwner.GetModel(RemoteHostsModel.STR_MVC_CLASS_NAME);
      if (model.GetNeedsRefresh())
      {
        HTMLScript inplaceRefreshScript = new HTMLScript("text/javaScript");
        XPStringBuilder sb = new XPStringBuilder(100);
        sb.Append("function ").Append(JAVASCRIPT_REFRESH).Append("() {\n");
        sb.Append("  ").Append(InPlaceRefreshHelper.GetJSSendPOSTOnAFormDP(m_asOwner.GetCurrentNormalizedBaseURL(),
         REFRESH_ID, RepostControl.POSTTOSELF_ACTION_IN_PLACE_REFRESH)).Append("\n");
        sb.Append("}\n");
        sb.Append("\n");
        sb.Append("document.PCC.RegisterForWindowEvent(\"onload\", \"").Append(JAVASCRIPT_REFRESH).Append("();\");\n");
        inplaceRefreshScript.AddInnerHTMLString(sb.ToString());
        myScripts.AddInnerHTMLElement(inplaceRefreshScript);
      }
      return myScripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PartialContentDisplay()"></seealso>
    public override HTMLElement PartialContentDisplay()
    {
      // Since we're refreshing, we know we need to generate the host list again.
      RemoteHostsModel model = (RemoteHostsModel) m_asOwner.GetModel(RemoteHostsModel.STR_MVC_CLASS_NAME);
      EditorModel diagPageModel = (EditorModel) m_asOwner.GetModel(DiagnosticPageModel.STR_MVC_CLASS_NAME);
      if (diagPageModel.GetCurrentRepostAction() == RepostControl.POSTTOSELF_ACTION_IN_PLACE_REFRESH)
      {
        // Only refresh the server list if we're requesting
        // an in-place refresh of this page.
        model.StartServerList();
      }
      // reset so we don't keep refreshing.  Only do it once.
      model.SetNeedsRefresh(false);
      return m_asOwner.GetView(RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display();
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}