using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.pages;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.hostservices;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts
{
  /// <summary>
  /// This model initializes the Server List with the
  /// Remote Hosts.
  /// </summary>
  /// <author>DonH</author>
  public class RemoteHostsModel : IModel,IModelRO
  {
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.RemoteHostsModel";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     sClassName);
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RemoteHosts";
    // Server types - for SERVER_TYPE column
    public const int SERVER_TYPE_REMOTE = 0;
    // Used to get the host name part of an url
    public const String PROTOCOL_SEPARATOR = "://";
    // portlet timeouts for testing the remote hosts.
    public const int INITIAL_TIMEOUT = 5000;
    public const int REPEAT_TIMEOUT = 15000;
    protected AActivitySpace m_asOwner;
    protected bool m_bNeedRefresh = false;
    protected XPHashtable m_htInitialPortletStatus = new XPHashtable();
    
    /// <summary>
    /// This method returns the model to it's original state
    /// before any tests have been run / lists initialized.
    /// </summary>
    public virtual void ResetModel()
    {
      m_bNeedRefresh = false;
      m_htInitialPortletStatus = new XPHashtable();
    }
    
    /// <summary>
    /// Helper method to start the Server List.
    /// </summary>
    public virtual void StartServerList()
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_asOwner.GetModel(RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      model.InitializeMetaDataList(
      // List Title -- "Remote Hosts"
      m_asOwner.GetString(3100, ResourceConstants.PORTALADMINMSGS), new String[]{
      // Server Icon -- "Type"
      m_asOwner.GetString(3090, ResourceConstants.PORTALADMINMSGS), 
      // Server Name
      m_asOwner.GetString(3091, ResourceConstants.PORTALADMINMSGS), 
      // Status
      m_asOwner.GetString(3092, ResourceConstants.PORTALADMINMSGS)}, 
      // Width -- we use percents for the small columns because otherwise
      // the column header breaks to a new line when the sort icon is added.
      new String[]{"10%", null, "10%"}, 
      // Server Type
      // Server Name
      // Status
      // Sortable
      new bool[]{true, true, true}, 
      // Server Type
      // Server Name
      // Status
      // default sort column -- sort by type
      1, 
      // Number of total columns (Visible + Data)
      ServerStatusListView.NUM_COLS, 
      // list key
      1);
      PopulateServerList();
    }
    
    /// <summary>
    /// Helper method to populate the Server List.
    /// </summary>
    public virtual void PopulateServerList()
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_asOwner.GetModel(RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Pre populate the list (By default the list will be empty.).
      model.AddRowsToList(GetHostData());
      if (AreAllServersOkay(model))
      {
      }
      // TODO: Resort by status with red at top
      // Set the message and instructions to display when the list is empty.
      // message: There are no remote hosts configured for this portal server.
      // instructions: To add remote hosts to this portal server, create portlets on this portal server.
      model.SetEmptyListMessages(m_asOwner.GetString(3102, ResourceConstants.PORTALADMINMSGS),
       m_asOwner.GetString(3103, ResourceConstants.PORTALADMINMSGS));
    }
    
    /// <summary>
    /// Helper method to generate the data for the Remote Hosts.
    /// </summary>
    /// <returns>Object[][] The Remote Host data.</returns>
    protected virtual Object[][] GetHostData()
    {
      XPHashtable hosts = ServerStatusHelper.getInstance().GetPortletIDs(m_asOwner,
       -1);
      IXPEnumerator hostNames = hosts.GetKeys();
      Object[][] oData = new Object[ServerStatusListView.NUM_COLS][];
      for (int j2c_index = 0;j2c_index < ServerStatusListView.NUM_COLS;j2c_index++)
      {
        oData[j2c_index] = new Object[hosts.GetSize()];
      }
      // This method checks the portlet status and fills out the relevant
      // parts of the data array for each portlet.
      // I.E. ServerStatusListView.SERVER_STATUS, SERVER_STATUS_MSG, & SERVER_STATUS_ERROR
      //SetPortletStatus(hosts, oData);
      //XPHashtable initialPortletStatus, Object[][] objectData, int nStatusTimeout) {
      //Remote hosts are checked twice: First time with a low timeout value, and if this timeout is too short
      //they will be checked again with a longer timeout.
      //So, if GetServerStatus returns true, which means an error occured, it will try again with a longer timeout.i
      int timeout = m_bNeedRefresh ? REPEAT_TIMEOUT : INITIAL_TIMEOUT;
      bool statusError = ServerStatusHelper.getInstance().GetServerStatus(m_asOwner,
       m_htInitialPortletStatus, hosts, oData, timeout);
      m_bNeedRefresh = m_bNeedRefresh ? false : statusError;
      int i = 0;
      while (hostNames.MoveNext())
      {
        String strHostName = (String) hostNames.GetCurrent();
        int nPortletID = XPConvert.ToInteger(hosts.GetElement(strHostName));
        // Visible columns
        oData[ServerStatusListView.SERVER_TYPE][i] = XPConvert.ToString(SERVER_TYPE_REMOTE);
        oData[ServerStatusListView.SERVER_NAME][i] = strHostName;
        // SERVER_STATUS already filled out.
        // Data only columns
        oData[ServerStatusListView.SERVER_ICON][i] = PTImageType.ICON_REMOTE_SERVER;
        oData[ServerStatusListView.SERVER_ANCHOR][i] = GetRemoteHostAnchor(strHostName);
        oData[ServerStatusListView.SERVER_DESCRIPTION][i] = null;
        // SERVER_STATUS_MSG and SERVER_STATUS_ERROR already filled out.
        i++;
      }
      // This will change the description for content
      // and collab diagnostic pages.
      AddContentServerMarkup(oData, hosts);
      AddCollabServerMarkup(oData, hosts);
      return oData;
    }
    
    /// <summary>
    /// This helper method strips the URL down to just
    /// the host name (and possibly port number).
    /// </summary>
    /// <param name="_strURL">The full URL.</param>
    /// <returns>String The host name.</returns>
    public static String GetHostName(String _strURL)
    {
      int nIndex = XPStringUtility.IndexOf(_strURL, PROTOCOL_SEPARATOR);
      if (nIndex != -1)
      {
        // Get the part after the http:// or https://
        _strURL = XPStringUtility.Substring(_strURL, nIndex + PROTOCOL_SEPARATOR.Length,
         _strURL.Length);
      }
      nIndex = XPStringUtility.IndexOf(_strURL, "/");
      if (nIndex != -1)
      {
        // Get just the host name & port number (if present)
        _strURL = XPStringUtility.Substring(_strURL, 0, nIndex);
      }
      return _strURL;
    }
    
    /// <summary>
    /// This method returns whether or not the results page needs refreshing
    /// because a host had connection problems.
    /// </summary>
    /// <returns>True implies that the results page needs to be refreshed.</returns>
    public virtual bool GetNeedsRefresh()
    {
      return m_bNeedRefresh;
    }
    
    /// <summary>
    /// This method sets whether or not the results page needs refreshing
    /// because a host had connection problems.
    /// </summary>
    /// <param name="_bNeedsRefresh">
    /// True implies that the results page needs to
    /// be refreshed.
    /// </param>
    public virtual void SetNeedsRefresh(bool _bNeedsRefresh)
    {
      m_bNeedRefresh = _bNeedsRefresh;
    }
    
    /// <summary>
    /// OA: Deprecated: Using ServerStatusHelper instead
    /// This method filles in the data array with String representations of
    /// int status codes, optional messages (disabled, timeout, etc..), and error
    /// messages (404, server not found, etc...).  The optional messages and
    /// error messages can be null.
    /// The 2 arrays must have the same length.
    /// </summary>
    /// <param name="_htPortletIDs">The ids of the portlets to check.</param>
    /// <param name="_oData">
    /// Filled in with int status codes, optional messages, and errors.
    /// protected void SetPortletStatus(XPHashtable _htPortletIDs, Object[][] _oData)
    /// {
    /// int[] portletIDs = new int[_htPortletIDs.GetSize()];
    /// IXPEnumerator hostNames = _htPortletIDs.GetKeys();
    /// int i = 0;
    /// while (hostNames.MoveNext())
    /// {
    /// portletIDs[i] = XPConvert.ToInteger(_htPortletIDs.GetElement(hostNames.GetCurrent()));
    /// i++;
    /// }
    /// // Get the temporary page used just for the diagnostic page
    /// // to query for the portlet content
    /// IPTPage diagPage = (IPTPage) ((IPTSession) m_asOwner.GetUserSession()).
    /// GetPages().Open(PT_INTRINSICS.PT_PAGE_DIAGNOSTIC, false);
    /// // Add the portlets to the page
    /// diagPage.AssignPortlets(portletIDs, 0);
    /// // Query for the page content
    /// // Create Application Data Object
    /// // 0 means not a community page
    /// IPTState state = AppDataObject.GetAppDataObject(0, PT_INTRINSICS.PT_PAGE_DIAGNOSTIC, "uri", m_asOwner, false);
    /// // Set the portlet timeout for this request to the appropriate value.
    /// int nStatusTimeout = INITIAL_TIMEOUT;
    /// if (m_bNeedRefresh)
    /// {
    /// nStatusTimeout = REPEAT_TIMEOUT;
    /// m_bNeedRefresh = false;
    /// }
    /// state.Add(PlumtreeExtensibility.PT_PORTLET_TIMEOUT_KEY, nStatusTimeout, 0, true);
    /// state.Add(PlumtreeExtensibility.PT_RETURN_URI_KEY, m_asOwner.GetCurrentNormalizedBaseURL(), 0, true);
    /// // Use Diagnostic mode here instead of runtime or preview mode, because
    /// // runtime mode will get cached content if there are errors with the portlets.
    /// // That would mask host failures forever.  Preview mode does not use
    /// // the cached content if there is an error, but it does still use it normally.
    /// // Preview mode also ignores the portlet timeout.
    /// IPTMyPortalGadgetContent content = diagPage.QueryPortletContent(0, PT_INTRINSICS.PT_PAGE_DIAGNOSTIC, state,
    /// "", PT_GADGET_MODES.PT_GADGETMODES_DIAGNOSTIC, true);
    /// i = 0;
    /// hostNames = _htPortletIDs.GetKeys();
    /// // Check the status of each portlet
    /// while (hostNames.MoveNext())
    /// {
    /// // Initialize with null
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = null;
    /// _oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = null;
    /// int nPortletID = XPConvert.ToInteger(_htPortletIDs.GetElement(hostNames.GetCurrent()));
    /// Object[][] objArrMarkup = null;
    /// // TODO: This code should be refactored so it can be reused by the
    /// // HostServicesModel as well, instead of duplicating code.
    /// try
    /// {
    /// objArrMarkup = content.GetContent(i);
    /// } catch (Exception e)
    /// {
    /// if( e instanceof PTException )
    /// {
    /// // TODO: This switch statement shouldn't be necessary, but
    /// // some kinds of portlets throw exceptions (gadget_runtime_error)
    /// // and some use the error reporting array below.
    /// switch ( ((PTException) e).GetErrorCode() )
    /// {
    /// case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
    /// {
    /// // Portlet timed out, might just be slow
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
    /// // "Timeout"
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3104, ResourceConstants.PORTALADMINMSGS);
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
    /// {
    /// // Portlet had a runtime error
    /// // This could be because the machine is down
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
    /// // This could be an intermittent problem.  Try again with a longer timeout
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
    /// {
    /// // Portlet had an HTTP error
    /// // This could be because the machine is down
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
    /// // This could be an intermittent problem.  Try again with a longer timeout
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
    /// {
    /// // We display disabled WebServices for info purposes.
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // "Disabled"
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3105, ResourceConstants.PORTALADMINMSGS);
    /// break;
    /// }
    /// default:
    /// {
    /// // Inconclusive
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // Unknown
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3135, ResourceConstants.PORTALADMINMSGS);
    /// m_bNeedRefresh = true;
    /// }
    /// }
    /// } else
    /// {
    /// // Inconclusive
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
    /// // Offline
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(1443, ResourceConstants.PORTALADMINMSGS);
    /// m_bNeedRefresh = true;
    /// // TODO: Should we log this exception?
    /// }
    /// objArrMarkup = null;
    /// }
    /// if (objArrMarkup != null)
    /// {
    /// int nlength = objArrMarkup.length;
    /// if (objArrMarkup.length == PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS)
    /// {
    /// if (!GatewayUtils.IsErrorContentArray(objArrMarkup))
    /// {
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_GREEN);
    /// // Online
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(1442, ResourceConstants.PORTALADMINMSGS);
    /// } else
    /// {
    /// int iErrorCode = GatewayUtils.GetErrorCode(objArrMarkup);
    /// // TODO: Do we need to check this?
    /// // if the response was received, need to make room in the array for response status, header, body
    /// //						boolean bResponseReceived = GatewayUtils.ResponseReceivedForErrors(objArrMarkup);
    /// switch (iErrorCode)
    /// {
    /// case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
    /// {
    /// // Portlet timed out, might just be slow
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // "Timeout"
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3104, ResourceConstants.PORTALADMINMSGS);
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
    /// {
    /// // Portlet had a runtime error
    /// // This could be because the machine is down
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
    /// String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
    /// if (strStatus != null)
    /// {
    /// // "HTTP {0} error"
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] =
    /// XPResourceManager.FormatMessage(
    /// m_asOwner.GetString(3106, ResourceConstants.PORTALADMINMSGS),
    /// strStatus); 
    /// }
    /// // We do not add the error message here, because it
    /// // is available on the detailed web services page.
    /// // This could be an intermittent problem.  Try again with a longer timeout
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
    /// {
    /// // Portlet had an http error
    /// // This could be because the machine is down
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
    /// String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
    /// if (strStatus != null)
    /// {
    /// // "HTTP {0} error"
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] =
    /// XPResourceManager.FormatMessage(
    /// m_asOwner.GetString(3106, ResourceConstants.PORTALADMINMSGS),
    /// strStatus); 
    /// }
    /// // We do not add the error message here, because it
    /// // is available on the detailed web services page.
    /// // This could be an intermittent problem.  Try again with a longer timeout
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
    /// {
    /// // We display disabled WebServices for info purposes.
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // "Disabled"
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3105, ResourceConstants.PORTALADMINMSGS);
    /// break;
    /// }
    /// default:
    /// {
    /// // Inconclusive
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // Unknown
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3135, ResourceConstants.PORTALADMINMSGS);
    /// m_bNeedRefresh = true;
    /// break;
    /// }
    /// }
    /// }
    /// } else
    /// {
    /// // Nothing in the markup - unclear what this means.
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // Unknown
    /// _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3135, ResourceConstants.PORTALADMINMSGS);
    /// m_bNeedRefresh = true;
    /// }
    /// }
    /// Object oInitialStatus = m_htInitialPortletStatus.GetElement(new Integer(nPortletID));
    /// if (null != oInitialStatus)
    /// {
    /// if (XPConvert.ToInteger(oInitialStatus) == ServerStatusListView.STATUS_RED)
    /// {
    /// if (XPConvert.ToInteger(_oData[ServerStatusListView.SERVER_STATUS][i]) ==
    /// ServerStatusListView.STATUS_GREEN)
    /// {
    /// // If we were red, but are now green, that still indicates a problem.
    /// // Set to yellow
    /// _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
    /// // "Failed on first attempt."
    /// _oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = m_asOwner.GetString(3107, ResourceConstants.PORTALADMINMSGS);
    /// }
    /// }
    /// } else
    /// {
    /// // Store the initial status for next time.
    /// m_htInitialPortletStatus.PutElement(new Integer(nPortletID),
    /// _oData[ServerStatusListView.SERVER_STATUS][i]);
    /// }
    /// i++;
    /// }
    /// }
    /// </param>
    public static bool AreAllServersOkay(SortedMetaDataListModel _model)
    {
      PTGrowableSortedArrayWrapper data = _model.GetItems();
      for (int i = 0;i < data.GetCount();i++)
      {
        // Constant is zero based, but data is not zero based.
        int nStatusCode = XPConvert.ToInteger(data.GetItem(i, ServerStatusListView.SERVER_STATUS + 1));
        if ((nStatusCode == ServerStatusListView.STATUS_RED) || (nStatusCode == ServerStatusListView.STATUS_YELLOW))
        {
          return false;
        }
      }
      return true;
    }
    
    /// <summary>
    /// This helper method determines which host is running
    /// Content Server and adds descriptive text to it.
    /// </summary>
    /// <param name="_oData">The data to add to the ServerStatusList.</param>
    protected virtual void AddContentServerMarkup(Object[][] _oData, XPHashtable _hosts)
    {
      // look for content remoteserver
      Object[][] contentFilter = RelatedServersModel.GetContentServerUUIDFilter();
      String strContentBaseURL = GetServerBaseURL(contentFilter, m_asOwner);
      if (null == strContentBaseURL)
      {
        // Content not installed on this portal
        return;
      }
      String strContentHost = GetHostName(strContentBaseURL);
      IXPEnumerator hostNames = _hosts.GetKeys();
      int i = 0;
      while (hostNames.MoveNext())
      {
        String strHostName = (String) hostNames.GetCurrent();
        if (0 == XPStringUtility.CompareIgnoreCase(strHostName, strContentHost))
        {
          if (null == _oData[ServerStatusListView.SERVER_DESCRIPTION][i])
          {
            // "Content Server Host"
            _oData[ServerStatusListView.SERVER_DESCRIPTION][i] = m_asOwner.GetString(3108,
             ResourceConstants.PORTALADMINMSGS);
          } else
          {
            // "Content Server Host: {0}"
            _oData[ServerStatusListView.SERVER_DESCRIPTION][i] = XPResourceManager.FormatMessage(m_asOwner.GetString(3109,
             ResourceConstants.PORTALADMINMSGS), _oData[ServerStatusListView.SERVER_DESCRIPTION][i]);
            }
          break;
        }
        i++;
      }
    }
    
    /// <summary>
    /// This helper method determines which host is running
    /// Collaboration Server and adds descriptive text to it.
    /// </summary>
    /// <param name="_oData">The data to add to the ServerStatusList.</param>
    protected virtual void AddCollabServerMarkup(Object[][] _oData, XPHashtable _hosts)
    {
      // look for collab remoteserver
      Object[][] collabFilter = RelatedServersModel.GetCollabServerUUIDFilter();
      String strCollabBaseURL = GetServerBaseURL(collabFilter, m_asOwner);
      if (null == strCollabBaseURL)
      {
        // Collab not installed on this portal
        return;
      }
      String strCollabHost = GetHostName(strCollabBaseURL);
      IXPEnumerator hostNames = _hosts.GetKeys();
      int i = 0;
      while (hostNames.MoveNext())
      {
        String strHostName = (String) hostNames.GetCurrent();
        if (0 == XPStringUtility.CompareIgnoreCase(strHostName, strCollabHost))
        {
          if (null == _oData[ServerStatusListView.SERVER_DESCRIPTION][i])
          {
            // "Collaboration Server Host"
            _oData[ServerStatusListView.SERVER_DESCRIPTION][i] = m_asOwner.GetString(3110,
             ResourceConstants.PORTALADMINMSGS);
          } else
          {
            // "Collaboration Server Host: {0}"
            _oData[ServerStatusListView.SERVER_DESCRIPTION][i] = XPResourceManager.FormatMessage(m_asOwner.GetString(3111,
             ResourceConstants.PORTALADMINMSGS), _oData[ServerStatusListView.SERVER_DESCRIPTION][i]);
            }
          break;
        }
        i++;
      }
    }
    
    /// <summary>
    /// This helper method gets the base URL of the requested
    /// server.
    /// </summary>
    /// <param name="_filter">The filter for the server (UUID).</param>
    /// <param name="_asOwner">The parent AActivitySpace.</param>
    /// <returns>String The base URL of the requested server.</returns>
    public static String GetServerBaseURL(Object[][] _filter, AActivitySpace _asOwner)
    {
      IPTObjectManager serverObjMgr = ((IPTSession) _asOwner.GetUserSession()).GetGadgetContentServers();
      IPTQueryResult ptqrServer = (IPTQueryResult) serverObjMgr.Query(PT_PROPIDS.PT_PROPID_OBJECTID,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, _filter);
      if (ptqrServer.RowCount() == 1)
      {
        IPTGadgetContentServer iptServer;
        try
        {
          iptServer = (IPTGadgetContentServer) serverObjMgr.Open(ptqrServer.ItemAsInt(0,
           PT_PROPIDS.PT_PROPID_OBJECTID), false);
        }
        catch (Exception e)
        {
          log.Error(e, "Unable to open remote server object.");
          return null;
        }
        return iptServer.GetURL();
      }
      if (ptqrServer.RowCount() > 1)
      {
        // this should never happen.
        log.Error("Query for a specific server returned multiple results.  Ignoring.");
        }
      return null;
    }
    
    /// <summary>
    /// Helper method that creates an HTML Anchor to a pop-up
    /// page viewing remote host details.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    protected virtual HTMLAnchor GetRemoteHostAnchor(String _strName)
    {
      ASURL remoteHostWebServicesURL = new ASURL(m_asOwner);
      // Note: We use a hack to initialize the editor by passing in the remote host name
      // as the subspace key.  This means that we cannot re-use cached spaces and must
      // always create a new space.
      remoteHostWebServicesURL.SetLinkCreateNewSpace(HostServicesAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      remoteHostWebServicesURL.SetDisplayPage(HostServicesPopupDP.STR_MVC_CLASS_NAME);
      // We use the subspace key to pass in the information
      // about which remote host to display.
      remoteHostWebServicesURL.SetSubSpaceKey(_strName);
      HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("window.open(\'" + remoteHostWebServicesURL.GetURLAsString() + "\',\'PopUpRemoteHostWebServices\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new RemoteHostsModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}