using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.hostservices
{
  /// <summary>
  /// Displays a list of all the portlet web services associated
  /// with a given host machine.
  /// </summary>
  /// <author>DonH</author>
  public class HostServicesAS : EditorAS
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "HostServices";
    
    /// <summary>
    /// Storage name for the multi column list classes 
    /// </summary>
    public const String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "HostServicesList";
    
    /// <summary>
    /// Registers all the classes of the Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = HostServicesModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      // Main Host Services Popup Page
      IDisplayPage popup = new HostServicesPopupDP();
      RegisterPage(popup);
      RegisterView(ContentCollabLinksView.STR_MVC_CLASS_NAME, null);
      // Register the View, Control, and the Model used by the multi column array.		
      RegisterModel(SortedMetaDataListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myListModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      RegisterView(ServerStatusListView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST,
       myListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST,
       myListModel);
      HostServicesModel myMainModel = (HostServicesModel) GetModel(HostServicesModel.STR_MVC_CLASS_NAME);
      // We have to initialize the list after all list MVC components
      // have been registered.
      myMainModel.StartWebServiceList();
      // Set up the editor framework
      //Sets left nav menu
      // BEGIN Sub menu "Web Services for {0}"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(XPResourceManager.FormatMessage(GetString(3114,
       ResourceConstants.PORTALADMINMSGS), GetHostServicesRemoteHostName()));
      // Add the link for the main Display Page to the left nav menu
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, popup.GetName());
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String,java.lang.String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession()))
      {
        return false;
      }
      // Check for right to access administration
      return ((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()"></seealso>
    public override String GetEditorTitle()
    {
      // "Web Services for {0}"
      return XPResourceManager.FormatMessage(GetString(3114, ResourceConstants.PORTALADMINMSGS),
       GetHostServicesRemoteHostName());
    }
    
    /// <summary>
    /// This helper method gets the name of the
    /// remote host that this page is displaying
    /// the webservices from.
    /// </summary>
    /// <returns>
    /// String The remote host name, possible
    /// including port number.
    /// </returns>
    public virtual String GetHostServicesRemoteHostName()
    {
      // Note: we pass in the remote host name as the sub space key.  This is
      // not exactly standard behavior, but it's easy to code.  This means
      // we cannot reuse subspaces, because their subspace key will not get
      // updated.
      return GetSubSpaceKey();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetRepostControlName()"></seealso>
    public override String GetRepostControlName()
    {
      return (ExpListControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new HostServicesAS();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}