using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.webservice;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts;
using com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.hostservices
{
  /// <summary>
  /// Displays a list of all the portlet web services associated
  /// with a given host machine.
  /// </summary>
  /// <author>DonH</author>
  public class HostServicesModel : EditorModel
  {
    
    /// <summary>
    /// Class name for the model 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "HostServices";
    // Server types - for SERVER_TYPE column
    public const int WEB_SERVICE_TYPE_PORTLET = 0;
    
    /// <summary>
    /// Helper method to start the Web Service List.
    /// </summary>
    public virtual void StartWebServiceList()
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_asOwner.GetModel(HostServicesAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // The name of the remote server for which we are querying
      // for webservices. 
      String strRemoteHostName = ((HostServicesAS) m_asOwner).GetHostServicesRemoteHostName();
      model.InitializeMetaDataList(
      // List Title -- "Web Services for {0}"
      XPResourceManager.FormatMessage(m_asOwner.GetString(3114, ResourceConstants.PORTALADMINMSGS),
       strRemoteHostName), new String[]{
      // Server Icon -- "Type"
      m_asOwner.GetString(3090, ResourceConstants.PORTALADMINMSGS), 
      // Server Name -- "Web Service Name"
      m_asOwner.GetString(3115, ResourceConstants.PORTALADMINMSGS), 
      // Status
      m_asOwner.GetString(3092, ResourceConstants.PORTALADMINMSGS)}, 
      // Width -- we use percents for the small columns because otherwise
      // the column header breaks to a new line when the sort icon is added.
      new String[]{"10%", null, "10%"}, 
      // Server Type
      // Server Name
      // Status
      // Sortable
      new bool[]{true, true, true}, 
      // Server Type
      // Server Name
      // Status
      // default sort column -- sort by type
      1, 
      // Number of total columns (Visible + Data)
      ServerStatusListView.NUM_COLS, 
      // list key
      1);
      PopulateWebServiceList();
    }
    
    /// <summary>
    /// Helper method to populate the Web Service List.
    /// </summary>
    public virtual void PopulateWebServiceList()
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_asOwner.GetModel(HostServicesAS.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
      // Pre populate the list (By default the list will be empty.).
      model.AddRowsToList(GetWebServiceData());
      if (RemoteHostsModel.AreAllServersOkay(model))
      {
      }
      // TODO: Resort by status with red at top
      String strRemoteHostName = ((HostServicesAS) m_asOwner).GetHostServicesRemoteHostName();
      // Set the message and instructions to display when the list is empty.
      // message: "There are no web services configured to use remote host {0}"
      // instructions: To add web services for this remote host, create Web
      // Services that use this Remote Server.
      model.SetEmptyListMessages(XPResourceManager.FormatMessage(m_asOwner.GetString(3116,
       ResourceConstants.PORTALADMINMSGS), strRemoteHostName), m_asOwner.GetString(3117,
       ResourceConstants.PORTALADMINMSGS));
    }
    
    /// <summary>
    /// Helper method to generate the data for the Web Services
    /// for this remote host.
    /// </summary>
    /// <returns>Object[][] The Web Service data.</returns>
    protected virtual Object[][] GetWebServiceData()
    {
      String strRemoteHostName = ((HostServicesAS) m_asOwner).GetHostServicesRemoteHostName();
      // Only Portlet Web Services
      Object[][] filter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID,
       PT_FILTEROPS.PT_FILTEROP_EQ, WSModelHelper.WSTYPE_HTTPGP);
      IPTQueryResult ptqrWebServices = (IPTQueryResult) ((IPTSession) m_asOwner.GetUserSession()).GetWebServices().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME,
       -1, PT_PROPIDS.PT_PROPID_NAME, 0, -1, filter);
      XPArrayList webserviceIDs = new XPArrayList();
      XPArrayList webserviceNames = new XPArrayList();
      XPArrayList portletIDs = new XPArrayList();
      // Run a separate query for all portlets.  We use this below to find a portlet
      // for each web service.
      IPTQueryResult ptqrPortlets = (IPTQueryResult) ((IPTSession) m_asOwner.GetUserSession()).GetGadgets().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, null);
      for (int nWebService = 0;nWebService < ptqrWebServices.RowCount();nWebService++)
      {
        int nWebServiceID = ptqrWebServices.ItemAsInt(nWebService, PT_PROPIDS.PT_PROPID_OBJECTID);
        IPTWebService ptWebService = (IPTWebService) ((IPTSession) m_asOwner.GetUserSession()).GetWebServices().Open(nWebServiceID,
         false);
        String strUrl = ptWebService.GetAbsoluteURL(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_URL);
        // We just want the host name, no http://, nothing afterwards
        String strHost = RemoteHostsModel.GetHostName(strUrl);
        // If this webservice comes from the current remote host, store it for display.
        if (0 == XPStringUtility.CompareIgnoreCase(strRemoteHostName, strHost))
        {
          // Look for a portlet that matches this web service
          for (int nPortlet = 0;nPortlet < ptqrPortlets.RowCount();nPortlet++)
          {
            if (nWebServiceID == ptqrPortlets.ItemAsInt(nPortlet, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID))
            {
              // Store the first portlet that matches
              webserviceIDs.Add(nWebServiceID);
              webserviceNames.Add(ptqrWebServices.ItemAsString(nWebService,
               PT_PROPIDS.PT_PROPID_NAME));
              portletIDs.Add(ptqrPortlets.ItemAsInt(nPortlet, PT_PROPIDS.PT_PROPID_OBJECTID));
              break;
            }
          }
        }
      }
      Object[][] oData = new Object[ServerStatusListView.NUM_COLS][];
      for (int j2c_index = 0;j2c_index < ServerStatusListView.NUM_COLS;j2c_index++)
      {
        oData[j2c_index] = new Object[webserviceIDs.GetSize()];
      }
      // This method checks the portlet status and fills out the relevant
      // parts of the data array for each portlet.
      // I.E. ServerStatusListView.SERVER_STATUS, SERVER_STATUS_MSG, & SERVER_STATUS_ERROR
      SetPortletStatus(portletIDs, oData);
      for (int i = 0;i < webserviceNames.GetSize();i++)
      {
        String strWebServiceName = XPConvert.ToString(webserviceNames.GetElement(i));
        int nWebServiceID = XPConvert.ToInteger(webserviceIDs.GetElement(i));
        int nPortletID = XPConvert.ToInteger(portletIDs.GetElement(i));
        // Visible columns
        oData[ServerStatusListView.SERVER_TYPE][i] = XPConvert.ToString(WEB_SERVICE_TYPE_PORTLET);
        oData[ServerStatusListView.SERVER_NAME][i] = strWebServiceName;
        // SERVER_STATUS already filled out.
        // Data only columns
        oData[ServerStatusListView.SERVER_ICON][i] = PTImageType.ICON_WEB_SERVICE;
        // TODO: This currently opens in the same popup window.  Is this good?
        // The main popup page does not refresh when you close the editor, so you
        // have to close it and open it again.  We should probably fix this.
        oData[ServerStatusListView.SERVER_ANCHOR][i] = GetWebServiceAnchor(strWebServiceName,
         nWebServiceID);
        oData[ServerStatusListView.SERVER_DESCRIPTION][i] = null;
      }
      // SERVER_STATUS_MSG and SERVER_STATUS_ERROR already filled out.
      // TODO: should we try to add markup for the collab and content
      // web services?  We only know the remote host UUID, so we would
      // have to do some extra manipulation.
      return oData;
    }
    
    /// <summary>
    /// Helper method to generate a list of portlet webservices
    /// for the remote host.
    /// </summary>
    /// <returns>XPHashtable The Web Service Portlet Mapping</returns>
    protected virtual XPHashtable GetWebServicePortletMapping()
    {
      String strRemoteHostName = ((HostServicesAS) m_asOwner).GetHostServicesRemoteHostName();
      // Only Portlet Web Services
      Object[][] filter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID,
       PT_FILTEROPS.PT_FILTEROP_EQ, WSModelHelper.WSTYPE_HTTPGP);
      IPTQueryResult ptqrWebServices = (IPTQueryResult) ((IPTSession) m_asOwner.GetUserSession()).GetWebServices().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_WEBSERVICE_ENABLED,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, filter);
      XPHashtable result = new XPHashtable();
      // Run a separate query for all portlets.  We use this below to find a portlet
      // for each web service.
      IPTQueryResult ptqrPortlets = (IPTQueryResult) ((IPTSession) m_asOwner.GetUserSession()).GetGadgets().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, null);
      for (int nWebService = 0;nWebService < ptqrWebServices.RowCount();nWebService++)
      {
        int nObjectID = ptqrWebServices.ItemAsInt(nWebService, PT_PROPIDS.PT_PROPID_OBJECTID);
        IPTWebService ptWebService = (IPTWebService) ((IPTSession) m_asOwner.GetUserSession()).GetWebServices().Open(nObjectID,
         false);
        String strUrl = ptWebService.GetAbsoluteURL(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_URL);
        // We just want the host name, no http://, nothing afterwards
        String strHost = RemoteHostsModel.GetHostName(strUrl);
        // If this webservice comes from the current remote host, store it for display.
        if (0 == XPStringUtility.CompareIgnoreCase(strRemoteHostName, strHost))
        {
          // Look for a portlet that matches this web service
          for (int nPortlet = 0;nPortlet < ptqrPortlets.RowCount();nPortlet++)
          {
            if (nObjectID == ptqrPortlets.ItemAsInt(nPortlet, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID))
            {
              // Store the first portlet that matches
              result.PutElement(nObjectID, ptqrPortlets.ItemAsInt(nPortlet,
               PT_PROPIDS.PT_PROPID_OBJECTID));
            }
          }
        }
      }
      return result;
    }
    
    /// <summary>
    /// This method filles in the data array with String representations of
    /// int status codes, optional messages (disabled, timeout, etc..), and error
    /// messages (404, server not found, etc...).  The optional messages and
    /// error messages can be null.
    /// The 2 arrays must have the same length.
    /// </summary>
    /// <param name="_htPortletIDs">The ids of the portlets to check.</param>
    /// <param name="_oData">Filled in with int status codes, optional messages, and errors.</param>
    protected virtual void SetPortletStatus(XPArrayList _alPortletIDs, Object[][] _oData)
    {
      int[] portletIDs = new int[_alPortletIDs.GetSize()];
      for (int i = 0;i < _alPortletIDs.GetSize();i++)
      {
        portletIDs[i] = XPConvert.ToInteger(_alPortletIDs.GetElement(i));
        }
      /*
       // Set the portlet timetout to the appropriate value and cache the
       // previous value.
       int nOriginalPortletTimeout = SetPortletTimeout(nStatusTimeout);
       */
       
      // Get the temporary page used just for the diagnostic page
      // to query for the portlet content
      IPTPage diagPage = (IPTPage) ((IPTSession) m_asOwner.GetUserSession()).GetPages().Open(PT_INTRINSICS.PT_PAGE_DIAGNOSTIC,
       false);
      // Add the portlets to the page
      diagPage.AssignPortlets(portletIDs, 0);
      // Query for the page content
      // Create Application Data Object
      // 0 means not a community page
      IPTState state = AppDataObject.GetAppDataObject(0, PT_INTRINSICS.PT_PAGE_DIAGNOSTIC,
       "uri", m_asOwner, false);
      // Set the portlet timeout for this request to the longer value,
      // since the user has requested more information.
      int nStatusTimeout = RemoteHostsModel.REPEAT_TIMEOUT;
      state.Add(PlumtreeExtensibility.PT_PORTLET_TIMEOUT_KEY, nStatusTimeout,
       0, true);
      state.Add(PlumtreeExtensibility.PT_RETURN_URI_KEY, m_asOwner.GetCurrentNormalizedBaseURL(),
       0, true);
      // Use Diagnostic mode here instead of runtime or preview mode, because
      // runtime mode will get cached content if there are errors with the portlets.
      // That would mask host failures forever.  Preview mode does not use
      // the cached content if there is an error, but it does still use it normally.
      // Preview mode also ignores the portlet timeout.
      IPTMyPortalGadgetContent content = diagPage.QueryPortletContent(0, PT_INTRINSICS.PT_PAGE_DIAGNOSTIC,
       state, "", PT_GADGET_MODES.PT_GADGETMODES_DIAGNOSTIC, true);
      // Check the status of each portlet
      for (int i = 0;i < portletIDs.Length;i++)
      {
        // Initialize with null
        _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = null;
        _oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = null;
        Object[][] objArrMarkup = null;
        try
        {
          objArrMarkup = content.GetContent(i);
        }
        catch (Exception e)
        {
          if (e is PTException)
          {
            // TODO: This switch statement shouldn't be necessary, but
            // some kinds of portlets throw exceptions (gadget_runtime_error)
            // and some use the error reporting array below.
            switch (((PTException) e).GetErrorCode()){
            case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
            {
              // Portlet timed out, might just be slow
              _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
              // "Timeout"
              _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3104,
               ResourceConstants.PORTALADMINMSGS);
              break;
            }
            case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
            {
              // Portlet had a runtime error
              // This could be because the machine is down
              _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
              break;
            }
            case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
            {
              // Portlet had an HTTP error
              // This could be because the machine is down
              _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
              break;
            }
            case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
            {
              // We display disabled WebServices for info purposes.
              _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
              // "Disabled"
              _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3105,
               ResourceConstants.PORTALADMINMSGS);
              break;
            }
            default:
            {
              // Inconclusive
              _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
              break;
            }
            }
          } else
          {
            // Inconclusive
            _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
            }
          objArrMarkup = null;
        }
        if (objArrMarkup != null)
        {
          int nlength = objArrMarkup.Length;
          if (objArrMarkup.Length == PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS)
          {
            if (!GatewayUtils.IsErrorContentArray(objArrMarkup))
            {
              _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_GREEN);
              } else
            {
              int iErrorCode = GatewayUtils.GetErrorCode(objArrMarkup);
              // TODO: Do we need to check this?
              // if the response was received, need to make room in the array for response status, header, body
              //						boolean bResponseReceived = GatewayUtils.ResponseReceivedForErrors(objArrMarkup);
              switch (iErrorCode){
              case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
              {
                // Portlet timed out, might just be slow
                _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
                // "Timeout"
                _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3104,
                 ResourceConstants.PORTALADMINMSGS);
                break;
              }
              case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
              {
                // Portlet had a runtime error
                // This could be because the machine is down
                _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
                String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
                if (strStatus != null)
                {
                  // "HTTP {0} error"
                  _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = XPResourceManager.FormatMessage(m_asOwner.GetString(3106,
                   ResourceConstants.PORTALADMINMSGS), strStatus);
                }
                String strError = GatewayUtils.GetErrorMessage(objArrMarkup);
                if (null != strError)
                {
                  _oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = strError;
                  }
                break;
              }
              case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
              {
                // Portlet had an http error
                // This could be because the machine is down
                _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
                String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
                if (strStatus != null)
                {
                  // "HTTP {0} error"
                  _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = XPResourceManager.FormatMessage(m_asOwner.GetString(3106,
                   ResourceConstants.PORTALADMINMSGS), strStatus);
                }
                String strError = GatewayUtils.GetErrorMessage(objArrMarkup);
                if (null != strError)
                {
                  _oData[ServerStatusListView.SERVER_STATUS_ERROR][i] = strError;
                  }
                break;
              }
              case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
              {
                // We display disabled WebServices for info purposes.
                _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
                // "Disabled"
                _oData[ServerStatusListView.SERVER_STATUS_MSG][i] = m_asOwner.GetString(3105,
                 ResourceConstants.PORTALADMINMSGS);
                break;
              }
              default:
              {
                // Inconclusive
                _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
                break;
              }
              }
            }
          } else
          {
            // Nothing in the markup
            // TODO: what does this mean?
            _oData[ServerStatusListView.SERVER_STATUS][i] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
            }
        }
      }
    }
    /*
     // Restore the portlet timetout to the original value.
     SetPortletTimeout(nOriginalPortletTimeout);
     */
     
    
    /// <summary>
    /// Helper method that creates an HTML Anchor to a pop-up
    /// page viewing remote host details.
    /// </summary>
    /// <param name="_strName">The name of the server.</param>
    /// <returns>HTMLAnchor The HTML Anchor.</returns>
    protected virtual HTMLAnchor GetWebServiceAnchor(String _strName, int _nWebServiceID)
    {
      String strWebServiceURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_WEBSERVICE_ID,
       _nWebServiceID, IPTOpenerConstants.OPENER_MODE_EDIT, m_asOwner);
      HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("window.open(\'" + strWebServiceURL + "\',\'PopUpRemoteHostWebServices\',\'location=no,menubar=no, scrollbars=yes, height=600,width=800\'); return false;");
      myAnchor.AddInnerHTMLEncodedString(_strName);
      myAnchor.SetTitle(_strName);
      return myAnchor;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public override void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public override void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#CheckEditorAccessAndStart(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      if (!PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) m_asOwner.GetUserSession()))
      {
        return false;
      }
      if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public override void Finish()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(java.lang.String,com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public override void Init(AActivitySpace _parent)
    {
      // Set to read only so we only get finish button
      m_bIsEditorReadOnly = true;
      base.Init(_parent);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new HostServicesModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}