using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist;
using com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist
{
  /// <summary>
  /// This view displays a generic server status list.
  /// </summary>
  /// <author>DonH</author>
  public class ServerStatusListView : MultiColumnListView
  {
    private const String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist.ServerStatusListView";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
     sClassName);
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ServerStatusList";
    
    /// <summary>
    /// The type column ID.  This usually contains
    /// a String representatio of an int that is
    /// different for every server type so that you
    /// can sort by server type.  The actual value
    /// is not used in this View.
    /// </summary>
    public const int SERVER_TYPE = 0;
    
    /// <summary>
    /// The name column ID.
    /// </summary>
    public const int SERVER_NAME = 1;
    
    /// <summary>
    /// The status column ID.
    /// </summary>
    public const int SERVER_STATUS = 2;
    
    /// <summary>
    /// The server icon column ID.  This is a
    /// PTImageType object, and is not sortable.
    /// </summary>
    public const int SERVER_ICON = 3;
    
    /// <summary>
    /// The server url ID.  This is an HTMLAnchor
    /// that includes the server name already.
    /// This may be null.
    /// </summary>
    public const int SERVER_ANCHOR = 4;
    
    /// <summary>
    /// The server description ID.  This does not
    /// have it's own visible column.
    /// This may be null.
    /// </summary>
    public const int SERVER_DESCRIPTION = 5;
    
    /// <summary>
    /// The server description ID.  This does not
    /// have it's own visible column.
    /// This may be null.
    /// </summary>
    public const int SERVER_STATUS_MSG = 6;
    
    /// <summary>
    /// The server status error ID.  This does not
    /// have it's own visible column.
    /// This may be null.
    /// </summary>
    public const int SERVER_STATUS_ERROR = 7;
    
    /// <summary>
    /// The number of columns.
    /// </summary>
    public const int NUM_COLS = 8;
    // Server status codes
    public const int STATUS_GREEN = 1;
    public const int STATUS_YELLOW = 2;
    public const int STATUS_RED = 3;
    public const int MAX_ERROR_CHARS = 60;
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex. Each row contains just an icon
    /// and input text for each column.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      SortedMetaDataListModel model = (SortedMetaDataListModel) m_model;
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      // Iterate through columns - this is not zero based
      for (int i = 1;i <= model.GetNumVisibleColumns();i++)
      {
        myCell = new HTMLTableCell();
        myCell.SetWidth(model.GetColumnWidth(i));
        myCell.SetHeight("30");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.SetNoWrap(true);
        if (i == (SERVER_NAME + 1))
        {
          // We want to allow long names and descriptions to wrap.
          myCell.SetNoWrap(false);
        }
        myCell.AddInnerHTMLElement(GetColumnHTML(i, _nRowIndex, _saData, model));
        result.AddInnerHTMLElement(myCell);
      }
      // input text
      return result;
    }
    
    /// <summary>
    /// This helper method takes the row meta data and outputs
    /// the proper HTML for the column entry.
    /// </summary>
    /// <param name="_nVisibleColumnIndex"></param>
    /// <param name="_nRowIndex"></param>
    /// <param name="_saData"></param>
    /// <param name="_model"></param>
    /// <returns>The HTML for the column entry.</returns>
    protected virtual HTMLElement GetColumnHTML(int _nVisibleColumnIndex,
     int _nRowIndex, IPTGrowableSortedArrayWrapperRO _saData, SortedMetaDataListModel _model)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      int nDataColumnIndex = _nVisibleColumnIndex - 1;
      switch (nDataColumnIndex){
      case SERVER_TYPE:
      // The visible index stores the type integer for sorting.  We want the icon
      // Icon index is zero based, data index is not
      PTImageType icon = (PTImageType) _saData.GetItem(_nRowIndex, SERVER_ICON + 1);
      result.AddInnerHTMLElement(GetHTMLForIcon(icon));
      break;
      case SERVER_NAME:
      HTMLSpan mySpan = new HTMLSpan();
      result.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
      HTMLAnchor nameAnchor = (HTMLAnchor) _saData.GetItem(_nRowIndex, SERVER_ANCHOR + 1);
      if (null != nameAnchor)
      {
        mySpan.AddInnerHTMLElement(nameAnchor);
      } else
      {
        String strName = (String) _saData.GetItem(_nRowIndex, nDataColumnIndex + 1);
        mySpan.AddInnerHTMLEncodedString(strName);
      }
      String strDescription = (String) _saData.GetItem(_nRowIndex, SERVER_DESCRIPTION + 1);
      if (strDescription != null)
      {
        result.AddInnerHTMLElement(new HTMLBr());
        mySpan = new HTMLSpan();
        result.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
        mySpan.AddInnerHTMLEncodedString(strDescription);
      }
      String strStatusError = (String) _saData.GetItem(_nRowIndex, SERVER_STATUS_ERROR + 1);
      if (strStatusError != null)
      {
        result.AddInnerHTMLElement(new HTMLBr());
        mySpan = new HTMLSpan();
        result.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
        // Since the error messages are often quite long, we need to
        // break them down so the display looks okay. 
        mySpan.AddInnerHTMLEncodedString(GeneralHelpers.BreakDownLongWordsInString(strStatusError,
         MAX_ERROR_CHARS));
      }
      break;
      case SERVER_STATUS:
      int nStatusCode = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, nDataColumnIndex + 1));
      String strStatusMessage = (String) _saData.GetItem(_nRowIndex, SERVER_STATUS_MSG + 1);
      PTImageType statusLight = null;
      switch (nStatusCode){
      case STATUS_GREEN:
      statusLight = PTImageType.ACTION_APPROVE;
      break;
      case STATUS_YELLOW:
      statusLight = PTImageType.ICON_HOLD;
      break;
      case STATUS_RED:
      statusLight = PTImageType.ACTION_UNAPPROVE;
      break;
      default:
      log.Warn("Invalid server status " + nStatusCode);
      break;
      }
      if (null != statusLight)
      {
        result.AddInnerHTMLElement(GetHTMLForIcon(statusLight));
        if (null != strStatusMessage)
        {
          // Disabled, timeout, etc...
          result.AddInnerHTMLString(strStatusMessage);
        }
      }
      break;
      default:
      break;
      }
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the delete cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected override HTMLTableCell GetHTMLForDeleteAction()
    {
      // To make sure the delete html doesn't get added.
      return new HTMLTableCell();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ServerStatusListView();
    }
  }
}