using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.ptutilities.automationserver;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.jobfolders
{
  /// <author>SudhaS</author>
  public class JobFoldersModel : EditorModel,IJobFoldersModelRO
  {
    public const String STR_MVC_CLASS_NAME = "JobFoldersModel";
    protected String m_sSetting1;
    protected String m_sSetting2;
    protected String m_strDescription = "";
    protected String m_strServerName = "";
    protected String m_strURI = "";
    protected int m_nActivityID = -1;
    
    /// <summary>
    /// Code executed when the Editor is starting.
    /// </summary>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      String[] data;
      if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      data = (String[]) _htFormData.GetElement(AutomationServerListModel.SERVER_NAME);
      if (data != null)
      {
        m_strServerName = data[0];
      }
      StartJobFoldersList();
      StartGetFolderJobs();
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobFoldersModel();
    }
    public override void Finish()
    {
      PTGrowableSortedArrayWrapper aJobFoldersObjectValues = ((JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME)).GetItems();
      //IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      //IPTScheduler ptScheduler = ptSession.GetScheduler();
      //IPTQueryResult ptqrJobHistoriesByFolder;
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTScheduler ptScheduler = ptSession.GetScheduler();
      for (int i = 0;i < aJobFoldersObjectValues.GetCount();i++)
      {
        int n_FolderID = XPConvert.ToInteger(aJobFoldersObjectValues.GetItem(i,
         JobFoldersListModel.EXPLIST_COL_OBJECTID));
        ptScheduler.AssignJobFolder(m_strServerName, n_FolderID);
      }
      int[] aRowsToDelete = ((JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME)).GetRowsToDelete();
      if (aRowsToDelete != null)
      {
        for (int i = 0;i < aRowsToDelete.Length;i++)
        {
          ptScheduler.UnassignJobFolder(m_strServerName, aRowsToDelete[i]);
          }
      }
    }
    //ResetInputs();
    
    /// <returns></returns>
    public virtual String GetActivityDescription()
    {
      return m_strDescription;
    }
    
    /// <returns></returns>
    public virtual int GetActivityID()
    {
      return m_nActivityID;
    }
    
    /// <returns></returns>
    public virtual String GetActivityURI()
    {
      return m_strURI;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual String GetServerName()
    {
      return m_strServerName;
    }
    public virtual void ResetInputs()
    {
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SaveMainPage(XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(AutomationServerListModel.SERVER_NAME);
      if (data != null)
      {
        m_strServerName = data[0];
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual void StartGetFolderJobs()
    {
      JobFoldersListModel myJobFoldersObjectModel = (JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME);
      myJobFoldersObjectModel.SetEnableMoveRowActions(false);
      //IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      //IPTScheduler ptScheduler = ptSession.GetScheduler();
      //IPTQueryResult ptqrJobHistoriesByFolder;
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTScheduler ptScheduler = ptSession.GetScheduler();
      IPTAdminCatalog ptCatalog = ptSession.GetAdminCatalog();
      IPTQueryResult ptqrJobFolders = ptScheduler.QueryJobAssignmentsByServer(m_strServerName);
      /* get the indices of folder ids that this user can access */
      XPArrayList indices = new XPArrayList(ptqrJobFolders.RowCount());
      for (int i = 0;i < ptqrJobFolders.RowCount();i++)
      {
        int id = ptqrJobFolders.ItemAsInt(i, PT_PROPIDS.PT_PROPID_FOLDERID);
        if (ptCatalog.IsAdminFolderAccessible(id, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
        {
          indices.Add(i);
        }
      }
      /* now create rows for each folder */
      Object[][] oRows = new Object[indices.GetSize()][];
      for (int j2c_index = 0;j2c_index < indices.GetSize();j2c_index++)
      {
        oRows[j2c_index] = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
        }
      for (int i = 0;i < indices.GetSize();i++)
      {
        int queryIdx = XPConvert.ToInteger(indices.GetElement(i));
        oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = myJobFoldersObjectModel.m_nNextIndex;
        myJobFoldersObjectModel.m_nNextIndex++;
        oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
        oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = ptqrJobFolders.ItemAsInt(queryIdx,
         PT_PROPIDS.PT_PROPID_FOLDERID);
        oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] = ptqrJobFolders.ItemAsString(queryIdx,
         PT_PROPIDS.PT_PROPID_NAME);
      }
      myJobFoldersObjectModel.SetDefaultObjects(oRows);
    }
    
    /// <summary>
    /// Helper method to start the Select PTObject List.
    /// </summary>
    public virtual void StartJobFoldersList()
    {
      JobFoldersListModel myJobFoldersObjectModel = (JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME);
      // ***CHANGE_HERE SELECTPTOBJECT*** Initialize the Select PTObject list.
      //      _sSectionTitle: Main title.
      //      _sSectionSubTitle: Sub title.
      //      _imgAddIcon: Icon for the add action.
      //      _sAddLabel: Text to display next to the add icon.
      //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
      //      _nListKey: In case you have multiple Expandable Lists on
      //                 the same DP, they should have a different key
      //                 (otherwise, just set it to 1).
      myJobFoldersObjectModel.InitializeSelectPTObject(m_strServerName, m_asOwner.GetString(1507,
       "ptmsgs_portaladminmsgs"), PTImageType.ICON_FOLDER, m_asOwner.GetString(1508,
       "ptmsgs_portaladminmsgs"), new int[]{PT_CLASSIDS.PT_ADMIN_FOLDER_ID},
       2);
      myJobFoldersObjectModel.SetTreeTitle(m_asOwner.GetString(2102, "ptmsgs_portaladminmsgs"));
      myJobFoldersObjectModel.SetTreeSubTitle(m_asOwner.GetString(2102, "ptmsgs_portaladminmsgs"));
      myJobFoldersObjectModel.SetTreeLeafType(TreeConstants.N_COMPOSITESELECT);
      // ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
      //     Use the method bellow to set the icon to display on each row.
      //     (By default there will be no icon.)
      myJobFoldersObjectModel.SetDefaultRowIcon(PTImageType.ICON_JOB);
      myJobFoldersObjectModel.SetEmptyListMessages(m_asOwner.GetString(1509,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1510, "ptmsgs_portaladminmsgs"));
      }
  }
}
// JF- The 2 lines below are only needed if you are going to enable the move row actions
/*
 if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE) {
 oRows = new Object[1][mySelectPTObjectModel.EXPLIST_COL_MAX];
 oRows[0][mySelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer( mySelectPTObjectModel.m_nNextIndex );
 mySelectPTObjectModel.m_nNextIndex ++;
 oRows[0][mySelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_USERGROUP_ID);
 oRows[0][mySelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(PT_INTRINSICS.PT_USERGROUP_EVERYONE);
 oRows[0][mySelectPTObjectModel.EXPLIST_COL_STRING] = new String("Everyone");
 } else if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT) {
 */
 
//}
