using System;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.ptutilities.localizedstrings
{
  /// <author>MichaelS</author>
  public class LocalizedStringsAS : PTEditorAS
  {
    
    /// <summary>
    /// AS name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LocalizedStrings";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LocalizedStringsAS();
    }
    
    /// <summary>
    /// Returns the Editor main title.
    /// It will get printed out in EditorHeaderView.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return GetString(1511, "ptmsgs_portaladminmsgs");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the name of the repost control class.
    /// E.g.: PropRepostControl.GetName()
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return LocalizedStringsControl.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      m_strModelName = LocalizedStringsModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(LocalizedStringsModel.STR_MVC_CLASS_NAME);
      // LocalizedStrings Display Page
      LocalizedStringsDP myPage = new LocalizedStringsDP();
      RegisterPage(myPage);
      //MES- Set multipart encoding so that file uploads work correctly
      myPage.SetMultiPartEncoding(true);
      // LocalizedStringsDownload Display Page
      LocalizedStringsDownloadDP myDownloadPage = new LocalizedStringsDownloadDP();
      RegisterPage(myDownloadPage);
      // LocalizedStrings Control
      RegisterControl(LocalizedStringsControl.STR_MVC_CLASS_NAME, myModel);
      // LocalizedStrings Views
      RegisterView(LocalizedStringsView.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(LocalizedStringsDP.STR_MVC_CLASS_NAME);
      // Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1535, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, LocalizedStringsDP.STR_MVC_CLASS_NAME);
      }
    // END Sub menu "General Settings"
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (LocalizedStringsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_LocalizationManager");
      }
    }
  }
}