using System;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.localizedstrings
{
  /// <summary>
  /// Display Pages aggregate Views and put them into an HTMLPage. They are owned
  /// by Activity Spaces and represent a view into an MVC framework. Display Pages
  /// are allowed to get and set data on the Models, if necessary. Display Pages
  /// are viewed as an extension of Activity Spaces, and therefore are not subject
  /// to the strict data/logic/presentation separation that MVC components are.
  /// </summary>
  /// <author>Don Hayler </author>
  public class LocalizedStringsDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "LocalizedStrings";
    
    /// <summary>
    /// MES- See
    /// com.plumtree.uiinfrastructure.editor.EditorDP.GetLeftNavString
    /// </summary>
    /// <returns></returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(1515, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1654, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#PageDisplay()"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      //MES- Add the LocalizedStringsView
      views.AddInnerHTMLElement(m_asOwner.GetView(LocalizedStringsView.STR_MVC_CLASS_NAME).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) + "opennewwindow.js");
      myScripts.AddInnerHTMLElement(script);
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(LocalizedStringsView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
  }
}