using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.xml.dom;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.ptutilities.localizedstrings
{
  /// <author>
  /// MichaelS
  /// MES- This display page returns the complete set of localized strings for a Portal.
  /// It returns the strings as XML, rather than HTML, for easy processing by the user (e.g.
  /// the user may send the XML file to a translation service.)  Note that this page returns
  /// NO HTML, it ONLY returns XML.
  /// </author>
  public class LocalizedStringsDownloadDP : IDisplayPage
  {
    public const String STR_MVC_CLASS_NAME = "LocalizedStringsDownload";
    /*MES- The following variables define elements in the XML we will return */
    public const String LOC_XML_ROOT_NODE = "localizationtable";
    public const String LOC_XML_LANGS_NODE = "languages";
    public const String LOC_XML_SEGMENTS_NODE = "segments";
    public const String LOC_XML_COUNT_ATT = "count";
    public const String LOC_XML_LANG_NODE = "language";
    public const String LOC_XML_SEGMENT_NODE = "segment";
    public const String LOC_XML_CLASSID_ATT = "classid";
    public const String LOC_XML_ITEMID_ATT = "itemid";
    public const String LOC_XML_STRINGID_ATT = "stringid";
    public const String LOC_XML_SOURCE_NODE = "source";
    public const String LOC_XML_TARGET_NODE = "target";
    public const String LOC_XML_LANG_ATT = "language";
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Construct the HTMLPage for Display.
    /// </summary>
    /// <param name="IWebData">The HTMLPage for display to the browser should be set on this object.</param>
    public virtual void Display(IWebData webData)
    {
      //MES- Get the data from the model
      ILocalizedStringsModelRO model = (ILocalizedStringsModelRO) m_asOwner.GetModel(LocalizedStringsModel.STR_MVC_CLASS_NAME);
      Object objData = model.GetData();
      String[] arrLangs = model.GetLangs();
      //MES- Convert the data to XML and put into the output
      webData.SetData(ConvertDataToXML(arrLangs, objData));
      //MES- Tell the browser that we're returning XML.
      //MES- TODO: Are these strings available in a centralized place?
      webData.SetHeader("Content-Type", "text/xml; charset=UTF-8");
      webData.SetHeader("Content-Disposition", "attachment; filename=LocalizedStrings.xml;");
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetParent()"></seealso>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <summary>
    /// MES- ConvertDataToXML takes in an array of languages and a
    /// 2D array of localized strings (as returned by the IPTStringLocalizationManager
    /// interface), and turns it into an XML string, encoded as UTF8.
    /// </summary>
    /// <param name="arrLangs">is a 1D String array of the languages we support</param>
    /// <param name="objData">
    /// is a 2D Object array (or null) containing the localized
    /// strings
    /// </param>
    /// <returns>a byte[] containing the relevant XML encoded as UTF8.</returns>
    private byte[] ConvertDataToXML(String[] arrLangs, Object objData)
    {
      //MES- Make a new document
      XPDocument docXML = new XPDocument();
      //MES- Add a root node, from which we'll hang other nodes
      XPElement elemRoot = docXML.CreateElement(LOC_XML_ROOT_NODE);
      docXML.AppendChild(elemRoot);
      //MES- Add two nodes to root- one for our list of languages, and
      //	one for the list of localized strings.  The list of languages
      //	is a convenience to the code that needs to parse this XML- 
      //	it doesn't have to look through all of the string localizations
      //	to get the complete list of supported languages
      XPElement elemLangs = docXML.CreateElement(LOC_XML_LANGS_NODE);
      XPElement elemStrings = docXML.CreateElement(LOC_XML_SEGMENTS_NODE);
      elemRoot.AppendChild(elemLangs);
      elemRoot.AppendChild(elemStrings);
      //MES- Add the count of languages, for convenience
      elemLangs.SetAttribute(LOC_XML_COUNT_ATT, XPConvert.ToString(arrLangs.Length));
      //MES- Add all of the languages 
      for (int iLangIndex = 0;iLangIndex < arrLangs.Length;iLangIndex++)
      {
        XPElement elemLang = docXML.CreateElement(LOC_XML_LANG_NODE);
        elemLangs.AppendChild(elemLang);
        XPText textLang = docXML.CreateTextNode(arrLangs[iLangIndex]);
        elemLang.AppendChild(textLang);
      }
      //MES- Is there any data?
      if (null != objData)
      {
        Object[][] arrData = (Object[][]) objData;
        int iNumCols = arrData.Length;
        int iNumRows = arrData[0].Length;
        //MES- Add the count of strings, for convenience
        elemStrings.SetAttribute(LOC_XML_COUNT_ATT, XPConvert.ToString(iNumRows));
        //MES- Add each string
        for (int iRowIndex = 0;iRowIndex < iNumRows;++iRowIndex)
        {
          //MES- Make a node for the string, and add the identifying info
          XPElement elemString = docXML.CreateElement(LOC_XML_SEGMENT_NODE);
          elemStrings.AppendChild(elemString);
          elemString.SetAttribute(LOC_XML_CLASSID_ATT, XPConvert.ToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_CLASSID][iRowIndex]));
          elemString.SetAttribute(LOC_XML_ITEMID_ATT, XPConvert.ToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_ITEMID][iRowIndex]));
          elemString.SetAttribute(LOC_XML_STRINGID_ATT, XPConvert.ToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_STRINGID][iRowIndex]));
          //MES- Add a child node for the "source" or primary translation
          XPElement elemSourceString = docXML.CreateElement(LOC_XML_SOURCE_NODE);
          elemString.AppendChild(elemSourceString);
          // TODO CR: Do we need ObToString? Also I removed the .toString() after the arrData array access, since it seems this is redundant.
          String sLang = ObToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_SOURCE_LANG][iRowIndex]);
          elemSourceString.SetAttribute(LOC_XML_LANG_ATT, sLang);
          String sValue = ObToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_SOURCE_STRING][iRowIndex]);
          XPText textPrimaryString = docXML.CreateTextNode(sValue);
          elemSourceString.AppendChild(textPrimaryString);
          //MES- Add a node for each possible localization
          for (int iColIndex = PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_TARGET_STRING_START;
          iColIndex < iNumCols;++iColIndex)
          {
            XPElement elemLocalization = docXML.CreateElement(LOC_XML_TARGET_NODE);
            elemString.AppendChild(elemLocalization);
            elemLocalization.SetAttribute(LOC_XML_LANG_ATT, arrLangs[iColIndex - PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_TARGET_STRING_START]);
            //MES- The value is "" if it's not translated to that language,
            //	or the string in that language if it is translated.
            String sLocalizedString = ObToString(arrData[iColIndex][iRowIndex]);
            XPText textString = docXML.CreateTextNode(sLocalizedString);
            elemLocalization.AppendChild(textString);
          }
        }
      } else
      {
        elemStrings.SetAttribute("count", "0");
      }
      return XPBuilder.GetDocumentAsByteArray(docXML, "UTF-8");
    }
    
    /// <summary>
    /// MES- ObToString is an internal helper function that converts an
    /// Object to a String.  It just calls toString, except in the case
    /// of NULL objects, where it returns the blank string
    /// </summary>
    /// <param name="ob">the object to be converted to a string</param>
    /// <returns>
    /// the object converted to a String, or the blank string for
    /// null objects
    /// </returns>
    private String ObToString(Object ob)
    {
      if (null == ob)
      {
        return "";
      } else
      {
        return ob.ToString();
      }
    }
  }
}