using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.ptutilities.localizedstrings
{
  /// <author>MichaelS</author>
  public class LocalizedStringsModel : EditorModel,ILocalizedStringsModelRO,
  ILocalizedStringsModel
  {
    //, IRepostModel
    public const String STR_MVC_CLASS_NAME = "LocalizedStrings";
    public IPTSession m_ptSession;
    private String m_sLastUploadMessage = "";
    private String[] m_arrLangsToLocalizeTo = null;
    private Object[][] m_arrLocalizedStringsArray = null;
    private bool m_bDataUploaded = false;
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// Use the Editor Type if needed.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      //MES- Nothing to do here
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LocalizedStringsModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      //MES- If data was uploaded, save it
      if (m_bDataUploaded && (null != m_arrLocalizedStringsArray) && (null != m_arrLangsToLocalizeTo))
      {
        IPTStringLocalizationManager mgr = (IPTStringLocalizationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_STRING_LOCALIZATION_MANAGER,
         false);
        mgr.SetLocalizedStrings(m_arrLangsToLocalizeTo, m_arrLocalizedStringsArray);
        }
    }
    
    /// <seealso cref="ILocalizedStringsModelRO#getData()"></seealso>
    public virtual Object[][] GetData()
    {
      // Methods like this are where you return data to your Section to be displayed.
      //MES- Cache the data if we haven't already
      if (null == m_arrLocalizedStringsArray)
      {
        IPTStringLocalizationManager mgr = (IPTStringLocalizationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_STRING_LOCALIZATION_MANAGER,
         false);
        m_arrLangsToLocalizeTo = m_asOwner.GetResourceManager().GetSupportedLanguages();
        m_arrLocalizedStringsArray = (Object[][]) mgr.GetLocalizedStrings(m_arrLangsToLocalizeTo);
        }
      return m_arrLocalizedStringsArray;
    }
    
    /// <seealso cref="ILocalizedStringsModelRO#getLangs()"></seealso>
    public virtual String[] GetLangs()
    {
      //MES- Cache the langs and data by calling getData
      GetData();
      //MES- And return the langs
      return m_arrLangsToLocalizeTo;
    }
    
    /// <summary>
    /// MES- GetLastUploadMessage returns a string describing the last upload,
    /// or the zero length string if there has been no upload
    /// </summary>
    /// <param name="none"></param>
    /// <returns>void</returns>
    public virtual String GetLastUploadMessage()
    {
      return m_sLastUploadMessage;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    //MES- Stuff for IRepostModel
    
    /// <summary>
    /// Inits the Model with the Activity Space.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_ptSession = (IPTSession) parent.GetUserSession();
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      //MES- We don't have pages, so we don't do anything
      return LocalizedStringsControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// MES- setData sets the array of localized strings
    /// </summary>
    /// <param name="arrLocalizedStrings">
    /// is a 2D array of localized strings, as
    /// required by IPTStringLocalizationManager::SetLocalizedStrings
    /// </param>
    /// <returns>void</returns>
    public virtual void SetData(Object[][] arrLocalizedStrings)
    {
      // Methods like this are how your Controls perform actions on your Models.
      m_arrLocalizedStringsArray = arrLocalizedStrings;
      m_bDataUploaded = true;
    }
    
    /// <summary>
    /// MES- setLangs sets the array of languages associated with m_arrLocalized
    /// StringsArray.  Each column in m_arrLocalizedStringsArray is represented by an
    /// item in arrLangs.
    /// </summary>
    /// <param name="arrLangs">is a 1D array of language identifiers (e.g. "en" or "en-us".)</param>
    /// <returns>void</returns>
    public virtual void SetLangs(String[] arrLangs)
    {
      m_arrLangsToLocalizeTo = arrLangs;
      m_bDataUploaded = true;
    }
    
    /// <summary>
    /// MES- SetUploadMessage sets a message that describes the most recent upload- success or failure
    /// </summary>
    /// <param name="sMessage">is the message</param>
    /// <returns>void</returns>
    public virtual void SetUploadMessage(String sMessage)
    {
      m_sLastUploadMessage = sMessage;
    }
    
    /// <seealso cref="ILocalizedStringsModelRO#userCanLocalize()"></seealso>
    public virtual bool UserCanLocalize()
    {
      //MES- Try to get the Localization Manager.  If we can get it, we can localize, but
      //	if we can't get it (presumably for security reasons), then we can't localize
      try
      {
        m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_STRING_LOCALIZATION_MANAGER,
         false);
        //MES- If we got here, we're cool
        return true;
      }
      catch (Exception e)
      {
        //MES- If we got here, we're NOT cool
        return false;
      }
    }
  }
}