using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.localizedstrings
{
  /// <author>
  /// Don Hayler
  /// Views are responsible for generating HTML in the MVC framework.  They query their
  /// model for data and build HTML from it.  The links and forms in that HTML should be
  /// constructed so the Interpreter can use the controls to process events.
  /// Views should encapsulate the presentation of the AActivitySpace.  As an MVC component,
  /// Views are subject to the strict separation between data, logic, and presentation.
  /// It is a requirement that Views not contain any server code other than constants
  /// (i.e. PT_PROPIDS.PT_PROPID_NAME).  IPTQueryResults should not be used in Views,
  /// rather, Models should provide accesor methods for them.
  /// It is also a requirement that Views not depend on Models for HTML.  Views can use
  /// helper classes (Strategies, delegation, etc...) to generate HTML, but Views should
  /// never expect a model to return an HTMLElement or HTMLConstruct to them.  Models can
  /// return text Strings for display in HTMLElements.
  /// Obviously, there should be a good way to refer to views without having to
  /// manually type in a text string.  There should be some sort of package identifier
  /// used to get these.
  /// </author>
  public class LocalizedStringsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.localizedstrings.LocalizedStringsView");
    public const String STR_MVC_CLASS_NAME = "LocalizedStrings";
    public const String STR_FILE_UPLOAD_CONTROL = "in_fi_FileName";
    private const String JS_UPLOAD_FUNC_NAME = "UploadLocalizedStrings";
    private AActivitySpace m_asOwner;
    private ILocalizedStringsModelRO m_asmModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LocalizedStringsView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      //MES- Does this user have the rights to localize strings?
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display LocalizedStringsView");
        result.AddInnerHTMLElement(myComment);
        // Header
        myComment = new HTMLComment("Begin: Display Category header");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(GetHeaderView(m_asOwner.GetString(1519,
         "ptmsgs_portaladminmsgs")));
        myComment = new HTMLComment("End: Display Category header");
        result.AddInnerHTMLElement(myComment);
        if (m_asmModel.UserCanLocalize())
        {
          //MES- This user CAN localize, show full UI
          //MES- Display an URL through which they can download the XML representation of the strings
          myTable = new HTMLTable();
          result.AddInnerHTMLElement(myTable);
          myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          myTable.SetCellPadding(CommonHTMLStrings.FIVE);
          myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
          //First row - downloading
          myRow = new HTMLTableRow();
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myTable.AddInnerHTMLElement(myRow);
          //First cell - the text
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell.SetWidth("30%");
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asOwner.GetString(1518, "ptmsgs_portaladminmsgs"));
          //Second cell - the button
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myInput = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_Download",
           m_asOwner.GetString(2181, "ptmsgs_portaladminmsgs"));
          myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          myInput.SetValue(m_asOwner.GetString(2181, "ptmsgs_portaladminmsgs"));
          myCell.AddInnerHTMLElement(myInput);
          ASURL urlDownload = new ASURL(m_asOwner);
          urlDownload.SetLinkGetCachedSpace(m_asOwner);
          urlDownload.SetDisplayPage(LocalizedStringsDownloadDP.STR_MVC_CLASS_NAME);
          urlDownload.SetControl(LocalizedStringsControl.STR_MVC_CLASS_NAME);
          myInput.SetOnClick("window.location = \'" + urlDownload.GetURLAsString() + "\'; return false;");
          //Second row - downloading
          myRow = new HTMLTableRow();
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myTable.AddInnerHTMLElement(myRow);
          //First cell - the text
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asOwner.GetString(1520, "ptmsgs_portaladminmsgs"));
          //Second cell - the input
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myRow.AddInnerHTMLElement(myCell);
          HTMLInput fileInput = new HTMLInput(HTMLInputTypes.FILE, STR_FILE_UPLOAD_CONTROL,
           "");
          fileInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
          myCell.AddInnerHTMLElement(fileInput);
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
          myInput = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_Done", "");
          myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          myInput.SetValue(m_asOwner.GetString(1521, "ptmsgs_portaladminmsgs"));
          myInput.SetOnClick(JS_UPLOAD_FUNC_NAME + "();");
          myCell.AddInnerHTMLElement(myInput);
          myRow = new HTMLTableRow();
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
          myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell.SetColSpan("2");
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(m_asmModel.GetLastUploadMessage());
        } else
        {
          //MES- This user does NOT have rights to localize strings- return an informative
          //	message
          result.AddInnerHTMLElement(new HTMLGenericElement(m_asOwner.GetString(1516,
           "ptmsgs_portaladminmsgs")));
        }
        result.AddInnerHTMLElement(new HTMLBr());
        myComment = new HTMLComment("End: Display LocalizedStringsView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        log.Error(e, "ExpListView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1517, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        sb = new XPStringBuilder(200);
        sb.Append("\nfunction " + JS_UPLOAD_FUNC_NAME + "()\n");
        sb.Append("{\n");
        sb.Append("    if (\"\" == document." + EditorDP.HTMLFORM_NAME + "." + STR_FILE_UPLOAD_CONTROL + ".value)\n");
        sb.Append("    {\n");
        //Enter a file name to upload
        sb.Append("        alert(\"" + m_asOwner.GetString(2520, "ptmsgs_portaladminmsgs") + "\");\n");
        sb.Append("        return false;\n");
        sb.Append("    }\n");
        sb.Append("    return postToSelf(\'" + LocalizedStringsControl.POSTTOSELF_ACTION_UPLOAD_LOCALIZED + "\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "LocalizedStringsView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      // need to initialize the parent owner so that the general
      // framework methods will have valid owner to work with.
      base.Init(model, parent);
      m_asmModel = (ILocalizedStringsModelRO) model;
      m_asOwner = parent;
    }
  }
}