using System;
using com.plumtree.openfoundation.io;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openkernel.exceptions;
using com.plumtree.openkernel.http;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tempfile;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility
{
  /// <author>jennifersu</author>
  public class MigrationLoadPackageModel : EditorModel,IMigrationLoadPackageModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationLoadPackageModel");
    public const String STR_MVC_CLASS_NAME = "MigrationLoadPackageModel";
    
    /// <summary>
    /// Storage key for MigrationLoadPackageModel 
    /// </summary>
    public const String strStorageLoadPackage = "STOR_LoadPackage";
    public const String PACKAGE_NAME = "Package_Name";
    public const String PACKAGE_DESCRIPTION = "Package_Description";
    public const String PUBLISHER_NAME = "Publisher_Name";
    
    /// <summary>
    /// The number of minutes we want our temp file to stick around.
    /// </summary>
    private static int TEMPFILE_MINUTES = 20;
    
    /// <summary>
    /// The filename (path) of the currently loaded package.
    /// </summary>
    protected String m_strPackagePath;
    
    /// <summary>
    /// The filename without the path of the currently loaded package.
    /// </summary>
    private String m_strFileName;
    
    /// <summary>
    /// Whether the package was loaded from a web location
    /// </summary>
    private bool m_bPackageIsWebLocation;
    
    /// <summary>
    /// If the package was loaded from a web location, the URL.
    /// </summary>
    private String m_strWebPath;
    
    /// <summary>
    /// Whether to pass basic auth credentials to retrieve package from URL.
    /// </summary>
    private bool m_bBasicAuth;
    
    /// <summary>
    /// Basic Auth username
    /// </summary>
    private String m_strUsername;
    
    /// <summary>
    /// Basic Auth password
    /// </summary>
    private String m_strPassword;
    
    /// <summary>
    /// True if a package has been successfully loaded
    /// </summary>
    private bool m_bPackageLoaded;
    
    /// <summary>
    /// Main model for the activity space (import or export)
    /// </summary>
    private MigrationUtilityModel m_mainModel;
    
    /// <summary>
    /// Empties all of our members and sets our package data to null.
    /// </summary>
    protected virtual void ClearPackage()
    {
      m_strPackagePath = "";
      m_strFileName = null;
      m_bPackageIsWebLocation = false;
      m_strWebPath = "";
      m_bBasicAuth = false;
      m_strUsername = "";
      m_strPassword = "";
      m_bPackageLoaded = false;
      m_mainModel.ResetMigrationManager();
    }
    
    /// <summary>
    /// Inits member variables
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_bBasicAuth = false;
      m_strUsername = "";
      m_strPassword = "";
      m_bPackageIsWebLocation = false;
      m_strFileName = "";
      m_strPackagePath = "";
      m_strWebPath = "";
      m_mainModel = (MigrationUtilityModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      m_bPackageLoaded = false;
    }
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationLoadPackageModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()"></seealso>
    public override void DoTaskBeforeStore()
    {
      base.DoTaskBeforeStore();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      return nPageStatus;
    }
    
    /// <param name="xpRUpload"></param>
    /// <param name="_htFormData"></param>
    public virtual void LoadPackage(XPHashtable _htFormData)
    {
      ClearPackage();
      // Create a temp directory to hold the new package data.
      XPFile xpfImport = new XPFile(TempFile.CreateTempFile("odimport", "importpackage",
       ".pte", TEMPFILE_MINUTES));
      // Determine if we are loading from URL or UNC path
      String[] data;
      data = (String[]) _htFormData.GetElement(MigrationLoadPackageView.HTMLRADIO_PACKAGE_TYPE);
      if ((null == data) || (0 == data.Length) || (null == data[0]))
      {
        log.Error(STR_MVC_CLASS_NAME + "::LoadPackage The package type is invalid: " + data);
        throw new XPException("blahblah");
      }
      if (data[0].Equals("web"))
      {
        m_bPackageIsWebLocation = true;
      } else
      {
        m_bPackageIsWebLocation = false;
      }
      if (!m_bPackageIsWebLocation)
      {
        LoadPackageFromFile(xpfImport);
      } else
      {
        // Extract URL and basic auth info before attempting to load package.
        data = (String[]) _htFormData.GetElement(MigrationLoadPackageView.HTMLTEXT_PACKAGE_WEB);
        if ((null == data) || (0 == data.Length) || (null == data[0]))
        {
          log.Error(STR_MVC_CLASS_NAME + "::LoadPackage The package URL is invalid: " + data);
          throw new XPException(STR_MVC_CLASS_NAME + "::LoadPackage The package URL is invalid: " + data);
          }
        m_strWebPath = data[0];
        log.Info("Retrieving migration package from: " + m_strWebPath);
        data = (String[]) _htFormData.GetElement(MigrationLoadPackageView.HTMLCHECKBOX_BASICAUTH);
        if ((null == data) || (0 == data.Length) || (null == data[0]))
        {
          m_bBasicAuth = false;
        } else
        {
          m_bBasicAuth = true;
        }
        if (m_bBasicAuth)
        {
          data = (String[]) _htFormData.GetElement(MigrationLoadPackageView.HTMLINPUT_USERNAME);
          if ((null == data) || (0 == data.Length) || (null == data[0]))
          {
            log.Error(STR_MVC_CLASS_NAME + "::LoadPackage The basic authusername is invalid: " + data);
            throw new XPException("blahblah");
          }
          m_strUsername = data[0];
          data = (String[]) _htFormData.GetElement(MigrationLoadPackageView.HTMLINPUT_PASSWORD);
          if ((null == data) || (0 == data.Length) || (null == data[0]))
          {
            log.Error(STR_MVC_CLASS_NAME + "::LoadPackage The basic password is invalid: " + data);
            throw new XPException("blahblah");
          }
          m_strPassword = data[0];
        }
        LoadPackageFromWeb(xpfImport);
      }
    }
    
    /// <summary>
    /// Loads a package file from a known location and updates our
    /// member variables accordingly. If the initialization fails or the
    /// path is the same as the previous path, nothing happens.
    /// </summary>
    private void LoadPackageFromFile(XPFile _xpfImport)
    {
      String strFilePath = "";
      try
      {
        // Upload to the directory we created the temp file into (unfortunately, the uploader will not
        // preserve the tempfile filename, so we must just a temp createfile to reserve a directory for us.
        // It hardly matters, the empty temp file will be removed when the real one is removed.
        IXPRequest _xpRUpload = m_asOwner.GetCurrentHTTPRequest();
        _xpRUpload.Save(_xpfImport.GetParent().GetFullPath());
        // Path that the file was uploaded to
        strFilePath = ((XPRequest) _xpRUpload).GetCompletePath();
        // Path that the file was uploaded from
        m_strPackagePath = ((XPRequest) _xpRUpload).GetRemoteFilePath();
        if ((null == strFilePath) || (0 >= strFilePath.Length))
        {
          throw new XPException(STR_MVC_CLASS_NAME + "::LoadPackage() : Filepath null or empty");
          }
        if (0 == m_strPackagePath.CompareTo(strFilePath))
        {
          // We've already loaded this package - why do it again?
          return;
        }
        m_mainModel.GetMigrationManager().InitializeForImport(strFilePath);
        m_strPackagePath = strFilePath;
        m_bPackageLoaded = true;
        log.Info("Loaded migration package into: " + m_strPackagePath);
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::LoadPackageFromFile(...) Unknown error loading package. e: " + e.Message);
        m_strPackagePath = "";
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_asOwner.GetString(510, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(510,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <summary>
    /// Loads a package file from a known location and updates our
    /// member variables accordingly. If the initialization fails or the
    /// path is the same as the previous path, nothing happens.
    /// </summary>
    private void LoadPackageFromWeb(XPFile _xpfImport)
    {
      String strFilePath = "";
      try
      {
        // Upload to the directory we created the temp file into (unfortunately, the uploader will not
        // preserve the tempfile filename, so we must just a temp createfile to reserve a directory for us.
        // It hardly matters, the empty temp file will be removed when the real one is removed.
        m_strFileName = XPStringUtility.Substring(m_strWebPath, XPStringUtility.LastIndexOf(m_strWebPath,
         "/") + 1);
        GetURLContent(_xpfImport);
        strFilePath = _xpfImport.GetParent().GetFullPath() + "\\" + m_strFileName;
        if ((null == strFilePath) || (0 >= strFilePath.Length))
        {
          throw new XPException(STR_MVC_CLASS_NAME + "::LoadPackageFromWeb() : Filepath null or empty");
          }
        m_mainModel.GetMigrationManager().InitializeForImport(strFilePath);
        m_strPackagePath = strFilePath;
        m_bPackageLoaded = true;
        log.Info("Loaded migration package into: " + m_strPackagePath);
      }
      catch (Exception e)
      {
        m_strPackagePath = "";
        log.Error(e, STR_MVC_CLASS_NAME + "::LoadPackageFromWeb(...) Unknown error loading package. e: " + e.Message);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_asOwner.GetString(510, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(510,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <summary>
    /// Sends HTTP request to m_strWebPath and writes response
    /// to _xpfImport location.
    /// </summary>
    /// <param name="_xpfImport"></param>
    private void GetURLContent(XPFile _xpfImport)
    {
      IOKHttpResponse response = SendRequest();
      if (response.GetResponseCode() == OKHttpResponseCode.OK)
      {
        log.Info(STR_MVC_CLASS_NAME + "::GetURLContent() Sent request to: " + m_strWebPath);
        }
      int intResponseCode = response.GetResponseCode();
      if (intResponseCode != OKHttpResponseCode.OK)
      {
        log.Error(STR_MVC_CLASS_NAME + "::GetURLContent() Received response code of: " + intResponseCode);
        }
      response.WriteBodyToFile(_xpfImport.GetParent().GetFullPath() + "\\" + m_strFileName);
      }
    
    /// <summary>
    /// Uses OpenHttp to send request to m_strWebPath.
    /// Sends appropriate Basic Authentication credentials.
    /// </summary>
    /// <returns>IHttpResponse</returns>
    private IOKHttpResponse SendRequest()
    {
      IOKHttpResponse response = null;
      try
      {
        IOKHttpService okservice = OpenHTTPServiceHelper.GetOpenHTTPService();
        IOKUrl url = okservice.CreateUrl(m_strWebPath);
        IOKHttpSession session = OpenHTTPServiceHelper.GetOpenHTTPSession();
        IOKHttpRequest request = session.CreateRequest(url);
        IOKRequestWaiter waiter = okservice.GetWaiterObject();
        if (m_bBasicAuth)
        {
          request.SetHttpAuthentication(m_strUsername, m_strPassword);
        }
        //could do timeout here...
        request.SetTimeout(15000);
        waiter.AddRequest(request);
        request.Submit();
        waiter.Wait(15000);
        if (OKHttpRequestState.DONE == request.GetRequestState())
        {
          response = request.GetResponse();
        } else
        if (OKHttpRequestState.CANCELED == request.GetRequestState())
        {
          log.Error(STR_MVC_CLASS_NAME + " ::SendRequest() Request timed out.");
          } else
        if (OKHttpRequestState.ERROR == request.GetRequestState())
        {
          OKHttpException e = request.GetErrorInfo();
          if (e != null)
          {
            throw e;
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + " ::SendRequest() Unknown error sending request to " + m_strWebPath + ". e: " + e.Message);
        throw XPException.GetInstance(e);
      }
      return response;
    }
    
    /// <summary>
    /// Returns filename (no path) of loaded package.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetPackageFileName()
    {
      return m_strPackagePath;
    }
    
    /// <summary>
    /// True if a package has been successfully loaded.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsPackageLoaded()
    {
      return m_bPackageLoaded;
    }
    
    /// <summary>
    /// Get package name
    /// </summary>
    /// <returns></returns>
    public virtual String GetPackageName()
    {
      if (!m_bPackageLoaded)
      {
        return "";
      }
      try
      {
        return m_mainModel.GetMigrationManager().ReadUserDataItemFromPackage(PACKAGE_NAME);
        }
      catch (Exception e)
      {
        return "";
      }
    }
    
    /// <summary>
    /// Get package description
    /// </summary>
    public virtual String GetPackageDescription()
    {
      if (!m_bPackageLoaded)
      {
        return "";
      }
      try
      {
        return m_mainModel.GetMigrationManager().ReadUserDataItemFromPackage(PACKAGE_DESCRIPTION);
        }
      catch (Exception e)
      {
        return "";
      }
    }
    
    /// <summary>
    /// Get package publisher
    /// </summary>
    public virtual String GetPublisherName()
    {
      if (!m_bPackageLoaded)
      {
        return "";
      }
      try
      {
        return m_mainModel.GetMigrationManager().ReadUserDataItemFromPackage(PUBLISHER_NAME);
        }
      catch (Exception e)
      {
        return "";
      }
    }
  }
}