using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.migrationutility.exp;
using com.plumtree.portalpages.browsing.editors.objectdelivery.common;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility
{
  public class MigrationLoadPackageView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationLoadPackageView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MigrationLoadPackageView";
    
    /// <summary>
    /// Upload button
    /// </summary>
    public const String HTMLBUTTON_PACKAGE_UPLOAD = "in_bu_PackageName";
    
    /// <summary>
    /// File chooser
    /// </summary>
    public const String HTMLFILE_PACKAGE_FILE = "in_fi_File";
    
    /// <summary>
    /// Web address
    /// </summary>
    public const String HTMLTEXT_PACKAGE_WEB = "in_tx_Web";
    
    /// <summary>
    /// Radio button: File or Web
    /// </summary>
    public const String HTMLRADIO_PACKAGE_TYPE = "in_ra_FileType";
    
    /// <summary>
    /// Basic auth username
    /// </summary>
    public const String HTMLINPUT_USERNAME = "in_tx_Username";
    
    /// <summary>
    /// Basic auth password
    /// </summary>
    public const String HTMLINPUT_PASSWORD = "in_pw_Password";
    
    /// <summary>
    /// Basic auth checkbox
    /// </summary>
    public const String HTMLCHECKBOX_BASICAUTH = "in_cb_BasicAuth";
    public override Object Create()
    {
      return new MigrationLoadPackageView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myRadio;
      HTMLSpan mySpan;
      int COLUMNS = 6;
      try
      {
        MigrationLoadPackageModel myModel = (MigrationLoadPackageModel) m_model;
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2737,
         "ptmsgs_portaladminmsgs")));
        myTable = ODViewHelper.AddTable(result);
        myTable.SetCellPadding("3");
        myTable.SetBorder("0");
        ODViewHelper.AddEmptyRow(myTable, "6");
        myRow = ODViewHelper.AddRow(myTable);
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        myCell = ODViewHelper.AddCell(myRow, XPConvert.ToString(COLUMNS));
        myCell.SetNoWrap(false);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        mySpan = ODViewHelper.AddSpanToCell(myCell);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2738, "ptmsgs_portaladminmsgs"));
        // Row 1: File Path
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        // Left Margin
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        // Radio button and "File Path:"
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myRow.AddInnerHTMLElement(myCell);
        myRadio = new HTMLInput(HTMLInputTypes.RADIO_TYPE, HTMLRADIO_PACKAGE_TYPE,
         "");
        myRadio.SetID(HTMLRADIO_PACKAGE_TYPE + "_file");
        myRadio.SetStyleClass(PTStyleClass.FORM_RADIO);
        myRadio.SetValue("file");
        myRadio.SetChecked(true);
        myRadio.SetOnClick("EnableUNC();");
        myCell.AddInnerHTMLElement(myRadio);
        myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(2739, "ptmsgs_portaladminmsgs"));
        // File chooser			
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        HTMLInput myFileChooser = new HTMLInput(HTMLInputTypes.FILE, HTMLFILE_PACKAGE_FILE,
         "");
        myFileChooser.SetID(HTMLFILE_PACKAGE_FILE);
        myFileChooser.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myFileChooser.SetSize(50);
        myCell.AddInnerHTMLElement(myFileChooser);
        // Row 2: Web Address
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        // Left Margin
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        // Radio button and "Web Address:"
        myCell = new HTMLTableCell();
        myCell.SetColSpan("2");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myRow.AddInnerHTMLElement(myCell);
        myRadio = new HTMLInput(HTMLInputTypes.RADIO_TYPE, HTMLRADIO_PACKAGE_TYPE,
         "");
        myRadio.SetID(HTMLRADIO_PACKAGE_TYPE + "_web");
        myRadio.SetStyleClass(PTStyleClass.FORM_RADIO);
        myRadio.SetValue("web");
        myRadio.SetOnClick("EnableURL();");
        myCell.AddInnerHTMLElement(myRadio);
        myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(2740, "ptmsgs_portaladminmsgs"));
        // Text box for web address
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        HTMLInput myTextBox = new HTMLInput(HTMLInputTypes.TEXT_TYPE, HTMLTEXT_PACKAGE_WEB,
         "");
        myTextBox.SetID(HTMLTEXT_PACKAGE_WEB);
        myTextBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myTextBox.SetSize(50);
        myTextBox.SetDisabled(true);
        myCell.AddInnerHTMLElement(myTextBox);
        // Row 3: Basic auth checkbox
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        // Left Margin
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        // Checkbox
        myCell = new HTMLTableCell();
        myCell.SetAlign("right");
        myRow.AddInnerHTMLElement(myCell);
        HTMLInput myCheckbox = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE,
         HTMLCHECKBOX_BASICAUTH, "");
        myCheckbox.SetID(HTMLCHECKBOX_BASICAUTH);
        myCheckbox.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        myCheckbox.SetDisabled(true);
        myCheckbox.SetOnClick("EnableBasicAuth();");
        myCell.AddInnerHTMLElement(myCheckbox);
        // "Use basic auth..."
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myCell.SetColSpan("3");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(2741, "ptmsgs_portaladminmsgs"));
        // Row 4: Basic auth username
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        // Left Margin
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        myCell = new HTMLTableCell();
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myRow.AddInnerHTMLElement(myCell);
        // "Username:"
        ODViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(741,
         "ptmsgs_portaladminmsgs"));
        // Text box for username
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        myTextBox = new HTMLInput(HTMLInputTypes.TEXT_TYPE, HTMLINPUT_USERNAME,
         "");
        myTextBox.SetID(HTMLINPUT_USERNAME);
        myTextBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myTextBox.SetSize(15);
        myTextBox.SetDisabled(true);
        myCell.AddInnerHTMLElement(myTextBox);
        // Row 5: Basic auth password
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        // Left Margin
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        myCell = new HTMLTableCell();
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myRow.AddInnerHTMLElement(myCell);
        // "Password:"
        ODViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(742,
         "ptmsgs_portaladminmsgs"));
        // Text box for password
        myCell = new HTMLTableCell();
        myCell.SetWidth("100%");
        myRow.AddInnerHTMLElement(myCell);
        myTextBox = new HTMLInput(HTMLInputTypes.PASSWORD_TYPE, HTMLINPUT_PASSWORD,
         "");
        myTextBox.SetID(HTMLINPUT_PASSWORD);
        myTextBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myTextBox.SetSize(15);
        myTextBox.SetDisabled(true);
        myCell.AddInnerHTMLElement(myTextBox);
        // Row 6: Empty Row
        ODViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
        // Row 7: Upload button
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        // Left Margin
        ODViewHelper.AddLeftMargin(myRow, COLUMNS);
        // Upload Button
        myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetColSpan("4");
        myCell.SetWidth("100%");
        mySpan = ODViewHelper.AddSpanToCell(myCell);
        // The actual button for doing an upload
        String strOnClick = "DoUpload(); return false;";
        mySpan.AddInnerHTMLElement(ODViewHelper.MakeSimpleButton(m_asOwner.GetString(2742,
         "ptmsgs_portaladminmsgs"), strOnClick));
        // Row 8: Empty Row
        ODViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
        if (myModel.IsPackageLoaded())
        {
          // Row 9: Package Name
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          // Left Margin
          ODViewHelper.AddLeftMargin(myRow, COLUMNS);
          myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.TWO);
          myCell.SetNoWrap(true);
          mySpan = ODViewHelper.AddSpanToCell(myCell);
          myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(2743, "ptmsgs_portaladminmsgs") + CommonHTMLStrings.SPACE);
          myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
          myCell.SetWidth("100%");
          mySpan = ODViewHelper.AddSpanToCell(myCell);
          String strName = myModel.GetPackageName();
          if (null == strName || strName.Equals(""))
          {
            strName = m_asOwner.GetString(2744, "ptmsgs_portaladminmsgs");
            }
          mySpan.AddInnerHTMLEncodedString(strName);
          // Row 10: Package Description
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          // Left Margin
          ODViewHelper.AddLeftMargin(myRow, COLUMNS);
          myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.TWO);
          myCell.SetNoWrap(true);
          mySpan = ODViewHelper.AddSpanToCell(myCell);
          myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(2745, "ptmsgs_portaladminmsgs") + CommonHTMLStrings.SPACE);
          myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
          myCell.SetWidth("100%");
          mySpan = ODViewHelper.AddSpanToCell(myCell);
          String strDescription = myModel.GetPackageDescription();
          if (null == strDescription || strDescription.Equals(""))
          {
            strDescription = m_asOwner.GetString(2744, "ptmsgs_portaladminmsgs");
            }
          mySpan.AddInnerHTMLEncodedString(strDescription);
          // Row 11: Publisher
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          // Left Margin
          ODViewHelper.AddLeftMargin(myRow, COLUMNS);
          myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.TWO);
          myCell.SetNoWrap(true);
          mySpan = ODViewHelper.AddSpanToCell(myCell);
          myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(2746, "ptmsgs_portaladminmsgs") + CommonHTMLStrings.SPACE);
          myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
          myCell.SetWidth("100%");
          mySpan = ODViewHelper.AddSpanToCell(myCell);
          String strPublisher = myModel.GetPublisherName();
          if (null == strPublisher || strPublisher.Equals(""))
          {
            strPublisher = m_asOwner.GetString(2744, "ptmsgs_portaladminmsgs");
            }
          mySpan.AddInnerHTMLEncodedString(strPublisher);
          MigrationUtilityModel mainModel = (MigrationUtilityModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
          IPTMigrationManager migMgr = mainModel.GetMigrationManager();
          String[] arStrUserData = migMgr.RetrieveAllUserDataNames();
          int nStrUserDataLen = (arStrUserData != null) ? arStrUserData.Length : 0;
          for (int indData = 0;indData < nStrUserDataLen;indData++)
          {
            String strDataName = arStrUserData[indData];
            if (strDataName.Equals(PTExportMigrationTask.PACKAGE_DESCRIPTION) || strDataName.Equals(PTExportMigrationTask.PACKAGE_NAME) || strDataName.Equals(PTExportMigrationTask.PUBLISHER_NAME))
            {
              // already wrote this info out
              continue;
            }
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            // Left Margin
            ODViewHelper.AddLeftMargin(myRow, COLUMNS);
            myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.TWO);
            myCell.SetNoWrap(true);
            mySpan = ODViewHelper.AddSpanToCell(myCell);
            myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
            mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
            mySpan.AddInnerHTMLString(arStrUserData[indData] + CommonHTMLStrings.SPACE);
            myCell = ODViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
            myCell.SetWidth("100%");
            mySpan = ODViewHelper.AddSpanToCell(myCell);
            String strDataValue = migMgr.ReadUserDataItemFromPackage(arStrUserData[indData]);
            if (null == strDataValue || strDataValue.Equals(""))
            {
              strDataValue = m_asOwner.GetString(2744, "ptmsgs_portaladminmsgs");
              }
            mySpan.AddInnerHTMLEncodedString(strDataValue);
          }
          // Row 12: Empty Row
          ODViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
          }
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.GetMessage());
        throw new XPException(m_asOwner.GetString(1442, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        sb = new XPStringBuilder(100);
        // DoUpload(): If using filechooser, set form enctype to multipart/form-data.
        // postToSelf.
        sb.Append("function DoUpload()\n");
        sb.Append("{\n");
        sb.Append("  if (document.getElementById(\'" + HTMLRADIO_PACKAGE_TYPE + "_file\').checked) {\n");
        sb.Append("    document.forms[0].encoding=\"multipart/form-data\";\n");
        sb.Append("  }\n");
        sb.Append("  postToSelf(").Append(MigrationUtilityRepostControl.POSTTOSELF_ACTION_MIGRATION_DOUPLOAD).Append(");\n");
        sb.Append("}\n\n");
        // EnableURL()
        sb.Append("function EnableURL()\n");
        sb.Append("{\n");
        sb.Append("  document.getElementById(\'" + HTMLCHECKBOX_BASICAUTH + "\').disabled=false;\n");
        sb.Append("  document.getElementById(\'" + HTMLTEXT_PACKAGE_WEB + "\').disabled=false;\n");
        sb.Append("  document.getElementById(\'" + HTMLTEXT_PACKAGE_WEB + "\').focus();\n");
        sb.Append("  document.getElementById(\'" + HTMLFILE_PACKAGE_FILE + "\').disabled=true;\n");
        sb.Append("  EnableBasicAuth();\n");
        sb.Append("}\n\n");
        // EnableBasicAuth(): Toggles.  If checking basic auth checkbox, enable
        // username and password text boxes.
        sb.Append("function EnableBasicAuth()\n");
        sb.Append("{\n");
        sb.Append("  if (document.getElementById(\'" + HTMLCHECKBOX_BASICAUTH + "\').checked) {\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_USERNAME + "\').disabled=false;\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_PASSWORD + "\').disabled=false;\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_USERNAME + "\').focus();\n");
        sb.Append("  } else {\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_USERNAME + "\').disabled=true;\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_PASSWORD + "\').disabled=true;\n");
        sb.Append("  }\n");
        sb.Append("}\n\n");
        // EnableUNC(): If clicking on File radio button, disable basic auth options.
        sb.Append("function EnableUNC()\n");
        sb.Append("{\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLTEXT_PACKAGE_WEB + "\').disabled=true;\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLCHECKBOX_BASICAUTH + "\').disabled=true;\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_USERNAME + "\').disabled=true;\n");
        sb.Append("  \tdocument.getElementById(\'" + HTMLINPUT_PASSWORD + "\').disabled=true;\n");
        sb.Append("     document.getElementById(\'" + HTMLFILE_PACKAGE_FILE + "\').disabled=false;\n");
        sb.Append("     document.getElementById(\'" + HTMLFILE_PACKAGE_FILE + "\').focus();\n");
        sb.Append("}\n\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element: " + he.GetMessage());
        }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}