using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility
{
  /// <author>jennifersu</author>
  public class MigrationResultPopupView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationResultPopupView");
    public const String STR_MVC_CLASS_NAME = "MigrationResultPopup";
    
    /// <summary>
    /// Activity Space
    /// </summary>
    private MigrationUtilityAS m_asOwner;
    
    /// <summary>
    /// Model
    /// </summary>
    private IModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activiMigrationResultPopupViewt#Create()"></seealso>
    public virtual Object Create()
    {
      return new MigrationResultPopupView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myMainTable;
      HTMLTableRow myMainTableRow;
      HTMLTableCell myMainTableCell;
      HTMLSpan mySpan;
      try
      {
        // Main table
        myMainTable = new HTMLTable();
        result.AddInnerHTMLElement(myMainTable);
        myMainTable.SetWidth("100%");
        myMainTable.SetHeight("100%");
        myMainTable.SetBorder("0");
        myMainTable.SetCellPadding("0");
        myMainTable.SetCellSpacing("0");
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetColSpan("3");
        myMainTableCell.SetHeight("10%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // 1st Row: Status display
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableCell.SetVAlign("bottom");
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        mySpan = new HTMLSpan();
        myMainTableCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2747, "ptmsgs_portaladminmsgs") + GetStatusString());
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        // 2nd Row: Close button
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetAlign("right");
        mySpan = new HTMLSpan();
        myMainTableCell.AddInnerHTMLElement(mySpan);
        HTMLInput cancelButton = new HTMLInput(HTMLInputTypes.BUTTON_TYPE,
         m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
        cancelButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        cancelButton.SetValue(m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
        cancelButton.SetOnClick("window.close();");
        mySpan.AddInnerHTMLElement(cancelButton);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetColSpan("3");
        myMainTableCell.SetHeight("20%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      catch (Exception e)
      {
        log.Error(e, "Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(24, "ptmsgs_portalcommonmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IModelRO) model;
      m_asOwner = (MigrationUtilityAS) parent;
    }
    
    /// <summary>
    /// Gets the status of the migration and returns the corresponding string.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetStatusString()
    {
      String strStatus = "";
      int intStatus = ((IMigrationUtilityModelRO) m_model).GetMigrationStatus();
      switch (intStatus){
      case PTMigrationTask.DONE:
      strStatus = m_asOwner.GetString(2748, "ptmsgs_portaladminmsgs");
      break;
      case PTMigrationTask.CANCEL:
      strStatus = m_asOwner.GetString(2749, "ptmsgs_portaladminmsgs");
      break;
      case PTMigrationTask.FAILED:
      strStatus = m_asOwner.GetString(2750, "ptmsgs_portaladminmsgs");
      break;
      }
      return strStatus;
    }
  }
}