using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.xui;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.xui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility
{
  public class MigrationUtilityModel : EditorModel,IMigrationUtilityModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationUtilityModel");
    public const String STR_MVC_CLASS_NAME = "MigrationUtilityModel";
    // For storing MWS REMOTEDATA in SCI settings on import.
    public const String MWS_REMOTEDATA_SCI_KEY = "MWS_REMOTEDATA";
    public const String MWS_REMOTEDATA_DELIMITER = ",";
    public const String MWS_REMOTEDATA_TYPE_ASSIGNMENT = "=";
    
    /// <summary>
    /// IPTMigrationManager. All helper models in this AS should
    /// access this MigrationManager.
    /// </summary>
    protected IPTMigrationManager m_ptMigrationManager = null;
    
    /// <summary>
    /// IPTSession
    /// </summary>
    protected IPTSession m_ptSession = null;
    
    /// <summary>
    /// MigrationElements of all objects (don't access this directly - use
    /// GetAllObjectsInPackage instead). This contains a hashtable of arrays
    /// or MigrationElements, keyed off of the CLASSID of the MigrationElements
    /// in question.
    /// </summary>
    protected XPHashtable m_xphtAllObjects;
    
    /// <summary>
    /// migration thread
    /// </summary>
    protected PTMigrationTask m_objMigrationTask;
    
    /// <summary>
    /// Array of MWS IDs
    /// </summary>
    protected XPArrayList m_alMWSIDs = new XPArrayList();
    
    /// <summary>
    /// Hashtable of MWS property bags to send.
    /// Key=MWS ID; Value=IXPPropertyBag 
    /// </summary>
    protected XPHashtable m_htPropBags;
    // String UUID of REMOTEDATA => String type (COLLABORATION|PUBLISHER|UNKNOWN)
    // See the IPTMigrationManager.GetMWSRemoteData() method for details.
    private XPHashtable remoteDataMap = new XPHashtable();
    // List of IXPPropertyBag: Internal references to XUI services' property bags.
    private XPArrayList mwsSCIPropertyBags = new XPArrayList();
    
    /// <summary>
    /// Inits member variables
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      m_ptMigrationManager = (IPTMigrationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
       false);
      m_xphtAllObjects = null;
      m_objMigrationTask = null;
      m_alMWSIDs = new XPArrayList();
      m_htPropBags = new XPHashtable();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#Create()
     */
     
    public override Object Create()
    {
      return new MigrationUtilityModel();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#CheckEditorAccessAndStart(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#Finish()
     */
     
    public override void Finish()
    {
    }
    public override void DoTaskBeforeStore()
    {
      base.DoTaskBeforeStore();
    }
    // mel: Fix for 45506, previously unable to import collab only resources
    
    /// <returns>true if objects are pending migration import/export, false if none.</returns>
    public virtual bool HasObjectsForMigration()
    {
      // mel: TODO (bug# 45525) What we really want to know here is whether the user has selected any objects in Collab/Content for migration but the current MWS just uses SCI, so we have no way of getting that information.
      int numMWSPages = 0;
      if (m_alMWSIDs != null)
      {
        numMWSPages = m_alMWSIDs.GetSize();
      }
      return numMWSPages > 0;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#SavePage(java.lang.String, com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      // Save XUI pages
      for (int indService = 0;indService < m_alMWSIDs.GetSize();indService++)
      {
        if (RepostControl.PAGE_STATUS_VALID == nPageStatus)
        {
          nPageStatus = ((XUIHelperModel) m_asOwner.GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indService)).SaveSection(_htFormData);
          if (RepostControl.PAGE_STATUS_INVALID == nPageStatus)
          {
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(2635, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2635,
             "ptmsgs_portaladminmsgs"));
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            break;
          }
        }
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// This should be called to clear any migration
    /// that has been initialized, such as when packages
    /// have been loaded.
    /// </summary>
    public virtual void ResetMigrationManager()
    {
      m_ptMigrationManager = (IPTMigrationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
       false);
      m_xphtAllObjects = null;
    }
    
    /// <summary>
    /// All classes in the AS should access the migration manager
    /// using this method, because the same IPTMigrationManager
    /// needs to be used for a given migration.
    /// </summary>
    /// <returns>IPTMigrationManager</returns>
    public virtual IPTMigrationManager GetMigrationManager()
    {
      return m_ptMigrationManager;
    }
    
    /// <summary>
    /// Gets an XPArrayList[] with all objects in the package, indexed by classID.
    /// Returns an array of IPTMigrationElements.
    /// Returns only supported CLASSIDS
    /// </summary>
    public virtual XPArrayList[] GetAllObjectsInPackage()
    {
      int nNumCLASSIDS = PT_MIGRATION_CLASSES.SUPPORTED_CLASSES.Length;
      XPArrayList[] xparResult = new XPArrayList[nNumCLASSIDS];
      // We've got to do this by CLASSID -- whee.
      for (int ncCLASSID = 0;ncCLASSID < nNumCLASSIDS;ncCLASSID++)
      {
        int nCLASSIDCurrent = PT_MIGRATION_CLASSES.SUPPORTED_CLASSES[ncCLASSID];
        xparResult[ncCLASSID] = GetAllObjectsInPackage(nCLASSIDCurrent);
      }
      return xparResult;
    }
    
    /// <summary>
    /// Gets an XPArrayList of all objects in the package.
    /// (based on CLASSID). Returns an array of IPTMigrationElements.
    /// Can return objects from unsupported CLASSIDS (see ObjectDeliveryHelper)
    /// </summary>
    public virtual XPArrayList GetAllObjectsInPackage(int nCLASSID)
    {
      if (null == m_xphtAllObjects)
      {
        m_xphtAllObjects = new XPHashtable();
      }
      //Cheap caching... see if the member hashtable already has this list of items.		
      if (m_xphtAllObjects.ContainsKey(nCLASSID))
      {
        return (XPArrayList) m_xphtAllObjects.GetElement(nCLASSID);
      }
      // Apparently not (Cheap caching).
      XPArrayList xparResult = new XPArrayList();
      int ncObjects = GetMigrationManager().GetObjectCount(nCLASSID);
      for (int nIndex = 0;nIndex < ncObjects;nIndex++)
      {
        // Get IPTMigrationElement
        IPTMigrationElement ptME = GetMigrationManager().RetrieveObjectFromImportPackage(nIndex,
         nCLASSID);
        xparResult.Add(ptME);
      }
      // Get Dependencies
      // If Dependency doesn't exist in package
      // Cache it for later.
      m_xphtAllObjects.PutElement(nCLASSID, xparResult);
      return xparResult;
    }
    
    /// <summary>
    /// Perform action for when user loads a package.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void DoLoadPackage(XPHashtable _htFormData)
    {
      MigrationLoadPackageModel lpModel = (MigrationLoadPackageModel) m_asOwner.GetModel(MigrationLoadPackageModel.strStorageLoadPackage);
      lpModel.LoadPackage(_htFormData);
      // mel: Fix for 46405, Collaboration and Publisher MWS need a way of knowing what zip file will be loaded. Add the REMOTEDATA UUID information to an SCI key for retrieval by the remote MWS.
      if (mwsSCIPropertyBags != null && !mwsSCIPropertyBags.IsEmpty())
      {
        String mwsRemoteDataSCIValue = GetMWSRemoteDataAsSCIValue();
        IXPEnumerator propBagEnumer = mwsSCIPropertyBags.GetEnumerator();
        while (propBagEnumer.MoveNext())
        {
          IXPPropertyBag sciPropertyBag = (IXPPropertyBag) propBagEnumer.GetCurrent();
          AddMWSRemoteDataToSCISettings(sciPropertyBag, mwsRemoteDataSCIValue);
          }
      }
    }
    
    /// <summary>
    /// Sets the status on the migration task to Cancel.
    /// Removes the migration task from the session.
    /// </summary>
    public virtual void CancelMigration()
    {
      m_objMigrationTask.Cancel();
    }
    
    /// <summary>
    /// Gets the status of the migration task.
    /// </summary>
    /// <returns>int (see PTMigrationTask for status values)</returns>
    public virtual int GetMigrationStatus()
    {
      return m_objMigrationTask.GetStatus();
    }
    
    /// <summary>
    /// Returns XPArrayList of Migration Web Service object IDs.
    /// </summary>
    protected virtual XPArrayList GetXUIServices()
    {
      // Get Web Service object manager
      IPTObjectManager wsManager = m_ptSession.GetWebServices();
      PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(wsManager);
      // Construct query filter to find web services
      // of migration provclsid.
      Object[][] ptqf = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        ptqf[j2c_index] = new Object[2];
      }
      ptqf[0][0] = PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID;
      ptqf[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      ptqf[2][0] = PT_PROVIDER_CLSIDS.PT_MIGRATION_PROVIDER;
      ptqf[0][1] = PT_PROPIDS.PT_PROPID_WEBSERVICE_ENABLED;
      ptqf[1][1] = PT_FILTEROPS.PT_FILTEROP_EQ;
      ptqf[2][1] = 1;
      // Query
      omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, ptqf);
      // Populate XPArrayList with IDs
      XPArrayList alWSIDs = new XPArrayList(omqw.GetCount());
      for (int i = 0;i < omqw.GetCount();i++)
      {
        alWSIDs.Add(omqw.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
      }
      return alWSIDs;
    }
    
    /// <summary>
    /// Add the latest REMOTEDATA from the PTMigrationManager to our internal remoteDataMap
    /// </summary>
    private void AddRemoteDataMapFromLatestMigrationManager()
    {
      // Unfortunately, MigrationLoadPackageModel needs to call
      // MigrationUtilityModel.ResetMigrationManager, which gets a new PTMigrationManager.
      // As a result, we have to track all REMOTEDATA in this model.
      // Ideally, we could let PTMigrationManager track everything for us.
      XPHashtable newRemoteDataMap = m_ptMigrationManager.GetMWSRemoteData();
      if (newRemoteDataMap != null)
      {
        IXPEnumerator remoteDataKeys = newRemoteDataMap.GetKeys();
        while (remoteDataKeys.MoveNext())
        {
          String remoteData = (String) remoteDataKeys.GetCurrent();
          String mwsType = (String) newRemoteDataMap.GetElement(remoteData);
          // Add to existing map
          remoteDataMap.PutElement(remoteData, mwsType);
        }
      }
    }
    // mel: Fix for 46405, Collaboration and Publisher MWS need a way of knowing what zip file will be loaded. Add the REMOTEDATA UUID information to an SCI key for retrieval by the remote MWS.
    
    /// <returns>
    /// A value for use with the MWS_REMOTEDATA_SCI_KEY,
    /// this is a comma delimeted list of the form UUID=TYPE.
    /// The UUID is the REMOTEDATA provided by an earlier MWS ExportPackage
    /// and stored in the pte.
    /// The type indicates what remote resources correspond to the UUID
    /// and is one of COLLABORATION, PUBLISHER, or UNKNOWN.
    /// Examples:
    /// 010199cf-f593-11d9-8909-0008744f211f=UNKNOWN
    /// 010199cf-f593-11d9-8909-0008744f211f=COLLABORATION,01ddd9cf-f593-11d9-8909-0008744f211f=UNKNOWN
    /// </returns>
    private String GetMWSRemoteDataAsSCIValue()
    {
      XPStringBuilder mwsRemoteDataSCIValue = new XPStringBuilder();
      try
      {
        AddRemoteDataMapFromLatestMigrationManager();
        // assert: remoteData != null
        IXPEnumerator remoteDataKeys = remoteDataMap.GetKeys();
        while (remoteDataKeys.MoveNext())
        {
          if (mwsRemoteDataSCIValue.GetLength() > 0)
          {
            // Add a comma if there is more than one elemnt in the list
            mwsRemoteDataSCIValue.Append(MWS_REMOTEDATA_DELIMITER);
          }
          String remoteData = (String) remoteDataKeys.GetCurrent();
          if (remoteData != null && remoteData.Length > 0)
          {
            String mwsType = (String) remoteDataMap.GetElement(remoteData);
            mwsRemoteDataSCIValue.Append(remoteData);
            mwsRemoteDataSCIValue.Append(MWS_REMOTEDATA_TYPE_ASSIGNMENT);
            mwsRemoteDataSCIValue.Append(mwsType);
          } else
          {
            // This should never occur
            log.Debug(STR_MVC_CLASS_NAME + ".GetMWSRemoteDataAsSCIValue skipped adding empty REMOTEDATA to the MWS SCI settings.");
            }
        }
      }
      catch (Exception anyException)
      {
        log.Error(STR_MVC_CLASS_NAME + ".GetMWSRemoteDataAsSCIValue failed to retrieve MWS REMOTEDATA UUIDs (zip file names). Collaboration or Publisher resources may not display properly.");
        }
      return mwsRemoteDataSCIValue.ToString();
    }
    
    /// <summary>
    /// Fail safe way to add the mwsRemoteDataSCIValue to the IXPPropertyBag of SCI settings.
    /// </summary>
    private void AddMWSRemoteDataToSCISettings(IXPPropertyBag sciSettings,
     String mwsRemoteDataSCIValue)
    {
      if (sciSettings == null)
      {
        // This should never occur
        log.Warn(STR_MVC_CLASS_NAME + ".AddMWSRemoteDataToSCISettings was called with a null property bag of SCI settings.");
        return;
      }
      if (mwsRemoteDataSCIValue == null || mwsRemoteDataSCIValue.Length == 0)
      {
        // This will occur whenever there is no MWS REMOTEDATA
        log.Debug(STR_MVC_CLASS_NAME + ".AddMWSRemoteDataToSCISettings was called with an empty mwsRemoteDataSCIValue. The " + MWS_REMOTEDATA_SCI_KEY + " will not be added to SCI settings.");
        return;
      }
      try
      {
        sciSettings.Write(MWS_REMOTEDATA_SCI_KEY, mwsRemoteDataSCIValue);
        }
      catch (Exception anyException)
      {
        log.Error(STR_MVC_CLASS_NAME + ".AddMWSRemoteDataToSCISettings failed to add MWS REMOTEDATA UUIDs (zip file names). Collaboration or Publisher resources may not display properly.");
        }
    }
    // mel: Fix for 46770 object migration editor does not open if there is a problem with any migration web services
    protected virtual void StartXUIServicesSafely(String sciEditorType)
    {
      if (!StartXUIServices(sciEditorType))
      {
        log.Error(STR_MVC_CLASS_NAME + "Failed to initialize SCI (XUI) services for Migration Web Services. Collaboration and Publisher migration are unavailable until this problem is repaired.");
        // Clearing the list of MWSs will disable both Collab
        // and Publisher, even if we only want to disable one.
        // XUI init currently fails the entire initialization
        // sequence anyway, so this behavior is okay until that
        // problem is resolved in a future version.
        m_alMWSIDs = new XPArrayList();
      }
    }
    private void RaiseXUIInitializationError(Exception cause)
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      UIError myError;
      sb.Append(m_asOwner.GetString(4, "ptmsgs_provUIMWS")).Append(cause);
      log.Error(cause, STR_MVC_CLASS_NAME + "::CheckEditorAccessAndStart " + sb.ToString());
      // String errorMessage = m_asOwner.GetString(TODO, "ptmsgs_provUIMWS"); // TODO bug 46852 i18n this string
      String errorMessage = "At least one remote migration web service could not be contacted.  Base portal items can still be migrated although Collaboration and Publisher items will not be included in the migration. Please consult the portal logs for details.";
      //Raise the error that XUI Could not be initialized
      myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
       null, errorMessage, errorMessage);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
    
    /// <summary>
    /// Retrieves all Migration XUI Services and initializes them.
    /// </summary>
    /// <param name="_strXUIEditorType"></param>
    /// <returns>boolean.  True if successful; false if error.</returns>
    protected virtual bool StartXUIServices(String _strXUIEditorType)
    {
      bool success = true;
      XPHashtable htPageCounts = new XPHashtable();
      try
      {
        m_alMWSIDs = GetXUIServices();
        log.Info("Found " + m_alMWSIDs.GetSize() + " Migration XUI Pages.");
        if (m_alMWSIDs.GetSize() > 0)
        {
          IServiceManager xuiManager = (IServiceManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_XUI_SERVICE_MANAGER,
           false);
          try
          {
            xuiManager.Initialize(XUIHelperMethods.XUI_XSL_TRANSFORMER);
          }
          catch (Exception e)
          {
            log.Error(e, STR_MVC_CLASS_NAME + "::CheckEditorAccessAndStart " + m_asOwner.GetString(3,
             "ptmsgs_provUIMWS"));
            //Raise the error that XUI Could not be initialized
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(3, "ptmsgs_provUIMWS"), m_asOwner.GetString(3,
             "ptmsgs_provUIMWS"));
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            // This return is required for proper functioning of XUI initialization. See below.
            // TODO Refactor this so we're not dependent upon this unexpected return.
            return false;
          }
          IPTState objAppDataObject = AppDataObject.GetAppDataObject(0, 0,
           PTConfigHelper.GetApplicationBaseURL(m_asOwner), m_asOwner);
          //Register one model per XUI service.
          for (int indXUI = 0;indXUI < m_alMWSIDs.GetSize();indXUI++)
          {
            IXPPropertyBag pbagSettings = PortalObjectsFactory.CreatePropertyBag();
            // mel: Fix for 46405, Collaboration and Publisher MWS need a way of knowing what zip file will be loaded. Add the REMOTEDATA UUID information to an SCI key for retrieval by the remote MWS.
            //
            // We have to hack around the fact that there's no easy way to update the SCI settings after
            // initialize, so we hold references to the prop bags and update it underneath.
            // Modifying another classes private member data is wrong but post-Martok-GA code freeze
            // there was no better answer.
            // TODO bug# 46427 Provide a clean way to update SCI settings after Initialize.
            mwsSCIPropertyBags.Add(pbagSettings);
            IService xuiService = (IService) xuiManager.OpenXUIService(m_ptSession,
             objAppDataObject, new String[]{_strXUIEditorType}, null, XPConvert.ToInteger(m_alMWSIDs.GetElement(indXUI)),
             XUIHelperMethods.XUI_TIMEOUT_IN_SECONDS);
            m_asOwner.RegisterModel(XUIHelperModel.STR_MVC_CLASS_NAME, XUIHelperModel.STR_MVC_CLASS_NAME + indXUI);
            ((XUIHelperModel) m_asOwner.GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indXUI)).InitializeXUIHelperModel(pbagSettings,
             xuiService);
            ((XUIHelperModel) m_asOwner.GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indXUI)).SetServiceIndex(indXUI);
            int nPageCount = xuiService.GetPageCount();
            htPageCounts.PutElement(indXUI, nPageCount);
            log.Info("Successfully initialized XUI Service: " + xuiService.GetURI());
            }
        }
      }
      catch (Exception e)
      {
        RaiseXUIInitializationError(e);
        success = false;
        // mel: Fix for 46770 reset the MWS list
        // TODO We should not be resetting this in multiple places. See StartXUIServicesSafely
        m_alMWSIDs = new XPArrayList();
        htPageCounts = new XPHashtable();
      }
      // mel: The fix for 46770 (object migration editor does not open
      // if there is a problem with any migration web services)
      // also required pulling out the InitXUIClasses call.
      // Above, there are actually two sections:
      // one for initializing XUI and one for MWS XUI pages.
      // The XUI initialization that happens regardless of whether
      // there are XUI pages must be completed by calling InitXUIClasses.
      // Note that this code depends on there being a return statement above.
      // This must be refactored in the future.
      try
      {
        ((MigrationUtilityAS) m_asOwner).InitXUIClasses(htPageCounts, m_alMWSIDs.GetSize());
        }
      catch (Exception e)
      {
        // Avoid rasing another UI error if one is already raised
        if (success)
        {
          RaiseXUIInitializationError(e);
        } else
        {
          log.Error(e, STR_MVC_CLASS_NAME + " failed to InitXUIClasses");
          }
        success = false;
      }
      return success;
    }
  }
}