using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.areyousure;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility
{
  /// <author>jennifersu</author>
  public abstract class MigrationUtilityRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationRepostControl");
    public const String STR_MVC_CLASS_NAME = "MigrationRepostControl";
    
    /// <summary>
    /// Migration-specific repost actions
    /// </summary>
    public const int POSTTOSELF_ACTION_MIGRATION_START = 10;
    public const int POSTTOSELF_ACTION_MIGRATION_POLL = 11;
    public const int POSTTOSELF_ACTION_MIGRATION_CANCEL = 12;
    public const int POSTTOSELF_ACTION_MIGRATION_DOUPLOAD = 13;
    public const int POSTTOSELF_ACTION_REDIRECT_ON_POPUP = 14;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public abstract override Object Create();
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Sets the editor to perform the Are You Sure popup.
    /// Takes in an XPArrayList of AYSMessages.
    /// </summary>
    protected abstract void PerformAYSPopup();
    
    /// <summary>
    /// Dynamically add javascript to the current DisplayPage.
    /// 1. Open the StatusPopup window
    /// 2. Redirect the main window to m_model.GetRedirectAfterFinish().
    /// </summary>
    public virtual void PerformMigrationPopup()
    {
      try
      {
        HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        XPStringBuilder sb;
        // Construct the ASURL for the popup
        ASURL statusPopup = new ASURL(m_asOwner);
        statusPopup.SetLinkGetCachedSpace(m_asOwner);
        statusPopup.SetDisplayPage(MigrationStatusPopupDP.STR_MVC_CLASS_NAME);
        statusPopup.SetControl(((MigrationUtilityAS) m_asOwner).GetRepostControlName());
        statusPopup.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF,
         POSTTOSELF_ACTION_MIGRATION_START);
        // Javascript: Open the popup
        sb = new XPStringBuilder(200);
        sb.Append("window.open(\'").Append(statusPopup.GetURLAsString()).Append("\', \'Status\', \'scrollbar=yes,resizable=yes,location=no,menubar=no,height=350,width=400\');\n");
        // Add the javascript to the <HEAD> of the current page.
        myScript.AddInnerHTMLString(sb.ToString());
        EditorDP currPage = (EditorDP) m_asOwner.GetCurrentPage();
        currPage.AddScriptToHead(myScript);
      }
      catch (Exception e)
      {
        log.Error(e, "Unknown error attempting to open StatusPopup. e: " + e.Message);
        }
    }
    private bool HasUIErrors()
    {
      IXPEnumerator enumer = UIErrorHandler.GetErrors(m_asOwner.GetSubSession(),
       m_asOwner.GetApplication(), m_asOwner, true, UIErrorHandler.GetDisplayAdminErrors(m_asOwner));
      bool rval = enumer.MoveNext();
      return rval;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int _nAction)
    {
      // Editor repost actions (Finish, Cancel, Change Page, etc.)
      base.PerformAction(_nAction);
      // Migration repost actions
      switch (_nAction){
      case POSTTOSELF_ACTION_FINISH:
      if (PAGE_STATUS_VALID == m_nPageStatus)
      {
        if (!HasUIErrors())
        {
          PerformAYSPopup();
        }
        SetRedirect(null);
      }
      break;
      case POSTTOSELF_ACTION_REDIRECT_ON_POPUP:
      // This gets called when the status window first pops up.
      // This redirects the main window out of the utility.
      SetRedirect(m_model.GetRedirectAfterFinish());
      break;
      case POSTTOSELF_ACTION_MIGRATION_POLL:
      // Poll the status of the migration task 
      Redirect pollRedirect = PollStatus();
      // Display the page if migration is still in progress.
      // Otherwise, redirect to results page.
      SetRedirect(pollRedirect);
      break;
      case POSTTOSELF_ACTION_MIGRATION_CANCEL:
      // Cancel the migration task
      ((MigrationUtilityModel) m_model).CancelMigration();
      // Redirect to the results page.
      Redirect cancelRedirect = new Redirect();
      cancelRedirect.SetLinkGetCachedSpace(m_asOwner);
      cancelRedirect.SetDisplayPage(MigrationResultPopupDP.STR_MVC_CLASS_NAME);
      cancelRedirect.SetControl(((MigrationUtilityAS) m_asOwner).GetRepostControlName());
      SetRedirect(cancelRedirect);
      break;
      case POSTTOSELF_ACTION_MIGRATION_DOUPLOAD:
      // Save page is called before we get here - it may error that the package is not
      // up-to-date (or that the folder's not selected). It shouldn't do that.
      UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      MigrationUtilityModel mainModel = (MigrationUtilityModel) m_model;
      mainModel.DoLoadPackage(m_htFormData);
      break;
      case AreYouSureControl.POSTTOSELF_ACTION_REDIRECT_AFTER_OK:
      PerformMigrationPopup();
      break;
      }
    }
    
    /// <summary>
    /// Polls for the status of the currently running migration task.  Depending on the status,
    /// return an appropriate redirect.
    /// </summary>
    /// <returns>Redirect</returns>
    public abstract Redirect PollStatus();
  }
}