using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility
{
  /// <summary>
  /// This class is what calls the actual server migration code.
  /// It runs in a separate thread to prevent UI timeouts.
  /// </summary>
  /// <author>jennifersu</author>
  public class PTMigrationTask : IXPRunnable
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.PTMigrationTask");
    // Status values for Migration tasks
    public const int CREATED = 0;
    public const int INPROGRESS = 1;
    public const int DONE = 2;
    public const int FAILED = 3;
    public const int CANCEL = 4;
    // Current status
    protected int m_intStatus;
    protected IPTMigrationManager m_MigrationManager;
    
    /// <summary>
    /// Sets status to CREATED.
    /// </summary>
    public PTMigrationTask(IPTMigrationManager _MigrationManager)
    {
      log.Info("Migration Task created.");
      m_MigrationManager = _MigrationManager;
      m_intStatus = CREATED;
    }
    
    /// <summary>
    /// Performs the actual migration.
    /// </summary>
    public virtual void run()
    {
    }
    
    /// <summary>
    /// Gets the current status of the migration task
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetStatus()
    {
      return m_intStatus;
    }
    
    /// <summary>
    /// Sets the status for the migration task to CANCEL
    /// </summary>
    public virtual void Cancel()
    {
      m_intStatus = CANCEL;
      log.Info("Cancelling migration task.");
    }
    // mel: Fix for 46247, When a user exports objects from Collab or Publisher, no feedback is given that this was done. At least provide the UUID of the zip file in the final migration status.
    
    /// <returns>XPArrayList of String each of which represents the return value from an MWS ExportPackage call with info about the MWS. If no MWS's are present or none responded, returns an empty list.</returns>
    public virtual XPArrayList GetMWSMessages()
    {
      return new XPArrayList();
    }
  }
}