using System;
using com.plumtree.server;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.exp
{
  /// <author>jennifersu</author>
  public class DependencyBundle
  {
    
    /// <summary>
    /// The IPTMigrationElement that this is a dependency
    /// bundle for
    /// </summary>
    protected IPTMigrationElement m_ptME;
    
    /// <summary>
    /// XPArrayList of all dependent IPTMigrationElements
    /// </summary>
    protected XPArrayList m_xparDependencies;
    
    /// <summary>
    /// XPHashtable of dependents.
    /// Key=UUID; Value=IPTMigrationElement
    /// </summary>
    protected XPHashtable m_xphtUUIDs;
    
    /// <summary>
    /// Object ID of this IPTMigrationElement
    /// </summary>
    protected int m_nObjectID;
    
    /// <param name="ptME"></param>
    /// <param name="nObjectID"></param>
    public DependencyBundle(IPTMigrationElement ptME, int nObjectID)
    {
      m_ptME = ptME;
      m_xparDependencies = new XPArrayList();
      m_xphtUUIDs = new XPHashtable();
      m_nObjectID = nObjectID;
    }
    
    /// <summary>
    /// Get the IPTMigrationELement that this
    /// bundle depends on
    /// </summary>
    /// <returns>IPTMigrationElement</returns>
    public virtual IPTMigrationElement GetMainObject()
    {
      return m_ptME;
    }
    
    /// <summary>
    /// Get the array list of dependent objects
    /// (IPTMigrationElements)
    /// </summary>
    /// <returns>XPArrayList</returns>
    public virtual XPArrayList GetDependentObjects()
    {
      return m_xparDependencies;
    }
    
    /// <summary>
    /// Get the object ID of the main
    /// IPTMigrationElement
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetMainObjectID()
    {
      return m_nObjectID;
    }
    
    /// <summary>
    /// Adds an IPTMigrationElement as a dependent
    /// on the main object.
    /// </summary>
    /// <param name="ptME"></param>
    public virtual void AddDependentObject(IPTMigrationElement ptME)
    {
      m_xparDependencies.Add(ptME);
      String strUUID = ptME.GetUUID();
      m_xphtUUIDs.PutElement(strUUID, ptME);
    }
    
    /// <summary>
    /// Looks up the UUID to see if it is a dependent
    /// in this bundle.
    /// </summary>
    /// <param name="strUUID"></param>
    /// <returns>boolean</returns>
    public virtual bool DependencyExistsInBundle(String strUUID)
    {
      IPTMigrationElement ptME = (IPTMigrationElement) m_xphtUUIDs.GetElement(strUUID);
      if (null == ptME)
      {
        return false;
      } else
      {
        return true;
      }
    }
  }
}