using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.exp
{
  /// <summary>
  /// Represent global export settings like export parent folders
  /// on the migration export resources page.
  /// </summary>
  public class ExportSettingsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.ExportSettingsView");
    public const String STR_MVC_CLASS_NAME = "ExportSettingsView";
    public const String HTMLCHECKBOX_EXPORT_PARENT_FOLDERS = "in_cb_ExportParentFolders";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ExportSettingsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      try
      {
        IMigrationUtilityExportModelRO modelRO = (IMigrationUtilityExportModelRO) m_model;
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(3183,
         "ptmsgs_portaladminmsgs")));
        myTable = ViewHelper.AddTable(result);
        myTable.SetBorder("0");
        // 1st row (Top Margin)
        ViewHelper.AddEmptyRow(myTable, "3");
        // 2nd row
        DrawCheckBox(myTable, HTMLCHECKBOX_EXPORT_PARENT_FOLDERS, "1", m_asOwner.GetString(3184,
         ResourceConstants.PORTALADMINMSGS), modelRO.IsExportParentFoldersEnabled());
        // last row (spacer row)
        ViewHelper.AddEmptyRow(myTable, "3");
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.GetMessage());
        throw new XPException(STR_MVC_CLASS_NAME + "::Display() Unknown error when trying to display HTML. ",
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
    }
    // Helper Function:
    private void DrawCheckBox(HTMLTable myTable, String strHTMLID, String strValue,
     String strUI, bool bChecked)
    {
      ViewHelper.AddSimpleCheckbox(myTable, 3, strUI, strHTMLID, strValue,
       bChecked, "");
    }
  }
}