using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.condition;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.condition;
using com.plumtree.server.treeiterator;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.exp
{
  /// <author>jennifersu</author>
  public class GlobalObjsTreeModel : ATreeModel,ITreeModel,ITreeModelRO,IRepostModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.GlobalObjsTreeModel");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GlobalObjsTree";
    
    /// <summary>
    /// Tree iterator 
    /// </summary>
    protected IPTTreeIterator m_ptIterator = null;
    
    /// <summary>
    /// Fake folder ID for all global maps
    /// </summary>
    private const int FOLDER_ID_MAPS = 0;
    
    /// <summary>
    /// Fake folder ID for all activity rights
    /// </summary>
    private const int FOLDER_ID_ACTIVITY_RIGHTS = 1;
    
    /// <summary>
    /// Fake folder ID for all subportal rules
    /// </summary>
    private const int FOLDER_ID_SUBPORTAL_RULES = 2;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GlobalObjsTreeModel();
    }
    
    /// <summary>
    /// This method expands a node in the tree
    /// </summary>
    /// <param name="bExpand">whether to expand or collapse (true implies expand)</param>
    /// <param name="nNodeID">the ID of the node to expand</param>
    public override void ExpandNode(bool bExpand, int nNodeID)
    {
      int nObjectID;
      base.ExpandNode(bExpand, nNodeID);
      TreeCompositeNode node = (TreeCompositeNode) m_Root.GetNode(nNodeID);
      if (node == null)
      {
        log.Error("Could not find node ID " + nNodeID);
        return;
      }
      node.m_bExpanded = bExpand;
      if ((node.m_bChildrenLoaded == false) && bExpand)
      {
        IASQueryResult query = null;
        TreeCompositeNode myFolder;
        TreeLeafNode myLeaf;
        if (node == m_Root)
        {
          int nFolderType;
          // Add Activity Rights folder
          myFolder = GetCompositeIfAlreadySelected(PT_CLASSIDS.PT_ACTIVITY_ID + "," + FOLDER_ID_ACTIVITY_RIGHTS);
          if (myFolder == null)
          {
            myFolder = new TreeCompositeNode(GetNextUniqueID());
            String activityRightsName = m_asOwner.GetString(397, ResourceConstants.PORTALADMINMSGS);
            myFolder.SetName(activityRightsName);
            myFolder.SetDescription(activityRightsName);
            myFolder.m_nObjectID = FOLDER_ID_ACTIVITY_RIGHTS;
            myFolder.m_nClassID = PT_CLASSIDS.PT_ACTIVITY_ID;
          }
          myFolder.m_bBrowsableOnly = true;
          node.AddCompositeChild(myFolder);
          log.Debug("In node " + nNodeID + ", loaded composite child " + myFolder.GetEncodedName());
          // Add Default Profiles Folder
          myFolder = GetCompositeIfAlreadySelected(PT_CLASSIDS.PT_USER_ID + "," + PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES);
          if (myFolder == null)
          {
            myFolder = new TreeCompositeNode(GetNextUniqueID());
            String defaultProfilesName = m_asOwner.GetString(1725, ResourceConstants.PORTALADMINMSGS);
            myFolder.SetName(defaultProfilesName);
            myFolder.SetDescription(defaultProfilesName);
            myFolder.m_nObjectID = PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES;
            myFolder.m_nClassID = PT_CLASSIDS.PT_USER_ID;
          }
          myFolder.m_bBrowsableOnly = true;
          node.AddCompositeChild(myFolder);
          log.Debug("In node " + nNodeID + ", loaded composite child " + myFolder.GetEncodedName());
          // Add Subportal Rules Folder
          myFolder = GetCompositeIfAlreadySelected(PT_CLASSIDS.PT_EXPRESSION_ID + "," + FOLDER_ID_SUBPORTAL_RULES);
          if (myFolder == null)
          {
            myFolder = new TreeCompositeNode(GetNextUniqueID());
            String experienceDefinitionName = m_asOwner.GetString(2229, ResourceConstants.PORTALADMINMSGS);
            myFolder.SetName(experienceDefinitionName);
            myFolder.SetDescription(experienceDefinitionName);
            myFolder.m_nObjectID = FOLDER_ID_SUBPORTAL_RULES;
            myFolder.m_nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
          }
          myFolder.m_bBrowsableOnly = true;
          node.AddCompositeChild(myFolder);
          log.Debug("In node " + nNodeID + ", loaded composite child " + myFolder.GetEncodedName());
          // Add Global Maps Folder
          myFolder = GetCompositeIfAlreadySelected(PT_CLASSIDS.PT_GLOBALOBJECT_ID + "," + FOLDER_ID_MAPS);
          if (myFolder == null)
          {
            myFolder = new TreeCompositeNode(GetNextUniqueID());
            String globalMapsName = m_asOwner.GetString(3186, ResourceConstants.PORTALADMINMSGS);
            myFolder.SetName(globalMapsName);
            myFolder.SetDescription(globalMapsName);
            myFolder.m_nObjectID = FOLDER_ID_MAPS;
            myFolder.m_nClassID = PT_CLASSIDS.PT_GLOBALOBJECT_ID;
          }
          myFolder.m_bBrowsableOnly = true;
          node.AddCompositeChild(myFolder);
        }
        // Expand Activity Rights folder
        if (node.m_nObjectID == FOLDER_ID_ACTIVITY_RIGHTS)
        {
          // Get all Activity RIghts
          IPTQueryResult ptQRRights = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().QueryActivityRights();
          if (null != ptQRRights)
          {
            PTSortedArrayWrapper sortedRights;
            // create sort by name.		
            int[][] arrSort = new int[1][];
            for (int j2c_index = 0;j2c_index < 1;j2c_index++)
            {
              arrSort[j2c_index] = new int[2];
            }
            arrSort[0][0] = PT_PROPIDS.PT_PROPID_NAME;
            arrSort[0][1] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
            // use helper class to sort data by name.
            sortedRights = new PTSortedArrayWrapper();
            sortedRights.Initialize(ptQRRights.Columns(), ptQRRights.Data(),
             arrSort, true);
            for (int ii = 0;ii < sortedRights.GetCount();ii++)
            {
              nObjectID = XPConvert.ToInteger(sortedRights.GetItem(ii, PT_PROPIDS.PT_PROPID_OBJECTID));
              // Only custom activity rights are migratable
              if (nObjectID > PT_SERVERCONSTANTS.PT_MAX_READONLYINTRINSIC_OBJECTID)
              {
                myLeaf = GetLeafIfAlreadySelected(PT_CLASSIDS.PT_ACTIVITY_ID + "," + nObjectID);
                if (myLeaf == null)
                {
                  myLeaf = new TreeLeafNode(GetNextUniqueID());
                  myLeaf.SetName(XPConvert.ToString(sortedRights.GetItem(ii,
                   PT_PROPIDS.PT_PROPID_NAME)));
                  myLeaf.m_nObjectID = nObjectID;
                  myLeaf.m_nClassID = PT_CLASSIDS.PT_ACTIVITY_ID;
                  myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ACTIVITY_RIGHT_CUSTOM).GetHTMLElement();
                  }
                node.AddLeafChild(myLeaf);
              }
            }
          }
        } else
        if (node.m_nObjectID == PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES)
        {
          // Get the correct query filter
          IPTObjectManager userObjMgr = (IPTObjectManager) ((IPTSession) m_asOwner.GetUserSession()).GetUsers();
          ObjectManagerHolder omHolder = new ObjectManagerHolder(userObjMgr);
          Object[][] ptqf = omHolder.m_ptqf;
          PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(omHolder.m_ptObjMgr);
          omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_USER_LOGINNAME,
           node.m_nObjectID, null, ptqf);
          query = omqw;
          int nCount = query.GetCount();
          for (int i = 0;i < nCount;i++)
          {
            nObjectID = XPConvert.ToInteger(query.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
            myLeaf = GetLeafIfAlreadySelected(omHolder.m_nManagedClassID + "," + nObjectID);
            if (myLeaf == null)
            {
              myLeaf = new TreeLeafNode(GetNextUniqueID());
              if (omHolder.m_nManagedClassID == PT_CLASSIDS.PT_USER_ID)
              {
                // Display both the human readable name and the loginname
                myLeaf.SetName((String) query.GetFields(i, PT_PROPIDS.PT_PROPID_NAME) + " (" + query.GetFields(i,
                 PT_PROPIDS.PT_PROPID_USER_LOGINNAME) + ")");
              } else
              {
                myLeaf.SetName((String) query.GetFields(i, PT_PROPIDS.PT_PROPID_NAME));
                }
              myLeaf.SetDescription(XPConvert.ToString(query.GetFields(i,
               PT_PROPIDS.PT_PROPID_DESCRIPTION)));
              myLeaf.m_nObjectID = nObjectID;
              myLeaf.m_nClassID = omHolder.m_ptObjMgr.GetManagedClassID();
              myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_USER).GetHTMLElement();
              }
            if (omHolder.m_nManagedClassID == PT_CLASSIDS.PT_USER_ID)
            {
              myLeaf.m_bMultiplyInstanced = true;
            }
            node.AddLeafChild(myLeaf);
            log.Debug("In node " + nNodeID + ", loaded leaf child " + myLeaf.GetEncodedName());
            }
        } else
        if (node.m_nObjectID == FOLDER_ID_MAPS)
        {
          // Array of migratable Global Maps
          int[] intGlobalObjIDs = {PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
           PT_GLOBALOBJECTS.PT_GLOBAL_DOCUMENTTYPEMAP, PT_GLOBALOBJECTS.PT_GLOBAL_PROPERTYMAP};
          for (int indGlobal = 0;indGlobal < intGlobalObjIDs.Length;indGlobal++)
          {
            nObjectID = intGlobalObjIDs[indGlobal];
            myLeaf = GetLeafIfAlreadySelected(PT_CLASSIDS.PT_GLOBALOBJECT_ID + "," + nObjectID);
            if (myLeaf == null)
            {
              myLeaf = new TreeLeafNode(GetNextUniqueID());
              myLeaf.SetName(GetLocalizedNameForGlobalObject(nObjectID));
              myLeaf.SetDescription(GetLocalizedDescriptionForGlobalObject(nObjectID));
              myLeaf.m_nObjectID = nObjectID;
              myLeaf.m_nClassID = PT_CLASSIDS.PT_GLOBALOBJECT_ID;
              myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_RESOURCE).GetHTMLElement();
              }
            node.AddLeafChild(myLeaf);
            log.Debug("In node " + nNodeID + ", loaded leaf child " + myLeaf.GetEncodedName());
            }
        } else
        if (node.m_nObjectID == FOLDER_ID_SUBPORTAL_RULES)
        {
          PortalObjectsFactory.GetExpressionEngineInstance().LoadExpressionsLite(ActionTypeEnum.SUBPORTAL);
          XPArrayList xpItemList = PortalObjectsFactory.GetExpressionEngineInstance().GetExpressionList(ActionTypeEnum.SUBPORTAL);
          IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
          for (int i = 0;i < xpItemList.GetSize();i++)
          {
            int[] arExpression = (int[]) xpItemList.GetElement(i);
            try
            {
              IPTExpressionInfo ptInfo = ptExpressionManager.CachedOpenExpressionInfo(arExpression[0]);
              nObjectID = ptInfo.GetObjectID();
              myLeaf = GetLeafIfAlreadySelected(PT_CLASSIDS.PT_EXPRESSION_ID + "," + nObjectID);
              if (myLeaf == null)
              {
                myLeaf = new TreeLeafNode(GetNextUniqueID());
                myLeaf.SetName(ptInfo.GetName());
                myLeaf.m_nObjectID = nObjectID;
                myLeaf.m_nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
                myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SUBPORTAL_RULE).GetHTMLElement();
                }
              node.AddLeafChild(myLeaf);
            }
            catch (Exception e)
            {
              log.Error("Could not retrieve expression with ID: " + arExpression[0] + " The following exception occured: " + e);
              }
          }
        }
        node.m_bChildrenLoaded = true;
        log.Info("Loaded children of folder # " + nNodeID);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
    }
    
    /// <summary>
    /// Initializes and begins the loading of the tree.
    /// </summary>
    public virtual void LoadObjects()
    {
      // Root is simply a dummy title
      m_Root = new TreeCompositeNode(GetNextUniqueID());
      m_Root.SetName(m_asOwner.GetString(1530, "ptmsgs_portaladminmsgs"));
      if (!m_bShowRoot)
      {
        ExpandNode(true, m_Root.m_nTreeNodeID);
      }
    }
    
    /// <summary>
    /// If there are multiple class ids, determine which
    /// ones to display.  For activity rights, we only
    /// have 1 class id, so this method is unimplemented.
    /// </summary>
    /// <param name="nIDs">determines which classids to display</param>
    public override void SetClassIDsToDisplay(int[] nIDs)
    {
    }
    
    /// <summary>
    /// Determines what items in the tree are to be displayed.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToDisplay(int[])"></seealso>
    /// <param name="nIDs">determines which nodes are not hidden.</param>
    public override void SetObjectIDsToDisplay(int[] nIDs)
    {
    }
    
    /// <summary>
    /// Determines what items in the tree are hidden.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToHide(int[])"></seealso>
    /// <param name="nIDs">determines which nodes are hidden</param>
    public override void SetObjectIDsToHide(int[] nIDs)
    {
    }
    
    /// <summary>
    /// Determines what items in the tree are selected.
    /// </summary>
    /// <param name="nIDs">determines which nodes are selected</param>
    public override void SetObjectIDsToSelect(int[] nIDs)
    {
      if (m_Root != null)
      {
        // we are refreshing selected items, so we clear all old items.
        // clear all selected items
        m_Root.ClearSelected(false, true);
        m_xpmSelectedItems.Clear();
      }
      PTObjectManagerQueryWrapper omqw;
      TreeLeafNode node;
      IPTAdminFolder folder;
      int nObjectID;
      for (int i = 0;(i + 1) < nIDs.Length;i+=2)
      {
        if (nIDs[i] == PT_CLASSIDS.PT_ACTIVITY_ID)
        {
          node = null;
          if (m_Root != null)
          {
            // Since we are refreshing, the object may already exist
            // Check if the object is already in the tree
            node = m_Root.GetNode(nIDs[i], nIDs[i + 1]);
          }
          if (node == null)
          {
            // Add leaf node children
            IPTQueryResult ptQRRights = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().QueryActivityRights();
            if (null != ptQRRights)
            {
              PTSortedArrayWrapper sortedRights;
              // create sort by name.		
              int[][] arrSort = new int[1][];
              for (int j2c_index = 0;j2c_index < 1;j2c_index++)
              {
                arrSort[j2c_index] = new int[2];
              }
              arrSort[0][0] = PT_PROPIDS.PT_PROPID_NAME;
              arrSort[0][1] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
              // use helper class to sort data by name.
              sortedRights = new PTSortedArrayWrapper();
              sortedRights.Initialize(ptQRRights.Columns(), ptQRRights.Data(),
               arrSort, true);
              for (int ii = 0;ii < sortedRights.GetCount();ii++)
              {
                nObjectID = XPConvert.ToInteger(sortedRights.GetItem(ii, PT_PROPIDS.PT_PROPID_OBJECTID));
                if (nObjectID == nIDs[i + 1])
                {
                  node = new TreeLeafNode(-1);
                  node.SetName(XPConvert.ToString(sortedRights.GetItem(ii,
                   PT_PROPIDS.PT_PROPID_NAME)));
                  node.m_nObjectID = nObjectID;
                  node.m_nClassID = PT_CLASSIDS.PT_ACTIVITY_ID;
                  node.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ACTIVITY_RIGHT_CUSTOM).GetHTMLElement();
                  break;
                }
              }
            }
          }
          if (node != null)
          {
            node.m_bSelected = true;
            m_xpmSelectedItems.PutElement(GetKeyFromNode(node), node);
          } else
          {
            log.Error("Unable to find global object (ObjectID " + nIDs[i + 1] + ").");
            }
        } else
        if (nIDs[i] == PT_CLASSIDS.PT_USER_ID)
        {
          node = null;
          if (m_Root != null)
          {
            // Since we are refreshing, the object may already exist
            // Check if the object is already in the tree
            node = m_Root.GetNode(nIDs[i], nIDs[i + 1]);
          }
          if (node == null)
          {
            // Get the correct query filter
            // TODO: fix this so we don't set ptqf in the result
            IPTObjectManager userObjMgr = (IPTObjectManager) ((IPTSession) m_asOwner.GetUserSession()).GetUsers();
            ObjectManagerHolder omHolder = new ObjectManagerHolder(userObjMgr);
            Object[][] ptqf = omHolder.m_ptqf;
            omqw = new PTObjectManagerQueryWrapper(omHolder.m_ptObjMgr);
            omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_USER_LOGINNAME,
             PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES, null, ptqf);
            IASQueryResult query = omqw;
            int nCount = query.GetCount();
            for (int indObj = 0;indObj < nCount;indObj++)
            {
              nObjectID = XPConvert.ToInteger(query.GetFields(indObj, PT_PROPIDS.PT_PROPID_OBJECTID));
              if (nObjectID == nIDs[i + 1])
              {
                node = new TreeLeafNode(-1);
                if (omHolder.m_nManagedClassID == PT_CLASSIDS.PT_USER_ID)
                {
                  // Display both the human readable name and the loginname
                  node.SetName((String) query.GetFields(indObj, PT_PROPIDS.PT_PROPID_NAME) + " (" + query.GetFields(indObj,
                   PT_PROPIDS.PT_PROPID_USER_LOGINNAME) + ")");
                } else
                {
                  node.SetName((String) query.GetFields(indObj, PT_PROPIDS.PT_PROPID_NAME));
                  }
                //TODO: Should all of these String casts use XPConvert.ToString?
                node.SetDescription((String) query.GetFields(indObj, PT_PROPIDS.PT_PROPID_DESCRIPTION));
                node.m_nObjectID = nObjectID;
                node.m_nClassID = omHolder.m_ptObjMgr.GetManagedClassID();
                node.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_USER).GetHTMLElement();
                }
            }
          }
          if (node != null)
          {
            node.m_bSelected = true;
            m_xpmSelectedItems.PutElement(GetKeyFromNode(node), node);
          } else
          {
            log.Error("Unable to find global object (ObjectID " + nIDs[i + 1] + ").");
            }
        } else
        if (nIDs[i] == PT_CLASSIDS.PT_GLOBALOBJECT_ID)
        {
          node = null;
          if (m_Root != null)
          {
            // Since we are refreshing, the object may already exist
            // Check if the object is already in the tree
            node = m_Root.GetNode(nIDs[i], nIDs[i + 1]);
          }
          if (node == null)
          {
            int[] intGlobalObjIDs = {PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
             PT_GLOBALOBJECTS.PT_GLOBAL_DOCUMENTTYPEMAP, PT_GLOBALOBJECTS.PT_GLOBAL_PROPERTYMAP};
            for (int indGlobal = 0;indGlobal < intGlobalObjIDs.Length;indGlobal++)
            {
              nObjectID = intGlobalObjIDs[indGlobal];
              if (nObjectID == nIDs[i + 1])
              {
                node = new TreeLeafNode(-1);
                node.SetName(GetLocalizedNameForGlobalObject(nObjectID));
                node.SetDescription(GetLocalizedDescriptionForGlobalObject(nObjectID));
                node.m_nObjectID = nObjectID;
                node.m_nClassID = PT_CLASSIDS.PT_GLOBALOBJECT_ID;
                node.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_RESOURCE).GetHTMLElement();
                }
            }
          }
          if (node != null)
          {
            node.m_bSelected = true;
            m_xpmSelectedItems.PutElement(GetKeyFromNode(node), node);
          } else
          {
            log.Error("Unable to find global object (ObjectID " + nIDs[i + 1] + ").");
            }
        } else
        if (nIDs[i] == PT_CLASSIDS.PT_EXPRESSION_ID)
        {
          node = null;
          if (m_Root != null)
          {
            // Since we are refreshing, the object may already exist
            // Check if the object is already in the tree
            node = m_Root.GetNode(nIDs[i], nIDs[i + 1]);
          }
          if (node == null)
          {
            try
            {
              IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).GetExpressions();
              IPTExpressionInfo ptInfo = ptExpressionManager.CachedOpenExpressionInfo(nIDs[i + 1]);
              nObjectID = ptInfo.GetObjectID();
              if (nObjectID == nIDs[i + 1])
              {
                node = new TreeLeafNode(-1);
                node.SetName(ptInfo.GetName());
                node.m_nObjectID = nObjectID;
                node.m_nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
                node.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SUBPORTAL_RULE).GetHTMLElement();
                }
            }
            catch (Exception e)
            {
              log.Error("Could not retrieve expression with ID: " + nIDs[i + 1] + " The following exception occured: " + e);
              }
          }
          if (node != null)
          {
            node.m_bSelected = true;
            m_xpmSelectedItems.PutElement(GetKeyFromNode(node), node);
          } else
          {
            log.Error("Unable to find global object (ObjectID " + nIDs[i + 1] + ").");
            }
        }
      }
    }
    private String GetLocalizedNameForGlobalObject(int nGlobalObjectID)
    {
      String strName;
      switch (nGlobalObjectID){
      case PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP:
      strName = m_asOwner.GetString(1547, "ptmsgs_portaladminmsgs");
      break;
      case PT_GLOBALOBJECTS.PT_GLOBAL_DOCUMENTTYPEMAP:
      strName = m_asOwner.GetString(1545, "ptmsgs_portaladminmsgs");
      break;
      case PT_GLOBALOBJECTS.PT_GLOBAL_PROPERTYMAP:
      strName = m_asOwner.GetString(1546, "ptmsgs_portaladminmsgs");
      break;
      default:
      strName = null;
      break;
      }
      return strName;
    }
    private String GetLocalizedDescriptionForGlobalObject(int nGlobalObjectID)
    {
      String strDesc;
      switch (nGlobalObjectID){
      case PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP:
      strDesc = m_asOwner.GetString(1547, "ptmsgs_portaladminmsgs");
      break;
      case PT_GLOBALOBJECTS.PT_GLOBAL_DOCUMENTTYPEMAP:
      strDesc = m_asOwner.GetString(1545, "ptmsgs_portaladminmsgs");
      break;
      case PT_GLOBALOBJECTS.PT_GLOBAL_PROPERTYMAP:
      strDesc = m_asOwner.GetString(1546, "ptmsgs_portaladminmsgs");
      break;
      default:
      strDesc = null;
      break;
      }
      return strDesc;
    }
    
    /// <summary>
    /// Helper class to wrap object managers
    /// </summary>
    /// <author>Don Hayler</author>
    public class ObjectManagerHolder
    {
      public IPTObjectManager m_ptObjMgr;
      public int[] m_nHiddenObjectIDs;
      public int[] m_nDisplayedObjectIDs;
      public Object[][] m_ptqf;
      public int m_nManagedClassID = -1;
      
      /// <summary>
      /// Creates a new ObjectManagerHolder object.
      /// </summary>
      /// <param name="ptObjMgr"></param>
      public ObjectManagerHolder(IPTObjectManager ptObjMgr)
      {
        m_ptObjMgr = ptObjMgr;
        if (m_ptObjMgr != null)
        {
          m_nManagedClassID = m_ptObjMgr.GetManagedClassID();
        }
        m_nHiddenObjectIDs = null;
        m_nDisplayedObjectIDs = null;
        m_ptqf = null;
      }
      
      /// <summary>
      /// This returns whether or not the object should be hidden
      /// </summary>
      /// <param name="nID">nID the object ID of the object to check</param>
      /// <returns>boolean true implies hidden, false implies visible</returns>
      public virtual bool HiddenObject(int nID)
      {
        if (m_nHiddenObjectIDs != null)
        {
          for (int i = 0;i < m_nHiddenObjectIDs.Length;i++)
          {
            if (nID == m_nHiddenObjectIDs[i])
            {
              return true;
            }
          }
        }
        return false;
      }
    }
    
    /// <summary>
    /// This method calculates the read only query filter.
    /// </summary>
    /// <param name="int">the access level required by the tree</param>
    /// <returns>the qf.</returns>
    protected virtual Object[][] CalculateFolderSelectQueryFilter(int nAccessLevel)
    {
      // This implementation will break if a new access level is
      // added because of the way the IN filter operator works.
      Object[][] result = null;
      if (nAccessLevel >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT)
      {
        Object[] nLevels = null;
        switch (nAccessLevel){
        case PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT:
        nLevels = new Object[3];
        nLevels[0] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT;
        nLevels[1] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT;
        nLevels[2] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
        break;
        case PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT:
        nLevels = new Object[2];
        nLevels[0] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT;
        nLevels[1] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
        break;
        case PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN:
        nLevels = new Object[1];
        nLevels[0] = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
        break;
        default:
        // Unknown access level.  Ignore.
        break;
        }
        if (nLevels != null)
        {
          result = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_ACCESSLEVEL,
           PT_FILTEROPS.PT_FILTEROP_IN, nLevels);
        }
      }
      return result;
    }
  }
}