using System;
using com.plumtree.openlog;
using XPFile=com.plumtree.openfoundation.io.XPFile;
using com.plumtree.openfoundation.util;
using XPHttpUtility=com.plumtree.openfoundation.web.XPHttpUtility;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using ResourceConstants=com.plumtree.uiinfrastructure.constants.ResourceConstants;
using com.plumtree.uiinfrastructure.filedownload;
using PTStyleClass=com.plumtree.xpshared.htmlconstructs.PTStyleClass;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.exp
{
  public class MigrationDownloadFilePopupDP : IDisplayPage
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.MigrationDownloadFilePopupDP");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MigrationDownloadFilePopupDP";
    
    /// <summary>
    /// HTML Object name: close button 
    /// </summary>
    public const String HTMLBUTTON_CLOSE = "in_bu_Close";
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    private AFileDownloadAS m_asOwner;
    
    /// <summary>
    /// Associated read-only Model.
    /// </summary>
    private FileDownloadModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new MigrationDownloadFilePopupDP();
    }
    
    /// <summary>
    /// Add the MWS messages (return value from ExportPackage + info about the MWS)
    /// to the HTML table if there are any. Has no effect if there are no messages.
    /// Errors are logged but not thrown.
    /// </summary>
    private void AddMWSMessages(HTMLTable myMainTable)
    {
      try
      {
        XPArrayList mwsMessages = (XPArrayList) m_asOwner.GetSubSession().GetAttribute(MigrationExportRepostControl.MWS_MESSAGES_SESSION_KEY);
        if (mwsMessages == null || mwsMessages.IsEmpty())
        {
          // The table remains unchanged since we have no MWS messages
          return;
        }
        // The following Migration Web Service(s) created external files that are needed for later import:
        String mwsFilesInfoMessage = m_asOwner.GetString(3188, ResourceConstants.PORTALADMINMSGS);
        mwsMessages.Insert(0, mwsFilesInfoMessage);
        IXPEnumerator enumer = mwsMessages.GetEnumerator();
        while (enumer.MoveNext())
        {
          String mwsExportReturnValue = (String) enumer.GetCurrent();
          HTMLTableRow tableRow = new HTMLTableRow();
          // Spacer cell
          {
            HTMLTableCell cell = new HTMLTableCell();
            tableRow.AddInnerHTMLElement(cell);
            cell.SetWidth("15");
          }
          // Message cell
          {
            HTMLTableCell cell = new HTMLTableCell();
            cell.SetVAlign("bottom");
            cell.SetAlign("center");
            tableRow.AddInnerHTMLElement(cell);
            cell.SetNoWrap(false);
            HTMLSpan span = new HTMLSpan();
            cell.AddInnerHTMLElement(span);
            span.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
            // Add MWS message
            span.AddInnerHTMLString(mwsExportReturnValue);
          }
          // Spacer cell
          {
            HTMLTableCell cell = new HTMLTableCell();
            tableRow.AddInnerHTMLElement(cell);
            cell.SetWidth("15");
          }
          // Add row to table
          myMainTable.AddInnerHTMLElement(tableRow);
        }
      }
      catch (Exception anyException)
      {
        log.Error(anyException, STR_MVC_CLASS_NAME + " failed to add Migration Web Services messsages.");
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(IWebData)"></seealso>
    public virtual void Display(IWebData webData)
    {
      HTMLPage myPage = new HTMLPage();
      // Set the HTMLPage as the data to be sent to the browser.
      webData.SetData(myPage);
      HTMLHead myHead = new HTMLHead();
      myPage.SetHead(myHead);
      //		GetFormTitle should already be encoded.
      HTMLTitle myTitle = new HTMLTitle(m_asOwner.GetString(582, ResourceConstants.PORTALBROWSINGMSGS));
      HTMLBody myBody = new HTMLBody();
      myBody.SetMarginWidth("0");
      myBody.SetMarginHeight("0");
      myBody.SetLeftMargin("0");
      myBody.SetTopMargin("0");
      myPage.SetBody(myBody);
      HTMLTable myMainTable;
      HTMLTableRow myMainTableRow;
      HTMLTableCell myMainTableCell;
      HTMLInput myInput;
      HTMLAnchor myAnchor;
      try
      {
        // AGC - Create the URL that actually commits a download.
        ASURL asurlDownload = new ASURL(m_asOwner);
        asurlDownload.SetLinkCreateNewSpace(AFileDownloadAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        asurlDownload.SetDisplayPage(DownloadBinaryDP.STR_MVC_CLASS_NAME);
        asurlDownload.SetControl(FileDownloadControl.STR_MVC_CLASS_NAME);
        asurlDownload.AddControlArgument(FileDownloadControl._QS_FD_CONTENT_TYPE,
         "application/octet-stream");
        asurlDownload.AddControlArgument(FileDownloadControl._QS_FD_SESSION_KEY,
         ((FileDownloadModel) m_model).GetSessionKeyToDownload());
        myHead.AddInnerHTMLElement(myTitle);
        // <META  HTTP-EQUIV="REFRESH" CONTENT="0; URL=http://www.redmeat.com">
        HTMLMeta myMeta = new HTMLMeta("2;URL=" + asurlDownload.GetURLAsString());
        myMeta.SetHTTPEquiv("REFRESH");
        myHead.AddInnerHTMLElement(myMeta);
        // Add the stylesheets.
        myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
        // Main table
        myMainTable = new HTMLTable();
        myBody.AddInnerHTMLElement(myMainTable);
        myMainTable.SetWidth("100%");
        myMainTable.SetHeight("100%");
        myMainTable.SetBorder("0");
        myMainTable.SetCellPadding("0");
        myMainTable.SetCellSpacing("0");
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetColSpan("3");
        myMainTableCell.SetHeight("10%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // 1st Row: Status display
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableCell.SetVAlign("bottom");
        myMainTableCell.SetAlign("center");
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetNoWrap(true);
        HTMLSpan mySpan = new HTMLSpan();
        myMainTableCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        // Migration Status: Successful
        mySpan.AddInnerHTMLString(m_asOwner.GetString(2755, "ptmsgs_portaladminmsgs"));
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        // Row 2 - begin
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableCell.SetAlign("center");
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        String strFileToDownload = (String) m_asOwner.GetSubSession().GetAttribute(m_model.GetSessionKeyToDownload());
        XPFile xpf = new XPFile(strFileToDownload);
        myAnchor = new HTMLAnchor(asurlDownload.GetURLAsString());
        myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(xpf.GetName()));
        myMainTableCell.AddInnerHTMLElement(myAnchor);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        // Rows: Migration Web Services messages
        AddMWSMessages(myMainTable);
        // 3rd Row: Close button
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetAlign("right");
        mySpan = new HTMLSpan();
        myMainTableCell.AddInnerHTMLElement(mySpan);
        HTMLInput cancelButton = new HTMLInput(HTMLInputTypes.BUTTON_TYPE,
         m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
        cancelButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        cancelButton.SetValue(m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
        cancelButton.SetOnClick("window.close();");
        mySpan.AddInnerHTMLElement(cancelButton);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // Main table = row 3
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("15");
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetColSpan("3");
        myMainTableCell.SetHeight("20%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // AGC- Now add our javascript
        HTMLScript myScript = DisplayJavascript();
        myHead.AddInnerHTMLElement(myScript);
      }
      catch (Exception e)
      {
        log.Error(e, "Display An error occured when trying to display the HTML.");
        throw new XPException(m_asOwner.GetString(585, ResourceConstants.PORTALADMINMSGS),
         e);
      }
      webData.SetData(myPage);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        sb = new XPStringBuilder(300);
        // AGC- redirect the parent window when we popup.
        sb.Append("  window.opener.postToSelf(\'" + FileDownloadControl.POSTTOSELF_ACTION_REDIRECT_AFTER_DOWNLOAD + "\'); \n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript An error occured when trying to display the JavaScript.");
        }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()"></seealso>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_model = (FileDownloadModel) parent.GetModel(FileDownloadModel.STR_MVC_CLASS_NAME);
      m_asOwner = (AFileDownloadAS) parent;
    }
  }
}