using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.migrationutility;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.exp
{
  /// <author>jennifersu</author>
  public class MigrationSelectForExportModel : SelectPTObjectModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.MigrationSelectForExportModel");
    public const String STR_MVC_CLASS_NAME = "MigrationSelectForExportModel";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 9;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_FOLDER_CONTENTS = 4;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_DEPENDENCIES = 5;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_TYPE = 6;
    
    /// <summary>
    /// This column contains the migration submitter.
    /// </summary>
    public const int EXPLIST_COL_SUBMITTED_BY = 7;
    
    /// <summary>
    /// This column contains the description
    /// </summary>
    public const int EXPLIST_COL_DESCRIPTION = 8;
    
    /// <summary>
    /// Column widths for the various columns.
    /// </summary>
    public const String ICON_COLUMN_WIDTH = "20";
    public const String NAME_COLUMN_WIDTH = "60%";
    public const String SUBMITTED_BY_COLUMN_WIDTH = "10%";
    public const String CONTENTS_COLUMN_WIDTH = "15%";
    public const String DEPENDENCIES_COLUMN_WIDTH = "15%";
    
    /// <summary>
    /// Hashtable to keep track of which objects have already
    /// been added to the list of objects to migrate.
    /// key=classid,objectid; value=name string.
    /// </summary>
    protected XPHashtable m_htObjsToMigrate;
    
    /// <summary>
    /// Tree Space ID. The first time the ID is empty and a new AS is opened,
    /// but after that, we save the ID and the same tree AS is reopened each time. 
    /// </summary>
    protected String m_sAdminTreeSpaceID = "";
    
    /// <summary>
    /// Tree Space ID. The first time the ID is empty and a new AS is opened,
    /// but after that, we save the ID and the same tree AS is reopened each time. 
    /// </summary>
    protected String m_sDirTreeSpaceID = "";
    
    /// <summary>
    /// Tree Space ID. The first time the ID is empty and a new AS is opened,
    /// but after that, we save the ID and the same tree AS is reopened each time. 
    /// </summary>
    protected String m_sGlobalTreeSpaceID = "";
    
    /// <summary>
    /// Current username.  Used for the SubmittedBy column.
    /// </summary>
    protected String m_sCurrentUser = "";
    
    /// <summary>
    /// HTML dropdown value for filtering on all.
    /// </summary>
    public const int TYPE_ADMIN_OBJ = 0;
    
    /// <summary>
    /// HTML dropdown value for filtering on admin disabled.
    /// </summary>
    public const int TYPE_DIRECTORY = 1;
    
    /// <summary>
    /// HTML dropdown value for filtering on agent disabled.
    /// </summary>
    public const int TYPE_GLOBAL = 2;
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_KEY_ADMINTREE = "AdminObjTree";
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_KEY_DIRTREE = "DirTree";
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_KEY_GLOBALTREE = "GlobalObjTree";
    
    /// <summary>
    /// Inits member variables
    /// </summary>
    public MigrationSelectForExportModel() : base()
    {
      // Want to be able to select leaf nodes and folders
      m_treeLeafType = TreeConstants.N_LEAFCOMPOSITESELECT;
      m_htObjsToMigrate = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationSelectForExportModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.ISelectPTObjectModelRO#GetTreeMultiSelect()"></seealso>
    public override String GetTreeMultiSelect()
    {
      return XPConvert.ToString(true);
    }
    
    /// <summary>
    /// "Resources to Export"
    /// </summary>
    public override String GetTreeTitle()
    {
      return m_asOwner.GetString(479, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <summary>
    /// Initializes and starts the list of 
    /// objects to export.
    /// </summary>
    public virtual void InitSFE(IPTSession ptSession)
    {
      m_sCurrentUser = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserName();
      InitializeSelectForExport(m_asOwner.GetString(480, "ptmsgs_portalbrowsingmsgs"),
       m_asOwner.GetString(481, "ptmsgs_portalbrowsingmsgs"), PTImageType.ACTION_ADD,
       m_asOwner.GetString(482, "ptmsgs_portalbrowsingmsgs"), PT_MIGRATION_CLASSES.SUPPORTED_CLASSES,
       999);
      SetEmptyListMessages(m_asOwner.GetString(483, "ptmsgs_portalbrowsingmsgs"),
       m_asOwner.GetString(1894, "ptmsgs_portalbrowsingmsgs"));
      // Can only export objects that the user has at least
      // EDIT rights to.
      SetAccessLevel(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
      SetAddIcon(PTImageType.ICON_RESOURCE);
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeSelectForExport(String _sSectionTitle, String _sSectionSubTitle,
     PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs,
     int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[4][];
      for (int j2c_index = 0;j2c_index < 4;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = NAME_COLUMN_WIDTH;
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_SUBMITTED_BY;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(26,
       "ptmsgs_infrastructure");
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = SUBMITTED_BY_COLUMN_WIDTH;
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[2][EXPLIST_COLUMN_ID] = EXPLIST_COL_FOLDER_CONTENTS;
      arrExpListColInfo[2][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2790,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH] = CONTENTS_COLUMN_WIDTH;
      arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[3][EXPLIST_COLUMN_ID] = EXPLIST_COL_DEPENDENCIES;
      arrExpListColInfo[3][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2791,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[3][EXPLIST_COLUMN_WIDTH] = DEPENDENCIES_COLUMN_WIDTH;
      arrExpListColInfo[3][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[3][EXPLIST_COLUMN_ENABLESORT] = false;
      m_arrObjectClassIDs = _arrObjectClassIDs;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING, EXPLIST_COL_FOLDER_CONTENTS,
       EXPLIST_COL_DEPENDENCIES, EXPLIST_COL_TYPE, EXPLIST_COL_SUBMITTED_BY,
       EXPLIST_COL_DESCRIPTION};
      int[][] arrSort = new int[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_CLASSID;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_STRING;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Loads the list with objects that get uploaded from the
    /// Add Existing Package feature.
    /// </summary>
    public virtual void LoadResources()
    {
      IMigrationUtilityModelRO mainModel = (IMigrationUtilityModelRO) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      XPArrayList[] alResources = mainModel.GetAllObjectsInPackage();
      // Iterate through each object in the package.  If the UUID is already
      // detected in the current list of objects to export, skip it.  
      // If the UUID can be found
      // in the local DB, that means the object exists and is available to be
      // exported.  If that's the case, go ahead and add it to the list of
      // resources to be exported.  If it can't be found, then it cannot be
      // exported, so we skip over it and log a warning message.
      IPTMigrationManager migMgr = mainModel.GetMigrationManager();
      for (int indClass = 0;indClass < alResources.Length;indClass++)
      {
        XPArrayList xpalClassObjs = alResources[indClass];
        int nClassID = PT_MIGRATION_CLASSES.SUPPORTED_CLASSES[indClass];
        for (int indObj = 0;indObj < xpalClassObjs.GetSize();indObj++)
        {
          IPTMigrationElement ptME = (IPTMigrationElement) xpalClassObjs.GetElement(indObj);
          int nObjectID = migMgr.ResolveObject(ptME, true);
          if (nObjectID != PT_INTRINSICS.PT_NULL_OBJECTID)
          {
            String strUniqueString = nClassID + "," + nObjectID;
            if (null != m_htObjsToMigrate.GetElement(strUniqueString))
            {
              log.Debug(ptME.GetName() + " already added to package. Skipping...");
              continue;
            } else
            {
              m_htObjsToMigrate.PutElement(strUniqueString, ptME.GetName());
              if (ptME.GetClassID() == PT_CLASSIDS.PT_EXPRESSION_ID && ptME.ReadSimpleElementAsInt("TOPICPOS") == 0)
              {
                // DCA - subexpressions are not shown on the list
                continue;
              } else
              {
                Object[] aRowToAdd = new Object[EXPLIST_COL_MAX];
                aRowToAdd[EXPLIST_COL_CLASSID] = nClassID;
                aRowToAdd[EXPLIST_COL_OBJECTID] = nObjectID;
                aRowToAdd[EXPLIST_COL_STRING] = ptME.GetName();
                aRowToAdd[EXPLIST_COL_FOLDER_CONTENTS] = false;
                aRowToAdd[EXPLIST_COL_DEPENDENCIES] = false;
                if (IsAdminObject(nClassID))
                {
                  aRowToAdd[EXPLIST_COL_TYPE] = TYPE_ADMIN_OBJ;
                } else
                if (IsDirObject(nClassID))
                {
                  aRowToAdd[EXPLIST_COL_TYPE] = TYPE_DIRECTORY;
                } else
                {
                  aRowToAdd[EXPLIST_COL_TYPE] = TYPE_GLOBAL;
                }
                aRowToAdd[EXPLIST_COL_SUBMITTED_BY] = m_sCurrentUser;
                String strDesc;
                try
                {
                  strDesc = ptME.GetDescription();
                }
                catch (Exception e)
                {
                  // This object probably doesn't support description
                  // (Global maps, etc)
                  strDesc = "";
                }
                aRowToAdd[EXPLIST_COL_DESCRIPTION] = strDesc;
                GetItems().AddRow(aRowToAdd);
                log.Info("Found object to add to export package: " + ptME.GetName());
                }
            }
          } else
          {
            log.Warn("Could not find object to add to export package: " + ptME.GetName() + ". Skipping...");
            }
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nValid = base.SaveSection(_htFormData);
      for (int indRow = 0;indRow < GetItems().GetCount();indRow++)
      {
        GetItems().SetItem(indRow, EXPLIST_COL_FOLDER_CONTENTS, false);
        GetItems().SetItem(indRow, EXPLIST_COL_DEPENDENCIES, false);
      }
      String sDataKey = GetUniqueString(MigrationSelectForExportView.HTMLCHECKBOX_FOLDERCONTENTS);
      String[] aDataValue;
      int intRow;
      if (_htFormData.ContainsKey(sDataKey))
      {
        aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && !(0 == aDataValue.Length))
        {
          for (int indValue = 0;indValue < aDataValue.Length;indValue++)
          {
            intRow = XPConvert.ToInteger(aDataValue[indValue]);
            GetItems().SetItem(intRow, EXPLIST_COL_FOLDER_CONTENTS, true);
            }
        }
      }
      sDataKey = GetUniqueString(MigrationSelectForExportView.HTMLCHECKBOX_DEPENDENCIES);
      if (_htFormData.ContainsKey(sDataKey))
      {
        aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && !(0 == aDataValue.Length))
        {
          for (int indValue = 0;indValue < aDataValue.Length;indValue++)
          {
            intRow = XPConvert.ToInteger(aDataValue[indValue]);
            GetItems().SetItem(intRow, EXPLIST_COL_DEPENDENCIES, true);
          }
        }
      }
      return nValid;
    }
    
    /// <summary>
    /// Saves the data for columns other than the plumtree object select column
    /// on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    // mel: Fix for bug# 45542
    
    /// <returns>The TreeAS corresponding to the subSpaceKey or null if none</returns>
    private TreeAS SafeGetSubSpace(String subSpaceKey)
    {
      if (subSpaceKey == null)
      {
        return null;
      }
      String uniqueString = GetUniqueString(subSpaceKey);
      TreeAS asTree = null;
      if (m_asOwner.GetSubSpaceExists(uniqueString))
      {
        asTree = (TreeAS) m_asOwner.GetSubSpace(uniqueString);
      }
      return asTree;
    }
    
    /// <summary>
    /// Clear the list and add all the values from the tree.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      if (!m_bIsReadOnly)
      {
        SaveTreeID(_htFormData);
        // TODO The subspace names and "TYPE_" should be merged since they represent the same data, a pseudo-enum would do nicely
        AddTreeSelectionToList(SUBSPACE_KEY_ADMINTREE, TYPE_ADMIN_OBJ);
        AddTreeSelectionToList(SUBSPACE_KEY_DIRTREE, TYPE_DIRECTORY);
        AddTreeSelectionToList(SUBSPACE_KEY_GLOBALTREE, TYPE_GLOBAL);
      }
    }
    private void AddTreeSelectionToList(String subspaceTreeKey, int objectType)
    {
      TreeAS asTree = SafeGetSubSpace(subspaceTreeKey);
      if (asTree == null)
      {
        // If the tree picker for this subspace (admin,dir,global)
        // has not been initialized yet, then we can't be selecting
        // items in it.
        return;
      }
      ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
      XPArrayList mySelected = myTree.GetSelectedItems();
      Object[] oNewRow;
      int nClassID;
      int nObjectID;
      int nIndex;
      Object[][] arrIndexMapping = CreateIndexMapping(GetItems());
      for (int i = 0;i < mySelected.GetSize();i++)
      {
        nClassID = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
        nObjectID = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
        nIndex = GetIndex(arrIndexMapping, nClassID, nObjectID);
        if (-1 == nIndex)
        {
          nIndex = m_nNextIndex;
          m_nNextIndex++;
        }
        oNewRow = new Object[EXPLIST_COL_MAX];
        oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = nIndex;
        oNewRow[EXPLIST_COL_CLASSID] = nClassID;
        oNewRow[EXPLIST_COL_OBJECTID] = nObjectID;
        // For PT_CLASSIDS.PT_CATALOGFOLDER_ID == nClassID)
        // we could use
        // oNewRow[EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).m_strLocation;
        // to get a path but that looks bad.
        oNewRow[EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
        oNewRow[EXPLIST_COL_FOLDER_CONTENTS] = false;
        oNewRow[EXPLIST_COL_DEPENDENCIES] = false;
        oNewRow[EXPLIST_COL_TYPE] = objectType;
        oNewRow[EXPLIST_COL_SUBMITTED_BY] = m_sCurrentUser;
        AddRowToList(oNewRow, nClassID, nObjectID);
      }
    }
    private void AddRowToList(Object[] rowObjectArray, int classID, int objectID)
    {
      String strUniqueString = classID + "," + objectID;
      if (!m_htObjsToMigrate.ContainsKey(strUniqueString))
      {
        m_htObjsToMigrate.PutElement(strUniqueString, rowObjectArray[EXPLIST_COL_STRING]);
        GetItems().AddRow(rowObjectArray);
      }
    }
    private void RemoveRowFromList(int classID, int objectID)
    {
      String strUniqueString = classID + "," + objectID;
      m_htObjsToMigrate.RemoveElement(strUniqueString);
      // mel: Fix for 42066, ensure the objects are removed from the selection
      // otherwise we'll just re-add them later.
      // mel: This remove method has no effect if the object does not
      // exist or is not selected.
      // When the remove button is clicked, we don't know which tree it applies to,
      // so we have to remove from each of the trees and rely on
      // RemoveItemFromTreeSelection ignoring remove on non-existent objects.
      RemoveItemFromTreeSelection(SUBSPACE_KEY_ADMINTREE, classID, objectID);
      RemoveItemFromTreeSelection(SUBSPACE_KEY_DIRTREE, classID, objectID);
      RemoveItemFromTreeSelection(SUBSPACE_KEY_GLOBALTREE, classID, objectID);
      }
    private void RemoveItemFromTreeSelection(String subspaceTreeKey, int classID,
     int objectID)
    {
      TreeAS asTree = SafeGetSubSpace(subspaceTreeKey);
      if (null != asTree)
      {
        ITreeModel myTree = (ITreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
        myTree.RemoveFromSelection(classID, objectID);
      }
    }
    // This override is a quick way to see where super.m_saData and super.GetItems are being used.
    //    public PTGrowableSortedArrayWrapper GetItems()
    //    {
    //        return super.GetItems();
    //    }
    
    /// <summary>
    /// Gets the array of checked rows and delete  them from the list.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      if (!m_bIsReadOnly)
      {
        String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
        // JF- We get back the list of index of rows to delete.
        if (_htFormData.ContainsKey(sDataKey))
        {
          int[] aRowsToDelete = GetArrayOfObjToDelete(_htFormData);
          // JF- We can only delete rows if the array is not empty
          if (GetItems().GetCount() > 0)
          {
            for (int indRow = 0;indRow < aRowsToDelete.Length;indRow++)
            {
              int nClassID = XPConvert.ToInteger(GetItems().GetItem(aRowsToDelete[indRow],
               EXPLIST_COL_CLASSID));
              int nObjectID = XPConvert.ToInteger(GetItems().GetItem(aRowsToDelete[indRow],
               EXPLIST_COL_OBJECTID));
              RemoveRowFromList(nClassID, nObjectID);
            }
            // mel: Must remove all at once. Removing one at a time will
            // cause indices to become invalid and incorrect items removed.
            GetItems().RemoveRows(aRowsToDelete);
          }
        }
      }
    }
    
    /// <summary>
    /// Adds all approved objects to list of resources to export.
    /// </summary>
    public virtual void AddAllApproved()
    {
      //TODO: The queries here could probably be optimized...
      IMigrationUtilityModelRO mainModel = (IMigrationUtilityModelRO) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      IPTMigrationManager migMgr = mainModel.GetMigrationManager();
      Object[] aRowToAdd;
      // Query the number of approved objects by class
      IPTQueryResult ptQRCount = migMgr.QueryObjectsByStatusCount(PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED,
       null);
      // Find the last row index so we can assign
      // row indices correctly
      int nRowIndex = GetItems().GetCount();
      // Loop through each class and add objects
      for (int indClass = 0;indClass < ptQRCount.RowCount();indClass++)
      {
        int nClassID = ptQRCount.ItemAsInt(indClass, PT_PROPIDS.PT_PROPID_CLASSID);
        int nNumObjects = ptQRCount.ItemAsInt(indClass, PT_PROPIDS.PT_PROPID_OBJECTCOUNT);
        // Only query the DB if necessary
        if (nNumObjects > 0)
        {
          // Query all approved objects of the current class
          IPTQueryResult ptQR = migMgr.QueryObjectsByStatus(nClassID, PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED,
           0, -1, null);
          for (int indObj = 0;indObj < ptQR.RowCount();indObj++)
          {
            int nObjectID = ptQR.ItemAsInt(indObj, PT_PROPIDS.PT_PROPID_OBJECTID);
            String strName = ptQR.ItemAsString(indObj, PT_PROPIDS.PT_PROPID_NAME);
            //RT - Names for Global Objects are not stored in the database, we check
            // if the current object is a global object and verify if name is empty value
            // then try to get the Name of this global object in a different way.
            if (nClassID == PT_CLASSIDS.PT_GLOBALOBJECT_ID)
            {
              //RT - If name is a null or empty string, we get name in a different way.
              if (null == strName || XPStringUtility.EqualsIgnoreCase(strName,
               ""))
              {
                strName = GetLocalizedNameForGlobalObject(nObjectID);
              }
            }
            String strSubmittedBy = ptQR.ItemAsString(indObj, PT_PROPIDS.PT_PROPID_MIGRATION_REQUESTOR);
            // Don't load duplicates
            String strUniqueString = nClassID + "," + nObjectID;
            if (null != m_htObjsToMigrate.GetElement(strUniqueString))
            {
              log.Debug(strName + " already added to package. Skipping...");
              continue;
            } else
            {
              m_htObjsToMigrate.PutElement(strUniqueString, strName);
              aRowToAdd = new Object[EXPLIST_COL_MAX];
              aRowToAdd[EXPLIST_SORTEDARRAY_PROPID_INDEX] = nRowIndex;
              aRowToAdd[EXPLIST_COL_CLASSID] = nClassID;
              aRowToAdd[EXPLIST_COL_OBJECTID] = nObjectID;
              aRowToAdd[EXPLIST_COL_STRING] = strName;
              aRowToAdd[EXPLIST_COL_FOLDER_CONTENTS] = false;
              aRowToAdd[EXPLIST_COL_DEPENDENCIES] = false;
              if (IsAdminObject(nClassID))
              {
                aRowToAdd[EXPLIST_COL_TYPE] = TYPE_ADMIN_OBJ;
              } else
              if (IsDirObject(nClassID))
              {
                aRowToAdd[EXPLIST_COL_TYPE] = TYPE_DIRECTORY;
              } else
              {
                aRowToAdd[EXPLIST_COL_TYPE] = TYPE_GLOBAL;
              }
              aRowToAdd[EXPLIST_COL_SUBMITTED_BY] = strSubmittedBy;
              GetItems().AddRow(aRowToAdd);
              nRowIndex++;
              log.Info("Adding " + strName + ", ObjectID " + nObjectID);
            }
          }
        }
      }
    }
    
    /// <summary>
    /// This method is used for getting name property value of global objects,
    /// Since their names are not stored in the database.
    /// </summary>
    /// <param name="nGlobalObjectID">Object ID of a GlobalObject.</param>
    /// <returns>Localized Name of the Global Object.</returns>
    private String GetLocalizedNameForGlobalObject(int nGlobalObjectID)
    {
      String strName;
      switch (nGlobalObjectID){
      case PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP:
      strName = m_asOwner.GetString(1547, "ptmsgs_portaladminmsgs");
      break;
      case PT_GLOBALOBJECTS.PT_GLOBAL_DOCUMENTTYPEMAP:
      strName = m_asOwner.GetString(1545, "ptmsgs_portaladminmsgs");
      break;
      case PT_GLOBALOBJECTS.PT_GLOBAL_PROPERTYMAP:
      strName = m_asOwner.GetString(1546, "ptmsgs_portaladminmsgs");
      break;
      default:
      strName = "";
      break;
      }
      return strName;
    }
    // mel: Fix for 45544, error: No object manager for this class (6) (PT_CLASSIDS.PT_ACTIVITY_ID).
    // Note that activities are handled via the GlobalObjsTreeModel, see GetGlobalTreeSpaceID
    //
    // mel: Fix for 45812, agents (intrinsic jobs) should not be exported, e.g. Card Refresh Agent
    // Excluding all global objects is acceptable because AdminTreeModel,
    // when displaying PT_GLOBALOBJECT_ID, only
    // displays PT_GLOBALOBJECTS.PT_GLOBAL_SCHEDULED_AGENTS and no others.
    private bool IsExcludedAdminObjectClassID(int migrationClassID)
    {
      // Don't want to dislpay PTGuestLogin (PT_CLASSIDS.PT_GUESTLOGIN_ID)
      if (migrationClassID == PT_CLASSIDS.PT_ACTIVITY_ID || migrationClassID == PT_CLASSIDS.PT_GUESTLOGIN_ID || migrationClassID == PT_CLASSIDS.PT_GLOBALOBJECT_ID)
      {
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Returns String of Class ID of the Objects
    /// displayed in the tree.
    /// E.g.: "2,45,3"
    /// This is the format used by the tree.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetAdminObjectClassIDs()
    {
      XPStringBuilder sbClassIDs = new XPStringBuilder();
      // JF- We loop through the array of IDs and add each ID 
      // to the StringBuilder.
      for (int i = 0;i < PT_MIGRATION_CLASSES.ADMIN_OBJ_CLASSES.Length;i++)
      {
        int migrationClassID = PT_MIGRATION_CLASSES.ADMIN_OBJ_CLASSES[i];
        if (!IsExcludedAdminObjectClassID(migrationClassID))
        {
          if (0 != sbClassIDs.GetLength())
          {
            sbClassIDs.Append(",");
          }
          sbClassIDs.Append(migrationClassID);
        }
      }
      return sbClassIDs.ToString();
    }
    
    /// <summary>
    /// Returns String of Class ID of the Objects
    /// displayed in the tree.
    /// E.g.: "2,45,3"
    /// This is the format used by the tree.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetDirectoryClassIDs()
    {
      XPStringBuilder sbClassIDs = new XPStringBuilder();
      // JF- We loop through the array of IDs and add each ID 
      // to the String.
      for (int i = 0;i < PT_MIGRATION_CLASSES.KD_CLASSES.Length;i++)
      {
        if (0 != sbClassIDs.GetLength())
        {
          sbClassIDs.Append(",");
        }
        sbClassIDs.Append(PT_MIGRATION_CLASSES.KD_CLASSES[i]);
      }
      return sbClassIDs.ToString();
    }
    
    /// <summary>
    /// Helper method to save the Tree ID on repost.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    protected override void SaveTreeID(XPHashtable _htFormData)
    {
      base.SaveTreeID(_htFormData);
      // JF- We save the tree ID only if we don't already have it.
      if (("").Equals(m_sAdminTreeSpaceID) && _htFormData.ContainsKey(GetUniqueString(MigrationSelectForExportView.HTMLINPUT_ADMIN_TREEASID)))
      {
        String[] data = (String[]) _htFormData.GetElement(GetUniqueString(MigrationSelectForExportView.HTMLINPUT_ADMIN_TREEASID));
        if ((null != data) && !(0 == data.Length))
        {
          m_sAdminTreeSpaceID = data[0];
        }
      }
      if (("").Equals(m_sDirTreeSpaceID) && _htFormData.ContainsKey(GetUniqueString(MigrationSelectForExportView.HTMLINPUT_DIR_TREEASID)))
      {
        String[] data = (String[]) _htFormData.GetElement(GetUniqueString(MigrationSelectForExportView.HTMLINPUT_DIR_TREEASID));
        if ((null != data) && !(0 == data.Length))
        {
          m_sDirTreeSpaceID = data[0];
        }
      }
      if (("").Equals(m_sGlobalTreeSpaceID) && _htFormData.ContainsKey(GetUniqueString(MigrationSelectForExportView.HTMLINPUT_GLOBAL_TREEASID)))
      {
        String[] data = (String[]) _htFormData.GetElement(GetUniqueString(MigrationSelectForExportView.HTMLINPUT_GLOBAL_TREEASID));
        if ((null != data) && !(0 == data.Length))
        {
          m_sDirTreeSpaceID = data[0];
        }
      }
    }
    
    /// <summary>
    /// Returns tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetAdminTreeSpaceID()
    {
      return m_sAdminTreeSpaceID;
    }
    
    /// <summary>
    /// Returns tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetDirectoryTreeSpaceID()
    {
      return m_sDirTreeSpaceID;
    }
    
    /// <summary>
    /// Returns tree AS ID.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetGlobalTreeSpaceID()
    {
      return m_sGlobalTreeSpaceID;
    }
    public virtual bool IsAdminObject(int _intClassID)
    {
      if (IsDirObject(_intClassID))
      {
        return false;
      } else
      if (IsGlobalObject(_intClassID))
      {
        return false;
      }
      return true;
    }
    public virtual bool IsDirObject(int _intClassID)
    {
      for (int indClass = 0;indClass < PT_MIGRATION_CLASSES.KD_CLASSES.Length;
      indClass++)
      {
        if (_intClassID == PT_MIGRATION_CLASSES.KD_CLASSES[indClass])
        {
          return true;
        }
      }
      return false;
    }
    public virtual bool IsGlobalObject(int _intClassID)
    {
      switch (_intClassID){
      case PT_CLASSIDS.PT_GLOBALOBJECT_ID:
      case PT_CLASSIDS.PT_ACTIVITY_ID:
      case PT_CLASSIDS.PT_EXPRESSION_ID:
      return true;
      goto default;
      default:
      return false;
      break;
      }
    }
  }
}