using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.imp
{
  public class ImportSettingsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.ImportSettingsView");
    public const String STR_MVC_CLASS_NAME = "ImportSettingsView";
    public const String HTMLCHECKBOX_IMPORT_ACLS = "in_cb_ImportACLs";
    public const String HTMLCHECKBOX_OVERWRITE_RS = "in_cb_OverwriteRS";
    public const String HTMLCHECKBOX_REMEMBER_DEPENDENCY_SETTINGS = "in_cb_RememberDependencySettings";
    public const String HTMLCHECKBOX_CREATE_NEW_OBJECTS = "in_cb_CreateNewObjs";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ImportSettingsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLInput myInput;
      try
      {
        IMigrationUtilityImportModelRO modelRO = (IMigrationUtilityImportModelRO) m_model;
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(2760,
         "ptmsgs_portaladminmsgs")));
        myTable = ViewHelper.AddTable(result);
        myTable.SetBorder("0");
        // 1st row (Top Margin)
        ViewHelper.AddEmptyRow(myTable, "3");
        // 2nd row
        DrawCheckBox(myTable, HTMLCHECKBOX_IMPORT_ACLS, "1", m_asOwner.GetString(2761,
         "ptmsgs_portaladminmsgs"), modelRO.GetImportACLs());
        // 3rd row
        DrawCheckBox(myTable, HTMLCHECKBOX_OVERWRITE_RS, "1", m_asOwner.GetString(2762,
         "ptmsgs_portaladminmsgs"), modelRO.GetOverwriteRemoteServers());
        // 4th row
        DrawCheckBox(myTable, HTMLCHECKBOX_REMEMBER_DEPENDENCY_SETTINGS, "1",
         m_asOwner.GetString(2763, "ptmsgs_portaladminmsgs"), modelRO.GetRememberDependencySettings());
        // 5th row
        DrawCheckBox(myTable, HTMLCHECKBOX_CREATE_NEW_OBJECTS, "1", m_asOwner.GetString(2764,
         "ptmsgs_portaladminmsgs"), modelRO.GetCreateNewObjectInstances());
        // last row (spacer row)
        ViewHelper.AddEmptyRow(myTable, "3");
      }
      catch (HTMLException e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.GetMessage());
        throw new XPException(STR_MVC_CLASS_NAME + "::Display() Unknown error when trying to display HTML. ",
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript result = new HTMLScript("text/javaScript");
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
    }
    // Helper Function:
    private void DrawCheckBox(HTMLTable myTable, String strHTMLID, String strValue,
     String strUI, bool bChecked)
    {
      ViewHelper.AddSimpleCheckbox(myTable, 3, strUI, strHTMLID, strValue,
       bChecked, "");
    }
  }
}