using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.webservice.credvaulttree;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.imp
{
  /// <author>jennifersu</author>
  public class MigrationDependencyListModel : ExpListModel,IMigrationDependencyListModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationDependencyListModel");
    public const String STR_MVC_CLASS_NAME = "MigrationDependencyList";
    
    /// <summary>
    /// Expandable list column for class ID 
    /// </summary>
    public const int EXPLIST_COL_CLASSID = 0;
    
    /// <summary>
    /// Expandable list column for UUID 
    /// </summary>
    public const int EXPLIST_COL_UUID = 1;
    
    /// <summary>
    /// Expandable list column for missing name 
    /// </summary>
    public const int EXPLIST_COL_NAME = 2;
    
    /// <summary>
    /// Expandable list column for new object ID 
    /// </summary>
    public const int EXPLIST_COL_NEW_UUID = 3;
    
    /// <summary>
    /// Expandable list column for new object name 
    /// </summary>
    public const int EXPLIST_COL_NEW_NAME = 4;
    
    /// <summary>
    /// Number total of columns 
    /// </summary>
    public const int EXPLIST_COL_MAX = 5;
    
    /// <summary>
    /// Key name used by the Activity Space to store the tree. 
    /// </summary>
    public const String SUBSPACE_KEY_SELECTDEPENDENCYTREE = "SelectDependencyTree";
    
    /// <summary>
    /// Table of unresolved dependencies.  
    /// Key=UUID; Value=CPTMigrationDependency
    /// </summary>
    protected XPHashtable m_htAllMissingDependencies;
    
    /// <summary>
    /// Table of all objects that depend on objects in this list.
    /// Key=UUID; Value=IPTMigrationElement
    /// </summary>
    protected XPHashtable m_htObjectsWithMissingDependencies;
    
    /// <summary>
    /// Array of XPArrayLists of objects loaded,
    /// indexed by classID.
    /// </summary>
    protected XPArrayList[] m_xparObjectsInPackage;
    
    /// <summary>
    /// Main import model
    /// </summary>
    private MigrationUtilityImportModel m_mainModel;
    
    /// <summary>
    /// Row index of the row currently being edited
    /// </summary>
    private int m_nEditRowIndex;
    
    /// <summary>
    /// Init
    /// </summary>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_mainModel = (MigrationUtilityImportModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      ClearPackage();
    }
    private void ClearPackage()
    {
      int nNumClasses = PT_MIGRATION_CLASSES.SUPPORTED_CLASSES.Length;
      m_xparObjectsInPackage = new XPArrayList[nNumClasses];
      for (int i = 0;i < nNumClasses;i++)
      {
        m_xparObjectsInPackage[i] = new XPArrayList();
      }
      m_htAllMissingDependencies = new XPHashtable();
      m_htObjectsWithMissingDependencies = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initializes columns and list
    /// </summary>
    public virtual void InitializeDependencies()
    {
      Object[][] arrExpListColInfo = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[EXPLIST_COLUMN_INVALID];
        }
      // The first column will be the property name and will be sortable
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2776,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "45%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      } else
      {
        arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      }
      // The second column will be the property value and will not be sortable
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_UUID;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2777,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "45%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      // The second column will be the property value and will not be sortable
      arrExpListColInfo[2][EXPLIST_COLUMN_ID] = EXPLIST_COL_UUID;
      arrExpListColInfo[2][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(2778,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH] = "10%";
      arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT] = false;
      // Initialize as read-only list because we don't want checkboxes or action bar
      base.InitializeReadOnlyExpandableList(m_asOwner.GetString(2765, "ptmsgs_portaladminmsgs"),
       arrExpListColInfo, 1);
      SetEmptyListMessages(m_asOwner.GetString(2779, "ptmsgs_portaladminmsgs"),
       "");
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper)
     */
     
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[EXPLIST_COL_MAX];
      arrColumns[EXPLIST_COL_CLASSID] = EXPLIST_COL_CLASSID;
      arrColumns[EXPLIST_COL_UUID] = EXPLIST_COL_UUID;
      arrColumns[EXPLIST_COL_NAME] = EXPLIST_COL_NAME;
      arrColumns[EXPLIST_COL_NEW_UUID] = EXPLIST_COL_NEW_UUID;
      arrColumns[EXPLIST_COL_NEW_NAME] = EXPLIST_COL_NEW_NAME;
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_NAME;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null bellow)
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(com.plumtree.uiinfrastructure.arraywrapper.PTGrowableSortedArrayWrapper, int, com.plumtree.openfoundation.util.XPHashtable)
     */
     
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#Create()
     */
     
    public override Object Create()
    {
      return new MigrationDependencyListModel();
    }
    // mel: WARNING: Code duplication, here and ImportContext, see bug# 45264
    private bool IsOptionalDependency(int dependencyTypeBitMask)
    {
      if ((0 != (dependencyTypeBitMask & (int) PT_OBJECT_DEPENDENCY_TYPES.PT_OBJECT_DEPENDENCY_ACL)) || (0 != (dependencyTypeBitMask & (int) PT_OBJECT_DEPENDENCY_TYPES.PT_OBJECT_DEPENDENCY_EOD)) || (0 != (dependencyTypeBitMask & (int) PT_OBJECT_DEPENDENCY_TYPES.PT_OBJECT_DEPENDENCY_OPTIONAL)))
      {
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Loads Dependencies into expandable list.
    /// </summary>
    public virtual void LoadObjectsAndDependencies()
    {
      IPTMigrationManager migrationMgr = m_mainModel.GetMigrationManager();
      String strSourcePortalUUID = migrationMgr.GetPackageSourcePortalUUID();
      // iterate through classes
      for (int indClass = 0;indClass < PT_MIGRATION_CLASSES.SUPPORTED_CLASSES.Length;
      indClass++)
      {
        // iterate through objects in the current class
        int nNumObjects = migrationMgr.GetObjectCount(PT_MIGRATION_CLASSES.SUPPORTED_CLASSES[indClass]);
        for (int indObject = 0;indObject < nNumObjects;indObject++)
        {
          IPTMigrationElement ptME = migrationMgr.RetrieveObjectFromImportPackage(indObject,
           PT_MIGRATION_CLASSES.SUPPORTED_CLASSES[indClass]);
          // add object to list for class
          m_xparObjectsInPackage[indClass].Add(ptME);
          try
          {
            // Checks that all dependencies exist on the local system
            // Returns Object[5][numMissingDependences]
            Object o = ptME.CheckDependencies();
            if ((null == o) || AllMissingDependenciesExistInPackage((Object[][]) o))
            {
              // no missing dependencies
              continue;
            }
            Object[][] arMissingDependencies = (Object[][]) o;
            int nNumMissingDependencies = arMissingDependencies[0].Length;
            // iterate through missing dependencies of current object
            for (int indDependency = 0;indDependency < nNumMissingDependencies;
            indDependency++)
            {
              String strUUID = (String) arMissingDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_UUID][indDependency];
              // If the dependency is about to be imported in this package, don't list it.
              if (migrationMgr.ObjectExistsInPackage(strUUID))
              {
                continue;
              }
              int nDependencyType = XPConvert.ToInteger(arMissingDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_DEPENDENCY_TYPE][indDependency]);
              // If it's an ACL, EOD, or OPTIONAL dependency, don't list it.
              if (IsOptionalDependency(nDependencyType))
              {
                continue;
              }
              try
              {
                // See if the missing dependency can be resolved by a mapping.
                String strMappedUUID = migrationMgr.LookupMappingInProfile(strSourcePortalUUID,
                 strUUID);
                ptME.ApplyDependencyMapping(strUUID, strMappedUUID);
              }
              catch (Exception e)
              {
                // No mapping was found.
                // See if we've encountered this missing dependency before, and
                // create it if it hasn't been seen before.
                CPTMigrationDependency cptmd;
                cptmd = (CPTMigrationDependency) m_htAllMissingDependencies.GetElement(strUUID);
                if (null == cptmd)
                {
                  int nClassID = XPConvert.ToInteger(arMissingDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_CLASSID][indDependency]);
                  String strName = XPConvert.ToString(arMissingDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_NAME][indDependency]);
                  cptmd = new CPTMigrationDependency(strUUID, nClassID, strName);
                  m_htAllMissingDependencies.PutElement(strUUID, cptmd);
                }
                // Add the current migration element to the list of objects to update
                // when this dependency is resolved.
                cptmd.AddResolvableObject(ptME);
                // Add this object to the list of objects with missing dependencies
                if (null == m_htObjectsWithMissingDependencies.GetElement(ptME.GetUUID()))
                {
                  m_htObjectsWithMissingDependencies.PutElement(ptME.GetUUID(),
                   ptME);
                }
              }
            }
          }
          catch (Exception e)
          {
            log.Error("Error in importing class " + PT_MIGRATION_CLASSES.SUPPORTED_CLASSES[indClass] + " with UUID " + ptME.GetUUID() + " (\'" + ptME.GetName() + "\')");
            }
          ptME = null;
        }
      }
      // Add rows to the expandable list
      Object[][] aRowsToAdd = new Object[m_htAllMissingDependencies.GetSize()][];
      for (int j2c_index = 0;j2c_index < m_htAllMissingDependencies.GetSize();
      j2c_index++)
      {
        aRowsToAdd[j2c_index] = new Object[EXPLIST_COL_MAX];
      }
      IXPEnumerator enumDepend = m_htAllMissingDependencies.GetKeys();
      int indRows = 0;
      while (enumDepend.MoveNext())
      {
        Object key = enumDepend.GetCurrent();
        CPTMigrationDependency cptmd = (CPTMigrationDependency) m_htAllMissingDependencies.GetElement(key);
        aRowsToAdd[indRows][EXPLIST_COL_CLASSID] = cptmd.GetClassID();
        aRowsToAdd[indRows][EXPLIST_COL_UUID] = cptmd.GetUUID();
        aRowsToAdd[indRows][EXPLIST_COL_NAME] = cptmd.GetName();
        aRowsToAdd[indRows][EXPLIST_COL_NEW_UUID] = null;
        aRowsToAdd[indRows][EXPLIST_COL_NEW_NAME] = null;
        indRows++;
      }
      // mel: Fix for 45964, clicking load without a package causes unresolved dependencies to disappear and fail during import time.
      // The m_saData (from ExpListModel) for the resource picker must only be reset when new dependencies are added, not every time load is called.
      m_saData.ClearArray();
      m_saData.AddRows(aRowsToAdd);
    }
    
    /// <summary>
    /// DOCUMENT_ME
    /// </summary>
    /// <param name="arMissingDependencies">DOCUMENT_ME</param>
    /// <returns>DOCUMENT_ME</returns>
    private bool AllMissingDependenciesExistInPackage(Object[][] arMissingDependencies)
    {
      int nDependencies = arMissingDependencies[0].Length;
      bool bResolved = true;
      for (int i = 0;(i < nDependencies) && bResolved;i++)
      {
        String strUUID = (String) arMissingDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_UUID][i];
        if (m_mainModel.GetMigrationManager().ObjectExistsInPackage(strUUID))
        {
          // If the dependency is about to be imported in this package, don't list it.
          continue;
        }
        int nDependencyType = XPConvert.ToInteger(arMissingDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_DEPENDENCY_TYPE][i]);
        // If it's an ACL, EOD, or OPTIONAL dependency, don't consider it missing.
        if (IsOptionalDependency(nDependencyType))
        {
          continue;
        }
        bResolved = false;
      }
      return bResolved;
    }
    
    /// <summary>
    /// True if unresolved dependencies exist
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool UnresolvedDependenciesExist()
    {
      return (!m_htObjectsWithMissingDependencies.IsEmpty());
    }
    
    /// <summary>
    /// Reads the selected item from dependency tree
    /// and sets the replacement on the unresolved dependency.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void DoEditDependency(XPHashtable _htFormData)
    {
      ATreeAS asTree;
      if (m_asOwner.GetSubSpaceExists(SUBSPACE_KEY_SELECTDEPENDENCYTREE + m_nEditRowIndex))
      {
        asTree = (ATreeAS) m_asOwner.GetSubSpace(SUBSPACE_KEY_SELECTDEPENDENCYTREE + m_nEditRowIndex);
        ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList mySelectedItems = myTree.GetSelectedItems();
        if (0 < mySelectedItems.GetSize())
        {
          // Get the first selected item
          String strObjectName = ((TreeLeafNode) mySelectedItems.GetElement(0)).GetName();
          int nObjectID = ((TreeLeafNode) mySelectedItems.GetElement(0)).m_nObjectID;
          int nClassID = ((TreeLeafNode) mySelectedItems.GetElement(0)).m_nClassID;
          IPTMigrationManager migMgr = m_mainModel.GetMigrationManager();
          String strNewUUID = migMgr.ObjectIDToUUID(nClassID, nObjectID);
          m_saData.SetItem(m_nEditRowIndex, EXPLIST_COL_NEW_NAME, strObjectName);
          m_saData.SetItem(m_nEditRowIndex, EXPLIST_COL_NEW_UUID, strNewUUID);
          String strOldUUID = XPConvert.ToString(m_saData.GetItem(m_nEditRowIndex,
           EXPLIST_COL_UUID));
          CPTMigrationDependency cptmd = (CPTMigrationDependency) m_htAllMissingDependencies.GetElement(strOldUUID);
          UpdateMissingDependencyList(cptmd, strNewUUID);
        }
      }
    }
    public virtual ASURL DoOpenDependencyTree(XPHashtable _htFormData)
    {
      ASURL myNewTree = null;
      // Get the hidden input with the row to modify
      String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && (aDataValue.Length > 0))
        {
          m_nEditRowIndex = XPConvert.ToInteger(aDataValue[0]);
          int nClassID = XPConvert.ToInteger(m_saData.GetItem(m_nEditRowIndex,
           EXPLIST_COL_CLASSID));
          String strUUID = XPConvert.ToString(m_saData.GetItem(m_nEditRowIndex,
           EXPLIST_COL_NEW_UUID));
          String strObjID = null;
          if (strUUID != null)
          {
            Object[] arObjID = m_mainModel.GetMigrationManager().UUIDToObjectID(strUUID);
            if (arObjID != null)
            {
              strObjID = XPConvert.ToString(arObjID[1]);
            }
          }
          if (nClassID == PT_CLASSIDS.PT_CATALOGCARD_ID || nClassID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
          {
            myNewTree = GetDirectoryTreeURL(nClassID, strObjID);
          } else
          {
            myNewTree = GetAdminObjTreeURL(nClassID, strObjID);
          }
        }
      }
      return myNewTree;
    }
    
    /// <summary>
    /// Get Tree URL for admin objects
    /// </summary>
    /// <param name="_strSelectedItems"></param>
    /// <returns></returns>
    private ASURL GetAdminObjTreeURL(int nClassID, String strObjID)
    {
      // The URL to open a new tree
      ASURL myNewTree = new ASURL(m_asOwner);
      if (nClassID == PT_CLASSIDS.PT_PROFILESECTION_ID)
      {
        myNewTree = GetLockboxTreeURL();
      } else
      {
        myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
        myNewTree.SetSubSpaceKey(SUBSPACE_KEY_SELECTDEPENDENCYTREE + m_nEditRowIndex);
        myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
         MigrationDependencyListView.HTMLINPUT_DEPENDENCYTREEASID + m_nEditRowIndex);
        myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
        myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
        myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
        myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
        myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
         GetUniqueString("OnReturnFromDependencyTree"));
        myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN);
        myNewTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(2792,
         "ptmsgs_portaladminmsgs"));
        myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(2793,
         "ptmsgs_portaladminmsgs"));
        int nCommunityMode = AObjectTreeModel.ALLCOMMUNITIES;
        myNewTree.AddControlArgument(StartTreeControl.COMMUNITY_MODE, nCommunityMode);
        myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
         nClassID);
        if (strObjID != null)
        {
          myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, nClassID + "," + strObjID);
          }
        if (nClassID == PT_CLASSIDS.PT_ADMIN_FOLDER_ID)
        {
          myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_COMPOSITESELECT);
          } else
        {
          myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
          }
        // Do not want to allow the Plumtree intrinsic auth source to be
        // selected to replace a missing auth source.
        if (nClassID == PT_CLASSIDS.PT_AUTHSOURCE_ID)
        {
          myNewTree.AddControlArgument(StartTreeControl.HIDDEN_ITEMS, nClassID + "," + PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE);
          }
      }
      return myNewTree;
    }
    
    /// <summary>
    /// Get Tree URL for directory objects
    /// </summary>
    /// <param name="_strSelectedItems"></param>
    /// <returns></returns>
    private ASURL GetDirectoryTreeURL(int nClassID, String strObjID)
    {
      // The URL to open a new tree
      ASURL myNewTree = new ASURL(m_asOwner);
      myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
      myNewTree.SetSubSpaceKey(SUBSPACE_KEY_SELECTDEPENDENCYTREE + m_nEditRowIndex);
      myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
      myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_FOLDER_ROOTFOLDER));
      myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
      myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
      myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, GetUniqueString("OnReturnFromDependencyTree"));
      myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN);
      myNewTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(2794,
       "ptmsgs_portaladminmsgs"));
      myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(2795,
       "ptmsgs_portaladminmsgs"));
      int nDirectoryMode = DirectoryTreeModel.EDIT_MODE;
      myNewTree.AddControlArgument(StartTreeControl.DIRECTORY_MODE, nDirectoryMode);
      myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
       nClassID);
      if (strObjID != null)
      {
        myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS, XPConvert.ToString(nClassID) + "," + strObjID);
        }
      if (nClassID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
      {
        myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_COMPOSITESELECT);
        } else
      {
        myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
        }
      myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       MigrationDependencyListView.HTMLINPUT_DEPENDENCYTREEASID + m_nEditRowIndex);
      return myNewTree;
    }
    
    /// <summary>
    /// Gets URL to the Lockbox tree, originally
    /// written for the web service editor.  Pointing
    /// to it here for code re-use.
    /// </summary>
    /// <returns></returns>
    private ASURL GetLockboxTreeURL()
    {
      ASURL newCredentialVaultTree = new ASURL(m_asOwner);
      newCredentialVaultTree.SetLinkCreateNewSpace(CredVaultTreeAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      newCredentialVaultTree.SetSubSpaceKey(SUBSPACE_KEY_SELECTDEPENDENCYTREE + m_nEditRowIndex);
      newCredentialVaultTree.SetControl(CredVaultStartTreeControl.STR_MVC_CLASS_NAME);
      newCredentialVaultTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
       XPConvert.ToString(false));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.SELECT_MODE,
       XPConvert.ToString(TreeConstants.N_LEAFSELECT));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
       XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
       AFormDP.HTMLFORM_NAME);
      newCredentialVaultTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
       MigrationDependencyListView.HTMLINPUT_DEPENDENCYTREEASID + m_nEditRowIndex);
      newCredentialVaultTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
       GetUniqueString("OnReturnFromDependencyTree"));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.SHOW_ROOT,
       XPConvert.ToString(false));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(2875,
       "ptmsgs_portaladminmsgs"));
      newCredentialVaultTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
       m_asOwner.GetString(2877, "ptmsgs_portaladminmsgs"));
      return newCredentialVaultTree;
    }
    
    /// <summary>
    /// Removes all unresolved dependencies in the list for
    /// the given object with UUID.  This should only be called
    /// when the object is removed from the Select Resources for
    /// Import list.
    /// </summary>
    /// <param name="_strUUID"></param>
    public virtual void RemoveAllUnresolvedDependenciesForObject(String _strUUID)
    {
      XPArrayList xpalRowsToRemove = new XPArrayList();
      for (int indDep = 0;indDep < m_saData.GetCount();indDep++)
      {
        String strMissingUUID = XPConvert.ToString(m_saData.GetItem(indDep,
         EXPLIST_COL_UUID));
        CPTMigrationDependency cptmd = (CPTMigrationDependency) m_htAllMissingDependencies.GetElement(strMissingUUID);
        if (cptmd.GetResolvableObject(_strUUID) != null)
        {
          cptmd.RemoveResolvableObject(_strUUID);
          if (cptmd.GetResolvableObjectCount() == 0)
          {
            m_htAllMissingDependencies.RemoveElement(strMissingUUID);
            xpalRowsToRemove.Add(indDep);
          }
        }
      }
      int[] arIntRows = new int[xpalRowsToRemove.GetSize()];
      for (int indRemove = 0;indRemove < xpalRowsToRemove.GetSize();indRemove++)
      {
        arIntRows[indRemove] = XPConvert.ToInteger(xpalRowsToRemove.GetElement(indRemove));
        }
      m_saData.RemoveRows(arIntRows);
      m_htObjectsWithMissingDependencies.RemoveElement(_strUUID);
    }
    
    /// <summary>
    /// Gets the CPTMigrationDependency object for the 
    /// given row.
    /// </summary>
    /// <param name="_intRowIndex"></param>
    /// <returns>CPTMigrationDependency</returns>
    public virtual CPTMigrationDependency GetUnresolvedDependency(int _intRowIndex)
    {
      String _strUUID = XPConvert.ToString(m_saData.GetItem(_intRowIndex,
       EXPLIST_COL_UUID));
      CPTMigrationDependency cptmd = (CPTMigrationDependency) m_htAllMissingDependencies.GetElement(_strUUID);
      return cptmd;
    }
    
    /// <summary>
    /// DOCUMENT ME!
    /// </summary>
    public virtual void UpdateMissingDependencyList(CPTMigrationDependency cptmd,
     String strMappedUUID)
    {
      XPHashtable xphtDependents = cptmd.GetAllResolvableObjects();
      IXPEnumerator enumKeys = xphtDependents.GetKeys();
      while (enumKeys.MoveNext())
      {
        IPTMigrationElement ptME = (IPTMigrationElement) (xphtDependents.GetElement(enumKeys.GetCurrent()));
        ptME.ApplyDependencyMapping(cptmd.GetUUID(), strMappedUUID);
        // Check if this element has been completely resolved, and if so 
        // mark it as ready to be imported.
        MarkReadyToImportIfResolved(ptME);
      }
    }
    
    /// <summary>
    /// Checks if the resolved object has any further missing dependencies,
    /// and removes it from the hashtable of objects with missing dependencies,
    /// if the object is ready to be imported.
    /// </summary>
    public virtual void MarkReadyToImportIfResolved(IPTMigrationElement ptME)
    {
      Object o = ptME.CheckDependencies();
      if ((null == o) || AllMissingDependenciesExistInPackage((Object[][]) o))
      {
        // All dependencies resolved.  Remove it from the list of objects
        // that need to be resolved.
        m_htObjectsWithMissingDependencies.RemoveElement(ptME.GetUUID());
        }
    }
    
    /// <summary>
    /// Gets XPHashtable of all missing dependencies.
    /// Key=UUID; Value=CPTMigrationDependency
    /// </summary>
    /// <returns>XPHashtable</returns>
    public virtual XPHashtable GetAllUnresolvedDependencies()
    {
      return m_htAllMissingDependencies;
    }
  }
}