using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.migrationutility;
using com.plumtree.portalpages.common.areyousure;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.imp
{
  /// <author>jennifersu</author>
  public class MigrationImportRepostControl : MigrationUtilityRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationImportRepostControl");
    public const String STR_MVC_CLASS_NAME = "MigrationImportRepostControl";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationImportRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Sets the editor to perform the Are You Sure popup.
    /// Takes in an XPArrayList of AYSMessages.
    /// </summary>
    protected override void PerformAYSPopup()
    {
      try
      {
        // Put the AYSMessages in a common Session space - so the popup can reach them.
        MigrationUtilityImportModel mainModel = (MigrationUtilityImportModel) m_asOwner.GetModel(MigrationUtilityImportModel.STR_MVC_CLASS_NAME);
        XPArrayList xpalAYSMessages = mainModel.GetAYSMessages();
        m_asOwner.GetSubSession().SetAttribute(MigrationUtilityImportModel.AYS_SESSION_KEY,
         xpalAYSMessages);
        // Set up the AYS popup
        HTMLScript myScript = new HTMLScript("text/javaScript");
        XPStringBuilder sb;
        ASURL asurlPopup = new ASURL(m_asOwner);
        asurlPopup.SetLinkCreateNewSpace(AreYouSureAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        asurlPopup.SetSubSpaceKey(MigrationUtilityImportAS.SUBSPACEKEY_AYS);
        asurlPopup.SetDisplayPage(AYSPopupDP.STR_MVC_CLASS_NAME);
        asurlPopup.SetControl(AreYouSureControl.STR_MVC_CLASS_NAME);
        asurlPopup.AddControlArgument(AreYouSureControl._QS_AYS_SESSION_KEY,
         MigrationUtilityImportModel.AYS_SESSION_KEY);
        sb = new XPStringBuilder(200);
        sb.Append("window.open(\'").Append(asurlPopup.GetURLAsString()).Append("\', \'Confirm\', \'scrollbar=yes,location=no,menubar=no,height=350,width=400\');\n");
        myScript.AddInnerHTMLString(sb.ToString());
        ((EditorDP) ((EditorAS) m_asOwner).GetCurrentPage()).AddScriptToHead(myScript);
        // AGC - we want to just repost here. Our new script will redirect us after download is
        // complete.
        SetRedirect(null);
      }
      catch (Exception e)
      {
        log.Error(e, "Unknown error attempting to open AYSPopup. e: " + e.Message);
        }
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int _nAction)
    {
      LeftNavMenu leftMenu;
      MigrationDependencyListModel depModel;
      MigrationSelectForImportModel listModel;
      // Editor repost actions (Finish, Cancel, Change Page, etc.)
      base.PerformAction(_nAction);
      // You need to call the PerformRepostAction on the dependency list control
      ((MigrationDependencyListRepostControl) m_asOwner.GetControl(MigrationDependencyListRepostControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
       m_htFormData);
      // You need to call the PerformRepostAction on the select for import control
      ((ExpListControl) m_asOwner.GetControl(MigrationUtilityImportAS.strStorageSelectForImport)).PerformRepostAction(_nAction,
       m_htFormData);
      listModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
      if (_nAction == listModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE))
      {
        leftMenu = ((MigrationUtilityImportAS) m_asOwner).GetLeftMenu();
        // If dependencies need to be resolved, show the link to Unresolved Dependencies Page
        depModel = ((MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME));
        if (depModel.UnresolvedDependenciesExist())
        {
          leftMenu.SetMandatoryPage(true, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
          } else
        {
          leftMenu.SetMandatoryPage(false, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
          }
      }
      // Migration repost actions
      switch (_nAction){
      case POSTTOSELF_ACTION_MIGRATION_START:
      // Start the migration thread 
      ((MigrationUtilityImportModel) m_model).StartImport();
      // Construct the redirect to the status polling page.
      Redirect startRedirect = new Redirect();
      startRedirect.SetLinkGetCachedSpace(m_asOwner);
      startRedirect.SetDisplayPage(MigrationStatusPopupDP.STR_MVC_CLASS_NAME);
      startRedirect.SetControl(((MigrationUtilityAS) m_asOwner).GetRepostControlName());
      startRedirect.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF,
       MigrationImportRepostControl.POSTTOSELF_ACTION_MIGRATION_POLL);
      // Go to the status polling page
      SetRedirect(startRedirect);
      break;
      case POSTTOSELF_ACTION_MIGRATION_DOUPLOAD:
      {
        leftMenu = ((MigrationUtilityImportAS) m_asOwner).GetLeftMenu();
        // mel: Fix for 46451, When loading pte files with only Collab objects in them, MWS SCI pages do not display until a package with portal objects is loaded.
        if (((MigrationUtilityImportModel) m_model).HasObjectsForMigration())
        {
          leftMenu.HideSubMenu(false, ((MigrationUtilityAS) m_asOwner).GetResourcesSubMenuID());
          }
        depModel = ((MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME));
        // Load dependencies
        depModel.LoadObjectsAndDependencies();
        // If dependencies need to be resolved, show the link to Unresolved Dependencies Page
        if (depModel.UnresolvedDependenciesExist())
        {
          leftMenu.HideLink(false, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
          leftMenu.SetMandatoryPage(true, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
          } else
        {
          leftMenu.HideLink(true, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
          leftMenu.SetMandatoryPage(false, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
          }
        break;
      }
      }
    }
    
    /// <summary>
    /// Polls for the status of the currently running migration task.  Depending on the status,
    /// return an appropriate redirect.
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect PollStatus()
    {
      MigrationUtilityImportModel myModel = (MigrationUtilityImportModel) m_model;
      // Begin polling
      if (myModel.GetMigrationStatus() != PTMigrationTask.DONE)
      {
        if (myModel.GetMigrationStatus() != PTMigrationTask.FAILED)
        {
          // It's not DONE and it's not FAILED, so it must still be in progress.
          // Return a null Redirect so the status page displays.	
          log.Info("Import task in progress.");
          return null;
        } else
        {
          // Handle failure and return a redirect to the result page.
          // The migration is done so remove the task from the session.
          log.Error("Import task failed.");
        }
      } else
      {
        // Success! Return a redirect to the result page.
        // The migration is done so remove the task from the session.
        log.Info("Import task successful! Removing from session.");
      }
      // Construct the redirect to the result page
      Redirect pollPage = new Redirect();
      pollPage.SetLinkGetCachedSpace(m_asOwner);
      pollPage.SetDisplayPage(MigrationResultPopupDP.STR_MVC_CLASS_NAME);
      pollPage.SetControl(((MigrationUtilityAS) m_asOwner).GetRepostControlName());
      return pollPage;
    }
  }
}