using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.migrationutility;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.impl.migration;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.imp
{
  /// <author>jennifersu</author>
  public class MigrationSelectForImportModel : ExpListModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationSelectForImportModel");
    public const String STR_MVC_CLASS_NAME = "MigrationSelectForImportModel";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 6;
    
    /// <summary>
    /// This column contains the Object Class IDs.
    /// </summary>
    public const int EXPLIST_COL_CLASSID = 1;
    
    /// <summary>
    /// This column contains the UUIDs.
    /// </summary>
    public const int EXPLIST_COL_UUID = 2;
    
    /// <summary>
    /// This column contains the name
    /// </summary>
    public const int EXPLIST_COL_NAME = 3;
    
    /// <summary>
    /// This column contains the description
    /// </summary>
    public const int EXPLIST_COL_DESCRIPTION = 4;
    
    /// <summary>
    /// This column contains the IPTMigrationElement
    /// </summary>
    public const int EXPLIST_COL_PTME = 5;
    
    /// <summary>
    /// Default initial size for the sorted array.
    /// </summary>
    public const int EXPLIST_DEFAULT_INITIAL_SIZE = 50;
    
    /// <summary>
    /// array of XPArrayLists containing IPTMigrationElements to
    /// migrate, indexed by classID.
    /// </summary>
    protected XPArrayList[] m_xparObjsToMigrate;
    
    /// <summary>
    /// An Hashtable to keep track of all the subexpression rules.
    /// If the user choose not to import a subportal rule, then
    /// all of its subexpressions are also deleted.
    /// </summary>
    protected XPHashtable m_htSubexpressions;
    
    /// <summary>
    /// Inits member variables
    /// </summary>
    public MigrationSelectForImportModel() : base()
    {
      m_xparObjsToMigrate = new XPArrayList[PT_MIGRATION_CLASSES.SUPPORTED_CLASSES.Length];
      for (int indClass = 0;indClass < PT_MIGRATION_CLASSES.SUPPORTED_CLASSES.Length;
      indClass++)
      {
        m_xparObjsToMigrate[indClass] = new XPArrayList();
      }
      m_htSubexpressions = new XPHashtable();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationSelectForImportModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initializes and starts the list of 
    /// objects to import.
    /// </summary>
    public virtual void InitSFE(IPTSession ptSession)
    {
      Object[][] arrExpListColInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(481,
       "ptmsgs_portalbrowsingmsgs");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      base.InitializeExpandableList(m_asOwner.GetString(481, "ptmsgs_portalbrowsingmsgs"),
       arrExpListColInfo, PTImageType.ACTION_ADD, m_asOwner.GetString(482,
       "ptmsgs_portalbrowsingmsgs"), 999);
      SetEmptyListMessages(m_asOwner.GetString(1895, "ptmsgs_portalbrowsingmsgs"),
       m_asOwner.GetString(1896, "ptmsgs_portalbrowsingmsgs"));
      DisableAddButton();
    }
    
    /// <summary>
    /// Loads the list with objects that get uploaded.
    /// </summary>
    public virtual void LoadResources()
    {
      IMigrationUtilityModelRO mainModel = (IMigrationUtilityModelRO) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      XPArrayList[] alResources = mainModel.GetAllObjectsInPackage();
      // Iterate through each object in the package.  If the UUID is already
      // detected in the current list of objects to import, skip it.  
      for (int indClass = 0;indClass < alResources.Length;indClass++)
      {
        XPArrayList xpalClassObjs = alResources[indClass];
        for (int indObj = 0;indObj < xpalClassObjs.GetSize();indObj++)
        {
          IPTMigrationElement ptME = (IPTMigrationElement) xpalClassObjs.GetElement(indObj);
          if (m_xparObjsToMigrate[indClass].Contains(ptME))
          {
            log.Debug(ptME.GetName() + " already loaded. Skipping...");
            continue;
          } else
          {
            m_xparObjsToMigrate[indClass].Add(ptME);
            if (ptME.GetClassID() == PT_CLASSIDS.PT_EXPRESSION_ID && ptME.ReadSimpleElementAsInt("TOPICPOS") == 0)
            {
              // DCA - subexpressions are not shown on the list, but we need to keep track in case they need to be deleted
              m_htSubexpressions.PutElement(ptME.GetUUID(), ptME);
            } else
            {
              Object[] aRowToAdd = new Object[EXPLIST_COL_MAX];
              aRowToAdd[EXPLIST_COL_CLASSID] = ptME.GetClassID();
              aRowToAdd[EXPLIST_COL_UUID] = ptME.GetUUID();
              aRowToAdd[EXPLIST_COL_NAME] = ptME.GetName();
              String strDesc;
              try
              {
                strDesc = ptME.GetDescription();
              }
              catch (Exception e)
              {
                // This object probably doesn't support description
                // (Global maps, etc)
                strDesc = "";
              }
              aRowToAdd[EXPLIST_COL_DESCRIPTION] = strDesc;
              aRowToAdd[EXPLIST_COL_PTME] = ptME;
              m_saData.AddRow(aRowToAdd);
              log.Info("Found object to load: " + ptME.GetName());
            }
          }
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)"></seealso>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nValid = base.SaveSection(_htFormData);
      return nValid;
    }
    
    /// <summary>
    /// Clear the list and add all the values from the tree.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
    }
    
    /// <summary>
    /// Gets the array of checked rows and delete them from the list.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      if (!m_bIsReadOnly)
      {
        String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
        // JF- We get back the list of index of rows to delete.
        if (_htFormData.ContainsKey(sDataKey))
        {
          int[] aRowsToDelete = GetArrayOfObjToDelete(_htFormData);
          // JF- We can only delete rows if the array is not empty
          if (m_saData.GetCount() > 0)
          {
            MigrationDependencyListModel depModel = (MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME);
            IMigrationUtilityModelRO mainModel = (IMigrationUtilityModelRO) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
            IPTMigrationManager migMgr = mainModel.GetMigrationManager();
            for (int indRow = 0;indRow < aRowsToDelete.Length;indRow++)
            {
              Object objUUID = m_saData.GetItem(aRowsToDelete[indRow], EXPLIST_COL_UUID);
              IPTMigrationElement ptME = (IPTMigrationElement) m_saData.GetItem(aRowsToDelete[indRow],
               EXPLIST_COL_PTME);
              int nClassID = XPConvert.ToInteger(m_saData.GetItem(aRowsToDelete[indRow],
               EXPLIST_COL_CLASSID));
              int nClassIndex = migMgr.GetObjectClassIndex(nClassID);
              m_xparObjsToMigrate[nClassIndex].Remove(ptME);
              depModel.RemoveAllUnresolvedDependenciesForObject(XPConvert.ToString(objUUID));
              if (PT_CLASSIDS.PT_EXPRESSION_ID == nClassID)
              {
                // DCA - remove subexpressions as well
                DeleteSubExpressions(ptME, m_xparObjsToMigrate[nClassIndex]);
                }
            }
            m_saData.RemoveRows(aRowsToDelete);
          }
        }
      }
    }
    private void DeleteSubExpressions(IPTMigrationElement ptME, XPArrayList alRulesToMigrate)
    {
      Object[][] arDependencies = ptME.GetDependencies();
      for (int i = 0;i < arDependencies[0].Length;i++)
      {
        String strUUID = XPConvert.ToString(arDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_UUID][i]);
        Object migrationElement = m_htSubexpressions.RemoveElement(strUUID);
        if (null != migrationElement)
        {
          // DCA - migrationElement should not be null if dependency is a subexpression
          alRulesToMigrate.Remove(migrationElement);
        }
      }
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_UUID, EXPLIST_COL_NAME, EXPLIST_COL_DESCRIPTION, EXPLIST_COL_PTME};
      // JF- Sort array
      // The growable array will always be sorted by the String column (the one displayed).
      int[][] arrSort = new int[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_CLASSID;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_NAME;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      // JF- Nothing to save on repost.
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// array of XPArrayLists containing IPTMigrationElements to
    /// migrate, indexed by classID.
    /// </summary>
    public virtual XPArrayList[] GetObjectsToMigrate()
    {
      return m_xparObjsToMigrate;
    }
  }
}