using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.xui;
using com.plumtree.portalpages.admin.ptutilities.migrationutility;
using com.plumtree.portalpages.common.areyousure;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.constants;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.imp
{
  /// <author>jennifersu</author>
  public class MigrationUtilityImportModel : MigrationUtilityModel,IMigrationUtilityImportModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationUtilityImportModel");
    public const String STR_MVC_CLASS_NAME = "MigrationUtilityImportModel";
    
    /// <summary>
    /// The name of the session key into which we will be storing confirmation messages that the 
    /// AreYouSure popup can access and display.
    /// </summary>
    public const String AYS_SESSION_KEY = "aysImportMessages";
    
    /// <summary>
    /// Import ACLs setting
    /// </summary>
    private bool m_bImportACLs;
    
    /// <summary>
    /// Overwrite Remote Servers setting
    /// </summary>
    private bool m_bOverwriteRemoteServers;
    
    /// <summary>
    /// Remember Dependency Settings setting
    /// </summary>
    private bool m_bRememberDependencySettings;
    
    /// <summary>
    /// Create New Object Instances setting
    /// </summary>
    private bool m_bCreateNewObjectInstances;
    
    /// <summary>
    /// Inits member variables
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      m_bImportACLs = true;
      m_bOverwriteRemoteServers = false;
      m_bRememberDependencySettings = true;
      m_bCreateNewObjectInstances = false;
    }
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      ((MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME)).InitializeDependencies();
      MigrationSelectForImportModel mySelectForImportModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
      mySelectForImportModel.InitSFE(m_ptSession);
      StartXUIServicesSafely(XUIHelperMethods.XUI_MIGRATION_IMPORT_SERVICEID);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MigrationUtilityImportModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()"></seealso>
    public override void DoTaskBeforeStore()
    {
      base.DoTaskBeforeStore();
      try
      {
        for (int indService = 0;indService < m_alMWSIDs.GetSize();indService++)
        {
          // mj: save xui pbag
          XUIHelperModel myXUIModel = (XUIHelperModel) m_asOwner.GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indService);
          IXPPropertyBag pbXUISettings = myXUIModel.GetFinalXUISettings();
          m_htPropBags.PutElement(m_alMWSIDs.GetElement(indService), pbXUISettings);
          }
      }
      catch (Exception e)
      {
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Providers"),
         STR_MVC_CLASS_NAME + "::DoTaskBeforeStore", e, true, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(2, "ptmsgs_provUIMWS"));
      }
    }
    // mel: Fix for 45506, previously unable to import collab only resources
    public override bool HasObjectsForMigration()
    {
      bool rval = false;
      MigrationSelectForImportModel listModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
      PTGrowableSortedArrayWrapper ptgsarItems = listModel.GetItems();
      if (ptgsarItems.GetCount() > 0)
      {
        rval = true;
      } else
      {
        rval = base.HasObjectsForMigration();
      }
      return rval;
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      MigrationLoadPackageModel loadModel = (MigrationLoadPackageModel) m_asOwner.GetModel(MigrationLoadPackageModel.strStorageLoadPackage);
      if (!loadModel.IsPackageLoaded())
      {
        String strError = m_asOwner.GetString(3131, "ptmsgs_portaladminmsgs");
        XPException e = new XPException(strError);
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "MigrationUtilityImportModel::Finish ", e, true, UIErrorLevel.FRIENDLY,
         strError);
      }
      if (!HasObjectsForMigration())
      {
        String strError = m_asOwner.GetString(2780, "ptmsgs_portaladminmsgs");
        XPException e = new XPException(strError);
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "MigrationUtilityImportModel::Finish ", e, true, UIErrorLevel.FRIENDLY,
         strError);
      }
      MigrationDependencyListModel depModel = (MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME);
      if (depModel.UnresolvedDependenciesExist())
      {
        String strError = m_asOwner.GetString(2781, "ptmsgs_portaladminmsgs");
        XPException e = new XPException(strError);
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "MigrationUtilityImportModel::Finish ", e, true, UIErrorLevel.FRIENDLY,
         strError);
      }
      if (m_bRememberDependencySettings)
      {
        PTGrowableSortedArrayWrapper ptgsarDeps = depModel.GetItems();
        String strPortalUUID = m_ptMigrationManager.GetPackageSourcePortalUUID();
        for (int indDep = 0;indDep < ptgsarDeps.GetCount();indDep++)
        {
          String strOldUUID = XPConvert.ToString(ptgsarDeps.GetItem(indDep,
           MigrationDependencyListModel.EXPLIST_COL_UUID));
          String strNewUUID = XPConvert.ToString(ptgsarDeps.GetItem(indDep,
           MigrationDependencyListModel.EXPLIST_COL_NEW_UUID));
          m_ptMigrationManager.StoreMappingInProfile(strPortalUUID, strOldUUID,
           strNewUUID);
        }
      }
      DoTaskBeforeStore();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      if (_sPageName.Equals(MigrationImportMainDP.STR_MVC_CLASS_NAME))
      {
        m_bCreateNewObjectInstances = ModelHelper.GetFormCheckboxBool(_htFormData,
         ImportSettingsView.HTMLCHECKBOX_CREATE_NEW_OBJECTS);
        m_bImportACLs = ModelHelper.GetFormCheckboxBool(_htFormData, ImportSettingsView.HTMLCHECKBOX_IMPORT_ACLS);
        m_bOverwriteRemoteServers = ModelHelper.GetFormCheckboxBool(_htFormData,
         ImportSettingsView.HTMLCHECKBOX_OVERWRITE_RS);
        m_bRememberDependencySettings = ModelHelper.GetFormCheckboxBool(_htFormData,
         ImportSettingsView.HTMLCHECKBOX_REMEMBER_DEPENDENCY_SETTINGS);
        if (!HasObjectsForMigration())
        {
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
          String errorMessage = m_asOwner.GetString(3176, ResourceConstants.PORTALADMINMSGS);
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, errorMessage, errorMessage);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
      }
      // Save select for import
      if (_sPageName.Equals(MigrationDependenciesDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = ((MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      // Save select for import
      if (_sPageName.Equals(MigrationImportPortalResourcesDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = ((MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport)).SaveSection(_htFormData);
        }
      nPageStatus = base.SavePage(_sPageName, _htFormData);
      return nPageStatus;
    }
    
    /// <summary>
    /// Creates a new PTMigrationTask and spawns the new thread.
    /// </summary>
    /// <returns> </returns>
    public virtual void StartImport()
    {
      log.Info("Starting new migration task.");
      // Initialize migration manager
      m_ptMigrationManager.InitializeForImport("");
      // Load IPTMigrationElements by classID into XPArrayList[] for migration.
      XPArrayList[] objsToMigrate = PrepareObjectsForPackage();
      // Create a new PTMigrationTask and spawn new thread.
      m_objMigrationTask = new PTImportMigrationTask(m_ptMigrationManager,
       objsToMigrate, m_bCreateNewObjectInstances, m_bImportACLs, m_bOverwriteRemoteServers,
       m_bRememberDependencySettings);
      XPThread migrationThread = new XPThread(m_objMigrationTask);
      migrationThread.SetBackground(true);
      migrationThread.Start();
    }
    
    /// <summary>
    /// Perform action when user Loads Package
    /// (load resources into list)
    /// </summary>
    public override void DoLoadPackage(XPHashtable _htFormData)
    {
      base.DoLoadPackage(_htFormData);
      MigrationSelectForImportModel listModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
      listModel.LoadResources();
    }
    
    /// <summary>
    /// Gets the Import ACLs setting
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetImportACLs()
    {
      return m_bImportACLs;
    }
    
    /// <summary>
    /// Gets the Remember Dependency Settings settings
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetRememberDependencySettings()
    {
      return m_bRememberDependencySettings;
    }
    
    /// <summary>
    /// Gets the Overwrite Remote Servers settings
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetOverwriteRemoteServers()
    {
      return m_bOverwriteRemoteServers;
    }
    
    /// <summary>
    /// Gets the Create New Object Instances settings
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool GetCreateNewObjectInstances()
    {
      return m_bCreateNewObjectInstances;
    }
    
    /// <summary>
    /// array of XPArrayLists containing IPTMigrationElements to
    /// migrate, indexed by classID.
    /// </summary>
    private XPArrayList[] PrepareObjectsForPackage()
    {
      MigrationSelectForImportModel listModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
      return listModel.GetObjectsToMigrate();
    }
    
    /// <summary>
    /// Get list of confirmation messages to 
    /// display in the AreYouSure popup
    /// </summary>
    /// <returns></returns>
    public virtual XPArrayList GetAYSMessages()
    {
      XPArrayList xpalMessages = new XPArrayList();
      String strMessage;
      strMessage = m_asOwner.GetString(3169, ResourceConstants.PORTALADMINMSGS);
      AYSMessage aysMessage = new AYSMessage(strMessage, AYSMessage.AYSTYPE_TOPLEVEL);
      xpalMessages.Add(aysMessage);
      return xpalMessages;
    }
  }
}