using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.ptutilities.migrationutility;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
namespace com.plumtree.portalpages.admin.ptutilities.migrationutility.imp
{
  /// <summary>
  /// This class is what calls the actual server migration code.
  /// It runs in a separate thread to prevent UI timeouts.
  /// </summary>
  /// <author>jennifersu</author>
  public class PTImportMigrationTask : PTMigrationTask
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.PTImportMigrationTask");
    
    /// <summary>
    /// array of XPArrayLists containing IPTMigrationElements to
    /// migrate, indexed by classID.
    /// </summary>
    private XPArrayList[] m_xparObjsToMigrate;
    
    /// <summary>
    /// Import ACLs setting
    /// </summary>
    private bool m_bImportACLs;
    
    /// <summary>
    /// Overwrite Remote Servers setting
    /// </summary>
    private bool m_bOverwriteRemoteServers;
    
    /// <summary>
    /// Remember Dependency Settings setting
    /// </summary>
    private bool m_bRememberDependencySettings;
    
    /// <summary>
    /// Create New Object Instances setting
    /// </summary>
    private bool m_bCreateNewObjectInstances;
    
    /// <summary>
    /// Sets status to CREATED.
    /// Initializes array of objects to migrate
    /// </summary>
    public PTImportMigrationTask(IPTMigrationManager _MigrationManager, XPArrayList[] _xparObjsToMigrate,
     bool _bCreateNewObjectInstances, bool _bImportACLs, bool _bOverwriteRemoteServers,
     bool _bRememberDependencySettings) : base(_MigrationManager)
    {
      m_xparObjsToMigrate = _xparObjsToMigrate;
      m_bImportACLs = _bImportACLs;
      m_bOverwriteRemoteServers = _bOverwriteRemoteServers;
      m_bRememberDependencySettings = _bRememberDependencySettings;
      m_bCreateNewObjectInstances = _bCreateNewObjectInstances;
    }
    
    /// <summary>
    /// Performs the actual migration.
    /// </summary>
    public override void run()
    {
      m_intStatus = INPROGRESS;
      log.Info("Migration Task in progress.");
      try
      {
        m_MigrationManager.PerformImport(m_xparObjsToMigrate, m_bCreateNewObjectInstances,
         m_bImportACLs, m_bOverwriteRemoteServers, m_bRememberDependencySettings);
        if (m_intStatus == CANCEL)
        {
          log.Info("Migration Task cancelled.");
          return;
        }
        m_MigrationManager.ImportMigrationWebServices();
        // End the import
        m_MigrationManager.EndImport();
        m_intStatus = DONE;
        log.Info("Migration Task completed.");
      }
      catch (Exception e)
      {
        m_intStatus = FAILED;
        log.Error(e, "PTImportMigrationTask::run Unknown error importing package.");
        }
    }
    // mel: Fix for 45685, the Cancel button does not kill the import task
    public override void Cancel()
    {
      // No need to synchronize since m_MigrationManager is assigned in ctor
      if (m_MigrationManager != null)
      {
        // CancelImport is synchronized
        m_MigrationManager.CancelImport();
      }
      base.Cancel();
    }
  }
}