using System;
// Framework Imports
using XPConvert=com.plumtree.openfoundation.util.XPConvert;
using ClassTypeDescManager=com.plumtree.portaluiinfrastructure.classtypedescriptors.ClassTypeDescManager;
using IPTClassTypeDesc=com.plumtree.portaluiinfrastructure.classtypedescriptors.IPTClassTypeDesc;
using com.plumtree.portaluiinfrastructure.editor;
using PTConfigHelper=com.plumtree.portaluiinfrastructure.statichelpers.PTConfigHelper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using PersonalSettingsHelper=com.plumtree.uiinfrastructure.statichelpers.PersonalSettingsHelper;
namespace com.plumtree.portalpages.admin.ptutilities.objectlockmanager
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Main Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>John Hogan</author>
  public class ObjectLockManagerAS : PTEditorAS
  {
    // All the AS in Plumtree need to have a unique name.
    
    /// <summary>
    /// The unique identifier for this activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjectLockManager";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjectLockManagerAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(1534, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // Strings to localize.
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (ObjectLockManagerRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = ObjectLockManagerModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      String strLanguage = null;
      try
      {
        strLanguage = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
         this));
      }
      catch (Exception e)
      {
      }
      IModel myModel = GetModel(ObjectLockManagerModel.STR_MVC_CLASS_NAME);
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      IPTClassTypeDesc[] allClassTypes = ptClassTypeDescManager.GetLockManagerClassTypes(strLanguage);
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1535, "ptmsgs_portaladminmsgs"));
      LockManagerObjectDP tmpLMO = null;
      LockManagerObjectDP firstObject = null;
      for (int i = 0;i < allClassTypes.Length;i++)
      {
        tmpLMO = new LockManagerObjectDP(allClassTypes[i]);
        if (firstObject == null)
        {
          firstObject = tmpLMO;
        }
        RegisterPage(tmpLMO);
        m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, tmpLMO.GetName());
      }
      // Register Views
      RegisterView(ObjectLockManagerView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(ObjectLockManagerRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(firstObject.GetName());
    }
    // END Sub menu "General Settings"
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()">Sets the help links for the object locks utility</seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      // set the help for all pages to this url -mgs
      this.SetHelpTopic("PT_ItemLocks");
    }
  }
}