using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.userinfopropmap
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Main Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>JohnH</author>
  public class UserInfoPropMapAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.userinfopropmap.UserInfoPropMapAS");
    // All the AS in Plumtree need to have a unique name.
    public const String STR_MVC_CLASS_NAME = "UserInfoPropMap";
    public const String STR_MVC_STORAGE_NAME_PLUG_IN = "UserInfoPropMapList";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserInfoPropMapAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(1570, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (UserInfoPropMapRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = UserInfoPropMapModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
      //Register the model, view and control for the property map list
      RegisterModel(UserInfoPropMapListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_PLUG_IN);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myMultiColumnListModel = GetModel(STR_MVC_STORAGE_NAME_PLUG_IN);
      RegisterView(PTMultiColumnListView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_PLUG_IN,
       myMultiColumnListModel);
      RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_PLUG_IN,
       myMultiColumnListModel);
      // Register DisplayPages
      RegisterPage(new MainDP());
      // Register Views
      // Register Controls
      RegisterControl(UserInfoPropMapRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      // Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1571, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          int iTitleId = 81;
          int iTipId = 82;
          int iSecondaryTipId = 83;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
  }
}
//	Got the tips model
