using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.ptutilities.userlockmanager
{
  /// <author>
  /// JenniferSu
  /// Expandable list implementation for the Release User Lock utility.
  /// </author>
  public class UserLockListModel : ExpListModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.userlockmanager.UserLockListModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserLockList";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 5;
    
    /// <summary>
    /// This column contains the User Object ID
    /// </summary>
    public const int EXPLIST_COL_USERID = 1;
    
    /// <summary>
    /// This column contains the Name.
    /// </summary>
    public const int EXPLIST_COL_NAME = 2;
    
    /// <summary>
    /// This column contains the sort order. Rows will be sorted by user name
    /// </summary>
    public const int EXPLIST_SORT_ORDER = 1;
    
    /// <summary>
    /// This column contains the Reason for Lock.
    /// </summary>
    public const int EXPLIST_COL_LOGINNAME = 3;
    
    /// <summary>
    /// This column contains the Date Locked.
    /// </summary>
    public const int EXPLIST_COL_DATELOCKED = 4;
    
    /// <summary>
    /// Filter reason string for admin disabled.
    /// </summary>
    public const String FILTER_ADMIN_DISABLED = "An administrator manually locked this account.";
    
    /// <summary>
    /// Filter reason string for agent disabled.
    /// </summary>
    public const String FILTER_AGENT_DISABLED = "This user has been locked by a User Synchronization Job.";
    
    /// <summary>
    /// Filter reason string for too many bad login attempts.
    /// </summary>
    public const String FILTER_BAD_LOGIN = "This user has had too many bad logon attempts.";
    
    /// <summary>
    /// Filter reason string for retrieving all.
    /// </summary>
    public const String FILTER_ALL = "";
    
    /// <summary>
    /// This is used on add to populate the input
    /// text of the newly added row.
    /// </summary>
    protected String m_sDefaultValue = "";
    private int[] m_arrObjectsToDelete;
    private String m_sCurrentFilter = "";
    private XPHashtable m_opItems;
    
    /// <summary>
    /// Adds one row at the bottom of the list
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserLockListModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initialize and load the expandable list.
    /// </summary>
    public virtual void InitializeUserLockList()
    {
      InitializeExpandableList(m_asOwner.GetString(1591, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(1594, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2658,
       "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1596, "ptmsgs_portaladminmsgs"),
       null, null, 1);
      m_opItems = new XPHashtable();
      Load(FILTER_ALL);
      SetEmptyListMessages(m_asOwner.GetString(2653, "ptmsgs_portaladminmsgs"),
       "");
      EnablePagination(UserLockManagerAS.strStorageUserLockList);
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeExpandableList(String _sSectionTitle, String _sSectionSubTitle1,
     String _sSectionSubTitle2, String _sSectionSubTitle3, PTImageType _imgAddIcon,
     String _sAddLabel, int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_USERID;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle1;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "0%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle1;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "33%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_LOGINNAME;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle2;
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "33%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      arrExpListColInfo[2][EXPLIST_COLUMN_ID] = EXPLIST_COL_DATELOCKED;
      arrExpListColInfo[2][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle3;
      arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH] = "33%";
      arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_USERID,
       EXPLIST_COL_NAME, EXPLIST_COL_LOGINNAME, EXPLIST_COL_DATELOCKED};
      // JF- Sort array
      // The growable array will always be sorted by the 1st column.
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORT_ORDER;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    //OKAN::WHY IS THIS USED AGAIN?
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      // Save the items to be unlocked
      m_arrObjectsToDelete = GetArrayOfObjToDelete(_htFormData);
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// ROB: Make the available for other models.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int[]</returns>
    public override int[] GetArrayOfObjToDelete(XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
      String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
      int[] aRowsToDelete = null;
      if ((null != aDataValue) && (aDataValue.Length > 0))
      {
        aRowsToDelete = new int[aDataValue.Length];
        for (int i = 0;i < aDataValue.Length;i++)
        {
          try
          {
            aRowsToDelete[i] = XPConvert.ToInteger(aDataValue[i]);
          }
          catch (Exception e)
          {
            log.Error("UserLockManagerModel::GetArrayOfObjToDelete Unbale to retrieve users to unlock.");
            }
        }
      }
      return aRowsToDelete;
    }
    
    /// <summary>
    /// Add the array passed in argument to the list.
    /// The array should be created using the EXPLIST_COL
    /// constants defined in this class.
    /// </summary>
    /// <param name="_arrRows">Array of rows to add.</param>
    public virtual void SetDefaultObjects(Object[][] _arrRows)
    {
      base.GetItems().AddRows(_arrRows);
    }
    
    /// <summary>
    /// This function unlocks users that have been checked in the UI
    /// </summary>
    public virtual void UnlockUsers()
    {
      try
      {
        //int intRowIndex;
        if (null != m_arrObjectsToDelete)
        {
          for (int i = 0;i < m_arrObjectsToDelete.Length;i++)
          {
            m_opItems.PutElement(GetReadOnlyItems().GetItem(m_arrObjectsToDelete[i],
             UserLockListModel.EXPLIST_COL_USERID), 1);
          }
          GetItems().RemoveRows(m_arrObjectsToDelete);
          m_arrObjectsToDelete = null;
        }
      }
      catch (Exception exc)
      {
        log.Error(exc, "UserLockManagerModel::UnlockObject Unable to unlock the user.");
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1590, "ptmsgs_portaladminmsgs"), "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    private void UnlockOneUser(int userID)
    {
      IPTUser ptUser;
      IPTServerContext mySC = null;
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      try
      {
        ptUser = (IPTUser) ptSession.GetUsers().Open(userID, true);
        ptUser.SetLockedStatus(false);
        mySC = (IPTServerContext) ptUser;
        mySC.Store();
        mySC.UnlockObject();
      }
      catch (Exception exc)
      {
        log.Error(exc, "UserLockManagerModel::Error occured during unlock user within Finish");
        throw new XPException(m_asOwner.GetString(1536, "ptmsgs_portaladminmsgs"),
         exc);
      }
    }
    
    /// <summary>
    /// Gets the array of checked rows and delete  them from the list.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      // we are already getting the selected user list from m_deletedItems, which is calculated in GetArrayOfObjToDelete
      // so ignore this _htFormData
      if (null != m_arrObjectsToDelete)
      {
        for (int i = 0;i < m_arrObjectsToDelete.Length;i++)
        {
          m_opItems.PutElement(GetReadOnlyItems().GetItem(m_arrObjectsToDelete[i],
           UserLockListModel.EXPLIST_COL_USERID), 2);
        }
      }
      GetItems().RemoveRows(m_arrObjectsToDelete);
      m_arrObjectsToDelete = null;
    }
    private void DeleteOneUser(int userID)
    {
      try
      {
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        IPTObjectManager objMgr = ptSession.GetObjectManagers(PT_CLASSIDS.PT_USER_ID);
        objMgr.Delete(userID);
      }
      catch (Exception exc)
      {
        log.Error(exc, "UserLockManagerModel::Error occured during delete user within Finish");
        throw new XPException(m_asOwner.GetString(1536, "ptmsgs_portaladminmsgs"),
         exc);
      }
    }
    public virtual void Finish()
    {
      IXPEnumerator eKeys = m_opItems.GetKeys();
      int userID = -1;
      int opMode = -1;
      while (eKeys.MoveNext())
      {
        opMode = XPConvert.ToInteger(m_opItems.GetElement(eKeys.GetCurrent()));
        userID = (XPConvert.ToInteger(eKeys.GetCurrent()));
        if (opMode == 1)
        {
          UnlockOneUser(userID);
        } else
        if (opMode == 2)
        {
          DeleteOneUser(userID);
        }
      }
      m_opItems.Clear();
    }
    
    /// <summary>
    /// Load the expandable list with locked users
    /// </summary>
    /// <param name="filter"></param>
    public virtual void Load(String filter)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTUserManager ptUserMan;
      ptUserMan = (IPTUserManager) ptSession.GetUsers();
      ASQueryResultWrapper ptqrUserLock = new ASQueryResultWrapper(ptUserMan.GetLockedAccounts(filter,
       0, -1));
      m_saData.ClearArray();
      XPArrayList objectRows = new XPArrayList();
      Object userID = null;
      Object[] columns = null;
      for (int i = 0;i < ptqrUserLock.GetCount();i++)
      {
        userID = ptqrUserLock.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (m_opItems.GetElement(userID) != null)
        {
          continue;
        }
        columns = new Object[UserLockListModel.EXPLIST_COL_MAX];
        columns[UserLockListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
        m_nNextIndex++;
        columns[UserLockListModel.EXPLIST_COL_USERID] = userID;
        columns[UserLockListModel.EXPLIST_COL_NAME] = ptqrUserLock.GetFields(i,
         PT_PROPIDS.PT_PROPID_NAME);
        columns[UserLockListModel.EXPLIST_COL_LOGINNAME] = ptqrUserLock.GetFields(i,
         PT_PROPIDS.PT_PROPID_USER_LOGINNAME);
        columns[UserLockListModel.EXPLIST_COL_DATELOCKED] = ptqrUserLock.GetFields(i,
         PT_PROPIDS.PT_PROPID_CREATED);
        objectRows.Add(columns);
      }
      Object[][] allRows = new Object[objectRows.GetSize()][];
      for (int i = 0;i < objectRows.GetSize();i++)
      {
        allRows[i] = (Object[]) (objectRows.GetElement(i));
      }
      m_saData.AddRows(allRows);
      m_sCurrentFilter = filter;
    }
    
    /// <summary>
    /// Get the reason that the list is currently filtering on.
    /// </summary>
    /// <returns></returns>
    public virtual String GetCurrentFilter()
    {
      return m_sCurrentFilter;
    }
  }
}