using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.ptutilities.userlockmanager
{
  /// <summary>
  /// Expandable list implementation for the Release User Locks utility. 
  /// </summary>
  /// <author>JenniferSu</author>
  public class UserLockListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.ptutilities.userlockmanager.UserLockListView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserLockList";
    public const String HTMLINPUT_ITEM = "in_tx_Item";
    public const String HTMLHIDDEN_PROPEDITORKEY = "in_hi_PropEditorKey";
    
    /// <summary>
    /// Job Server javascript opener function 
    /// </summary>
    public const String JAVASCRIPT_EDITOBJECT = "EditObject";
    
    /// <summary>
    /// HTML dropdown value for filtering on all.
    /// </summary>
    public const String HTML_FILTER_ALL_VALUE = "0";
    
    /// <summary>
    /// HTML dropdown value for filtering on admin disabled.
    /// </summary>
    public const String HTML_FILTER_ADMIN_VALUE = "1";
    
    /// <summary>
    /// HTML dropdown value for filtering on agent disabled.
    /// </summary>
    public const String HTML_FILTER_AGENT_VALUE = "2";
    
    /// <summary>
    /// HTML dropdown value for filtering on bad logins.
    /// </summary>
    public const String HTML_FILTER_BADLOGIN_VALUE = "3";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserLockListView();
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      try
      {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLTableCell myCell;
        String strUserName = XPConvert.ToString(_saData.GetItem(_nRowIndex,
         UserLockListModel.EXPLIST_COL_NAME));
        String strLoginName = XPConvert.ToString(_saData.GetItem(_nRowIndex,
         UserLockListModel.EXPLIST_COL_LOGINNAME));
        XPDateFormat xpDateFormat = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
         /* use portal server time zone */
        false);
        XPDateTime dtUserLockedDate = (XPDateTime) _saData.GetItem(_nRowIndex,
         UserLockListModel.EXPLIST_COL_DATELOCKED);
        String strUserLockedDate = xpDateFormat.Format(dtUserLockedDate);
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strUserName));
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strLoginName));
        myCell = new HTMLTableCell();
        result.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLString(strUserLockedDate);
        return result;
      }
      catch (HTMLException e)
      {
        log.Error(e, "UserLockListView.");
      }
      catch (Exception e)
      {
        log.Error(e, "UserLockListView.");
      }
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the space below the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLForActionBar()
    {
      try
      {
        HTMLTable myTable;
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        myTable = new HTMLTable();
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // 1st Row begin (there is only one row)
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        // Empty Cell
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        // Filter dropdown
        UserLockListModel listModel = (UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList);
        myCell = new HTMLTableCell();
        myCell.SetHeight("25");
        myCell.SetNoWrap(true);
        myRow.AddInnerHTMLElement(myCell);
        HTMLSelect myFilter = new HTMLSelect("in_se_filter", "");
        myFilter.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        myFilter.SetOnChange(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + UserLockManagerRepostControl.POSTTOSELF_ACTION_FILTER + "); return false;");
        myCell.AddInnerHTMLElement(myFilter);
        HTMLOption allOption = new HTMLOption(HTML_FILTER_ALL_VALUE);
        allOption.AddInnerHTMLString(m_asOwner.GetString(2685, "ptmsgs_portaladminmsgs"));
        if (listModel.GetCurrentFilter().Equals(UserLockListModel.FILTER_ALL))
        {
          allOption.SetSelected(true);
        }
        myFilter.AddInnerHTMLElement(allOption);
        HTMLOption adminDisabledOption = new HTMLOption(HTML_FILTER_ADMIN_VALUE);
        adminDisabledOption.AddInnerHTMLString(m_asOwner.GetString(2674, "ptmsgs_portaladminmsgs"));
        if (listModel.GetCurrentFilter().Equals(UserLockListModel.FILTER_ADMIN_DISABLED))
        {
          adminDisabledOption.SetSelected(true);
        }
        myFilter.AddInnerHTMLElement(adminDisabledOption);
        HTMLOption agentDisabledOption = new HTMLOption(HTML_FILTER_AGENT_VALUE);
        agentDisabledOption.AddInnerHTMLString(m_asOwner.GetString(2675, "ptmsgs_portaladminmsgs"));
        if (listModel.GetCurrentFilter().Equals(UserLockListModel.FILTER_AGENT_DISABLED))
        {
          agentDisabledOption.SetSelected(true);
        }
        myFilter.AddInnerHTMLElement(agentDisabledOption);
        HTMLOption badLoginOption = new HTMLOption(HTML_FILTER_BADLOGIN_VALUE);
        badLoginOption.AddInnerHTMLString(m_asOwner.GetString(2657, "ptmsgs_portaladminmsgs"));
        if (listModel.GetCurrentFilter().Equals(UserLockListModel.FILTER_BAD_LOGIN))
        {
          badLoginOption.SetSelected(true);
        }
        myFilter.AddInnerHTMLElement(badLoginOption);
        // JF- No need to display the delete icon, if the list is empty.
        if (0 != ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
        {
          // Empty Cell
          myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
          // Unlock button
          //	Get a button construct
          PTButtonType myButtonType = PTButtonType.UNLOCK_OBJ_ACTIONBAR;
          PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct(myButtonType,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(myButtonType.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(1593, "ptmsgs_portaladminmsgs"));
          ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1593,
           "ptmsgs_portaladminmsgs"));
          myButtonConstruct.GetHTMLElement().SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + UserLockManagerRepostControl.POSTTOSELF_ACTION_UNLOCK + "); return false;");
          myCell = new HTMLTableCell();
          myCell.SetHeight("25");
          myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
          myCell.SetNoWrap(true);
          myCell.AddInnerHTMLElement(myButtonConstruct.GetHTMLElement());
          myRow.AddInnerHTMLElement(myCell);
          // Empty Cell
          myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
          // Delete icon cell
          myRow.AddInnerHTMLElement(GetHTMLForDeleteAction());
        }
        AddHTMLToActionBar(myRow);
        // Last Empty Cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetHeight("25");
        myCell.AddInnerHTMLString(SPACE);
        // 1st Row ends
        return myTable;
      }
      catch (HTMLException e)
      {
        log.Error(e, "UserLockListView.");
      }
      catch (Exception e)
      {
        log.Error(e, "UserLockListView.");
      }
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the delete cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected override HTMLTableCell GetHTMLForDeleteAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // Delete icon
      myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetDeleteIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(m_asOwner.GetString(2654, "ptmsgs_portaladminmsgs"));
      myImage.SetAlign("absmiddle");
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("DeleteRows") + "(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE) + "\'); return false;");
      myAnchor.AddInnerHTMLElement(myImage);
      HTMLSpan mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      mySpan.AddInnerHTMLString(m_asOwner.GetString(2654, "ptmsgs_portaladminmsgs") + "&nbsp;");
      myAnchor.AddInnerHTMLElement(mySpan);
      myCell.AddInnerHTMLElement(myAnchor);
      return myCell;
    }
  }
}