using System;
// Framework Imports
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.admin.ptutilities.userlockmanager
{
  /// <summary>
  /// Activity Space for Release User Locks utility.
  /// </summary>
  /// <author>JenniferSu</author>
  public class UserLockManagerAS : PTEditorAS
  {
    public const String STR_MVC_CLASS_NAME = "UserLockManager";
    public const String strStorageUserLockList = "UserLockList";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserLockManagerAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(1587, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (UserLockManagerRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = UserLockManagerModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(UserLockManagerModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new MainDP());
      // Register Controls
      RegisterControl(UserLockManagerRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register UserLockList 
      RegisterModel(UserLockListModel.STR_MVC_CLASS_NAME, strStorageUserLockList);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myUserLockListModel = GetModel(strStorageUserLockList);
      RegisterView(UserLockListView.STR_MVC_CLASS_NAME, strStorageUserLockList,
       myUserLockListModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageUserLockList,
       myUserLockListModel);
      // Set default page
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      // Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1535, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      }
    // END Sub menu "General Settings"
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()">Sets the help links for the user locks utility</seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      // set the help for all pages to this url -mgs
      this.SetHelpTopic("PT_UserLocks");
    }
  }
}