using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.ptutilities.userlockmanager
{
  /// <summary>
  /// This class keeps an up-to-date state of all the settings.
  /// It contains the set and get methods for those settings.
  /// It contains the start, save and finish methods.
  /// </summary>
  /// <author>JohnH</author>
  /// <author>JenniferSu</author>
  public class UserLockManagerModel : EditorModel
  {
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserLockManagerModel";
    public UserLockManagerModel() : base()
    {
    }
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      //Check for administration rights
      IPTSession session = (IPTSession) m_asOwner.GetUserSession();
      if (!PlumtreeHelpers.CheckCurrentUserIsAdmin(session))
      {
        return false;
      }
      ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).InitializeUserLockList();
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserLockManagerModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Finish();
      }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Model with the IPTSession.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).SaveSection(_htFormData);
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}