using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.admin.ptutilities.userlockmanager
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to the Misc Editor (other than
  /// "change page", "finish" and "cancel" actions).
  /// </summary>
  /// <author>JohnH</author>
  /// <author>JenniferSu</author>
  public class UserLockManagerRepostControl : EditorRepostControl
  {
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "UserLockManagerRepost";
    
    /// <summary>
    /// The unlock action 
    /// </summary>
    public const int POSTTOSELF_ACTION_UNLOCK = 10;
    
    /// <summary>
    /// The sort action 
    /// </summary>
    public const int POSTTOSELF_ACTION_SORT = 20;
    
    /// <summary>
    /// The filtering action 
    /// </summary>
    public const int POSTTOSELF_ACTION_FILTER = 30;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new UserLockManagerRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      ((ExpListControl) m_asOwner.GetControl(UserLockManagerAS.strStorageUserLockList)).PerformRepostAction(_nAction,
       m_htFormData);
      switch (_nAction){
      case POSTTOSELF_ACTION_UNLOCK:
      ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).UnlockUsers();
      break;
      case POSTTOSELF_ACTION_FILTER:
      String filter = ((String[]) m_htFormData.GetElement("in_se_filter"))[0];
      if (filter.Equals(UserLockListView.HTML_FILTER_ALL_VALUE))
      {
        ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_ALL);
        } else
      if (filter.Equals(UserLockListView.HTML_FILTER_ADMIN_VALUE))
      {
        ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_ADMIN_DISABLED);
        } else
      if (filter.Equals(UserLockListView.HTML_FILTER_AGENT_VALUE))
      {
        ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_AGENT_DISABLED);
        } else
      if (filter.Equals(UserLockListView.HTML_FILTER_BADLOGIN_VALUE))
      {
        ((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_BAD_LOGIN);
        }
      break;
      }
    }
  }
}