using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.sendinvitation
{
  /// <author>DustinA</author>
  public class InvCodesListControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.sendinvitation.InvCodesListControl");
    public const String STR_MVC_CLASS_NAME = "InvCodesListControl";
    protected AActivitySpace m_asOwner;
    protected InvCodesListModel m_model;
    
    /// <summary>
    /// Localized String 
    /// </summary>
    private XPHashtable m_htFormData;
    
    /// <summary>
    /// Execute the control business logic and optionally return a Redirect object
    /// pointing to another AActivitySpace.  Returning null
    /// means that the user should return to the parent AActivitySpace's current page.
    /// </summary>
    /// <param name="XPHashtable">
    /// this contains all of the name value pairs for the control
    /// in String, String[] format.  This may contain information the control
    /// doesn't need.  The control should not modify this argument.
    /// </param>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      m_htFormData = arguments;
      // Set InvitationID
      String[] data;
      bool bInvIDFound = false;
      data = (String[]) m_htFormData.GetElement(InvCodesListModel.CONTROLARGUMENT_OBJECTID);
      if ((null != data) && (0 != data.Length))
      {
        m_model.SetInvitationID(XPConvert.ToInteger(data[0]));
        bInvIDFound = true;
      }
      if (bInvIDFound)
      {
        if (LoginHelper.INSTANCE.GetIsGuestUser(m_asOwner.GetUserSession()))
        {
          Redirect sendInvURL = new Redirect();
          sendInvURL.SetLinkGetCachedSpace(m_asOwner);
          sendInvURL.SetControl(this.GetName());
          sendInvURL.AddControlArgument(InvCodesListModel.CONTROLARGUMENT_OBJECTID,
           m_model.GetInvitationID());
          sendInvURL.SetIsErrorRedirect(true);
          return sendInvURL;
        }
        m_model.InitInvitationExpList(m_asOwner.GetString(1280, "ptmsgs_portaladminmsgs"),
         m_asOwner.GetString(1281, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1282,
         "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1283, "ptmsgs_portaladminmsgs"),
         PTImageType.ACTION_ADD, m_asOwner.GetString(1284, "ptmsgs_portaladminmsgs"),
         1);
      }
      // Set InvitationCode
      data = (String[]) m_htFormData.GetElement(InvCodesListView.CONTROLARGUMENT_INVCODE);
      if ((null != data) && (0 != data.Length))
      {
        m_model.SetInvitationCode(data[0]);
      } else
      {
        log.Warn("InvCodesListControl::Execute Invitation ID and Invitation Code was not in Query String.");
        }
      m_htFormData = null;
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new InvCodesListControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the class with the associated model and activity space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="space"></param>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asOwner = space;
      try
      {
        m_model = (InvCodesListModel) model;
      }
      catch (Exception e)
      {
        log.Error(e, "InvCodesListControl::Init Unable to cast the Object " + model + " to InvCodesListModel. The following exception occured: " + e.Message);
        // JF- No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + model + " to InvCodesListModel.",
         e);
      }
    }
  }
}