using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.sendinvitation
{
  /// <author>dustina</author>
  public class InvCodesListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.sendinvitation.InvCodesListView");
    public const String STR_MVC_CLASS_NAME = "InvCodesListView";
    
    /// <summary>
    /// invite argument processed by CreateAccountControl and Invite control; make sure they match 
    /// </summary>
    public const String CONTROLARGUMENT_INVCODE = "in_hi_invcode";
    public const String JS_CREATE_POPUP = "createPopUp";
    protected AActivitySpace m_asOwner;
    protected HTMLImg m_imgInvitation;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new InvCodesListView();
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        if (((IInvCodeListModelRO) m_model).GetInvObjectStatus())
        {
          myTable = new HTMLTable();
          result.AddInnerHTMLElement(myTable);
          myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          myTable.SetAlign(CommonHTMLStrings.CENTER);
          myTable.SetCellPadding(CommonHTMLStrings.ZERO);
          myTable.SetCellSpacing("15");
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLElement(base.Display());
        } else
        {
          myTable = new HTMLTable();
          result.AddInnerHTMLElement(myTable);
          myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          myTable.SetAlign(CommonHTMLStrings.CENTER);
          myTable.SetCellPadding(CommonHTMLStrings.ZERO);
          myTable.SetCellSpacing("15");
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
          myCell.AddInnerHTMLString(m_asOwner.GetString(1297, "ptmsgs_portaladminmsgs"));
          }
      }
      catch (Exception e)
      {
        log.Error(e, "InvCodesListView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(52, 
        //m_asOwner.GetString(14, "ptmsgs_portaladminmsgs")
        "ptmsgs_infrastructure"), e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      // The URL to open the pop-up
      ASURL myPopUp = new ASURL(m_asOwner);
      myPopUp.SetLinkGetCachedSpace(m_asOwner);
      myPopUp.SetDisplayPage(NewLinkPopUpDP.STR_MVC_CLASS_NAME);
      myPopUp.SetControl(SendInvitationRepostControl.STR_MVC_CLASS_NAME);
      XPStringBuilder sb;
      try
      {
        // Open Pop Up function
        sb = new XPStringBuilder(200);
        sb.Append("function " + JS_CREATE_POPUP + "()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(myPopUp.GetURLAsString()).Append("\', \'_blank3\', \'location=no,menubar=no,width=535,height=270\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "InvCodesListView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <summary>
    /// Will be called for each row.
    /// Should return the HTML for row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      // The URL to open the pop-up
      Object myObject = _saData.GetItem(_nRowIndex, InvCodesListModel.INVEXPLIST_COL_CODE);
      ASURL myHref = new ASURL(m_asOwner);
      myHref.SetLinkGetCachedSpace(m_asOwner);
      myHref.SetDisplayPage(CodePopUpDP.STR_MVC_CLASS_NAME);
      myHref.SetControl(InvCodesListControl.STR_MVC_CLASS_NAME);
      myHref.AddControlArgument(CONTROLARGUMENT_INVCODE, XPConvert.ToString(myObject));
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth("40%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myAnchor.SetOnClick("window.open(\'" + myHref.GetURLAsString() + "\', \'_blank3\', \'location=no,menubar=no,width=460,height=220\'); return false;");
      myObject = _saData.GetItem(_nRowIndex, InvCodesListModel.INVEXPLIST_COL_NAME);
      if (m_imgInvitation != null)
      {
        myAnchor.AddInnerHTMLElement(m_imgInvitation);
      }
      myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(XPConvert.ToString(myObject)));
      //}
      // add # of Invitation
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth("30%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myObject = _saData.GetItem(_nRowIndex, InvCodesListModel.INVEXPLIST_COL_NUMOFINV);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLString(XPConvert.ToString(myObject));
      // add Expiration Date
      myCell = new HTMLTableCell();
      result.AddInnerHTMLElement(myCell);
      myCell.SetWidth("30%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myObject = _saData.GetItem(_nRowIndex, InvCodesListModel.INVEXPLIST_COL_EXPR);
      PageMgr m_PageMgr = ((IInvCodeListModelRO) m_model).GetDatePickerControlManager().GetPageMgr();
      XPDateFormat dateParser = XPDateFormat.GetDateInstance(XPDateFormat.MEDIUM,
       m_PageMgr.GetLocale(), m_PageMgr.GetTimeZone());
      String strEprDate = dateParser.Format((XPDateTime) myObject);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLString(strEprDate);
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Section with the read-only Model and the Activity Space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = model;
      try
      {
        m_asOwner = parent;
      }
      catch (Exception e)
      {
        log.Error(e, "InvCodesListView::Init Unable to cast the Object " + parent + " to AActivitySpace. The following exception occured: " + e.Message);
        // DCA - No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + parent + " to AActivitySpace.",
         e);
      }
      try
      {
        m_imgInvitation = GetIcon(PTImageType.ICON_INVITATION);
      }
      catch (Exception e)
      {
        m_imgInvitation = null;
      }
    }
    
    /// <summary>
    /// Returns the HTML for the space below the Action bar.
    /// (The one with the add and delete icons).
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      //Spacer Row begin
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("5");
      //Spacer Row ends
      // 1st Row begin (there is only one row)
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myCell.AddInnerHTMLString(m_asOwner.GetString(1296, "ptmsgs_portaladminmsgs"));
      myCell.AddInnerHTMLElement(new HTMLBr());
      //Spacer Row begin
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("5");
      //Spacer Row ends
      return myTable;
    }
    
    /// <summary>
    /// Returns the HTML for the Action bar.
    /// (The one with the add icons).
    /// copied from JulieF's ExpListView but got rid of the delete Action cause invitation
    /// instances can't be deleted.
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected override HTMLTable GetHTMLForActionBar()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myTable = new HTMLTable();
      myTable.SetBorder("0");
      myTable.SetCellPadding("0");
      myTable.SetCellSpacing("0");
      // 1st Row begin (there is only one row)
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      // Add icon cell
      myRow.AddInnerHTMLElement(GetHTMLForAddAction());
      // Empty Cell
      myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      // Add Extra HTML to the action bar (like a "create" button)
      AddHTMLToActionBar(myRow);
      // Last Empty Cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetHeight("25");
      myCell.AddInnerHTMLString(SPACE);
      // 1st Row ends
      return myTable;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      // mj: removed 'Javascript:' from function name
      myAnchor = ConstructStaticHelpers.GetJavascriptAnchor("", JS_CREATE_POPUP + "()");
      myAnchor.AddInnerHTMLElement(myImage);
      if (m_imgInvitation != null)
      {
        myAnchor.AddInnerHTMLElement(m_imgInvitation);
      }
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the sub header.
    /// </summary>
    /// <returns>HTMLTableRow</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableRow GetHTMLForSubHeader()
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      HTMLImg myImage;
      PTConstruct myConstruct;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      Object[][] oArrExpListColInfo = ((IExpListModelRO) m_model).GetArrExpListColInfo();
      int nColumnID;
      for (int i = 0;i < oArrExpListColInfo.Length;i++)
      {
        // Row 1
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_WIDTH]);
        myCell.SetColSpan((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
        myCell.SetHeight("20");
        myCell.SetNoWrap(true);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.AddInnerHTMLString(SPACE);
        if (XPConvert.ToBoolean(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ENABLESORT]))
        {
          nColumnID = XPConvert.ToInteger(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID]);
          if (nColumnID == ((IExpListModelRO) m_model).GetMainColumnSort())
          {
            // mj: replaced the following line with a blank constructur and SetOnClick()
            // myAnchor = new HTMLAnchor("postToSelf('" +
            myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick("postToSelf(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_REVERSESORT) + "\'); return false;");
            myCell.AddInnerHTMLElement(myAnchor);
            myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
            if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IExpListModelRO) m_model).GetMainColumnSortDirection())
            {
              myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
               true, this.m_asOwner);
              myImage = (HTMLImg) myConstruct.GetHTMLElement();
              myImage.SetAlt(m_asOwner.GetString(55, 
              //_ui_DescendingIconAlt
              "ptmsgs_infrastructure"));
              myImage.SetAlign("absmiddle");
              myAnchor.AddInnerHTMLElement(myImage);
            } else
            {
              myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
               true, this.m_asOwner);
              myImage = (HTMLImg) myConstruct.GetHTMLElement();
              myImage.SetAlt(m_asOwner.GetString(54, 
              //_ui_AscendingIconAlt
              "ptmsgs_infrastructure"));
              myImage.SetAlign("absmiddle");
              myAnchor.AddInnerHTMLElement(myImage);
            }
          } else
          {
            // mj: replaced the following line with a blank constructur and SetOnClick()
            // myAnchor = new HTMLAnchor(
            myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("SortBy") + "(\'" + oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID] + "\'); return false;");
            myCell.AddInnerHTMLElement(myAnchor);
            myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
            }
        } else
        {
          myCell.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
          }
      }
      return myRow;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
    
    /// <summary>
    /// We ned to overwrite this method because because SendInvitationAS extends 
    /// from PlumtreeAS and not EditorAS.  However, we are still using EditorView
    /// to display headers, and that requires our activity space to be extended 
    /// from EditorAS.  Instead, we will circumvent that dependency.
    /// </summary>
    /// <param name="_sHeaderTitle">Title you want to display in the header.</param>
    /// <returns>HTMLTable</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLElement GetHeaderView(String _sHeaderTitle)
    {
      return GetHeaderViewHelper(m_asOwner, _sHeaderTitle);
    }
  }
}