using System;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.admin.sendinvitation
{
  /// <author>
  /// DustinA
  /// AActivitySpaces contain the MVC setup for a set of Display Pages, as well
  /// as the Display Pages themselves.  All objects should come to their parent
  /// AActivitySpace for access to other objects, such as IModels, IViews, and
  /// user objects like IPTSession and UserPreferences.
  /// Activity spaces setup and manage the interaction between the different MVC
  /// objects and the IDisplayPage.  They initialize all of the objects, and can
  /// get and set data on the Models if necessary.  Activity Spaces are not subject
  /// to the strict data/logic/presentation separation that MVC components are.
  /// </author>
  public class SendInvitationAS : PlumtreeAS
  {
    public const String STR_MVC_CLASS_NAME = "SendInvitationAS";
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // DCA - call super's to check for change in navigational scheme
      base.CheckBasicAccess(strPage, strControl, bSameSpace);
      return ((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_INVITATIONS);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SendInvitationAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SendInvitationRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SendInvitationDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SendInvitation");
      } else
      if (NewLinkPopUpDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_CreateInvitationLink");
      }
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      // SendInvitation Display Page
      SendInvitationDP SendInvPage = new SendInvitationDP();
      RegisterPage(SendInvPage);
      // NewLinkPopUp Display Page
      NewLinkPopUpDP NewLinkPage = new NewLinkPopUpDP();
      RegisterPage(NewLinkPage);
      // CreateInvCode Display Page
      CreateInvCodeDP CreateCodePage = new CreateInvCodeDP();
      RegisterPage(CreateCodePage);
      // CodePopUp Display Page
      CodePopUpDP CodePopUpPage = new CodePopUpDP();
      RegisterPage(CodePopUpPage);
      // Invitation ExpList Model
      RegisterModel(InvCodesListModel.STR_MVC_CLASS_NAME);
      IModel myModel = GetModel(InvCodesListModel.STR_MVC_CLASS_NAME);
      // Invitation ExpList Control
      RegisterControl(InvCodesListControl.STR_MVC_CLASS_NAME, myModel);
      // Invitation ExpList Views
      RegisterView(InvCodesListView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(CodePopUpView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(NewLinkPopUpView.STR_MVC_CLASS_NAME, myModel);
      // SendInvitation Model
      RegisterModel(SendInvitationModel.STR_MVC_CLASS_NAME);
      myModel = GetModel(SendInvitationModel.STR_MVC_CLASS_NAME);
      // SendInvitation Repost Control
      RegisterControl(SendInvitationRepostControl.STR_MVC_CLASS_NAME, myModel);
      // SendInvitation Views
      RegisterView(SendInvitationView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(CreateInvCodeView.STR_MVC_CLASS_NAME, myModel);
    }
  }
}