using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.auditmanager
{
  /// <summary>
  /// This class implements the Activity Space for the Audit Manager utility.  It
  /// incorporates the display pages from the Audit Query Central editor as well.
  /// </summary>
  /// <author>ErickS</author>
  public class AuditManagerEditorAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.auditmanager.AuditManagerEditorAS");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AuditManagerEditor";
    private const String sClassName = "com.plumtree.portalpages.admin.serversettings.auditmanager.AuditManagerEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AuditManagerEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(1614, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (AuditManagerRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (AuditManagerDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AuditManager_MainSettings");
      } else
      if (AuditQueryCentralDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AuditManager_CreateAuditQuery");
      } else
      if (AuditQueryResultDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AuditManager_RunQuery");
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession());
      if (!bInAdminGroup)
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = AuditManagerModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(AuditManagerModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new AuditManagerDP());
      // Register Controls
      RegisterControl(AuditManagerRepostControl.STR_MVC_CLASS_NAME, myModel);
      //Register AuditManagerView
      RegisterView(MessageTypesView.STR_MVC_CLASS_NAME, myModel);
      //Register ArchivingAgentView
      RegisterView(ArchivingAgentView.STR_MVC_CLASS_NAME, myModel);
      //Register MessageDeleteView
      RegisterView(MessageDeleteView.STR_MVC_CLASS_NAME, myModel);
      //********** Audit Query Central registration ************
      // Register DisplayPages
      RegisterPage(new AuditQueryCentralDP());
      RegisterPage(new AuditQueryResultDP());
      //Register SearchCriteria Section
      RegisterView(SearchCriteriaView.STR_MVC_CLASS_NAME, myModel);
      //Register TimesDates Section
      RegisterView(TimesDatesView.STR_MVC_CLASS_NAME, myModel);
      //Register DisplayPrefs Section
      RegisterView(DisplayPrefsView.STR_MVC_CLASS_NAME, myModel);
      //Register AuditQueryResult Section
      RegisterView(AuditQueryResultView.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      SetCurrentPage(AuditManagerDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1615, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AuditManagerDP.STR_MVC_CLASS_NAME);
      //************ Audit Query Central pages **************
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AuditQueryCentralDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AuditQueryResultDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      //Sets left nav menu
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 96;
          int iTipId = 97;
          int iSecondaryTipId = 98;
          tm.SetTipTitle(this.GetString(iTitleId, ResourceConstants.TIPS));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           ResourceConstants.TIPS));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, ResourceConstants.TIPS);
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
  }
}
//	Got the tips model
