using System;
// Framework Imports
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.auditmanager
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the Expandable List page of the List Editor.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class AuditQueryCentralDP : EditorDP
  {
    // ***CHANGE_HERE*** Change the name of the class.
    // ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
    //       when you are done.
    // ***CHANGE_HERE*** Set the class name.
    // COMMENT1- All the DPs in your AS need to have a unique name.
    public const String STR_MVC_CLASS_NAME = "AuditQueryCentral";
    
    /// <summary>
    /// Displays some HTML after the body tag and before the form tag.
    /// For example this is used by pages using a DHTML calendar to display the div tag.
    /// The function is optional.  If it exists, it will be called by the framework, and
    /// the resulting HTMLElement will be added in the right place.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElementCollection DisplayHTMLBeforeForm()
    {
      IAuditManagerModelRO ptROModel = (IAuditManagerModelRO) m_asOwner.GetModel(AuditManagerModel.STR_MVC_CLASS_NAME);
      return ptROModel.GetDatePickerControlManager(AuditManagerModel.N_DATE_PICKER_PAGE_TYPE_QUERY).GetPagePreFormContent();
      }
    
    /// <summary>
    /// Returns the HTML that is placed in the HEAD section of this HTML page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElementCollection DisplayHTMLinHEAD()
    {
      IAuditManagerModelRO ptROModel = (IAuditManagerModelRO) m_asOwner.GetModel(AuditManagerModel.STR_MVC_CLASS_NAME);
      return ptROModel.GetDatePickerControlManager(AuditManagerModel.N_DATE_PICKER_PAGE_TYPE_MESSAGES).GetJSIncludes();
      }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      // ***CHANGE_HERE*** Returns the String to display on the left navigation menu, 
      //       linking to that page.
      // ***COMMENT_1*** That String will also be printed out in the page header, so
      //     even if you don't use the left nav menu, it should still return something.
      return (m_asOwner.GetString(1362, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1645, "ptmsgs_portaladminmsgs"),
       this.m_asOwner);
    }
    // Strings to localize.
    // ***CHANGE_HERE*** List of the Strings that need to be localized.
    // ***COMMENT_1*** The names should all start with "_ui_".
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for that Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // ***CHANGE_HERE PLUG-IN ONLY*** For each Section you want to display on that page, 
      //       copy the line below and replace ListView with your Section name.
      // ***CHANGE_HERE GROWABLELIST*** Display the list.
      //views.AddInnerHTMLElement(((EditorView)
      //	m_asOwner.GetView(AuditQueryCentralEditorAS.m_strStorageGrowableList)).Display());
      // ***CHANGE_HERE SELECTPTOBJECT*** Display the list.
      //views.AddInnerHTMLElement(((EditorView)
      //	m_asOwner.GetView(AuditManagerEditorAS.m_strStorageSelectPTObject)).Display());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SearchCriteriaView.STR_MVC_CLASS_NAME)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      // ***CHANGE_HERE*** If you have more than one Section, 
      //      you might want to insert an empty table between your Views:
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(TimesDatesView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(DisplayPrefsView.STR_MVC_CLASS_NAME)).Display());
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      // ***CHANGE_HERE GROWABLELIST*** Display JavaScripts for the Growable Array.
      //myScripts.AddInnerHTMLElement(m_asOwner.GetView(AuditQueryCentralEditorAS.m_strStorageGrowableList).DisplayJavascript());
      // ***CHANGE_HERE SELECTPTOBJECT*** Display JavaScripts for the Select PTObject list.
      //myScripts.AddInnerHTMLElement(m_asOwner.GetView(AuditManagerEditorAS.m_strStorageSelectPTObject).DisplayJavascript());
      return myScripts;
    }
  }
}