using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.auditmanager
{
  /// <summary>
  /// This class implements the display prefs view for the Query Central part
  /// of the Audit Query Manager
  /// </summary>
  /// <author>ErickS</author>
  public class DisplayPrefsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.auditmanager.DisplayPrefsView");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DisplayPrefsView";
    // HTML Object names.
    
    /// <summary>
    /// Radio button for the sort type 
    /// </summary>
    public const String HTMLRADIO_SORTTYPE = "in_ra_SortType";
    
    /// <summary>
    /// Input for results per page 
    /// </summary>
    public const String HTMLINPUT_RESULTSPERPAGE = "in_tx_ResultsPerPage";
    public static readonly int iNewestFirst = PT_ORDERBY_SETTINGS.PT_ORDERBY_DESCENDING;
    public static readonly int iOldestFirst = PT_ORDERBY_SETTINGS.PT_ORDERBY_ASCENDING;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DisplayPrefsView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable = new HTMLTable();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1385,
         "ptmsgs_portaladminmsgs")));
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder("1");
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        /* Sort messages row begin */
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        myCell.SetWidth("20%");
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1387, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        // add first sort option
        myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_SORTTYPE,
         m_asOwner.GetString(1388, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
        myInput.SetValue(XPConvert.ToString(iNewestFirst));
        if (((IAuditManagerModelRO) m_model).GetSortType() == iNewestFirst)
        {
          myInput.SetChecked(true);
        }
        mySpan.AddInnerHTMLElement(myInput);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1388, "ptmsgs_portaladminmsgs"));
        // second row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        // create empty cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        // add second sort option
        myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_SORTTYPE,
         m_asOwner.GetString(1389, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
        myInput.SetValue(XPConvert.ToString(iOldestFirst));
        if (((IAuditManagerModelRO) m_model).GetSortType() == iOldestFirst)
        {
          myInput.SetChecked(true);
        }
        mySpan.AddInnerHTMLElement(myInput);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1389, "ptmsgs_portaladminmsgs"));
        /* Sort Messages end */
        /* Results per Page begin */
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1390, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_RESULTSPERPAGE,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetValue("" + ((IAuditManagerModelRO) m_model).GetResultsPerPage() + "");
        myInput.SetMaxLength(4);
        myInput.SetSize(4);
      }
      /* Results per Page end */
      catch (Exception e)
      {
        log.Error(e, "DisplayPrefsView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1386, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}