using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.auditmanager
{
  /// <author>ErickS</author>
  public class MessageDeleteView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.auditmanager.MessageDeleteView");
    public const String STR_MVC_CLASS_NAME = "MessageDeleteView";
    // HTML Object names.
    // ***CHANGE_HERE*** Declare some constans for each 
    //        HTML object you are using in the display method
    // ***COMMENT_1*** You should follow the HTMLElements naming standards:
    //       <select> starts with in_se
    //       <input button> starts with in_bu
    //       <input text> starts with in_tx
    //       <input checkbox> starts with in_cb
    //       <input radio> starts with in_ra
    //       <textarea> starts with in_ta
    public const String HTMLCHECKBOX_ITEM_CHANGE = "in_cb_DeleteItemChange";
    public const String HTMLCHECKBOX_ITEM_DELETION = "in_cb_DeleteItemDeletion";
    public const String HTMLCHECKBOX_LOCKED_ACCOUNT = "in_cb_DeleteLockedAccount";
    public const String HTMLCHECKBOX_SECURITY_CHANGE = "in_cb_DeleteSecurityChange";
    public const String HTMLCHECKBOX_USER_LOGIN = "in_cb_DeleteUserLogin";
    public const String HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE = "in_cb_DeleteGlobalSystemChange";
    public const String HTMLCHECKBOX_DELETEACTION = "in_cb_DeleteAction";
    public const int intUnchecked = 0;
    public const int intChecked = 1;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MessageDeleteView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLSpan mySpan;
      HTMLInput myInput;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1616,
         "ptmsgs_portaladminmsgs")));
        HTMLTable myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder("1");
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // Delete warning
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetColSpan(CommonHTMLStrings.TWO);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        // Use auditing agent, don't delete manually.
        mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(3149, "ptmsgs_portaladminmsgs"));
        // Delete message start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("30%");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1618, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        // add the date picker
        myCell.AddInnerHTMLElement(((IAuditManagerModelRO) m_model).GetDatePickerControlManager(AuditManagerModel.N_DATE_PICKER_PAGE_TYPE_MESSAGES).GetComponentHTML(AuditManagerModel.STR_DELETION_DATE_PICKER_UNIQUE_ID));
        // Delete message type start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        myCell.SetVAlign("top");
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1619, "ptmsgs_portaladminmsgs"));
        int iMessageTypeValue = ((IAuditManagerModelRO) m_model).GetDeleteMessageTypeValue();
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        HTMLTable myNewTable = new HTMLTable();
        myCell.AddInnerHTMLElement(myNewTable);
        myRow = new HTMLTableRow();
        myNewTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Item Change
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_ITEM_CHANGE,
         "");
        bool bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE) == PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1620, "ptmsgs_portaladminmsgs"));
        // ***<input checkbox>*** ends here
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Security Change
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_SECURITY_CHANGE,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE) == PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1624, "ptmsgs_portaladminmsgs"));
        myRow = new HTMLTableRow();
        myNewTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Item Deletion
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_ITEM_DELETION,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION) == PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1621, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // User Login
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_USER_LOGIN,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_LOGIN) == PT_AUDIT_TYPES.PT_AUDIT_LOGIN) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1622, "ptmsgs_portaladminmsgs"));
        // Start in a new row
        myRow = new HTMLTableRow();
        myNewTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Locked Account
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_LOCKED_ACCOUNT,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT) == PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1623, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Global System Change
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE) == PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1625, "ptmsgs_portaladminmsgs"));
        // Start delete action
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1626, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // delete action checkbox
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_DELETEACTION,
         "");
        myInput.SetChecked((MessageDeleteView.intChecked == (((IAuditManagerModelRO) m_model).GetDeleteAction())) ? true : false);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1627, "ptmsgs_portaladminmsgs"));
        }
      catch (Exception e)
      {
        log.Error(e, "MessageDeleteView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1617, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}