using System;
// Plumtree Server Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.auditmanager
{
  /// <summary>
  /// This class implements the search criteria view for the Audit Query Central
  /// part of the Audit Manager
  /// </summary>
  public class SearchCriteriaView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.auditmanager.SearchCriteriaView");
    public const String STR_MVC_CLASS_NAME = "SearchCriteriaView";
    // HTML Object names.
    // ***CHANGE_HERE*** Declare some constans for each 
    //        HTML object you are using in the display method
    // ***COMMENT_1*** You should follow the HTMLElements naming standards:
    //       <select> starts with in_se
    //       <input button> starts with in_bu
    //       <input text> starts with in_tx
    //       <input checkbox> starts with in_cb
    //       <input radio> starts with in_ra
    //       <textarea> starts with in_ta
    public const String HTMLSELECT_ITEM_TYPE = "in_se_ItemType";
    public const String HTMLINPUT_ITEM_NAME = "in_tx_ItemName";
    public const String HTMLSELECT_ITEM_NAME_APPROXIMATE_TYPE = "in_se_ItemNameApproximateType";
    public const String HTMLINPUT_USER_NAME = "in_tx_UserName";
    public const String HTMLSELECT_USER_NAME_APPROXIMATE_TYPE = "in_se_UserNameApproximateType";
    public const String HTMLINPUT_SERVER_NAME = "in_tx_ServerName";
    public const String HTMLSELECT_SERVER_NAME_APPROXIMATE_TYPE = "in_se_ServerNameApproximateType";
    public const String HTMLINPUT_WORD_IN_MESSAGE = "in_tx_WordInMessage";
    public const String HTMLCHECKBOX_ITEM_CHANGE = "in_cb_ItemChange";
    public const String HTMLCHECKBOX_ITEM_DELETION = "in_cb_ItemDeletion";
    public const String HTMLCHECKBOX_LOCKED_ACCOUNT = "in_cb_LockedAccount";
    public const String HTMLCHECKBOX_SECURITY_CHANGE = "in_cb_SecurityChange";
    public const String HTMLCHECKBOX_USER_LOGIN = "in_cb_UserLogin";
    public const String HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE = "in_cb_GlobalSystemChange";
    public const int iAllItemType = -1;
    public const int iApproximateValue = 0;
    public const int iNotApproximateValue = 1;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SearchCriteriaView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable = new HTMLTable();
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLInput myInput;
      HTMLSpan mySpan;
      HTMLSelect mySelect;
      HTMLOption myOption;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(1391,
         "ptmsgs_portaladminmsgs")));
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder("1");
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        /* Item Type row begin */
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1393, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        mySelect = new HTMLSelect(HTMLSELECT_ITEM_TYPE, "itemtypeselect");
        mySelect.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        myCell.AddInnerHTMLElement(mySelect);
        // ***EXAMPLE*** How to implement a <select> ?
        // ***<select>*** begins here
        // option 1 - All
        myOption = new HTMLOption("-1");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1394, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == iAllItemType)
        {
          myOption.SetSelected(true);
        }
        //make a collection -mgs
        HTMLElementCollection col = new HTMLElementCollection();
        // option 2 - Auth Source
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_AUTHSOURCE_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1395, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_AUTHSOURCE_ID)
        {
          myOption.SetSelected(true);
        }
        // option 3 - Community
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_COMMUNITY_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1397, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_COMMUNITY_ID)
        {
          myOption.SetSelected(true);
        }
        // option 4 - Content Syndication
        //MES- Content Syndication has been desupported
        // option 5 - Crawler
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_CRAWLER_ID));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1399, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_CRAWLER_ID)
        {
          myOption.SetSelected(true);
        }
        // option 6 - Data Source
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_DATASOURCE_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1400, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_DATASOURCE_ID)
        {
          myOption.SetSelected(true);
        }
        // option 7 - Document
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_CATALOGCARD_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1409, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_CATALOGCARD_ID)
        {
          myOption.SetSelected(true);
        }
        // option 8 - Document Folder
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_CATALOGFOLDER_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1396, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
        {
          myOption.SetSelected(true);
        }
        // option 9 - Document Type
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_DOCUMENTTYPE_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1401, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_DOCUMENTTYPE_ID)
        {
          myOption.SetSelected(true);
        }
        // option 10 - Filter
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_FILTER_ID));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1403, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_FILTER_ID)
        {
          myOption.SetSelected(true);
        }
        // option 11 - Global Object
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_GLOBALOBJECT_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1405, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_GLOBALOBJECT_ID)
        {
          myOption.SetSelected(true);
        }
        // option 12 - Group
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_USERGROUP_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1406, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_USERGROUP_ID)
        {
          myOption.SetSelected(true);
        }
        // option 13 - Invitation
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_INVITATION_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1407, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_INVITATION_ID)
        {
          myOption.SetSelected(true);
        }
        // option 14 - Job
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_JOB_ID));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1408, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_JOB_ID)
        {
          myOption.SetSelected(true);
        }
        // option 15 - Network Search
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_FEDERATEDPORTAL_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1402, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_FEDERATEDPORTAL_ID)
        {
          myOption.SetSelected(true);
        }
        // option 16 - Portlet
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1404, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_GADGET_ID)
        {
          myOption.SetSelected(true);
        }
        // option 17 - Property
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1410, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_PROPERTY_ID)
        {
          myOption.SetSelected(true);
        }
        // option 18 - Site
        //MES- Sites have been desupported
        // option 19 - Sync Agent
        myOption = new HTMLOption("" + PT_CLASSIDS.PT_SYNCAGENT_ID + "");
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1412, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_SYNCAGENT_ID)
        {
          myOption.SetSelected(true);
        }
        // option 20 - User
        myOption = new HTMLOption(XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1413, "ptmsgs_portaladminmsgs"));
        col.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemType() == PT_CLASSIDS.PT_USER_ID)
        {
          myOption.SetSelected(true);
        }
        //add the collection to the select -mgs
        mySelect.AddInnerHTMLElement(col);
        // Item Type Row end
        // Item Name start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1414, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        // ***EXAMPLE*** How to display an input text?
        // ***<input text>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_ITEM_NAME,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        // ***EXAMPLE*** This is how you can HTMLEncode your Strings
        myInput.SetValue(((IAuditManagerModelRO) m_model).GetItemName());
        myInput.SetMaxLength(63);
        myInput.SetSize(50);
        // ***<input text>*** ends here
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        mySelect = new HTMLSelect(HTMLSELECT_ITEM_NAME_APPROXIMATE_TYPE, "itemnameselect");
        mySelect.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        myCell.AddInnerHTMLElement(mySelect);
        // ***EXAMPLE*** How to implement a <select> ?
        // ***<select>*** begins here
        // option 1 - Approximate
        myOption = new HTMLOption(XPConvert.ToString(iApproximateValue));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1417, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemNameApproximateType() == iApproximateValue)
        {
          myOption.SetSelected(true);
        }
        // option 2 - Not Approximate
        myOption = new HTMLOption(XPConvert.ToString(iNotApproximateValue));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1418, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetItemNameApproximateType() == iNotApproximateValue)
        {
          myOption.SetSelected(true);
        }
        // Item Name end
        // User Name start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1415, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        // ***EXAMPLE*** How to display an input text?
        // ***<input text>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_USER_NAME,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        // ***EXAMPLE*** This is how you can HTMLEncode your Strings
        myInput.SetValue(((IAuditManagerModelRO) m_model).GetUserName());
        myInput.SetMaxLength(63);
        myInput.SetSize(50);
        // ***<input text>*** ends here
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        mySelect = new HTMLSelect(HTMLSELECT_USER_NAME_APPROXIMATE_TYPE, "usernameselect");
        mySelect.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        myCell.AddInnerHTMLElement(mySelect);
        // ***EXAMPLE*** How to implement a <select> ?
        // ***<select>*** begins here
        // option 1 - Approximate
        myOption = new HTMLOption(XPConvert.ToString(iApproximateValue));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1417, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetUserNameApproximateType() == iApproximateValue)
        {
          myOption.SetSelected(true);
        }
        // option 2 - Not Approximate
        myOption = new HTMLOption(XPConvert.ToString(iNotApproximateValue));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1418, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetUserNameApproximateType() == iNotApproximateValue)
        {
          myOption.SetSelected(true);
        }
        // User Name end
        // Server Name start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1416, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        // ***EXAMPLE*** How to display an input text?
        // ***<input text>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_SERVER_NAME,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        // ***EXAMPLE*** This is how you can HTMLEncode your Strings
        myInput.SetValue(((IAuditManagerModelRO) m_model).GetServerName());
        myInput.SetMaxLength(63);
        myInput.SetSize(50);
        // ***<input text>*** ends here
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        mySelect = new HTMLSelect(HTMLSELECT_SERVER_NAME_APPROXIMATE_TYPE,
         "servernameselect");
        mySelect.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        myCell.AddInnerHTMLElement(mySelect);
        // ***EXAMPLE*** How to implement a <select> ?
        // ***<select>*** begins here
        // option 1 - Approximate
        myOption = new HTMLOption(XPConvert.ToString(iApproximateValue));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1417, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetServerNameApproximateType() == iApproximateValue)
        {
          myOption.SetSelected(true);
        }
        // option 2 - Not Approximate
        myOption = new HTMLOption(XPConvert.ToString(iNotApproximateValue));
        mySpan = new HTMLSpan();
        myOption.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1418, "ptmsgs_portaladminmsgs"));
        mySelect.AddInnerHTMLElement(myOption);
        if (((IAuditManagerModelRO) m_model).GetServerNameApproximateType() == iNotApproximateValue)
        {
          myOption.SetSelected(true);
        }
        // Server Name end
        // Word in Message start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1419, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        // ***EXAMPLE*** How to display an input text?
        // ***<input text>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_WORD_IN_MESSAGE,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        // ***EXAMPLE*** This is how you can HTMLEncode your Strings
        myInput.SetValue(((IAuditManagerModelRO) m_model).GetWordInMessage());
        myInput.SetMaxLength(63);
        myInput.SetSize(50);
        // ***<input text>*** ends here
        // Word in Message end
        // Message Type start
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        myCell.SetVAlign("TOP");
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1420, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        myTable = new HTMLTable();
        myCell.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        int iMessageTypeValue = ((IAuditManagerModelRO) m_model).GetQueryMessageTypeValue();
        // Item Change
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_ITEM_CHANGE,
         "");
        bool bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE) == PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1421, "ptmsgs_portaladminmsgs"));
        // ***<input checkbox>*** ends here
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Security Change
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_SECURITY_CHANGE,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE) == PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1425, "ptmsgs_portaladminmsgs"));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Item Deletion
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_ITEM_DELETION,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION) == PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1422, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // User Login
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_USER_LOGIN,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_LOGIN) == PT_AUDIT_TYPES.PT_AUDIT_LOGIN) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1423, "ptmsgs_portaladminmsgs"));
        // Start in a new row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Locked Account
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_LOCKED_ACCOUNT,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT) == PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1424, "ptmsgs_portaladminmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Global System Change
        // ***<input checkbox>*** begins here
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE,
         "");
        bSetChecked = ((iMessageTypeValue & PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE) == PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE) ? true : false;
        myInput.SetChecked(bSetChecked);
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1426, "ptmsgs_portaladminmsgs"));
        }
      // Message Type end
      catch (Exception e)
      {
        log.Error(e, "SearchCriteriaView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1392, "ptmsgs_portaladminmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}