using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.admin.serversettings.general
{
  /// <author></author>
  public class SetServerSettingsModel : EditorModel,ISetServerSettingsModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.general.SetServerSettingsModel");
    public const String STR_MVC_CLASS_NAME = "SetServerSettingsModel";
    public const int MIN_PASSWORD_LENGTH = 5;
    public const int MAX_PASSWORD_LENGTH = 20;
    public const int MAXIMUM_PASSWORD_HISTORY = 12;
    private AActivitySpace m_asasParent = null;
    private String sDefaultLocale = null;
    private String sDefaultTimeZone = null;
    private String sDocumentDisplayURL = null;
    //	private String sIncomingSearchURL		    = null;
    private int iMinutesToLockAccounts = -1;
    private int iMinutesToTrackFailedLogins = -1;
    private int iNumberOfFailedLoginsAllowed = -1;
    private String sPrimaryWebServerURL = null;
    private String sSoapServerURL = null;
    private String sSharedFilesPath = null;
    private String sInviteCipherKey = null;
    private bool bInviteCipherKeySet = false;
    private bool m_bMinutesToLockAccountsError = false;
    private bool m_bMinutesToTrackFailedLoginsError = false;
    private bool m_bNumberOfFailedLoginsAllowedError = false;
    private Object[] settings;
    private bool bAllowNumericAuthentication = false;
    private bool bAllowNumericAuthenticationSet = false;
    private bool bAllowUserCreation = false;
    private bool bAllowUserCreationSet = false;
    private bool bAutoAssignNumericID = false;
    private bool bAutoAssignNumericIDSet = false;
    private bool bEnableAccountLocking = false;
    private bool bEnableAccountLockingSet = false;
    private bool bEnableDebugSubportalRulesMode = false;
    private bool bEnableDebugSubportalRulesModeSet = false;
    private bool bEnableDebugPortletErrorsMode = false;
    private bool bEnableDebugPortletErrorsModeSet = false;
    // Default values for the password management rules.
    private int m_nPasswordLength = -1;
    private bool m_bPasswordNumbers = false;
    private bool m_bPasswordCasing = false;
    private bool m_bPasswordPunctuation = false;
    private bool m_bPasswordNoUserIDs = false;
    private int m_nPasswordReuseHistory = -1;
    private int m_nPasswordExpiration = -1;
    private int m_nPasswordExpirationWarning = -1;
    private bool m_bPasswordLengthError = false;
    private bool m_bPasswordReuseHistoryError = false;
    private bool m_bPasswordExpirationError = false;
    private bool m_bPasswordExpirationWarningError = false;
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// Use the Editor Type if needed.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
      if (!ptSession.GetSessionInfo().CheckCurrentUserIsAdmin())
      {
        return false;
      }
      try
      {
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        // load default password settings
        m_nPasswordLength = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_LENGTH);
        m_bPasswordNumbers = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_NUMBERS);
        m_bPasswordCasing = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_CASING);
        m_bPasswordPunctuation = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_PUNCTUATION);
        m_bPasswordNoUserIDs = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_NO_USER_IDS);
        m_nPasswordReuseHistory = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_REUSE_HISTORY);
        m_nPasswordExpiration = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION);
        m_nPasswordExpirationWarning = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION_WARNING);
        }
      catch (Exception e)
      {
        log.Error(e, "Unable to load password settings from DB in server settings utility, using default values.");
        // NOTE: This will reset all the values if there is an error loading any of them.  Is this the right
        // thing to do?
        // Default values for the password management rules.
        m_nPasswordLength = 7;
        m_bPasswordNumbers = false;
        m_bPasswordCasing = false;
        m_bPasswordPunctuation = false;
        m_bPasswordNoUserIDs = true;
        m_nPasswordReuseHistory = 0;
        m_nPasswordExpiration = 0;
        m_nPasswordExpirationWarning = 0;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SetServerSettingsModel();
    }
    
    /// <summary>
    /// Code executed after the object is stored.
    /// </summary>
    public override void DoTaskAfterStore()
    {
    }
    
    /// <summary>
    /// Initializes IPTProperty with the property type member
    /// variable just before we store the object in the DB.
    /// Also sets 2 other values to default.
    /// </summary>
    public override void DoTaskBeforeStore()
    {
    }
    public override void Finish()
    {
      log.Debug("Finish()");
      IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
      IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       true);
      //   PRIMARY WEB SERVER URL
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_WEBSERVER_URL,
         this.GetPrimaryWebServerURL());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: Primary Web Server URL");
        }
      //   SOAP SERVER URL
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_SOAPAPI_URL,
         this.GetSoapServerURL());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: pt soap api url");
        }
      //   SharedFilesPath
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_INSTALL_PATH,
         this.GetSharedFilesPath());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: install path");
        }
      //
      //
      //		//   INCOMING SEARCH URL
      //		try
      //		{
      //			IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
      //					true);
      //
      //			config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_OPENFEDERATEDSEARCH_URL,
      //				this.GetIncomingSearchURL());
      //		}
      //		catch (Exception ex)
      //		{
      //			
      //				log.Error(ex, //					"Error in SetServerSettingsModel::Finish: ");
      //			
      //		}
      //   AUTOASSIGN NUMERIC ID
      try
      {
        if (this.GetAutoAssignNumericID())
        {
          ptSession.SetSettings(PT_SESSION_SETTINGS.PT_SESSION_AUTOASSIGNNUMERICAUTH,
           1);
        } else
        {
          ptSession.SetSettings(PT_SESSION_SETTINGS.PT_SESSION_AUTOASSIGNNUMERICAUTH,
           0);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: auto assign numeric auth");
        }
      //   DISPLAY FILES URL
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_DISPLAYFILESDIRECTORY_URL,
         this.GetDocumentDisplayURL());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: display files url");
        }
      //   DEFAULT LOCALE
      try
      {
        //ptSession.SetSettings(PT_SESSION_SETTINGS.PT_SESSION_LOCALE,
        //	this.GetDefaultLocale());
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_DEFAULT_LOCALE,
         this.GetDefaultLocale());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: default locale");
        }
      //   DEFAULT TIME ZONE		
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_DEFAULT_TIMEZONE,
         this.GetDefaultTimeZone());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: default time zone");
        }
      //   ALLOW NUMERIC AUTHENTICATION
      try
      {
        if (this.GetAllowNumericAuthentication())
        {
          ptSession.SetSettings(PT_SESSION_SETTINGS.PT_SESSION_NUMERICAUTH,
           1);
        } else
        {
          ptSession.SetSettings(PT_SESSION_SETTINGS.PT_SESSION_NUMERICAUTH,
           0);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: numeric authentication");
        }
      //   ENABLE ACCOUNT LOCKING
      try
      {
        if (this.GetEnableAccountLocking())
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_ENABLELOCKING,
           1);
        } else
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_ENABLELOCKING,
           0);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: enable locking");
        }
      //   MINUTES TO LOCK
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_LOCKMINUTES,
         this.GetMinutesToLockAccounts());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: lock minutes");
        }
      //   MINUTES TO TRACK
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_BADLOGONMINUTES,
         this.GetMinutesToTrackFailedLogins());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: minutes to track");
        }
      //   NUMBER OF FAILURES
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_BADLOGONATTEMPTS,
         GetNumberOfFailedLoginsAllowed());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: number of failures");
        }
      //   CORE INVITE CRYPTO KEY
      try
      {
        if (bInviteCipherKeySet)
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_INVITE_CIPHER_KEY,
           GetInviteCipherKey());
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: core invite");
        }
      //   ALLOW USER CREATION TO ALL
      try
      {
        if (this.GetAllowUserCreation())
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ALLOW_NEW_USER_CREATION_TO_ALL,
           1);
          //	this will change this value in the application cache
          //	used by the login page.		
          PTLoginHelper.SetAllowUserCreation(this.m_asasParent, this.m_asasParent.GetApplication(),
           true);
        } else
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ALLOW_NEW_USER_CREATION_TO_ALL,
           0);
          //	this will change this value in the application cache
          //	used by the login page.		
          PTLoginHelper.SetAllowUserCreation(this.m_asasParent, this.m_asasParent.GetApplication(),
           false);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: user creation");
        }
      // Password Management Rules
      // Password Length
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_LENGTH,
         GetPasswordLength());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password length");
        }
      // Password Include Numbers
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_NUMBERS,
         GetPasswordIncludeNumbers());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password include numbers");
        }
      // Password Include Casing
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_CASING,
         GetPasswordIncludeCasing());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password include casing");
        }
      // Password Include Punctuation
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_PUNCTUATION,
         GetPasswordIncludePunctuation());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password include punctuation");
        }
      // Password No User IDs
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_NO_USER_IDS,
         GetPasswordNoUserIDs());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password no user ids");
        }
      // Password Reuse History
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_REUSE_HISTORY,
         GetPasswordReuseHistory());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password reuse history");
        }
      // Password Expiration
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION,
         GetPasswordExpiration());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password expiration");
        }
      // Password Expiration Warning
      try
      {
        config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION_WARNING,
         GetPasswordExpirationWarning());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: password expiration warning");
        }
      // ENABLE SUBPORTAL RULES DEBUGGING MODE
      try
      {
        if (this.GetEnableSubportalRulesDebugMode())
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_SUBPORTAL_RULES_MODE,
           1);
        } else
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_SUBPORTAL_RULES_MODE,
           0);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: rules debugging");
        }
      // ENABLE PORTLET ERRORS DEBUGGING MODE
      try
      {
        if (this.GetEnablePortletErrorsDebugMode())
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_PORTLET_ERRORS_MODE,
           1);
        } else
        {
          config.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_PORTLET_ERRORS_MODE,
           0);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in SetServerSettingsModel::Finish: portlet errors mode");
        }
      ClearCachedValues();
    }
    
    /// <returns></returns>
    public virtual bool GetAllowNumericAuthentication()
    {
      log.Debug("GetAllowNumericAuthentication() - bAllowNumericAuthentication: " + XPConvert.ToString(bAllowNumericAuthentication));
      if (!bAllowNumericAuthenticationSet)
      {
        log.Debug("Obtaining from portal server");
        bAllowNumericAuthenticationSet = true;
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        if (ptSession.GetSettingsAsInt(PT_SESSION_SETTINGS.PT_SESSION_NUMERICAUTH) == 1)
        {
          bAllowNumericAuthentication = true;
        } else
        {
          bAllowNumericAuthentication = false;
        }
      }
      return bAllowNumericAuthentication;
    }
    
    /// <returns></returns>
    public virtual bool GetAllowUserCreation()
    {
      if (!bAllowUserCreationSet)
      {
        bAllowUserCreationSet = true;
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        if (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ALLOW_NEW_USER_CREATION_TO_ALL) == 1)
        {
          bAllowUserCreation = true;
        } else
        {
          bAllowUserCreation = false;
        }
      }
      return bAllowUserCreation;
    }
    
    /// <returns></returns>
    public virtual bool GetAutoAssignNumericID()
    {
      if (!bAutoAssignNumericIDSet)
      {
        bAutoAssignNumericIDSet = true;
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        if ((ptSession.GetSettingsAsInt(PT_SESSION_SETTINGS.PT_SESSION_AUTOASSIGNNUMERICAUTH)) == 1)
        {
          bAutoAssignNumericID = true;
        } else
        {
          bAutoAssignNumericID = false;
        }
      }
      return bAutoAssignNumericID;
    }
    
    /// <returns></returns>
    public virtual String GetDefaultLocale()
    {
      if (sDefaultLocale == null)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        //sDefaultLocale = (String) ptSession.GetSettingsAsString(PT_SESSION_SETTINGS.PT_SESSION_LOCALE);
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        sDefaultLocale = (String) config.GetSettingAsString(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_DEFAULT_LOCALE);
        }
      return sDefaultLocale;
    }
    
    /// <returns></returns>
    public virtual String GetDefaultTimeZone()
    {
      log.Debug("GetDefaultTimeZone() - sDefaultTimeZone: " + sDefaultTimeZone);
      if (sDefaultTimeZone == null)
      {
        //	The server config var might be an Integer or a 
        //	String.  If it's an int, it's garbage to be 
        //	thrown away.  We set it as a String.
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        sDefaultTimeZone = (String) config.GetSettingAsString(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_DEFAULT_TIMEZONE);
        }
      log.Debug("GetDefaultTimeZone() - sDefaultTimeZone: " + sDefaultTimeZone);
      return sDefaultTimeZone;
    }
    
    /// <returns></returns>
    public virtual String GetDocumentDisplayURL()
    {
      if (sDocumentDisplayURL == null)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        sDocumentDisplayURL = (String) ptSession.GetSettingsAsString(PT_SESSION_SETTINGS.PT_SESSION_DISPLAYFILESDIRECTORYURL);
        }
      return sDocumentDisplayURL;
    }
    
    /// <returns></returns>
    public virtual bool GetEnableAccountLocking()
    {
      if (!bEnableAccountLockingSet)
      {
        bEnableAccountLockingSet = true;
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        if (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_ENABLELOCKING) == 1)
        {
          bEnableAccountLocking = true;
        } else
        {
          bEnableAccountLocking = false;
        }
      }
      return bEnableAccountLocking;
    }
    
    /// <returns></returns>
    public virtual bool GetEnableSubportalRulesDebugMode()
    {
      if (!bEnableDebugSubportalRulesModeSet)
      {
        bEnableDebugSubportalRulesModeSet = true;
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        if (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_SUBPORTAL_RULES_MODE) == 1)
        {
          bEnableDebugSubportalRulesMode = true;
        } else
        {
          bEnableDebugSubportalRulesMode = false;
        }
      }
      return bEnableDebugSubportalRulesMode;
    }
    
    /// <returns></returns>
    public virtual bool GetEnablePortletErrorsDebugMode()
    {
      if (!bEnableDebugPortletErrorsModeSet)
      {
        bEnableDebugPortletErrorsModeSet = true;
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        if (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_PORTLET_ERRORS_MODE) == 1)
        {
          bEnableDebugPortletErrorsMode = true;
        } else
        {
          bEnableDebugPortletErrorsMode = false;
        }
      }
      return bEnableDebugPortletErrorsMode;
    }
    //	/**
    //	 * 
    //	 *
    //	 * @return 
    //	 */
    //	public String GetIncomingSearchURL()
    //	{
    //		if (sIncomingSearchURL == null)
    //		{
    //			IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
    //
    //			sIncomingSearchURL = ptSession.GetSettingsAsString(PT_SESSION_SETTINGS.PT_SESSION_OPENFEDERATEDSEARCHURL);
    //		}
    //
    //		return sIncomingSearchURL;
    //	}
    
    /// <returns></returns>
    public virtual String GetSharedFilesPath()
    {
      if (sSharedFilesPath == null)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        sSharedFilesPath = config.GetSettingAsString(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_INSTALL_PATH);
        }
      return sSharedFilesPath;
    }
    
    /// <returns></returns>
    public virtual String GetSoapServerURL()
    {
      if (sSoapServerURL == null)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        sSoapServerURL = config.GetSettingAsString(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_SOAPAPI_URL);
        }
      return sSoapServerURL;
    }
    
    /// <returns></returns>
    public virtual int GetMinutesToLockAccounts()
    {
      if (iMinutesToLockAccounts == -1)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        iMinutesToLockAccounts = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_LOCKMINUTES);
        }
      return iMinutesToLockAccounts;
    }
    
    /// <returns>Whether or not there was an error on the MinutesToLockAccounts setting.</returns>
    public virtual bool HasMinutesToLockAccountsError()
    {
      return m_bMinutesToLockAccountsError;
    }
    
    /// <returns></returns>
    public virtual int GetMinutesToTrackFailedLogins()
    {
      if (iMinutesToTrackFailedLogins == -1)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        iMinutesToTrackFailedLogins = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_BADLOGONMINUTES);
        }
      return iMinutesToTrackFailedLogins;
    }
    
    /// <returns>Whether or not there was an error on the MinutesToTrackFailedLogins setting.</returns>
    public virtual bool HasMinutesToTrackFailedLoginsError()
    {
      return m_bMinutesToTrackFailedLoginsError;
    }
    
    /// <returns></returns>
    public virtual int GetNumberOfFailedLoginsAllowed()
    {
      if (iNumberOfFailedLoginsAllowed == -1)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        IPTServerConfigSettings config = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
         true);
        iNumberOfFailedLoginsAllowed = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_USERACCOUNT_BADLOGONATTEMPTS);
        }
      return iNumberOfFailedLoginsAllowed;
    }
    
    /// <returns>Whether or not there was an error on the NumberOfFailedLoginsAllowed setting.</returns>
    public virtual bool HasNumberOfFailedLoginsAllowedError()
    {
      return m_bNumberOfFailedLoginsAllowedError;
    }
    
    /// <returns></returns>
    public virtual String GetPrimaryWebServerURL()
    {
      if (sPrimaryWebServerURL == null)
      {
        IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
        sPrimaryWebServerURL = ptSession.GetSettingsAsString(PT_SESSION_SETTINGS.PT_SESSION_WEBSERVERURL);
        }
      return sPrimaryWebServerURL;
    }
    
    /// <returns>The minimum password length.</returns>
    public virtual int GetPasswordLength()
    {
      return m_nPasswordLength;
    }
    public virtual bool HasPasswordLengthError()
    {
      return m_bPasswordLengthError;
    }
    
    /// <returns>Whether or not numbers are required in the passwords.</returns>
    public virtual bool GetPasswordIncludeNumbers()
    {
      return m_bPasswordNumbers;
    }
    
    /// <returns>Whether or not both upper and lower case letters are required in the passwords.</returns>
    public virtual bool GetPasswordIncludeCasing()
    {
      return m_bPasswordCasing;
    }
    
    /// <returns>Whether or not punctuation is required in the passwords.</returns>
    public virtual bool GetPasswordIncludePunctuation()
    {
      return m_bPasswordPunctuation;
    }
    
    /// <returns>Whether or not user IDs should be dissalowed in the passwords.</returns>
    public virtual bool GetPasswordNoUserIDs()
    {
      return m_bPasswordNoUserIDs;
    }
    
    /// <returns>The number of passwords to keep in history to check for reuse.</returns>
    public virtual int GetPasswordReuseHistory()
    {
      return m_nPasswordReuseHistory;
    }
    public virtual bool HasPasswordReuseHistoryError()
    {
      return m_bPasswordReuseHistoryError;
    }
    
    /// <returns>The password expiration in days.</returns>
    public virtual int GetPasswordExpiration()
    {
      return m_nPasswordExpiration;
    }
    
    /// <returns>Whether or not there was an error in saving the password expiration in days.</returns>
    public virtual bool HasPasswordExpirationError()
    {
      return m_bPasswordExpirationError;
    }
    
    /// <returns>The password expiration warning in days.</returns>
    public virtual int GetPasswordExpirationWarning()
    {
      return m_nPasswordExpirationWarning;
    }
    
    /// <returns>Whether or not there was an error in saving the password expiration warning in days.</returns>
    public virtual bool HasPasswordExpirationWarningError()
    {
      return m_bPasswordExpirationWarningError;
    }
    
    /// <returns></returns>
    public virtual Object[] GetServerSettings()
    {
      return settings;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModel#Init(IActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      m_asasParent = parent;
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      settings = (Object[]) application.GetCachingManager().GetEntry("DisplayServerSettings");
      base.Init(parent);
    }
    
    /// <summary>
    /// Does nothing for now.
    /// </summary>
    public virtual void RepostAdvPage()
    {
    }
    // JF- do nothing for this one, it will just save the page.
    
    /// <summary>
    /// Modifies the object description on repost.
    /// </summary>
    public virtual void RepostMainPage()
    {
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      if (_sPageName.Equals(UserSettingsDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SaveUserSettingsPage(_htFormData);
      } else
      if (_sPageName.Equals(PortalURLsDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SavePortalUrlsPage(_htFormData);
      } else
      if (_sPageName.Equals(GeneralSettingsDP.STR_MVC_CLASS_NAME))
      {
        nPageStatus = SaveGeneralPage(_htFormData);
      }
      return nPageStatus;
    }
    
    /// <param name="b"></param>
    public virtual void SetAllowNumericAuthentication(bool b)
    {
      log.Debug("SetAllowNumericAuthentication()");
      bAllowNumericAuthentication = b;
    }
    
    /// <param name="b"></param>
    public virtual void SetAllowUserCreation(bool b)
    {
      bAllowUserCreation = b;
    }
    
    /// <param name="b"></param>
    public virtual void SetAutoAssignNumericID(bool b)
    {
      bAutoAssignNumericID = b;
    }
    
    /// <param name="s"></param>
    public virtual void SetDefaultLocale(String s)
    {
      sDefaultLocale = s;
    }
    
    /// <param name="s"></param>
    public virtual void SetDefaultTimeZone(String s)
    {
      sDefaultTimeZone = s;
    }
    
    /// <param name="s"></param>
    public virtual void SetDocumentDisplayURL(String s)
    {
      sDocumentDisplayURL = s;
    }
    
    /// <param name="s"></param>
    public virtual void SetSoapServerURL(String s)
    {
      sSoapServerURL = s;
    }
    
    /// <param name="s"></param>
    public virtual void SetSharedFilesPath(String s)
    {
      sSharedFilesPath = s;
    }
    
    /// <param name="b"></param>
    public virtual void SetEnableAccountLocking(bool b)
    {
      bEnableAccountLocking = b;
    }
    
    /// <param name="b"></param>
    public virtual void SetEnableDebugSubportalRulesMode(bool b)
    {
      bEnableDebugSubportalRulesMode = b;
    }
    
    /// <param name="b"></param>
    public virtual void SetEnableDebugPortletErrorsMode(bool b)
    {
      bEnableDebugPortletErrorsMode = b;
    }
    //	/**
    //	 * 
    //	 *
    //	 * @param s 
    //	 */
    //	public void SetIncomingSearchURL(String s)
    //	{
    //		sIncomingSearchURL = s;
    //	}
    
    /// <param name="s"></param>
    public virtual void SetMinutesToLockAccounts(int i)
    {
      iMinutesToLockAccounts = i;
    }
    
    /// <param name="s"></param>
    public virtual void SetMinutesToTrackFailedLogins(int i)
    {
      iMinutesToTrackFailedLogins = i;
    }
    
    /// <param name="s"></param>
    public virtual void SetNumberOfFailedLoginsAllowed(int i)
    {
      iNumberOfFailedLoginsAllowed = i;
    }
    
    /// <param name="s"></param>
    public virtual void SetPrimaryWebServerURL(String s)
    {
      sPrimaryWebServerURL = s;
    }
    
    /// <param name="_nPasswordLength">The minimum password length</param>
    public virtual void SetPasswordLength(int _nPasswordLength)
    {
      m_nPasswordLength = _nPasswordLength;
    }
    
    /// <param name="_bPasswordNumbers">Whether or not numbers are required in the passwords.</param>
    public virtual void SetPasswordIncludeNumbers(bool _bPasswordNumbers)
    {
      m_bPasswordNumbers = _bPasswordNumbers;
    }
    
    /// <param name="_bPasswordCasing">Whether or not both upper and lower case letters are required in the passwords.</param>
    public virtual void SetPasswordIncludeCasing(bool _bPasswordCasing)
    {
      m_bPasswordCasing = _bPasswordCasing;
    }
    
    /// <param name="_bPasswordPunctuation">Whether or not punctuation is required in the passwords.</param>
    public virtual void SetPasswordIncludePunctuation(bool _bPasswordPunctuation)
    {
      m_bPasswordPunctuation = _bPasswordPunctuation;
    }
    
    /// <param name="_bPasswordNoUserIDs">Whether or not user IDs should be dissalowed in the passwords.</param>
    public virtual void SetPasswordNoUserIDs(bool _bPasswordNoUserIDs)
    {
      m_bPasswordNoUserIDs = _bPasswordNoUserIDs;
    }
    
    /// <param name="_nPasswordReuseHistory">The number of passwords to keep in history to check for reuse.</param>
    public virtual void SetPasswordReuseHistory(int _nPasswordReuseHistory)
    {
      m_nPasswordReuseHistory = _nPasswordReuseHistory;
    }
    
    /// <param name="_nPasswordExpiration">The password expiration in days.</param>
    public virtual void SetPasswordExpiration(int _nPasswordExpiration)
    {
      m_nPasswordExpiration = _nPasswordExpiration;
    }
    
    /// <param name="_nPasswordExpirationWarning">The password expiration warning in days.</param>
    public virtual void SetPasswordExpirationWarning(int _nPasswordExpirationWarning)
    {
      m_nPasswordExpirationWarning = _nPasswordExpirationWarning;
    }
    // BEGIN ***************** save DP methods *****************
    
    /// <summary>
    /// Saves the data on the User Settings page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    protected virtual int SaveUserSettingsPage(XPHashtable _htFormData)
    {
      // Reset the error flags
      m_bMinutesToTrackFailedLoginsError = false;
      m_bMinutesToLockAccountsError = false;
      m_bNumberOfFailedLoginsAllowedError = false;
      m_bPasswordLengthError = false;
      m_bPasswordReuseHistoryError = false;
      m_bPasswordExpirationError = false;
      m_bPasswordExpirationWarningError = false;
      String[] data;
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      log.Debug("SaveMainPage()");
      //	ALLOW USER CREATION
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_ALLOW_USER_CREATION);
      if (data != null)
      {
        this.SetAllowUserCreation(XPConvert.ToBoolean(data[0]));
      } else
      {
        this.SetAllowUserCreation(false);
      }
      //	ALLOW NUMERIC LOGIN
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_ALLOW_NUMERIC_LOGIN);
      if (data != null)
      {
        log.Debug("SaveMainPage() - data is PARAM_ALLOW_NUMERIC_LOGIN - data[0]: " + data[0]);
        this.SetAllowNumericAuthentication(XPConvert.ToBoolean(data[0]));
        } else
      {
        this.SetAllowNumericAuthentication(false);
      }
      //	AUTO ASSIGN IDS
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_AUTO_ASSIGN_IDS);
      if (data != null)
      {
        this.SetAutoAssignNumericID(XPConvert.ToBoolean(data[0]));
      } else
      {
        this.SetAutoAssignNumericID(false);
      }
      // ENABLE ACCOUNT LOCKING
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_ENABLE_ACCOUNT_LOCKING);
      if (data != null)
      {
        this.SetEnableAccountLocking(XPConvert.ToBoolean(data[0]));
      } else
      {
        this.SetEnableAccountLocking(false);
      }
      //	MINUTES TO TRACK FAILED LOGINS
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_MINUTES_TO_TRACK_FAILED_LOGINS);
      if (data != null)
      {
        String sPostedVal = data[0];
        //MES- Try to convert it to a number- if the conversion
        //	fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          //MES- Do some simple validation
          if (0 <= iPostedVal)
          {
            this.SetMinutesToTrackFailedLogins(iPostedVal);
          } else
          {
            //MES- This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Minutes To Track Failed Logins- value \'{0}\' is not an allowed value.  Change not stored.",
             sPostedVal);
            nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            m_bMinutesToTrackFailedLoginsError = true;
            SetUIValidationError();
          }
        }
        catch (XPException xpe)
        {
          //MES- Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Minutes To Track Failed Logins- value \'{0}\' could not be converted to an integer.  Change not stored.",
           sPostedVal);
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
          m_bMinutesToTrackFailedLoginsError = true;
          SetUIValidationError();
        }
      }
      //	MAX FAILURES ALLOWED
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_NUMBER_FAILURES_ALLOWED);
      if (data != null)
      {
        String sPostedVal = data[0];
        //MES- Try to convert it to a number- if the conversion
        //	fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          //MES- Do some simple validation
          if (0 <= iPostedVal)
          {
            this.SetNumberOfFailedLoginsAllowed(iPostedVal);
          } else
          {
            //MES- This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Number Of Failed Logins Allowed- value \'{0}\' is not an allowed value.",
             sPostedVal);
            nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            m_bNumberOfFailedLoginsAllowedError = true;
            SetUIValidationError();
          }
        }
        catch (XPException xpe)
        {
          //MES- Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Number Of Failed Logins - value \'{0}\' could not be converted to a number.  Change not stored.",
           sPostedVal);
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
          m_bNumberOfFailedLoginsAllowedError = true;
          SetUIValidationError();
        }
      }
      //	MINUTES TO LOCK
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_MINUTES_TO_LOCK_ACCOUNTS);
      if (data != null)
      {
        String sPostedVal = data[0];
        //MES- Try to convert it to a number- if the conversion
        //	fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          //MES- Do some simple validation
          if (0 <= iPostedVal)
          {
            this.SetMinutesToLockAccounts(iPostedVal);
          } else
          {
            //MES- This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Minutes To Lock Accounts- value \'{0}\' is not an allowed value.",
             sPostedVal);
            nPageStatus = RepostControl.PAGE_STATUS_INVALID;
            m_bMinutesToLockAccountsError = true;
            SetUIValidationError();
          }
        }
        catch (XPException xpe)
        {
          //MES- Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Minutes To Lock Accounts - value \'{0}\' could not be converted to a number.  Change not stored.",
           sPostedVal);
          nPageStatus = RepostControl.PAGE_STATUS_INVALID;
          m_bMinutesToLockAccountsError = true;
          SetUIValidationError();
        }
      }
      //	DEFAULT LOCALE
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_DEFAULT_LOCALE);
      if (data != null)
      {
        this.SetDefaultLocale(data[0]);
      }
      //	DEFAULT TIME ZONE
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_DEFAULT_TIMEZONE);
      if (data != null)
      {
        this.SetDefaultTimeZone(data[0]);
      }
      //	INVITE CIPHER KEY
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_INVITE_CIPHER_KEY);
      if (data != null)
      {
        this.SetInviteCipherKey(data[0]);
      }
      // PASSWORD LENGTH
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_LENGTH);
      bool bValid = true;
      if (data != null)
      {
        String sPostedVal = data[0];
        // Try to convert it to a number- if the conversion
        // fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          // Do some simple validation - passwords can't be under 5 characters long
          // or over 20.
          if ((iPostedVal >= MIN_PASSWORD_LENGTH) && (iPostedVal <= MAX_PASSWORD_LENGTH))
          {
            this.SetPasswordLength(iPostedVal);
          } else
          {
            // This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Password Length- value \'{0}\' is not an allowed value. Must be between " + MIN_PASSWORD_LENGTH + " and " + MAX_PASSWORD_LENGTH + ".",
             sPostedVal);
            bValid = false;
          }
        }
        catch (XPException xpe)
        {
          // Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Password Length - value \'{0}\' could not be converted to a number.  Change not stored.",
           sPostedVal);
          bValid = false;
        }
      }
      if (!bValid)
      {
        nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        m_bPasswordLengthError = true;
        SetUIValidationError(XPResourceManager.FormatMessage(m_asOwner.GetString(3258,
         ResourceConstants.PORTALADMINMSGS), MIN_PASSWORD_LENGTH, MAX_PASSWORD_LENGTH));
        }
      // PASSWORD INCLUDE NUMBERS
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_NUMBERS);
      if (data != null)
      {
        this.SetPasswordIncludeNumbers(XPConvert.ToBoolean(data[0]));
      } else
      {
        this.SetPasswordIncludeNumbers(false);
      }
      // PASSWORD INCLUDE CASING
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_CASING);
      if (data != null)
      {
        this.SetPasswordIncludeCasing(XPConvert.ToBoolean(data[0]));
      } else
      {
        this.SetPasswordIncludeCasing(false);
      }
      // PASSWORD INCLUDE PUNCTUATION
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_PUNCTUATION);
      if (data != null)
      {
        this.SetPasswordIncludePunctuation(XPConvert.ToBoolean(data[0]));
        } else
      {
        this.SetPasswordIncludePunctuation(false);
      }
      // PASSWORD NO USER IDS
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_NO_USER_IDS);
      if (data != null)
      {
        this.SetPasswordNoUserIDs(XPConvert.ToBoolean(data[0]));
      } else
      {
        this.SetPasswordNoUserIDs(false);
      }
      // PASSWORD REUSE HISTORY
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_REUSE_HISTORY);
      bValid = true;
      if (data != null)
      {
        String sPostedVal = data[0];
        // Try to convert it to a number- if the conversion
        // fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          // Do some simple validation
          if ((iPostedVal >= 0) && (iPostedVal <= MAXIMUM_PASSWORD_HISTORY))
          {
            this.SetPasswordReuseHistory(iPostedVal);
          } else
          {
            // This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Password Reuse History - value \'{0}\' is not an allowed value. Must be between 0 and " + MAXIMUM_PASSWORD_HISTORY + ".",
             sPostedVal);
            bValid = false;
          }
        }
        catch (XPException xpe)
        {
          // Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Password Reuse History - value \'{0}\' could not be converted to a number.  Change not stored.",
           sPostedVal);
          bValid = false;
        }
      }
      if (!bValid)
      {
        nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        m_bPasswordReuseHistoryError = true;
        SetUIValidationError(XPResourceManager.FormatMessage(m_asOwner.GetString(3259,
         ResourceConstants.PORTALADMINMSGS), 0, MAXIMUM_PASSWORD_HISTORY));
        }
      // PASSWORD EXPIRATION
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION);
      bValid = true;
      if (data != null)
      {
        String sPostedVal = data[0];
        // Try to convert it to a number- if the conversion
        // fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          // Do some simple validation
          if (iPostedVal >= 0)
          {
            this.SetPasswordExpiration(iPostedVal);
          } else
          {
            // This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Password Expiration - value \'{0}\' is not an allowed value. Must be non-negative.",
             sPostedVal);
            bValid = false;
          }
        }
        catch (XPException xpe)
        {
          // Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Password Expiration - value \'{0}\' could not be converted to a number.  Change not stored.",
           sPostedVal);
          bValid = false;
        }
      }
      if (!bValid)
      {
        nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        m_bPasswordExpirationError = true;
        SetUIValidationError(XPResourceManager.FormatMessage(m_asOwner.GetString(3260,
         ResourceConstants.PORTALADMINMSGS), 0));
      }
      // PASSWORD EXPIRATION WARNING
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION_WARNING);
      bValid = true;
      if (data != null)
      {
        String sPostedVal = data[0];
        // Try to convert it to a number- if the conversion
        // fails, don't modify the setting!
        try
        {
          int iPostedVal = XPConvert.ToInteger(sPostedVal);
          // Do some simple validation.  The warning must be less than the expiration.
          if (iPostedVal < 0)
          {
            // This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Password Expiration Warning - value \'{0}\' is not an allowed value. Must be non-negative.",
             sPostedVal);
            bValid = false;
          } else
          if ((iPostedVal >= this.GetPasswordExpiration()) && (iPostedVal != 0))
          {
            // These values can only be equal when they are both 0.
            // This is a disallowed value, report
            log.Info("Validation Error in SetServerSettingsModel when attempting to store Password Expiration Warning - value \'{0}\' is not an allowed value. Must be less than the Password Expiration value of {1}.",
             sPostedVal, this.GetPasswordExpirationWarning());
            bValid = false;
          } else
          {
            this.SetPasswordExpirationWarning(iPostedVal);
          }
        }
        catch (XPException xpe)
        {
          // Log the error, but don't store any changes
          log.Warn(xpe, "Error in SetServerSettingsModel when attempting to store Password Expiration - value \'{0}\' could not be converted to a number.  Change not stored.",
           sPostedVal);
          bValid = false;
        }
      }
      if (!bValid)
      {
        nPageStatus = RepostControl.PAGE_STATUS_INVALID;
        m_bPasswordExpirationWarningError = true;
        SetUIValidationError(m_asOwner.GetString(3265, ResourceConstants.PORTALADMINMSGS));
        }
      return nPageStatus;
    }
    
    /// <summary>
    /// Saves the data on the General Settings page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    protected virtual int SaveGeneralPage(XPHashtable _htFormData)
    {
      String[] data;
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      log.Debug("SaveGeneralPage()");
      // ENABLE SUBPORTAL RULES DEBUGGING MODE
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_ENABLE_DEBUG_SUBPORTAL_RULES_MODE);
      if (data != null)
      {
        this.SetEnableDebugSubportalRulesMode(XPConvert.ToBoolean(data[0]));
        } else
      {
        this.SetEnableDebugSubportalRulesMode(false);
      }
      // ENABLE DEBUGGING MODE
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_ENABLE_DEBUG_PORTLET_ERRORS_MODE);
      if (data != null)
      {
        this.SetEnableDebugPortletErrorsMode(XPConvert.ToBoolean(data[0]));
        } else
      {
        this.SetEnableDebugPortletErrorsMode(false);
      }
      return nPageStatus;
    }
    
    /// <param name="_htFormData"></param>
    protected virtual int SavePortalUrlsPage(XPHashtable _htFormData)
    {
      log.Debug("SavePortalUrlsPage()");
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      String[] data;
      //	WEB SERVER URL
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_PRIMARY_WEB_SERVER_URL);
      if (data != null)
      {
        this.SetPrimaryWebServerURL(data[0]);
      }
      //	DISPLAY FILES URL
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_DISPLAY_FILES_URL);
      if (data != null)
      {
        this.SetDocumentDisplayURL(data[0]);
      }
      //	SOAP SERVER URL
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_SOAP_SERVER_URL);
      if (data != null)
      {
        this.SetSoapServerURL(data[0]);
      }
      //	SHARED FILES PATH
      data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_SHARED_FILES_PATH);
      if (data != null)
      {
        this.SetSharedFilesPath(data[0]);
      }
      //
      //		//	WEB INCOMING SEARCH URL
      //
      //		data = (String[]) _htFormData.GetElement(SetServerSettingsRepostControl.PARAM_INCOMING_SEARCH_URL);
      //
      //		if (data != null)
      //		{
      //			this.SetIncomingSearchURL(data[0]);
      //		}
      return nPageStatus;
    }
    protected virtual void SetUIValidationError()
    {
      SetUIValidationError(m_asOwner.GetString(3257, ResourceConstants.PORTALADMINMSGS));
      }
    protected virtual void SetUIValidationError(String _strError)
    {
      // raise error to display to user
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       _strError, null);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
    private void ClearCachedValues()
    {
      log.Debug("ClearCachedValues()");
      bAllowUserCreation = false;
      bAllowNumericAuthentication = false;
      bAutoAssignNumericID = false;
      bEnableAccountLocking = false;
      bAllowUserCreationSet = false;
      bAllowNumericAuthenticationSet = false;
      bAutoAssignNumericIDSet = false;
      bEnableAccountLockingSet = false;
      iMinutesToTrackFailedLogins = -1;
      iNumberOfFailedLoginsAllowed = -1;
      iMinutesToLockAccounts = -1;
      sDefaultLocale = null;
      sDefaultTimeZone = null;
      sPrimaryWebServerURL = null;
      sSoapServerURL = null;
      sSharedFilesPath = null;
      sDocumentDisplayURL = null;
      //		sIncomingSearchURL		 = null;
      sInviteCipherKey = null;
      // password management rules.
      m_nPasswordLength = -1;
      m_bPasswordNumbers = false;
      m_bPasswordCasing = false;
      m_bPasswordPunctuation = false;
      m_bPasswordNoUserIDs = false;
      m_nPasswordReuseHistory = -1;
      m_nPasswordExpiration = -1;
      m_nPasswordExpirationWarning = -1;
    }
    public virtual void UpdateLoginTokenKey()
    {
      //DCD TODO: Update Server Config here
      log.Debug("Called UpdateLoginTokenKey");
      IPTSession ptSession = (IPTSession) m_asasParent.GetUserSession();
      IPTServerConfigSettings SCS = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      XPSecureRandom rand = new XPSecureRandom();
      String sNewKey = XPConvert.ToString(rand.NextInt()) + XPConvert.ToString(rand.NextInt());
      SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_TOKEN_PASSWORD, sNewKey);
      }
    
    /// <summary>
    /// GetInviteCipherKey - the key used to encrypt the codes for CreateAccount invites
    /// </summary>
    /// <returns></returns>
    public virtual String GetInviteCipherKey()
    {
      return sInviteCipherKey;
    }
    
    /// <summary>
    /// SetInviteCipherKey - the key used to encrypt the codes for CreateAccount invites
    /// </summary>
    /// <param name="sKey"></param>
    public virtual void SetInviteCipherKey(String sKey)
    {
      sInviteCipherKey = sKey;
      bInviteCipherKeySet = true;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}