using System;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.admin.serversettings.general
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to the Server Settings Editor (other than
  /// "change page", "finish" and "cancel" actions).
  /// </summary>
  /// <author>Julie Fournier</author>
  public class SetServerSettingsRepostControl : EditorRepostControl
  {
    public const String STR_MVC_CLASS_NAME = "SetServerSettingsRepostControl";
    public const String PARAM_ALLOW_USER_CREATION = "in_cb_aucta";
    public const String PARAM_ALLOW_NUMERIC_LOGIN = "in_cb_anli";
    public const String PARAM_AUTO_ASSIGN_IDS = "in_cb_aaids";
    public const String PARAM_ENABLE_ACCOUNT_LOCKING = "in_cb_eal";
    public const String PARAM_MINUTES_TO_TRACK_FAILED_LOGINS = "in_tx_mttfl";
    public const String PARAM_NUMBER_FAILURES_ALLOWED = "in_tx_nfa";
    public const String PARAM_MINUTES_TO_LOCK_ACCOUNTS = "in_tx_mtla";
    public const String PARAM_DEFAULT_LOCALE = "in_se_dl";
    public const String PARAM_DEFAULT_TIMEZONE = "in_se_dtz";
    public const String PARAM_DEFAULT_CHARSET = "in_se_dcs";
    public const String PARAM_PRIMARY_WEB_SERVER_URL = "in_tx_pwsu";
    public const String PARAM_DISPLAY_FILES_URL = "in_tx_dfu";
    public const String PARAM_INCOMING_SEARCH_URL = "in_tx_isu";
    public const String PARAM_SOAP_SERVER_URL = "in_tx_ssu";
    public const String PARAM_SHARED_FILES_PATH = "in_tx_sfp";
    public const String PARAM_INVITE_CIPHER_KEY = "in_se_icky";
    public const String PARAM_ENABLE_DEBUG_SUBPORTAL_RULES_MODE = "in_cb_srdebugmode";
    public const String PARAM_ENABLE_DEBUG_PORTLET_ERRORS_MODE = "in_cb_pedebugmode";
    // These are the parameters for the password management section
    public const String PARAM_PASSWORD_LENGTH = "in_tx_pw_length";
    public const String PARAM_PASSWORD_INCLUDE_NUMBERS = "in_cb_pw_numbers";
    public const String PARAM_PASSWORD_INCLUDE_CASING = "in_cb_pw_casing";
    public const String PARAM_PASSWORD_INCLUDE_PUNCTUATION = "in_cb_pw_punctuation";
    public const String PARAM_PASSWORD_NO_USER_IDS = "in_cb_pw_no_ids";
    public const String PARAM_PASSWORD_REUSE_HISTORY = "in_tx_pw_reuse_history";
    public const String PARAM_PASSWORD_EXPIRATION = "in_tx_pw_expiration";
    public const String PARAM_PASSWORD_EXPIRATION_WARNING = "in_tx_pw_expiration_warning";
    public const int POSTTOSELF_ACTION_UPDATE_KEY = 47;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SetServerSettingsRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      switch (_nAction){
      case POSTTOSELF_ACTION_UPDATE_KEY:
      ((SetServerSettingsModel) m_model).UpdateLoginTokenKey();
      break;
      default:
      break;
      }
      base.PerformAction(_nAction);
    }
  }
}