using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.globalaclsyncmap
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Main Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>JohnH</author>
  public class GlobalACLSyncMapAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapAS");
    // All the AS in Plumtree need to have a unique name.
    public const String STR_MVC_CLASS_NAME = "GlobalACLSyncMap";
    public const String STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN = "GlobalACLSyncMapDomainList";
    public const String STR_MVC_STORAGE_NAME_GROUP_PLUG_IN = "GlobalACLSyncMapGroupList";
    private const String sClassName = "com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GlobalACLSyncMapAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(1473, "ptmsgs_portaladminmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (GlobalACLSyncMapRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession());
      if (!bInAdminGroup)
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = GlobalACLSyncMapModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(GlobalACLSyncMapModel.STR_MVC_CLASS_NAME);
      //Register the model, view and control for the domain map list
      RegisterModel(GlobalACLSyncMapListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myMultiColumnListModel = GetModel(STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN);
      RegisterView(GlobalACLSyncMapListView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN,
       myMultiColumnListModel);
      RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN,
       myMultiColumnListModel);
      //Register the model, view and control for the group map list
      RegisterModel(GlobalACLSyncMapListModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_GROUP_PLUG_IN);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myGroupListModel = GetModel(STR_MVC_STORAGE_NAME_GROUP_PLUG_IN);
      RegisterView(GlobalACLSyncMapListView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_GROUP_PLUG_IN,
       myGroupListModel);
      RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_GROUP_PLUG_IN,
       myGroupListModel);
      // Register DisplayPages
      RegisterPage(new MainDP());
      RegisterPage(new GroupMapDP());
      // Register Views
      // Register Controls
      RegisterControl(GlobalACLSyncMapRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register Migration History Plugin
      RegisterModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME);
      RegisterView(MigrationHistoryView.STR_MVC_CLASS_NAME, GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME));
      RegisterPage(new MigrationHistoryPluginDP());
      // Set default page
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);
      // Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1474, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupMapDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 84;
          int iTipId = 85;
          int iSecondaryTipId = 86;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (MainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_GlobalACLSyncMap_PrefixDomainMap");
      } else
      if (GroupMapDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_GlobalACLSyncMap_PortalExternalGroupMap");
      } else
      if (MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_MigrationHistoryandStatus");
      }
    }
  }
}