using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.ptmulticolumnlist;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.admin.serversettings.globalaclsyncmap
{
  /// <author>
  /// jennifersu
  /// Custom MultiColumnListModel for the Global ACL Sync Map.
  /// Has a Select PT Object Tree but displays certain properties about
  /// the selected objects rather than the name itself. (Domain mapping displays
  /// auth source prefix; Group mapping displays mappingauthname).  Also,
  /// can edit both columns of the list.
  /// </author>
  public class GlobalACLSyncMapListModel : PTMultiColumnListModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapListModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GlobalACLSyncMapListModel";
    
    /// <summary>
    /// List displays domain mappings.
    /// </summary>
    public const int ACL_MAP_TYPE_DOMAIN = 0;
    
    /// <summary>
    /// List displays group mappings.
    /// </summary>
    public const int ACL_MAP_TYPE_GROUP = 1;
    
    /// <summary>
    /// The type of mapping that the current list displays.
    /// </summary>
    private int m_nACLMapType;
    
    /// <summary>
    /// The column index that is currently being edited.
    /// Need this since both columns of a given row is editable.
    /// </summary>
    private int m_intEditColumn;
    public GlobalACLSyncMapListModel() : base()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GlobalACLSyncMapListModel();
    }
    
    /// <summary>
    /// Set the type of mapping that this list contains.
    /// Use constants.
    /// </summary>
    /// <param name="_nMapType"></param>
    public virtual void SetMapType(int _nMapType)
    {
      m_nACLMapType = _nMapType;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Overrides PTMultiColumnListModel since
    /// we don't want the tree to pre-select anything.
    /// This is the format used by the tree.
    /// </summary>
    /// <returns>String</returns>
    public override String GetSelectedItems()
    {
      String sSelectedItems = "";
      return sSelectedItems;
    }
    
    /// <summary>
    /// Initializes the expandable list.  Overrides PTMultiColumnListModel
    /// since we want both columns to be editable.
    /// </summary>
    /// <param name="_sSectionTitle">- Main title of the view.</param>
    /// <param name="_sFirstColSubTitle">
    /// - The subtitle for the selected Plumtree
    /// Object, if appropriate.  If _bIncludePTSelect is FALSE, this shoudl be
    /// set to null.
    /// </param>
    /// <param name="_sSectionSubTitle">
    /// - An array of subtitles for non-plumtree object
    /// columns
    /// </param>
    /// <param name="_imgAddIcon">- Icon for the add action.</param>
    /// <param name="_sAddLabel">- Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">
    /// - The Class ID of the objects displayed on the
    /// list.  This should be null if _bIncludePTSelect is FALSE.
    /// </param>
    /// <param name="_nListKey">
    /// - In case you have multiple Expandable Lists on the same
    /// DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public override void InitializePTMultiColumnList(String _sSectionTitle,
     String _sFirstColSubTitle, String[] _sSectionSubTitle, PTImageType _imgAddIcon,
     String _sAddLabel, int[] _arrObjectClassIDs, int _nListKey)
    {
      int intNumColumns;
      if (m_bIncludePTSelect)
      {
        intNumColumns = m_intNumColumns + 1;
      } else
      {
        intNumColumns = m_intNumColumns;
      }
      //Set the width based on the number of columns
      int intColWidth = 100 / (intNumColumns);
      XPStringBuilder sb = new XPStringBuilder(5);
      sb.Append(intColWidth).Append("%");
      Object[][] arrExpListColInfo = new Object[intNumColumns][];
      for (int j2c_index = 0;j2c_index < intNumColumns;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      if (m_bIncludePTSelect)
      {
        //First initialize the name column
        arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING + m_intPTObjectPosition;
        arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_TITLE] = _sFirstColSubTitle;
        arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_WIDTH] = sb.ToString();
        arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_COLSPAN] = "2";
        arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_ENABLESORT] = true;
        }
      //now initialize the subsequent columns
      int intColumnID;
      int intColIndex;
      for (int i = 0;i < m_intNumColumns;i++)
      {
        if (i < m_intPTObjectPosition)
        {
          intColIndex = i;
          intColumnID = i + 1;
        } else
        {
          intColIndex = i + 1;
          intColumnID = i + 4;
        }
        arrExpListColInfo[intColIndex][EXPLIST_COLUMN_ID] = intColumnID;
        arrExpListColInfo[intColIndex][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle[i];
        arrExpListColInfo[intColIndex][EXPLIST_COLUMN_WIDTH] = sb.ToString();
        arrExpListColInfo[intColIndex][EXPLIST_COLUMN_COLSPAN] = "2";
        arrExpListColInfo[intColIndex][EXPLIST_COLUMN_ENABLESORT] = false;
        }
      m_arrObjectClassIDs = _arrObjectClassIDs;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Calls the appropriate AddRowOnRepost helper method,
    /// depending on what type of list this is.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      if (m_nACLMapType == ACL_MAP_TYPE_DOMAIN)
      {
        AddDomainRowsOnRepost(_htFormData);
      } else
      if (m_nACLMapType == ACL_MAP_TYPE_GROUP)
      {
        AddGroupRowsOnRepost(_htFormData);
      }
    }
    
    /// <summary>
    /// For domain mappings, look up the selected auth source's prefix.
    /// The row that gets added displays the prefix string, NOT the auth
    /// source name.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    private void AddDomainRowsOnRepost(XPHashtable _htFormData)
    {
      if (m_bIncludePTSelect)
      {
        //Validate that the proposed position of the selected Plumtree
        //object is not greater than the number of other columns
        if (m_intPTObjectPosition > m_intNumColumns)
        {
          m_intPTObjectPosition = 0;
        }
        TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_KEY_SELECTTREE));
        if (null != asTree)
        {
          ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList mySelected = myTree.GetSelectedItems();
          Object[] oNewRow;
          int nClassID;
          //First, save the data so we can re-populate the non-tree items
          XPHashtable[] arrHashtables = new XPHashtable[m_intNumColumns + 3];
          for (int i = 0;i < (m_intNumColumns + 3);i++)
          {
            arrHashtables[i] = new XPHashtable();
          }
          for (int i = 0;i < m_saData.GetCount();i++)
          {
            //skip the index column
            for (int j = 1;j < (m_intNumColumns + 4);j++)
            {
              arrHashtables[j - 1].PutElement(m_saData.GetItem(i, EXPLIST_COL_STRING + m_intPTObjectPosition),
               m_saData.GetItem(i, j));
            }
          }
          // Look up prefix strings for the selected auth sources.
          IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
          IPTObjectManager authManager = ptSession.GetAuthSources();
          PTObjectManagerQueryWrapper authQW = new PTObjectManagerQueryWrapper(authManager);
          Object[][] objQueryFilter;
          String strAuthName = "";
          String strPrefix = "";
          for (int i = 0;i < mySelected.GetSize();i++)
          {
            oNewRow = new Object[m_intNumColumns + 4];
            oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
            m_nNextIndex++;
            nClassID = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
            oNewRow[EXPLIST_COL_CLASSID + m_intPTObjectPosition] = nClassID;
            //bogus object id since we're not really storing objects here
            oNewRow[EXPLIST_COL_OBJECTID + m_intPTObjectPosition] = -12345;
            // get prefix
            strAuthName = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
            objQueryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_NAME,
             PT_FILTEROPS.PT_FILTEROP_EQ, strAuthName);
            authQW.Query(-1, -1, null, objQueryFilter);
            if (authQW.GetCount() > 0)
            {
              strPrefix = XPConvert.ToString(authQW.GetFields(0, PT_PROPIDS.PT_PROPID_AUTHSOURCE_PREFIXSTRING));
              if (null == strPrefix)
              {
                int nAuthID = XPConvert.ToInteger(authQW.GetFields(0, PT_PROPIDS.PT_PROPID_OBJECTID));
                if (1 == nAuthID)
                {
                  strPrefix = "Plumtree";
                }
              }
            } else
            {
              log.Error("GlobalACLSyncMapListModel::AddDomainRowOnRepost\tAn error occurred when trying to add a row to the domain map list.");
              }
            oNewRow[EXPLIST_COL_STRING + m_intPTObjectPosition] = strPrefix;
            //Add the other empty columns
            // TODO CR not used, commenting out.
            //String strValue;
            int intColIndex;
            for (int j = 0;j < m_intNumColumns;j++)
            {
              if (j < m_intPTObjectPosition)
              {
                intColIndex = j + 1;
              } else
              {
                intColIndex = j + 4;
              }
              oNewRow[intColIndex] = "";
            }
            base.GetItems().AddRow(oNewRow);
          }
        }
      } else
      {
        String[][] arrDefault = new String[m_intNumColumns][];
        for (int j2c_index = 0;j2c_index < m_intNumColumns;j2c_index++)
        {
          arrDefault[j2c_index] = new String[1];
        }
        for (int i = 0;i < m_intNumColumns;i++)
        {
          arrDefault[i][0] = m_arrDefaultValue[i];
        }
        AddRowsToList(arrDefault);
      }
    }
    
    /// <summary>
    /// For group mappings, look up the group's mappingauthname instead
    /// of the group object name, since we don't want to display any prefixes
    /// in the UI.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    private void AddGroupRowsOnRepost(XPHashtable _htFormData)
    {
      if (m_bIncludePTSelect)
      {
        //Validate that the proposed position of the selected Plumtree
        //object is not greater than the number of other columns
        if (m_intPTObjectPosition > m_intNumColumns)
        {
          m_intPTObjectPosition = 0;
        }
        TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_KEY_SELECTTREE));
        if (null != asTree)
        {
          ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList mySelected = myTree.GetSelectedItems();
          Object[] oNewRow;
          int nClassID;
          //First, save the data so we can re-populate the non-tree items
          XPHashtable[] arrHashtables = new XPHashtable[m_intNumColumns + 3];
          for (int i = 0;i < (m_intNumColumns + 3);i++)
          {
            arrHashtables[i] = new XPHashtable();
          }
          for (int i = 0;i < m_saData.GetCount();i++)
          {
            //skip the index column
            for (int j = 1;j < (m_intNumColumns + 4);j++)
            {
              arrHashtables[j - 1].PutElement(m_saData.GetItem(i, EXPLIST_COL_STRING + m_intPTObjectPosition),
               m_saData.GetItem(i, j));
            }
          }
          // Look up the selected groups' mappingauthnames
          IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
          IPTObjectManager groupManager = ptSession.GetUserGroups();
          PTObjectManagerQueryWrapper groupQW = new PTObjectManagerQueryWrapper(groupManager);
          Object[][] objQueryFilter;
          String strGroupName = "";
          String strMappingAuthName = "";
          for (int i = 0;i < mySelected.GetSize();i++)
          {
            oNewRow = new Object[m_intNumColumns + 4];
            oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
            m_nNextIndex++;
            nClassID = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
            oNewRow[EXPLIST_COL_CLASSID + m_intPTObjectPosition] = nClassID;
            // bogus objectid since we're not really storing objects
            oNewRow[EXPLIST_COL_OBJECTID + m_intPTObjectPosition] = -12345;
            // get mappingauthname
            strGroupName = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
            objQueryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_NAME,
             PT_FILTEROPS.PT_FILTEROP_EQ, strGroupName);
            groupQW.Query(-1, -1, null, objQueryFilter);
            if (groupQW.GetCount() > 0)
            {
              strMappingAuthName = XPConvert.ToString(groupQW.GetFields(0,
               PT_PROPIDS.PT_PROPID_USERGROUP_SIMPLENAME));
            } else
            {
              log.Error("GlobalACLSyncMapListModel::AddGroupRowOnRepost\tAn error occurred when trying to add a row to the group map list.");
              }
            oNewRow[EXPLIST_COL_STRING + m_intPTObjectPosition] = strMappingAuthName;
            //Add the other empty columns
            // TODO CR not used, commenting out.
            //String strValue;
            int intColIndex;
            for (int j = 0;j < m_intNumColumns;j++)
            {
              if (j < m_intPTObjectPosition)
              {
                intColIndex = j + 1;
              } else
              {
                intColIndex = j + 4;
              }
              oNewRow[intColIndex] = "";
            }
            base.GetItems().AddRow(oNewRow);
          }
        }
      } else
      {
        String[][] arrDefault = new String[m_intNumColumns][];
        for (int j2c_index = 0;j2c_index < m_intNumColumns;j2c_index++)
        {
          arrDefault[j2c_index] = new String[1];
        }
        for (int i = 0;i < m_intNumColumns;i++)
        {
          arrDefault[i][0] = m_arrDefaultValue[i];
        }
        AddRowsToList(arrDefault);
      }
    }
    
    /// <summary>
    /// Saves the data for columns other than the plumtree object select column
    /// on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append(PTMultiColumnListView.HTMLINPUT_ITEM);
      int intIndex;
      for (int i = 0;i <= m_intNumColumns;i++)
      {
        if (i < m_intPTObjectPosition)
        {
          intIndex = i + 1;
        } else
        {
          intIndex = i + 3;
        }
        String sDataKey = GetUniqueString(sb.Append(intIndex).ToString()) + _nRowIndex;
        String[] aDataValue;
        // JF- For each input text posted by the form, we get the value back
        // and set the new value in the array.
        if (_htFormData.ContainsKey(sDataKey))
        {
          aDataValue = (String[]) _htFormData.GetElement(sDataKey);
          if ((null != aDataValue) && !(0 == aDataValue.Length))
          {
            _saData.SetItem(_nRowIndex, intIndex, aDataValue[0]);
          }
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Returns the column currently being edited.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetEditColumn()
    {
      return m_intEditColumn;
    }
    
    /// <summary>
    /// Sets the column currently being edited.
    /// </summary>
    /// <param name="editColumn">The column to set</param>
    public virtual void SetEditColumn(int editColumn)
    {
      m_intEditColumn = editColumn;
    }
    
    /// <summary>
    /// Action for modifying a row
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void ModifyRow(XPHashtable _htFormData)
    {
      String[] data = (String[]) _htFormData.GetElement(PTMultiColumnListView.HTMLHIDDEN_EDITROW);
      if (null != data)
      {
        this.SetEditRow(XPConvert.ToInteger(data[0]));
      }
      data = (String[]) _htFormData.GetElement(GlobalACLSyncMapListView.HTMLHIDDEN_EDITCOL);
      if (null != data)
      {
        this.SetEditColumn(XPConvert.ToInteger(data[0]));
      }
    }
  }
}