using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.objectpropertymap
{
  /// <summary>
  /// Activity space for object properties map
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropMapEditorAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.objectpropertymap.ObjPropMapEditorAS");
    
    /// <summary>
    /// Class name for ObjPropMapEditorAS 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropMapEditor";
    
    /// <summary>
    /// Plugin for object properties map  
    /// </summary>
    public const String strStorageObjPropMapPlugin = "StorageObjPropMapPlugin";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjPropMapEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return GetString(542, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Document Type Map Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (ObjPropMapRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession());
      if (!bInAdminGroup)
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = ObjPropMapModel.STR_MVC_CLASS_NAME;
      // Warning: m_myModel must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(ObjPropMapModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new ObjPropMapDP());
      // Register Controls
      RegisterControl(ObjPropMapRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register Plugin
      RegisterModel(ObjPropMapPluginModel.STR_MVC_CLASS_NAME, strStorageObjPropMapPlugin);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myObjPropPluginModel = GetModel(strStorageObjPropMapPlugin);
      RegisterView(ObjPropMapPluginView.STR_MVC_CLASS_NAME, strStorageObjPropMapPlugin,
       myObjPropPluginModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageObjPropMapPlugin,
       myObjPropPluginModel);
      // Set default page
      SetCurrentPage(ObjPropMapDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(321, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, ObjPropMapDP.STR_MVC_CLASS_NAME);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          int iTitleId = 87;
          int iTipId = 88;
          int iSecondaryTipId = 89;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <summary>
    /// Set the help page for this editor. 
    /// </summary>
    /// <param name="page"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)"></seealso>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (ObjPropMapDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_GlobalObjectPropertyMap_ObjectPropertyMap");
        }
    }
  }
}