using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.serversettings.objectpropertymap
{
  /// <summary>
  /// Model for object properties map
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropMapModel : EditorModel,IObjPropMapModelRO
  {
    
    /// <summary>
    /// Class name for ObjPropMapModel 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropMap";
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    protected IPTSession m_ptSession;
    
    /// <summary>
    /// Modifies the object name on repost.
    /// </summary>
    public virtual void ActionOnRepost()
    {
    }
    // Code to perform on repost.
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#CheckEditorAccessAndStart(XPHashtable)"></seealso>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      if (!m_ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(429, "ptmsgs_portalinfrastructure"), null);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return false;
      }
      if (!m_ptSession.GetSessionInfo().CheckCurrentUserIsAdmin())
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(431, "ptmsgs_portalinfrastructure"), null);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return false;
      }
      // Init common pages
      StartObjPropMap();
      // Perform Editor specific tasks
      DoTaskOnStartEditor(_htFormData);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjPropMapModel();
    }
    
    /// <summary>
    /// This method contains the code to store the object property mappings.
    /// </summary>
    public override void Finish()
    {
      ObjPropMapPluginModel opModel = (ObjPropMapPluginModel) m_asOwner.GetModel(ObjPropMapEditorAS.strStorageObjPropMapPlugin);
      opModel.StorePropertyMappings();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Model with the Activity Space.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      // JF- Get the Session object from the associated AS.
      m_ptSession = (IPTSession) parent.GetUserSession();
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      if (_sPageName.Equals(ObjPropMapDP.STR_MVC_CLASS_NAME))
      {
        SaveMainPage(_htFormData);
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
    }
    // Code to save the page.
    
    /// <summary>
    /// Initialize object properties map
    /// </summary>
    protected virtual void StartObjPropMap()
    {
      ObjPropMapPluginModel opModel = (ObjPropMapPluginModel) m_asOwner.GetModel(ObjPropMapEditorAS.strStorageObjPropMapPlugin);
      opModel.InitializeObjectPropertiesMap(m_ptSession, m_asOwner.GetString(548,
       "ptmsgs_portaladminmsgs"), 1);
    }
  }
}