using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin
{
  /// <summary>
  /// This is the implementation of the Expandable List for object properties map.
  /// </summary>
  /// <author>josephc</author>
  public class ObjPropMapPluginModel : ExpListModel,IObjPropMapPluginModelRO
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjPropMapPlugin";
    
    /// <summary>
    /// Number total of columns 
    /// </summary>
    public const int EXPLIST_COL_MAX = 3;
    
    /// <summary>
    /// Column for class ID 
    /// </summary>
    public const int EXPLIST_COL_CLASSID = 0;
    
    /// <summary>
    /// Column for class name 
    /// </summary>
    public const int EXPLIST_COL_CLASS_NAME = 1;
    
    /// <summary>
    /// Column for mapped properties 
    /// </summary>
    public const int EXPLIST_COL_MAPPED_PROPERTIES = 2;
    
    /// <summary>
    /// Subspace key for property tree 
    /// </summary>
    public const String SUBSPACE_KEY_PROPERTYTREE = "ObjPropMapSelectPropertySubSpace";
    
    /// <summary>
    /// Property info column for name 
    /// </summary>
    public const int PROPERTY_INFO_NAME = 0;
    
    /// <summary>
    /// Property info column for description 
    /// </summary>
    public const int PROPERTY_INFO_DESC = 1;
    
    /// <summary>
    /// Class info column for class ID 
    /// </summary>
    private const int CLASS_INFO_COLUMN_CLASSID = 0;
    
    /// <summary>
    /// Class info column for class name 
    /// </summary>
    private const int CLASS_INFO_COLUMN_NAME = 1;
    
    /// <summary>
    /// Property object manager 
    /// </summary>
    protected IPTObjectManager m_ptPropertyManager;
    
    /// <summary>
    /// Object property map 
    /// </summary>
    protected IPTObjectPropertyMap m_ptOPM;
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    protected IPTSession m_ptSession;
    
    /// <summary>
    /// This is used on add to populate the input text of the newly added row. 
    /// </summary>
    protected Object m_oDefaultValue;
    
    /// <summary>
    /// Table of class mappings 
    /// </summary>
    protected XPHashtable m_htClassMappings;
    
    /// <summary>
    /// Table of property names and descrptions 
    /// </summary>
    protected XPHashtable m_htPropertyInfo;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(XPHashtable)"></seealso>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_KEY_PROPERTYTREE));
      if (null != asTree)
      {
        ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList mySelected = myTree.GetSelectedItems();
        String sRowKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);
        int nRowIndex = -1;
        if (_htFormData.ContainsKey(sRowKey))
        {
          String[] aRowValue = (String[]) _htFormData.GetElement(sRowKey);
          if ((null != aRowValue) && (aRowValue.Length > 0))
          {
            nRowIndex = XPConvert.ToInteger(aRowValue[0]);
          }
        }
        if (-1 != nRowIndex)
        {
          AddPropertiesToRow(nRowIndex, mySelected);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjPropMapPluginModel();
    }
    
    /// <summary>
    /// Returns the class icon
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Icon for class</returns>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.objectpropertymap.plugin.IObjPropMapPluginModelRO#GetClassIcon(int)"></seealso>
    public virtual HTMLImg GetClassIcon(int _nRowIndex)
    {
      // Get the list of all the classes in the system
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      int nClassID = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, ObjPropMapPluginModel.EXPLIST_COL_CLASSID));
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       m_asOwner);
      return ptClassTypeDescManager.GetDefaultIconForClassType(nClassID, strLangID);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns array of property names and descriptions.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Array of property names and descriptions</returns>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.objectpropertymap.plugin.IObjPropMapPluginModelRO#GetPropertyNames(int)"></seealso>
    public virtual String[][] GetPropertyInfo(int _nRowIndex)
    {
      Object nClassID = m_saData.GetItem(_nRowIndex, ObjPropMapPluginModel.EXPLIST_COL_CLASSID);
      XPArrayList alistProperties = (XPArrayList) m_htClassMappings.GetElement(nClassID);
      String[][] arPropertyInfo = new String[alistProperties.GetSize()][];
      for (int j2c_index = 0;j2c_index < alistProperties.GetSize();j2c_index++)
      {
        arPropertyInfo[j2c_index] = new String[2];
      }
      for (int i = 0;i < alistProperties.GetSize();i++)
      {
        Object nPropertyID = alistProperties.GetElement(i);
        // Try to get cached name of property.  If not found, then open property and cache it.
        if (!m_htPropertyInfo.ContainsKey(nPropertyID))
        {
          IPTProperty ptProperty = (IPTProperty) m_ptPropertyManager.Open(XPConvert.ToInteger(nPropertyID),
           false);
          arPropertyInfo[i][PROPERTY_INFO_NAME] = ptProperty.GetLocalizedName();
          arPropertyInfo[i][PROPERTY_INFO_DESC] = ptProperty.GetDescription();
          // Cache the row
          m_htPropertyInfo.PutElement(nPropertyID, arPropertyInfo[i]);
        } else
        {
          arPropertyInfo[i] = (String[]) m_htPropertyInfo.GetElement(nPropertyID);
          }
      }
      return arPropertyInfo;
    }
    
    /// <summary>
    /// Returns a String of Class IDs and Object IDs of the Objects  to select
    /// in the tree. E.g.: "propertyClassID,ObjID1,propertyClassID,objID2".  In
    /// our case, propertyClassID is the classID for properties.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>String</returns>
    /// <seealso cref="com.plumtree.portalpages.admin.editors.objectpropertymap.plugin.IObjPropMapPluginModelRO#GetSelectedItems(int)"></seealso>
    public virtual String GetSelectedItems(int _nRowIndex)
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      Object nClassID = m_saData.GetItem(_nRowIndex, ObjPropMapPluginModel.EXPLIST_COL_CLASSID);
      XPArrayList alistProperties = (XPArrayList) m_htClassMappings.GetElement(nClassID);
      // RW - loop through array and add object id to string
      for (int i = 0;i < alistProperties.GetSize();i++)
      {
        int nPropertyID = XPConvert.ToInteger(alistProperties.GetElement(i));
        // JS- Add the separator
        if (0 != i)
        {
          sb.Append(",");
        }
        sb.Append(PT_CLASSIDS.PT_PROPERTY_ID).Append(",").Append(nPropertyID);
        }
      return sb.ToString();
    }
    
    /// <summary>
    /// Initialize object properties map. Initialize expandable list and set the
    /// row icon.
    /// </summary>
    /// <param name="_ptSession">IPTSession</param>
    /// <param name="_sSectionTitle">Category title</param>
    /// <param name="_nListKey">List key</param>
    /// <returns>True if initialized successfully. False otherwise.</returns>
    public virtual bool InitializeObjectPropertiesMap(IPTSession _ptSession,
     String _sSectionTitle, int _nListKey)
    {
      m_ptSession = _ptSession;
      m_ptOPM = (IPTObjectPropertyMap) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP,
       false);
      m_ptPropertyManager = m_ptSession.GetProperties();
      // Initialize expandable list
      InitExpandableList(_sSectionTitle, _nListKey);
      return true;
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
    /// mapping and an array of sort. The growable array will be sorted by the
    /// 2 columns, first the name and second classID, ascending
    /// </summary>
    /// <param name="_saData"></param>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(PTGrowableSortedArrayWrapper)"></seealso>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      int[] arrColumns = new int[]{EXPLIST_COL_CLASSID, EXPLIST_COL_CLASS_NAME};
      // The growable array will be sorted by 2 columns, first the class name and classID
      int[][] arrSort = new int[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_CLASS_NAME;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_CLASSID;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      Object[][] arClassInfo = null;
      // Get the list of all the classes in the system
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       m_asOwner);
      int[] arAllClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs(PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage());
      XPArrayList alistClassIDs = new XPArrayList();
      // Filter out all of the classes that cannot be used for extended object data.
      if (null != arAllClassIDs)
      {
        for (int i = 0;i < arAllClassIDs.Length;i++)
        {
          int nClassID = arAllClassIDs[i];
          if (ptClassTypeDescManager.AppearsInGlobalObjPropMap(nClassID))
          {
            alistClassIDs.Add(nClassID);
          }
        }
      }
      // Construct class info array in order to initialize the sorted array
      if (!alistClassIDs.IsEmpty())
      {
        arClassInfo = new Object[2][];
        for (int j2c_index = 0;j2c_index < 2;j2c_index++)
        {
          arClassInfo[j2c_index] = new Object[alistClassIDs.GetSize()];
        }
        for (int i = 0;i < alistClassIDs.GetSize();i++)
        {
          arClassInfo[CLASS_INFO_COLUMN_CLASSID][i] = alistClassIDs.GetElement(i);
          int nClassID = XPConvert.ToInteger(alistClassIDs.GetElement(i));
          arClassInfo[CLASS_INFO_COLUMN_NAME][i] = ptClassTypeDescManager.GetClassTypeLocalizedName(nClassID,
           strLangID);
        }
        // Load mappings into hashtable
        LoadClassMappings(alistClassIDs);
      }
      // Initialize the sorted array
      _saData.Initialize(arrColumns, arClassInfo, arrSort, true);
    }
    
    /// <summary>
    /// Sets a new default value.
    /// </summary>
    /// <param name="_oDefaultValue">New value</param>
    public virtual void SetDefaultValue(Object _oDefaultValue)
    {
      m_oDefaultValue = _oDefaultValue;
    }
    
    /// <summary>
    /// Stores the property mapping changes to the property object.
    /// </summary>
    public virtual void StorePropertyMappings()
    {
      // Iterate through the different classes
      for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
      {
        Object nClassID = m_saData.GetItem(nRowIndex, EXPLIST_COL_CLASSID);
        // For each class get the list of properties
        XPArrayList alistProperties = (XPArrayList) m_htClassMappings.GetElement(nClassID);
        int[] arPropertyIDs = new int[alistProperties.GetSize()];
        for (int i = 0;i < arPropertyIDs.Length;i++)
        {
          int nPropertyID = XPConvert.ToInteger(alistProperties.GetElement(i));
          arPropertyIDs[i] = nPropertyID;
        }
        m_ptOPM.SetClassPropertyMappings(XPConvert.ToInteger(nClassID), arPropertyIDs);
        }
    }
    
    /// <summary>
    /// Adds new properties to the row.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_alistSelectedProperties">List of selected properties</param>
    protected virtual void AddPropertiesToRow(int _nRowIndex, XPArrayList _alistSelectedProperties)
    {
      // Get classID
      Object nClassID = m_saData.GetItem(_nRowIndex, EXPLIST_COL_CLASSID);
      XPArrayList alistProperties = (XPArrayList) m_htClassMappings.GetElement(nClassID);
      alistProperties.Clear();
      for (int i = 0;i < _alistSelectedProperties.GetSize();i++)
      {
        int nPropertyID = ((TreeLeafNode) _alistSelectedProperties.GetElement(i)).m_nObjectID;
        alistProperties.Add(nPropertyID);
      }
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Initializes expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Category title</param>
    /// <param name="_nListKey">List key</param>
    private void InitExpandableList(String _sSectionTitle, int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      // The first column will be the class name and will be sortable
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_CLASS_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(535,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "20%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      // The second column will be the properties mapped to the class and will not be sortable
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_MAPPED_PROPERTIES;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(536,
       "ptmsgs_portaladminmsgs");
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "80%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "2";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeReadOnlyExpandableList(_sSectionTitle, arrExpListColInfo,
       _nListKey);
    }
    
    /// <summary>
    /// Load class mappings into table.
    /// </summary>
    /// <param name="alistClassIDs">List of class ID's</param>
    private void LoadClassMappings(XPArrayList alistClassIDs)
    {
      // Create hash table of class ID's and properties
      m_htClassMappings = new XPHashtable();
      // Create hash table of property names
      m_htPropertyInfo = new XPHashtable();
      IXPEnumerator enumClasses = alistClassIDs.GetEnumerator();
      while (enumClasses.MoveNext())
      {
        Object nClassID = enumClasses.GetCurrent();
        // Add array list to hash table
        m_htClassMappings.PutElement(nClassID, new XPArrayList());
      }
      // TODOCR JIC - Are we supposed to use a wrapper class isntead of IPTQueryResult?
      IPTQueryResult ptQR = m_ptOPM.QueryAllClassPropertyMappings(PT_PROPIDS.PT_PROPID_ALL);
      for (int nRow = 0;nRow < ptQR.RowCount();nRow++)
      {
        Object nClassID = ptQR.ItemAsInt(nRow, PT_PROPIDS.PT_PROPID_CLASSID);
        Object nPropertyID = ptQR.ItemAsInt(nRow, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (m_htClassMappings.ContainsKey(nClassID))
        {
          XPArrayList alistProperties = (XPArrayList) m_htClassMappings.GetElement(nClassID);
          alistProperties.Add(nPropertyID);
          if (!m_htPropertyInfo.ContainsKey(nPropertyID))
          {
            String strPropertyName = ptQR.ItemAsString(nRow, PT_PROPIDS.PT_PROPID_NAME);
            String strPropertyDesc = ptQR.ItemAsString(nRow, PT_PROPIDS.PT_PROPID_DESCRIPTION);
            String[] propertyInfoRow = new String[2];
            propertyInfoRow[PROPERTY_INFO_NAME] = strPropertyName;
            propertyInfoRow[PROPERTY_INFO_DESC] = strPropertyDesc;
            m_htPropertyInfo.PutElement(nPropertyID, propertyInfoRow);
          }
        }
      }
    }
  }
}