using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.search
{
  /// <author>MatthewF</author>
  public class IndexingStatusView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.search.IndexingStatusView");
    public const String STR_MVC_CLASS_NAME = "IndexingStatusView";
    public const String CB_CHECK_ONE = "in_cb_checkone";
    public const String CB_CHECK_ALL = "in_cb_checkall";
    private static readonly String PORTAL_ADMIN_MSGS = ResourceConstants.PORTALADMINMSGS;
    private SearchServerSettingsEditorModel _model;
    
    /// <returns></returns>
    public override Object Create()
    {
      return new IndexingStatusView();
    }
    
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      // The URL to open the pop-up
      ASURL myPopUp = new ASURL(m_asOwner);
      myPopUp.SetLinkGetCachedSpace(m_asOwner);
      myPopUp.SetDisplayPage(IndexingStatusPopUpDP.STR_MVC_CLASS_NAME);
      // Add the following 2 lines only if you need to have an "on open pop-up" action
      // The code to execute when the pop-up gets opened should go in Misc2RepostControl under "case POSTTOSELF_ACTION_OPEN_IS_POPUP"
      //	myPopUp.SetControl(SearchServerSettingsEditorRepostControl.STR_MVC_CLASS_NAME);
      //myPopUp.AddControlArgument(EditorRepostControl.HTMLINPUT_POSTTOSELF, XPConvert.ToString(SearchServerSettingsEditorRepostControl.POSTTOSELF_ACTION_OPEN_IS_POPUP));
      XPStringBuilder sb;
      try
      {
        // Open Pop Up function
        sb = new XPStringBuilder(200);
        sb.Append("function AlertNoAdd()\n");
        sb.Append("{\n");
        sb.Append("    alert(\'" + m_asOwner.GetString(2527, PORTAL_ADMIN_MSGS) + "\');\n");
        sb.Append("}\n");
        sb.Append("function OpenPopUp()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(myPopUp.GetURLAsString()).Append("\', \'_blank3\', \'location=no,menubar=no,scrollbars=yes,height=200,width=350\');\n");
        sb.Append("}\n");
        sb.Append("\n\nfunction DoToggleAllCBs() {\n");
        sb.Append("    var fElem = document.mainform;\n");
        sb.Append("    var feLen = fElem.elements.length;\n");
        sb.Append("    var checkVal = false;\n");
        sb.Append("    for (var i = 0; i < feLen; i++) {\n");
        sb.Append("        if (fElem.elements[i].name == \'" + CB_CHECK_ALL + "\') {\n");
        sb.Append("            checkVal = fElem.elements[i].checked;\n");
        sb.Append("        }\n");
        sb.Append("    }\n");
        sb.Append("    for (var i = 0; i < feLen; i++) {\n");
        sb.Append("        if (fElem.elements[i].name.indexOf(\'" + CB_CHECK_ONE + "\') != -1) {\n");
        sb.Append("             fElem.elements[i].checked = checkVal;\n");
        sb.Append("        }\n");
        sb.Append("    }\n");
        sb.Append("    return true;\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "SearchServerSettingsEditorMainView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      _model = (SearchServerSettingsEditorModel) m_model;
      XPArrayList counts = _model.GetIndexingCounts();
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHeaderTable());
      try
      {
        HTMLTable table = new HTMLTable();
        table.SetCellSpacing(CommonHTMLStrings.TWO);
        table.SetCellPadding(CommonHTMLStrings.TWO);
        result.AddInnerHTMLElement(table);
        HTMLTableRow row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
        table.AddInnerHTMLElement(row);
        // Type header cell
        HTMLTableCell cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetColSpan(CommonHTMLStrings.TWO);
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetColSpan(CommonHTMLStrings.TWO);
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2487 = Search Server
        cell.AddInnerHTMLString(m_asOwner.GetString(2487, PORTAL_ADMIN_MSGS));
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetColSpan(CommonHTMLStrings.TWO);
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2488 = Database
        cell.AddInnerHTMLString(m_asOwner.GetString(2488, PORTAL_ADMIN_MSGS));
        row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
        table.AddInnerHTMLElement(row);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        HTMLInput checkB = new HTMLInput(HTMLInputTypes.CHECKBOX, CB_CHECK_ALL,
         "");
        checkB.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        checkB.SetOnClick("DoToggleAllCBs()");
        cell.AddInnerHTMLElement(checkB);
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetWidth("25%");
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2486 = Type
        cell.AddInnerHTMLString(m_asOwner.GetString(2486, PORTAL_ADMIN_MSGS));
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetWidth("18%");
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2489 = Indexed Count
        cell.AddInnerHTMLString(m_asOwner.GetString(2489, PORTAL_ADMIN_MSGS));
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetWidth("18%");
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2490 = Marked Delete
        cell.AddInnerHTMLString(m_asOwner.GetString(2490, PORTAL_ADMIN_MSGS));
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetWidth("18%");
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2491 Count
        cell.AddInnerHTMLString(m_asOwner.GetString(2491, PORTAL_ADMIN_MSGS));
        cell = new HTMLTableCell();
        cell.SetHeight("25");
        cell.SetVAlign(CommonHTMLStrings.MIDDLE);
        cell.SetWidth("18%");
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        // 2492 = Dirty Count
        cell.AddInnerHTMLString(m_asOwner.GetString(2492, PORTAL_ADMIN_MSGS));
        int i = 0;
        IXPEnumerator xpEnum = counts.GetEnumerator();
        ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
        String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
         m_asOwner);
        while (xpEnum.MoveNext())
        {
          SearchServerSettingsEditorModel.IndexingCount item = (SearchServerSettingsEditorModel.IndexingCount) xpEnum.GetCurrent();
          row = new HTMLTableRow();
          if (i % 2 == 0)
          {
            row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
          } else
          {
            row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
          }
          table.AddInnerHTMLElement(row);
          cell = new HTMLTableCell();
          row.AddInnerHTMLElement(cell);
          cell.SetHeight("25");
          cell.SetVAlign(CommonHTMLStrings.MIDDLE);
          checkB = new HTMLInput(HTMLInputTypes.CHECKBOX, CB_CHECK_ONE, "");
          checkB.SetValue(XPConvert.ToString(item.GetClassId()));
          if (item.GetClassId() == SearchServerSettingsEditorModel.IndexingCount.ALL_OTHERS_ID)
          {
            checkB.SetDisabled(true);
          }
          checkB.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
          cell.AddInnerHTMLElement(checkB);
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign(CommonHTMLStrings.MIDDLE);
          cell.SetNoWrap(true);
          HTMLImg image;
          if (item.GetClassId() != SearchServerSettingsEditorModel.IndexingCount.ALL_OTHERS_ID)
          {
            image = ptClassTypeDescManager.GetDefaultIconForClassType(item.GetClassId(),
             strLangID);
            image.SetWidth("20");
            image.SetHeight("20");
            cell.AddInnerHTMLElement(image);
            cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
          }
          row.AddInnerHTMLElement(cell);
          cell.SetStyleClass(PTStyleClass.LIST_TEXT);
          cell.AddInnerHTMLString(item.GetClassName());
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign(CommonHTMLStrings.MIDDLE);
          row.AddInnerHTMLElement(cell);
          cell.SetStyleClass(PTStyleClass.LIST_TEXT);
          cell.AddInnerHTMLString(XPConvert.ToString(item.GetNumberInSearchIndex()));
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign(CommonHTMLStrings.MIDDLE);
          row.AddInnerHTMLElement(cell);
          cell.SetStyleClass(PTStyleClass.LIST_TEXT);
          cell.AddInnerHTMLString(XPConvert.ToString(item.GetNumberAwaitingDelete()));
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign(CommonHTMLStrings.MIDDLE);
          row.AddInnerHTMLElement(cell);
          cell.SetStyleClass(PTStyleClass.LIST_TEXT);
          cell.AddInnerHTMLString(XPConvert.ToString(item.GetTotalDatabaseCount()));
          cell = new HTMLTableCell();
          cell.SetHeight("25");
          cell.SetVAlign(CommonHTMLStrings.MIDDLE);
          row.AddInnerHTMLElement(cell);
          cell.SetStyleClass(PTStyleClass.LIST_TEXT);
          cell.AddInnerHTMLString(XPConvert.ToString(item.GetNumberDirty()));
          i++;
        }
      }
      catch (Exception e)
      {
        // 2493 Error getting Indexing Status
        throw new XPException(m_asOwner.GetString(2493, PORTAL_ADMIN_MSGS),
         e);
      }
      return result;
    }
    protected virtual HTMLElement GetHeaderTable()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetBorder(CommonHTMLStrings.ZERO);
      table.SetCellSpacing(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.ZERO);
      result.AddInnerHTMLElement(table);
      HTMLTableRow row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
      table.AddInnerHTMLElement(row);
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      cell.SetHeight("20");
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.OBJECT_HEADER);
      span.AddInnerHTMLString(m_asOwner.GetString(2485, PORTAL_ADMIN_MSGS));
      cell.AddInnerHTMLElement(span);
      table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetBorder(CommonHTMLStrings.ZERO);
      table.SetCellSpacing(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.ZERO);
      result.AddInnerHTMLElement(table);
      row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      table.AddInnerHTMLElement(row);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      //cell.SetWidth("100%");
      cell.SetHeight("25");
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      HTMLImg newImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ACTION_NEW,
       "", "6", "25");
      newImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg docImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ICON_DOCUMENT,
       "", "15", "20");
      docImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg delImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ACTION_DELETE,
       "", "25", "25");
      delImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg sp1Img = SearchUIUtility.GetImage(m_asOwner, PTImageType.SPACER,
       "", CommonHTMLStrings.ONE, CommonHTMLStrings.ONE);
      HTMLImg sp2Img = SearchUIUtility.GetImage(m_asOwner, PTImageType.SPACER,
       "", CommonHTMLStrings.ONE, CommonHTMLStrings.ONE);
      HTMLAnchor a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      XPArrayList unused = _model.GetUndisplayedNamesAndTypes();
      if (unused.GetSize() > 0)
      {
        a.SetOnClick("OpenPopUp(); return false;");
      } else
      {
        a.SetOnClick("AlertNoAdd(); return false;");
      }
      cell.AddInnerHTMLElement(a);
      a.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      a.AddInnerHTMLElement(newImg);
      a.AddInnerHTMLElement(docImg);
      span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      span.AddInnerHTMLString(m_asOwner.GetString(2526, PORTAL_ADMIN_MSGS));
      a.AddInnerHTMLElement(span);
      a.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      a.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
      cell.AddInnerHTMLElement(sp1Img);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      a.SetOnClick("postToSelf(" + SearchServerSettingsEditorRepostControl.POSTTOSELF_ACTION_IS_DEL_ROWS + "); return false;");
      //Add delete link?
      cell.AddInnerHTMLElement(a);
      a.AddInnerHTMLElement(delImg);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
      cell.AddInnerHTMLElement(sp2Img);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      HTMLElement spacer = SearchUIUtility.makeSpacer(m_asOwner, CommonHTMLStrings.FIVE);
      result.AddInnerHTMLElement(spacer);
      // Add two hidden inputs for the popup.
      HTMLInput select = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, "");
      select.SetValue("");
      select.SetValidateName(false);
      select.SetName(IndexingStatusPopUpView.SELECT_NAME);
      result.AddInnerHTMLElement(select);
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, "");
      myInput.SetValidateName(false);
      myInput.SetChecked(false);
      myInput.SetName(IndexingStatusPopUpView.CHECKBOX_ADD_ALL);
      myInput.SetValue("false");
      result.AddInnerHTMLElement(myInput);
      return result;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}