using System;
using com.plumtree.openfoundation.util;
using PT_RESULTCODES=com.plumtree.server.PT_RESULTCODES;
using PortalObjectsFactory=com.plumtree.server.PortalObjectsFactory;
using PTException=com.plumtree.server.marshalers.PTException;
namespace com.plumtree.portalpages.admin.serversettings.search
{
  /// <summary>
  /// Helper class which yanks information out of the PropertyBag
  /// returned by a search server status request.
  /// </summary>
  public class SearchClusterStatusInfo
  {
    /* Individual-server-related values */
    public String connectStatus = "ERROR";
    public String pbagString;
    public bool isValid = false;
    /* Cluster-related values */
    public String clusterHome;
    public String clusterDocsetTID;
    public String lastSubittedTID;
    public String clusterSearchState;
    public String clusterIndexState;
    public String clusterLexiconTID;
    public String numberOfNodes;
    public String numberOfPartitions;
    public String mbFree;
    public String mbUsed;
    public String[] errors;
    public NodeInfo[] nodes;
    
    /// <param name="lastSubittedTID">The lastSubittedTID to set.</param>
    public virtual void setLastSubittedTID(String lastSubittedTID)
    {
      this.lastSubittedTID = lastSubittedTID;
    }
    
    /// <returns>Returns the clusterIndexState.</returns>
    public virtual String getClusterIndexState()
    {
      return this.clusterIndexState;
    }
    
    /// <returns>Returns the clusterSearchState.</returns>
    public virtual String getClusterSearchState()
    {
      return this.clusterSearchState;
    }
    
    /// <returns>Returns the errors.</returns>
    public virtual String[] getErrors()
    {
      return this.errors;
    }
    
    /// <returns>Returns the mbFree(in Megs).</returns>
    public virtual String getFreeMem()
    {
      return this.mbFree;
    }
    
    /// <returns>Returns the mbUsed(in Megs).</returns>
    public virtual String getUsedMem()
    {
      return this.mbUsed;
    }
    
    /// <returns>Returns the nodes.</returns>
    public virtual NodeInfo[] getNodes()
    {
      return this.nodes;
    }
    
    /// <returns>Returns the clusterDocsetTID.</returns>
    public virtual String getClusterDocsetTID()
    {
      return this.clusterDocsetTID;
    }
    
    /// <returns>Returns the clusterHome.</returns>
    public virtual String getClusterHome()
    {
      return this.clusterHome;
    }
    
    /// <returns>Returns the clusterLexiconTID.</returns>
    public virtual String getClusterLexiconTID()
    {
      return this.clusterLexiconTID;
    }
    
    /// <returns>Returns the clusterSearchState.</returns>
    public virtual String getClusterState()
    {
      return this.clusterSearchState;
    }
    
    /// <returns>Returns the connectStatus.</returns>
    public virtual String getConnectStatus()
    {
      return this.connectStatus;
    }
    
    /// <returns>Returns the isValid.</returns>
    public virtual bool valid()
    {
      return this.isValid;
    }
    
    /// <returns>Returns the mbUsed.</returns>
    public virtual String getKbUsed()
    {
      return this.mbUsed;
    }
    
    /// <returns>Returns the lastSubittedTID.</returns>
    public virtual String getLastSubittedTID()
    {
      return this.lastSubittedTID;
    }
    
    /// <returns>Returns the numberOfNodes.</returns>
    public virtual String getNumberOfNodes()
    {
      return this.numberOfNodes;
    }
    
    /// <returns>Returns the numberOfPartitions.</returns>
    public virtual String getNumberOfPartitions()
    {
      return this.numberOfPartitions;
    }
    
    /// <returns>Returns the pbagString.</returns>
    public virtual String getPbagString()
    {
      return this.pbagString;
    }
    
    /// <summary>
    /// Construct a SearchServerStatusInfo from a named subbag of a search
    /// status propertybag. <p />
    /// When all is well, connectStatus == "OK".
    /// When there is no search server running, connectStatus contains
    /// "Error: (0x80044301) Unable to connect to search server: Winsock error code 10061"
    /// </summary>
    /// <param name="pBag">PropertyBag result of SearchRequest.RetrieveStatus()</param>
    public SearchClusterStatusInfo(IXPPropertyBag pBag)
    {
      IXPPropertyBag subBag = pBag.ReadAsIXPPropertyBag("CLUSTERSTATUS");
      if (subBag == null)
      {
        isValid = false;
        return;
      }
      isValid = true;
      connectStatus = subBag.ReadAsString("CONNECTSTATUS");
      if (!XPStringUtility.EqualsIgnoreCase(connectStatus, "OK"))
      {
        throw new PTException(connectStatus, PT_RESULTCODES.PT_E_SEARCH_FAIL);
        }
      clusterHome = subBag.ReadAsString("CLUSTER_HOME");
      clusterDocsetTID = subBag.ReadAsString("CLUSTER_DOCSET_TID_STRING");
      //        lastSubittedTID = subBag.ReadAsString("LAST_TRANSACTION_ID");
      clusterSearchState = subBag.ReadAsString("CLUSTER_SEARCH_STATE_STRING");
      clusterIndexState = subBag.ReadAsString("CLUSTER_INDEX_STATE_STRING");
      clusterLexiconTID = subBag.ReadAsString("CLUSTER_LEXICON_TID_STRING");
      numberOfNodes = subBag.ReadAsString("NUMBER_OF_NODES");
      numberOfPartitions = subBag.ReadAsString("NUMBER_OF_PARTITIONS");
      mbFree = subBag.ReadAsString("MB_FREE");
      mbUsed = subBag.ReadAsString("MB_USED");
      Object[] errorsObj = subBag.ReadAsObject1DArray("ERRORS");
      errors = new String[errorsObj.Length];
      for (int count = 0;count < errorsObj.Length;count++)
      {
        errors[count] = (String) errorsObj[count];
      }
      Object[] nodeBags = subBag.ReadAsObject1DArray("NODES");
      nodes = new NodeInfo[nodeBags.Length];
      for (int count = 0;count < nodeBags.Length;count++)
      {
        nodes[count] = new NodeInfo((IXPPropertyBag) nodeBags[count]);
      }
    }
  }
}
// class SearchServerStatusInfo
