using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.admin.serversettings.search
{
  /// <author>OlegS</author>
  public class SearchServerSettingsEditorAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.search.SearchServerSettingsEditorAS");
    public const String STR_MVC_CLASS_NAME = "SearchServerSettingsEditor";
    private const String sClassName = "com.plumtree.portalpages.admin.serversettings.search.SearchServerSettingsEditorAS";
    // True if we've checked for the indexing status file config option.
    private static bool _isInitialized = false;
    // Tagname to put in ptconfig.xml to turn indexing status on.
    private static String SPECIAL_VAL_NAME = "IndexingStatus";
    // True if we are showing indexing status page
    private static bool _showIndexingStatus = false;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SearchServerSettingsEditorAS();
    }
    
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      return (GetString(152, "ptmsgs_portalcommonmsgs"));
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public override String GetRepostControlName()
    {
      return (SearchServerSettingsEditorRepostControl.STR_MVC_CLASS_NAME);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession());
      if (!bInAdminGroup)
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    public override void Init()
    {
      if (!_isInitialized)
      {
        loadConfig();
      }
      m_strModelName = SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      RegisterPage(new SearchServerSettingsEditorDP());
      RegisterPage(new SearchServerSettingsPopUpDP());
      RegisterView(SearchServerSettingsEditorView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SearchServerSettingsPopUpView.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SearchServerSettingsEditorRepostControl.STR_MVC_CLASS_NAME,
       myModel);
      SetCurrentPage(SearchServerSettingsEditorDP.STR_MVC_CLASS_NAME);
      // Set left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(153, "ptmsgs_portalcommonmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SearchServerSettingsEditorDP.STR_MVC_CLASS_NAME);
      if (_showIndexingStatus)
      {
        RegisterPage(new IndexingStatusDP());
        RegisterPage(new IndexingStatusPopUpDP());
        RegisterView(IndexingStatusView.STR_MVC_CLASS_NAME, myModel);
        RegisterView(IndexingStatusPopUpView.STR_MVC_CLASS_NAME, myModel);
        m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, IndexingStatusDP.STR_MVC_CLASS_NAME);
        }
      // END Sub menu "General Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 132;
          int iTipId = 133;
          int iSecondaryTipId = 134;
          tm.SetTipTitle(this.GetString(iTitleId, ResourceConstants.TIPS));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           ResourceConstants.TIPS));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, ResourceConstants.TIPS);
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    //	Got the tips model
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SearchServerSettingsEditorDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SearchServerManager_MainSettings");
      } else
      if (IndexingStatusDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SearchServerManager_IndexingStatus");
      } else
      if (SearchServerSettingsPopUpDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SearchServerStatus");
      }
    }
    private static void loadConfig()
    {
      _isInitialized = true;
      try
      {
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        PTConfigVarPack vpPTConfig = (PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID);
        try
        {
          String categoryName = vpPTConfig.GetConfigValueAsString("Search",
           SPECIAL_VAL_NAME, "value");
          if (categoryName != null && !XPStringUtility.Trim(categoryName).Equals(""))
          {
            _showIndexingStatus = true;
          }
        }
        catch (Exception e)
        {
          log.Error(e, "Trouble parsing Indexing Status flag.");
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Trouble parsing Indexing Status info: " + e.Message);
        }
    }
  }
}