using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.search
{
  /// <author>MatthewF</author>
  public class SearchServerTuningEditorAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.search.SearchServerTuningEditorAS");
    public const String STR_MVC_CLASS_NAME = "SearchServerTuningEditor";
    private const String sClassName = "com.plumtree.portalpages.admin.serversettings.search.SearchServerTuningEditorAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SearchServerTuningEditorAS();
    }
    
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      return (GetString(2574, "ptmsgs_portaladminmsgs"));
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public override String GetRepostControlName()
    {
      return (SearchServerTuningEditorRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      IPTSession ptSession = (IPTSession) GetUserSession();
      bool hasRight = ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SEARCH_SERVER_TUNING);
      if (!hasRight)
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    public override void Init()
    {
      m_strModelName = SearchServerTuningEditorModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      RegisterPage(new BestBetsListDP());
      RegisterPage(new ThesaurusSettingsDP());
      RegisterPage(new BannerFieldAliasDP());
      RegisterView(BestBetsListView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ThesaurusSettingsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(BannerFieldAliasView.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SearchServerTuningEditorRepostControl.STR_MVC_CLASS_NAME,
       myModel);
      SetCurrentPage(BestBetsListDP.STR_MVC_CLASS_NAME);
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(153, "ptmsgs_portalcommonmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, BestBetsListDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, BannerFieldAliasDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, ThesaurusSettingsDP.STR_MVC_CLASS_NAME);
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          //TODO: Get help topic and tips for Tuning rather than Manager
          int iTitleId = 135;
          int iTipId = 136;
          int iSecondaryTipId = 137;
          tm.SetTipTitle(this.GetString(iTitleId, ResourceConstants.TIPS));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           ResourceConstants.TIPS));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, ResourceConstants.TIPS);
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (BestBetsListDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SearchResultsManager_BestBets");
      } else
      if (ThesaurusSettingsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SearchResultsManager_ThesaurusandSpellCorrection");
        } else
      if (BannerFieldAliasDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_SearchResultsManager_BannerFields");
      }
    }
  }
}