using System;
using XPLocale=com.plumtree.openfoundation.internationalization.XPLocale;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.search;
using com.plumtree.server.search.admin;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.admin.serversettings.search
{
  /// <author>SamirM</author>
  public class SearchServerTuningEditorModel : EditorModel,ISearchServerTuningEditorModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.search.SearchServerTuningEditorModel");
    public const String STR_MVC_CLASS_NAME = "SearchServerTuningEditorModel";
    // member variables
    internal XPStringBuilder m_errors = null;
    private AliasElement[] _aliasElements = null;
    private String _alias = null;
    private bool _thesaurusOn = false;
    private bool _spellCheckOn = false;
    // Best Bet Model - initialized by InitBestBetsList()
    private IPTSearchBestBetMaintenance m_bestBetModel;
    public SearchServerTuningEditorModel() : base()
    {
      m_errors = new XPStringBuilder();
    }
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
    }
    protected virtual void InitSpellCheckThesaurus()
    {
      IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      _thesaurusOn = (ptSCS.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SEARCH_ALLOW_THESAURUS) == 1);
      _spellCheckOn = (ptSCS.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SEARCH_ALLOW_SPELLCHECK) == 1);
      }
    // interface PropertyValidatorOwner
    public virtual XPStringBuilder GetErrorString()
    {
      return m_errors;
    }
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      bool isAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession);
      bool hasRight = ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SEARCH_SERVER_TUNING);
      if (!(isAdmin || hasRight))
      {
        log.Debug("CheckEditorAccessAndStart returning false");
        return false;
      }
      InitBestBetsList();
      InitSpellCheckThesaurus();
      SetEnableApplyButton(true);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SearchServerTuningEditorModel();
    }
    public override void Finish()
    {
      DoApplyChanges(null);
    }
    public virtual void DoApplyChanges(XPHashtable lastUserVals)
    {
      SaveBestBetsChanges();
      if (lastUserVals != null)
      {
        LoadLastUserVals(lastUserVals);
      }
      if (CheckBannerAliasAndDelocalizeWeights())
      {
        SaveFieldAliasToServer();
      }
      SaveThesaurusSpellToServer();
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      TraceHelper.Trace("SavePage(" + _sPageName + ")");
      TraceHelper.TraceQueryString(_htFormData);
      int result = RepostControl.PAGE_STATUS_VALID;
      if (_sPageName.Equals(SearchServerTuningEditorDP.STR_MVC_CLASS_NAME))
      {
        result = SaveMainPage(_htFormData);
      } else
      if (_sPageName.Equals(ThesaurusSettingsDP.STR_MVC_CLASS_NAME))
      {
        SaveThesaurusFromForm(_htFormData);
      } else
      if (_sPageName.Equals(BannerFieldAliasDP.STR_MVC_CLASS_NAME))
      {
        result = SaveBannerAlias(_htFormData);
      }
      return result;
    }
    /* START - ISearchServerTuningEditorModelRO implementation */
    
    /// <summary>
    /// START - BEST BET RELATED METHODS ******
    /// </summary>
    private String m_searchString;
    private int m_nNumBBsAskedFor = 10;
    private int m_nBBStartCount = 1;
    public virtual String GetBestBetSearchString()
    {
      return m_searchString;
    }
    public virtual bool GetIsShowAllBestBets()
    {
      return m_bestBetModel.GetShowingAll();
    }
    public virtual int GetNumBestBetsAskedFor()
    {
      return m_nNumBBsAskedFor;
    }
    public virtual int GetNumBestBetsOnPage()
    {
      return m_bestBetModel.GetDisplayedCount();
    }
    public virtual int GetBestBetStartCount()
    {
      return m_nBBStartCount;
    }
    public virtual bool GetShowPreviousBestBet()
    {
      return (GetBestBetStartCount() > 1);
    }
    public virtual bool GetShowNextBestBet()
    {
      return (GetTotalBestBetCount() >= (GetBestBetStartCount() + GetNumBestBetsOnPage()));
      }
    public virtual int GetTotalBestBetCount()
    {
      return m_bestBetModel.GetTotalCount();
    }
    public virtual int GetNumDeletedBestBets()
    {
      return m_bestBetModel.GetDeletedCount();
    }
    public virtual int GetNumAddedBestBets()
    {
      return m_bestBetModel.GetAddedCount();
    }
    // Make sure to call CheckDuplicateBestBetQuery before calling this.
    /* IPTBestBetTarget */
    public virtual void UpdateBestBetFromSubEditor(String originalTrigger,
     bool bModifiedBBWasFromDB, String strTrigger, String setup, IXPList arrTargets)
    {
      m_bestBetModel.UpdateBestBet(originalTrigger, bModifiedBBWasFromDB,
       strTrigger, setup, arrTargets);
      m_bestBetModel.RefreshDisplayList();
    }
    public virtual String GetBestBetTrigger(int i)
    {
      return m_bestBetModel.GetDisplayedItemTrigger(i);
    }
    public virtual String GetBestBetSetupString(int i)
    {
      return m_bestBetModel.GetDisplayedItemSetupString(i);
    }
    public virtual IXPList GetBestBetTargets(int i)
    {
      return m_bestBetModel.GetDisplayedItemTargets(i);
    }
    public virtual bool HasBestBetBeenDeleted(int i)
    {
      return m_bestBetModel.HasDisplayedItemBeenDeleted(i);
    }
    public virtual bool HasBestBetStringBeenDeleted(String trigger)
    {
      return m_bestBetModel.HasBestBetBeenDeleted(trigger);
    }
    public virtual bool HasBestBetBeenNewlyAdded(int i)
    {
      return m_bestBetModel.HasDisplayedItemBeenNewlyAdded(i);
    }
    public virtual bool CheckDuplicateBestBetQuery(String originalTrigger,
     String strTrigger, bool bNewlyAdded)
    {
      return m_bestBetModel.CanAddBestBet(originalTrigger, strTrigger, bNewlyAdded);
      }
    /* END - IMPLEMENTATION OF ISearchServerTuningEditorModelRO */
    public virtual void SetNumBestBetsAskedFor(int n)
    {
      m_nNumBBsAskedFor = n;
      m_bestBetModel.SetNumResultsAskedFor(n);
    }
    public virtual void SetBestBetStartCount(int n)
    {
      m_nBBStartCount = n;
      m_bestBetModel.SetStartCount(n);
    }
    // Assumption is that list of ids are in ascending order.
    public virtual void DeleteBestBets(int[] ids)
    {
      m_bestBetModel.DeleteFromDisplayedList(ids);
      m_bestBetModel.RefreshDisplayList();
    }
    public virtual void SearchBestBets(String str)
    {
      m_searchString = str;
      m_bestBetModel.SetShowingAll(false);
      m_bestBetModel.SetSearchString(str);
      SetBestBetStartCount(1);
      m_bestBetModel.RefreshDisplayList();
    }
    public virtual void ShowAllBestBets()
    {
      m_bestBetModel.SetShowingAll(true);
      m_bestBetModel.SetSearchString(null);
      m_searchString = "";
      SetBestBetStartCount(1);
      m_bestBetModel.RefreshDisplayList();
    }
    public virtual void PaginateBestBets(int startCount, int numResultsPerPage)
    {
      SetBestBetStartCount(startCount);
      SetNumBestBetsAskedFor(numResultsPerPage);
      m_bestBetModel.RefreshDisplayList();
    }
    
    /// <summary>
    /// END - BEST BET RELATED METHODS ******
    /// </summary>
    protected virtual int SaveBannerAlias(XPHashtable _htFormData)
    {
      int result = RepostControl.PAGE_STATUS_VALID;
      String[] numVals = (String[]) _htFormData.GetElement(BannerFieldAliasView.IN_HI_NUM_FIELDS);
      if (numVals == null || numVals.Length != 1)
      {
        return RaiseBannerAliasError(m_asOwner.GetString(2567, "ptmsgs_portaladminmsgs"));
        }
      int number = XPConvert.ToInteger(numVals[0]);
      String alias = "";
      AliasElement[] newAlias = new AliasElement[number];
      String id;
      for (int i = 0;i < number;i++)
      {
        if (i > 0)
        {
          alias+=",";
        }
        String idInputName = BannerFieldAliasView.IN_SE_NAME + i;
        String[] idVals = (String[]) _htFormData.GetElement(idInputName);
        id = idVals[0];
        String weightInputName = BannerFieldAliasView.IN_WEIGHT_INPUT + i;
        String[] weightVals = (String[]) _htFormData.GetElement(weightInputName);
        String newPropVal = "PT" + id + "[";
        if (XPStringUtility.IndexOf(alias, newPropVal) != -1)
        {
          return RaiseBannerAliasError(m_asOwner.GetString(2568, "ptmsgs_portaladminmsgs"));
          }
        try
        {
          float weight = XPConvert.ToFloat(DeLocalizeFloat(weightVals[0]));
          if (weight <= 0)
          {
            return RaiseBannerAliasError(m_asOwner.GetString(2569, "ptmsgs_portaladminmsgs"));
            }
        }
        catch (Exception e)
        {
          return RaiseBannerAliasError(m_asOwner.GetString(2570, "ptmsgs_portaladminmsgs"));
          }
        alias+=newPropVal + DeLocalizeFloat(weightVals[0]) + "]";
        newAlias[i] = new AliasElement(id, DeLocalizeFloat(weightVals[0]));
        }
      _aliasElements = newAlias;
      _alias = alias;
      return result;
    }
    protected virtual bool CheckBannerAliasAndDelocalizeWeights()
    {
      if (_aliasElements == null)
      {
        return false;
      }
      for (int i = 0;i < _aliasElements.Length;i++)
      {
        for (int j = 1;j < _aliasElements.Length;j++)
        {
          if (i != j)
          {
            if (_aliasElements[i].propID == _aliasElements[j].propID)
            {
              RaiseBannerAliasError(m_asOwner.GetString(2568, "ptmsgs_portaladminmsgs"));
              return false;
            }
          }
        }
        try
        {
          float weight = XPConvert.ToFloat(DeLocalizeFloat(_aliasElements[i].weightVal));
          if (weight <= 0)
          {
            RaiseBannerAliasError(m_asOwner.GetString(2569, "ptmsgs_portaladminmsgs"));
            return false;
          }
          // Replace the existing weight val in memory with the "delocalized" version.
          _aliasElements[i].weightVal = XPConvert.ToString(weight);
        }
        catch (Exception e)
        {
          RaiseBannerAliasError(m_asOwner.GetString(2570, "ptmsgs_portaladminmsgs"));
          return false;
        }
      }
      // OK, it all looks ok right now, but recalculate the percentages, and make sure
      // that none of them round down to 0.
      RecalculatePercentages(_aliasElements);
      for (int i = 0;i < _aliasElements.Length;i++)
      {
        if (XPConvert.ToFloat(_aliasElements[i].percentage) <= 0)
        {
          RaiseBannerAliasError(m_asOwner.GetString(2569, "ptmsgs_portaladminmsgs"));
          return false;
        }
      }
      return true;
    }
    public virtual void AddAliasTerm(XPHashtable lastUserVals)
    {
      AliasElement[] newAlias = new AliasElement[_aliasElements.Length + 1];
      for (int i = 0;i < _aliasElements.Length;i++)
      {
        newAlias[i] = _aliasElements[i];
      }
      // This default is "Name" "1.0", which seems as good as any.
      newAlias[_aliasElements.Length] = new AliasElement("1", "1.0");
      _aliasElements = newAlias;
      LoadLastUserVals(lastUserVals);
    }
    public virtual bool OkToDeleteThisManyAliasTerms(int number)
    {
      // We can't delete all the terms--at least one must remain.
      return (number < _aliasElements.Length);
    }
    public virtual void DeleteTheseAliasTerms(int[] indices, XPHashtable lastUserVals)
    {
      LoadLastUserVals(lastUserVals);
      int newNumber = _aliasElements.Length - indices.Length;
      AliasElement[] newAlias = new AliasElement[newNumber];
      int count = 0;
      for (int j = 0;j < indices.Length;j++)
      {
        _aliasElements[indices[j]] = null;
      }
      for (int i = 0;i < _aliasElements.Length;i++)
      {
        if (_aliasElements[i] != null)
        {
          newAlias[count++] = _aliasElements[i];
        }
      }
      _aliasElements = newAlias;
    }
    public virtual void LoadLastUserVals(XPHashtable lastUserVals)
    {
      if (_aliasElements == null)
      {
        return;
      }
      for (int i = 0;i < _aliasElements.Length;i++)
      {
        String weightName = BannerFieldAliasView.IN_WEIGHT_INPUT + i;
        String[] vals = (String[]) lastUserVals.GetElement(weightName);
        if (vals != null)
        {
          _aliasElements[i].weightVal = vals[0];
        }
        String propIdName = BannerFieldAliasView.IN_SE_NAME + i;
        vals = (String[]) lastUserVals.GetElement(propIdName);
        try
        {
          if (vals != null)
          {
            _aliasElements[i].propID = XPConvert.ToInteger(vals[0]);
          }
        }
        catch (Exception e)
        {
        }
      }
    }
    protected virtual void BuildAliasFromElements()
    {
      String alias = "";
      for (int i = 0;i < _aliasElements.Length;i++)
      {
        if (i > 0)
        {
          alias+=",";
        }
        alias+="PT" + _aliasElements[i].propID + "[" + _aliasElements[i].weightVal + "]";
        }
      _alias = alias;
    }
    protected virtual void SaveFieldAliasToServer()
    {
      BuildAliasFromElements();
      if (_alias == null || _alias.Equals(""))
      {
        return;
      }
      IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      ptSCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SEARCH_DEFAULT_FIELD_ALIAS,
       _alias);
      if (log.IsDebugEnabled())
      {
        log.Debug("Saving Banner Alias = " + _alias);
      }
    }
    protected virtual int RaiseBannerAliasError(String message)
    {
      UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       message, "");
      err.SetActivitySpace(m_asOwner.GetName());
      err.SetDisplayOnSeparatePage(false);
      err.SetClearWithActivitySpaceChange(true);
      err.SetImmediateClear(true);
      UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      return RepostControl.PAGE_STATUS_INVALID;
    }
    
    /// <returns></returns>
    public virtual AActivitySpace asOwner()
    {
      return m_asOwner;
    }
    
    /// <summary>
    /// Trace a message if debug tracing is enabled for the UI component.
    /// This method could be moved into the EditorModel base class, along
    /// with trace() and traceEnabled().
    /// </summary>
    protected virtual void TraceDebug(String msg)
    {
      if (TraceHelper.Enabled())
      {
        TraceHelper.Trace(msg);
      }
    }
    public virtual void ActionOnRepost()
    {
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveMainPage(XPHashtable _htFormData)
    {
      int result = RepostControl.PAGE_STATUS_VALID;
      return result;
    }
    protected virtual void SaveThesaurusFromForm(XPHashtable _htFormData)
    {
      // Recover the checkbox element for turning spell check on, if any
      String[] vals = (String[]) _htFormData.GetElement(ThesaurusSettingsView.APPLY_SPELL_CB);
      bool spellCheckOn = false;
      if (vals != null && vals.Length == 1)
      {
        spellCheckOn = true;
        if (log.IsDebugEnabled())
        {
          log.Debug("SaveThesaurusFromForm: spell check on");
        }
      } else
      if (log.IsDebugEnabled())
      {
        log.Error("SaveThesaurusFromForm: spell check off");
      }
      SetSpellCheckOn(spellCheckOn);
      // Recover the thesaurus element
      vals = (String[]) _htFormData.GetElement(ThesaurusSettingsView.APPLY_THESAURUS_CB);
      bool thesaurusOn = false;
      if (vals != null && vals.Length == 1)
      {
        thesaurusOn = true;
        if (log.IsDebugEnabled())
        {
          log.Debug("SaveThesaurusFromForm: thesaurus on");
        }
      } else
      if (log.IsDebugEnabled())
      {
        log.Debug("SaveThesaurusFromForm: thesaurus off");
      }
      SetThesaurusOn(thesaurusOn);
    }
    protected virtual void SaveThesaurusSpellToServer()
    {
      int spellOn = GetSpellCheckOn() ? 1 : 0;
      int thesOn = GetThesaurusOn() ? 1 : 0;
      IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      ptSCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SEARCH_ALLOW_SPELLCHECK,
       spellOn);
      if (log.IsDebugEnabled())
      {
        log.Debug("SaveThesaurusSpellToServer: spellcheck setting " + spellOn);
        }
      ptSCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_SEARCH_ALLOW_THESAURUS,
       thesOn);
      if (log.IsDebugEnabled())
      {
        log.Debug("SaveThesaurusSpellToServer: thesaurus setting " + thesOn);
        }
    }
    // Best Bets interface
    private void InitBestBetsList()
    {
      try
      {
        IPTSession session = (IPTSession) m_asOwner.GetUserSession();
        IPTSearchFactory sf = session.GetSearchFactory();
        IPTSAdmin searchAdmin = sf.createAdmin();
        m_bestBetModel = searchAdmin.createBestBetMaintenance();
        m_bestBetModel.SetStartCount(1);
        m_bestBetModel.RefreshDisplayList();
      }
      catch (Exception e)
      {
        XPException i18n = SearchUIUtility.GetI18NException(e, m_asOwner);
        UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         i18n, i18n.GetMessage(), "");
        err.SetActivitySpace(m_asOwner.GetName());
        err.SetDisplayOnSeparatePage(false);
        err.SetHTMLMessage(((SearchExecutionError) i18n).GetComment());
        err.SetClearWithActivitySpaceChange(true);
        err.SetImmediateClear(true);
        UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    private void SaveBestBetsChanges()
    {
      try
      {
        m_bestBetModel.ApplyChanges();
      }
      catch (Exception e)
      {
        XPException i18n = SearchUIUtility.GetI18NException(e, m_asOwner);
        UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         i18n, i18n.GetMessage(), "");
        err.SetActivitySpace(m_asOwner.GetName());
        err.SetDisplayOnSeparatePage(false);
        err.SetHTMLMessage(((SearchExecutionError) i18n).GetComment());
        err.SetClearWithActivitySpaceChange(true);
        err.SetImmediateClear(true);
        UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    protected virtual String GetFieldAliasFromServer()
    {
      IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      _alias = ptSCS.GetSettingAsString(PT_SERVER_CONFIG_SETTINGNAME.PT_SEARCH_DEFAULT_FIELD_ALIAS);
      return _alias;
    }
    protected virtual AliasElement[] ParseAlias(String alias)
    {
      if (alias == null || alias.Equals(""))
      {
        return new AliasElement[0];
      }
      String delim = ",";
      int j = 0;
      XPStringTokenizer tokenizer = new XPStringTokenizer(alias, delim);
      String[] ellsVals = new String[tokenizer.GetTokenCount()];
      while (tokenizer.HasMoreElements())
      {
        ellsVals[j++] = tokenizer.GetNextElement();
      }
      AliasElement[] retval = new AliasElement[ellsVals.Length];
      for (int i = 0;i < ellsVals.Length;i++)
      {
        int openBrace = XPStringUtility.IndexOf(ellsVals[i], "[");
        String propIDVal = XPStringUtility.Substring(ellsVals[i], 2, openBrace);
        int closeBrace = XPStringUtility.IndexOf(ellsVals[i], "]");
        String weight = XPStringUtility.Substring(ellsVals[i], openBrace + 1,
         closeBrace);
        AliasElement el = new AliasElement();
        try
        {
          el.propID = XPConvert.ToInteger(propIDVal);
        }
        catch (Exception e)
        {
          el.propID = -1;
        }
        el.weightVal = weight;
        try
        {
          XPConvert.ToFloat(weight);
        }
        catch (Exception e)
        {
          el.propID = -1;
        }
        retval[i] = el;
      }
      RecalculatePercentages(retval);
      return retval;
    }
    public virtual void RestoreDefaultFieldAlias()
    {
      _alias = "PT1[2.0],PT2[0.1],PT50[0.1]";
      _aliasElements = new AliasElement[3];
      _aliasElements[0] = new AliasElement("1", "2.0");
      _aliasElements[1] = new AliasElement("2", "0.1");
      _aliasElements[2] = new AliasElement("50", "0.1");
    }
    public virtual Object[] GetCurrentAliasElements()
    {
      if (_aliasElements == null)
      {
        _aliasElements = ParseAlias(GetFieldAliasFromServer());
      }
      return _aliasElements;
    }
    protected virtual void RecalculatePercentages(AliasElement[] elements)
    {
      float totalWeight = 0;
      for (int i = 0;i < elements.Length;i++)
      {
        try
        {
          totalWeight+=XPConvert.ToFloat(elements[i].weightVal);
        }
        catch (Exception e)
        {
        }
      }
      for (int i = 0;i < elements.Length;i++)
      {
        try
        {
          String temp = XPConvert.ToString((XPConvert.ToFloat(elements[i].weightVal) / totalWeight) * 100.0 + 0.0050);
          int decimalpt = XPStringUtility.IndexOf(temp, ".");
          elements[i].percentage = XPStringUtility.Substring(temp, 0, decimalpt + 3);
          }
        catch (Exception e)
        {
          elements[i].percentage = "0";
        }
      }
    }
    public class AliasElement
    {
      internal int propID;
      internal String weightVal;
      internal String percentage;
      public AliasElement(String prop, String weight)
      {
        try
        {
          propID = XPConvert.ToInteger(prop);
        }
        catch (Exception e)
        {
          propID = -1;
        }
        weightVal = weight;
      }
      public AliasElement()
      {
        propID = -1;
      }
    }
    public virtual bool GetThesaurusOn()
    {
      return _thesaurusOn;
    }
    public virtual void SetThesaurusOn(bool tf)
    {
      _thesaurusOn = tf;
    }
    public virtual bool GetSpellCheckOn()
    {
      return _spellCheckOn;
    }
    public virtual void SetSpellCheckOn(bool tf)
    {
      _spellCheckOn = tf;
    }
    
    /// <summary>
    /// GetLocalizedDecimalSeperator - Returns the locale specific decimal seperator.
    /// This method is public since it is used by the view.
    /// Helper method that deals with localization of floating point #s in the UI.
    /// </summary>
    /// <returns></returns>
    public virtual char GetLocalizedDecimalSeperator()
    {
      double d = 0.1;
      String s = XPFormat.Format(new XPLocale(m_asOwner.GetLocale()), d);
      // something wierd is going on...
      if (s.Length != 3)
      {
        return '.';
      } else
      {
        return XPStringUtility.CharAt(s, 1);
      }
    }
    
    /// <summary>
    /// LocalizeFloat - Converts internal string representation of floating point
    /// number into the locale specific string representation.
    /// This method is public since it is used by the view.
    /// Helper method that deals with localization of floating point #s in the UI.
    /// </summary>
    /// <param name="strFloatVal"></param>
    /// <returns></returns>
    public virtual String LocalizeFloat(String strFloatVal)
    {
      if (strFloatVal == null || strFloatVal.Length == 0)
      {
        return "";
      }
      double d = 0.0;
      try
      {
        d = XPConvert.ToDouble(strFloatVal);
      }
      catch (XPException e)
      {
        return "";
      }
      return XPFormat.Format(new XPLocale(m_asOwner.GetLocale()), d);
    }
    
    /// <summary>
    /// DeLocalizeFloat - Converts a localized string representation of a floating point
    /// number into the internal string representation (i.e. replaces
    /// locale specific decimal seperator with a period '.')
    /// Helper method that deals with localization of floating point #s in the UI.
    /// </summary>
    /// <param name="strFloatVal"></param>
    /// <returns></returns>
    private String DeLocalizeFloat(String strFloatVal)
    {
      char cSep = GetLocalizedDecimalSeperator();
      String strSep = "" + cSep;
      int nPosComma = XPStringUtility.IndexOf(strFloatVal, strSep);
      if (nPosComma >= 0)
      {
        strFloatVal = strFloatVal.Replace(cSep, '.');
      }
      return strFloatVal;
    }
  }
}