using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.admin.serversettings.search
{
  /// <author>MatthewF</author>
  public class ThesaurusSettingsView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
     "com.plumtree.portalpages.admin.serversettings.search.ThesaurusSettingsView");
    public const String STR_MVC_CLASS_NAME = "ThesaurusSettingsView";
    public const String APPLY_SPELL_CB = "in_cb_apply_spell";
    public const String APPLY_THESAURUS_CB = "in_cb_apply_thesaurus";
    // Constants
    private SearchServerTuningEditorModel _model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ThesaurusSettingsView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      _model = (SearchServerTuningEditorModel) m_model;
      try
      {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLComment myComment = new HTMLComment("Begin: Display ThesaurusSettingsView");
        result.AddInnerHTMLElement(myComment);
        HTMLTable table = new HTMLTable();
        table.SetWidth("100%");
        table.SetBorder("0");
        table.SetCellSpacing("0");
        table.SetCellPadding("0");
        result.AddInnerHTMLElement(table);
        HTMLTableRow row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
        table.AddInnerHTMLElement(row);
        HTMLTableCell cell = new HTMLTableCell();
        cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        cell.SetHeight("25");
        row.AddInnerHTMLElement(cell);
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        span.AddInnerHTMLString(m_asOwner.GetString(2558, "ptmsgs_portaladminmsgs"));
        cell.AddInnerHTMLElement(span);
        row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        table.AddInnerHTMLElement(row);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetWidth("100%");
        cell.SetHeight("25");
        cell.SetVAlign("middle");
        cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        HTMLInput cb = new HTMLInput(HTMLInputTypes.CHECKBOX, APPLY_THESAURUS_CB,
         APPLY_THESAURUS_CB, "");
        cb.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        cb.SetChecked(_model.GetThesaurusOn());
        cell.AddInnerHTMLElement(cb);
        span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        span.AddInnerHTMLString(m_asOwner.GetString(2559, "ptmsgs_portaladminmsgs"));
        cell.AddInnerHTMLElement(span);
        row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        table.AddInnerHTMLElement(row);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetWidth("100%");
        cell.SetHeight("25");
        cell.SetVAlign("middle");
        cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        cb = new HTMLInput(HTMLInputTypes.CHECKBOX, APPLY_SPELL_CB, APPLY_SPELL_CB,
         "");
        cb.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        cb.SetChecked(_model.GetSpellCheckOn());
        cell.AddInnerHTMLElement(cb);
        span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        span.AddInnerHTMLString(m_asOwner.GetString(2560, "ptmsgs_portaladminmsgs"));
        cell.AddInnerHTMLElement(span);
        return result;
      }
      catch (Exception e)
      {
        log.Error(e, "Exception in ThesaurusSettingsView.Display.");
        throw XPException.GetInstance(e);
      }
    }
    
    /// <summary>
    /// Returns Java Script for editBB function.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script;
      try
      {
        XPStringBuilder sb = new XPStringBuilder(400);
        script = new HTMLScript("text/javaScript");
        sb.Append("\n");
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "ThesaurusSettingsView::DisplayJavascript An error occured when trying to display the JavaScript.");
        throw XPException.GetInstance(e);
      }
      return script;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}