using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.opener;
namespace com.plumtree.portalpages.ajax
{
  /// <author>MattC</author>
  public class AjaxControl : BaseOpenerControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_AJAX),
     "com.plumtree.portalpages.ajax.AjaxControl");
    private static String ACTION_KEY = "action";
    private static String ACTION_RENAME = "rename";
    private static String CLASS_ID = "cid";
    private static String OBJECT_ID = "oid";
    private static String NEW_NAME = "name";
    public const String STR_MVC_CLASS_NAME = "AjaxControl";
    public const int POST_ACTION_RENAME = 1;
    public const int STATUS_FAIL = 0;
    public const int STATUS_SUCCESS = 1;
    private AActivitySpace m_asOwner;
    private AjaxModel m_ajaxModel;
    
    /// <summary>
    /// This overrides the implementation from IControl for certain actions
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String[] aDataValue = (String[]) arguments.GetElement(ACTION_KEY);
      if (XPStringUtility.EqualsIgnoreCase(aDataValue[0], ACTION_RENAME))
      {
        int classID = -1;
        int objectID = -1;
        String newName = "";
        try
        {
          // perform the rename
          classID = XPConvert.ToInteger(((String[]) arguments.GetElement(CLASS_ID))[0]);
          objectID = XPConvert.ToInteger(((String[]) arguments.GetElement(OBJECT_ID))[0]);
          newName = ((String[]) arguments.GetElement(NEW_NAME))[0];
          if (null != newName)
          {
            // DCA - get rid of whitespaces in front and at the end
            newName = XPStringUtility.Trim(newName);
            // DCA - make sure name is within the database limit
            if (newName.Length > 255)
            {
              newName = XPStringUtility.Substring(newName, 0, 255);
            }
            renameObject(classID, objectID, newName);
          }
        }
        catch (Exception ex)
        {
          log.Warn("Failed renaming object with classID " + classID + " and objectID " + objectID + ": " + ex.Message);
          String message = XPResourceManager.FormatMessage(m_asOwner.GetString(548,
           "ptmsgs_portalinfrastructure"), "Object", newName, ex.Message);
          m_ajaxModel.setMessage(message, STATUS_FAIL);
        }
      }
      return null;
    }
    private int renameObject(int classID, int objectID, String newName)
    {
      IPTPage ptPage = null;
      switch (classID){
      case PT_CLASSIDS.PT_PAGE_ID:
      try
      {
        m_ajaxModel.setObjectId(objectID);
        m_ajaxModel.setClassId(classID);
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        ptPage = (IPTPage) ptSession.GetPages().Open(objectID, false);
        m_ajaxModel.setOldName(ptPage.GetName());
        if (newName.Length > 0 && !ptPage.GetName().Equals(newName))
        {
          ptPage.LockObject();
          ptPage.SetName(newName);
          ptPage.Store();
          ptPage.UnlockObject();
        }
        m_ajaxModel.setNewName(ptPage.GetName());
        String message = XPResourceManager.FormatMessage(m_asOwner.GetString(548,
         "ptmsgs_portalinfrastructure"), "Page", m_ajaxModel.getOldName(),
         m_ajaxModel.getNewName());
        m_ajaxModel.setMessage(message, STATUS_SUCCESS);
      }
      catch (Exception ex)
      {
        log.Warn("Failed renaming page to \'" + newName + "\': " + ex.Message);
        String message = XPResourceManager.FormatMessage(m_asOwner.GetString(549,
         "ptmsgs_portalinfrastructure"), "Page", newName, ex.Message);
        m_ajaxModel.setMessage(message, STATUS_FAIL);
        // DCA - unlock object if it was locked
        if (null != ptPage && ptPage.GetLockState() == PT_LOCKSTATES.PT_LOCKED)
        {
          ptPage.UnlockObject();
        }
        return STATUS_FAIL;
      }
      break;
      case PT_CLASSIDS.PT_MYPAGESCONTAINER_ID:
      try
      {
        m_ajaxModel.setObjectId(objectID);
        m_ajaxModel.setClassId(classID);
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        ptPage = (IPTPage) ptSession.GetPages().Open(objectID, false);
        m_ajaxModel.setOldName(ptPage.GetName());
        if (newName.Length > 0 && !ptPage.GetName().Equals(newName))
        {
          ptPage.LockObject();
          ptPage.SetName(newName);
          ptPage.Store();
          ptPage.UnlockObject();
        }
        m_ajaxModel.setNewName(ptPage.GetName());
        String message = XPResourceManager.FormatMessage(m_asOwner.GetString(548,
         "ptmsgs_portalinfrastructure"), "MyPage", m_ajaxModel.getOldName(),
         m_ajaxModel.getNewName());
        m_ajaxModel.setMessage(message, STATUS_SUCCESS);
      }
      catch (Exception ex)
      {
        log.Warn("Failed renaming myPage to \'" + newName + "\': " + ex.Message);
        String message = XPResourceManager.FormatMessage(m_asOwner.GetString(549,
         "ptmsgs_portalinfrastructure"), "Page", newName, ex.Message);
        m_ajaxModel.setMessage(message, STATUS_FAIL);
        // DCA - unlock object if it was locked
        if (null != ptPage && ptPage.GetLockState() == PT_LOCKSTATES.PT_LOCKED)
        {
          ptPage.UnlockObject();
        }
        return STATUS_FAIL;
      }
      break;
      }
      return STATUS_SUCCESS;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AjaxControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public override void Init(IModel model, AActivitySpace space)
    {
      m_ajaxModel = (AjaxModel) model;
      m_asOwner = space;
    }
  }
}