using System;
using XPStringBuilder=com.plumtree.openfoundation.util.XPStringBuilder;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.ptlink;
namespace com.plumtree.portalpages.ajax
{
  /// <summary>
  /// This class returns the results of an AJAX call.
  /// The response is JSON, not HTML.
  /// </summary>
  /// <author>MattC</author>
  public class AjaxView : IView
  {
    public const String STR_MVC_CLASS_NAME = "AjaxView";
    private AjaxModel m_ajaxModel;
    private AActivitySpace m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new AjaxView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      return null;
    }
    public virtual String DisplayResponse()
    {
      // generate JSON response
      XPStringBuilder buf = new XPStringBuilder(200);
      buf.Append("{");
      buf.Append("oldname:\'").Append(NavigationCommonHelpers.EscapeSingleQuotes(m_ajaxModel.getOldName())).Append("\', ");
      buf.Append("newname:\'").Append(NavigationCommonHelpers.EscapeSingleQuotes(m_ajaxModel.getNewName())).Append("\', ");
      buf.Append("classid:\'").Append(m_ajaxModel.getClassId()).Append("\', ");
      buf.Append("objectid:\'").Append(m_ajaxModel.getObjectId()).Append("\', ");
      buf.Append("status:\'").Append(m_ajaxModel.getStatus()).Append("\', ");
      buf.Append("message:\'").Append(NavigationCommonHelpers.EscapeSingleQuotes(m_ajaxModel.getMessage())).Append("\', ");
      IPTURL refreshURL;
      if (m_ajaxModel.getClassId() == PT_CLASSIDS.PT_MYPAGESCONTAINER_ID)
      {
        refreshURL = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(m_asOwner,
         m_ajaxModel.getObjectId(), m_ajaxModel.getNewName());
      } else
      {
        // DCA - must be a community page
        IPTSession session = (IPTSession) m_asOwner.GetUserSession();
        IPTPageInfo curPage = ((IPTPageManager) session.GetPages()).CachedOpenPageInfo(m_ajaxModel.getObjectId(),
         false, false);
        refreshURL = TaskAPIUICommunity.CreateCommunityPageCommonOpenerURL(m_asOwner,
         curPage.GetContainerObjectID(), curPage.GetObjectID(), m_ajaxModel.getNewName());
        }
      buf.Append("refreshURL:\'").Append(refreshURL.GetFullURL()).Append("\'}");
      return buf.ToString();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_ajaxModel = (AjaxModel) model;
      m_asOwner = parent;
    }
  }
}