using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <author>Don Hayler</author>
  public class DirBreadcrumbView : IView
  {
    public const String STR_MVC_CLASS_NAME = "CatalogFolderBreadcrumb";
    private AActivitySpace m_asOwner;
    private IDirModelRO m_asModel;
    private String m_strControlName = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new DirBreadcrumbView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      //Display the Breadcrumb path, flush left to the margin
      HTMLElementCollection myGroup = new HTMLElementCollection();
      HTMLElement result = myGroup;
      ASURL upFolder = new ASURL(m_asOwner);
      upFolder.SetLinkGetCachedSpace(m_asOwner);
      upFolder.SetDisplayPage(m_asOwner.GetCurrentPage().GetName());
      // if control isn't specified, use default OpenSubFolderControl
      if (null == m_strControlName)
      {
        upFolder.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
      } else
      {
        upFolder.SetControl(m_strControlName);
      }
      upFolder.AddControlArgument(OpenSubFolderControl.m_SubFolderID, XPConvert.ToString(m_asModel.GetParentFolderID()));
      try
      {
        // Bread crumb path
        myGroup.AddInnerHTMLElement(GetBreadcrumbPath().GetPathAsHTMLElement());
        myGroup.AddInnerHTMLElement(new HTMLBr());
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating " + STR_MVC_CLASS_NAME + " Section: " + e.Message + "<BR>");
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#getName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IDirModelRO) model;
      m_asOwner = parent;
    }
    
    /// <param name="strControlName"></param>
    public virtual void SetControlName(String strControlName)
    {
      m_strControlName = strControlName;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    private PTBreadcrumbPath GetBreadcrumbPath()
    {
      PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();
      IASQueryResult qrPath = m_asModel.GetBreadCrumbPath();
      ASURL myURL;
      int nPathCount = qrPath.GetCount();
      for (int i = 0;i < nPathCount;i++)
      {
        int nFolderID = XPConvert.ToInteger(qrPath.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
        String strFolderName = (String) qrPath.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
        String strEncodedPath = XPHttpUtility.HtmlEncode(strFolderName);
        if (i < (nPathCount - 1))
        {
          String strOptArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" + m_asModel.GetDirectoryMode();
          // Open folder URL
          String strOpenFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
           nFolderID, IPTOpenerConstants.OPENER_MODE_VIEW, m_asOwner, m_asOwner.GetName(),
           m_asOwner.GetSpaceID(), strOptArgs);
          HTMLAnchor myAnchor = new HTMLAnchor(strOpenFolderURL);
          myAnchor.SetTitle(strEncodedPath);
          myAnchor.AddInnerHTMLString(strEncodedPath);
          myCrumbs.appendAnchorItem(myAnchor);
        } else
        {
          myCrumbs.appendTextItem(strEncodedPath);
        }
      }
      return myCrumbs;
    }
  }
}