using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <author>
  /// RupaP
  /// Constants for the Directory.
  /// </author>
  public class DirConstants
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.DirConstants");
    // *** Constants ***
    //QueryString arguments
    public const String QS_DIRECTORY_MODE = "DirMode";
    public const String QS_FOLDERPATH = "dirPath";
    public const String QS_CARDID = "cardID";
    public const String QS_ADVANCED_CARDID = "ADVcardID";
    public const String QS_RRCATEGORY = "rrCategory";
    public const String QS_RROBJECTID = "rrObjectID";
    public const String QS_MOREFOLDERID = "moreFolderID";
    public const String QS_RANGE_TO = "rangeTo";
    public const String QS_RANGE_FROM = "rangeFrom";
    /* Query String for displaying Number of Cards per page */
    public const String QS_PER_PAGE = "numCards";
    /* Query String for Displaying Docuument by given Type ID */
    public const String QS_DOCUMENT_TYPEID = "typeID";
    public const String QS_SORTBY = "sortBy";
    public const String QS_PARENT_FOLDER = "ParentFolder";
    public const String QS_SELFSELECT_EXPERT = "addMeExpert";
    public const String QS_RETURN_UPLOAD_PATH = "returnUploadPath";
    public const String QS_RETURN_UPLOAD_ERROR = "returnUploadError";
    public const String QS_RETURN_UPLOAD_TYPE = "returnUploadType";
    public const String QS_RETURN_UPLOAD_DOCID = "returnUploadDocID";
    public const String QS_RETURN_UPLOAD_DUID = "duid";
    public const String QS_RETURN_UPLOAD_DUSERVER = "duserver";
    public const String QS_508_DELETE = "508DeleteCard";
    // Pop-up Page Names
    public const String JAVASCRIPT_SIMPLESUBMIT_DONE = "DirSimpleCardSubmitDone";
    public const String JAVASCRIPT_CARDPROPERTIES_POPUP = "DirCardPropertiesPopup";
    public const String JAVASCRIPT_MORERR_POPUP = "MoreRRPopup";
    public const String JAVASCRIPT_MORERR_CLICKTHROUGH = "MoreRRClickThrough";
    public const String JAVASCRIPT_CARDPROPERTIES_MOREDOCS = "DirCardPropertiesMoreDocs";
    public const String JAVASCRIPT_SENDDOCLINK_POPUP = "SendDocLinkPopup";
    //Directory Modes
    public const int BROWSE_MODE = 1;
    public const int EDIT_MODE = 2;
    public const int DISABILITY_MODE = 3;
    public const int INVALID_MODE = -1;
    // Card Submit Modes
    public const int CARDSUBMITMODE_MAIN = 1;
    public const int CARDSUBMITMODE_UPLOADING = 2;
    public const int CARDSUBMITMODE_DONE = 3;
    //Related Resource Locations
    public const int RELATED_RESOURCE_LOCATION_LEFT = 1;
    public const int RELATED_RESOURCE_LOCATION_RIGHT = 2;
    public const int RELATED_RESOURCE_LOCATION_TOP = 3;
    public const int RELATED_RESOURCE_LOCATION_BOTTOM = 4;
    //Folder Description Type
    public const String DIR_FOLD_DESC_FULL = "FF";
    public const String DIR_FOLD_DESC_ABBR = "FA";
    public const String DIR_FOLD_DESC_NONE = "FN";
    //Document Description Type
    public const String DIR_DOC_DESC_FULL = "DF";
    public const String DIR_DOC_DESC_ABBR = "DA";
    public const String DIR_DOC_DESC_NONE = "DN";
    //Directory Browse By
    public const int BROWSE_BY_SEARCH = 1;
    public const int BROWSE_BY_DATABASE = 2;
    //The maximum number of subfolder links to display below each folder in browse mode
    //Administrator can select the actual number in Directory Preferences
    public const int MAX_NUM_SUB_SUB_FOLDERS_TO_DISPLAY = 5;
    //The maximum number of folder columns in browse mode
    //Administrator can select the actual number in Directory Preferences
    public const int MAX_NUM_FOLDER_COLUMNS = 8;
    //The maximum number of document columns in browse mode
    //Administrator can select the actual number in Directory Preferences
    public const int MAX_NUM_DOCUMENT_COLUMNS = 3;
    public const int DEFAULT_NUMDOCSONPAGE = 20;
    public const int DEFAULT_NUMFOLDERCOLUMNS = 3;
    public const int DEFAULT_NUMSUBSUBFOLDERS = 5;
    public const int DESCRIPTION_ABBR_LENGTH = 100;
    public const int SORTING_NOTSET = 0;
    public const int PROP_COLUMNS_MAX = 3;
    public const int PROP_COLUMNS_INDEX_ID = 0;
    public const int PROP_COLUMNS_INDEX_NAME = 1;
    public const int PROP_COLUMNS_INDEX_TYPE = 2;
    private const String CHINESE_LOCALE_CODE = "zh";
    public int[] m_arRelatedResourceIDs = {PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES,
     PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS, PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS,
     PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS, PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS};
    public bool m_bShowRelatedResources = true;
    public const String BREAK = "<br>";
    private const int URL_MAX_LENGTH = 50;
    private const int LONG_STRING_MAX_LENGTH = 50;
    
    /// <summary>
    /// This is displayed at the top of directory pages.
    /// It shows the breadcrumb for all folders except the root,
    /// </summary>
    public static HTMLTable DisplayBreadcrumbTable(AActivitySpace asOwner)
    {
      IFolderModelRO asFolderModel = (IFolderModelRO) asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);
      HTMLTable table = new HTMLTable();
      table.SetWidth("100%");
      try
      {
        table.SetStyleClass(PTStyleClass.BREADCRUMB_TEXT);
        HTMLTableRow row = new HTMLTableRow();
        table.AddInnerHTMLElement(row);
        HTMLTableCell cell;
        //Breadcrumbs - don't display them in the root folder
        bool bInRootFolder = asFolderModel.InRootFolder();
        if (!bInRootFolder)
        {
          cell = new HTMLTableCell();
          cell.AddInnerHTMLElement(asOwner.GetView(DirBreadcrumbView.STR_MVC_CLASS_NAME).Display());
          row.AddInnerHTMLElement(cell);
        } else
        {
          return null;
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error in DirConstants.DisplayBreadcrumbTable: " + he.Message);
        }
      return table;
    }
    
    /// <summary>
    /// This is displayed below the documents if there are additional documents to view
    /// </summary>
    public static HTMLTable DisplayDocumentLinksTable(AActivitySpace asOwner,
     String _strPrevious, String _strNext, String _strTableSummary)
    {
      IDirModelRO asDirModel = (IDirModelRO) asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);
      int nFolderID = asDirModel.GetCurrentFolderID();
      int nDirMode = asDirModel.GetDirectoryMode();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      try
      {
        // Show pagination links if needed
        int nNumDocsDisplayed = asDirModel.GetObjectCount();
        if (0 < nNumDocsDisplayed)
        {
          bool bShowLinks = false;
          // Create the table, but only add it to the page if there are links
          myTable = new HTMLTable();
          myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          myTable.SetCellPadding("2");
          myTable.SetCellSpacing("2");
          myTable.SetSummary(_strTableSummary);
          myRow = new HTMLTableRow();
          //todo: set to 508 style
          myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);
          myCell.SetAlign(CommonHTMLStrings.RIGHT);
          myRow.AddInnerHTMLElement(myCell);
          int nBeginID = asDirModel.GetCardRangeBegin();
          int nEndID = (nBeginID + nNumDocsDisplayed) - 1;
          int nTotalCount = asDirModel.GetTotalResults();
          int nNumDocsPerPage = asDirModel.GetNumDocsPerPage();
          // Show "Prev" link
          if (1 != nBeginID)
          {
            bShowLinks = true;
            int nPrevBegin = nBeginID - nNumDocsPerPage;
            int nPrevEnd = nBeginID - 1;
            if (1 > nPrevBegin)
            {
              nPrevBegin = 1;
            }
            ASURL myURL = new ASURL(asOwner);
            myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, asOwner);
            myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
            myURL.AddControlArgument(DirConstants.QS_RANGE_FROM, nPrevBegin);
            myURL.AddControlArgument(DirConstants.QS_RANGE_TO, nPrevEnd);
            myURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID, nFolderID);
            myURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, nDirMode);
            myAnchor = new HTMLAnchor(myURL.GetURLAsString());
            int nNumDocsInRange = nPrevEnd - nPrevBegin + 1;
            String strPrevious = "<-" + CommonHTMLStrings.SPACE + XPResourceManager.FormatMessage(_strPrevious,
             XPConvert.ToString(nNumDocsInRange));
            myAnchor.AddInnerHTMLString(strPrevious);
            myAnchor.SetTitle(strPrevious);
            myCell.AddInnerHTMLElement(myAnchor);
          }
          // Show "Next" link
          if (nEndID != nTotalCount)
          {
            bShowLinks = true;
            int nNextBegin = nEndID + 1;
            int nNextEnd = nEndID + nNumDocsPerPage;
            if (nTotalCount < nNextEnd)
            {
              nNextEnd = nTotalCount;
            }
            ASURL myURL = new ASURL(asOwner);
            myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, asOwner);
            myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
            myURL.AddControlArgument(DirConstants.QS_RANGE_FROM, nNextBegin);
            myURL.AddControlArgument(DirConstants.QS_RANGE_TO, nNextEnd);
            myURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID, nFolderID);
            myURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, nDirMode);
            myAnchor = new HTMLAnchor(myURL.GetURLAsString());
            int nNumDocsInRange = nNextEnd - nNextBegin + 1;
            String strNext = XPResourceManager.FormatMessage(_strNext, XPConvert.ToString(nNumDocsInRange)) + CommonHTMLStrings.SPACE + "->";
            myAnchor.AddInnerHTMLString(strNext);
            myAnchor.SetTitle(strNext);
            myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
            myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
            myCell.AddInnerHTMLElement(myAnchor);
          }
          if (bShowLinks)
          {
            return myTable;
          } else
          {
            return null;
          }
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error in DirConstants.DisplayDocumentLinksTable.");
        }
      return null;
    }
    public static HTMLImg CreateSpacerImage(int nHeight, int nWidth)
    {
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetWidth(XPConvert.ToString(nWidth));
      myImage.SetHeight(XPConvert.ToString(nHeight));
      myImage.SetBorder("0");
      return myImage;
    }
    
    /// <param name="nColSpan"></param>
    /// <param name="nHeight"></param>
    /// <returns></returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableRow CreateSpacerRow(int nColSpan, int nHeight)
    {
      HTMLTableRow row = new HTMLTableRow();
      HTMLTableCell cell = new HTMLTableCell();
      cell.SetColSpan(XPConvert.ToString(nColSpan));
      cell.SetHeight(XPConvert.ToString(nHeight));
      row.AddInnerHTMLElement(cell);
      return row;
    }
    
    /// <summary>
    /// Helper method: returns empty table.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public static HTMLElement CreateSpacerTable(int nHeight, int nWidth)
    {
      HTMLElementCollection myResult = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Spacer table");
        myResult.AddInnerHTMLElement(myComment);
        myTable = new HTMLTable();
        myResult.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // 1st Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLElement(CreateSpacerImage(nHeight, nWidth));
        myComment = new HTMLComment("End: Spacer table");
        myResult.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        log.Error(e, "EditorDP::GetSpacerTable The following error occured when trying to display the HTML: " + e.Message);
        }
      return myResult;
    }
    
    /// <summary>
    /// Inxight languages are specified as a two character string (like "en" or "fr"),
    /// with the exception of the chinese languages which can be "zh-TW" or "zh-CN"
    /// </summary>
    public static String TrimCardLanguage(String strLanguage)
    {
      if (strLanguage.Length == 2)
      {
        return XPStringUtility.ToLowerCase(strLanguage);
      } else
      if (strLanguage.Length > 2)
      {
        String strFirstTwoCharacters = XPStringUtility.Substring(strLanguage,
         0, 2);
        if (0 == XPStringUtility.CompareIgnoreCase(strFirstTwoCharacters,
         CHINESE_LOCALE_CODE))
        {
          return strLanguage;
        } else
        {
          return XPStringUtility.ToLowerCase(strFirstTwoCharacters);
        }
      } else
      {
        return strLanguage;
      }
    }
    
    /// <param name="strURL"></param>
    /// <returns></returns>
    public static String BreakUpStringAndHTMLEncode(String strURL)
    {
      return BreakUpStringAndHTMLEncode(strURL, URL_MAX_LENGTH);
    }
    
    /// <param name="strURL"></param>
    /// <returns></returns>
    public static String BreakUpStringAndHTMLEncode(String strURL, int nLength)
    {
      if (strURL.Length > nLength)
      {
        String strNewString = XPHttpUtility.HtmlEncode(XPStringUtility.Substring(strURL,
         0, nLength));
        String strLeft = XPStringUtility.Substring(strURL, nLength);
        while (strLeft.Length > 0)
        {
          if (strLeft.Length > nLength)
          {
            strNewString = strNewString + BREAK + XPHttpUtility.HtmlEncode(XPStringUtility.Substring(strLeft,
             0, nLength));
            strLeft = XPStringUtility.Substring(strLeft, nLength);
          } else
          {
            strNewString = strNewString + BREAK + XPHttpUtility.HtmlEncode(strLeft);
            break;
          }
        }
        return strNewString;
      } else
      {
        return XPHttpUtility.HtmlEncode(strURL);
      }
    }
    
    /// <param name="strURL"></param>
    /// <returns></returns>
    public static String BreakUpLongWordsInStringAndHTMLEncode(String strURL)
    {
      return BreakUpLongWordsInStringAndHTMLEncode(strURL, LONG_STRING_MAX_LENGTH);
      }
    
    /// <param name="strURL"></param>
    /// <returns></returns>
    public static String BreakUpLongWordsInStringAndHTMLEncode(String str,
     int nLength)
    // SCC: This method iterates through a String and breaks up long words into smaller words
    {
      try
      {
        int nStringLength = str.Length;
        if (nStringLength > nLength)
        {
          XPStringBuilder sb = new XPStringBuilder();
          int nOldPos = 0;
          int nSpacePos = 0;
          while (nSpacePos != -1)
          {
            nSpacePos = XPStringUtility.IndexOf(str, " ", nOldPos);
            // no spaces left
            if (-1 == nSpacePos)
            {
              // last word too long
              if (nStringLength - nOldPos > nLength)
              {
                sb.Append(XPHttpUtility.HtmlEncode(XPStringUtility.Substring(str,
                 nOldPos, nOldPos + nLength)));
                sb.Append(BREAK);
                nOldPos = nOldPos + nLength;
                nSpacePos = 0;
              } else
              {
                sb.Append(XPHttpUtility.HtmlEncode(XPStringUtility.Substring(str,
                 nOldPos)));
                break;
              }
            } else
            // break up the word if too long
            if (nSpacePos - nOldPos > nLength)
            {
              sb.Append(XPHttpUtility.HtmlEncode(XPStringUtility.Substring(str,
               nOldPos, nOldPos + nLength)));
              sb.Append(BREAK);
              nOldPos = nOldPos + nLength;
            } else
            // add the word to the final String
            {
              sb.Append(XPHttpUtility.HtmlEncode(XPStringUtility.Substring(str,
               nOldPos, nSpacePos + 1)));
              nOldPos = nSpacePos + 1;
            }
          }
          return sb.ToString();
        } else
        {
          return XPHttpUtility.HtmlEncode(str);
        }
      }
      catch (Exception e)
      {
        return str;
      }
    }
  }
}