using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.serversettings.search;
using com.plumtree.portalpages.browsing.directory.edit;
using com.plumtree.portalpages.browsing.editors.dircommon;
using ITaggingModel=com.plumtree.portaluiinfrastructure.pathways.tagging.ITaggingModel;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.editor.commonpages.keywords;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.search.exceptions;
using com.plumtree.portaluiinfrastructure.statichelpers;
using HashtableDataObject=com.plumtree.portaluiinfrastructure.tags.data.HashtableDataObject;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.form.sort;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <summary>
  /// This model contains data for both the Browse and Edit Modes of the
  /// Directory.
  /// </summary>
  /// <author>StephenC</author>
  public class DirModel : AClearModel,IDirModelRO,ISortModelRO,IRepostModel,
  IDirModel,ITaggingModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.DirModel");
    
    /// <summary>
    /// Activity space name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "Dir";
    public const String HTTP_PREFIX = "http://";
    public const String ENGLISH_LOCALE_CODE = "en";
    public const String CHINESE_LANGUAGE_CODE = "zh";
    public const String CHINESE_LOCALE_CODE_CN = "CN";
    public const String CHINESE_LOCALE_CODE_TW = "TW";
    public const String CHINESE_LOCALE_CODE_HK = "HK";
    public const String CHINESE_LOCALE_CODE_MO = "MO";
    public const String CHINESE_LOCALE_CODE_SG = "SG";
    public const String DEFAULTDATA = "Default Data";
    public const String strDataSourceTREESUBSPACE = "DataSourceTreeSubSpace";
    public const String strMoveTargetFolderTREESUBSPACE = "MoveTargetFolderTreeSubSpace";
    public const String strCopyTargetFolderTREESUBSPACE = "CopyTargetFolderTreeSubSpace";
    public const int HEADER_PROPERTIES_SIZE = 3;
    public const int HEADER_NAME_INDEX = 0;
    public const int HEADER_SORT_URL_INDEX = 1;
    public const int HEADER_ID_INDEX = 2;
    // This is read from a server config setting
    private static String m_strDefaultInxightLanguage = "en";
    public int m_nCurrentFolderID;
    
    /// <summary>
    /// For Card Properties *
    /// </summary>
    public int m_nCurrentCardID = -1;
    
    /// <summary>
    /// For Advanced Card Submission to prevent Card Confirmation page from being displayed more than once if the page is refreshed. *
    /// </summary>
    public int m_nLoadedCardID = -1;
    // moved initialization into the constructore to accomodate j2c tool
    
    /// <summary>
    /// Directory mode - Browse, Edit, Disability 
    /// </summary>
    protected int m_nDirMode = 0;
    private IPTSession m_ptSession = null;
    private int m_nNumDocsPerPage = 0;
    private int[] m_nABOJobIDs;
    private XPHashtable m_objDocsTags = null;
    
    /// <summary>
    /// whether or not there are folders to be deleted. 
    /// </summary>
    private bool m_bFoldersForDeleteCheck;
    // positive for ascending and negative for descending
    // moved initialization into the constructore to accomodate j2c tool
    private int m_nSortingPropertyID = 0;
    
    /// <summary>
    /// For Simple Card Submission *
    /// </summary>
    private String m_strCSSelectedURL = null;
    private String m_strCSCardName = null;
    private String m_strCSCardDescription = null;
    // For REST API submissions with a folder override.
    // -1 means use the current folder.
    private int m_nCSCardFolder = -1;
    // For errors in the REST API submissions.
    // -1 means no error.
    private int m_nCSError = -1;
    /* positive if there needs to be filter on DocumentType */
    private int m_nDocumentTypeId = -1;
    private int m_nCSSelectedDataSource = -1;
    
    /// <summary>
    /// warnings returned after executing a search request
    /// used to inform about a user  "partial results" and timeouts
    /// </summary>
    private SearchExecutionWarning _warning = null;
    /* for file upload */
    private String m_duID = null;
    private String m_duServer = null;
    // This flag determines whether ClearTempData should clear m_strCSSelectedURL
    private bool m_bCSSaveURL = false;
    // Config Var Pack values (never changes during the life of the application)
    private static int s_nNumDaysToDisplayNewTag = -1;
    private static int s_nNumDaysToDisplayUpdatedTag = -1;
    private static bool s_bSubfolderQueryThroughSearch = false;
    
    /// <summary>
    /// Card Submission Mode (used to determine which View to display 
    /// </summary>
    private int m_nCardSubmitMode = 1;
    // SCC: The following three used to be stored in the TempData, but it was too costly on performance to be retrieved every t
    
    /// <summary>
    /// Sorting Columns *
    /// </summary>
    public XPArrayList m_xpPropColumns = null;
    
    /// <summary>
    /// New Document Date *
    /// </summary>
    public XPDateTime m_xpNewTagDate;
    
    /// <summary>
    /// Updated Document Date *
    /// </summary>
    public XPDateTime m_xpUpdateTagDate;
    
    /// <summary>
    /// Document Range 
    /// </summary>
    public int m_nRangeBegin = -1;
    public int m_nRangeEnd = -1;
    
    /// <summary>
    /// User Pref settings 
    /// </summary>
    public bool m_bOpenDocInNewWindow = false;
    
    /// <summary>
    /// Settable Dir Pref *
    /// </summary>
    public int m_nNumFoldCol = DirConstants.DEFAULT_NUMFOLDERCOLUMNS;
    
    /// <summary>
    /// index for object range array returned via GetObjectRange() 
    /// </summary>
    public const int BEGIN_INDEX = 0;
    public const int END_INDEX = 1;
    public const int CARD_CNT = 2;
    public const int TOTAL_CNT_INDEX = 3;
    // This array list does not need to be managed as type of the property
    //    cannot be changed. 
    private static XPHashtable m_xpDateProps = null;
    private static int m_nLastCheckedPropID = 0;
    private static int m_nLastCheckedPropType = 0;
    private XPException m_taggingError;
    public DirModel() : base()
    {
      m_nDirMode = DirConstants.BROWSE_MODE;
      m_nSortingPropertyID = DirConstants.SORTING_NOTSET;
      m_nCardSubmitMode = DirConstants.CARDSUBMITMODE_MAIN;
      if (null == m_xpDateProps)
      {
        m_xpDateProps = new XPHashtable();
      }
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTConfigVarPack vpPTConfig = (PTConfigVarPack) application.GetVarPackManager().GetVariablePackage(PTConfigVarPack.VARPACK_ID);
      try
      {
        s_nNumDaysToDisplayUpdatedTag = vpPTConfig.GetConfigValueAsInt("Documents",
         "DocumentLastUpdated", "value");
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get config value for DocumentLastUpdated.  Defaulting to 7.");
        // Default to 7.
        s_nNumDaysToDisplayUpdatedTag = 7;
      }
      try
      {
        s_nNumDaysToDisplayNewTag = vpPTConfig.GetConfigValueAsInt("Documents",
         "NewDocumentTime", "value");
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get config value for NewDocumentTime.  Defaulting to 7.");
        // Default to 7.
        s_nNumDaysToDisplayNewTag = 7;
      }
      try
      {
        s_bSubfolderQueryThroughSearch = (1 == vpPTConfig.GetConfigValueAsInt("Documents",
         "SubFolderBrowseThroughSearch", "value"));
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get config value for SubFolderBrowseThroughSearch.  Defaulting to 0.");
        // Default to 0.
        s_bSubfolderQueryThroughSearch = false;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#ABODeleteFolders(int[])
     */
     
    public virtual void ABODeleteFolders(int[] arFolderIDs)
    {
      try
      {
        // JF- Error messages from all PEIs for all folders
        String sErrorMsgs = "";
        IApplication application = m_asOwner.GetApplication();
        Object[] oDirectoryActions = (Object[]) application.GetCachingManager().GetEntry("DirectoryActions");
        int nNumFolders = arFolderIDs.Length;
        m_nABOJobIDs = new int[nNumFolders];
        for (int i = 0;i < nNumFolders;i++)
        {
          //PEI : IDirectoryActions : OnBeforeCreateABOJob - BEGIN
          //JF- Implementation of the OnBeforeCreateABOJob function of the IDirectoryActions
          //For each folder being scheduled to be deleted, the OnBeforeCreateABOJob function 
          //will be processed to see if the folder and its corresponding objects should be deleted. 
          //This will only be done if there are implemented IDirectoryActions functions otherwise the normal
          //processing will occur. The normal processing will also occur if no errors are returned.
          if (oDirectoryActions != null)
          {
            // JF- Error messages from all PEIs for the current folder
            String sObjectErrorMsgs = "";
            Object oDirectoryAction;
            IDirectoryActions iAction;
            for (int x = 0;x < oDirectoryActions.Length;x++)
            {
              oDirectoryAction = oDirectoryActions[x];
              log.Debug("DirModel.ABODeleteFolders - About to call OnBeforeCreateABOJob on an: " + oDirectoryAction);
              if (oDirectoryAction != null)
              {
                String sError;
                iAction = (IDirectoryActions) oDirectoryAction;
                sError = iAction.OnBeforeCreateABOJob(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                 PT_CLASSIDS.PT_CATALOGFOLDER_ID, arFolderIDs[i]);
                if ((null != sError) && (sError.Length > 0))
                {
                  sObjectErrorMsgs+=sError + " ";
                }
              }
            }
            if ((null != sObjectErrorMsgs) && (sObjectErrorMsgs.Length > 0))
            {
              sErrorMsgs+=sObjectErrorMsgs + " ";
            } else
            {
              m_nABOJobIDs[i] = CreateABOJobToDeleteFolder(arFolderIDs[i]);
              //PEI : IDirectoryActions : OnAfterCreateABOJob - BEGIN
              for (int z = 0;z < oDirectoryActions.Length;z++)
              {
                oDirectoryAction = oDirectoryActions[z];
                log.Debug("DirModel.ABODeleteFolders - About to call OnAfterCreateABOJob on an: " + oDirectoryAction);
                if (oDirectoryAction != null)
                {
                  iAction = (IDirectoryActions) oDirectoryAction;
                  iAction.OnAfterCreateABOJob(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                   m_nABOJobIDs[i], PT_CLASSIDS.PT_CATALOGFOLDER_ID, arFolderIDs[i]);
                  }
              }
            }
          } else
          //PEI : IDirectoryActions : OnAfterCreateABOJob - END
          //PEI : IDirectoryActions : OnBeforeCreateABOJob - END
          {
            m_nABOJobIDs[i] = CreateABOJobToDeleteFolder(arFolderIDs[i]);
            }
        }
        if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
        {
          RaiseError(sErrorMsgs);
        }
      }
      catch (XPException xpe)
      {
        throw new XPException(STR_MVC_CLASS_NAME + "::DeleteFolders Error when deleting folders" + xpe.GetMessage(),
         xpe);
      }
    }
    
    /// <summary>
    /// Helper method to create the ABO Job for the Folder.
    /// </summary>
    /// <param name="_nFolderID"></param>
    /// <returns>int - ABO Job ID</returns>
    private int CreateABOJobToDeleteFolder(int _nFolderID)
    {
      IPTFolder ptFolder = m_ptSession.GetCatalog().OpenFolder(_nFolderID,
       false);
      ptFolder.ScheduleRecursiveAction(PT_CONTAINER_OPERATIONS.PT_CONTAINER_JOB_DELETEFOLDER);
      IPTScheduledOperation ptOp = (IPTScheduledOperation) ptFolder;
      return ptOp.ScheduleImmediateJob();
    }
    public virtual bool ABOJobIDsToDisplay()
    {
      if (m_nABOJobIDs.Length > 0)
      {
        for (int i = 0;i < m_nABOJobIDs.Length;i++)
        {
          if (m_nABOJobIDs[i] != -1)
          {
            return true;
          }
        }
      }
      return false;
    }
    // Add Self-Selected Related Expert
    public virtual void AddSelfSelectedRelatedExpert()
    {
      try
      {
        DirTempData td = (DirTempData) GetTempData();
        // Add the Current User as a Related Expert
        td.m_ptCurrentFolder.AddUserAsRelatedExpert();
        IPTCatalog ptCatalog = m_ptSession.GetCatalog();
        td.m_ptCurrentFolder = ptCatalog.OpenFolder(m_nCurrentFolderID, false);
        }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1220, "ptmsgs_portalbrowsingmsgs"), e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <returns></returns>
    public virtual bool CheckFoldersForDelete()
    {
      return m_bFoldersForDeleteCheck;
    }
    
    /// <param name="nActivityRight"></param>
    /// <returns></returns>
    public virtual bool CheckForActivityRight(int nActivityRight)
    {
      IPTSessionInfo ptSessionInfo = m_ptSession.GetSessionInfo();
      return ptSessionInfo.CheckForActivityRight(nActivityRight);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public override void CleanupTempData()
    {
      DirTempData data = (DirTempData) GetTempData();
      if (data != null)
      {
        // The search results hold onto lots of native memory,
        // which we need to cleanup as soon as possible, rather
        // than waiting for the garbage collection to do it.
        if (data.m_srSubFolders != null)
        {
          data.m_srSubFolders.Clear();
        }
        if (data.m_ptSearchDocuments != null)
        {
          data.m_ptSearchDocuments.Clear();
        }
      }
      base.CleanupTempData();
      // Reset Card Submit URL and Mode if not being used
      if (false == m_bCSSaveURL)
      {
        m_strCSSelectedURL = null;
        m_strCSCardName = null;
        m_strCSCardDescription = null;
        m_nCSSelectedDataSource = -1;
        m_nCSCardFolder = -1;
        m_nCSError = -1;
        m_nCardSubmitMode = DirConstants.CARDSUBMITMODE_MAIN;
      } else
      {
        // If a POSTTOSELF_ACTION_CARDSIMPLESUBMIT_CHANGED_DS repost occurs, then this value will be set to true again
        m_bCSSaveURL = false;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#CopyCards(int[], int)
     */
     
    public virtual void CopyCards(int[] arCardIDs, int nTargetFolder)
    {
      try
      {
        Object[] aResults = m_ptSession.GetCatalog().AddMultipleCardsToFolder(arCardIDs,
         
        // just like 4.5ws, move as approved and bAddOnlyAtSpecifiedApprovalState = false
        nTargetFolder, PT_CARDREF_STATES.PT_APPROVED, false);
        for (int i = 0;i < aResults.Length;i++)
        {
          if (PT_RESULTCODES.PT_E_ACCESSDENIED == XPConvert.ToInteger(aResults[i]))
          {
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, m_asOwner.GetString(2023, "ptmsgs_portalbrowsingmsgs"),
             "");
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
          }
        }
      }
      catch (PTException pte)
      {
        RaiseError(m_asOwner.GetString(1731, "ptmsgs_portalbrowsingmsgs"),
         pte.GetMessage());
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#CopyFolders(int[], int)
     */
     
    public virtual void CopyFolders(int[] arFolderIDs, int nTargetFolder)
    {
      String sErrorMsgs = "";
      String sExtendedErrorMsgs = "";
      int nNumFolders = arFolderIDs.Length;
      for (int i = 0;i < nNumFolders;i++)
      {
        int nFolderID = arFolderIDs[i];
        try
        {
          m_ptSession.GetCatalog().CopyFolder(nFolderID, nTargetFolder, 
          // recursive and cards are also copied
          true, true);
        }
        catch (PTException pte)
        {
          String strUIErrorString = "";
          try
          {
            String strFolderName = m_ptSession.GetCatalog().OpenFolder(nFolderID,
             false).GetLocalizedName();
            strUIErrorString = XPResourceManager.FormatMessage(m_asOwner.GetString(1728,
             "ptmsgs_portalbrowsingmsgs"), strFolderName) + "  ";
          }
          catch (PTException ptex)
          {
            strUIErrorString = XPResourceManager.FormatMessage(m_asOwner.GetString(1735,
             "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nFolderID)) + "  ";
            }
          sErrorMsgs+=strUIErrorString;
          sExtendedErrorMsgs+=pte.GetMessage() + "  ";
        }
      }
      if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
      {
        RaiseError(sErrorMsgs, sExtendedErrorMsgs);
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DirModel();
    }
    
    /// <summary>
    /// Creates a Directory Folder
    /// </summary>
    /// <param name="strName">Folder Name</param>
    /// <param name="strDescription">Folder Description</param>
    /// <returns>int - Returns the ID of the new folder</returns>
    private int CreateDirectoryFolderHelper(String strName, String strDescription)
    {
      IPTFolder ptFolder = (IPTFolder) m_ptSession.GetCatalog().CreateFolder(m_nCurrentFolderID);
      ptFolder.SetName(strName);
      ptFolder.SetDescription(strDescription);
      ptFolder.SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PUT_CARDS_HERE,
       1);
      ptFolder.SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_DEFAULT_SUBFOLDERID,
       PT_INTRINSICS.PT_NULL_OBJECTID);
      // check the search server first, if it is up, then index, 
      // otherwise don't and display an warning to the user
      IXPPropertyBag statusBag = m_ptSession.GetCatalog().GetSearchServerStatus();
      SearchServerStatusInfo statusInfo = new SearchServerStatusInfo(statusBag,
       "INDEXSTATUS");
      if (XPStringUtility.EqualsIgnoreCase(statusInfo.connectStatus, "OK"))
      {
        ptFolder.SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_INDEXONSTORE, 1);
        } else
      {
        ptFolder.SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_INDEXONSTORE, 0);
        RaiseError(m_asOwner.GetString(1813, "ptmsgs_portalbrowsingmsgs"));
        }
      IPTServerContext ptSC = (IPTServerContext) ptFolder;
      ptSC.Store();
      ptSC.UnlockObject();
      DirTempData td = (DirTempData) GetTempData();
      td.m_nCreatedFolderID = ptSC.GetObjectID();
      return td.m_nCreatedFolderID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#CreateDirectoryFolder(java.lang.String, java.lang.String)
     */
     
    public virtual void CreateDirectoryFolder(String strName, String strDescription)
    {
      Object oDirectoryAction;
      IDirectoryActions iAction;
      try
      {
        IApplication application = m_asOwner.GetApplication();
        Object[] oDirectoryActions = (Object[]) application.GetCachingManager().GetEntry("DirectoryActions");
        if (oDirectoryActions != null)
        {
          int nNewFolderID;
          String sErrorMsgs = "";
          //PEI : IDirectoryActions - BEGIN
          //JF- Implementation of the OnBeforeCreateDirectoryFolder function of the IDirectoryActions
          //For the folder being created, the OnBeforeDeleteDirectoryFolder function will be processed
          //to see if the folder should be created. This will
          //only be done if there are implemented IDirectoryActions functions otherwise the normal
          //processing will occur. The normal processing will also occur if no errors are returned.
          for (int x = 0;x < oDirectoryActions.Length;x++)
          {
            oDirectoryAction = oDirectoryActions[x];
            log.Debug("DirModel.CreateDirectoryFolderAndCallPEIs - " + "About to call OnBeforeDeleteDirectoryFolder on an: " + oDirectoryAction);
            if (oDirectoryAction != null)
            {
              String sError;
              iAction = (IDirectoryActions) oDirectoryAction;
              sError = iAction.OnBeforeCreateDirectoryFolder(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
               strName, strDescription);
              if ((null != sError) && (sError.Length > 0))
              {
                sErrorMsgs+=sError + " ";
              }
            }
          }
          // PEI : IDirectoryActions - END
          if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
          {
            RaiseError(sErrorMsgs);
            return;
          } else
          {
            nNewFolderID = CreateDirectoryFolderHelper(strName, strDescription);
            }
          //PEI : IDirectoryActions - BEGIN
          //JF- Implementation of the OnAfterCreateDirectoryFolder function of the IDirectoryActions
          //For the folder being created, the OnAfterCreateDirectoryFolder function will be processed
          //to execute some code after the deletion. This will
          //only be done if there are implemented IDirectoryActions functions otherwise the normal
          //processing will occur. 
          for (int x = 0;x < oDirectoryActions.Length;x++)
          {
            oDirectoryAction = oDirectoryActions[x];
            log.Debug("DirModel.CreateDirectoryFolderAndCallPEIs - About to call OnAfterCreateDirectoryFolder on an: " + oDirectoryAction);
            if (oDirectoryAction != null)
            {
              iAction = (IDirectoryActions) oDirectoryAction;
              iAction.OnAfterCreateDirectoryFolder(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
               nNewFolderID);
            }
          }
        } else
        //PEI : IDirectoryActions - END	
        {
          CreateDirectoryFolderHelper(strName, strDescription);
        }
      }
      catch (Exception e)
      {
        throw new XPException(STR_MVC_CLASS_NAME + "::CreateDirectoryFolderAndCallPEIs Error when creating folder" + e.Message,
         e);
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#DeleteCards(int[])
     */
     
    public virtual void DeleteCards(int[] arCardIDs)
    {
      Object oDirectoryAction;
      IDirectoryActions iAction;
      Object[] deleteResults = null;
      try
      {
        // JF- Error messages from all PEIs for all cards
        String sErrorMsgs = "";
        IApplication application = m_asOwner.GetApplication();
        Object[] oDirectoryActions = (Object[]) application.GetCachingManager().GetEntry("DirectoryActions");
        if (oDirectoryActions != null)
        {
          for (int i = 0;i < arCardIDs.Length;i++)
          {
            // JF- Error messages from all PEIs for the current card
            String sObjectErrorMsgs = "";
            //PEI : IDirectoryActions - BEGIN
            //JF- Implementation of the OnBeforeDeleteDocument function of the IDirectoryActions
            //For each document being deleted, the OnBeforeDeleteDocument function will be processed
            //to see if the document should be deleted. This will
            //only be done if there are implemented IDirectoryActions functions otherwise the normal
            //processing will occur. The normal processing will also occur if no errors are returned.
            for (int x = 0;x < oDirectoryActions.Length;x++)
            {
              oDirectoryAction = oDirectoryActions[x];
              log.Debug("DirModel.DeleteCards - About to call OnBeforeDeleteDocument on an: " + oDirectoryAction);
              if (oDirectoryAction != null)
              {
                String sError;
                iAction = (IDirectoryActions) oDirectoryAction;
                sError = iAction.OnBeforeDeleteDocument(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                 arCardIDs[i]);
                if ((null != sError) && (sError.Length > 0))
                {
                  sObjectErrorMsgs+=sError + " ";
                }
              }
            }
            if ((null != sObjectErrorMsgs) && (sObjectErrorMsgs.Length > 0))
            {
              sErrorMsgs+=sObjectErrorMsgs + " ";
            } else
            {
              deleteResults = m_ptSession.GetCatalog().RemoveCards(m_nCurrentFolderID,
               arCardIDs[i]);
            }
          }
        } else
        // PEI : IDirectoryActions - END
        {
          deleteResults = m_ptSession.GetCatalog().RemoveCards(m_nCurrentFolderID,
           arCardIDs);
        }
        // test to see if there were problems deleting cards (bug 58004)
        if (null != deleteResults)
        {
          for (int i = 0;i < deleteResults.Length;i++)
          {
            String deleteResult = (String) deleteResults[i];
            // if this is anything other than an empty string raise an error
            if (XPStringUtility.Compare(deleteResult, "") != 0)
            {
              RaiseError(m_asOwner.GetString(1942, "ptmsgs_portalbrowsingmsgs"));
              break;
            }
          }
        }
        if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
        {
          RaiseError(sErrorMsgs);
        }
      }
      catch (PTException pte)
      {
        RaiseError(m_asOwner.GetString(1730, "ptmsgs_portalbrowsingmsgs"),
         pte.GetMessage());
      }
    }
    
    /// <summary>
    /// Helper method to raise an error
    /// </summary>
    /// <param name="strError">- Error message</param>
    /// <param name="strError">- Extended error message</param>
    public virtual void RaiseError(String strError, String strExtended)
    {
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       strError, strExtended);
      myError.SetActivitySpace(m_asOwner.GetName());
      myError.SetDisplayOnSeparatePage(false);
      myError.SetClearWithActivitySpaceChange(true);
      myError.SetImmediateClear(true);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      }
    
    /// <summary>
    /// Helper method to raise an error
    /// </summary>
    /// <param name="strError">- Error message</param>
    public virtual void RaiseError(String strError)
    {
      RaiseError(strError, strError);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#DeleteFolders(int[])
     */
     
    public virtual void DeleteFolders(int[] arFolderIDs)
    {
      Object oDirectoryAction;
      IDirectoryActions iAction;
      try
      {
        // SCC: all error messages: PEI or not
        String sErrorMsgs = "";
        String sExtendedErrorMsgs = "";
        IApplication application = m_asOwner.GetApplication();
        Object[] oDirectoryActions = (Object[]) application.GetCachingManager().GetEntry("DirectoryActions");
        for (int i = 0;i < arFolderIDs.Length;i++)
        {
          int nFolderToDeleteID = arFolderIDs[i];
          if (oDirectoryActions != null)
          {
            // JF- Error messages from all PEIs for the current folder
            String sObjectErrorMsgs = "";
            //PEI : IDirectoryActions - BEGIN
            //JF- Implementation of the OnBeforeDeleteDirectoryFolder function of the IDirectoryActions
            //For each folder being deleted, the OnBeforeDeleteDirectoryFolder function will be processed
            //to see if the document should be deleted. This will
            //only be done if there are implemented IDirectoryActions functions otherwise the normal
            //processing will occur. The normal processing will also occur if no errors are returned.
            for (int x = 0;x < oDirectoryActions.Length;x++)
            {
              oDirectoryAction = oDirectoryActions[x];
              log.Debug("DirModel.DeleteFolders - About to call OnBeforeDeleteDirectoryFolder on an: " + oDirectoryAction);
              if (oDirectoryAction != null)
              {
                String sError;
                iAction = (IDirectoryActions) oDirectoryAction;
                sError = iAction.OnBeforeDeleteDirectoryFolder(m_asOwner,
                 (IPTSession) m_asOwner.GetUserSession(), nFolderToDeleteID);
                if ((null != sError) && (sError.Length > 0))
                {
                  sObjectErrorMsgs+=sError + " ";
                }
              }
            }
            // PEI : IDirectoryActions - END
            if ((null != sObjectErrorMsgs) && (sObjectErrorMsgs.Length > 0))
            {
              sErrorMsgs+=sObjectErrorMsgs + " ";
            } else
            {
              try
              {
                // recursive
                m_ptSession.GetCatalog().DeleteFolder(nFolderToDeleteID, true);
                //PEI : IDirectoryActions - BEGIN
                //JF- Implementation of the OnAfterDeleteDirectoryFolder function of the IDirectoryActions
                //For each folder being deleted, the OnAfterDeleteDirectoryFolder function will be processed
                //to execute some code after the deletion. This will
                //only be done if there are implemented IDirectoryActions functions otherwise the normal
                //processing will occur. The normal processing will also occur if no errors are returned.
                for (int x = 0;x < oDirectoryActions.Length;x++)
                {
                  oDirectoryAction = oDirectoryActions[x];
                  log.Debug("DirModel.DeleteFolders - About to call OnAfterDeleteDirectoryFolder on an: " + oDirectoryAction);
                  if (oDirectoryAction != null)
                  {
                    iAction = (IDirectoryActions) oDirectoryAction;
                    iAction.OnAfterDeleteDirectoryFolder(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                     nFolderToDeleteID);
                  }
                }
              }
              //PEI : IDirectoryActions - END	
              catch (PTException pte)
              {
                //check and see if the folder has already been deleted...
                if (PT_RESULTCODES.PT_E_ACCESSDENIED == pte.GetErrorCode())
                {
                  sErrorMsgs+=m_asOwner.GetString(1721, "ptmsgs_portalbrowsingmsgs") + "  ";
                  } else
                {
                  String strUIErrorString = "";
                  try
                  {
                    String strFolderName = m_ptSession.GetCatalog().OpenFolder(nFolderToDeleteID,
                     false).GetLocalizedName();
                    strUIErrorString = XPResourceManager.FormatMessage(m_asOwner.GetString(1727,
                     "ptmsgs_portalbrowsingmsgs"), strFolderName) + "  ";
                    }
                  catch (PTException ptex)
                  {
                    strUIErrorString = XPResourceManager.FormatMessage(m_asOwner.GetString(1734,
                     "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nFolderToDeleteID)) + "  ";
                    }
                  sErrorMsgs+=strUIErrorString;
                  sExtendedErrorMsgs+=pte.GetMessage() + "  ";
                }
              }
            }
          } else
          {
            try
            {
              // recursive
              m_ptSession.GetCatalog().DeleteFolder(nFolderToDeleteID, true);
              }
            catch (PTException pte)
            {
              //check and see if the folder has already been deleted...
              if (PT_RESULTCODES.PT_E_ACCESSDENIED == pte.GetErrorCode())
              {
                sErrorMsgs+=m_asOwner.GetString(1721, "ptmsgs_portalbrowsingmsgs") + "  ";
                } else
              {
                String strFolderName = m_ptSession.GetCatalog().OpenFolder(nFolderToDeleteID,
                 false).GetLocalizedName();
                sErrorMsgs+=XPResourceManager.FormatMessage(m_asOwner.GetString(1727,
                 "ptmsgs_portalbrowsingmsgs"), strFolderName) + "  ";
                sExtendedErrorMsgs+=pte.GetMessage() + "  ";
              }
            }
          }
        }
        if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
        {
          RaiseError(sErrorMsgs, sExtendedErrorMsgs);
        }
      }
      catch (Exception e)
      {
        throw new XPException(STR_MVC_CLASS_NAME + "::DeleteFolders Error when deleting folders" + e.Message,
         e);
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#MigrateObjects(int, int[], java.lang.String)
     */
     
    public virtual void MigrateObjects(int nClassID, int[] nObjects, String sComment)
    {
      IPTMigrationManager ptMM = (IPTMigrationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
       false);
      if ((nObjects != null) && (nObjects.Length > 0))
      {
        try
        {
          ptMM.BulkSetMigrationStatus(nClassID, nObjects, PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED,
           sComment);
        }
        catch (Exception e)
        {
          log.Error(e, m_asOwner.GetString(1219, "ptmsgs_portalbrowsingmsgs") + e.Message);
          throw new XPException(STR_MVC_CLASS_NAME + "::MigrateFolders Error when migrating folders" + e.Message,
           e);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#DoNotShowObject(int)"></seealso>
    public virtual bool DoNotShowObject(int nIndex)
    {
      return false;
    }
    public virtual void Finish()
    {
    }
    // ABO methods
    public virtual int[] GetABOJobIDs()
    {
      int[] result = m_nABOJobIDs;
      m_nABOJobIDs = new int[0];
      return result;
    }
    
    /// <returns></returns>
    public virtual XPSortedDictionary GetBasicCardProperties()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_xpBasicProperties;
    }
    
    /// <returns></returns>
    public virtual int GetBrowseBy()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      return vpPTDirPrefs.GetBrowseBy();
    }
    
    /// <returns></returns>
    public virtual int GetBrowseBySource()
    {
      return GetBrowseBy();
    }
    
    /// <returns></returns>
    public virtual int GetCardID()
    {
      return m_nCurrentCardID;
    }
    
    /// <returns></returns>
    public virtual int GetLoadedCardID()
    {
      return m_nLoadedCardID;
    }
    
    /// <returns></returns>
    public virtual void SetLoadedCardID(int nCardID)
    {
      m_nLoadedCardID = nCardID;
    }
    
    /// <returns></returns>
    public virtual XPSortedDictionary GetCardInformation()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_xpCardInformation;
    }
    
    /// <param name="nCardID"></param>
    /// <returns></returns>
    public virtual String GetCardName(int nCardID)
    {
      try
      {
        return m_ptSession.GetCatalog().OpenCard(nCardID, false).GetLocalizedName();
        }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t retrieve Card Name for cardid: " + nCardID);
        return "";
      }
    }
    
    /// <returns></returns>
    public virtual String GetCardName()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (!td.m_bLoadedFolder)
      {
        this.LoadFoldersAndDocuments();
      }
      return td.m_ptCurrentCard.GetLocalizedName();
    }
    
    /// <summary>
    /// start the keywords section.
    /// </summary>
    public virtual void StartCardKeywords(int _nCardID)
    {
      try
      {
        IPTObject obj = m_ptSession.GetCatalog().OpenCard(_nCardID, false);
        ((KeywordsModel) m_asOwner.GetModel(DirAS.STR_MVC_STORAGE_NAME_KEYWORDS)).InitializeKeywords(obj,
         71);
      }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t retrieve Keywords for cardid: " + _nCardID);
        }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetObjectID()
     */
     
    public virtual int GetObjectID()
    {
      IPTServerContext pSC = null;
      try
      {
        DirTempData td = (DirTempData) GetTempData();
        pSC = (IPTServerContext) td.m_ptCurrentCard;
      }
      catch (Exception e)
      {
        // if the object does not support IPTServerContext, return 0 -jas
        return 0;
      }
      return pSC.GetObjectID();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetObjectUUID()
     */
     
    public virtual String GetObjectUUID()
    {
      IPTMigratable pM = null;
      try
      {
        DirTempData td = (DirTempData) GetTempData();
        pM = (IPTMigratable) td.m_ptCurrentCard;
      }
      catch (Exception e)
      {
        // if the object does not support IPTMigratable, return null -jas
        return null;
      }
      return pM.GetObjectUUID();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetClassID()"></seealso>
    public virtual int GetClassID()
    {
      IPTObject pObj = null;
      try
      {
        DirTempData td = (DirTempData) GetTempData();
        pObj = (IPTObject) td.m_ptCurrentCard;
      }
      catch (Exception e)
      {
        // if the object does not support IPTObject, return 0 -jas
        return 0;
      }
      return pObj.GetClassID();
    }
    
    /// <returns></returns>
    public virtual int GetCardRangeBegin()
    {
      return m_nRangeBegin;
    }
    
    /// <returns></returns>
    public virtual int GetCardSubmitDataSource()
    {
      if (-1 == m_nCSSelectedDataSource)
      {
        m_nCSSelectedDataSource = GetParentDefaultDataSourceIDRecursive();
        }
      return m_nCSSelectedDataSource;
    }
    
    /// <param name="bIsWebDataSource"></param>
    /// <returns></returns>
    public virtual String GetCardSubmitURL(bool bIsWebDataSource)
    {
      if (null == m_strCSSelectedURL)
      {
        m_strCSSelectedURL = bIsWebDataSource ? HTTP_PREFIX : "";
      } else
      if (bIsWebDataSource && XPStringUtility.EqualsIgnoreCase("", m_strCSSelectedURL))
      {
        m_strCSSelectedURL = HTTP_PREFIX;
      }
      return m_strCSSelectedURL;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModelRO#GetCardSubmitMode()
     */
     
    public virtual int GetCardSubmitError()
    {
      return m_nCSError;
    }
    ///////////////////////////
    // Copy Tree Methods
    public virtual String GetCopyTargetFolderTREESUBSPACE()
    {
      return strCopyTargetFolderTREESUBSPACE;
    }
    // Folder Creation (for confirmation page)
    public virtual int GetCreatedFolderID()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_nCreatedFolderID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetCurrentFolderID()"></seealso>
    public virtual int GetCurrentFolderID()
    {
      return m_nCurrentFolderID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetCurrentFolderLevel()"></seealso>
    public virtual int GetCurrentFolderLevel()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (!td.m_bLoadedFolder)
      {
        this.LoadFoldersAndDocuments();
      }
      return td.m_ptCurrentFolder.GetFolderLevel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetCurrentFolderName()"></seealso>
    public virtual String GetCurrentFolderName()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (!td.m_bLoadedFolder)
      {
        this.LoadFoldersAndDocuments();
      }
      return td.m_ptCurrentFolder.GetLocalizedName();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IPaginationModelRO#GetCurrentLowerObjectIndex()"></seealso>
    public virtual int GetCurrentLowerObjectIndex()
    {
      // This will eventually return a useful value after the framework is set up
      return -1;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IPaginationModelRO#GetCurrentUpperObjectIndex()"></seealso>
    public virtual int GetCurrentUpperObjectIndex()
    {
      // This will eventually return a useful value after the framework is set up
      return -1;
    }
    
    /// <returns></returns>
    public virtual XPSortedDictionary GetCustomCardProperties()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_xpCustomProperties;
    }
    
    /// <param name="nDataSourceID"></param>
    /// <returns></returns>
    public virtual String GetDataSourceName(int nDataSourceID)
    {
      PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(m_ptSession.GetDataSources());
      omqw.QuerySingleObject(nDataSourceID);
      String strDataSourceName = (String) omqw.GetFields(0, PT_PROPIDS.PT_PROPID_NAME);
      return strDataSourceName;
    }
    // Card Submission
    public virtual String GetDataSourceProviderName(int nDataSourceID)
    {
      IPTDataSource ptDataSource = (IPTDataSource) m_ptSession.GetDataSources().Open(nDataSourceID,
       false);
      String strDSProviderCLSID = ptDataSource.GetDataSourceProviderCLSID();
      ClassTypeDescManager ptObjDescMgr = PTConfigHelper.GetPTClassTypeDescrManager();
      IProvInfo[] ptProvInfo = ptObjDescMgr.GetRegisteredProvInfoForClassType(PT_CLASSIDS.PT_DATASOURCE_ID);
      for (int i = 0;i < ptProvInfo.Length;i++)
      {
        String strProviderGUID = ptProvInfo[i].GetProviderCLSID();
        if (0 == XPStringUtility.Compare(strProviderGUID, strDSProviderCLSID))
        {
          return ptProvInfo[i].GetProviderEnglishName();
        }
      }
      return "";
    }
    
    /// <returns></returns>
    public virtual String GetDataSourceTREESUBSPACE()
    {
      return strDataSourceTREESUBSPACE;
    }
    
    /// <summary>
    /// Gets the current directory mode - Browse or Edit
    /// </summary>
    /// <returns>int    Directory mode constant</returns>
    public virtual int GetDirectoryMode()
    {
      switch (m_nDirMode){
      case DirConstants.BROWSE_MODE:
      return DirConstants.BROWSE_MODE;
      goto case DirConstants.EDIT_MODE;
      case DirConstants.EDIT_MODE:
      return DirConstants.EDIT_MODE;
      goto case DirConstants.DISABILITY_MODE;
      case DirConstants.DISABILITY_MODE:
      return DirConstants.DISABILITY_MODE;
      goto default;
      default:
      return DirConstants.INVALID_MODE;
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetDisplayPaginationHiddenInputs()"></seealso>
    public virtual bool GetDisplayPaginationHiddenInputs()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetDisplaySortHiddenInputs()"></seealso>
    public virtual bool GetDisplaySortHiddenInputs()
    {
      // This will eventually return true after the framework is set up
      return false;
    }
    //////////////////////////////
    // DIRECTORY PREFERENCES
    public virtual String GetDocDescriptionType()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      return vpPTDirPrefs.GetDocDescriptionType();
    }
    
    /// <returns></returns>
    public virtual IASQueryResult GetFilteredDataSources()
    {
      try
      {
        IPTQueryResult ptQR = m_ptSession.GetCatalog().GetCardSubmitDataSources(PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_SIMPLE);
        return new ASQueryResultWrapper(ptQR);
      }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t retrieve CardSubmit datasources");
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFirstFolderIndex()"></seealso>
    public virtual int GetFirstFolderIndex()
    {
      return (m_nRangeBegin - 1);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderColumnCount()"></seealso>
    public virtual int GetFolderColumnCount()
    {
      switch (m_nDirMode){
      case DirConstants.BROWSE_MODE:
      int nDirPrefFolderCount = GetNumFolderColumns();
      return ((nDirPrefFolderCount > 0) ? nDirPrefFolderCount : 3);
      goto case DirConstants.EDIT_MODE;
      case DirConstants.EDIT_MODE:
      return 1;
      goto default;
      default:
      return 1;
      break;
      }
    }
    
    /// <returns></returns>
    public virtual String GetFolderDescriptionType()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      return vpPTDirPrefs.GetFolderDescriptionType();
    }
    
    /// <param name="nFolderID"></param>
    /// <returns></returns>
    public virtual String GetFolderName(int nFolderID)
    {
      try
      {
        return m_ptSession.GetCatalog().OpenFolder(nFolderID, false).GetLocalizedName();
        }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t retrieve Folder Name for folderid: " + nFolderID);
        return "";
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderObjectCount()"></seealso>
    public virtual IASQueryResult GetFolderObjectCount()
    {
      return null;
    }
    
    /// <param name="nFolderID"></param>
    /// <returns></returns>
    public virtual String GetFolderPath(int nFolderID)
    {
      try
      {
        return m_ptSession.GetCatalog().OpenFolder(nFolderID, false).GetPath();
        }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t retrieve Folder Path for folderid: " + nFolderID);
        return "";
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderData()"></seealso>
    public virtual IASQueryResult GetFolderQueryResult()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_asqrSubFolders;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.directory.GetFolderSearchResponse()"></seealso>
    public virtual IPTSearchResponse GetFolderSearchResponse()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_srSubFolders;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderViewHelper()"></seealso>
    public virtual IFolderViewHelper GetFolderViewHelper()
    {
      return new DirFolderViewHelper();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderCount()"></seealso>
    public virtual int GetHeaderCount()
    {
      if (m_nDirMode == DirConstants.BROWSE_MODE)
      {
        if (DirConstants.BROWSE_BY_SEARCH == GetBrowseBy())
        {
          return 3 + m_xpPropColumns.GetSize();
        } else
        {
          return 4;
        }
      } else
      if (m_nDirMode == DirConstants.EDIT_MODE)
      {
        return 5;
      } else
      //DirConstants.DISABILITY_MODE)
      {
        return 0;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderHasCheckbox()"></seealso>
    public virtual bool GetHeaderHasCheckbox()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderRow()"></seealso>
    public virtual HTMLTableRow GetHeaderRow()
    {
      HTMLTableRow myRow = null;
      HTMLAnchor myAnchor;
      HTMLImg myImage;
      PTConstruct myConstruct;
      HTMLInput myInput;
      HTMLTableCell myCell;
      try
      {
        myRow = new HTMLTableRow();
        myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
        // Edit Mode
        if (m_nDirMode == DirConstants.EDIT_MODE)
        {
          // CheckBox
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth("25");
          myCell.SetAlign(CommonHTMLStrings.CENTER);
          myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
          myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
          myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, ObjectView.HTMLINPUT_CHECK_ALL,
           m_asOwner.GetString(150, "ptmsgs_portalbrowsingmsgs"));
          myCell.AddInnerHTMLElement(myInput);
          // mj: removed 'Javascript:' from function name
          myInput.SetOnClick(ObjectView.JAVASCRIPT_CHECK_ALL + "(this, \'" + EditDocViewHelper.QS_CHECKBOX + "\');");
          }
        // DCA - iterate through headers and display them
        IXPList xpHeaders = GetHeaderProperties();
        if (null == xpHeaders)
        {
          return null;
        }
        for (int i = 0;i < xpHeaders.GetSize();i++)
        {
          String[] arrHeader = (String[]) xpHeaders.GetElement(i);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("16");
          myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
          myCell.SetNoWrap(true);
          // DCA - first one spans two columns
          if (i == 0)
          {
            // cover the image as well as the docname column
            myCell.SetColSpan(CommonHTMLStrings.TWO);
          }
          if (null != arrHeader[HEADER_SORT_URL_INDEX])
          {
            int nAbsoluteSortingPropertyID = ((m_nSortingPropertyID > 0) ? m_nSortingPropertyID : (-m_nSortingPropertyID));
            bool bSortUp = (m_nSortingPropertyID > 0);
            myAnchor = new HTMLAnchor(arrHeader[HEADER_SORT_URL_INDEX]);
            myAnchor.AddInnerHTMLString(arrHeader[HEADER_NAME_INDEX]);
            myCell.AddInnerHTMLElement(myAnchor);
            if (XPConvert.ToInteger(arrHeader[HEADER_ID_INDEX]) == nAbsoluteSortingPropertyID)
            {
              // SCC: add the sorting icon
              myAnchor = new HTMLAnchor(arrHeader[HEADER_SORT_URL_INDEX]);
              myConstruct = UIConstructFactory.GetConstruct((bSortUp ? PTImageType.ICON_ARROW_DESCEND : PTImageType.ICON_ARROW_ASCEND),
               true, m_asOwner);
              myImage = (HTMLImg) myConstruct.GetHTMLElement();
              myImage.SetAlt(bSortUp ? m_asOwner.GetString(149, "ptmsgs_portalbrowsingmsgs") : m_asOwner.GetString(148,
               "ptmsgs_portalbrowsingmsgs"));
              myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
              myAnchor.AddInnerHTMLElement(myImage);
              myCell.AddInnerHTMLElement(myAnchor);
            }
          } else
          {
            myCell.AddInnerHTMLString(arrHeader[HEADER_NAME_INDEX]);
          }
        }
        // Browse Mode
        if (m_nDirMode == DirConstants.BROWSE_MODE)
        {
          // empty header over SendDoc link
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, STR_MVC_CLASS_NAME + "::GetHeaderRow The following error occured when trying to display the HTML: " + he.GetMessage());
        return null;
      }
      return myRow;
    }
    public virtual IXPList GetHeaderProperties()
    {
      XPArrayList xpHeaders = new XPArrayList();
      try
      {
        if (m_nDirMode == DirConstants.BROWSE_MODE)
        {
          // Browsing through Search
          if (DirConstants.BROWSE_BY_SEARCH == GetBrowseBy())
          {
            int nAbsoluteSortingPropertyID = ((m_nSortingPropertyID > 0) ? m_nSortingPropertyID : (-m_nSortingPropertyID));
            // Sort By url
            IPTFolder currFolder = ((DirTempData) GetTempData()).m_ptCurrentFolder;
            String strCurrFolderName = null;
            if (null != currFolder)
            {
              strCurrFolderName = currFolder.GetName();
            }
            IPTURL subFolderURL = TaskAPIUIDirectory.CreateCommonOpenerDirectoryFolderURL(m_asOwner,
             m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs"), GetDirectoryMode(),
             m_nCurrentFolderID, strCurrFolderName);
            String sortBaseURL = null;
            // Getting the base URL for Sorting.
            // If Friendly URLs are turned on then we proceed by getting the base URL from
            // Current Folder URL.					
            if (TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_CATALOGFOLDER_ID))
            {
              sortBaseURL = subFolderURL.GetFullURL();
            } else
            // If friendly URLs are turned off then we create base URL for
            // sorting in old fashioned way, i.e., using ASURL Object.
            {
              ASURL sortByURI = new ASURL(m_asOwner);
              sortByURI.SetLinkGetCachedSpace(m_asOwner);
              sortBaseURL = sortByURI.GetURLAsString();
            }
            XPStringBuilder sbSortURL = new XPStringBuilder(sortBaseURL);
            if (XPStringUtility.IndexOf(sbSortURL.ToString(), LinkConstants.QUESTION) > 0)
            {
              sbSortURL.Append(LinkConstants.AMPERSAND);
            } else
            {
              sbSortURL.Append(LinkConstants.QUESTION);
            }
            sbSortURL.Append(ASConstants.CONTROL).Append(LinkConstants.EQUALS).Append(DirRepostControl.STR_MVC_CLASS_NAME);
            sbSortURL.Append(LinkConstants.AMPERSAND).Append(DirConstants.QS_SORTBY).Append(LinkConstants.EQUALS).Append(((nAbsoluteSortingPropertyID == PT_INTRINSICS.PT_PROPERTY_OBJECTNAME) ? -m_nSortingPropertyID : PT_INTRINSICS.PT_PROPERTY_OBJECTNAME));
            // DCA - add to list
            String[] arrHeader = new String[HEADER_PROPERTIES_SIZE];
            arrHeader[HEADER_NAME_INDEX] = m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs");
            arrHeader[HEADER_SORT_URL_INDEX] = sbSortURL.ToString();
            arrHeader[HEADER_ID_INDEX] = XPConvert.ToString(PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
            xpHeaders.Add(arrHeader);
            for (int nCustomHeaderIndex = 0;nCustomHeaderIndex < m_xpPropColumns.GetSize();
            nCustomHeaderIndex++)
            {
              Object[] arPropInfo = (Object[]) m_xpPropColumns.GetElement(nCustomHeaderIndex);
              String strPropName = (String) arPropInfo[DirConstants.PROP_COLUMNS_INDEX_NAME];
              int nPropID = XPConvert.ToInteger(arPropInfo[DirConstants.PROP_COLUMNS_INDEX_ID]);
              // Sort By url
              sbSortURL = new XPStringBuilder(sortBaseURL);
              if (XPStringUtility.IndexOf(sbSortURL.ToString(), LinkConstants.QUESTION) > 0)
              {
                sbSortURL.Append(LinkConstants.AMPERSAND);
              } else
              {
                sbSortURL.Append(LinkConstants.QUESTION);
              }
              sbSortURL.Append(ASConstants.CONTROL).Append(LinkConstants.EQUALS).Append(DirRepostControl.STR_MVC_CLASS_NAME);
              /* set the sort by prop */
              int nSortByThisProp;
              if (nAbsoluteSortingPropertyID == nPropID)
              {
                /* invert the current choice */
                nSortByThisProp = -m_nSortingPropertyID;
              } else
              if (IsDateProperty(nPropID))
              {
                /* dates are descending by default */
                nSortByThisProp = -nPropID;
              } else
              {
                nSortByThisProp = nPropID;
              }
              sbSortURL.Append(LinkConstants.AMPERSAND).Append(DirConstants.QS_SORTBY).Append(LinkConstants.EQUALS).Append(nSortByThisProp);
              // DCA - add to list
              arrHeader = new String[HEADER_PROPERTIES_SIZE];
              arrHeader[HEADER_NAME_INDEX] = strPropName;
              arrHeader[HEADER_SORT_URL_INDEX] = sbSortURL.ToString();
              arrHeader[HEADER_ID_INDEX] = XPConvert.ToString(nPropID);
              xpHeaders.Add(arrHeader);
            }
          } else
          // Browsing through DB
          {
            // Doc Name
            String[] arrHeader = new String[HEADER_PROPERTIES_SIZE];
            arrHeader[HEADER_NAME_INDEX] = m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs");
            arrHeader[HEADER_SORT_URL_INDEX] = null;
            arrHeader[HEADER_ID_INDEX] = XPConvert.ToString(PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
            xpHeaders.Add(arrHeader);
            // Doc Created
            arrHeader = new String[HEADER_PROPERTIES_SIZE];
            arrHeader[HEADER_NAME_INDEX] = m_asOwner.GetString(147, "ptmsgs_portalbrowsingmsgs");
            arrHeader[HEADER_SORT_URL_INDEX] = null;
            arrHeader[HEADER_ID_INDEX] = XPConvert.ToString(PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED);
            xpHeaders.Add(arrHeader);
          }
        } else
        // Edit Mode
        if (m_nDirMode == DirConstants.EDIT_MODE)
        {
          // Doc Name
          String[] arrHeader = new String[HEADER_PROPERTIES_SIZE];
          arrHeader[HEADER_NAME_INDEX] = m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs");
          arrHeader[HEADER_SORT_URL_INDEX] = null;
          arrHeader[HEADER_ID_INDEX] = XPConvert.ToString(PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
          xpHeaders.Add(arrHeader);
          // Doc Created
          arrHeader = new String[HEADER_PROPERTIES_SIZE];
          arrHeader[HEADER_NAME_INDEX] = m_asOwner.GetString(147, "ptmsgs_portalbrowsingmsgs");
          arrHeader[HEADER_SORT_URL_INDEX] = null;
          arrHeader[HEADER_ID_INDEX] = XPConvert.ToString(PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED);
          xpHeaders.Add(arrHeader);
        } else
        // 508 Mode
        if (m_nDirMode == DirConstants.DISABILITY_MODE)
        {
          return null;
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, STR_MVC_CLASS_NAME + "::GetHeaderProperties The following error occured when trying to display the HTML: " + he.GetMessage());
        return null;
      }
      return xpHeaders;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderText(int)"></seealso>
    public virtual String GetHeaderText(int nHeaderIndex)
    {
      if (nHeaderIndex < 0)
      {
        return "";
      }
      if (m_nDirMode == DirConstants.BROWSE_MODE)
      {
        if (DirConstants.BROWSE_BY_SEARCH == GetBrowseBy())
        {
          // basic headers
          switch (nHeaderIndex){
          case 1:
          return m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs");
          goto case 0;
          case 0:
          return "";
          break;
          }
          Object[] arPropInfo = (Object[]) m_xpPropColumns.GetElement(nHeaderIndex);
          String strPropName = (String) arPropInfo[DirConstants.PROP_COLUMNS_INDEX_NAME];
          return strPropName;
        } else
        {
          // basic headers
          switch (nHeaderIndex){
          case 1:
          return m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs");
          goto case 2;
          case 2:
          return m_asOwner.GetString(147, "ptmsgs_portalbrowsingmsgs");
          goto case 0;
          case 0:
          default:
          return "";
          break;
          }
        }
      } else
      {
        switch (nHeaderIndex){
        case 0:
        return EditDocViewHelper.QS_CHECKBOX;
        goto case 2;
        case 2:
        return m_asOwner.GetString(146, "ptmsgs_portalbrowsingmsgs");
        goto case 3;
        case 3:
        return m_asOwner.GetString(147, "ptmsgs_portalbrowsingmsgs");
        goto case 1;
        case 1:
        case 4:
        default:
        return "";
        break;
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetIsCollapsable()"></seealso>
    public virtual bool GetIsCollapsable()
    {
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetShowCheckbox()"></seealso>
    public virtual bool GetIsFolderSelected(int nFolderID)
    {
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetIsObjectSelected(int)"></seealso>
    public virtual bool GetIsObjectSelected(int nObjectID)
    {
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetLastFolderIndex()"></seealso>
    public virtual int GetLastFolderIndex()
    {
      return m_nRangeEnd - 1;
    }
    
    /// <returns></returns>
    public virtual int GetMoreFolderID()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_nMoreFolderID;
    }
    // Retrieves the and LastModified Date
    public virtual Object[][] GetMoreRelatedResources(int nRelatedResourceID)
    {
      DirTempData td = (DirTempData) GetTempData();
      IASQueryResult asQRCategory;
      switch (nRelatedResourceID){
      case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
      asQRCategory = td.m_asqrRelatedCommunities;
      break;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS:
      asQRCategory = td.m_asqrRelatedFolders;
      break;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
      asQRCategory = td.m_asqrRelatedPortlets;
      break;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
      asQRCategory = td.m_asqrRelatedExperts;
      break;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
      asQRCategory = td.m_asqrRelatedContentManagers;
      break;
      default:
      return null;
      break;
      }
      if (null == asQRCategory)
      {
        return null;
      }
      int nNumRRs = asQRCategory.GetCount();
      Object[][] arMoreRRAdditionalInfo;
      // We can use the object manager query for efficiency
      if (PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS != nRelatedResourceID)
      {
        IPTObjectManager ptOM;
        switch (nRelatedResourceID){
        case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
        ptOM = m_ptSession.GetCommunities();
        break;
        case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
        ptOM = m_ptSession.GetGadgets();
        break;
        case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
        case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
        ptOM = m_ptSession.GetUsers();
        break;
        default:
        return null;
        break;
        }
        int[] arRRObjectIDs = new int[nNumRRs];
        for (int i = 0;i < nNumRRs;i++)
        {
          int nObjectID = XPConvert.ToInteger(asQRCategory.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
          arRRObjectIDs[i] = nObjectID;
        }
        // Filter to return only the Related Resources in this Folder
        Object[][] arFilter = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          arFilter[j2c_index] = new Object[1];
        }
        arFilter[0][0] = PT_PROPIDS.PT_PROPID_OBJECTID;
        arFilter[1][0] = PT_FILTEROPS.PT_FILTEROP_IN;
        arFilter[2][0] = arRRObjectIDs;
        IPTQueryResult ptQR = ptOM.Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_LASTMODIFIED,
         -1, PT_PROPIDS.PT_PROPID_NAME, 0, -1, arFilter);
        if (null == ptQR)
        {
          return null;
        }
        int nQRCount = ptQR.RowCount();
        arMoreRRAdditionalInfo = new Object[nQRCount][];
        for (int j2c_index = 0;j2c_index < nQRCount;j2c_index++)
        {
          arMoreRRAdditionalInfo[j2c_index] = new Object[4];
        }
        for (int i = 0;i < nQRCount;i++)
        {
          int nObjectID = ptQR.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
          arMoreRRAdditionalInfo[i][0] = nObjectID;
          // Get Localized Name
          arMoreRRAdditionalInfo[i][1] = (String) ptQR.ItemAsObject(i, PT_PROPIDS.PT_PROPID_NAME);
          // Get Localized Description
          arMoreRRAdditionalInfo[i][2] = (String) ptQR.ItemAsObject(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
          // Get Last Modified Date
          XPDateTime date = (XPDateTime) ptQR.ItemAsObject(i, PT_PROPIDS.PT_PROPID_LASTMODIFIED);
          /* usersTimeZone= */
          XPDateFormat xpDateFormat = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
           true);
          arMoreRRAdditionalInfo[i][3] = xpDateFormat.Format(date);
        }
      } else
      // Related Folders (We need a special case here since the Catalog Folder
      //   is not managed by the IPTObjectManager and therefore cannot be queried
      {
        arMoreRRAdditionalInfo = new Object[nNumRRs][];
        for (int j2c_index = 0;j2c_index < nNumRRs;j2c_index++)
        {
          arMoreRRAdditionalInfo[j2c_index] = new Object[4];
        }
        for (int i = 0;i < nNumRRs;i++)
        {
          int nObjectID = XPConvert.ToInteger(asQRCategory.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
          arMoreRRAdditionalInfo[i][0] = nObjectID;
          IPTObject ptFolder;
          ptFolder = (IPTObject) m_ptSession.GetCatalog().OpenFolder(nObjectID,
           false);
          // Get Localized Name
          arMoreRRAdditionalInfo[i][1] = ptFolder.GetLocalizedName();
          // Get Localized Description
          arMoreRRAdditionalInfo[i][2] = ptFolder.GetLocalizedDescription();
          // Get Last Modified Date
          XPDateTime date = ptFolder.GetLastModified();
          /* usersTimeZone= */
          XPDateFormat xpDateFormat = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
           true);
          arMoreRRAdditionalInfo[i][3] = xpDateFormat.Format(date);
        }
      }
      return arMoreRRAdditionalInfo;
    }
    ///////////////////////////
    // Move Tree Methods
    public virtual String GetMoveTargetFolderTREESUBSPACE()
    {
      return strMoveTargetFolderTREESUBSPACE;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public override Object GetNewTempData()
    {
      DirTempData td = new DirTempData();
      return td;
    }
    
    /// <returns></returns>
    public virtual int GetNumDocsPerPage()
    {
      if (m_nNumDocsPerPage > 0)
      {
        return m_nNumDocsPerPage;
      } else
      {
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
        return vpPTDirPrefs.GetNumDocsPerPage();
      }
    }
    
    /// <param name="_nNumDocsPerPage">The Number of cards per page to be set.</param>
    public virtual void SetNumDocsPerPage(int _nNumDocsPerPage)
    {
      m_nNumDocsPerPage = _nNumDocsPerPage;
    }
    
    /// <returns></returns>
    public virtual int GetNumFolderColumns()
    {
      return m_nNumFoldCol;
    }
    ///////////////////////////////////////////
    // Read only method from IPaginationModelRO
    ///////////////////////////////////////////
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IPaginationModelRO#GetNumObjects()"></seealso>
    public virtual int GetNumObjects()
    {
      // This will eventually return a useful value after the framework is set up
      return -1;
    }
    
    /// <returns></returns>
    public virtual int GetNumSubSubFolders()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      return vpPTDirPrefs.GetNumSubSubFolders();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetNumSubSubFolders()"></seealso>
    public virtual int GetNumSubSubFoldersToDisplay()
    {
      if (IsAtMaxFolderLevel())
      {
        return 0;
      } else
      if (m_nDirMode == DirConstants.DISABILITY_MODE)
      {
        return 0;
      } else
      {
        return GetNumSubSubFolders();
      }
    }
    
    /// <summary>
    /// this creates a string with the banner sub-header text.
    /// </summary>
    public virtual String GetObjectBannerText()
    {
      int[] objRange = GetCardRange();
      if (objRange[CARD_CNT] == 0)
      {
        return "";
      } else
      {
        return " " + XPResourceManager.FormatMessage(m_asOwner.GetString(145,
         "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(objRange[BEGIN_INDEX]),
         XPConvert.ToString(objRange[END_INDEX]), XPConvert.ToString(objRange[TOTAL_CNT_INDEX]));
        }
    }
    
    /// <summary>
    /// Returns an array with 4 int, [0] start of range, [1] end of range, 
    /// [2] card count, [3] total count
    /// </summary>
    public virtual int[] GetCardRange()
    {
      int[] cardRange = new int[4];
      DirTempData td = (DirTempData) GetTempData();
      int nDocumentCount = GetObjectCount();
      if (nDocumentCount > 0)
      {
        cardRange[BEGIN_INDEX] = m_nRangeBegin;
        cardRange[END_INDEX] = (m_nRangeBegin + nDocumentCount) - 1;
        cardRange[CARD_CNT] = nDocumentCount;
        cardRange[TOTAL_CNT_INDEX] = td.m_nTotalResults;
      } else
      {
        cardRange[BEGIN_INDEX] = 0;
        cardRange[END_INDEX] = 0;
        cardRange[CARD_CNT] = 0;
        cardRange[TOTAL_CNT_INDEX] = 0;
      }
      return cardRange;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectBannerTitle()"></seealso>
    public virtual String GetObjectBannerTitle()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (!td.m_bLoadedFolder)
      {
        this.LoadFoldersAndDocuments();
      }
      return XPResourceManager.FormatMessage(m_asOwner.GetString(144, "ptmsgs_portalbrowsingmsgs"),
       " \"" + XPHttpUtility.HtmlEncode(td.m_ptCurrentFolder.GetLocalizedName()) + "\"");
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectColumnCount()"></seealso>
    public virtual int GetObjectColumnCount()
    {
      return 1;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectCount()"></seealso>
    public virtual int GetObjectCount()
    // Items returned, not total matches
    {
      DirTempData td = (DirTempData) GetTempData();
      if ((m_nDirMode == DirConstants.BROWSE_MODE) && (DirConstants.BROWSE_BY_SEARCH == GetBrowseBy()))
      {
        if (!td.m_bLoadedFolder)
        {
          this.LoadFoldersAndDocuments();
        }
        if (null == td.m_ptSearchDocuments)
        {
          return 0;
        } else
        {
          return td.m_ptSearchDocuments.GetResultsReturned();
        }
      } else
      {
        if (!td.m_bLoadedFolder)
        {
          this.LoadFoldersAndDocuments();
        }
        if (null == td.m_asqrDocuments)
        {
          return 0;
        } else
        {
          return td.m_asqrDocuments.GetCount();
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectFields(int,int)"></seealso>
    public virtual Object GetObjectFields(int nIndex, int nPropID)
    {
      DirTempData td = (DirTempData) GetTempData();
      if ((m_nDirMode == DirConstants.BROWSE_MODE) && (DirConstants.BROWSE_BY_SEARCH == GetBrowseBy()))
      {
        if (!td.m_bLoadedFolder)
        {
          this.LoadFoldersAndDocuments();
        }
        if ((PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED == nPropID) || (PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED == nPropID))
        {
          return SearchResultModel.ConvertSearchDateTimeToXPDateTime(td.m_ptSearchDocuments.GetFieldsAsDouble(nIndex,
           nPropID));
        }
        return td.m_ptSearchDocuments.GetFieldsAsObject(nIndex, nPropID);
        } else
      // edit or disability
      {
        if (!td.m_bLoadedFolder)
        {
          this.LoadFoldersAndDocuments();
        }
        return td.m_asqrDocuments.GetFields(nIndex, nPropID);
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IObjectModelRO#GetObjectType()"></seealso>
    public virtual int GetObjectType()
    {
      return PT_CLASSIDS.PT_CATALOGCARD_ID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectSubType()"></seealso>
    public virtual int GetObjectSubType(int nIndex)
    {
      return -1;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectViewIsCollapsed()"></seealso>
    public virtual bool GetObjectViewIsCollapsed()
    {
      // This should not get called.
      return false;
    }
    
    /// <returns></returns>
    public virtual int GetParentDefaultDataSourceIDRecursive()
    {
      try
      {
        IPTFolder ptFolder = m_ptSession.GetCatalog().OpenFolder(m_nCurrentFolderID,
         false);
        int nDataSourceID = ptFolder.GetDefaultDataSource();
        return nDataSourceID;
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return 0;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetParentFolderID()"></seealso>
    public virtual int GetParentFolderID()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (!td.m_bLoadedFolder)
      {
        this.LoadFoldersAndDocuments();
      }
      return td.m_ptCurrentFolder.GetParentFolderID();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#OpenFolderByPath(java.lang.String)
     */
     
    public virtual int OpenFolderByPath(String strPath)
    {
      try
      {
        IPTCatalog ptCatalog = m_ptSession.GetCatalog();
        IPTFolder ptFolder = ptCatalog.OpenFolderByPath(strPath, false);
        IPTServerContext ptSC = (IPTServerContext) ptFolder;
        DirTempData td = (DirTempData) GetTempData();
        td.m_ptCurrentFolder = ptFolder;
        return ptSC.GetObjectID();
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         e, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return PT_INTRINSICS.PT_FOLDER_ROOTFOLDER;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetParentFolderIDs()"></seealso>
    public virtual Object[] GetParentFolderIDs()
    {
      Object[] oIDs = null;
      try
      {
        IPTCatalog ptCatalog = m_ptSession.GetCatalog();
        // We need the path in all modes to be printed at the top
        IPTQueryResult ptqrParentFolderIDs = ptCatalog.QueryParentFolderIDs(m_nCurrentFolderID);
        //int nNumParentIDs  = ptqrParentFolderIDs.RowCount();
        ASQueryResultWrapper asqr = new ASQueryResultWrapper(ptqrParentFolderIDs);
        oIDs = ASQueryResultWrapper.ConvertToArrayList(asqr, PT_PROPIDS.PT_PROPID_OBJECTID).ToArray();
        }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return oIDs;
    }
    public virtual IASQueryResult GetBreadCrumbPath()
    {
      try
      {
        DirTempData td = (DirTempData) GetTempData();
        return new ASQueryResultWrapper(td.m_ptCurrentFolder.GetPathAsQueryResult());
        }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER,
         e, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetPath()"></seealso>
    public virtual String GetPath()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (!td.m_bLoadedFolder)
      {
        this.LoadFoldersAndDocuments();
      }
      return td.m_ptCurrentFolder.GetPath();
    }
    
    /// <returns></returns>
    public virtual XPArrayList GetPropColumns()
    {
      return m_xpPropColumns;
    }
    
    /// <returns></returns>
    public virtual int GetRRCategory()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_nCurrentRRCategoryID;
    }
    
    /// <returns></returns>
    public virtual int GetRRObjectID()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_nCurrentRRObjectID;
    }
    
    /// <returns></returns>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <param name="lRelatedResourceID"></param>
    /// <returns></returns>
    public virtual IASQueryResult GetRelatedResource(int lRelatedResourceID)
    {
      DirTempData td = (DirTempData) GetTempData();
      switch (lRelatedResourceID){
      case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
      return td.m_asqrRelatedCommunities;
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS:
      return td.m_asqrRelatedFolders;
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
      return td.m_asqrRelatedPortlets;
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
      return td.m_asqrRelatedExperts;
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
      return td.m_asqrRelatedContentManagers;
      goto default;
      default:
      return null;
      break;
      }
    }
    
    /// <returns></returns>
    public virtual int[] GetRelatedResourceIDs()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_arRelatedResourceIDs;
    }
    
    /// <param name="nRelatedResourceID"></param>
    /// <returns></returns>
    public virtual String GetRelatedResourceString(int nRelatedResourceID)
    {
      switch (nRelatedResourceID){
      case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
      return m_asOwner.GetString(153, "ptmsgs_portalbrowsingmsgs");
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS:
      return m_asOwner.GetString(154, "ptmsgs_portalbrowsingmsgs");
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
      return m_asOwner.GetString(155, "ptmsgs_portalbrowsingmsgs");
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
      return m_asOwner.GetString(156, "ptmsgs_portalbrowsingmsgs");
      goto case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS;
      case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
      return m_asOwner.GetString(157, "ptmsgs_portalbrowsingmsgs");
      goto default;
      default:
      return "";
      break;
      }
    }
    
    /// <returns></returns>
    public virtual int GetRelatedResourcesLocation()
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      return vpPTDirPrefs.GetRelatedResourcesPlacement();
    }
    
    /// <returns></returns>
    public virtual IPTSession GetSession()
    {
      return m_ptSession;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetShowCheckbox()"></seealso>
    public virtual bool GetShowCheckbox()
    {
      switch (m_nDirMode){
      case DirConstants.BROWSE_MODE:
      return false;
      goto case DirConstants.EDIT_MODE;
      case DirConstants.EDIT_MODE:
      return true;
      goto default;
      default:
      return false;
      break;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetShowBanner()"></seealso>
    public virtual bool GetShowFolderBanner()
    {
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetShowPagination()"></seealso>
    public virtual bool GetShowPagination()
    {
      // This will eventually return true after the framework is set up
      return false;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.ISortModelRO#GetSortDirection()"></seealso>
    public virtual int GetSortDirection()
    {
      if (m_nSortingPropertyID > 0)
      {
        return PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      } else
      {
        return PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#GetSortable()"></seealso>
    public virtual bool GetSortable()
    {
      // This will eventually return true after the framework is set up
      return false;
    }
    //////////////////////////////////////
    // Read only methods from ISortModelRO
    //////////////////////////////////////
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.ISortModelRO#GetSortedHeader()"></seealso>
    public virtual int GetSortedHeader()
    {
      return m_nSortingPropertyID;
    }
    
    /// <summary>
    /// Get the SpaceID of the parent Activity Space
    /// </summary>
    /// <returns>int m_asOwner.GetSpaceID();</returns>
    public virtual String GetSpaceID()
    {
      return m_asOwner.GetSpaceID();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderCount()"></seealso>
    public virtual int GetSubFolderCount()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (RetrieveSubFoldersThroughSearch())
      {
        if (td.m_arMappedSubFolderIndex != null)
        {
          return td.m_arMappedSubFolderIndex.Length;
        } else
        {
          return 0;
        }
      } else
      {
        if (td.m_asqrSubFolders != null)
        {
          return td.m_asqrSubFolders.GetCount();
        } else
        {
          return 0;
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderCount()"></seealso>
    public virtual int GetSubFolderCount(int nLevel)
    {
      DirTempData td = (DirTempData) GetTempData();
      int count = 0;
      int nTotalNumFolders = 0;
      if (RetrieveSubFoldersThroughSearch())
      {
        if (td.m_arMappedSubFolderIndex != null)
        {
          nTotalNumFolders = td.m_arMappedSubFolderIndex.Length;
        }
        for (int i = 0;i < nTotalNumFolders;i++)
        {
          int nMappedIndex = GetFolderSearchMapping(i);
          int nThisLevel = td.m_srSubFolders.GetFieldsAsInt(nMappedIndex,
           PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
          if (nThisLevel == nLevel)
          {
            count++;
          }
        }
      } else
      {
        if (td.m_asqrSubFolders != null)
        {
          nTotalNumFolders = td.m_asqrSubFolders.GetCount();
        }
        for (int i = 0;i < nTotalNumFolders;i++)
        {
          int nThisLevel = XPConvert.ToInteger(td.m_asqrSubFolders.GetFields(i,
           PT_PROPIDS.PT_PROPID_FOLDER_LEVEL));
          if (nThisLevel == nLevel)
          {
            count++;
          }
        }
      }
      return count;
    }
    
    /// <returns></returns>
    public virtual int GetTotalResults()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_nTotalResults;
    }
    
    /// <returns></returns>
    public virtual bool HasAccessToEditCard()
    {
      return m_ptSession.GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGCARD_ID,
       m_nCurrentCardID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
    }
    
    /// <returns></returns>
    public virtual bool HasAccessToEditFolder()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (null == td.m_ptCurrentFolder)
      {
        return m_ptSession.GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
         m_nCurrentFolderID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
      } else
      {
        IPTServerContext ptSC = (IPTServerContext) td.m_ptCurrentFolder;
        return PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT <= ptSC.GetAccessLevel();
        }
    }
    
    /// <returns></returns>
    public virtual bool HasAccessToApproveCardInFolder()
    {
      DirTempData td = (DirTempData) GetTempData();
      if (null == td.m_ptCurrentFolder)
      {
        return m_ptSession.GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
         m_nCurrentFolderID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN);
      } else
      {
        IPTServerContext ptSC = (IPTServerContext) td.m_ptCurrentFolder;
        return PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN <= ptSC.GetAccessLevel();
        }
    }
    
    /// <returns></returns>
    public virtual bool HasSelfSelectExpertRightOnThisFolder()
    {
      bool bHasSelfSelectRight = CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_SELFSELECTING_EXPERTS);
      DirTempData td = (DirTempData) GetTempData();
      bool bHasSelectAccessOnFolder;
      if (null == td.m_ptCurrentFolder)
      {
        bHasSelectAccessOnFolder = m_ptSession.GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
         m_nCurrentFolderID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
      } else
      {
        IPTServerContext ptSC = (IPTServerContext) td.m_ptCurrentFolder;
        bHasSelectAccessOnFolder = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT <= ptSC.GetAccessLevel();
        }
      return bHasSelfSelectRight && bHasSelectAccessOnFolder;
    }
    
    /// <returns></returns>
    public virtual int GetSubPortalAccessType()
    {
      IPTSubPortalInfo ptSubPortalInfo = m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
      return ptSubPortalInfo.GetAccessType();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModelRO#InRootFolder()"></seealso>
    public virtual bool InRootFolder()
    {
      return (m_nCurrentFolderID == PT_INTRINSICS.PT_FOLDER_ROOTFOLDER);
    }
    
    /// <returns></returns>
    public virtual bool InUnclassifiedCardsFolder()
    {
      return (m_nCurrentFolderID == PT_INTRINSICS.PT_FOLDER_UNCLASSIFIEDCARDS);
      }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public override void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      m_nDirMode = DirConstants.BROWSE_MODE;
      m_nCurrentFolderID = PT_INTRINSICS.PT_FOLDER_ROOTFOLDER;
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      m_nNumFoldCol = vpPTDirPrefs.GetNumFolderColumns();
      // Load default card language from server config
      IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      Object oSetting = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_DEFAULT_LOCALE);
      if (null == oSetting)
      {
        m_strDefaultInxightLanguage = ENGLISH_LOCALE_CODE;
      } else
      {
        m_strDefaultInxightLanguage = PlumtreeHelpers.TrimCardLanguage((String) oSetting);
        }
      LoadBrowsingPropColumns();
      LoadUserPrefs();
    }
    public virtual void LoadBrowsingPropColumns()
    {
      // Only load if necessary
      if (null != m_xpPropColumns)
      {
        return;
      }
      m_xpPropColumns = new XPArrayList();
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
      XPArrayList xpPropColumnIDs = vpPTDirPrefs.GetPropColumns();
      IPTProperty ptProperty = null;
      // build a list of properties in case we need to reset them.
      String strSelectedProperties = "";
      for (int i = 0;i < xpPropColumnIDs.GetSize();i++)
      {
        int nPropID = XPConvert.ToInteger(xpPropColumnIDs.GetElement(i));
        // Check if user has the right to browse using this property
        if (!m_ptSession.GetSessionInfo().CheckPropertySearchRight(nPropID))
        {
          continue;
        }
        try
        {
          ptProperty = (IPTProperty) m_ptSession.GetProperties().Open(nPropID,
           false);
        }
        catch (Exception e)
        {
          log.Warn(e, "Init::Unable to open selected property " + nPropID + ".");
          continue;
        }
        Object[] arProps = new Object[DirConstants.PROP_COLUMNS_MAX];
        arProps[DirConstants.PROP_COLUMNS_INDEX_ID] = nPropID;
        String strPropName = ptProperty.GetLocalizedName();
        strSelectedProperties = strSelectedProperties + strPropName + " ";
        int nPropType = ptProperty.GetType();
        arProps[DirConstants.PROP_COLUMNS_INDEX_NAME] = strPropName;
        arProps[DirConstants.PROP_COLUMNS_INDEX_TYPE] = nPropType;
        m_xpPropColumns.Add(arProps);
      }
    }
    
    /// <returns></returns>
    public virtual bool IsAtMaxFolderLevel()
    {
      DirTempData td = (DirTempData) GetTempData();
      return PT_SERVERCONSTANTS.PT_MAX_FOLDERDEPTH == td.m_ptCurrentFolder.GetFolderLevel();
      }
    
    /// <returns></returns>
    public virtual bool IsRelatedExpert()
    {
      DirTempData td = (DirTempData) GetTempData();
      int nCurrentUserID = m_ptSession.GetSessionInfo().GetCurrentUserID();
      IASQueryResult asExperts = td.m_asqrRelatedExperts;
      if (null == asExperts)
      {
        return false;
      }
      for (int i = 0;i < asExperts.GetCount();i++)
      {
        if (XPConvert.ToInteger(asExperts.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID)) == nCurrentUserID)
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Check if the provider for this data source supports web paths.
    /// </summary>
    /// <param name="nDataSourceID">the data source to check</param>
    /// <returns>whether or not the provider for this data source supports web paths.</returns>
    public virtual bool IsWebDataSource(int nDataSourceID)
    {
      try
      {
        ITaskAPIUIDirectory task = TaskAPIUIDirectoryService.GetInstance();
        IPTDataSource ptDataSource = (IPTDataSource) m_ptSession.GetDataSources().Open(nDataSourceID,
         false);
        // This method gets the data source provider and checks if it supports web paths.
        return task.IsWebDataSource(ptDataSource, m_ptSession);
      }
      catch (Exception e)
      {
        log.Error(e, "CardSubmitSimpleModel::IsWebDataSource Error retrieving Data Source " + nDataSourceID + ".");
        return false;
      }
    }
    public virtual void LoadCardProperties()
    {
      DirTempData td = (DirTempData) GetTempData();
      LoadTempUserPrefs();
      td.m_xpBasicProperties = null;
      td.m_xpCustomProperties = null;
      td.m_xpCardInformation = null;
      XPSortedDictionary xpBasicProperties = new XPSortedDictionary();
      XPSortedDictionary xpCustomProperties = new XPSortedDictionary();
      XPSortedDictionary xpCardInformation = new XPSortedDictionary();
      IPTCard ptCard = td.m_ptCurrentCard;
      IPTCardPropertyValues ptPropValues = ptCard.GetPropertyValues();
      // Get all Properties
      IPTQueryResult ptqrProperties = m_ptSession.GetProperties().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_PROP_VALUETYPE | PT_PROPIDS.PT_PROPID_PROP_HREF | PT_PROPIDS.PT_PROPID_PROP_READONLYVALUE,
       -1, PT_PROPIDS.PT_PROPID_NAME, 0, -1, null);
      // Get the property IDs for this card
      Object[] arCardPropIDs = (Object[]) ptPropValues.GetPropertyIDs();
      for (int i = 0;i < ptqrProperties.RowCount();i++)
      {
        int nPropID = ptqrProperties.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (doesPropertyDescribeCard(arCardPropIDs, nPropID))
        {
          CardPropertyObject cpo = new CardPropertyObject(ptPropValues.GetItem(nPropID),
           i, ptqrProperties, m_asOwner);
          // Skip Plumtree Card Image UUID
          if (cpo.m_bIsDisplayable)
          {
            continue;
          }
          if (true == IsBasicCardProperty(cpo))
          {
            xpBasicProperties.PutElement(XPConvert.ToString(nPropID), cpo);
            } else
          {
            String strPropName = cpo.m_sPropName;
            xpCustomProperties.PutElement(strPropName, cpo);
          }
        }
      }
      // for
      // Get Popularity Stats
      IPTQueryResult ptQR = m_ptSession.GetCatalog().GetStatistics().QueryCardPopularityStatistics(m_nCurrentCardID);
      String strPopularity = XPConvert.ToString(ptQR.ItemAsInt(0, PT_PROPIDS.PT_PROPID_CARD_POPULARITY));
      String strAccessCount = XPConvert.ToString(ptQR.ItemAsInt(0, PT_PROPIDS.PT_PROPID_CARD_ACCESSCOUNT));
      XPDateTime xpLastModified = ptQR.ItemAsXPDateTime(0, PT_PROPIDS.PT_PROPID_CARD_LASTACCESS);
      XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM,
       XPDateFormat.MEDIUM, GetUserPrefLocale(), GetUserPrefTimeZone());
      String strLastModified = xpDateTimeFormat.Format(xpLastModified);
      // Get Card Paths
      IPTQueryResult qrCardPaths = m_ptSession.GetCatalog().QueryCardPaths(m_nCurrentCardID,
       false, false);
      int nParentFolderCount = qrCardPaths.RowCount();
      Object[][] arCardPaths = new Object[nParentFolderCount][];
      for (int j2c_index = 0;j2c_index < nParentFolderCount;j2c_index++)
      {
        arCardPaths[j2c_index] = new Object[2];
      }
      for (int i = 0;i < nParentFolderCount;i++)
      {
        arCardPaths[i][0] = qrCardPaths.ItemAsObject(i, PT_PROPIDS.PT_PROPID_CARD_PARENTFOLDERID);
        arCardPaths[i][1] = qrCardPaths.ItemAsObject(i, PT_PROPIDS.PT_PROPID_FOLDER_PATH);
        }
      xpCardInformation.PutElement(m_asOwner.GetString(141, "ptmsgs_portalbrowsingmsgs"),
       new CardStatisticObject(m_asOwner.GetString(141, "ptmsgs_portalbrowsingmsgs"),
       strLastModified, null));
      xpCardInformation.PutElement(m_asOwner.GetString(140, "ptmsgs_portalbrowsingmsgs"),
       new CardStatisticObject(m_asOwner.GetString(140, "ptmsgs_portalbrowsingmsgs"),
       strPopularity, null));
      xpCardInformation.PutElement(m_asOwner.GetString(142, "ptmsgs_portalbrowsingmsgs"),
       new CardStatisticObject(m_asOwner.GetString(142, "ptmsgs_portalbrowsingmsgs"),
       strAccessCount, null));
      xpCardInformation.PutElement(m_asOwner.GetString(143, "ptmsgs_portalbrowsingmsgs"),
       new CardStatisticObject(m_asOwner.GetString(143, "ptmsgs_portalbrowsingmsgs"),
       null, arCardPaths));
      td.m_xpBasicProperties = xpBasicProperties;
      td.m_xpCustomProperties = xpCustomProperties;
      td.m_xpCardInformation = xpCardInformation;
    }
    public virtual bool LoadFoldersAndDocuments()
    {
      LoadNewAndUpdatedDates();
      LoadTempUserPrefs();
      bool bLoadedFolderSuccess = QueryFolders(m_nCurrentFolderID);
      if (false == InRootFolder())
      {
        if (bLoadedFolderSuccess)
        {
          if ((DirConstants.BROWSE_MODE == m_nDirMode) && (DirConstants.BROWSE_BY_SEARCH == GetBrowseBy()))
          {
            QueryDocumentsSEARCH(m_nCurrentFolderID);
            // After getting all the documents in current folder Load Tags for 
            // these documents from Search Result
            LoadDocumentsTags();
          } else
          // edit or 508
          {
            QueryDocumentsEDIT(m_nCurrentFolderID);
          }
        }
      }
      // Mark that we have completed loading on the temp data.  This replaces
      // the hack used to fix bug#25242.
      ((DirTempData) GetTempData()).m_bLoadedFolder = bLoadedFolderSuccess;
      return bLoadedFolderSuccess;
    }
    public virtual void LoadNewAndUpdatedDates()
    {
      XPCalendar xpNewCal = XPCalendar.GetInstance();
      xpNewCal.Add(XPCalendar.DATE, -s_nNumDaysToDisplayNewTag);
      m_xpNewTagDate = xpNewCal.GetTime();
      xpNewCal = XPCalendar.GetInstance();
      xpNewCal.Add(XPCalendar.DATE, -s_nNumDaysToDisplayUpdatedTag);
      m_xpUpdateTagDate = xpNewCal.GetTime();
    }
    public virtual XPDateTime GetObjectNewTagDate()
    {
      return m_xpNewTagDate;
    }
    
    /// <returns></returns>
    public virtual XPDateTime GetObjectUpdateTagDate()
    {
      return m_xpUpdateTagDate;
    }
    public virtual void LoadUserPrefs()
    {
      try
      {
        String strOpenDocInNewWindow = null;
        try
        {
          strOpenDocInNewWindow = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.OPEN_DOC_NEW_WINDOW,
           m_asOwner);
        }
        catch (Exception e)
        {
          // Set this setting if it has not yet been set.
          PTPersonalSettingsHelper.SetAndCachePersonalSetting(PersonalSettingNames.OPEN_DOC_NEW_WINDOW,
           0, m_asOwner);
        }
        if (null != strOpenDocInNewWindow)
        {
          m_bOpenDocInNewWindow = strOpenDocInNewWindow.Equals("1");
        }
      }
      catch (Exception e)
      {
      }
    }
    private void LoadTempUserPrefs()
    {
      DirTempData td = (DirTempData) GetTempData();
      td.m_xpLocale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner);
      td.m_xpTimeZone = PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner);
      }
    public virtual bool GetUserPrefOpenDocInNewWindow()
    {
      return m_bOpenDocInNewWindow;
    }
    public virtual XPLocale GetUserPrefLocale()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_xpLocale;
    }
    public virtual XPTimeZone GetUserPrefTimeZone()
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_xpTimeZone;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#MoveCards(int[], int)
     */
     
    public virtual void MoveCards(int[] arCardIDs, int nTargetFolder)
    {
      try
      {
        //if moving to the same folder, give the user an error message -mgs
        if (m_nCurrentFolderID == nTargetFolder)
        {
          UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
           null, m_asOwner.GetString(1891, "ptmsgs_portalbrowsingmsgs"), "");
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          } else
        // do the move
        {
          Object[] aResults = m_ptSession.GetCatalog().MoveCards(m_nCurrentFolderID,
           arCardIDs, 
          // just like 4.5ws, move as approved and bAddOnlyAtSpecifiedApprovalState = false
          nTargetFolder, PT_CARDREF_STATES.PT_APPROVED, false);
          //check for pt_e_accessdenied being returned too
          for (int i = 0;i < aResults.Length;i++)
          {
            if (PT_RESULTCODES.PT_E_ACCESSDENIED == XPConvert.ToInteger(aResults[i]))
            {
              UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
               null, m_asOwner.GetString(2024, "ptmsgs_portalbrowsingmsgs"),
               "");
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
            }
          }
        }
      }
      catch (PTException pte)
      {
        RaiseError(m_asOwner.GetString(1732, "ptmsgs_portalbrowsingmsgs"),
         pte.GetMessage());
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#MoveFolders(int[], int)
     */
     
    public virtual void MoveFolders(int[] arFolderIDs, int nTargetFolder)
    {
      String sErrorMsgs = "";
      String sExtendedErrorMsgs = "";
      int nNumFolders = arFolderIDs.Length;
      for (int i = 0;i < nNumFolders;i++)
      {
        int nFolderID = arFolderIDs[i];
        try
        {
          m_ptSession.GetCatalog().MoveFolder(nFolderID, nTargetFolder);
        }
        catch (PTException pte)
        {
          String strUIErrorString = "";
          try
          {
            String strFolderName = m_ptSession.GetCatalog().OpenFolder(nFolderID,
             false).GetLocalizedName();
            strUIErrorString = XPResourceManager.FormatMessage(m_asOwner.GetString(1729,
             "ptmsgs_portalbrowsingmsgs"), strFolderName) + "  ";
          }
          catch (PTException ptex)
          {
            strUIErrorString = XPResourceManager.FormatMessage(m_asOwner.GetString(1736,
             "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nFolderID)) + "  ";
            }
          sErrorMsgs+=strUIErrorString;
          sExtendedErrorMsgs+=pte.GetMessage() + "  ";
        }
      }
      if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
      {
        RaiseError(sErrorMsgs, sExtendedErrorMsgs);
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#OpenSubFolder(int)
     */
     
    public virtual void OpenSubFolder(int ID)
    {
      m_nCurrentFolderID = ID;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual int RefreshItemFromCopyTargetFolderTree()
    {
      AActivitySpace asTree = m_asOwner.GetSubSpace(strCopyTargetFolderTREESUBSPACE);
      ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
      XPArrayList itemList = treeModel.GetSelectedItems();
      if (itemList.GetSize() != 1)
      {
        log.Error("Tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
        }
      TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
      if (item == null)
      {
        log.Error("Tree selected item null");
      }
      return item.m_nObjectID;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual int RefreshItemFromDataSourceTree()
    {
      AActivitySpace asTree = m_asOwner.GetSubSpace(strDataSourceTREESUBSPACE);
      ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
      XPArrayList itemList = treeModel.GetSelectedItems();
      if (itemList.GetSize() != 1)
      {
        log.Error("Tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
        }
      TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
      if (item == null)
      {
        log.Error("Tree selected item null");
      }
      return item.m_nObjectID;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual int RefreshItemFromMoveTargetFolderTree()
    {
      AActivitySpace asTree = m_asOwner.GetSubSpace(strMoveTargetFolderTREESUBSPACE);
      ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
      XPArrayList itemList = treeModel.GetSelectedItems();
      if (itemList.GetSize() != 1)
      {
        log.Error("Tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
        }
      TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
      if (item == null)
      {
        log.Error("Tree selected item null");
      }
      return item.m_nObjectID;
    }
    //////////////////////////////////////
    // Edit Mode methods - (form posting)
    //////////////////////////////////////
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    /// <returns>int Page status for server side validation</returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return DirRepostControl.PAGE_STATUS_VALID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitMode(int)
     */
     
    public virtual void SetCardSubmitMode(int nCardID)
    {
      m_nCardSubmitMode = nCardID;
    }
    public virtual int GetCardSubmitMode()
    {
      return m_nCardSubmitMode;
    }
    // Card Properties
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardID(int)
     */
     
    public virtual void SetCardID(int nCardID)
    {
      DirTempData td = (DirTempData) GetTempData();
      m_nCurrentCardID = nCardID;
      td.m_ptCurrentCard = m_ptSession.GetCatalog().OpenCard(nCardID, false);
      LoadCardProperties();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#ClearCardRange()
     */
     
    public virtual void ClearCardRange()
    {
      SetCardRange(-1, -1);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardRange(int, int)
     */
     
    public virtual void SetCardRange(int nRangeBegin, int nRangeEnd)
    {
      m_nRangeBegin = nRangeBegin;
      m_nRangeEnd = nRangeEnd;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitDataSource(int)
     */
     
    public virtual void SetCardSubmitDataSource(int nDataSourceID)
    {
      m_nCSSelectedDataSource = nDataSourceID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitURL(java.lang.String)
     */
     
    public virtual void SetCardSubmitURL(String strURL)
    {
      m_bCSSaveURL = true;
      m_strCSSelectedURL = strURL;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetDocUploadParams(java.lang.String, java.lang.String)
     */
     
    public virtual void SetDocUploadParams(String _duID, String _duServer)
    {
      m_duID = _duID;
      m_duServer = _duServer;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitName(java.lang.String)
     */
     
    public virtual void SetCardSubmitName(String strName)
    {
      m_bCSSaveURL = true;
      m_strCSCardName = strName;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitDescription(java.lang.String)
     */
     
    public virtual void SetCardSubmitDescription(String strDescription)
    {
      m_bCSSaveURL = true;
      m_strCSCardDescription = strDescription;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitFolder(int)
     */
     
    public virtual void SetCardSubmitFolder(int _nFolderID)
    {
      m_nCSCardFolder = _nFolderID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModelRO#GetCardSubmitFolder()
     */
     
    public virtual int GetCardSubmitFolder()
    {
      if (m_nCSCardFolder > 0)
      {
        return m_nCSCardFolder;
      }
      return m_nCurrentFolderID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetCardSubmitError(int)
     */
     
    public virtual void SetCardSubmitError(int _nErrorCode)
    {
      m_nCSError = _nErrorCode;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetDefaultCardRefreshSettings(int)
     */
     
    public virtual void SetDefaultCardRefreshSettings(int nCardID)
    {
      // set Refresh Settings
      IPTCardRefreshAgent ptCardRefreshAgent = (IPTCardRefreshAgent) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_CARD_REFRESH_AGENT,
       false);
      IPTCardRefreshInfo ptCardRefreshInfo = ptCardRefreshAgent.GetCardRefreshInfo(nCardID);
      ptCardRefreshInfo.SetCardMissingDocumentDeletionDelay(PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY,
       2);
      ptCardRefreshInfo.SetCardRefreshRate(PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY,
       3);
      // default?
      ptCardRefreshInfo.SetCheckLinkOnly(false);
      // Set Last refresh date to NOW
      XPCalendar gcDateNow = XPCalendar.GetInstance();
      XPDateTime dtNowDate = gcDateNow.GetTime();
      ptCardRefreshInfo.SetCardLastRefreshedDate(dtNowDate);
      XPCalendar gcDateNextRefresh = XPCalendar.GetInstance();
      gcDateNextRefresh.Add(ConvertCalendarUnit(PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY),
       3);
      // Calculate Next refresh date
      XPDateTime dtNextRefreshDate = gcDateNextRefresh.GetTime();
      ptCardRefreshInfo.SetCardNextRefreshDate(dtNextRefreshDate);
      // Don't set Expiration... defaults to NULL
      IPTPersist ptCardRefreshInfoPersist = (IPTPersist) ptCardRefreshInfo;
      ptCardRefreshAgent.SetCardRefreshInfo(nCardID, ptCardRefreshInfoPersist.SaveToXML(0));
      }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetDirectoryMode(int)
     */
     
    public virtual void SetDirectoryMode(int nMode)
    {
      m_nDirMode = nMode;
    }
    /////////////////////////////////////////
    // Write methods from IFolderModel
    /////////////////////////////////////////
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModel#SetFirstItemIndex(int)"></seealso>
    public virtual void SetFirstItemIndex(int nFirstItemIndex)
    {
      m_nRangeBegin = nFirstItemIndex + 1;
    }
    
    /// <summary>
    /// Opens the requested subfolder and sets the mode as appropriate.
    /// </summary>
    public virtual void SetFolderIDAndMode(int ID, int nMode)
    {
      m_nCurrentFolderID = ID;
      m_nDirMode = nMode;
    }
    
    /// <param name="bFolders"></param>
    public virtual void SetFoldersForDeleteCheck(bool bFolders)
    {
      m_bFoldersForDeleteCheck = bFolders;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModel#SetLastItemIndex(int)"></seealso>
    public virtual void SetLastItemIndex(int nLastItemIndex)
    {
      m_nRangeEnd = nLastItemIndex + 1;
    }
    
    /// <param name="nFolderID"></param>
    public virtual void SetMoreFolderID(int nFolderID)
    {
      DirTempData td = (DirTempData) GetTempData();
      td.m_nMoreFolderID = nFolderID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModel#SetNumColumns(int)"></seealso>
    public virtual void SetNumColumns(int nNumColumns)
    {
      m_nNumFoldCol = nNumColumns;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetObjectType(int)
     */
     
    public virtual void SetObjectType(int nNewObjectType)
    {
    }
    
    /// <param name="nCategoryID"></param>
    public virtual void SetRRCategory(int nCategoryID)
    {
      DirTempData td = (DirTempData) GetTempData();
      td.m_nCurrentRRCategoryID = nCategoryID;
    }
    
    /// <param name="nObjectID"></param>
    public virtual void SetRRObjectID(int nObjectID)
    {
      DirTempData td = (DirTempData) GetTempData();
      td.m_nCurrentRRObjectID = nObjectID;
    }
    
    /// <param name="nSortByPropID"></param>
    public virtual void SetSortByPropID(int nSortByPropID)
    {
      m_nSortingPropertyID = nSortByPropID;
    }
    // END DIRECTORY PREFERENCES
    public virtual bool ShowFolderActionBanner()
    {
      bool bBrowseModeInRootFolder = InRootFolder() && (DirConstants.BROWSE_MODE == m_nDirMode);
      if (bBrowseModeInRootFolder)
      {
        return false;
      }
      DirTempData td = (DirTempData) GetTempData();
      bool bHasSelectAccessOnFolder;
      if (null == td.m_ptCurrentFolder)
      {
        bHasSelectAccessOnFolder = m_ptSession.GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
         m_nCurrentFolderID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
      } else
      {
        IPTServerContext ptSC = (IPTServerContext) td.m_ptCurrentFolder;
        bHasSelectAccessOnFolder = PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT <= ptSC.GetAccessLevel();
        }
      return bHasSelectAccessOnFolder;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectModelRO#ShowObjectBanner()"></seealso>
    public virtual bool ShowObjectBanner()
    {
      return false;
    }
    
    /// <returns></returns>
    public virtual bool ShowRelatedResources()
    {
      DirTempData td = (DirTempData) GetTempData();
      // not in root folder
      return ((false == InRootFolder()) && 
      // not in unclassifed folder
      (false == InUnclassifiedCardsFolder()) && 
      // no resources selected
      (((null != td.m_asqrRelatedCommunities) || (null != td.m_asqrRelatedFolders) || (null != td.m_asqrRelatedPortlets) || (null != td.m_asqrRelatedExperts) || (null != td.m_asqrRelatedContentManagers)) || 
      // has self-select rights
      HasSelfSelectExpertRightOnThisFolder()));
    }
    /* *********************************************************************
     * the following methods deal with webservices that support uploads
     *
     * *********************************************************************/
     
    
    /// <returns>
    /// boolean true if the specified data source is valid for
    /// simple submit (i.e. web, or remote document upload).
    /// </returns>
    public virtual bool IsValidSimpleSubmitSource(int _nDataSourceID)
    {
      // NOTE: The Publisher KD and Crawler Data Sources are set incorrectly
      // to be of type simple and advanced, but they are not (Bug#69636).
      if (0 >= _nDataSourceID)
      {
        return false;
      }
      /* web data sources are valid */
      if (IsWebDataSource(_nDataSourceID))
      {
        return true;
      }
      IPTWebService service = GetWebService(_nDataSourceID);
      /* upload support is specified on the data source's web service */
      int type = service.GetCardSubmitType();
      if (0 == (type & PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD))
      {
        // If it doesn't support upload, then it isn't valid.
        return false;
      }
      // NOTE: The publisher sources are also missing upload URLs,
      // but the previous check should catch them.
      return true;
    }
    
    /// <summary>
    /// Returns true if the specified data source supports remote document 
    /// upload.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool SupportsUpload(int _nDataSourceID)
    {
      bool bSupportsUpload = false;
      try
      {
        if (0 >= _nDataSourceID)
        {
          return false;
        }
        /* web data sources do not support upload */
        if (IsWebDataSource(_nDataSourceID))
        {
          return false;
        }
        /* upload support is specified on the data source's web service */
        IPTWebService contentService = GetWebService(_nDataSourceID);
        int type = contentService.GetCardSubmitType();
        bSupportsUpload = (0 != (type & PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD));
        }
      catch (PTException ex)
      {
        log.Error(ex, "DirModel::SupportsUpload Error retrieving Data Source " + _nDataSourceID + ".");
        }
      return bSupportsUpload;
    }
    private IPTWebService GetWebService(int _nDataSourceID)
    {
      int nWebServiceID = GetWebServiceID(_nDataSourceID);
      IPTWebService myWebService = (IPTWebService) m_ptSession.GetWebServices().Open(nWebServiceID,
       false);
      return myWebService;
    }
    public virtual int GetWebServiceID(int _nDataSourceID)
    {
      int nWebServiceID = ((IPTDataSource) m_ptSession.GetDataSources().Open(_nDataSourceID,
       false)).GetWebServiceID();
      return nWebServiceID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.IBaseSearchResultModelRO.GetWarning()"></seealso>
    public virtual SearchExecutionWarning GetWarning()
    {
      return _warning;
    }
    
    /// <summary>
    /// Returns the webservice's upload url if it supports uploads and it is set. 
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetUploadWSURL(int _nDataSourceID)
    {
      /* web data sources do not support upload */
      if (IsWebDataSource(_nDataSourceID))
      {
        return "";
      }
      /* attempt to get the upload url */
      IPTWebService myWebService = GetWebService(_nDataSourceID);
      String sUploadUrl = myWebService.GetAbsoluteURL(AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL);
      /* not all webservices will have this */
      return (sUploadUrl == null ? "" : sUploadUrl);
    }
    /* *********************************************************************
     *  The following are different ways of submitting a card
     *
     * ********************************************************************/
     
    // SCC: this version uses the parameters stored on the model.
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SubmitCard()
     */
     
    public virtual void SubmitCard()
    {
      int nFolder = GetCardSubmitFolder();
      if (!CheckForValidCardSubmitFolder(nFolder))
      {
        return;
      }
      IXPPropertyBag pbag = CreateCardSubmitPropertyBag(m_strCSSelectedURL,
       m_nCSSelectedDataSource);
      SubmitCardWithPropertyBag(m_nCSSelectedDataSource, m_strCSCardName,
       m_strCSCardDescription, pbag, nFolder);
    }
    /* this version will create the pbag using the specified path and DS. */
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SubmitCard(java.lang.String, int)
     */
     
    public virtual void SubmitCard(String _strPath, int _nCSSelectedDataSource)
    {
      int nFolder = GetCardSubmitFolder();
      if (!CheckForValidCardSubmitFolder(nFolder))
      {
        return;
      }
      IXPPropertyBag pbag = CreateCardSubmitPropertyBag(_strPath, _nCSSelectedDataSource);
      SubmitCardWithPropertyBag(_nCSSelectedDataSource, null, null, pbag,
       nFolder);
    }
    /* this version will create an Upload pbag */
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SubmitCard(java.lang.String, java.lang.String, java.lang.String)
     */
     
    public virtual void SubmitCard(String _path, String _type, String _docID)
    {
      int nFolder = GetCardSubmitFolder();
      if (!CheckForValidCardSubmitFolder(nFolder))
      {
        return;
      }
      IXPPropertyBag pbag = CreateCardSubmitUploadPropertyBag(_path, _type,
       _docID);
      SubmitCardWithPropertyBag(m_nCSSelectedDataSource, m_strCSCardName,
       m_strCSCardDescription, pbag, nFolder);
    }
    private bool CheckForValidCardSubmitFolder(int _nFolderID)
    {
      if (_nFolderID == PT_INTRINSICS.PT_FOLDER_ROOTFOLDER)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_asOwner.GetString(1726, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1726,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        //			throw new XPException(m_asOwner.GetString(1726, "ptmsgs_portalbrowsingmsgs"));
        return false;
      }
      return true;
    }
    //	public void UpdatePropertiesForDocUpload(String _id, String _server)
    //	{
    //		/* get the card and it's property values */
    //		IPTCard ptCard = m_ptSession.GetCatalog().OpenCard(m_nCurrentCardID, true);
    //		IPTCardPropertyValues ptPropValues = ptCard.GetPropertyValues();
    //		
    //		/* Document Upload ID */
    //		IPTCardPropertyValue ptValue = ptPropValues.Add(PT_INTRINSICS.PT_PROPERTY_UPLOAD_DUID);
    //		ptValue.SetOverrideValue(_id); /* make this an override value so it is not lost on a re-index */
    //		
    //		/* Document Upload Server */
    //		ptValue = ptPropValues.Add(PT_INTRINSICS.PT_PROPERTY_UPLOAD_DUSERVER);
    //		ptValue.SetOverrideValue(_server); /* make this an override value so it is not lost on a re-index */
    //		
    //		/* save card */
    //		IPTServerContext ptSC = (IPTServerContext) ptCard.GetInterfaces("IPTServerContext");
    //		ptSC.Store();
    //		ptSC.UnlockObject();
    //	}
    /* helper method that creates a pbag based on the path and DS */
    private IXPPropertyBag CreateCardSubmitPropertyBag(String strPath, int nDataSourceID)
    {
      int nWebServiceID = ((IPTDataSource) m_ptSession.GetDataSources().Open(nDataSourceID,
       false)).GetWebServiceID();
      IPTDataSource ptDS = (IPTDataSource) m_ptSession.GetDataSources().Open(nDataSourceID,
       false);
      Object ptSubmitHelper;
      if (IsWebDataSource(nDataSourceID))
      // Web Submit Helper
      {
        ptSubmitHelper = m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_WEB_SUBMIT_HELPER,
         false);
      } else
      // SOAP Submit Helper
      {
        ptSubmitHelper = m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SUBMIT_HELPER,
         false);
      }
      // Initialize the Provider
      IPTDataSourceProvider ptDSP = (IPTDataSourceProvider) ptSubmitHelper;
      ptDSP.Initialize(ptDS.GetRepositoryInfo(), m_ptSession, nWebServiceID);
      IPTGenerateState ptGS = (IPTGenerateState) ptSubmitHelper;
      IXPPropertyBag pbagCardProp = ptGS.GenerateState(strPath);
      return pbagCardProp;
    }
    /* helper method that creates a pbag for webservices that support upload */
    public virtual IXPPropertyBag CreateCardSubmitUploadPropertyBag(String _path,
     String _type, String _docID)
    {
      IXPPropertyBag pbagCardProp;
      pbagCardProp = PortalObjectsFactory.CreatePropertyBag();
      pbagCardProp.Write("PTC_PBAGFORMAT", 2000);
      pbagCardProp.Write("PTC_DTM_SECT", XPConvert.ToInteger(_type));
      pbagCardProp.Write("PTC_UNIQUE", _path);
      pbagCardProp.Write("PTC_DOC_ID", _docID);
      return pbagCardProp;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SubmitCardWithPropertyBag(int, java.lang.String, java.lang.String, com.plumtree.openfoundation.util.IXPPropertyBag, int)
     */
     
    public virtual void SubmitCardWithPropertyBag(int nDataSourceID, String strCardName,
     String strCardDescription, IXPPropertyBag pbagCardProp, int nFolderID)
    {
      // SCC: It is important that this is set before the card is submitted so that we know when to reset the m_nCardSubmitMode flag
      m_bCSSaveURL = false;
      // Set Parent Folder
      int[] arFolderIDs = new int[]{nFolderID};
      // Set Language to be that of the default locale
      // Retrieve the SearchLocaleVarPack to verify the language
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      PTSearchLocaleVarPack vpPTSearchLocales = (PTSearchLocaleVarPack) application.GetVarPackManager().GetVariablePackage(PTSearchLocaleVarPack.VARPACK_ID);
      // Retrieve the user's default language:
      String strCardLanguageCode = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       m_asOwner);
      // JHQ 020204 - bug 27552: special case for chinese languages
      // search supports zh_cn and zh_tw
      if (CHINESE_LANGUAGE_CODE.Equals(strCardLanguageCode))
      {
        String strTempLocaleCode = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE,
         m_asOwner);
        // uppercase in case locale was returned in all lowercase or mixed
        // case because are ending locales need to be uppercase 
        strTempLocaleCode = XPStringUtility.ToUpperCase(strTempLocaleCode);
        // check the ending locale code and map to appropriate chinese locale
        if (XPStringUtility.EndsWith(strTempLocaleCode, CHINESE_LOCALE_CODE_HK))
        {
          strCardLanguageCode = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_TW;
          } else
        if (XPStringUtility.EndsWith(strTempLocaleCode, CHINESE_LOCALE_CODE_MO))
        {
          strCardLanguageCode = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_TW;
          } else
        if (XPStringUtility.EndsWith(strTempLocaleCode, CHINESE_LOCALE_CODE_CN))
        {
          strCardLanguageCode = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_CN;
          } else
        if (XPStringUtility.EndsWith(strTempLocaleCode, CHINESE_LOCALE_CODE_SG))
        {
          strCardLanguageCode = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_CN;
          } else
        if (XPStringUtility.EndsWith(strTempLocaleCode, CHINESE_LOCALE_CODE_TW))
        {
          strCardLanguageCode = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_TW;
          }
      }
      // Error handling for invalid languages
      if (false == vpPTSearchLocales.IsValidLanguage(strCardLanguageCode))
      {
        strCardLanguageCode = m_strDefaultInxightLanguage;
        if (false == vpPTSearchLocales.IsValidLanguage(strCardLanguageCode))
        {
          // otherwise set it to english
          strCardLanguageCode = ENGLISH_LOCALE_CODE;
        }
      }
      SubmitCardWithPropertyBag(arFolderIDs, strCardLanguageCode, 0, nDataSourceID,
       pbagCardProp, strCardName, strCardDescription);
      m_nCSSelectedDataSource = -1;
      m_strCSSelectedURL = null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SubmitCardWithPropertyBag(int[], java.lang.String, int, int, com.plumtree.openfoundation.util.IXPPropertyBag, java.lang.String, java.lang.String)
     */
     
    public virtual void SubmitCardWithPropertyBag(int[] arFolderIDs, String strLanguage,
     int nDocTypeID, int nDataSourceID, IXPPropertyBag pbagCardProp, String strCardName,
     String strCardDescription)
    {
      // Create the Card
      IPTCard ptCard = m_ptSession.GetCatalog().CreateCard();
      ptCard.SetContentLanguage(strLanguage);
      // Parent IDs can be a single value or an array of values
      ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_PARENTFOLDERIDS, arFolderIDs);
      // if the index server isn't up, don't try to index, create the card
      // and inform the user later
      IXPPropertyBag statusBag = m_ptSession.GetCatalog().GetSearchServerStatus();
      SearchServerStatusInfo statusInfo = new SearchServerStatusInfo(statusBag,
       "INDEXSTATUS");
      if (XPStringUtility.EqualsIgnoreCase(statusInfo.connectStatus, "OK"))
      {
        ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INDEXONSTORE, 1);
        } else
      {
        ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INDEXONSTORE, 0);
        log.Error("The index server did not respond. ERROR: " + statusInfo.connectStatus);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_asOwner.GetString(1812, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1812,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INSERTAPPROVED, 1);
      /* inherit parent folder ACLs */
      ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INHERITPARENTFOLDERPERMISSIONS,
       1);
      // Set the crawler tag to be "Manual"
      ptCard.SetCrawlerTag(m_asOwner.GetString(1635, "ptmsgs_portalbrowsingmsgs"));
      if (null != strCardName)
      {
        ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_OVERWRITENAME, 0);
        ptCard.SetName(strCardName);
      }
      if (null != strCardDescription)
      {
        ptCard.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_OVERWRITEDESCRIPTION,
         0);
        ptCard.SetDescription(strCardDescription);
      }
      ptCard.SetDocumentLocation(pbagCardProp);
      ptCard.SetDataSourceID(nDataSourceID);
      //Get the DocumentTypeMap
      if (0 == nDocTypeID)
      {
        // Determine Default
        IPTDocumentTypeMap ptMap;
        ptMap = (IPTDocumentTypeMap) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_DOCUMENTTYPEMAP,
         false);
        ptMap.Initialize(m_ptSession);
        nDocTypeID = ptMap.LookupByPropBag(pbagCardProp);
        // If no default DocType was found, determine what default DocType should be used based on the server config setting
        if (0 == nDocTypeID)
        {
          IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
          PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager().GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
          nDocTypeID = vpPTDirPrefs.GetDefaultDocType();
          // If the default is 0, then this means that the card is not to be imported
          if (0 == nDocTypeID)
          {
            throw new XPException(m_asOwner.GetString(1221, "ptmsgs_portalbrowsingmsgs"));
            }
        }
      }
      IPTDataSource ptDS = (IPTDataSource) m_ptSession.GetDataSources().Open(nDataSourceID,
       false);
      String strCardPropBagXML = pbagCardProp.SaveToXML(0);
      ptDS.ImportDocument(strCardPropBagXML, nDocTypeID, ptCard, true, null);
      /* set file upload properties if existent */
      if (null != m_duID && null != m_duServer)
      {
        /* get the card and it's property values */
        IPTCardPropertyValues ptPropValues = ptCard.GetPropertyValues();
        /* Document Upload ID */
        IPTCardPropertyValue ptValue = ptPropValues.Add(PT_INTRINSICS.PT_PROPERTY_UPLOAD_DUID);
        /* make this an override value so it is not lost on a re-index */
        ptValue.SetOverrideValue(m_duID);
        /* Document Upload Server */
        ptValue = ptPropValues.Add(PT_INTRINSICS.PT_PROPERTY_UPLOAD_DUSERVER);
        /* make this an override value so it is not lost on a re-index */
        ptValue.SetOverrideValue(m_duServer);
        m_duID = null;
        m_duServer = null;
      }
      //store the card
      IPTServerContext ptSC = (IPTServerContext) ptCard;
      ptSC.Store();
      ptSC.UnlockObject();
      m_nCurrentCardID = ptSC.GetObjectID();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#doApproval(int[], int)
     */
     
    public virtual void doApproval(int[] arCardIDs, int nAction)
    /* 2 for approve, 1 for unapprov*/
    {
      try
      {
        int[] arFolderIDs = {m_nCurrentFolderID};
        int nNumCards = arCardIDs.Length;
        for (int i = 0;i < nNumCards;i++)
        {
          int nCardID = arCardIDs[i];
          m_ptSession.GetCatalog().SetApprovalStateByCard(nCardID, nAction,
           arFolderIDs);
        }
      }
      catch (XPException xpe)
      {
        throw new XPException(STR_MVC_CLASS_NAME + "::doApproval Error in setting card approval" + xpe.GetMessage(),
         xpe);
      }
    }
    
    /// <param name="arCardPropIDs"></param>
    /// <param name="nPropID"></param>
    /// <returns></returns>
    public virtual bool doesPropertyDescribeCard(Object[] arCardPropIDs, int nPropID)
    {
      for (int i = 0;i < arCardPropIDs.Length;i++)
      {
        if (nPropID == XPConvert.ToInteger(arCardPropIDs[i]))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <param name="unit"></param>
    /// <returns></returns>
    private int ConvertCalendarUnit(int unit)
    {
      switch (unit){
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_ANNUALY:
      return XPCalendar.YEAR;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY:
      return XPCalendar.MONTH;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY:
      return XPCalendar.WEEK_OF_YEAR;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY:
      return XPCalendar.DATE;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY:
      return XPCalendar.HOUR;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY:
      return XPCalendar.MINUTE;
      break;
      }
      return XPCalendar.MINUTE;
    }
    
    /// <param name="cpo"></param>
    /// <returns></returns>
    private bool IsBasicCardProperty(CardPropertyObject cpo)
    {
      int nPropID = cpo.m_nPropID;
      bool bReadOnly = cpo.m_bIsReadOnly;
      return ((CardPropertyObject.ID_OF_NAME == nPropID) || (CardPropertyObject.ID_OF_DESC == nPropID) || (CardPropertyObject.ID_OF_DOC_TYPE_PROP == nPropID) || (CardPropertyObject.ID_OF_OPEN_DOC_URL == nPropID) || (CardPropertyObject.ID_OF_CRAWLER_TAG == nPropID) || bReadOnly);
      }
    ////////////////////////
    // Related Resources
    ////////////////////////
    private void LoadAllRelatedResources()
    {
      DirTempData td = (DirTempData) GetTempData();
      try
      {
        // BEGIN Retrieve the Related Resource Display Options
        IPTSubPortalInfo ptSubPortalInfo = m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
        int nRRAccessType = ptSubPortalInfo.GetRelatedResourcesAccessType();
        bool bViewRRCommunities = (0 != (nRRAccessType & PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_COMMUNITIES_ACCESS));
        bool bViewRRFolders = (0 != (nRRAccessType & PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_FOLDERS_ACCESS));
        bool bViewRRPortlets = (0 != (nRRAccessType & PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_PORTLETS_ACCESS));
        bool bViewRRExperts = (0 != (nRRAccessType & PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_EXPERTS_ACCESS));
        bool bViewRRContentManagers = (0 != (nRRAccessType & PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_CONTENTMANAGERS_ACCESS));
        // Don't display Related Portlets in 508 mode (bug 20040)
        if (DirConstants.DISABILITY_MODE == m_nDirMode)
        {
          bViewRRPortlets = false;
        }
        int nNumRRViewable = 0;
        if (bViewRRCommunities)
        {
          nNumRRViewable++;
        }
        if (bViewRRFolders)
        {
          nNumRRViewable++;
        }
        if (bViewRRPortlets)
        {
          nNumRRViewable++;
        }
        if (bViewRRExperts)
        {
          nNumRRViewable++;
        }
        if (bViewRRContentManagers)
        {
          nNumRRViewable++;
        }
        td.m_arRelatedResourceIDs = new int[nNumRRViewable];
        int nIndex = 0;
        if (bViewRRCommunities)
        {
          td.m_arRelatedResourceIDs[nIndex++] = PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES;
          }
        if (bViewRRFolders)
        {
          td.m_arRelatedResourceIDs[nIndex++] = PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS;
          }
        if (bViewRRPortlets)
        {
          td.m_arRelatedResourceIDs[nIndex++] = PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS;
          }
        if (bViewRRExperts)
        {
          td.m_arRelatedResourceIDs[nIndex++] = PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS;
          }
        if (bViewRRContentManagers)
        {
          td.m_arRelatedResourceIDs[nIndex++] = PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS;
          }
        // END Retrieve the Related Resource Display Options
        // Retrieve the Related Resources
        Object[] arRRValues = (Object[]) td.m_ptCurrentFolder.GetRelatedResources(td.m_arRelatedResourceIDs);
        for (int i = 0;i < td.m_arRelatedResourceIDs.Length;i++)
        {
          // Retrieve values for this single RR
          IPTQueryResult ptQR = (IPTQueryResult) arRRValues[i];
          if (null == ptQR)
          {
            continue;
          }
          switch (td.m_arRelatedResourceIDs[i]){
          case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
          td.m_asqrRelatedCommunities = new ASQueryResultWrapper(ptQR);
          break;
          case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS:
          td.m_asqrRelatedFolders = new ASQueryResultWrapper(ptQR);
          break;
          case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
          td.m_asqrRelatedPortlets = new ASQueryResultWrapper(ptQR);
          break;
          case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
          td.m_asqrRelatedExperts = new ASQueryResultWrapper(ptQR);
          break;
          case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
          td.m_asqrRelatedContentManagers = new ASQueryResultWrapper(ptQR);
          break;
          }
        }
      }
      // End for loop
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t retrieve Related Resources");
      }
    }
    
    /// <param name="ID"></param>
    private void QueryDocumentsEDIT(int ID)
    {
      DirTempData td = (DirTempData) GetTempData();
      int nSkipResults;
      int nMaxResults;
      try
      {
        // We don't show cards in the root folder
        if (m_nCurrentFolderID == PT_INTRINSICS.PT_FOLDER_ROOTFOLDER)
        {
          nSkipResults = 0;
          nMaxResults = 0;
          td.m_asqrDocuments = null;
        } else
        {
          // When opening a new folder, start at the beginning
          if ((1 > m_nRangeBegin) || (1 > m_nRangeEnd))
          {
            m_nRangeBegin = 1;
            nSkipResults = 0;
            nMaxResults = GetNumDocsPerPage();
          } else
          {
            // Set # Skipped
            // 0 based
            nSkipResults = m_nRangeBegin - 1;
            // Set # Max Results
            int nRangeSize = m_nRangeEnd - m_nRangeBegin + 1;
            nMaxResults = (nRangeSize <= 0) ? GetNumDocsPerPage() : nRangeSize;
            }
          bool bShowUnapproved;
          bool bCanApprove = HasAccessToApproveCardInFolder();
          // Do we show approved cards or not?
          if (m_nDirMode == DirConstants.EDIT_MODE && bCanApprove)
          {
            bShowUnapproved = true;
          } else
          {
            bShowUnapproved = false;
          }
          int nPropIDMask = PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_IMAGEUUID | PT_PROPIDS.PT_PROPID_CREATED | PT_PROPIDS.PT_PROPID_LASTMODIFIED | PT_PROPIDS.PT_PROPID_FOLDER_CARDAPPROVALSTATE | PT_PROPIDS.PT_PROPID_CARD_DOCUMENTTYPEID | PT_PROPIDS.PT_PROPID_CARD_CONTENTLANGUAGE;
          // Sort By Property
          int[][] arrSort;
          Object oDefaultDatabaseOrderBy = td.m_ptCurrentFolder.GetDefaultOrderBy();
          if (null == oDefaultDatabaseOrderBy)
          {
            arrSort = null;
          } else
          {
            arrSort = new int[1][];
            for (int j2c_index = 0;j2c_index < 1;j2c_index++)
            {
              arrSort[j2c_index] = new int[2];
            }
            arrSort[0][0] = XPConvert.ToInteger(oDefaultDatabaseOrderBy);
            arrSort[0][1] = 1;
          }
          // Query for the documents
          PTSortedDocumentsQueryWrapper qwDocuments = new PTSortedDocumentsQueryWrapper(td.m_ptCurrentFolder);
          qwDocuments.SetMaxRows(nMaxResults);
          qwDocuments.SetSkippedRows(nSkipResults);
          qwDocuments.QueryCards(nPropIDMask, bShowUnapproved, arrSort, null);
          td.m_asqrDocuments = qwDocuments;
          td.m_nTotalResults = td.m_ptCurrentFolder.QueryCardsCount(bShowUnapproved);
          m_nRangeEnd = (m_nRangeBegin + qwDocuments.GetCount()) - 1;
        }
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        log.Error(e, "Document query through database failed.");
      }
    }
    
    /// <param name="ID"></param>
    private void QueryDocumentsSEARCH(int ID)
    {
      _warning = null;
      DirTempData td = (DirTempData) GetTempData();
      try
      {
        int nSkipResults;
        int nMaxResults;
        if ((1 > m_nRangeBegin) || (1 > m_nRangeEnd))
        {
          m_nRangeBegin = 1;
          nSkipResults = 0;
          nMaxResults = GetNumDocsPerPage();
        } else
        {
          // Set # Skipped
          // 0 based
          nSkipResults = m_nRangeBegin - 1;
          // Set # Max Results
          int nRangeSize = m_nRangeEnd - m_nRangeBegin + 1;
          nMaxResults = (nRangeSize <= 0) ? GetNumDocsPerPage() : nRangeSize;
          }
        int[] folderid = {ID};
        IPTSearchRequest ptSR = m_ptSession.GetSearchRequest();
        IPTSearchQuery ptQuery = ptSR.CreateBasicQuery("*", "");
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS, folderid);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
         false);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, new int[]{PT_CLASSIDS.PT_CATALOGCARD_ID});
        /* bug 19302 fix */
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE, "dirbrowse");
        // Set Search Order By
        int nDefaultSearchOrderBy;
        if (DirConstants.SORTING_NOTSET == m_nSortingPropertyID)
        {
          nDefaultSearchOrderBy = m_nSortingPropertyID = td.m_ptCurrentFolder.GetDefaultSearchOrderBy();
          // initially invert date sorts
          if (IsDateProperty(nDefaultSearchOrderBy))
          {
            nDefaultSearchOrderBy = m_nSortingPropertyID = -nDefaultSearchOrderBy;
            }
        } else
        {
          nDefaultSearchOrderBy = m_nSortingPropertyID;
        }
        int nAbsoluteSearchOrderBy = ((nDefaultSearchOrderBy > 0) ? nDefaultSearchOrderBy : -nDefaultSearchOrderBy);
        // Check if user has the right to browse using this property
        if (!m_ptSession.GetSessionInfo().CheckPropertySearchRight(nAbsoluteSearchOrderBy))
        {
          // if not, use NAME by default
          nDefaultSearchOrderBy = PT_INTRINSICS.PT_PROPERTY_OBJECTNAME;
        }
        //			// Sorting by Name is done by a special intrinsic property
        //			if (PT_INTRINSICS.PT_PROPERTY_OBJECTNAME == nAbsoluteSearchOrderBy)
        //			{
        //				nDefaultSearchOrderBy = ((nDefaultSearchOrderBy > 0)
        //					? PT_INTRINSICS.PT_PROPERTY_NAMEINDEX : -PT_INTRINSICS.PT_PROPERTY_NAMEINDEX);
        //			}
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, nDefaultSearchOrderBy);
        // name, description, created, modified, card image uiid
        bool bGetDescription = !GetDocDescriptionType().Equals(DirConstants.DIR_FOLD_DESC_NONE);
        int[] arPropIDs = new int[bGetDescription ? (6 + m_xpPropColumns.GetSize()) : (5 + m_xpPropColumns.GetSize())];
        int nPropIDIndex = 0;
        // 1
        arPropIDs[nPropIDIndex++] = PT_INTRINSICS.PT_PROPERTY_OBJECTNAME;
        if (true == bGetDescription)
        {
          // 2
          arPropIDs[nPropIDIndex++] = PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY;
          }
        // 4
        arPropIDs[nPropIDIndex++] = PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED;
        // 3
        arPropIDs[nPropIDIndex++] = PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED;
        // 7
        arPropIDs[nPropIDIndex++] = PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID;
        // Adding Pathways TagInfo to be returned from search server
        // pathways tags
        arPropIDs[nPropIDIndex++] = PT_INTRINSICS.PT_PROPERTY_PATHWAYS_TAGS_USERS;
        for (int i = 0;i < m_xpPropColumns.GetSize();i++)
        {
          Object[] arPropInfo = (Object[]) m_xpPropColumns.GetElement(i);
          int nPropID = XPConvert.ToInteger(arPropInfo[DirConstants.PROP_COLUMNS_INDEX_ID]);
          arPropIDs[nPropIDIndex++] = nPropID;
        }
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS, arPropIDs);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC, false);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, false);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, false);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, nSkipResults);
        ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, nMaxResults);
        /* If the Document Type ID is Positive only then we set the search option */
        if (m_nDocumentTypeId > 0)
        {
          ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DOCUMENT_TYPE,
           XPConvert.ToString(m_nDocumentTypeId));
        }
        td.m_ptSearchDocuments = ptSR.Search(ptQuery);
        td.m_nTotalResults = td.m_ptSearchDocuments.GetTotalMatches();
        m_nRangeEnd = (m_nRangeBegin + td.m_ptSearchDocuments.GetResultsReturned()) - 1;
        // Check for warnings
        int warning = td.m_ptSearchDocuments.GetWarning();
        if (PT_SEARCH_WARNING.PT_SEARCHWARNING_NONE != warning)
        {
          switch (warning){
          case PT_SEARCH_WARNING.PT_SEARCHWARNING_QUERY_TIMED_OUT:
          _warning = new QueryTimeoutWarning(m_asOwner);
          break;
          case PT_SEARCH_WARNING.PT_SEARCHWARNING_WILDCARD_TOO_GENERAL:
          _warning = new WildcardExpansionWarning(m_asOwner);
          break;
          case PT_SEARCH_WARNING.PT_SEARCHWARNING_QUERY_IS_PARTIAL:
          _warning = new PartialQueryWarning(m_asOwner);
          break;
          }
        }
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_asOwner.GetString(152, "ptmsgs_portalbrowsingmsgs"), e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        log.Error(e, "Document query through search failed.");
      }
    }
    
    /// <summary>
    /// This method is executed after Searching for Documents.
    /// it loads up all the tags 
    /// </summary>
    private void LoadDocumentsTags()
    {
      //Each Tag data item returned by search result is a concatenated string
      // as follows 'tag1$userid,tag2$userid,tag3$userid' . userid is the id of the user
      // who created the tag on the document.
      DirTempData td = (DirTempData) GetTempData();
      // Getting current User ID to determine if the tag is created by this user
      String strCurrentUserID = XPConvert.ToString(m_ptSession.GetSessionInfo().GetCurrentUserID());
      int ntotalDocs = td.m_ptSearchDocuments.GetResultsReturned();
      m_objDocsTags = new XPHashtable(ntotalDocs);
      for (int i = 0;i < ntotalDocs;i++)
      {
        int ndocId = td.m_ptSearchDocuments.GetFieldsAsInt(i, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
        String pathwaysTagString = td.m_ptSearchDocuments.GetFieldsAsString(i,
         PT_INTRINSICS.PT_PROPERTY_PATHWAYS_TAGS_USERS);
        IXPList tagsList = new XPArrayList();
        if (pathwaysTagString != null)
        {
          log.Debug("Pathways Tags Info for document " + ndocId + " :" + pathwaysTagString);
          // Parsing the list of TagInfo
          XPStringTokenizer strTok = new XPStringTokenizer(pathwaysTagString,
           ",");
          // Parsing TagName and Owner ID.
          while (strTok.HasMoreTokens())
          {
            String strTagandOwner = strTok.GetNextToken();
            // Each Tag Info has only 2 values Name and Owner
            int index = XPStringUtility.LastIndexOf(strTagandOwner, "$");
            if (index > 0)
            {
              // Name of the Tag
              String strTagName = XPStringUtility.Trim(XPStringUtility.Substring(strTagandOwner,
               0, index));
              HashtableDataObject htObject = new HashtableDataObject();
              htObject.SetData(PathwaysConstants.TAG_VALUE, strTagName);
              // Owner ID is the value after last $ char in the concatenated string.
              String strTagUser = XPStringUtility.Substring(strTagandOwner,
               index + 1, strTagandOwner.Length);
              strTagUser = XPStringUtility.Trim(strTagUser);
              //Verify if this is applied by current user.
              bool bTagUser = (0 == XPStringUtility.Compare(strCurrentUserID,
               strTagUser));
              htObject.SetData(PathwaysConstants.TAG_OWNER, XPConvert.ToString(bTagUser));
              tagsList.Add(htObject);
            } else
            {
              throw new XPParseException("Failed to Parse Tag name and Owner from the token, it should contain \'$\' between tagname and owner id");
              }
          }
        }
        // Adding Tags to the HashTable containing Document ID as Key
        m_objDocsTags.PutElement(ndocId, tagsList);
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#GetObjectTags(int)
     */
     
    public virtual IXPList GetObjectTags(int docId)
    {
      if (null != m_objDocsTags)
      {
        return (IXPList) m_objDocsTags.GetElement(docId);
      }
      return null;
    }
    
    /// <param name="ID"></param>
    /// <returns></returns>
    private bool QueryFolders(int ID)
    {
      DirTempData td = (DirTempData) GetTempData();
      IPTFolder ptFolder = null;
      try
      {
        IPTCatalog ptCatalog = m_ptSession.GetCatalog();
        ptFolder = ptCatalog.OpenFolder(ID, false);
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(151, "ptmsgs_portalbrowsingmsgs"), e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return false;
      }
      if (ptFolder != null)
      {
        td.m_ptCurrentFolder = ptFolder;
        m_nCurrentFolderID = ID;
        // Check if user is allowed to view Edit mode
        if (DirConstants.EDIT_MODE == m_nDirMode)
        {
          bool bHasAccessToEdit = HasAccessToEditFolder();
          if (InRootFolder())
          {
            bHasAccessToEdit = (bHasAccessToEdit || CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY));
            }
          if (false == bHasAccessToEdit)
          {
            m_nDirMode = DirConstants.BROWSE_MODE;
            log.Info("user does not have edit rights on this folder.  switching to browse mode");
            }
        }
        if (IsAtMaxFolderLevel())
        {
          td.m_asqrSubFolders = null;
          if (m_nDirMode == DirConstants.BROWSE_MODE)
          {
            LoadAllRelatedResources();
          }
          return true;
        }
        if (RetrieveSubFoldersThroughSearch())
        {
          long lSearchQuery_BEFORE = XPSystem.GetCurrentTimeMilliSec();
          td.m_srSubFolders = SearchSubFolders(ID, ptFolder.GetFolderLevel());
          long lSearchQuery_AFTER = XPSystem.GetCurrentTimeMilliSec();
          long lSearchQuery_ELAPSED = (lSearchQuery_AFTER - lSearchQuery_BEFORE);
          int nSearchFolderCount = td.m_srSubFolders.GetResultsReturned();
          log.Info(" SubFolder Query via SEARCH Found RowCount=" + nSearchFolderCount + " in " + lSearchQuery_ELAPSED + "ms");
          // Calculate the mapping in order to mimic how results are returned by IPTCatalog.QuerySubfolders()
          td.m_arMappedSubFolderIndex = CalculateReportMapping(td.m_srSubFolders,
           ptFolder.GetFolderLevel());
        } else
        {
          try
          {
            // 0 means just this level
            int nLevel = 0;
            int nPropIDsForQuery = PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_CREATED | PT_PROPIDS.PT_PROPID_LASTMODIFIED | PT_PROPIDS.PT_PROPID_FOLDER_LEVEL;
            //query for more than one level if showing subsubfolder links
            if (DirConstants.DISABILITY_MODE == m_nDirMode)
            {
              nLevel = 0;
            } else
            if (GetNumSubSubFolders() > 0)
            {
              nLevel = 1;
            }
            //Change, default behavior so that, description info is always available
            //for showing in the mouse-over event
            //if (!GetFolderDescriptionType().equals(DirConstants.DIR_FOLD_DESC_NONE))
            {
              nPropIDsForQuery = nPropIDsForQuery | PT_PROPIDS.PT_PROPID_DESCRIPTION;
              }
            // Apply a filter if needed to exclude the Unclassified Folder
            Object[][] filter = null;
            if (m_nCurrentFolderID == PT_INTRINSICS.PT_FOLDER_ROOTFOLDER)
            {
              bool bHasAccessToUnclassifiedFolder = CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UNCLASSIFIED_FOLDER);
              if (m_nDirMode != DirConstants.EDIT_MODE || false == bHasAccessToUnclassifiedFolder)
              {
                filter = new Object[3][];
                for (int j2c_index = 0;j2c_index < 3;j2c_index++)
                {
                  filter[j2c_index] = new Object[1];
                }
                filter[0][0] = PT_PROPIDS.PT_PROPID_OBJECTID;
                filter[1][0] = PT_FILTEROPS.PT_FILTEROP_NE;
                filter[2][0] = PT_INTRINSICS.PT_FOLDER_UNCLASSIFIEDCARDS;
                }
            }
            // query for folders
            IPTQueryResult ptqrSubFolders = null;
            if (m_nDirMode == DirConstants.EDIT_MODE)
            {
              ptqrSubFolders = td.m_ptCurrentFolder.QuerySubfolders(nPropIDsForQuery,
               0, PT_PROPIDS.PT_PROPID_NAME, 0, -1, filter);
            } else
            // Browse mode,
            {
              long lDBQuery_BEFORE = XPSystem.GetCurrentTimeMilliSec();
              ptqrSubFolders = td.m_ptCurrentFolder.QuerySubfolders(nPropIDsForQuery,
               nLevel, PT_PROPIDS.PT_PROPID_NAME, 0, -1, filter);
              long lDBQuery_AFTER = XPSystem.GetCurrentTimeMilliSec();
              long lDBQuery_ELAPSED = (lDBQuery_AFTER - lDBQuery_BEFORE);
              int nDBFolderCount = ptqrSubFolders.RowCount();
              log.Info(" SubFolder Query via DATABASE Found RowCount=" + nDBFolderCount + " in " + lDBQuery_ELAPSED + "ms");
              }
            td.m_asqrSubFolders = new ASQueryResultWrapper(ptqrSubFolders);
            }
          catch (Exception e)
          {
            throw new XPException("Error querying folders. Check ptspy log for specific error.",
             e);
          }
        }
        if (m_nDirMode != DirConstants.EDIT_MODE && false == InRootFolder())
        {
          LoadAllRelatedResources();
        }
      }
      return true;
    }
    public virtual bool RetrieveSubFoldersThroughSearch()
    {
      return (DirConstants.BROWSE_MODE == m_nDirMode) && 
      // SCC For Ellington/Superdrive release, this subfolder querying via search will be off by default
      //    It can be turned on through a PTConfig.xml variable.  In a later release, this can be controlled
      //    through the same mechanism as done for card browsing. NOTE: querying by DB for
      //    subfolders is faster than search, although search is faster for querying cards (documents).
      s_bSubfolderQueryThroughSearch && 
      // root folder always goes through Directory??? 
      m_nCurrentFolderID != PT_INTRINSICS.PT_FOLDER_ROOTFOLDER && DirConstants.DISABILITY_MODE != m_nDirMode;
      }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SearchSubFolders(int, int)
     */
     
    public virtual IPTSearchResponse SearchSubFolders(int nFolderID, int nCurrentLevel)
    {
      IPTSearchRequest ptSR = m_ptSession.GetSearchRequest();
      int[] folderid = {nFolderID};
      // Limit Level to subfolder and subsubfolders
      IPTFilter filterLevel = CreateSubFolderSearchFilter(nCurrentLevel);
      //		IPTSearchQuery ptQuery = ptSR.CreateBasicQuery("*", "");
      IPTSearchQuery ptQuery = ptSR.CreateAdvancedQuery(filterLevel);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS, folderid);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
       true);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, new int[]{PT_CLASSIDS.PT_CATALOGFOLDER_ID});
      /* bug 19302 fix */
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE, "dirfolderbrowse");
      // Set Search Order By
      int nDefaultSearchOrderBy = PT_INTRINSICS.PT_PROPERTY_NAMEINDEX;
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, nDefaultSearchOrderBy);
      // NOTE: This has never included the description, although it
      // appears designed to query for the description.  We should
      // probably add this in at some point.  Bug#67435
      // name, description, created, modified
      int[] arPropIDs = {
      // 1
      PT_INTRINSICS.PT_PROPERTY_OBJECTNAME, 
      //			PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY, // 2
      // 3
      PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED, 
      // 11 folderlevel
      PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL};
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_USUAL_FIELDS,
       false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS, arPropIDs);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC, false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, 0);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, 10000);
      IPTSearchResponse ptSearchDocuments = ptSR.Search(ptQuery);
      return ptSearchDocuments;
    }
    public virtual IPTFilter CreateSubFolderSearchFilter(int nCurrentLevel)
    {
      IPTFilter filter = PortalObjectsFactory.CreateSearchFilter();
      IPTPropertyFilterStatement statementThisLevel = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
      statementThisLevel.SetOperand(PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
      statementThisLevel.SetOperator(PT_FILTEROPS.PT_FILTEROP_EQ);
      statementThisLevel.SetValue(XPConvert.ToString(nCurrentLevel + 1));
      IPTPropertyFilterStatement statementNextLevel = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
      statementNextLevel.SetOperand(PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
      statementNextLevel.SetOperator(PT_FILTEROPS.PT_FILTEROP_EQ);
      statementNextLevel.SetValue(XPConvert.ToString(nCurrentLevel + 2));
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
      clause.SetOperator(PT_BOOLOPS.PT_BOOLOP_OR);
      clause.AddItem(statementThisLevel, 0);
      clause.AddItem(statementNextLevel, 1);
      if (0 < GetNumSubSubFoldersToDisplay())
      {
        filter.SetPropertyFilter(clause);
      } else
      {
        filter.SetPropertyFilter(statementThisLevel);
      }
      return filter;
    }
    public virtual int GetFolderSearchMapping(int nIndex)
    {
      DirTempData td = (DirTempData) GetTempData();
      return td.m_arMappedSubFolderIndex[nIndex];
    }
    
    /// <summary>
    /// Generates a mapping to an array that mimics what is returned by IPTFolder.QuerySubFolders()
    /// </summary>
    public virtual int[] CalculateReportMapping(IPTSearchResponse ptSR, int nCurrentLevel)
    {
      int nSubFolderLevel = nCurrentLevel + 1;
      int nSubSubFolderLevel = nCurrentLevel + 2;
      int nResultCount = ptSR.GetResultsReturned();
      int[] arReportMapping = new int[nResultCount];
      int nNumSubSubFoldersToDisplay = GetNumSubSubFoldersToDisplay();
      int nReportMappingIndex = 0;
      for (int nSubFolderIndex = 0;nSubFolderIndex < nResultCount;nSubFolderIndex++)
      {
        int nPotentialSubFolderLevel = ptSR.GetFieldsAsInt(nSubFolderIndex,
         PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
        // This for loop only concerns subfolders
        if (nPotentialSubFolderLevel != nSubFolderLevel)
        {
          continue;
        }
        // Store the mapping to this subfolder 
        arReportMapping[nReportMappingIndex++] = nSubFolderIndex;
        // Now look for the subsubfolders of this folder
        if (0 < nNumSubSubFoldersToDisplay)
        {
          int nSubFolderID = ptSR.GetFieldsAsInt(nSubFolderIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
          int nSubSubFolderCount = 0;
          for (int nSubSubFolderIndex = 0;nSubSubFolderIndex < nResultCount;
          nSubSubFolderIndex++)
          {
            int nPotentialSubSubFolderLevel = ptSR.GetFieldsAsInt(nSubSubFolderIndex,
             PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
            // This for loop only concerns subsubfolders
            if (nPotentialSubSubFolderLevel != nSubSubFolderLevel)
            {
              continue;
            }
            String strParentFolder = ptSR.GetResultInternalField(nSubSubFolderIndex,
             PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_PARENTIDS);
            int nParentFolderID = XPConvert.ToInteger(XPStringUtility.Substring(strParentFolder,
             2));
            // check if this is a child folder of our subfolder
            if (nParentFolderID == nSubFolderID)
            {
              // if so, then store it
              arReportMapping[nReportMappingIndex++] = nSubSubFolderIndex;
              nSubSubFolderCount++;
            }
            if (nNumSubSubFoldersToDisplay == nSubSubFolderCount)
            {
              break;
            }
          }
        }
      }
      int[] arReturn = new int[nReportMappingIndex];
      for (int i = 0;i < nReportMappingIndex;i++)
      {
        arReturn[i] = arReportMapping[i];
      }
      return arReturn;
    }
    
    /// <param name="strURL"></param>
    /// <returns></returns>
    public virtual bool IsDateProperty(int nPropertyID)
    {
      if (nPropertyID == PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED || nPropertyID == PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED)
      {
        return true;
      } else
      // non-date intrinsic property
      if (nPropertyID < 100)
      {
        return false;
      } else
      {
        int nPropType;
        // check the last checked prop first
        if (m_nLastCheckedPropID == nPropertyID)
        {
          nPropType = m_nLastCheckedPropType;
        } else
        {
          // otherwise check the cache
          Object oProp = m_xpDateProps.GetElement(nPropertyID);
          if (null != oProp)
          {
            nPropType = XPConvert.ToInteger(oProp);
          } else
          // otherwise check the database as a last resort and add it to the cache
          {
            try
            {
              IPTProperty ptProp = (IPTProperty) m_ptSession.GetProperties().Open(nPropertyID,
               false);
              nPropType = ptProp.GetType();
              m_xpDateProps.PutElement(nPropertyID, nPropType);
            }
            catch (PTException pte)
            {
              return false;
            }
          }
          m_nLastCheckedPropID = nPropertyID;
          m_nLastCheckedPropType = nPropType;
        }
        bool bDateType = (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == nPropType);
        return bDateType;
      }
    }
    
    /// <param name="_nObjectIndex"></param>
    /// <param name="xpCustomProps"></param>
    /// <returns></returns>
    public virtual XPArrayList GetCustomFields(int _nObjectIndex, XPArrayList xpCustomProps,
     XPLocale xpLocale, XPTimeZone xpTimeZone)
    {
      XPArrayList xpCustomFields = new XPArrayList();
      for (int i = 0;i < xpCustomProps.GetSize();i++)
      {
        Object[] arPropInfo = (Object[]) xpCustomProps.GetElement(i);
        int nPropID = XPConvert.ToInteger(arPropInfo[DirConstants.PROP_COLUMNS_INDEX_ID]);
        int nPropType = XPConvert.ToInteger(arPropInfo[DirConstants.PROP_COLUMNS_INDEX_TYPE]);
        Object oPropValue;
        String strPropValue;
        oPropValue = GetObjectFields(_nObjectIndex, nPropID);
        if (null == oPropValue)
        {
          strPropValue = "";
        } else
        {
          switch (nPropType){
          case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
          strPropValue = (String) oPropValue;
          break;
          case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
          strPropValue = XPConvert.ToString(oPropValue);
          break;
          case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
          XPDateTime dtDate = (XPDateTime) oPropValue;
          XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
           XPDateFormat.SHORT, xpLocale, xpTimeZone);
          strPropValue = xpDateTimeFormat.Format(dtDate);
          break;
          // NOTE: doubles are not searchable
          default:
          strPropValue = "";
          break;
          }
        }
        xpCustomFields.Add(strPropValue);
      }
      return xpCustomFields;
    }
    
    /// <version>$Revision$</version>
    /// <author>StephenC</author>
    private class DirTempData
    {
      
      /// <summary>
      /// This variable displays whether or not the current
      /// folder has been loaded.
      /// </summary>
      public bool m_bLoadedFolder = false;
      public IASQueryResult m_asqrDocuments = null;
      
      /// <summary>
      /// Related Resource  *
      /// </summary>
      public IASQueryResult m_asqrRelatedCommunities = null;
      public IASQueryResult m_asqrRelatedContentManagers = null;
      public IASQueryResult m_asqrRelatedExperts = null;
      public IASQueryResult m_asqrRelatedFolders = null;
      public IASQueryResult m_asqrRelatedPortlets = null;
      public IASQueryResult m_asqrSubFolders = null;
      public IPTSearchResponse m_srSubFolders = null;
      public int[] m_arMappedSubFolderIndex = null;
      public IPTCard m_ptCurrentCard = null;
      
      /// <summary>
      /// Current folder info 
      /// </summary>
      public IPTFolder m_ptCurrentFolder = null;
      
      /// <summary>
      /// Documents from Search 
      /// </summary>
      public IPTSearchResponse m_ptSearchDocuments = null;
      public XPSortedDictionary m_xpBasicProperties = null;
      public XPSortedDictionary m_xpCardInformation = null;
      public XPSortedDictionary m_xpCustomProperties = null;
      public int[] m_arRelatedResourceIDs = null;
      
      /// <summary>
      /// For Folder Creation *
      /// </summary>
      public int m_nCreatedFolderID;
      public int m_nCurrentRRCategoryID = -1;
      public int m_nCurrentRRObjectID = -1;
      public int m_nMoreFolderID = -1;
      public int m_nTotalResults = 0;
      public XPLocale m_xpLocale;
      public XPTimeZone m_xpTimeZone;
    }
    
    /// <param name="saveURL">The m_bCSSaveURL to set.</param>
    public virtual void SetSaveTempData(bool _saveTempData)
    {
      m_bCSSaveURL = _saveTempData;
    }
    public virtual int GetDocumentTypeId()
    {
      return m_nDocumentTypeId;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.IDirModel#SetDocumentTypeId(java.lang.String)
     */
     
    public virtual void SetDocumentTypeId(String documentTypeId)
    {
      m_nDocumentTypeId = XPConvert.ToInteger(documentTypeId);
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#AddRemoveObjectTag(java.lang.String, java.lang.String, int, java.lang.String)
     */
     
    // TODO Add a new Logger for Pathways
    public virtual void AddRemoveObjectTag(String tagname, String strid, int action,
     String ptsource)
    {
      IPathwaysRestAPIService svcPathwaysRest = PathwaysRestAPIService.GetInstance(m_asOwner);
      if (svcPathwaysRest.IsPathwaysEnabled())
      {
        try
        {
          svcPathwaysRest.AddRemoveTagRest(tagname, strid, action, ptsource);
          }
        catch (Exception e)
        {
          //TODO: this should be 500 error via DP since server processing failed.
          m_taggingError = new XPException("An Exception occured while making REST request to Add/Remove Tag",
           e);
        }
      } else
      {
        //TODO: this should be 500 error via DP since server processing failed.
        throw new XPIllegalStateException("Failed to Send Add/Remove Tag REST request to Pathways, it is not enabled!");
        }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#RenameObjectTag(java.lang.String, java.lang.String, java.lang.String, java.lang.String)
     */
     
    // TODO Add a new Logger for Pathways
    public virtual void RenameObjectTag(String tagname, String strid, String ptsource,
     String renametag)
    {
      IPathwaysRestAPIService svcPathwaysRest = PathwaysRestAPIService.GetInstance(m_asOwner);
      if (svcPathwaysRest.IsPathwaysEnabled())
      {
        svcPathwaysRest.RenameTagRest(tagname, strid, ptsource, renametag);
        } else
      {
        XPException ex = new XPIllegalStateException("Failed to Send Rename Tag REST request to Pathways, it is not enabled!");
        SetPathwaysTaggingError(ex);
        throw ex;
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.directory.pathways.ITaggingModel#IsTaggingEnabled(java.lang.String, java.lang.String, boolean )
     */
     
    public virtual bool IsTaggingEnabled()
    {
      IPathwaysRestAPIService svcPathwaysRest = PathwaysRestAPIService.GetInstance(m_asOwner);
      if (null != svcPathwaysRest)
      {
        return svcPathwaysRest.IsPathwaysEnabled();
      }
      return false;
    }
    public virtual XPException GetPathwaysTaggingError()
    {
      return m_taggingError;
    }
    public virtual void SetPathwaysTaggingError(XPException e)
    {
      m_taggingError = e;
    }
  }
}