using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory.abodelete;
using com.plumtree.portalpages.browsing.directory.documentsubmitsimple;
using com.plumtree.portalpages.browsing.directory.edit;
using com.plumtree.portalpages.common.createfolder;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.securitymatrix;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <author>StephenC</author>
  public class FolderBannerView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.FolderBannerView");
    public const String STR_MVC_CLASS_NAME = "FolderBanner";
    public const String JAVASCRIPT_SUBMIT_NO_REFRESH = "submitDirNoRefresh";
    public const String JAVASCRIPT_CREATEFOLDER_POPUP = "DirCreateFolderPopup";
    public const String JAVASCRIPT_CARDSUBMIT_POPUP = "DirCardSubmitSimplePopup";
    public const String JAVASCRIPT_CARDSUBMIT_BUTTON = "DirCardSubmitButton";
    public const String JAVASCRIPT_DELETE = "DirDelete";
    public const String JAVASCRIPT_MIGRATE = "DirMigrate";
    public const String JAVASCRIPT_APPROVE = "DirApprove";
    public const String JAVASCRIPT_UNAPPROVE = "DirUnapprove";
    public const String JAVASCRIPT_LINKSETTINGS = "DirLinkSettings";
    public const String JAVASCRIPT_DATASOURCETREE_POPUP = "OpenDataSourceTree";
    public const String JAVASCRIPT_MOVETARGETFOLDERTREE_POPUP = "OpenMoveTargetFolderTree";
    public const String JAVASCRIPT_COPYTARGETFOLDERTREE_POPUP = "OpenCopyTargetFolderTree";
    public const String JAVASCRIPT_SECURITY = "editSecurity";
    public const String JAVASCRIPT_CHECK_FOLDERS_SELECTED = "checkFoldersSelected";
    public const String JAVASCRIPT_CHECK_CARDS_SELECTED = "checkCardsSelected";
    public const String JAVASCRIPT_GET_FIRST_INPUT = "getFirstSelectedObject";
    public const String JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING = "getAllObjectsString";
    public const String JAVASCRIPT_GET_OBJECT_SELECTED_STRING = "getObjectString";
    public const String JAVASCRIPT_CHECKCOUNT = "checkCount";
    public const String JAVASCRIPT_GET_NUMOBJECTS_SELECTED_STRING = "getNumSelected";
    private const String JSREPOST_DATASOURCE_FUNC = "frmRepostDataSourceChosen";
    private const String JSREPOST_MOVETARGETFOLDER_FUNC = "frmRepostMoveTargetFolderChosen";
    private const String JSREPOST_COPYTARGETFOLDER_FUNC = "frmRepostCopyTargetFolderChosen";
    // HTML Object names.
    public const String HTMLSELECT_SUBMITTYPE = "in_se_CardSubmitType";
    public const String HTML_INPUT_COMMENT = "in_hi_Comment";
    internal AActivitySpace m_asOwner = null;
    internal IDirModelRO m_asModel = null;
    private const String strSimpleCardSubmit_NotSelected = "0";
    private const String strSimpleCardSubmitGUID = "1";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new FolderBannerView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      PTConstruct bannerConstruct;
      PTConstruct buttonConstruct;
      HTMLAnchor myAnchor;
      HTMLInput myInput;
      ASURL url;
      int nDirMode = m_asModel.GetDirectoryMode();
      //Folder title banner
      try
      {
        // Optional inputs (filled in by javascript)
        // Hidden input for the migration or disable comment
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTML_INPUT_COMMENT,
         "");
        result.AddInnerHTMLElement(myInput);
        //Get folder banner construct
        String strTitle = XPResourceManager.FormatMessage(m_asOwner.GetString(181,
         "ptmsgs_portalbrowsingmsgs"), "\"" + XPHttpUtility.HtmlEncode(m_asModel.GetCurrentFolderName()) + "\" ");
        if (DirConstants.EDIT_MODE == nDirMode)
        {
          strTitle+=m_asOwner.GetString(182, "ptmsgs_portalbrowsingmsgs");
          }
        bannerConstruct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
         true, this.m_asOwner);
        bannerConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.FOLDER.TITLE_ELEMENT_NAME,
         strTitle);
        result.AddInnerHTMLElement(bannerConstruct.GetHTMLElement());
        bool bShowActionBanner = m_asModel.ShowFolderActionBanner();
        bool bCanEditFolder = ((IDirModelRO) m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME)).HasAccessToEditFolder();
        if (m_asModel.InRootFolder())
        {
          bShowActionBanner = (bShowActionBanner || m_asModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY));
          bCanEditFolder = (bCanEditFolder || m_asModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY));
          }
        if (bShowActionBanner && (DirConstants.EDIT_MODE == nDirMode) && (false == m_asModel.InUnclassifiedCardsFolder()))
        {
          //Edit button
          PTButtonType ptEditFolderButton = PTButtonType.EDIT_FOLDER_DIR_ACTIONBAR;
          buttonConstruct = UIConstructFactory.GetConstruct(ptEditFolderButton,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(ptEditFolderButton.TITLE_ELEMENT_NAME,
           "");
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(ptEditFolderButton.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + DirRepostControl.POSTTOSELF_ACTION_EDIT + "); return false;");
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(173,
           "ptmsgs_portalbrowsingmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(173,
           "ptmsgs_portalbrowsingmsgs"));
          bannerConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
        }
        if (false == ((IFolderModelRO) m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME)).InRootFolder())
        {
          //Go up button
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.GO_UP.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(168, "ptmsgs_portalbrowsingmsgs"));
          String strOptArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" + m_asModel.GetDirectoryMode();
          // Open folder URL
          String strOpenFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
           m_asModel.GetParentFolderID(), IPTOpenerConstants.OPENER_MODE_VIEW,
           m_asOwner, m_asOwner.GetName(), m_asOwner.GetSpaceID(), strOptArgs);
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.GO_UP.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(strOpenFolderURL);
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(169,
           "ptmsgs_portalbrowsingmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(169,
           "ptmsgs_portalbrowsingmsgs"));
          bannerConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
        }
        if (true == bCanEditFolder && m_asModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY))
        {
          switch (nDirMode){
          case DirConstants.EDIT_MODE:
          //Toggle Mode button has Browse image
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.BROWSE_HEADER,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.BROWSE_HEADER.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(170, "ptmsgs_portalbrowsingmsgs"));
          String strOptBrowseArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" + DirConstants.BROWSE_MODE;
          // ToggleBrowseMode URL
          String strToggleBrowseModeURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
           m_asModel.GetCurrentFolderID(), IPTOpenerConstants.OPENER_MODE_VIEW,
           m_asOwner, m_asOwner.GetName(), m_asOwner.GetSpaceID(), strOptBrowseArgs);
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.BROWSE_HEADER.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(strToggleBrowseModeURL);
          bannerConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(170,
           "ptmsgs_portalbrowsingmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(170,
           "ptmsgs_portalbrowsingmsgs"));
          break;
          case DirConstants.BROWSE_MODE:
          //Toggle Mode button has Edit image
          buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EDIT_HEADER,
           true, this.m_asOwner);
          buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.EDIT_HEADER.TITLE_ELEMENT_NAME,
           m_asOwner.GetString(171, "ptmsgs_portalbrowsingmsgs"));
          String strOptEditArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" + DirConstants.EDIT_MODE;
          // ToggleBrowseMode URL
          String strToggleEditModeURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
           m_asModel.GetCurrentFolderID(), IPTOpenerConstants.OPENER_MODE_VIEW,
           m_asOwner, m_asOwner.GetName(), m_asOwner.GetSpaceID(), strOptEditArgs);
          myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.EDIT_HEADER.ANCHOR_ELEMENT_NAME);
          myAnchor.SetHRef(strToggleEditModeURL);
          bannerConstruct.AddElementToNestedElement(PTBannerType.FOLDER.EXTENDABLE_CELL_ELEMENT_NAME,
           buttonConstruct.GetHTMLElement());
          ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(171,
           "ptmsgs_portalbrowsingmsgs"));
          ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(171,
           "ptmsgs_portalbrowsingmsgs"));
          break;
          }
        }
        //Folder actions banner 
        bool bShowFolderActionBanner = m_asModel.ShowFolderActionBanner();
        if (m_asModel.InRootFolder())
        {
          bShowFolderActionBanner = (bShowFolderActionBanner || m_asModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY));
          }
        if (bShowFolderActionBanner)
        {
          bannerConstruct = UIConstructFactory.GetConstruct(PTBannerType.DIRECTORY_ACTION_BAR);
          result.AddInnerHTMLElement(bannerConstruct.GetHTMLElement());
          if (DirConstants.EDIT_MODE == nDirMode)
          {
            if (false == m_asModel.IsAtMaxFolderLevel() && true == bCanEditFolder && m_asModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_FOLDERS))
            {
              //Create button
              buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.CREATE_FOLDER_DIR_ACTIONBAR,
               true, this.m_asOwner);
              buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.CREATE_FOLDER_DIR_ACTIONBAR.TITLE_ELEMENT_NAME,
               "");
              myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.CREATE_FOLDER_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
              myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
              myAnchor.SetOnClick(JAVASCRIPT_CREATEFOLDER_POPUP + "(); return false;");
              ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(172,
               "ptmsgs_portalbrowsingmsgs"));
              ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(172,
               "ptmsgs_portalbrowsingmsgs"));
              bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
               buttonConstruct.GetHTMLElement());
            }
            //Move button
            buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.MOVE_DIR_ACTIONBAR,
             true, this.m_asOwner);
            myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.MOVE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
            myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(JAVASCRIPT_MOVETARGETFOLDERTREE_POPUP + "(); return false;");
            ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(174,
             "ptmsgs_portalbrowsingmsgs"));
            ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(174,
             "ptmsgs_portalbrowsingmsgs"));
            bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
             buttonConstruct.GetHTMLElement());
            //Copy button
            buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.COPY_DIR_ACTIONBAR,
             true, this.m_asOwner);
            myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.COPY_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
            myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(JAVASCRIPT_COPYTARGETFOLDERTREE_POPUP + "(); return false;");
            ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(175,
             "ptmsgs_portalbrowsingmsgs"));
            ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(175,
             "ptmsgs_portalbrowsingmsgs"));
            bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
             buttonConstruct.GetHTMLElement());
            //Security button
            buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SECURITY_DIR_ACTIONBAR,
             true, this.m_asOwner);
            myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.SECURITY_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
            myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(JAVASCRIPT_SECURITY + "(); return false;");
            ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(178,
             "ptmsgs_portalbrowsingmsgs"));
            ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(178,
             "ptmsgs_portalbrowsingmsgs"));
            bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
             buttonConstruct.GetHTMLElement());
            //Delete button
            buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.DELETE_DIR_ACTIONBAR,
             true, this.m_asOwner);
            myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.DELETE_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
            myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(JAVASCRIPT_DELETE + "(); return false;");
            ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(177,
             "ptmsgs_portalbrowsingmsgs"));
            ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(177,
             "ptmsgs_portalbrowsingmsgs"));
            bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
             buttonConstruct.GetHTMLElement());
            // Request Migration button
            buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.MIGRATE_OBJECTS_DIR_ACTIONBAR,
             true, this.m_asOwner);
            myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.MIGRATE_OBJECTS_DIR_ACTIONBAR.ANCHOR_ELEMENT_NAME);
            myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
            myAnchor.SetOnClick(JAVASCRIPT_MIGRATE + "(); return false;");
            ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(1250,
             "ptmsgs_portaladminmsgs"));
            ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(1250,
             "ptmsgs_portaladminmsgs"));
            bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
             buttonConstruct.GetHTMLElement());
          }
          if (false == bCanEditFolder || m_asModel.InRootFolder())
          {
          } else
          // don't show Submit button, since there are no cards allowed in the root folder
          {
            bool bHasAdvancedDocSubmissionRights = m_asModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_USE_ADVANCEDDOCSUBMISSION);
            if ((DirConstants.EDIT_MODE == nDirMode) && (true == bHasAdvancedDocSubmissionRights))
            {
              // Card Type Selector
              ClassTypeDescManager ptObjDescMgr = PTConfigHelper.GetPTClassTypeDescrManager();
              IProvInfo[] ptProvInfo = ptObjDescMgr.GetRegisteredProvInfoForClassType(PT_CLASSIDS.PT_DATASOURCE_ID);
              HTMLSelect mySelect = new HTMLSelect(HTMLSELECT_SUBMITTYPE,
               "");
              mySelect.SetOnChange(JAVASCRIPT_CARDSUBMIT_BUTTON + "(); return false;");
              mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
              bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.RIGHT_SIDE_EXTENDABLE_CELL_ELEMENT_NAME,
               mySelect);
              // Simple Card Submit Not Selected
              HTMLOption optionVal = new HTMLOption(strSimpleCardSubmit_NotSelected);
              optionVal.SetSelected(true);
              mySelect.AddInnerHTMLElement(optionVal);
              optionVal.AddInnerHTMLString(m_asOwner.GetString(1598, "ptmsgs_portalbrowsingmsgs"));
              // Simple Card Submit Option
              optionVal = new HTMLOption(strSimpleCardSubmitGUID);
              mySelect.AddInnerHTMLElement(optionVal);
              optionVal.AddInnerHTMLString(m_asOwner.GetString(183, "ptmsgs_portalbrowsingmsgs"));
              String strLang = XPConvert.ToString(PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
               m_asOwner));
              for (int i = 0;i < ptProvInfo.Length;i++)
              {
                String strProviderName = ptProvInfo[i].GetProviderAndClassLocalizedName(strLang,
                 PT_CLASSIDS.PT_CATALOGCARD_ID);
                String strProviderGUID = ptProvInfo[i].GetProviderCLSID();
                optionVal = new HTMLOption(strProviderGUID);
                optionVal.SetSelected(false);
                mySelect.AddInnerHTMLElement(optionVal);
                optionVal.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strProviderName));
                }
            } else
            // browse mode
            {
              PTButtonType ptSubmitButtonType = PTButtonType.SUBMIT_DIR_ACTIONBAR;
              buttonConstruct = UIConstructFactory.GetConstruct(ptSubmitButtonType,
               true, this.m_asOwner);
              buttonConstruct.ReplaceNestedElementsWithHTMLString(ptSubmitButtonType.TITLE_ELEMENT_NAME,
               m_asOwner.GetString(180, "ptmsgs_portalbrowsingmsgs"));
              ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(180,
               "ptmsgs_portalbrowsingmsgs"));
              ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(180,
               "ptmsgs_portalbrowsingmsgs"));
              myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(ptSubmitButtonType.ANCHOR_ELEMENT_NAME);
              myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
              myAnchor.SetOnClick(JAVASCRIPT_CARDSUBMIT_POPUP + "(); return false;");
              bannerConstruct.AddElementToNestedElement(PTBannerType.DIRECTORY_ACTION_BAR.RIGHT_SIDE_EXTENDABLE_CELL_ELEMENT_NAME,
               buttonConstruct.GetHTMLElement());
            }
          }
        }
      }
      // if(m_asModel.CanAddToThisFolder()) {
      catch (Exception e)
      {
        log.Error(e, "FolderBannerView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1226, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      bool bEditMode = (DirConstants.EDIT_MODE == ((IDirModelRO) m_asModel).GetDirectoryMode());
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(100);
      ASURL myCardSubmitURL = new ASURL(m_asOwner);
      myCardSubmitURL.SetLinkGetCachedSpace(m_asOwner);
      myCardSubmitURL.SetDisplayPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
      try
      {
        sb = new XPStringBuilder(200);
        // Open Card Submit Simple popup function
        sb.Append("function ").Append(JAVASCRIPT_CARDSUBMIT_POPUP).Append("()\n");
        sb.Append("{\n");
        sb.Append("  window.open(\'").Append(myCardSubmitURL.GetURLAsString()).Append("\', \'SubmitCard\', \'location=no,menubar=no,height=300,width=600\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        if (bEditMode)
        {
          sb = new XPStringBuilder(10000);
          ASURL myCreateFolderURL = new ASURL(m_asOwner);
          myCreateFolderURL.SetLinkGetCachedSpace(m_asOwner);
          myCreateFolderURL.SetDisplayPage(CreateFolderDP.STR_MVC_CLASS_NAME);
          myCreateFolderURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
          myCreateFolderURL.AddControlArgument(CreateFolderDP.QS_PARENT_FOLDER,
           m_asModel.GetCurrentFolderID());
          // Open create folder popup function
          sb.Append("function ").Append(JAVASCRIPT_CREATEFOLDER_POPUP).Append("()\n");
          sb.Append("{\n");
          sb.Append("  window.open(\'").Append(myCreateFolderURL.GetURLAsString()).Append("\', \'CreateFolder\', \'location=no,menubar=no,height=180,width=400\');\n");
          sb.Append("}\n");
          // Approve function
          sb.Append("function ").Append(JAVASCRIPT_APPROVE).Append("()\n");
          sb.Append("{\n");
          sb.Append("     if (").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("() != true)\n");
          sb.Append("     {\n");
          // And display an error if nothing is selected
          sb.Append("       alert(\'").Append(m_asOwner.GetString(186, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("       return false;\n");
          sb.Append("     }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(" + DirRepostControl.POSTTOSELF_ACTION_APPROVE + ");\n");
          sb.Append("}\n");
          // Unapprove function
          sb.Append("function ").Append(JAVASCRIPT_UNAPPROVE).Append("()\n");
          sb.Append("{\n");
          sb.Append("     if (").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("() != true)\n");
          sb.Append("     {\n");
          // And display an error if nothing is selected
          sb.Append("       alert(\'").Append(m_asOwner.GetString(186, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("       return false;\n");
          sb.Append("     }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(" + DirRepostControl.POSTTOSELF_ACTION_UNAPPROVE + ");\n");
          sb.Append("}\n");
          // Link Settings function
          sb.Append("function ").Append(JAVASCRIPT_LINKSETTINGS).Append("()\n");
          sb.Append("{\n");
          sb.Append("     if (").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("() != true)\n");
          sb.Append("     {\n");
          // And display an error if nothing is selected
          sb.Append("       alert(\'").Append(m_asOwner.GetString(186, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("       return false;\n");
          sb.Append("     }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(" + DirRepostControl.POSTTOSELF_ACTION_LINKSETTINGS + ");\n");
          sb.Append("}\n");
          /////////////////////////////////////////////////////////////////
          //** Begin JS Tree for Selecting DataSources for Card Submit **//
          String strFormName = AFormDP.HTMLFORM_NAME;
          // The URL to open a new tree
          ASURL myNewDataSourceTree = new ASURL(m_asOwner);
          myNewDataSourceTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          myNewDataSourceTree.SetSubSpaceKey(((IDirModelRO) m_asModel).GetDataSourceTREESUBSPACE());
          myNewDataSourceTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
          myNewDataSourceTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(false));
          myNewDataSourceTree.AddControlArgument(StartTreeControl.ROOT_ID,
           "1");
          myNewDataSourceTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
           XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
          myNewDataSourceTree.AddControlArgument(StartTreeControl.SELECT_MODE,
           XPConvert.ToString(TreeConstants.N_LEAFSELECT));
          myNewDataSourceTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
           strFormName);
          myNewDataSourceTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
           JSREPOST_DATASOURCE_FUNC);
          myNewDataSourceTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
           XPConvert.ToString(PT_CLASSIDS.PT_DATASOURCE_ID));
          myNewDataSourceTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
           m_asOwner.GetString(1223, "ptmsgs_portalbrowsingmsgs") + ".");
          myNewDataSourceTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1223,
           "ptmsgs_portalbrowsingmsgs"));
          // Open server datasource tree function
          sb.Append("function ").Append(JAVASCRIPT_DATASOURCETREE_POPUP).Append("(dataSourceCLSID)\n");
          sb.Append("{\n");
          sb.Append("    window.open(\'").Append(myNewDataSourceTree.GetURLAsString()).Append("&").Append(StartTreeControl.QUERY_FILTER).Append("=").Append(PT_CLASSIDS.PT_DATASOURCE_ID).Append(",").Append(PT_PROPIDS.PT_PROPID_DS_PROVIDERCLSID).Append(",\'+dataSourceCLSID").Append(", \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
          sb.Append("}\n");
          sb.Append("function ");
          sb.Append(JSREPOST_DATASOURCE_FUNC);
          sb.Append("()\n {\n\t").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(");
          sb.Append(DirRepostControl.POSTTOSELF_ACTION_CARDSUBMITADVANCED);
          sb.Append(");\n}\n");
          //** End JS Tree for Selecting DataSources for Card Submit **//
          sb.Append("function ").Append(JAVASCRIPT_CARDSUBMIT_BUTTON).Append("()\n");
          sb.Append("{\n");
          sb.Append("    var dataSourceGUID = document." + AFormDP.HTMLFORM_NAME + "." + HTMLSELECT_SUBMITTYPE + ".value; \n");
          sb.Append("    if (\"").Append(strSimpleCardSubmit_NotSelected).Append("\" == dataSourceGUID) \n");
          sb.Append("    {\n");
          sb.Append("    \t\treturn;\n");
          sb.Append("    } else if (\"").Append(strSimpleCardSubmitGUID).Append("\" == dataSourceGUID) \n");
          sb.Append("    {\n");
          sb.Append("    \t\tJavascript:" + JAVASCRIPT_CARDSUBMIT_POPUP + "();\n");
          sb.Append("    } else {\n");
          sb.Append("         Javascript:" + JAVASCRIPT_DATASOURCETREE_POPUP + "(dataSourceGUID);\n");
          sb.Append("    } \n");
          sb.Append("    document.").Append(AFormDP.HTMLFORM_NAME + "." + HTMLSELECT_SUBMITTYPE + ".value=" + strSimpleCardSubmit_NotSelected + ";\n");
          sb.Append("}\n\n");
          ///////////////////////////////////////////////////////////////
          //** Begin JS Tree for Selecting Target Folder for MOVING **//
          // The URL to open a new tree
          ASURL myNewMoveFolderTree = new ASURL(m_asOwner);
          myNewMoveFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          myNewMoveFolderTree.SetSubSpaceKey(((IDirModelRO) m_asModel).GetMoveTargetFolderTREESUBSPACE());
          myNewMoveFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(false));
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.ROOT_ID,
           "1");
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
           XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE,
           XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
           strFormName);
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
           m_asOwner.GetString(1224, "ptmsgs_portalbrowsingmsgs"));
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1224,
           "ptmsgs_portalbrowsingmsgs"));
          //See DisplayJavascript below for the definition of frmRepostRemoteViewChosen
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
           JSREPOST_MOVETARGETFOLDER_FUNC);
          myNewMoveFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
           XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
          // Open server folder tree function
          sb.Append("function ").Append(JAVASCRIPT_MOVETARGETFOLDERTREE_POPUP).Append("()\n");
          sb.Append("{\n");
          sb.Append("     var bFoldersSelected = ").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("();\n");
          sb.Append("     var bCardsSelected = ").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("();\n");
          sb.Append("     if(!bFoldersSelected && !bCardsSelected)\n");
          sb.Append("     {\n");
          // And display an error if nothing is selected
          sb.Append("       alert(\'").Append(m_asOwner.GetString(187, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("       return false;\n");
          sb.Append("     }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  var sURL = \"").Append(myNewMoveFolderTree.GetURLAsString()).Append("\";\n");
          sb.Append("  if(bCardsSelected)\n");
          sb.Append("     sURL += \"&").Append(StartTreeControl.SHOW_ROOT).Append("=0\"").Append("\n");
          sb.Append("  window.open(sURL, \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
          sb.Append("}\n");
          sb.Append("function ");
          sb.Append(JSREPOST_MOVETARGETFOLDER_FUNC);
          sb.Append("()\n {\n\t").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(");
          sb.Append(DirRepostControl.POSTTOSELF_ACTION_MOVE);
          sb.Append(");\n}\n");
          //** End JS Tree for Selecting Target Folder for MOVING **//
          ///////////////////////////////////////////////////////////////
          //** Begin JS Tree for Selecting Target Folder for COPYING **//
          // The URL to open a new tree
          ASURL myNewCopyFolderTree = new ASURL(m_asOwner);
          myNewCopyFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          myNewCopyFolderTree.SetSubSpaceKey(((IDirModelRO) m_asModel).GetCopyTargetFolderTREESUBSPACE());
          myNewCopyFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(false));
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.ROOT_ID,
           "1");
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
           XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE,
           XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
           strFormName);
          //See DisplayJavascript below for the definition of frmRepostRemoteViewChosen
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
           JSREPOST_COPYTARGETFOLDER_FUNC);
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
           XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
           m_asOwner.GetString(1224, "ptmsgs_portalbrowsingmsgs"));
          myNewCopyFolderTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1224,
           "ptmsgs_portalbrowsingmsgs"));
          // Open server user tree function
          sb.Append("function ").Append(JAVASCRIPT_COPYTARGETFOLDERTREE_POPUP).Append("()\n");
          sb.Append("{\n");
          sb.Append("     var bFoldersSelected = ").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("();\n");
          sb.Append("     var bCardsSelected = ").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("();\n");
          sb.Append("     if(!bFoldersSelected && !bCardsSelected)\n");
          sb.Append("     {\n");
          // And display an error if nothing is selected
          sb.Append("       alert(\'").Append(m_asOwner.GetString(187, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("       return false;\n");
          sb.Append("     }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  var sURL = \"").Append(myNewCopyFolderTree.GetURLAsString()).Append("\";\n");
          sb.Append("  if(bCardsSelected)\n");
          sb.Append("     sURL += \"&").Append(StartTreeControl.SHOW_ROOT).Append("=0\"").Append("\n");
          sb.Append("  window.open(sURL, \'_blank3\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
          sb.Append("}\n");
          sb.Append("function ");
          sb.Append(JSREPOST_COPYTARGETFOLDER_FUNC);
          sb.Append("()\n {\n\t").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(");
          sb.Append(DirRepostControl.POSTTOSELF_ACTION_COPY);
          sb.Append(");\n}\n");
          //** End JS Tree for Selecting Target Folder for COPYING **//
          // helper functions
          sb.Append("function ").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("()\n");
          sb.Append("{\n");
          sb.Append("  return (").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(DirFolderViewHelper.QS_CHECKBOX).Append(") >= 0);\n");
          sb.Append("}\n");
          sb.Append("\n");
          // helper functions
          sb.Append("function ").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("()\n");
          sb.Append("{\n");
          sb.Append("  return (").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(EditDocViewHelper.QS_CHECKBOX).Append(") >= 0);\n");
          sb.Append("}\n");
          sb.Append("\n");
          // returns the index to the first selected input, -1 if nothing is selected
          // Warning, can't use input[i].value with the result of this, because 0 can mean
          // that it is a single object, not an array.  Use GetInputValue(input, i)
          sb.Append("function ").Append(JAVASCRIPT_GET_FIRST_INPUT).Append("(varMultiButton)\n");
          sb.Append("{\n");
          sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
          sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
          sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
          sb.Append("        return i;\n");
          sb.Append("      }\n");
          sb.Append("    }\n");
          sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
          sb.Append("      return 0;\n");
          sb.Append("  }\n");
          sb.Append("  return -1;\n");
          sb.Append("}\n");
          sb.Append("\n");
          sb.Append("function ").Append(JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("()\n");
          sb.Append("{\n");
          sb.Append("  strValue = \'\';\n");
          // add the string for each folders and cards
          // folders
          sb.Append("  strTemp = ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(DirFolderViewHelper.QS_CHECKBOX).Append(", ").Append(PT_CLASSIDS.PT_CATALOGFOLDER_ID).Append(");\n");
          sb.Append("  if ((strValue != \'\') && (strTemp != \'\')) strValue += \',\';\n");
          sb.Append("  strValue += strTemp;\n");
          // cards
          sb.Append("  strTemp = ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(EditDocViewHelper.QS_CHECKBOX).Append(", ").Append(PT_CLASSIDS.PT_CATALOGCARD_ID).Append(");\n");
          sb.Append("  if ((strValue != \'\') && (strTemp != \'\')) strValue += \',\';\n");
          sb.Append("  strValue += strTemp;\n");
          sb.Append("  return strValue;\n");
          sb.Append("}\n");
          sb.Append("\n");
          // returns a string of classid,objectID pairs separated by commas
          sb.Append("function ").Append(JAVASCRIPT_GET_OBJECT_SELECTED_STRING).Append("(varMultiButton, varnClassID)\n");
          sb.Append("{\n");
          sb.Append("  strResult = \'\';\n");
          sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
          sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
          sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
          sb.Append("        if (strResult == \'\') {\n");
          sb.Append("          strResult = varnClassID + \',\' + varMultiButton[i].value;\n");
          sb.Append("        } else {\n");
          sb.Append("          strResult += \',\' + varnClassID + \',\' + varMultiButton[i].value;\n");
          sb.Append("        }\n");
          sb.Append("      }\n");
          sb.Append("    }\n");
          sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
          sb.Append("      strResult = varnClassID + \',\' + varMultiButton.value;\n");
          sb.Append("  }\n");
          sb.Append("  return strResult;\n");
          sb.Append("}\n");
          sb.Append("\n");
          sb.Append("function ").Append(JAVASCRIPT_GET_NUMOBJECTS_SELECTED_STRING).Append("(varMultiButton)\n");
          sb.Append("{\n");
          sb.Append("  var nCount=0;\n");
          sb.Append("  if ((varMultiButton) && (varMultiButton.length)) {\n");
          sb.Append("    for ( var i = 0; i < varMultiButton.length; i++ ) {\n");
          sb.Append("      if ( varMultiButton[i].checked == true ) {\n");
          sb.Append("          nCount++;\n");
          sb.Append("      }\n");
          sb.Append("    }\n");
          sb.Append("  } else if ((varMultiButton) && (varMultiButton.checked == true)) {\n");
          sb.Append("      nCount=1;\n");
          sb.Append("  }\n");
          sb.Append("  return nCount;\n");
          sb.Append("}\n");
          sb.Append("\n");
          ASURL securityURL = new ASURL(m_asOwner);
          securityURL.SetLinkCreateNewSpace(SecurityMatrixEditorAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          securityURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
          securityURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
           EditorStartControl.EDITOR_START_FLAG_MISC);
          // This must be the last argument so we can append the classID,objectID string
          securityURL.AddControlArgument(MultiObjectsSecurityModel.QS_MULTI_OBJ_SECURITY_IDS);
          sb.Append("function ").Append(JAVASCRIPT_SECURITY).Append("()\n");
          sb.Append("{\n");
          sb.Append("  if ((").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() != true) &&\n");
          sb.Append("      (").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("() != true))\n");
          sb.Append("  {\n");
          // And display an error if nothing is selected
          sb.Append("    alert(\'").Append(m_asOwner.GetString(187, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("    return false;\n");
          sb.Append("  }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  window.open(\'").Append(securityURL.GetURLAsString()).Append("\' + ").Append(JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("(), \'_blank2\', \'location=no,menubar=no,height=600,width=800,resizable,scrollbars\');\n");
          sb.Append("}\n");
          sb.Append("\n");
          // Routine to validate  50 or less selected objects
          sb.Append("function ").Append(JAVASCRIPT_CHECKCOUNT).Append("()\n");
          sb.Append("{\n");
          // check for 50 or less selected objects
          sb.Append("  var nObjects = 0; \n");
          sb.Append("  var folders = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(DirFolderViewHelper.QS_CHECKBOX).Append(";\n");
          sb.Append("  var docs = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(EditDocViewHelper.QS_CHECKBOX).Append(";\n");
          sb.Append("  if (folders) {\n");
          sb.Append("      nObjects += ").Append(JAVASCRIPT_GET_NUMOBJECTS_SELECTED_STRING).Append("(folders);\n");
          sb.Append("  }\n");
          sb.Append("  if (docs) {\n");
          sb.Append("      nObjects += ").Append(JAVASCRIPT_GET_NUMOBJECTS_SELECTED_STRING).Append("(docs);\n");
          sb.Append("  }\n");
          sb.Append("  if (nObjects > 50) {\n");
          sb.Append("    alert(\'").Append(m_asOwner.GetString(188, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("    return false;\n");
          sb.Append("  }\n");
          sb.Append("  return true;\n");
          sb.Append("}\n");
          /*
           * ABO routines
           */
           
          // The validate function always returns true (in the submit method), so we don't
          // need to worry about resetting the form method to GET if that fails.
          sb.Append("function ").Append(JAVASCRIPT_SUBMIT_NO_REFRESH).Append("(varID)\n");
          sb.Append("{\n");
          sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".method=\'POST\';\n");
          sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(varID);\n");
          sb.Append("}\n");
          sb.Append("\n");
          ASURL deleteURL = new ASURL(m_asOwner);
          deleteURL.SetLinkGetCachedSpace(m_asOwner);
          deleteURL.SetControl(DirCheckDeleteControl.STR_MVC_CLASS_NAME);
          // Delete function
          sb.Append("function ").Append(JAVASCRIPT_DELETE).Append("()\n");
          sb.Append("{\n");
          sb.Append("  if ((").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() != true) &&\n");
          sb.Append("      (").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("() != true))\n");
          sb.Append("  {\n");
          // And display an error if nothing is selected
          sb.Append("    alert(\'").Append(m_asOwner.GetString(187, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("    return false;\n");
          sb.Append("  }\n");
          sb.Append("  if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("    return false;\n");
          sb.Append("  window.open(\'").Append(deleteURL.GetURLAsString()).Append("&").Append(DirCheckDeleteControl.DELETEFOLDERS).Append("=\' + ").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() + \'").Append(LinkConstants.AMPERSAND).Append(DirCheckDeleteControl.OBJECTIDPAIRS).Append("=\' + ").Append(JAVASCRIPT_GET_ALL_OBJECTS_SELECTED_STRING).Append("(), \'_blank2\', \'location=no,menubar=no,height=200,width=350\');\n");
          sb.Append("}\n");
          sb.Append("\n");
          sb.Append("function ").Append(JAVASCRIPT_MIGRATE).Append("()\n");
          sb.Append("{\n");
          sb.Append("  if ((").Append(JAVASCRIPT_CHECK_FOLDERS_SELECTED).Append("() != true) &&\n");
          sb.Append("      (").Append(JAVASCRIPT_CHECK_CARDS_SELECTED).Append("() != true))\n");
          sb.Append("  {\n");
          sb.Append("    alert(\'").Append(m_asOwner.GetString(187, "ptmsgs_portalbrowsingmsgs")).Append("\');\n");
          sb.Append("  } else {\n");
          sb.Append("    if(false == ").Append(JAVASCRIPT_CHECKCOUNT).Append("())\n");
          sb.Append("      return false;\n");
          sb.Append("    migrationcomment = window.prompt(\'").Append(m_asOwner.GetString(1225,
           "ptmsgs_portalbrowsingmsgs")).Append("\', \'\');\n");
          // TODO: do we need if(nn == null || nn == "null" || nn == "") for different browsers?  what if someone enters a null comment
          // null implies they cancelled the action
          sb.Append("    if (migrationcomment != null) {\n");
          sb.Append("      document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTML_INPUT_COMMENT).Append(".value = migrationcomment;\n");
          sb.Append("      ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(DirRepostControl.POSTTOSELF_ACTION_MIGRATE).Append(");\n");
          sb.Append("    }\n");
          sb.Append("  }\n");
          sb.Append("}\n");
          sb.Append("\n");
          myScript.AddInnerHTMLString(sb.ToString());
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, "FolderBannerView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        throw new XPException(m_asOwner.GetString(185, "ptmsgs_portalbrowsingmsgs"),
         he);
      }
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IDirModelRO) model;
      m_asOwner = parent;
    }
  }
}