using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <summary>
  /// This interface contains the methods on the DirModel that
  /// make changes.  IDirModelRO contains the read-only methods.
  /// </summary>
  public interface IDirModel : IDirModelRO
  {
    
    /// <param name="arFolderIDs"></param>
    void ABODeleteFolders(int[] arFolderIDs);
    
    /// <param name="arCardIDs"></param>
    /// <param name="nTargetFolder"></param>
    void CopyCards(int[] arCardIDs, int nTargetFolder);
    
    /// <param name="arFolderIDs"></param>
    /// <param name="nTargetFolder"></param>
    void CopyFolders(int[] arFolderIDs, int nTargetFolder);
    
    /// <summary>
    /// Creates a Directory Folder and calls the PEIs
    /// OnBeforeCreateDirectoryFolder and OnAfterCreateDirectoryFolder.
    /// </summary>
    /// <param name="strName">Folder Name</param>
    /// <param name="strDescription">Folder Description</param>
    void CreateDirectoryFolder(String strName, String strDescription);
    
    /// <param name="arCardIDs"></param>
    void DeleteCards(int[] arCardIDs);
    
    /// <param name="arFolderIDs"></param>
    void DeleteFolders(int[] arFolderIDs);
    
    /// <summary>
    /// This method adds objects into the migration queue.
    /// </summary>
    void MigrateObjects(int nClassID, int[] nObjects, String sComment);
    int OpenFolderByPath(String strPath);
    
    /// <param name="arCardIDs"></param>
    /// <param name="nTargetFolder"></param>
    void MoveCards(int[] arCardIDs, int nTargetFolder);
    
    /// <param name="arFolderIDs"></param>
    /// <param name="nTargetFolder"></param>
    void MoveFolders(int[] arFolderIDs, int nTargetFolder);
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderModel#OpenSubFolder(int)"></seealso>
    void OpenSubFolder(int ID);
    void SetCardSubmitMode(int nCardID);
    // Card Properties
    void SetCardID(int nCardID);
    void ClearCardRange();
    
    /// <param name="nRangeBegin"></param>
    /// <param name="nRangeEnd"></param>
    void SetCardRange(int nRangeBegin, int nRangeEnd);
    
    /// <param name="nDataSourceID"></param>
    void SetCardSubmitDataSource(int nDataSourceID);
    
    /// <param name="strURL"></param>
    void SetCardSubmitURL(String strURL);
    void SetDocUploadParams(String _duID, String _duServer);
    
    /// <param name="strURL"></param>
    void SetCardSubmitName(String strName);
    
    /// <param name="strURL"></param>
    void SetCardSubmitDescription(String strDescription);
    
    /// <summary>
    /// Set the folder to use when submitting a document.  If this is
    /// not set, the current folder will be used.
    /// </summary>
    /// <param name="_nFolderID"></param>
    void SetCardSubmitFolder(int _nFolderID);
    
    /// <summary>
    /// Sets the error associated with the card submit.
    /// </summary>
    /// <param name="_nErrorCode">
    /// The error generated during card submission.
    /// -1 means no error, and is the default value.
    /// </param>
    void SetCardSubmitError(int _nErrorCode);
    
    /// <param name="nCardID"></param>
    void SetDefaultCardRefreshSettings(int nCardID);
    
    /// <summary>
    /// Sets the Directory mode - Browse or Edit.
    /// </summary>
    /// <param name="int">Directory mode constant</param>
    void SetDirectoryMode(int nMode);
    
    /// <summary>
    /// This activity space holds only cards, so no need to change the type.
    /// </summary>
    /// <param name="ID">not used</param>
    void SetObjectType(int nNewObjectType);
    // SCC: this version uses the parameters stored on the model.
    void SubmitCard();
    /* this version will create the pbag using the specified path and DS. */
    void SubmitCard(String _strPath, int _nCSSelectedDataSource);
    /* this version will create an Upload pbag */
    void SubmitCard(String _path, String _type, String _docID);
    
    /// <param name="strPath"></param>
    /// <param name="nDataSourceID"></param>
    /// <param name="strCardName"></param>
    /// <param name="strCardDescription"></param>
    /// <param name="pbagCardProp"></param>
    /// <param name="nFolderID">the folder to use.  If this is -1, the current folder will be used.</param>
    /// <throws>Exception</throws>
    void SubmitCardWithPropertyBag(int nDataSourceID, String strCardName,
     String strCardDescription, IXPPropertyBag pbagCardProp, int nFolderID);
    
    /// <param name="arFolderIDs"></param>
    /// <param name="strLanguage"></param>
    /// <param name="nDocTypeID"></param>
    /// <param name="nDataSourceID"></param>
    /// <param name="pbagCardProp"></param>
    /// <param name="strCardName"></param>
    /// <param name="strCardDescription"></param>
    /// <throws>Exception</throws>
    /// <throws>XPException</throws>
    void SubmitCardWithPropertyBag(int[] arFolderIDs, String strLanguage,
     int nDocTypeID, int nDataSourceID, IXPPropertyBag pbagCardProp, String strCardName,
     String strCardDescription);
    
    /// <param name="arCardIDs"></param>
    /// <param name="nAction"></param>
    void doApproval(/* 2 for approve, 1 for unapprov*/
    int[] arCardIDs, int nAction);
    IPTSearchResponse SearchSubFolders(int nFolderID, int nCurrentLevel);
    void SetDocumentTypeId(String documentTypeId);
  }
}