using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using SearchExecutionWarning=com.plumtree.portaluiinfrastructure.search.SearchExecutionWarning;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <summary>
  /// This model contains data for both the Browse and Edit Modes of the
  /// Directory. The folder and document queries are cached in the model.
  /// </summary>
  /// <author>StephenC</author>
  public interface IDirModelRO : IModelRO,IFolderModel,IFolderModelRO,IObjectModelRO
  {
    
    /// <summary>
    /// This method returns whether or not there are any job IDs to display.
    /// </summary>
    /// <returns>boolean true implies there are job ids to display.</returns>
    bool ABOJobIDsToDisplay();
    
    /// <returns></returns>
    bool CheckFoldersForDelete();
    
    /// <summary>
    /// return a warning from the last search query(used in browse by search)
    /// </summary>
    SearchExecutionWarning GetWarning();
    
    /// <param name="nActivityRight"></param>
    /// <returns></returns>
    bool CheckForActivityRight(int nActivityRight);
    
    /// <summary>
    /// This method returns the job IDs for the last ABO deletes, and then clears
    /// them.
    /// </summary>
    /// <returns>int[] an array of job IDs for folder deletions.</returns>
    int[] GetABOJobIDs();
    
    /// <returns></returns>
    XPSortedDictionary GetBasicCardProperties();
    
    /// <returns></returns>
    int GetBrowseBy();
    
    /// <returns></returns>
    int GetBrowseBySource();
    ///////////////////
    // Card Properties
    int GetCardID();
    
    /// <returns></returns>
    XPSortedDictionary GetCardInformation();
    
    /// <returns></returns>
    String GetCardName();
    
    /// <param name="nCardID"></param>
    /// <returns></returns>
    String GetCardName(int nCardID);
    // Card Range
    int GetCardRangeBegin();
    int[] GetCardRange();
    
    /// <returns></returns>
    int GetCardSubmitDataSource();
    
    /// <param name="bIsWebDataSource"></param>
    /// <returns></returns>
    String GetCardSubmitURL(bool bIsWebDataSource);
    
    /// <returns>
    /// the folder the card was submitted into (either the
    /// current folder, or the card submit override folder).
    /// </returns>
    int GetCardSubmitFolder();
    
    /// <summary>
    /// Retrieve any errors generated during card submission
    /// using the REST API.
    /// </summary>
    /// <returns>
    /// The error generated during card submission.
    /// -1 if there was no error.
    /// </returns>
    int GetCardSubmitError();
    
    /// <returns></returns>
    String GetCopyTargetFolderTREESUBSPACE();
    
    /// <returns></returns>
    int GetCreatedFolderID();
    
    /// <returns></returns>
    XPSortedDictionary GetCustomCardProperties();
    
    /// <summary>
    /// returns the name of a given datasource.
    /// </summary>
    String GetDataSourceName(int nDataSourceID);
    
    /// <returns></returns>
    String GetDataSourceTREESUBSPACE();
    
    /// <summary>
    /// Gets the current directory mode - Browse or Edit
    /// </summary>
    /// <returns>int    Directory mode constant</returns>
    int GetDirectoryMode();
    // Dir Preferences
    String GetDocDescriptionType();
    
    /// <summary>
    /// returns a list of data sources that support Card Submission
    /// </summary>
    IASQueryResult GetFilteredDataSources();
    
    /// <returns></returns>
    String GetFolderDescriptionType();
    
    /// <param name="nFolderID"></param>
    /// <returns></returns>
    String GetFolderName(int nFolderID);
    
    /// <param name="nFolderID"></param>
    /// <returns></returns>
    String GetFolderPath(int nFolderID);
    
    /// <returns></returns>
    int GetMoreFolderID();
    
    /// <param name="nRelatedResourceID"></param>
    /// <returns></returns>
    Object[][] GetMoreRelatedResources(int nRelatedResourceID);
    
    /// <returns></returns>
    String GetMoveTargetFolderTREESUBSPACE();
    
    /// <returns></returns>
    int GetNumDocsPerPage();
    
    /// <returns></returns>
    int GetNumFolderColumns();
    
    /// <returns></returns>
    int GetNumSubSubFolders();
    
    /// <summary>
    /// this creates a string with the banner sub-header text.
    /// </summary>
    String GetObjectBannerText();
    
    /// <summary>
    /// returns the ID of the Default DataSource for this folder.  It will recursively search up the ancestors to          
    /// </summary>
    int GetParentDefaultDataSourceIDRecursive();
    
    /// <returns></returns>
    XPArrayList GetPropColumns();
    
    /// <returns></returns>
    int GetRRCategory();
    
    /// <returns></returns>
    int GetRRObjectID();
    
    /// <param name="nRelatedResourceID"></param>
    /// <returns></returns>
    IASQueryResult GetRelatedResource(int nRelatedResourceID);
    // Related Resource routines
    int[] GetRelatedResourceIDs();
    
    /// <param name="nRelatedResourceID"></param>
    /// <returns></returns>
    String GetRelatedResourceString(int nRelatedResourceID);
    
    /// <returns></returns>
    int GetRelatedResourcesLocation();
    
    /// <returns></returns>
    int GetTotalResults();
    
    /// <returns></returns>
    bool HasAccessToEditCard();
    
    /// <returns></returns>
    bool HasAccessToEditFolder();
    
    /// <returns></returns>
    bool HasSelfSelectExpertRightOnThisFolder();
    
    /// <returns></returns>
    int GetSubPortalAccessType();
    
    /// <returns></returns>
    bool InUnclassifiedCardsFolder();
    
    /// <summary>
    /// This method returns whether or not the current folder is at the max level
    /// </summary>
    /// <returns>boolean</returns>
    bool IsAtMaxFolderLevel();
    
    /// <returns></returns>
    bool IsRelatedExpert();
    
    /// <param name="nDataSourceID"></param>
    /// <returns></returns>
    bool IsWebDataSource(int nDataSourceID);
    
    /// <summary>
    /// returns the currently selected Copy TargetFolder ID
    /// </summary>
    int RefreshItemFromCopyTargetFolderTree();
    
    /// <summary>
    /// returns the currently selected DataSource ID
    /// </summary>
    int RefreshItemFromDataSourceTree();
    
    /// <summary>
    /// returns the currently selected Move TargetFolder ID
    /// </summary>
    int RefreshItemFromMoveTargetFolderTree();
    
    /// <returns></returns>
    bool ShowFolderActionBanner();
    
    /// <returns></returns>
    bool ShowRelatedResources();
    
    /// <returns></returns>
    XPDateTime GetObjectNewTagDate();
    
    /// <returns></returns>
    XPDateTime GetObjectUpdateTagDate();
    
    /// <returns></returns>
    IPTSession GetSession();
    
    /// <returns></returns>
    bool GetUserPrefOpenDocInNewWindow();
    
    /// <returns></returns>
    XPLocale GetUserPrefLocale();
    
    /// <returns></returns>
    XPTimeZone GetUserPrefTimeZone();
    
    /// <returns></returns>
    int GetCardSubmitMode();
    
    /// <returns></returns>
    bool HasAccessToApproveCardInFolder();
    
    /// <returns></returns>
    IASQueryResult GetBreadCrumbPath();
    
    /// <returns>
    /// boolean true if the specified data source is valid for
    /// simple submit (i.e. web, or remote document upload).
    /// </returns>
    bool IsValidSimpleSubmitSource(int _nDataSourceID);
    
    /// <summary>
    /// Returns true if the specified data source supports remote document 
    /// upload.
    /// </summary>
    /// <returns>boolean</returns>
    bool SupportsUpload(int _nDataSourceID);
    
    /// <summary>
    /// Returns the webservice's upload url if it supports uploads and it is set. 
    /// </summary>
    /// <returns>String</returns>
    String GetUploadWSURL(int _nDataSourceID);
    
    /// <summary>
    /// This method returns whether or not subfolders queries are performed through search
    /// </summary>
    /// <returns>boolean</returns>
    bool RetrieveSubFoldersThroughSearch();
    
    /// <summary>
    /// Get an IPTSearchResponse containing all of the subfolders of the current folder.
    /// </summary>
    IPTSearchResponse GetFolderSearchResponse();
    
    /// <summary>
    /// Retrieves the index within the SearchResponse that corresponds to the 
    /// ordering that would have been returned from IPTCatalog.QuerySubfolders()
    /// </summary>
    int GetFolderSearchMapping(int nUnmappedIndex);
    
    /// <summary>
    /// Retrieves the headers to be displayed in a array that includes the header's name, property Id, 
    /// and sort URL if applicaple.
    /// </summary>
    /// <returns></returns>
    IXPList GetHeaderProperties();
    
    /// <summary>
    /// Returns an array list of the values for each custom property in xpCustomProps 
    /// for the document in index _nObjectIndex.
    /// </summary>
    /// <param name="_nObjectIndex"></param>
    /// <param name="xpCustomProps"></param>
    /// <param name="xpLocale"></param>
    /// <param name="xpTimeZone"></param>
    /// <returns></returns>
    XPArrayList GetCustomFields(int _nObjectIndex, XPArrayList xpCustomProps,
     XPLocale xpLocale, XPTimeZone xpTimeZone);
    //////////////////////
    // basic object ids
    
    /// <returns></returns>
    int GetClassID();
    
    /// <returns></returns>
    int GetObjectID();
    
    /// <returns></returns>
    String GetObjectUUID();
    
    /// <returns></returns>
    int GetDocumentTypeId();
  }
}