using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.directory
{
  /// <author>StephenC</author>
  public class OpenDirFolderControl : OpenSubFolderControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.OpenDirFolderControl");
    public const String STR_MVC_CLASS_NAME = "OpenDirFolder";
    public const String m_SubFolderID = "subfolderID";
    private AActivitySpace m_space;
    private DirModel m_asModel;
    private int m_nDirMode = 0;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#execute()"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      try
      {
        bool bResetCardRange = true;
        // SubFolderID
        String[] sValues = (String[]) arguments.GetElement(m_SubFolderID);
        if (sValues == null)
        {
          sValues = (String[]) arguments.GetElement(DirConstants.QS_FOLDERPATH);
          if (sValues == null)
          {
            if (0 == m_nSubFolderID)
            {
              log.Info("could not find folder ID in query string. Opening root folder");
              m_nSubFolderID = PT_INTRINSICS.PT_FOLDER_ROOTFOLDER;
            } else
            {
              log.Info("could not find folder ID in query string. Opening current folder " + m_nSubFolderID);
              }
          } else
          // we have a folder path
          {
            int nNewSubFolderID = m_asModel.OpenFolderByPath(sValues[0]);
            if (m_nSubFolderID != nNewSubFolderID)
            {
              m_nSubFolderID = nNewSubFolderID;
            } else
            {
              bResetCardRange = false;
            }
          }
        } else
        {
          int nQueryStringSubFolderID = XPConvert.ToInteger(sValues[0]);
          if (NavigationModel.FOLDERID_UNCHANGED == nQueryStringSubFolderID)
          {
            if (0 == m_nSubFolderID)
            {
              m_nSubFolderID = PT_INTRINSICS.PT_FOLDER_ROOTFOLDER;
            }
          } else
          {
            if (m_nSubFolderID != nQueryStringSubFolderID)
            {
              m_nSubFolderID = nQueryStringSubFolderID;
            } else
            {
              bResetCardRange = false;
            }
          }
        }
        // DirMode
        // Check if this is 508 mode
        if (AccessStyles.STANDARD != m_space.GetAccessStyle())
        {
          m_nDirMode = DirConstants.DISABILITY_MODE;
          bResetCardRange = true;
        } else
        {
          sValues = (String[]) arguments.GetElement(DirConstants.QS_DIRECTORY_MODE);
          if (sValues == null)
          {
            log.Warn("could not find Directory mode in query string.  Using Browse mode");
            m_nDirMode = DirConstants.BROWSE_MODE;
          } else
          {
            int nQSDDirMode = XPConvert.ToInteger(sValues[0]);
            // Always reset the card range if the mode is changed
            if (m_nDirMode != nQSDDirMode)
            {
              bResetCardRange = true;
            }
            m_nDirMode = nQSDDirMode;
          }
        }
        //PEI : DirectoryActions : OnOpenFolder
        //BrianH: This set of code will process all of the available OnOpenFolder function PEIs.
        //It will load them from the Application cache and then loop through them and process
        //each until a Redirect is returned or not.
        Object[] oa;
        Object o;
        IDirectoryActions iActions;
        IApplication application = m_space.GetApplication();
        Redirect directoryActionsRedirect;
        oa = (Object[]) application.GetCachingManager().GetEntry("DirectoryActions");
        if (oa != null)
        {
          for (int x = 0;x < oa.Length;x++)
          {
            o = oa[x];
            log.Debug("OpenDirFolderControl.CheckActionSecurityAndExecute - About to call OnOpenFolder on an: " + o);
            if (o != null)
            {
              iActions = (IDirectoryActions) o;
              directoryActionsRedirect = iActions.OnOpenFolder(m_space, (IPTSession) m_space.GetUserSession(),
               m_nSubFolderID);
              if (directoryActionsRedirect != null)
              {
                return directoryActionsRedirect;
              }
            }
          }
        }
        m_asModel.SetFolderIDAndMode(m_nSubFolderID, m_nDirMode);
        if (bResetCardRange)
        {
          m_asModel.ClearCardRange();
          /* bug 21469 fix: reset the sorting property id so that each
           * folder's default sorting setting is maintained.
           */
           
          m_asModel.SetSortByPropID(DirConstants.SORTING_NOTSET);
        }
        bool bLoadedFolderSuccess = m_asModel.LoadFoldersAndDocuments();
        if (!bLoadedFolderSuccess)
        {
          throw new Exception(m_space.GetString(151, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         e, m_space.GetString(1227, "ptmsgs_portalbrowsingmsgs"), e.Message);
        UIErrorHandler.RaiseError(myError, m_space.GetSubSession(), m_space.GetApplication());
        log.Error(e, "Could not open folder");
        /* if we failed to open the doc/folder because we were not logged
         * in yet, display error and login page... logging in will then
         * attempt to reopen doc/folder
         */
         
        IPTSession ptSession = (IPTSession) m_space.GetUserSession();
        if (LoginHelper.INSTANCE.GetIsGuestUser(ptSession))
        {
          Redirect myRedirectToLogin = new Redirect();
          myRedirectToLogin.SetIsErrorRedirect(true);
          myRedirectToLogin.SetLinkCreateNewSpace(m_space.GetName(), m_space);
          myRedirectToLogin.SetControl(STR_MVC_CLASS_NAME);
          myRedirectToLogin.AddControlArguments(arguments);
          return myRedirectToLogin;
        } else
        {
          myError.SetDisplayOnSeparatePage(true);
        }
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new OpenDirFolderControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#getName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#init(IModel,AActivitySpace)"></seealso>
    public override void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (DirModel) model;
      m_space = space;
    }
  }
}