using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.directory.edit;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory.browse_D
{
  /// <summary>
  /// Presents Documents through Database (Disability)
  /// </summary>
  /// <author>StephenC</author>
  public class BrowseDocViewHelper_D : IObjectViewHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.browse_D.BrowseDocViewHelper_D");
    
    /// <summary>
    /// Localized String: Document Type:  
    /// </summary>
    private IDirModelRO m_dirModel;
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#AddObjectViewHTML()"></seealso>
    public virtual HTMLElement AddObjectViewHTML(IObjectModelRO model)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#Display508Object(int,HTMLTable,IObjectModelRO,AActivitySpace)"></seealso>
    public virtual void Display508Object(int nObjectIndex, HTMLTable tableObjects,
     IObjectModelRO model, AActivitySpace parent)
    {
      m_dirModel = (IDirModelRO) model;
      //Construct definitions
      HTMLTableRow row;
      try
      {
        // Get the document ID
        String strDocumentID = XPConvert.ToString(m_dirModel.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_OBJECTID));
        //Get the document name
        String strName = XPHttpUtility.HtmlEncode((String) m_dirModel.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_NAME));
        //Get the image uiid
        String strImageUIID = (String) m_dirModel.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_IMAGEUUID);
        // get the current language.					
        String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
         parent);
        // get the tooltip string based on the UUID.  use the PTDocTypesVarPack.
        // default to the document name if the PTDocTypesVarPack does not have
        // the string for this UUID.
        String strImageToolTip = strName;
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        if (null != application)
        {
          PTDocTypesVarPack varPack = (PTDocTypesVarPack) application.GetVarPackManager().GetVariablePackage(PTDocTypesVarPack.VARPACK_ID);
          if (null != varPack)
          {
            strImageToolTip = varPack.GetLocalizedName(strImageUIID, strLangID);
            if (strImageToolTip.Equals(""))
            {
              strImageToolTip = strName;
            }
          }
        }
        //Description
        String strDescType = m_dirModel.GetDocDescriptionType();
        String strDesc = "";
        if (false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,
         strDescType))
        {
          strDesc = (String) m_dirModel.GetObjectFields(nObjectIndex, (PT_PROPIDS.PT_PROPID_DESCRIPTION));
          if (null == strDesc)
          {
            strDesc = "";
          }
          // abbreviate the description if necessary
          if (true == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_ABBR,
           strDescType))
          {
            if (DirConstants.DESCRIPTION_ABBR_LENGTH < strDesc.Length)
            {
              strDesc = XPStringUtility.Substring(strDesc, 0, DirConstants.DESCRIPTION_ABBR_LENGTH) + "...";
              }
          }
          // HTMLEncode
          strDesc = XPHttpUtility.HtmlEncode(strDesc);
        }
        // Open document URL
        String strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGCARD_ID,
         XPConvert.ToInteger(strDocumentID), IPTOpenerConstants.OPENER_MODE_VIEW,
         parent);
        // anchor for list item construct
        HTMLAnchor aPrimaryLink = new HTMLAnchor(strURL);
        aPrimaryLink.SetTitle(strName);
        // if we need to set the 508-compliant lang tag
        String itemLang = GetDocumentLangTag(nObjectIndex, m_dirModel, parent);
        HTMLSpan langSpan;
        if (null != itemLang)
        {
          langSpan = new HTMLSpan();
          langSpan.SetLangLocal(itemLang);
          langSpan.AddInnerHTMLString(strName);
          aPrimaryLink.AddInnerHTMLElement(langSpan);
        } else
        {
          aPrimaryLink.AddInnerHTMLString(strName);
        }
        // since we can't have js to popup new window use _blank
        if (m_dirModel.GetUserPrefOpenDocInNewWindow())
        {
          aPrimaryLink.SetTarget("_blank");
        }
        // use list item construct
        UIListItem itemConstruct;
        itemConstruct = new UIListItem(aPrimaryLink, parent);
        itemConstruct.SetTitle(strName);
        itemConstruct.SetTitleStyleClass(PTStyleClass.LIST_SUBTITLE);
        if ((false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,
         strDescType)) && (0 != strDesc.Length))
        {
          // if we need to set the 508-compliant lang tag
          if (null != itemLang)
          {
            langSpan = new HTMLSpan();
            langSpan.SetLangLocal(itemLang);
            langSpan.AddInnerHTMLString(strDesc);
            itemConstruct.SetDescription(langSpan.GetDisplayString());
          } else
          {
            itemConstruct.SetDescription(strDesc);
          }
        }
        //Properties URL
        ASURL myURL = new ASURL(parent);
        myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, parent);
        myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
        myURL.SetDisplayPage(DirCardPropertiesDP_D.STR_MVC_CLASS_NAME);
        myURL.AddControlArgument(DirConstants.QS_CARDID, strDocumentID);
        HTMLAnchor myAnchor = new HTMLAnchor(myURL.GetURLAsString());
        myAnchor.AddInnerHTMLString(parent.GetString(1794, "ptmsgs_portalbrowsingmsgs"));
        myAnchor.SetTitle(XPResourceManager.FormatMessage(parent.GetString(1792,
         "ptmsgs_portalbrowsingmsgs"), strName));
        itemConstruct.SetPropertiesLink(myAnchor);
        // Image UIID
        HTMLImg myImg = PlumtreeHelpers.GetHTMLImage(strImageUIID, true);
        myImg.SetAlt(strImageToolTip);
        itemConstruct.SetItemTypeImage(myImg);
        // delete
        bool canEditKD = m_dirModel.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY);
        bool canEditFolder = m_dirModel.HasAccessToEditFolder();
        if (canEditKD && canEditFolder)
        {
          myURL = new ASURL(parent);
          myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, parent);
          myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
          myURL.AddControlArgument(EditDocViewHelper.QS_CHECKBOX, new String[]{strDocumentID});
          myURL.AddControlArgument(DirConstants.QS_508_DELETE, "true");
          itemConstruct.SetItemEditButton(PTImageType.ACTION_DELETE, parent.GetString(177,
           "ptmsgs_portalbrowsingmsgs"), myURL.GetURLAsString());
        }
        // convert the construct to table
        try
        {
          row = new HTMLTableRow();
          row.SetStyleClass(((nObjectIndex % 2) == 1) ? PTStyleClass.LIST_ITEM_ONE_BG : PTStyleClass.LIST_ITEM_TWO_BG);
          itemConstruct.AddItemCellsToRow(row);
          tableObjects.AddInnerHTMLElement(row);
        }
        catch (Exception e)
        {
          log.Error(e, "BrowseDocViewHelper_D::Display508Object. The following exception occured: " + e.Message);
          }
      }
      catch (Exception e)
      {
        log.Error(e, "BrowseDocViewHelper_D::Display508Object. The following exception occured: " + e.Message);
        }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#GetThereAreNoItemsString(AActivitySpace)"></seealso>
    public virtual String GetThereAreNoItemsString(AActivitySpace asOwner)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayJavascriptCollection(AActivitySpace)"></seealso>
    public virtual HTMLScriptCollection DisplayJavascriptCollection(AActivitySpace asOwner,
     IObjectModelRO model)
    {
      return null;
    }
    
    /// <summary>
    /// Displays the object at the given index in the query result. This must be
    /// overridden by all subclasses.
    /// </summary>
    /// <param name="nObjectIndex"></param>
    /// <param name="tableObjects"></param>
    /// <param name="model"></param>
    public virtual void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
     IObjectModelRO model, AActivitySpace asOwner)
    {
      m_dirModel = (IDirModelRO) model;
      //Construct definitions
      HTMLTableRow row;
      try
      {
        // Get the document ID
        String strDocumentID = XPConvert.ToString(m_dirModel.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_OBJECTID));
        //Get the document name
        String strName = XPHttpUtility.HtmlEncode((String) m_dirModel.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_NAME));
        //Get the image uiid
        String strImageUIID = (String) m_dirModel.GetObjectFields(nObjectIndex,
         PT_PROPIDS.PT_PROPID_IMAGEUUID);
        //Description
        String strDescType = m_dirModel.GetDocDescriptionType();
        String strDesc = "";
        if (false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,
         strDescType))
        {
          strDesc = XPHttpUtility.HtmlEncode((String) m_dirModel.GetObjectFields(nObjectIndex,
           (PT_PROPIDS.PT_PROPID_DESCRIPTION)));
          if (null == strDesc)
          {
            strDesc = "";
          }
          // abbreviate the description if necessary
          if (true == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_ABBR,
           strDescType))
          {
            if (DirConstants.DESCRIPTION_ABBR_LENGTH < strDesc.Length)
            {
              strDesc = XPStringUtility.Substring(strDesc, 0, DirConstants.DESCRIPTION_ABBR_LENGTH) + "...";
              }
          }
        }
        // Open document URL
        String strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGCARD_ID,
         XPConvert.ToInteger(strDocumentID), IPTOpenerConstants.OPENER_MODE_VIEW,
         asOwner);
        // use list item construct
        UIListItem itemConstruct = new UIListItem(strName, strURL, asOwner);
        itemConstruct.SetTitleStyleClass(PTStyleClass.LIST_SUBTITLE);
        if ((false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,
         strDescType)) && (0 != strDesc.Length))
        {
          itemConstruct.SetDescription(strDesc);
        }
        //Properties URL
        ASURL myURL = new ASURL(asOwner);
        myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, asOwner);
        myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
        myURL.SetDisplayPage(DirCardPropertiesDP_D.STR_MVC_CLASS_NAME);
        myURL.AddControlArgument(DirConstants.QS_CARDID, strDocumentID);
        HTMLAnchor myAnchor = new HTMLAnchor(myURL.GetURLAsString());
        myAnchor.AddInnerHTMLString(asOwner.GetString(31, "ptmsgs_portalbrowsingmsgs"));
        myAnchor.SetTitle(asOwner.GetString(31, "ptmsgs_portalbrowsingmsgs"));
        itemConstruct.SetPropertiesLink(myAnchor);
        // Image UIID
        HTMLImg myImg = PlumtreeHelpers.GetHTMLImage(strImageUIID, true);
        itemConstruct.SetItemTypeImage(myImg);
        // convert the construct to table
        try
        {
          row = new HTMLTableRow();
          itemConstruct.AddItemCellsToRow(row);
          tableObjects.AddInnerHTMLElement(row);
        }
        catch (Exception e)
        {
          log.Error(e, "BrowseDocViewHelper_D::DisplayObject. The following exception occured: " + e.Message);
          }
      }
      catch (Exception e)
      {
        log.Error(e, "BrowseDocViewHelper_D::DisplayObject. The following exception occured: " + e.Message);
        }
    }
    // returns null if no document lang tag is need.
    private String GetDocumentLangTag(int nObjectIndex, IDirModelRO model,
     AActivitySpace asOwner)
    {
      // What's the user's default language?  We'll need this for tagging any strings
      // that we think are in another language.
      String sUserLang = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
       asOwner);
      String sDocLang;
      try
      {
        sDocLang = (String) m_dirModel.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_CARD_CONTENTLANGUAGE);
        }
      catch (Exception e)
      {
        // if we can't get the lang don't use lang tag
        return null;
      }
      if ((null != sDocLang) && (0 == sDocLang.Length))
      {
        // Ignore empty strings
        return null;
      }
      if (null != sDocLang)
      {
        sDocLang = XPStringUtility.ToLowerCase(sDocLang);
        if (XPStringUtility.EqualsIgnoreCase(sDocLang, sUserLang))
        {
          // If the item is in the user's default language, 
          // don't bother marking it with special tags.
          return null;
        }
      }
      return sDocLang;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.objects.IObjectViewHelper#SetExpandButton(HTMLAnchor,IObjectModelRO)"></seealso>
    public virtual void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model)
    {
    }
  }
}