using System;
// Framework imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory.documentsubmitsimple
{
  /// <summary>
  /// This Section contains the HTML for the dependencies page.
  /// </summary>
  /// <author>StephenC</author>
  public class DirCardSubmitDependenciesView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.documentsubmitsimple.DirCardSubmitDependenciesView");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DirCardSubmitPopUpDependencies";
    
    /// <summary>
    /// HTML Object name: close button 
    /// </summary>
    public const String HTMLBUTTON_CLOSE = "in_bu_Close";
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Associated read-only Model.
    /// </summary>
    protected IDirModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new DirCardSubmitDependenciesView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myMainTable;
      HTMLTable myTable;
      HTMLTableRow myMainTableRow;
      HTMLTableRow myRow;
      HTMLTableCell myMainTableCell;
      HTMLTableCell myCell;
      HTMLInput myInput;
      try
      {
        // Main table
        myMainTable = new HTMLTable();
        result.AddInnerHTMLElement(myMainTable);
        myMainTable.SetWidth("100%");
        myMainTable.SetHeight("600");
        myMainTable.SetBorder("0");
        myMainTable.SetCellPadding("0");
        myMainTable.SetCellSpacing("0");
        // Main table = row 1
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetHeight("60");
        myMainTableCell.SetWidth("100%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // Main table = row 2
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("100%");
        myMainTableCell.SetHeight("380");
        myMainTableCell.SetVAlign("top");
        // Content table
        myTable = new HTMLTable();
        myMainTableCell.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("5");
        // Row 1 - begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetColSpan("2");
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_NOTICE_HEADER);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1205, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(new HTMLBr());
        // Row 1 - end
        // Dependency rows
        myTable.AddInnerHTMLElement(GetHTMLForDependencies());
        // Row Close Button - begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetColSpan("2");
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myCell.AddInnerHTMLElement(new HTMLBr());
        myCell.AddInnerHTMLElement(new HTMLBr());
        // Button to close the window and redirect the main one.
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1202, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("self.close();");
        // Row Close Button - end
        // Row 4 - begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100%");
        myCell.SetColSpan("2");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // Row 4 - end
        // Main table = row 3
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetHeight("160");
        myMainTableCell.SetWidth("100%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      catch (HTMLException e)
      {
        log.Error(e, "DirCardSubmitDependenciesView::Display The following error occured when trying to display the HTML: ");
        throw new XPException(m_asOwner.GetString(1203, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IDirModelRO) model;
      m_asOwner = parent;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected virtual HTMLTableCell GetEmptyCell()
    {
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
      myCell.SetWidth("30");
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the successfully created message.
    /// This message can be customized for each Object by extending
    /// this Section and overriding this method.
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    protected virtual HTMLElementCollection GetHTMLForDependencies()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      int nParentFolderID = m_model.GetCurrentFolderID();
      int nSubmittedCardID = m_model.GetCardID();
      // Row 1 - begin
      myRow = new HTMLTableRow();
      result.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetColSpan("2");
      myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
      myCell.AddInnerHTMLString(m_asOwner.GetString(1204, "ptmsgs_portalbrowsingmsgs"));
      // Row 1 - end
      // Row Card Name - begin
      myRow = new HTMLTableRow();
      result.AddInnerHTMLElement(myRow);
      myRow.AddInnerHTMLElement(GetEmptyCell());
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
      myCell.AddInnerHTMLString(m_asOwner.GetString(1200, "ptmsgs_portalbrowsingmsgs"));
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_model.GetCardName(nSubmittedCardID)));
      // Row Card Name - end
      // Row Card Path - begin
      myRow = new HTMLTableRow();
      result.AddInnerHTMLElement(myRow);
      myRow.AddInnerHTMLElement(GetEmptyCell());
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
      myCell.AddInnerHTMLString(m_asOwner.GetString(1201, "ptmsgs_portalbrowsingmsgs"));
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_model.GetFolderPath(nParentFolderID)));
      // Row Card Path - end
      result.AddInnerHTMLElement(DirConstants.CreateSpacerRow(2, 30));
      return result;
    }
  }
}