using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.directory.opendoc
{
  /// <author>John Osborne</author>
  public class OpenDocControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.opendoc.OpenDocControl");
    public const String STR_MVC_CLASS_NAME = "OpenDoc";
    private AActivitySpace m_asOwner;
    private IOpenDocModel m_modModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      int nCardID = HTTPHelpers.GetArgumentAsInt(arguments, DirConstants.QS_CARDID,
       -1);
      m_modModel.SetDocumentID(nCardID);
      if (m_modModel.GetOpenDocURL() == null)
      {
        Redirect myRedirectToLogin = new Redirect();
        myRedirectToLogin.SetLinkGetCachedSpace(m_asOwner);
        myRedirectToLogin.SetIsErrorRedirect(true);
        myRedirectToLogin.SetControl(STR_MVC_CLASS_NAME);
        myRedirectToLogin.AddControlArguments(arguments);
        return myRedirectToLogin;
      }
      // Get the URL we want to redirect to.
      String strOpenDocURL = m_modModel.GetOpenDocURL();
      // RWW - Bug 33047, the URL being returned isn't completely
      // encoded.  We can't just use a EncodeURL because parts of
      // the URL may already be encoded.  If we end up using this
      // in other parts of the UI, move to a helper class.	
      XPStringBuilder sbOpenDocURLEncoded = new XPStringBuilder(512);
      byte[] bytesOpenDocURL = XPEncoding.GetBytes(strOpenDocURL, XPStringUtility.DEFAULT_ENCODING);
      for (int i = 0;i < bytesOpenDocURL.Length;i++)
      {
        byte byteCurrentByte = bytesOpenDocURL[i];
        // In C# a "byte" is unsigned and therefore we need to 
        // check above 127.  In JAVA a "byte" is signed and we
        // therefore need to check for below 0.
        if ((byteCurrentByte < 0) || (byteCurrentByte > 127))
        {
          String strHexRepOfByte = XPConvert.ToHexString(byteCurrentByte);
          sbOpenDocURLEncoded.Append("%").Append(XPStringUtility.Substring(strHexRepOfByte,
           strHexRepOfByte.Length - 2, strHexRepOfByte.Length));
        } else
        {
          sbOpenDocURLEncoded.Append(XPConvert.ToChar(byteCurrentByte));
        }
      }
      strOpenDocURL = sbOpenDocURLEncoded.ToString();
      Redirect redirect = new Redirect();
      if (XPStringUtility.IndexOf(strOpenDocURL, GatewayHelpers.GATEWAY_URL_PREFIX) > 0)
      {
        // DCA - Let us do an internal redirect to the Gateway space to keep the URL in the browser the same
        redirect.SetLinkCreateNewSpace(GatewayAS.STR_MVC_CLASS_NAME, m_asOwner);
        redirect.SetControl(GatewayControl.STR_MVC_CLASS_NAME);
        // DCA - this is the Gateway URL to the document. We're storing it in the user's session so that we can
        // retrieve it in the Gateway Control when we're redirected
        m_asOwner.GetSubSession().SetAttribute(STR_MVC_CLASS_NAME, strOpenDocURL);
        } else
      {
        // DCA - it's not gatewayed, perform OnClickThroughToDoc PEI
        Redirect peiRedirect = OpenDocControl.PerformOnClickThroughToDocPEI(nCardID,
         m_asOwner);
        if (null != peiRedirect)
        {
          return peiRedirect;
        } else
        {
          // DCA - do external redirect
          redirect.SetLinkToExternalURL(strOpenDocURL);
        }
      }
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new OpenDocControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel _modModel, AActivitySpace _asOwner)
    {
      m_modModel = (IOpenDocModel) _modModel;
      m_asOwner = _asOwner;
    }
    public static Redirect PerformOnClickThroughToDocPEI(int _nCardId, AActivitySpace _asOwner)
    {
      // PEI : DirectoryActions : OnClickThroughToDoc
      //BrianH: This set of code will process all of the available OnClickThroughToDoc function PEIs.
      //It will load them from the Application cache and then loop through them and process
      //each until a Redirect is returned or not.
      Object[] oa;
      Object o;
      IDirectoryActions iActions;
      IApplication application = _asOwner.GetApplication();
      Redirect directoryActionsRedirect;
      oa = (Object[]) application.GetCachingManager().GetEntry("DirectoryActions");
      if (oa != null)
      {
        for (int x = 0;x < oa.Length;x++)
        {
          o = oa[x];
          log.Debug("OpenDocControl.CheckActionSecurityAndExecute - About to call OnClickThroughToDoc on an: " + o);
          if (o != null)
          {
            iActions = (IDirectoryActions) o;
            directoryActionsRedirect = iActions.OnClickThroughToDoc(_asOwner,
             (IPTSession) _asOwner.GetUserSession(), _nCardId);
            if (directoryActionsRedirect != null)
            {
              return directoryActionsRedirect;
            }
          }
        }
      }
      return null;
    }
  }
}
//PEI: DirectoryActions : END	
