using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.directory.opendoc
{
  /// <author>John Osborne</author>
  public class OpenDocDP : IDisplayPage
  {
    public const String STR_MVC_CLASS_NAME = "OpenDoc";
    private AActivitySpace m_asOwner;
    private IOpenDocModelRO m_modMyModelRO;
    
    /// <param name="webData"></param>
    public virtual void Display(IWebData webData)
    {
      // DCA - this is currently not being used anymore. The code was moved to the OpenDocControl class
      // so that we can do an internal redirect to the Gateway AS and have the gateway URL hidden.
      // Get the URL we want to redirect to.
      String strOpenDocURL = m_modMyModelRO.GetOpenDocURL();
      // RWW - Bug 33047, the URL being returned isn't completely
      // encoded.  We can't just use a EncodeURL because parts of
      // the URL may already be encoded.  If we end up using this
      // in other parts of the UI, move to a helper class.	
      XPStringBuilder sbOpenDocURLEncoded = new XPStringBuilder(512);
      byte[] bytesOpenDocURL = XPEncoding.GetBytes(strOpenDocURL, XPStringUtility.DEFAULT_ENCODING);
      for (int i = 0;i < bytesOpenDocURL.Length;i++)
      {
        byte byteCurrentByte = bytesOpenDocURL[i];
        // In C# a "byte" is unsigned and therefore we need to 
        // check above 127.  In JAVA a "byte" is signed and we
        // therefore need to check for below 0.
        if ((byteCurrentByte < 0) || (byteCurrentByte > 127))
        {
          String strHexRepOfByte = XPConvert.ToHexString(byteCurrentByte);
          sbOpenDocURLEncoded.Append("%").Append(XPStringUtility.Substring(strHexRepOfByte,
           strHexRepOfByte.Length - 2, strHexRepOfByte.Length));
        } else
        {
          sbOpenDocURLEncoded.Append(XPConvert.ToChar(byteCurrentByte));
        }
      }
      // Send redirect to the properly encoded URL.
      webData.SendRedirect(sbOpenDocURLEncoded.ToString());
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()"></seealso>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace _asOwner)
    {
      m_asOwner = _asOwner;
      m_modMyModelRO = (IOpenDocModelRO) m_asOwner.GetModel(OpenDocModel.STR_MVC_CLASS_NAME);
      }
  }
}