using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.browsing.directory.opendoc
{
  /// <author>John Osborne</author>
  public class OpenDocModel : IOpenDocModel,IOpenDocModelRO
  {
    public const String STR_MVC_CLASS_NAME = "OpenDoc";
    private OpenDocAS m_asOwner;
    private String m_strDocURL = null;
    private int m_nDocID = -1;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new OpenDocModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual String GetOpenDocURL()
    {
      if (m_strDocURL == null)
      {
        try
        {
          m_strDocURL = ((IPTSession) m_asOwner.GetUserSession()).GetCatalog().OpenCard(m_nDocID,
           false).GetDocumentURL();
        }
        catch (Exception e)
        {
          m_strDocURL = null;
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, m_asOwner.GetString(1685, "ptmsgs_portalbrowsingmsgs"), e.Message);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
      }
      return m_strDocURL;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = (OpenDocAS) parent;
    }
    
    /// <param name="_nDocID"></param>
    public virtual void SetDocumentID(int _nDocID)
    {
      m_nDocID = _nDocID;
      // DCA - doc Id is changing, clear out doc URL
      m_strDocURL = null;
    }
  }
}