using System;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.keywords;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory.properties
{
  /// <author>
  /// joseq
  /// extends KeywordsView so that it can be used with DirAS with in a non-EditorAS.
  /// KeywordsView.Init() is overridding so that the explicit casting of the activityspace
  /// to EditorAS does not occur.  Also, we wrap the Keywords view in a table to 
  /// keep the Properties display page uniform. 
  /// </author>
  public class DirKeywordsView : KeywordsView
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DirKeywords";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DirKeywordsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the View with the read-only Model and the Activity Space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = model;
      m_asOwner = parent;
    }
    
    /// <summary>
    /// Returns the HTML for the View.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection resultWrapper = new HTMLElementCollection();
      /* wrapper table */
      HTMLTable mainTable = new HTMLTable();
      resultWrapper.AddInnerHTMLElement(mainTable);
      mainTable.SetBorder("0");
      mainTable.SetWidth("100%");
      mainTable.SetCellPadding("2");
      mainTable.SetCellSpacing("2");
      /* spacer */
      mainTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(2, 25));
      /* row + cell */
      HTMLTableRow myRow = new HTMLTableRow();
      mainTable.AddInnerHTMLElement(myRow);
      HTMLTableCell myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetColSpan("2");
      /* add the original Keywords view */
      myCell.AddInnerHTMLElement(base.Display());
      return resultWrapper;
    }
  }
}