using System;
namespace com.plumtree.portalpages.browsing.directory.rest
{
  /// <summary>
  /// This class contains constants for the KD Rest API.  These can
  /// be used in both the JSON format and the XML format.
  /// Each constant is marked with input and/or output depending on
  /// whether it can be used as an input to the API, an output, or both.
  /// </summary>
  public class DirRESTConstants
  {
    // These constants describe the JSON/XML input/output format.
    
    /// <summary>
    /// The name of the document object in the format (i.e. the object
    /// itself, not a member of the object).
    /// input/output
    /// </summary>
    public const String DOCUMENT_FORMAT_NAME = "document";
    
    /// <summary>
    /// The key for the document name member.
    /// input/output
    /// </summary>
    public const String DOCUMENT_NAME = "name";
    
    /// <summary>
    /// The key for the document description member.
    /// input
    /// </summary>
    public const String DOCUMENT_DESCRIPTION = "description";
    
    /// <summary>
    /// The key for the document data source ID member.
    /// input
    /// </summary>
    public const String DOCUMENT_DATA_SOURCE_ID = "datasourceid";
    
    /// <summary>
    /// The key for the document content url member.
    /// input
    /// </summary>
    public const String DOCUMENT_CONTENT_URL = "contenturl";
    
    /// <summary>
    /// The key for the document type member.
    /// input
    /// </summary>
    public const String DOCUMENT_TYPE = "type";
    
    /// <summary>
    /// The key for the document doc ID member.
    /// input
    /// </summary>
    public const String DOCUMENT_DOC_ID = "docid";
    
    /// <summary>
    /// The key for the document server ID member.
    /// input
    /// </summary>
    public const String DOCUMENT_SERVER_ID = "serverid";
    
    /// <summary>
    /// The key for the document object ID member.
    /// output
    /// </summary>
    public const String DOCUMENT_OBJECT_ID = "objectid";
    
    /// <summary>
    /// The key for the document folder ID member.
    /// output
    /// </summary>
    public const String DOCUMENT_FOLDER_ID = "folderid";
    
    /// <summary>
    /// The key for the document folder path member.
    /// output
    /// </summary>
    public const String DOCUMENT_FOLDER_PATH = "folderpath";
  }
}