using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.rest;
using com.plumtree.portalpages.rest.utils;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.directory.rest
{
  /// <summary>
  /// This display page handles display the JSON/XML results of the KD REST API.
  /// </summary>
  public class DirRESTDP : IDisplayPage
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
     "com.plumtree.portalpages.browsing.directory.browse.DirRESTDP");
    public const String STR_MVC_CLASS_NAME = "DirREST";
    protected AActivitySpace m_asOwner;
    protected IDirModelRO m_dirModel;
    public virtual void Display(IWebData webData)
    {
      // Comment filtering is often used to thwart JSON security attacks.
      // The JSON data should be wrapped in /* */ for any JSON created on
      // the server side.
      // In addition, all JSON output should be wrapped in a plain { } block
      // so that it can't be used directly in a script src tag.
      try
      {
        // This will turn off HTML performance comments, allowing us to output
        // a valid JSON response.  Note that adding comment filtering allows us
        // to add the comments after the comment and Dojo will ignore them.  We
        // should still disable them anyways, in case someone wants to use a
        // library other than Dojo.
        webData.SetIsHTMLText(false);
        // Say that this data is comment-filtered JSON.
        webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "text/json-comment-filtered");
        // This currently only supports JSON output
        int nError = m_dirModel.GetCardSubmitError();
        if (nError > 0)
        {
          IRESTError error = CommonRestErrors.GENERAL;
          try
          {
            error = RESTErrors.GetError(nError);
          }
          catch (Exception e)
          {
            log.Warn("Unable to retrieve Dir REST API error " + nError + ". Using general error instead.");
            error = CommonRestErrors.GENERAL;
          }
          // This handles outputting the error to the webdata object.
          new RESTHelper().OutputError(error, webData, true);
        } else
        {
          // Display document creation results
          // Really rough estimate of smallest output
          XPStringBuilder sbJSON = new XPStringBuilder(130);
          int nSubmittedCardID = m_dirModel.GetCardID();
          String strCardName = m_dirModel.GetCardName(nSubmittedCardID);
          // Make sure we HTML encode anything that goes out as JSON, because it could be eval'ed,
          // which is a pretty big security issue.
          String strFittedAndEncodedCardName = DirConstants.BreakUpLongWordsInStringAndHTMLEncode(strCardName);
          int nParentFolderID = m_dirModel.GetCardSubmitFolder();
          String strFolderPath = XPHttpUtility.HtmlEncode(m_dirModel.GetFolderPath(nParentFolderID));
          // Since the output of this API will be used in Javascript, we need to escape the string
          // so that \'s will be treated as \'s, rather than the start of escape sequences.
          strFittedAndEncodedCardName = GeneralHelpers.Replace(strFittedAndEncodedCardName,
           "\\", "\\\\");
          strFolderPath = GeneralHelpers.Replace(strFolderPath, "\\", "\\\\");
          // We don't need to escape the IDs, since those are ints.
          sbJSON.Append("/*{\n").Append("  \"").Append(DirRESTConstants.DOCUMENT_FORMAT_NAME).Append("\": {\n").Append("    \"").Append(DirRESTConstants.DOCUMENT_NAME).Append("\": \"").Append(strFittedAndEncodedCardName).Append("\",\n").Append("    \"").Append(DirRESTConstants.DOCUMENT_OBJECT_ID).Append("\": \"").Append(nSubmittedCardID).Append("\",\n").Append("    \"").Append(DirRESTConstants.DOCUMENT_FOLDER_ID).Append("\": \"").Append(nParentFolderID).Append("\",\n").Append("    \"").Append(DirRESTConstants.DOCUMENT_FOLDER_PATH).Append("\": \"").Append(strFolderPath).Append("\"\n").Append("  }\n").Append("}*/");
          // Created HTTP Status Code
          webData.SetStatus(201);
          webData.SetData(sbJSON.ToString());
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to display JSON output in Dir REST API.");
        // This handles outputting the error to the webdata object.
        new RESTHelper().OutputError(CommonRestErrors.GENERAL, webData, true);
        }
    }
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_dirModel = (IDirModelRO) m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);
      }
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}