using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.directory.senddoc
{
  /// <author>stephenc</author>
  public class SendDocPopUpView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.directory.senddoc.SendDocPopUpView");
    public const String STR_MVC_CLASS_NAME = "SendDocPopUpView";
    
    /// <summary>
    /// Localized String: To send this document link, just paste the following URL into an email: 
    /// </summary>
    public const String HTMLBUTTON_SEND = "in_bu_Send";
    public const String HTMLBUTTON_DONE = "in_bu_Done";
    protected AActivitySpace m_asOwner;
    protected IDirModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SendDocPopUpView();
    }
    
    /// <returns></returns>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      HTMLTextArea myTextArea;
      HTMLInput myInput;
      try
      {
        int nCardID = m_model.GetCardID();
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        //Header Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1514, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(new HTMLBr());
        // Header Row end
        //Instruction Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1515, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(new HTMLBr());
        // Instruction Row end
        //Email Text Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        // ***<textarea>*** begins here
        myTextArea = new HTMLTextArea("65", "6");
        myTextArea.SetReadOnly(true);
        myCell.AddInnerHTMLElement(myTextArea);
        myTextArea.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        // The URL to open the pop-up
        String strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGCARD_ID,
         nCardID, IPTOpenerConstants.OPENER_MODE_VIEW, m_asOwner);
        myTextArea.AddInnerHTMLString(strURL);
        // ***<textarea>*** ends here
        // Email Text Row end
        // Done Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // send button
        // FUTURE (bug 19059): add mail to link
        /*
         
         myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_SEND, m_asOwner.GetString(1510, "ptmsgs_portalbrowsingmsgs"));
         myCell.AddInnerHTMLElement(myInput);
         myCell.SetAlign(CommonHTMLStrings.CENTER);
         
         
         myInput.SetValue(m_asOwner.GetString(1509, "ptmsgs_portalbrowsingmsgs"));
         myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
         myInput.SetOnClick("OpenMailTo('" + strURL + "'); return false;");	// mj: removed 'Javascript:' from function name
         //			myInput.SetOnClick("window.open('mailto:?body=<" + strURL + "')");
         */
         
        // done button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_DONE, m_asOwner.GetString(1512,
         "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(myInput);
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myInput.SetValue(m_asOwner.GetString(1511, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("window.close();");
        // Done Row end
        //spacer Row begin
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetHeight("150");
      }
      // spacer Row end
      catch (Exception e)
      {
        log.Error(e, "SendDocPopUpView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(1513, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb = new XPStringBuilder(200);
      // OpenMailTo popup function
      sb.Append("function OpenMailTo(body)");
      sb.Append("{\n");
      sb.Append("  window.open(\"mailto:?body=\" + body);");
      sb.Append("}\n");
      myScript.AddInnerHTMLString(sb.ToString());
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Section with the read-only Model and the Activity Space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IDirModelRO) model;
      m_asOwner = parent;
    }
  }
}