using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.community
{
  /// <author>MichaelD</author>
  public class CommunityEditorPagesDP : EditorDP
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CommunityEditorPages";
    
    /// <summary>
    /// Input Hidden: Comm Temp Selected
    /// </summary>
    public const String STR_HIDDEN_COMM_TEMP_SELECTED = "in_hi_CommTempSelected";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(273, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1074, "ptmsgs_portalbrowsingmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException </throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_PAGE_LIST).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(m_asOwner.GetView(DisableSiteMapView.STR_MVC_CLASS_NAME).Display());
      HTMLInput inputCommTempSelected = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE,
       "");
      inputCommTempSelected.SetName(STR_HIDDEN_COMM_TEMP_SELECTED);
      if (0 < ((CommunityTemplateSelectorModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).GetNumObjects())
      {
        inputCommTempSelected.SetValue(CommonHTMLStrings.ONE);
      } else
      {
        inputCommTempSelected.SetValue(CommonHTMLStrings.ZERO);
      }
      views.AddInnerHTMLElement(inputCommTempSelected);
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from PlumtreeDP need
    /// to implement.  The method should add whatever HTML the child class wants to
    /// use the DisplayJavaScript and add it to the head.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#DisplayJavaScriptFromChild()"></seealso>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection result = base.DisplayJavaScriptFromChild();
      result.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR).DisplayJavascript());
      result.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_PAGE_LIST).DisplayJavascript());
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append("function ").Append(CommunityEditorAS.JS_COMM_TEMP_SELECTED).Append("()\n");
      sb.Append("{\n");
      sb.Append("  if (document." + AFormDP.HTMLFORM_NAME + "." + STR_HIDDEN_COMM_TEMP_SELECTED + ".value == \'0\') { \n");
      sb.Append("\t\talert(\"" + m_asOwner.GetString(1900, ResourceConstants.PORTALBROWSINGMSGS) + "\");\n");
      sb.Append("      return false;\n");
      sb.Append("  }\n");
      sb.Append("  return true;\n");
      sb.Append("}\n");
      myScript.AddInnerHTMLString(sb.ToString());
      result.AddInnerHTMLElement(myScript);
      return result;
    }
  }
}