using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.page;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.expandablelist.template;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree.template;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.browsing.editors.community
{
  /// <author>michaeld</author>
  public class PageListModel : ExpListModel,IPageListModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.community.PageListModel");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageList";
    
    /// <summary>
    /// Page Growable Array Max Columns 
    /// </summary>
    public const int EXPLIST_COL_MAX = 2;
    
    /// <summary>
    /// Page Growable Array Page Model Column 
    /// </summary>
    public const int EXPLIST_COL_PAGE_MODEL = 1;
    
    /// <summary>
    /// Page Growable Array Page Name Column 
    /// </summary>
    public const int EXPLIST_COL_PAGE_NAME = 2;
    public const int EXPLIST_COL_PAGE_FROMCOMMTEMP = 3;
    
    /// <summary>
    /// Key name used by the Activity Space to store the new page tree. 
    /// </summary>
    public const String SUBSPACE_NAME_NEWPAGETREE = "NewPageSubspace";
    
    /// <summary>
    /// Key name used by the Activity Space to store the edit page pop up. 
    /// </summary>
    public const String SUBSPACE_NAME_EDITPAGE = "EditPageSubspace";
    private const int INITIAL_UNIQUE_ID = 0;
    
    /// <summary>
    /// Default initial size for the sorted array.
    /// </summary>
    public const int EXPLIST_DEFAULT_INITIAL_SIZE = 25;
    
    /// <summary>
    /// Column widths for the various columns.
    /// </summary>
    public const String NAME_COLUMN_WIDTH = "80%";
    public const String TEMPLATE_COLUMN_WIDTH = "120";
    public const String ORDERING_COLUMN_WIDTH = "20";
    
    /// <summary>
    /// Pages to Remove 
    /// </summary>
    internal XPArrayList m_xpPagesToRemove;
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    protected IPTSession m_Session;
    
    /// <summary>
    /// Space IDs 
    /// </summary>
    private XPHashtable m_htFormData;
    
    /// <summary>
    /// Next available unique id. Used for pages to give them a
    /// unique edit page space id.
    /// </summary>
    private int m_nNextAvailableUniqueID;
    
    /// <summary>
    /// Page Count 
    /// </summary>
    protected int m_nPageCount;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(XPHashtable)"></seealso>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageListModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)"></seealso>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
      // JF- We get back the list of index of rows to delete.
      if (_htFormData.ContainsKey(sDataKey))
      {
        int[] aRowsToDelete = GetArrayOfObjToDelete(_htFormData);
        // JF- We can only delete rows if the array is not empty
        if (m_saData.GetCount() > 0)
        {
          PageData myPageModel;
          Object oPageID;
          for (int i = 0;i < aRowsToDelete.Length;i++)
          {
            myPageModel = (PageData) m_saData.GetItem(aRowsToDelete[i], PageListModel.EXPLIST_COL_PAGE_MODEL);
            oPageID = myPageModel.m_nPageID;
            if ((0 != myPageModel.m_nPageID) && !m_xpPagesToRemove.Contains(oPageID))
            {
              m_xpPagesToRemove.Add(oPageID);
            }
          }
          m_saData.RemoveRows(aRowsToDelete);
        }
        m_nPageCount--;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.community.IPageListModelRO#GetInputValue(String)"></seealso>
    public virtual String GetInputValue(String name)
    {
      String value = (String) m_htFormData.GetElement(name);
      if (value == null)
      {
        return "";
      }
      return value;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Get next available unique id.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetNextAvailableUniqueID()
    {
      return m_nNextAvailableUniqueID++;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.community.IPageListModelRO#GetPageCount()"></seealso>
    public virtual int GetPageCount()
    {
      // TODO-MJD :is this ever different from the lenght of m_saData?
      return m_nPageCount;
    }
    
    /// <summary>
    /// Returns the pages to remove as an XPArrayList of Integers.
    /// </summary>
    /// <returns>XPArrayList</returns>
    public virtual XPArrayList GetPagesToRemove()
    {
      return m_xpPagesToRemove;
    }
    
    /// <summary>
    /// Method InitializePageList.
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_Session"></param>
    /// <param name="_nListKey"></param>
    public virtual void InitializePageList(IPTSession _Session, int _nListKey)
    {
      ResetUniqueID();
      m_Session = _Session;
      Object[][] arrExpListColInfo = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      // Name Column
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_PAGE_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(305,
       ResourceConstants.PORTALBROWSINGMSGS);
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = NAME_COLUMN_WIDTH;
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      // From Community Template Column
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_PAGE_FROMCOMMTEMP;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(1857,
       ResourceConstants.PORTALBROWSINGMSGS);
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = TEMPLATE_COLUMN_WIDTH;
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      // Ordering Column
      arrExpListColInfo[2][EXPLIST_COLUMN_ID] = EXPLIST_COL_PAGE_MODEL;
      arrExpListColInfo[2][EXPLIST_COLUMN_TITLE] = "";
      arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH] = ORDERING_COLUMN_WIDTH;
      arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeExpandableList(m_asOwner.GetString(306, ResourceConstants.PORTALBROWSINGMSGS),
       arrExpListColInfo, PTImageType.ICON_DOCUMENT, m_asOwner.GetString(314,
       ResourceConstants.PORTALBROWSINGMSGS), _nListKey);
      // Setup hash map with names and values of form inputs
      // Currently this can only be used by the pages list view, 
      // but it could easily be extended for use by other views.
      m_htFormData = new XPHashtable();
      m_htFormData.PutElement(TemplateListView.HTMLINPUT_TEMPLATETREEASID,
       "");
      m_htFormData.PutElement(PageListView.HTMLINPUT_NEWPAGETREEASID, "");
      m_htFormData.PutElement(PageListView.HTMLINPUT_HI_EDITPAGE, "");
      m_xpPagesToRemove = new XPArrayList();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(PTGrowableSortedArrayWrapper)"></seealso>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_PAGE_MODEL};
      // JF- Sort array
      // The growable array will always be sorted by the String column (the one displayed).
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null bellow)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Repost when edit page submitted.
    /// </summary>
    public virtual void DoTaskOnComeBackFromSubEditor()
    {
      int nEditPageIndex = XPConvert.ToInteger((String) m_htFormData.GetElement(PageListView.HTMLINPUT_HI_EDITPAGE));
      String strSubspaceName = SUBSPACE_NAME_EDITPAGE + XPConvert.ToString(((PageData) this.GetItems().GetItem(nEditPageIndex,
       PageListModel.EXPLIST_COL_PAGE_MODEL)).m_nUniqueID);
      if (m_asOwner.GetSubSpaceExists(strSubspaceName))
      {
        PageEditorAS asEditPage = (PageEditorAS) m_asOwner.GetSubSpace(strSubspaceName);
        PageEditorModel myEditPage = (PageEditorModel) asEditPage.GetModel(PageEditorModel.STR_MVC_CLASS_NAME);
        PageData myPageModel = (PageData) GetItems().GetItem(nEditPageIndex,
         PageListModel.EXPLIST_COL_PAGE_MODEL);
        myPageModel.m_strPageName = myEditPage.GetObjectName();
      }
    }
    
    /// <summary>
    /// Repost when new page is added.
    /// </summary>
    public virtual void RepostNewPage()
    {
      if (m_asOwner.GetSubSpaceExists(SUBSPACE_NAME_NEWPAGETREE))
      {
        TemplateTreeAS asTree = (TemplateTreeAS) m_asOwner.GetSubSpace(SUBSPACE_NAME_NEWPAGETREE);
        ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
        XPArrayList mySelected = myTree.GetSelectedItems();
        // Get page template id
        int nPageTemplateID = ((TreeLeafNode) mySelected.GetElement(0)).m_nObjectID;
        IInheritTemplateModelRO inheritModel = (IInheritTemplateModelRO) asTree.GetModel(TemplateTreeAS.PLUGIN_INHERIT_TEMPLATE);
        bool bInheritPageTemplate = inheritModel.IsTemplateInherited();
        AddPageToCommunity(nPageTemplateID, bInheritPageTemplate);
      }
    }
    
    /// <summary>
    /// enables the add button
    /// </summary>
    public virtual void EnableAddButton()
    {
      m_bAddButtonDisabled = false;
    }
    
    /// <summary>
    /// modifies the Add Label shown on the Add button.
    /// </summary>
    public virtual void SetAddLabel(String _label)
    {
      m_sAddLabel = _label;
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nReturn = base.SaveSection(_htFormData);
      String strKey;
      String[] data;
      IXPEnumerator xpKeys = m_htFormData.GetKeys();
      XPHashtable tempFormData = new XPHashtable();
      // Put values of inputs on main page into the form data object.
      // These inputs include the space ids for selecting a community
      // template, adding a new page, and one for each edit page. Also
      // the current edit page index is kept in here.
      while (xpKeys.MoveNext())
      {
        strKey = (String) xpKeys.GetCurrent();
        if (_htFormData.ContainsKey(strKey))
        {
          data = (String[]) _htFormData.GetElement(strKey);
          if ((null != data) && (0 != data.Length))
          {
            tempFormData.PutElement(strKey, data[0]);
          }
        }
      }
      // Put value from _htFormData in m_htFormData 
      // Now copy it back to the core page model 
      IXPEnumerator xpKeys2 = tempFormData.GetKeys();
      String data2;
      while (xpKeys2.MoveNext())
      {
        strKey = (String) xpKeys2.GetCurrent();
        if (_htFormData.ContainsKey(strKey))
        {
          data2 = (String) tempFormData.GetElement(strKey);
          if ((null != data2) && (0 != data2.Length))
          {
            m_htFormData.PutElement(strKey, data2);
          }
        }
      }
      // Put value from _htFormData in m_htFormData 
      return nReturn;
    }
    
    /// <summary>
    /// Add the array passed in argument to the list.
    /// The array should be created using the EXPLIST_COL
    /// constants defined in this class.
    /// </summary>
    /// <param name="_arrRows">Array of rows to add.</param>
    public virtual void SetDefaultObjects(Object[][] _arrRows)
    {
      m_nPageCount = 0;
      int nUniqueID;
      for (int i = 0;i < _arrRows.Length;i++)
      {
        nUniqueID = GetNextAvailableUniqueID();
        ((PageData) _arrRows[i][EXPLIST_COL_PAGE_MODEL]).m_nUniqueID = nUniqueID;
        // Add a space id for this page's edit page space to form data hash map
        m_htFormData.PutElement((PageListView.HTMLINPUT_EDITPAGEASID + XPConvert.ToString(nUniqueID)),
         "");
        m_nPageCount++;
      }
      // fix for #51045: add all rows in one a 
      base.GetItems().AddRows(_arrRows);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(PTGrowableSortedArrayWrapper,int,XPHashtable)"></seealso>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Method AddPageToCommunity.
    /// Adds a single page to the community using page template id.
    /// </summary>
    /// <param name="nPageTemplateID"></param>
    /// <param name="bInheritPageTemplate"></param>
    private void AddPageToCommunity(int nPageTemplateID, bool bInheritPageTemplate)
    {
      IPTPage ptPage = (IPTPage) m_Session.GetPages().Create(((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorAS.STR_MVC_CLASS_NAME)).GetCommunityFolderID());
      ptPage.SetPageTemplateID(nPageTemplateID);
      ptPage.SetInheritPageTemplate(bInheritPageTemplate);
      ptPage.SetDefaultsFromPageTemplate(nPageTemplateID);
      ptPage.SetNotDeletable(false);
      // Store page
      ptPage.Store();
      ptPage.UnlockObject();
      PageData newPageModel = new PageData(ptPage.GetObjectID(), ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorAS.STR_MVC_CLASS_NAME)).GetCommunityID(),
       ptPage.GetPageTemplateID(), ptPage.GetNotDeletable(), ptPage.GetPageType(),
       ptPage.GetLocalizedName());
      newPageModel.m_nUniqueID = GetNextAvailableUniqueID();
      // Add a space id for this page's edit page space to form data hash map
      m_htFormData.PutElement((PageListView.HTMLINPUT_EDITPAGEASID + XPConvert.ToString(newPageModel.m_nUniqueID)),
       "");
      Object[] arrRow = new Object[PageListModel.EXPLIST_COL_MAX];
      arrRow[PageListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nPageCount;
      arrRow[PageListModel.EXPLIST_COL_PAGE_MODEL] = newPageModel;
      this.GetItems().AddRow(arrRow);
      m_nPageCount++;
    }
    
    /// <summary>
    /// Method InitializePages.
    /// Initializes the community pages using a query result.
    /// Only called when on start editor when editing a community,
    /// or when the community template is selected for the first time
    /// when creating a community.
    /// </summary>
    /// <param name="asqr"></param>
    protected virtual Object[][] InitializePages(IASQueryResult asqr)
    {
      if (null == asqr)
      {
        m_nPageCount = 0;
      } else
      {
        m_nPageCount = asqr.GetCount();
      }
      Object[][] arrReturn = new Object[m_nPageCount][];
      PageData myPageModel;
      int nPageType;
      int nPageTemplateID;
      bool bFromCommTemp;
      String strPageName;
      if (0 < m_nPageCount)
      {
        SetAddLabel(m_asOwner.GetString(313, "ptmsgs_portalbrowsingmsgs"));
        for (int i = 0;i < m_nPageCount;i++)
        {
          // Get information about page to put in page model object
          nPageType = XPConvert.ToInteger(asqr.GetFields(i, PT_PROPIDS.PT_PROPID_PAGES_TYPE));
          nPageTemplateID = XPConvert.ToInteger(asqr.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
          bFromCommTemp = true;
          strPageName = (String) asqr.GetFields(i, PT_PROPIDS.PT_PROPID_PAGETEMPLATE_DEFAULTPAGENAME);
          // Create a page model object for this page
          myPageModel = new PageData(nPageTemplateID, bFromCommTemp, nPageType,
           strPageName);
          myPageModel.m_nUniqueID = ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetNextAvailableUniqueID();
          arrReturn[i] = new Object[PageListModel.EXPLIST_COL_MAX];
          arrReturn[i][PageListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = i;
          arrReturn[i][PageListModel.EXPLIST_COL_PAGE_MODEL] = myPageModel;
          // Add a space id for this page's edit page space to form data hash map
          m_htFormData.PutElement((PageListView.HTMLINPUT_EDITPAGEASID + XPConvert.ToString(myPageModel.m_nUniqueID)),
           "");
        }
      }
      return arrReturn;
    }
    
    /// <summary>
    /// Set next available unique id to initial unique id.
    /// </summary>
    private void ResetUniqueID()
    {
      m_nNextAvailableUniqueID = INITIAL_UNIQUE_ID;
    }
  }
}