using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal.editpage;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.portaluiinfrastructure.tree.template;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.opener;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.community
{
  /// <summary>
  /// Section for a list of pages, with action bar.
  /// </summary>
  /// <author>michaeld</author>
  public class PageListView : ExpListView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.community.PageListView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageListView";
    
    /// <summary>
    /// Form Input: Checbox for Pages 
    /// </summary>
    public const String HTMLINPUT_CB_PAGE = "in_cb_Page";
    
    /// <summary>
    /// New Page Tree Space ID 
    /// </summary>
    public const String HTMLINPUT_NEWPAGETREEASID = "in_hi_NewPageTreeSpaceID";
    
    /// <summary>
    /// Edit Page Space ID 
    /// </summary>
    public const String HTMLINPUT_EDITPAGEASID = "in_hi_EditPageSpaceID";
    
    /// <summary>
    /// Form Input: Hidden Edit Page 
    /// </summary>
    public const String HTMLINPUT_HI_EDITPAGE = "in_hi_PageIndex";
    
    /// <summary>
    /// Form Input: Hidden Page Count 
    /// </summary>
    public const String HTMLINPUT_HI_PAGECOUNT = "in_hi_pageCount";
    
    /// <summary>
    /// Query String: Page Unique ID 
    /// </summary>
    public const String PAGE_UNIQUE_ID = "PageUniqueID";
    
    /// <summary>
    /// Javascript function names - do not need to localize *
    /// </summary>
    private const String JAVASCRIPT_ADD_NEWPAGE = "addNewPage";
    private const String JAVASCRIPT_EDIT_PAGE = "editPage";
    private const String JAVASCRIPT_ONRETURN_ADD_NEWPAGE = "onReturnAddNewPage";
    public const String JAVASCRIPT_CHECK_HOME_PAGE = "checkHomePage";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageListView();
    }
    
    /// <summary>
    /// Display the javascript functions that are needed in this view.
    /// </summary>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      ASURL myNewTree;
      XPStringBuilder sb;
      HTMLScript script = base.DisplayJavascript();
      // SE: Bug 56636 - Fix for Vodafone. Backout changes to limit community page creation.
      // PT_SERVERCONSTANTS.PT_MAX_COMMUNITY_PAGES has been deprecated as of CL 183567 and
      // there is no longer a limit to how many pages that can be created. 
      /* &&
       (PT_SERVERCONSTANTS.PT_MAX_COMMUNITY_PAGES > ((IPageListModelRO) m_model).GetPageCount())) */
       
      if (!((IExpListModelRO) m_model).IsAddButtonDisabled())
      {
        // Create URL for adding a new page
        myNewTree = new ASURL(m_asOwner);
        myNewTree.SetLinkCreateNewSpace(TemplateTreeAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        myNewTree.SetSubSpaceKey(PageListModel.SUBSPACE_NAME_NEWPAGETREE);
        myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        myNewTree.AddControlArgument(StartTreeControl.ROOT_ID, PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
        myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
        myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE, TreeConstants.N_LEAFSELECT);
        myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, TreeConstants.N_SERVERSUBMIT);
        myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
        myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
         HTMLINPUT_NEWPAGETREEASID);
        myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
         JAVASCRIPT_ONRETURN_ADD_NEWPAGE);
        myNewTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(315,
         "ptmsgs_portalbrowsingmsgs"));
        myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(316,
         "ptmsgs_portalbrowsingmsgs"));
        myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
         PT_CLASSIDS.PT_PAGETEMPLATE_ID);
        try
        {
          // New Page function
          sb = new XPStringBuilder(200);
          sb.Append("function ").Append(JAVASCRIPT_ADD_NEWPAGE).Append("(myInput)\n").Append("{\n").Append("\t\tvar myInputArg = \'\';\n").Append("\t\tif ( \'\' != myInput.value ) {\n").Append("\t\t\tmyInputArg = \'&").Append(ASConstants.SPACEID).Append("=\' + myInput.value;\n").Append("\t\t}\n").Append("\t\twindow.open(\'").Append(myNewTree.GetURLAsString()).Append("\' + myInputArg").Append(", \'NewPage\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n").Append("}\n");
          script.AddInnerHTMLString(sb.ToString());
          // On return from Tree function
          sb = new XPStringBuilder(200);
          sb.Append("function ").Append(JAVASCRIPT_ONRETURN_ADD_NEWPAGE).Append("()\n").Append("{\n").Append("\tpostToSelf(\'").Append(PageListControl.POSTTOSELF_ACTION_NEW_PAGE).Append("\');\n").Append("}\n");
          script.AddInnerHTMLString(sb.ToString());
        }
        catch (HTMLException he)
        {
          log.Error(he, "PageListView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
          }
      }
      // The url to open a previously opened server edit page
      // This needs to have the SpaceID added to it.
      ASURL myOldEditPage = CreateUrlToEditPrevPage();
      myOldEditPage.SetControl(RefreshEditPageControl.STR_MVC_CLASS_NAME);
      myOldEditPage.IsSubSpace();
      // The URL to edit a page
      ASURL myNewEditPage = CreateUrlToEditPage();
      try
      {
        // Edit Page function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JAVASCRIPT_EDIT_PAGE).Append("(pageIndex, editSpaceID, myInput, pageID)\n").Append("{\n").Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_HI_EDITPAGE).Append(".value = pageIndex;\n").Append("  if (myInput.value == \'\') {\n").Append("    window.open(\'").Append(myNewEditPage.GetURLAsString()).Append("&").Append(IPTOpenerConstants.STR_QS_OBJECTID).Append("=\' + pageID + \'&").Append(ASConstants.SUBSPACE).Append("=").Append(PageListModel.SUBSPACE_NAME_EDITPAGE).Append("\' + editSpaceID + \'&").Append(PAGE_UNIQUE_ID).Append("=\' + editSpaceID + \'&").Append(EditMyPortalPageModel.HTMLINPUT_PARENT_FORM_SPACE_ID).Append("=").Append(HTMLINPUT_EDITPAGEASID).Append("\' + editSpaceID + \'").Append("&").Append(HTMLINPUT_HI_EDITPAGE).Append("=\' + pageIndex").Append(", \'EditPage\', \'location=no,menubar=no,height=600,width=700,resizable=yes,scrollbars=yes\');\n").Append("  } else {\n").Append("    window.open(\'").Append(myOldEditPage.GetURLAsString()).Append("&").Append(ASConstants.SUBSPACE).Append("=").Append(PageListModel.SUBSPACE_NAME_EDITPAGE).Append("\' + editSpaceID + \'").Append("&").Append(PAGE_UNIQUE_ID).Append("=\' + editSpaceID + \'").Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(" + \'&").Append(HTMLINPUT_HI_EDITPAGE).Append("=\' + pageIndex").Append(", \'EditPage\', \'location=no,menubar=no,height=600,width=700,resizable=yes,scrollbars=yes\');\n").Append("  }\n").Append("}\n\n");
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "PageListView::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return script;
    }
    
    /// <summary>
    /// Creates URL to edit a page.  NOTE: Seperated this from the displayJS()
    /// method so that we can subclass this class and have it open to an AS
    /// that subclasses EditMyPortalPageAS.
    /// </summary>
    protected virtual ASURL CreateUrlToEditPage()
    {
      // The URL to edit a page
      ASURL myNewEditPage = new ASURL(m_asOwner);
      myNewEditPage.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      myNewEditPage.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
      myNewEditPage.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID,
       PT_CLASSIDS.PT_PAGE_ID);
      return myNewEditPage;
    }
    
    /// <summary>
    /// Creates URL to edit a previously opened page.  NOTE: Seperated this from
    /// the displayJS() method so that we can subclass this class and have it
    /// open to an AS that subclasses EditMyPortalPageAS.
    /// </summary>
    protected virtual ASURL CreateUrlToEditPrevPage()
    {
      // The url to open a previously opened server edit page
      // This needs to have the SpaceID added to it.
      ASURL myOldEditPage = new ASURL(m_asOwner);
      myOldEditPage.SetLinkCreateNewSpace(BaseOpenerAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      return myOldEditPage;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(IPTGrowableSortedArrayWrapperRO,int)"></seealso>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      result.AddInnerHTMLElement(GetHTMLForFromCommunityTemplateColumn(_saData,
       _nRowIndex));
      if (1 < ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
      {
        result.AddInnerHTMLElement(GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Gets the HTML for the add new page action, for the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    protected override HTMLTableCell GetHTMLForAddAction()
    {
      HTMLTableCell myCell = new HTMLTableCell();
      HTMLInput myInput;
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // SE: Bug 56636 - Fix for Vodafone. Backout changes to limit community page creation.
      // PT_SERVERCONSTANTS.PT_MAX_COMMUNITY_PAGES has been deprecated as of CL 183567 and
      // there is no longer a limit to how many pages that can be created.
      //		if (PT_SERVERCONSTANTS.PT_MAX_COMMUNITY_PAGES > ((IPageListModelRO) m_model).GetPageCount())
      //		{
      // ***New Page*** begins here
      myCell.AddInnerHTMLString(SPACE);
      // Add icon
      /*PTImageType.NEW_PAGE*/
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
       true, this.m_asOwner);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLAnchor myAnchor = ConstructStaticHelpers.GetJavascriptAnchor("",
       JAVASCRIPT_ADD_NEWPAGE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_NEWPAGETREEASID + ")");
      myAnchor.AddInnerHTMLElement(myImage);
      // now get the icon for a document, which is being used for pages throughout the portal
      /*PTImageType.NEW_PAGE*/
      myConstruct = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
       true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myAnchor.AddInnerHTMLElement(myImage);
      HTMLSpan mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      mySpan.AddInnerHTMLString(SPACE);
      // Add label
      if (0 == ((IPageListModelRO) m_model).GetPageCount())
      {
        mySpan.AddInnerHTMLString(m_asOwner.GetString(314, ResourceConstants.PORTALBROWSINGMSGS));
        } else
      {
        mySpan.AddInnerHTMLString(m_asOwner.GetString(313, ResourceConstants.PORTALBROWSINGMSGS));
        }
      mySpan.AddInnerHTMLString(SPACE);
      mySpan.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(SPACE);
      // Hidden input for space of new page selection tree control
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_NEWPAGETREEASID,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((IPageListModelRO) m_model).GetInputValue(HTMLINPUT_NEWPAGETREEASID));
      //		}
      /*
       else
       {
       myCell = new HTMLTableCell();
       myCell.SetHeight("25");
       myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
       myCell.SetNoWrap(true);
       }
       */
       
      return myCell;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(com.plumtree.xpshared.htmlelements.HTMLTableRow)"></seealso>
    protected override void AddHTMLToActionBar(HTMLTableRow _row)
    {
      base.AddHTMLToActionBar(_row);
      HTMLTableCell myCell = new HTMLTableCell();
      _row.AddInnerHTMLElement(myCell);
      // Hidden input for page count.
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_HI_PAGECOUNT,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(XPConvert.ToString(((IPageListModelRO) m_model).GetPageCount()));
      // Hidden input for page being currently edited.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_HI_EDITPAGE,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((IPageListModelRO) m_model).GetInputValue(HTMLINPUT_HI_EDITPAGE));
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForCheckBox(int)"></seealso>
    protected override HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
    {
      IPTGrowableSortedArrayWrapperRO saData = ((IExpListModelRO) m_model).GetReadOnlyItems();
      // Page cannot be deleted. It is from the community template.
      if (((PageData) saData.GetItem(_nRowIndex, PageListModel.EXPLIST_COL_PAGE_MODEL)).m_bFromCommTemp)
      {
        HTMLTableCell myCell = new HTMLTableCell();
        myCell.SetWidth("20");
        myCell.SetHeight("30");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLString(SPACE);
        return (myCell);
      }
      return base.GetHTMLForCheckBox(_nRowIndex);
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      HTMLInput myInput;
      int pageUniqueID = ((PageData) _saData.GetItem(_nRowIndex, PageListModel.EXPLIST_COL_PAGE_MODEL)).m_nUniqueID;
      String strEditPageASID = HTMLINPUT_EDITPAGEASID + pageUniqueID;
      // Object Name
      String strPageName = ((PageData) _saData.GetItem(_nRowIndex, PageListModel.EXPLIST_COL_PAGE_MODEL)).m_strPageName;
      myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(JAVASCRIPT_EDIT_PAGE + "(" + XPConvert.ToString(_nRowIndex) + ", " + XPConvert.ToString(pageUniqueID) + ", document." + AFormDP.HTMLFORM_NAME + "." + strEditPageASID + ", " + ((PageData) _saData.GetItem(_nRowIndex,
       PageListModel.EXPLIST_COL_PAGE_MODEL)).m_nPageID + ")");
      myCell = new HTMLTableCell();
      myCell.SetWidth(PageListModel.NAME_COLUMN_WIDTH);
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      // row icon
      myAnchor.AddInnerHTMLElement(GetIcon(PTImageType.ICON_DOCUMENT));
      // tiny space between document and name of page
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetWidth(CommonHTMLStrings.FIVE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myAnchor.AddInnerHTMLElement(myImage);
      myAnchor.AddInnerHTMLEncodedString(strPageName);
      if (0 == _nRowIndex)
      {
        // this is the home page
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE + "(" + m_asOwner.GetString(320,
         ResourceConstants.PORTALBROWSINGMSGS) + ")");
      }
      // Hidden input for space of edit page.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, strEditPageASID, "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((IPageListModelRO) m_model).GetInputValue(strEditPageASID));
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForFromCommunityTemplateColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      // Object Name
      bool bPageFromCommunityTemplate = ((PageData) _saData.GetItem(_nRowIndex,
       PageListModel.EXPLIST_COL_PAGE_MODEL)).m_bFromCommTemp;
      // Other cells are set to nowrap (which is broken), but we want this cell to wrap
      // in certain cases, so we don't set it to nowrap.
      myCell = new HTMLTableCell();
      myCell.SetWidth(PageListModel.TEMPLATE_COLUMN_WIDTH);
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.AddInnerHTMLString(SPACE);
      if (bPageFromCommunityTemplate)
      {
        myCell.AddInnerHTMLString(m_asOwner.GetString(1858, ResourceConstants.PORTALBROWSINGMSGS));
        } else
      {
        myCell.AddInnerHTMLString(m_asOwner.GetString(1859, ResourceConstants.PORTALBROWSINGMSGS));
        }
      myCell.AddInnerHTMLString(SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      return (myImage);
    }
  }
}