using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.portletpreview;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.community
{
  /// <summary>
  /// View of portlet preferences used for both community and my pages
  /// </summary>
  /// <author>MichaelD</author>
  public class PortletPreferencesView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.community.PortletPreferencesView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PortletPreference";
    public const String HTMLINPUT_PROP_NAME = "in_tx_Name";
    public const String HTMLINPUT_PROP_DESCRIPTION = "in_ta_Description";
    public const String HTMLBUTTON_REPOST = "in_bu_repost";
    public const String HTMLINPUT_SELECTION_PORTLET = "in_cb_Portlet";
    public const String HTMLHIDDEN_SORTINGPAGEINDEX = "in_hi_sortingpageindex";
    public const String HTMLHIDDEN_FLIPGADGETID = "in_hi_flipgadgetid";
    public const String HTMLHIDDEN_FLIPCURRENTTITLEBARSTATE = "in_hi_flipcurrenttitlebarstate";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletPreferencesView();
    }
    
    /// <summary>
    /// Main display page
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>XPException </throws>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myParentTable;
      HTMLTableRow myParentRow;
      HTMLTableCell myParentCell;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: DisplayGadgetPrefencesView");
        result.AddInnerHTMLElement(myComment);
        myParentTable = new HTMLTable();
        result.AddInnerHTMLElement(myParentTable);
        //Specifying the mainTable attributes
        myParentTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myParentTable.SetBorder(CommonHTMLStrings.ZERO);
        myParentTable.SetCellSpacing("15");
        myParentTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myParentTable.SetSummary(m_asOwner.GetString(1613, "ptmsgs_portalbrowsingmsgs"));
        myParentRow = new HTMLTableRow();
        myParentTable.AddInnerHTMLElement(myParentRow);
        myParentCell = new HTMLTableCell();
        myParentRow.AddInnerHTMLElement(myParentCell);
        // three hidden input variables -- one for SortBy function, two for FlipTitleBar function
        HTMLInput inputPageToSort = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_SORTINGPAGEINDEX,
         "");
        inputPageToSort.SetValue("-1");
        myParentCell.AddInnerHTMLElement(inputPageToSort);
        HTMLInput inputFlipPortletID = new HTMLInput(HTMLInputTypes.HIDDEN,
         HTMLHIDDEN_FLIPGADGETID, "");
        inputFlipPortletID.SetValue("-1");
        myParentCell.AddInnerHTMLElement(inputFlipPortletID);
        HTMLInput inputFlipCurrentTitleBarState = new HTMLInput(HTMLInputTypes.HIDDEN,
         HTMLHIDDEN_FLIPCURRENTTITLEBARSTATE, "");
        inputFlipCurrentTitleBarState.SetValue("-1");
        myParentCell.AddInnerHTMLElement(inputFlipCurrentTitleBarState);
        int lPageCount = ((IPortletPreferencesModelRO) m_model).GetPageCount();
        int nCommunityID = ((IPortletPreferencesModelRO) m_model).GetCommunityID();
        for (int iCurrentPage = 0;iCurrentPage < lPageCount;iCurrentPage++)
        {
          // if this is not the very first row, add a spacer row
          if (iCurrentPage != 0)
          {
            // spacer row
            HTMLTable mySpacerTable = GetBeforePageNameSpacerTable();
            mySpacerTable.SetSummary(m_asOwner.GetString(1614, "ptmsgs_portalbrowsingmsgs"));
            myParentCell.AddInnerHTMLElement(mySpacerTable);
          }
          int nPageID = ((IPortletPreferencesModelRO) m_model).GetPageID(iCurrentPage);
          // the name of the current page and encode it
          String strEncodedPageName = XPHttpUtility.HtmlEncode(((IPortletPreferencesModelRO) m_model).GetPageName(iCurrentPage));
          // this returns an XPArrayList containig info about the gadgets with prefs
          PTSortedArrayWrapper arrPortlets = ((IPortletPreferencesModelRO) m_model).GetPortletPreferencesList(iCurrentPage);
          // Page name row
          myTable = GetPageNameTable(strEncodedPageName);
          myTable.SetSummary(strEncodedPageName);
          myParentCell.AddInnerHTMLElement(myTable);
          // spacer row
          myTable = GetAfterPageNameSpacerTable();
          myTable.SetSummary(m_asOwner.GetString(1614, "ptmsgs_portalbrowsingmsgs"));
          myParentCell.AddInnerHTMLElement(myTable);
          // "portlet name" and "display titlebar" table; has a header row then all the portlets
          myTable = new HTMLTable();
          myParentCell.AddInnerHTMLElement(myTable);
          myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          myTable.SetCellSpacing("2");
          myTable.SetCellPadding(CommonHTMLStrings.ZERO);
          myTable.SetSummary(strEncodedPageName);
          myRow = GetPortletNameDisplayTitleBarRow(iCurrentPage, nCommunityID,
           arrPortlets);
          myTable.AddInnerHTMLElement(myRow);
          bool bDisplayPersonalPrefColumn = DisplayPersonalPrefsColumn();
          bool bDisplayCommunityPrefColumn = DisplayCommunityPrefColumn(nCommunityID);
          bool bDisplayAdminPrefColumn = DisplayAdminPrefColumn(arrPortlets);
          for (int iCurrentPortlet = 0;iCurrentPortlet < arrPortlets.GetCount();
          iCurrentPortlet++)
          {
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            if ((0 == iCurrentPortlet) || (((iCurrentPortlet + 1) / 2) == (iCurrentPortlet / 2)))
            {
              // it's even
              myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
            } else
            {
              // it's odd
              myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
            }
            int nPortletID = XPConvert.ToInteger(arrPortlets.GetItem(iCurrentPortlet,
             PT_PROPIDS.PT_PROPID_OBJECTID));
            int nTitleBarState = XPConvert.ToInteger(arrPortlets.GetItem(iCurrentPortlet,
             PT_PROPIDS.PT_PROPID_GADGET_FLAGS));
            int nPortletType = XPConvert.ToInteger(arrPortlets.GetItem(iCurrentPortlet,
             PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE));
            //int nPortletSize	 = XPConvert.ToInteger(arrPortlets.GetItem(iCurrentPortlet,
            //		PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT));
            // JD- this value can be NULL if the portlet has no web service.
            Object oHasPortletPrefs = arrPortlets.GetItem(iCurrentPortlet,
             PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION);
            int nGadgetPersonalizationBitMask = 0;
            nGadgetPersonalizationBitMask = XPConvert.ToInteger(oHasPortletPrefs);
            String strPortletName = (String) arrPortlets.GetItem(iCurrentPortlet,
             PT_PROPIDS.PT_PROPID_NAME);
            // Get HTML for portlet name
            myCell = GetHTMLForPortletName(strPortletName, nPortletID, nPortletType);
            myRow.AddInnerHTMLElement(myCell);
            myCell = GetHTMLForCheckBox(nPortletID, nTitleBarState);
            if (null != myCell)
            {
              myRow.AddInnerHTMLElement(myCell);
            }
            bool bHasUserPref = (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER & nGadgetPersonalizationBitMask) > 0 && !((IPortletPreferencesModelRO) m_model).IsCommunityEditor();
            bool bHasCommunityPref = nCommunityID > 0 && (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER & nGadgetPersonalizationBitMask) > 0 && TaskAPIUICommunity.CheckUserAccessLevelToCommunity(m_asOwner,
             PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT, nCommunityID);
            bool bHasAdminPref = (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR & nGadgetPersonalizationBitMask) > 0 && UserHasAdminAccessToPortlet(nPortletID);
            int ptPrefsType;
            HTMLTableCell prefCell = null;
            if (bDisplayPersonalPrefColumn)
            {
              ptPrefsType = PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER;
              prefCell = GetHTMLForPortletPref(nPortletID, nPageID, nCommunityID,
               ptPrefsType, bHasUserPref, strPortletName);
              myRow.AddInnerHTMLElement(prefCell);
            }
            if (bDisplayCommunityPrefColumn)
            {
              ptPrefsType = PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER;
              prefCell = GetHTMLForPortletPref(nPortletID, nPageID, nCommunityID,
               ptPrefsType, bHasCommunityPref, strPortletName);
              myRow.AddInnerHTMLElement(prefCell);
            }
            if (bDisplayAdminPrefColumn)
            {
              ptPrefsType = PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR;
              prefCell = GetHTMLForPortletPref(nPortletID, nPageID, nCommunityID,
               ptPrefsType, bHasAdminPref, strPortletName);
              myRow.AddInnerHTMLElement(prefCell);
            }
          }
          if (0 == arrPortlets.GetCount())
          {
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
            myCell.SetHeight("20");
            myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
            if (((IPortletPreferencesModelRO) m_model).DisplayTitleBarColumn())
            {
              myCell.SetColSpan("2");
            }
            myCell.AddInnerHTMLString(m_asOwner.GetString(291, "ptmsgs_portalbrowsingmsgs"));
            }
        }
        myComment = new HTMLComment("End: DisplayGadgetPrefencesView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        log.Error(e, "PortletPreferencesView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(279, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns Java Script for goToPage function.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        HTMLScript myScript = null;
        myScript = new HTMLScript("text/javaScript");
        try
        {
          XPStringBuilder sb;
          sb = new XPStringBuilder(300);
          // JavaScript to sort by column	
          sb.Append("function SortBy" + "(varCurrentPageIndex)\n");
          sb.Append("{\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + HTMLHIDDEN_SORTINGPAGEINDEX + ".value= varCurrentPageIndex;\n");
          sb.Append("  postToSelf(" + CommunityEditorRepostControl.POSTTOSELF_ACTION_CHANGEGADGETPREFSSORT + ");\n");
          sb.Append("}\n");
          myScript.AddInnerHTMLString(sb.ToString());
          sb = new XPStringBuilder(300);
          // JavaScript to sort by column	
          sb.Append("function FlipTitleBar" + "(varGadgetID, varCurrentTitleBarState)\n");
          sb.Append("{\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + HTMLHIDDEN_FLIPGADGETID + ".value= varGadgetID;\n");
          sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + HTMLHIDDEN_FLIPCURRENTTITLEBARSTATE + ".value= varCurrentTitleBarState;\n");
          sb.Append("  postToSelf(" + CommunityEditorRepostControl.POSTTOSELF_ACTION_FLIPTITLEBAR + ");\n");
          sb.Append("}\n");
          myScript.AddInnerHTMLString(sb.ToString());
          myScript.AddInnerHTMLString("function OpenPortletPrefsWindow(strURL) { window.open(strURL,\'PortletPrefsWindow\'," + "\'width=700,height=500,resizable=1,status=0,toolbar=0,menubar=0,scrollbars=1,location=0\');   }");
          }
        catch (Exception e)
        {
          log.Error(e, "ExpListView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
          throw new XPException(m_asOwner.GetString(293, "ptmsgs_portalbrowsingmsgs"),
           e);
        }
        return myScript;
      }
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the checkbox for a gadget
    /// </summary>
    /// <param name="nPortletID"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell GetHTMLForCheckBox(int nPortletID, int nPortletTitleBarState)
    {
      if (((IPortletPreferencesModelRO) m_model).DisplayTitleBarColumn() && (-1 != nPortletTitleBarState))
      {
        HTMLTableCell myCell;
        HTMLInput myInput;
        myCell = new HTMLTableCell();
        myCell.SetWidth("100");
        myCell.SetHeight("20");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetNoWrap(true);
        if (nPortletTitleBarState != CommunityEditorModel.COMMUNITYEDITOR_GADGETTITLEBARS_SERVERFALSE)
        {
          // checkbox
          myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLINPUT_SELECTION_PORTLET,
           XPResourceManager.FormatMessage(m_asOwner.GetString(292, "ptmsgs_portalbrowsingmsgs"),
           nPortletID));
          myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
          myInput.SetValue(XPConvert.ToString(nPortletID));
          if (nPortletTitleBarState == CommunityEditorModel.COMMUNITYEDITOR_GADGETTITLEBARS_PREFFALSE)
          {
            myInput.SetChecked(false);
          } else
          {
            myInput.SetChecked(true);
          }
          // mj: removed 'JavaScript:' from function name
          String strOnClickJavascript = "FlipTitleBar(" + nPortletID + ", " + nPortletTitleBarState + ")";
          myInput.SetOnClick(strOnClickJavascript);
          myCell.AddInnerHTMLElement(myInput);
        }
        return (myCell);
      }
      return null;
    }
    
    /// <summary>
    /// Returns the HTML for the cell containing the portlet name
    /// </summary>
    /// <param name="strPortletName"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell GetHTMLForPortletName(String strPortletName,
     int nPortletID, int nPortletType)
    {
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_PORTLET,
       true, this.m_asOwner);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetWidth("20");
      myImage.SetHeight("20");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myImage.SetAlt(m_asOwner.GetString(289, "ptmsgs_portalbrowsingmsgs"));
      myCell.AddInnerHTMLElement(myImage);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      String strEncodedPortletName = XPHttpUtility.HtmlEncode(strPortletName);
      HTMLAnchor anchor;
      if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle() && nPortletType != PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY)
      {
        ASURL previewURL = new ASURL(m_asOwner);
        previewURL.SetLinkGetSpaceIfCached(PreviewPortletAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        previewURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
        previewURL.AddControlArgument(PreviewPortletControl.m_strPortletParam,
         nPortletID);
        previewURL.AddControlArgument(PreviewPortletControl.m_PreviewType,
         PreviewPortletModel.PREVIEWHEADER);
        anchor = ConstructStaticHelpers.GetJavascriptAnchor(strEncodedPortletName,
         "OpenWideGadgetPreviewWindow(\'" + previewURL.GetURLAsString() + "\')");
        anchor.SetTitle(strEncodedPortletName);
        myCell.AddInnerHTMLElement(anchor);
      } else
      {
        myCell.AddInnerHTMLString(strEncodedPortletName);
      }
      return (myCell);
    }
    
    /// <summary>
    /// Returns the HTML for the cell containing the portlet preference url
    /// </summary>
    /// <param name="">int nPortletID, int nPageID, int nCommunityID, int nHasPortletPrefs</param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell GetHTMLForPortletPref(int nPortletID,
     int nPageID, int nCommunityID, int ptPrefsType, bool bHasAccess, String strPortletName)
    {
      HTMLTableCell myCell;
      myCell = new HTMLTableCell();
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Display grayed out image if we aren't displaying a prefs link.
      if (!bHasAccess)
      {
        PTConstruct ptDisabledImg = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT_DISABLED,
         true, this.m_asOwner);
        HTMLImg disImg = (HTMLImg) ptDisabledImg.GetHTMLElement();
        disImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        disImg.SetBorder(CommonHTMLStrings.ZERO);
        //disImg.SetAlt(m_asOwner.GetString(1652, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(disImg);
        return myCell;
      }
      bool bUsePopup = (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD);
      String prefsURL = null;
      String strAlt = "";
      if (ptPrefsType == PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER)
      {
        if (0 == nCommunityID)
        {
          prefsURL = GatewayHelpers.ConstructPortletPrefsLink(m_asOwner, nPortletID,
           nPageID, bUsePopup);
        } else
        {
          // link to the community-user-gadget prefs page, because this is a user clicking on edit preferences
          // from within a community
          prefsURL = GatewayHelpers.ConstructPortletUserCommunityPrefsLink(m_asOwner,
           nPortletID, nCommunityID, bUsePopup);
        }
        strAlt = XPResourceManager.FormatMessage(m_asOwner.GetString(1902,
         "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strPortletName));
        } else
      if (ptPrefsType == PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER)
      {
        prefsURL = GatewayHelpers.ConstructCommunityPrefsLink(m_asOwner, nPortletID,
         nCommunityID, nPageID, bUsePopup);
        strAlt = XPResourceManager.FormatMessage(m_asOwner.GetString(1904,
         "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strPortletName));
        } else
      if (ptPrefsType == PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR)
      {
        // Create an URL to the editor
        prefsURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_GADGET_ID,
         nPortletID, IPTOpenerConstants.OPENER_MODE_EDIT, m_asOwner);
        strAlt = XPResourceManager.FormatMessage(m_asOwner.GetString(1905,
         "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strPortletName));
        }
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT,
       true, this.m_asOwner);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myImage.SetAlt(strAlt);
      HTMLAnchor anchor;
      if (bUsePopup && ptPrefsType != PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR)
      {
        anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
        anchor.AddInnerHTMLElement(myImage);
        anchor.SetOnClick("OpenPortletPrefsWindow(\'" + prefsURL + "\'); return false;");
        } else
      {
        anchor = new HTMLAnchor(prefsURL);
        anchor.AddInnerHTMLElement(myImage);
      }
      myCell.AddInnerHTMLElement(anchor);
      return myCell;
    }
    
    /// <returns></returns>
    /// <throws>Exception </throws>
    protected virtual HTMLTable GetAfterPageNameSpacerTable()
    {
      HTMLTableCell innerCell;
      HTMLTableRow innerRow;
      HTMLTable myTable;
      PTConstruct myConstruct;
      HTMLImg myImage;
      myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      innerRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(innerRow);
      innerCell = new HTMLTableCell();
      innerRow.AddInnerHTMLElement(innerCell);
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetWidth("1");
      myImage.SetHeight("5");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myImage.SetAlt("");
      innerCell.AddInnerHTMLElement(myImage);
      return myTable;
    }
    
    /// <summary>
    /// Localized String: Unable to display the JavaScript for PortletPreferencesView (DisplayJavascript). 
    /// </summary>
    protected virtual HTMLTable GetBeforePageNameSpacerTable()
    {
      HTMLTableCell innerCell;
      HTMLTableRow innerRow;
      HTMLTable myTable;
      PTConstruct myConstruct;
      HTMLImg myImage;
      myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      innerRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(innerRow);
      innerCell = new HTMLTableCell();
      innerRow.AddInnerHTMLElement(innerCell);
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetWidth("1");
      myImage.SetHeight("5");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myImage.SetAlt("");
      innerCell.AddInnerHTMLElement(myImage);
      return myTable;
    }
    
    /// <param name="strEncodedPageName">Page Name must be html encoded before being passed to this method.</param>
    /// <returns>html table for the page name</returns>
    /// <throws>Exception </throws>
    protected virtual HTMLTable GetPageNameTable(String strEncodedPageName)
    {
      HTMLTableRow innerRow;
      HTMLTableCell innerCell;
      HTMLTable myTable;
      HTMLSpan mySpan;
      myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      innerRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(innerRow);
      innerRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
      innerCell = new HTMLTableCell();
      innerRow.AddInnerHTMLElement(innerCell);
      innerCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      innerCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      innerCell.SetHeight("20");
      innerCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan = new HTMLSpan();
      innerCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
      mySpan.AddInnerHTMLString(strEncodedPageName);
      return myTable;
    }
    
    /// <param name="iCurrentPage"></param>
    /// <param name="arrPortlets"></param>
    /// <returns></returns>
    /// <throws>Exception </throws>
    protected virtual HTMLTableRow GetPortletNameDisplayTitleBarRow(int iCurrentPage,
     int nCommunityID, PTSortedArrayWrapper arrPortlets)
    {
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      // "portlet name", "display titlebar" and "Edit" row
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      String strPortletName = m_asOwner.GetString(285, "ptmsgs_portalbrowsingmsgs");
      // if 508 mode, just add the string "Portlet Name".  If not in 508 mode,
      // then "Portlet Name" will be clickable, and will sort the portlets in ascending
      // or descending order.
      if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
      {
        myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(strPortletName,
         "SortBy(" + iCurrentPage + ")");
        myCell.AddInnerHTMLElement(myAnchor);
        int[][] arrSort = arrPortlets.GetSort();
        if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == arrSort[0][1])
        {
          myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
           true, this.m_asOwner);
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          myImage.SetAlt(m_asOwner.GetString(288, "ptmsgs_portalbrowsingmsgs"));
          myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
          myAnchor.AddInnerHTMLElement(myImage);
        } else
        {
          myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
           true, this.m_asOwner);
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          myImage.SetAlt(m_asOwner.GetString(287, "ptmsgs_portalbrowsingmsgs"));
          myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
          myAnchor.AddInnerHTMLElement(myImage);
        }
      } else
      {
        myCell.AddInnerHTMLString(strPortletName);
      }
      if (((IPortletPreferencesModelRO) m_model).DisplayTitleBarColumn())
      {
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("100");
        myCell.SetHeight("20");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(286, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      // DCA - "User prefs"
      if (DisplayPersonalPrefsColumn())
      {
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("60");
        myCell.SetHeight("20");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1831, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      // if in community, show community portlet prefs column
      if (DisplayCommunityPrefColumn(nCommunityID))
      {
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("60");
        myCell.SetHeight("20");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1832, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      if (DisplayAdminPrefColumn(arrPortlets))
      {
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("60");
        myCell.SetHeight("20");
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1833, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      return myRow;
    }
    protected virtual bool UserHasAdminAccessToPortlet(int nPortletID)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      return ptSession.GetSessionInfo().CheckGadgetAccess(nPortletID) >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
      }
    protected virtual bool DisplayAdminPrefColumn(PTSortedArrayWrapper arrPortlets)
    {
      if (((IPortletPreferencesModelRO) m_model).IsCommunityEditor() || m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
      {
        return false;
      }
      for (int i = 0;i < arrPortlets.GetCount();i++)
      {
        int nGadgetPrefsBitMask = XPConvert.ToInteger(arrPortlets.GetItem(i,
         PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION));
        if ((nGadgetPrefsBitMask & PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR) > 0)
        {
          return true;
        }
      }
      return false;
    }
    protected virtual bool DisplayCommunityPrefColumn(int nCommunityID)
    {
      if (((IPortletPreferencesModelRO) m_model).IsCommunityEditor())
      {
        return true;
      }
      return nCommunityID > 0;
    }
    protected virtual bool DisplayPersonalPrefsColumn()
    {
      return !(((IPortletPreferencesModelRO) m_model).IsCommunityEditor());
      }
  }
}