using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.browsing.editors.dircommon.doctype
{
  /// <summary>
  /// This Model contains the state of the DocType plug-in section.
  /// </summary>
  /// <author>StephenC</author>
  public class DocTypePlugInModel : EditorHelperModel,IDocTypePlugInModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.dircommon.doctype.DocTypePlugInModel");
    public const String STR_MVC_CLASS_NAME = "DocTypePlugIn";
    public const String DEFAULTDATA = "Default Data";
    private const String m_strTREESUBSPACE = "TreeSubSpace";
    public IPTSession m_ptSession = null;
    protected String m_strDocTypeName = "";
    protected int m_nDocTypeChoice = 0;
    protected int m_nDocTypeID = 0;
    private String m_strDocTypeSubSpaceID = "";
    // END ***************** repost action methods ***************** 
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DocTypePlugInModel();
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetDocTypeName()"></seealso>
    public virtual int GetDocTypeChoice()
    {
      return m_nDocTypeChoice;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetDocTypeNAme()"></seealso>
    public virtual String GetDocTypeName(int nDocTypeID)
    {
      try
      {
        PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(m_ptSession.GetDocumentTypes());
        omqw.QuerySingleObject(nDocTypeID);
        String strDocTypeName = (String) omqw.GetFields(0, PT_PROPIDS.PT_PROPID_NAME);
        return strDocTypeName;
      }
      catch (XPException xpe)
      {
        log.Error(xpe, STR_MVC_CLASS_NAME + "::GetDocTypeName Error while retrieving Name for DocType " + nDocTypeID + ".");
        return "";
      }
    }
    
    /// <seealso cref="com.plumtree.portalpagessample.form.ISampleFormModelRO#GetDocTypeSubSpaceID(String)"></seealso>
    public virtual String GetDocTypeSubSpaceID()
    {
      if (null == m_strDocTypeSubSpaceID)
      {
        return DEFAULTDATA;
      } else
      {
        return m_strDocTypeSubSpaceID;
      }
    }
    
    /// <returns></returns>
    public virtual String GetDocTypeTREESUBSPACE()
    {
      return m_strTREESUBSPACE;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // BEGIN ***************** helper methods ***************** 
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetSelectedDocType()"></seealso>
    public virtual int GetSelectedDocTypeID()
    {
      return m_nDocTypeID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetSelectedDocTypeName()"></seealso>
    public virtual String GetSelectedDocTypeName()
    {
      return m_strDocTypeName;
    }
    
    /// <summary>
    /// This method gets the selected items from the tree.
    /// </summary>
    public virtual void RefreshItemFromTree()
    {
      AActivitySpace asTree = m_asOwner.GetSubSpace(m_strTREESUBSPACE);
      ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
      XPArrayList itemList = treeModel.GetSelectedItems();
      if (itemList.GetSize() != 1)
      {
        log.Error("Tree selected wrong number of items.  Expecting 1, got " + itemList.GetSize());
        }
      TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
      if (item == null)
      {
        log.Error("Tree selected item null");
      } else
      // TODO CR DLH: Shouldn't this do something?  Otherwise we'd get NPEs below,
      // if I hadn't put that in the else.
      {
        m_nDocTypeID = item.m_nObjectID;
        m_strDocTypeName = item.GetName();
      }
    }
    // END ***************** helper methods ***************** 
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      String[] data;
      // DocType
      data = (String[]) _htFormData.GetElement(DocTypePlugInView.HTMLRADIO_DOCTYPE);
      if ((null != data) && !(0 == data.Length))
      {
        m_nDocTypeChoice = XPConvert.ToInteger(data[0]);
      } else
      {
        log.Warn("FolderEditorModel::SaveMainPage DocType Radio was not in Query String.");
        }
      data = (String[]) _htFormData.GetElement(DocTypePlugInView.HTMLHIDDEN_DOCTYPE);
      if ((null != data) && !(0 == data.Length))
      {
        m_strDocTypeSubSpaceID = data[0];
      } else
      {
        log.Warn("FolderEditorModel::SaveMainPage Hidden DocType was not in Query String.");
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
  }
}