using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.property;
using com.plumtree.portalpages.browsing.editors.dircommon;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.server.treeiterator;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
using com.plumtree.uiinfrastructure.pagecontrols.timepicker;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty
{
  /// <summary>
  /// This is the implementation of the Expandable List for editing card properties.
  /// </summary>
  /// <author>stephenc</author>
  public class EditCardPropModel : ExpListPropModel,IEditCardPropModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty.EditCardPropModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditCardProp";
    
    /// <summary>
    /// Number total of columns 
    /// </summary>
    public const int EXPLIST_COL_MAX = 5;
    public const int ROW_STATUS_ADDED_NEW = 3;
    
    /// <summary>
    /// Input for input text box 
    /// </summary>
    public const String HTMLINPUT_ITEM = "in_tx_Item";
    public const int NEW_PROP_DEFAULTVALUE = -1;
    public const int NEW_PROP_PROPID_UNSELECTED = -1;
    
    /// <summary>
    /// Subspace key for pick tree 
    /// </summary>
    public const String SUBSPACE_KEY_PICKTREE = "PickTreeSubSpace";
    
    /// <summary>
    /// XPArrayList: This holds only the original properties that have been deleted.
    /// Newly added properties that are deleted are not added to this list
    /// </summary>
    public XPArrayList m_xpDeletedProperties = null;
    
    /// <summary>
    /// XPSortedDictionary 
    /// </summary>
    public XPSortedDictionary m_xpUnusedProperties = null;
    
    /// <summary>
    /// Card properties 
    /// </summary>
    public XPSortedDictionary m_xpCardProperties = null;
    
    /// <summary>
    /// IPTCardPropertyValues 
    /// </summary>
    protected IPTCardPropertyValues m_ptCardPropertyValues;
    
    /// <summary>
    /// IPTObject 
    /// </summary>
    protected IPTObject m_ptObject;
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    protected IPTSession m_ptSession;
    
    /// <summary>
    /// This is used on add to populate the input  text of the newly added row.
    /// </summary>
    protected Object m_oDefaultValue;
    
    /// <summary>
    /// Icon to display on each row, just before the input text. 
    /// </summary>
    protected PTImageType m_imgRowIcon;
    private int m_nNewAddSelectedPropID = 0;
    protected XPHashtable m_htPickTypes;
    protected XPHashtable m_htPickListValues;
    
    /// <summary>
    /// This flag is used to commit MultiValued property and when we add a value 
    /// </summary>
    protected bool m_bAddMultiValuedPropSortLater = false;
    
    /// <summary>
    /// PTObjectManager that holds all the properties to get metainfo for each property 
    /// </summary>
    private IPTObjectManager m_ptOM;
    
    /// <summary>
    /// Stores temporary cache of MetaInfo for each property with key as property ID 
    /// </summary>
    private XPHashtable m_propertyMetaInfoCache;
    
    /// <summary>
    /// Creates a new EditCardPropModel object.
    /// </summary>
    public EditCardPropModel() : base()
    {
      m_nNewAddSelectedPropID = NEW_PROP_PROPID_UNSELECTED;
    }
    
    /// <param name="_htFormData"></param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      // Before Commiting new row we have to determine if the newly added row is multivalued property
      // and also we are adding a value to this multivalued property in the same request
      int nMultiValuedAddValIndex = -1;
      // Get the hidden input with the row to modify
      String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && (aDataValue.Length > 0))
        {
          if (null != aDataValue[0] && !XPStringUtility.EqualsIgnoreCase(aDataValue[0],
           ""))
          {
            // Row index of Multivalued property for which we will be adding the value
            nMultiValuedAddValIndex = XPConvert.ToInteger(aDataValue[0]);
            for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
            {
              int nStatus = GetRowStatus(nRowIndex);
              if ((ROW_STATUS_ADDED_NEW == nStatus || ROW_STATUS_MODIFIED == nStatus) && CheckRowIsMultiValued(nRowIndex))
              {
                //We turn on below flag so that we will not sort right after commiting current row but 
                //we will sort after adding value to Multivalued Property
                m_bAddMultiValuedPropSortLater = (nMultiValuedAddValIndex == nRowIndex);
                break;
              }
            }
          }
        }
      }
      // First Commit the current New Row (if any) to the Added List
      CommitNewAddRow();
      // Determine if the request is from a MultiValued Property
      // to add a new property value.
      if (nMultiValuedAddValIndex >= 0)
      {
        // Handle adding rows to multivalued Properties		
        Object nPropertyID = m_saData.GetItem(nMultiValuedAddValIndex, EXPLIST_COL_PROPID);
        Object nPropType = m_saData.GetItem(nMultiValuedAddValIndex, EXPLIST_COL_TYPE);
        Object strPropName = m_saData.GetItem(nMultiValuedAddValIndex, EXPLIST_COL_NAME);
        Object[] oNewRow = new Object[EXPLIST_COL_MAX];
        oNewRow[EXPLIST_COL_PROPID] = nPropertyID;
        oNewRow[EXPLIST_COL_VALUE] = null;
        oNewRow[EXPLIST_COL_NAME] = strPropName;
        oNewRow[EXPLIST_COL_STATUS] = ROW_STATUS_ADDED_NEW;
        oNewRow[EXPLIST_COL_TYPE] = nPropType;
        // If this flag is true then sorting is not yet done and we are doing a late sort, so that we preserve same order
        // of the Properties in the list. 
        if (m_bAddMultiValuedPropSortLater)
        {
          m_saData.SortArray();
        }
        base.GetItems().AddRow(oNewRow);
        return;
      }
      // Request is to add actual new row and not new value for multivalued property.
      // Create a New Row
      if (m_xpUnusedProperties.GetSize() > 0)
      {
        Object[] oNewRow = new Object[EXPLIST_COL_MAX];
        // Get type of first unused propID
        int nFirstUnusedPropType;
        IXPEnumerator xpEnum = m_xpUnusedProperties.GetElements();
        if (xpEnum.MoveNext())
        {
          int nFirstUnusedPropID = XPConvert.ToInteger(xpEnum.GetCurrent());
          nFirstUnusedPropType = GetPropertyType(nFirstUnusedPropID);
        } else
        {
          nFirstUnusedPropType = NEW_PROP_DEFAULTVALUE;
        }
        oNewRow[EXPLIST_COL_PROPID] = int.MaxValue;
        oNewRow[EXPLIST_COL_VALUE] = null;
        // FUTURE: (bug 19089): find a better way to list item last when sorting
        oNewRow[EXPLIST_COL_NAME] = "zzzzzzzzzzzzzzzzzzz";
        oNewRow[EXPLIST_COL_STATUS] = ROW_STATUS_ADDED_NEW;
        oNewRow[EXPLIST_COL_TYPE] = nFirstUnusedPropType;
        base.GetItems().AddRow(oNewRow);
        UpdateDateTimeUniqueKeys();
        m_nNewAddSelectedPropID = NEW_PROP_PROPID_UNSELECTED;
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EditCardPropModel();
    }
    
    /// <param name="_htFormData"></param>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      //Determine if the request is to remove one of the
      // values of multivalued properties.
      String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);
      // Handle removing a value of  multivalued Property.
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && (aDataValue.Length > 0))
        {
          if (null != aDataValue[0] && !XPStringUtility.EqualsIgnoreCase(aDataValue[0],
           ""))
          {
            int nRowIndex = XPConvert.ToInteger(aDataValue[0]);
            // Removing one of the values of multivalued property from the list of property values
            m_ptCardPropertyValues.Remove(GetRowPropertyID(nRowIndex), GetRowValue(nRowIndex));
            // Now Removing it from the display list of property values.
            m_saData.RemoveRow(nRowIndex);
            //Updating DateTime keys since the list of displayed values changed.
            UpdateDateTimeUniqueKeys();
            return;
          }
        }
      }
      // This request is to remove normal property and not to remove
      // one of the values of multivalued properties.
      sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
      // JF- We get back the list of index of rows to delete.
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        int[] aRowsToDelete = GetRowsToDelete(aDataValue);
        // Remove rows
        m_saData.RemoveRows(aRowsToDelete);
        UpdateDateTimeUniqueKeys();
      }
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public virtual void DoTaskOnComeBackFromSubEditor()
    {
      String sEditorASName;
      EditorAS myEditorAS;
      ObjEditorModel myObjEditorModel;
      sEditorASName = PropEditorAS.STR_MVC_CLASS_NAME;
      if (m_asOwner.GetSubSpaceExists(sEditorASName))
      {
        myEditorAS = (EditorAS) m_asOwner.GetSubSpace(sEditorASName);
        myObjEditorModel = (ObjEditorModel) myEditorAS.GetModel(myEditorAS.m_strModelName);
        int nPropID = myObjEditorModel.GetObjectID();
        int nPropType = GetPropertyType(nPropID);
        String strPropName = ((IPTProperty) m_ptSession.GetProperties().Open(nPropID,
         false)).GetLocalizedName();
        m_xpUnusedProperties.PutElement(strPropName, nPropID);
        // Commit the current New Row (if any) to the Added List
        CommitNewAddRow();
        Object[] oNewRow = new Object[EXPLIST_COL_MAX];
        oNewRow[EXPLIST_COL_PROPID] = nPropID;
        oNewRow[EXPLIST_COL_VALUE] = null;
        // FUTURE: (bug 19089): find a better way to list item last when sorting
        oNewRow[EXPLIST_COL_NAME] = "zzzzzzzzzzzzzzzzzzz";
        oNewRow[EXPLIST_COL_STATUS] = ROW_STATUS_ADDED_NEW;
        oNewRow[EXPLIST_COL_TYPE] = nPropType;
        base.GetItems().AddRow(oNewRow);
        UpdateDateTimeUniqueKeys();
        m_nNewAddSelectedPropID = nPropID;
        m_asOwner.DeleteSubSpace(sEditorASName);
      }
    }
    
    /// <summary>
    /// Action for modifying a row. Override the default behavior of this method
    /// so that pick tree or reference tree can modify the row.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#ModifyRow(XPHashtable)"></seealso>
    public override void ModifyRow(XPHashtable _htFormData)
    {
      // Get the hidden input with the row to modify
      String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValue) && (aDataValue.Length > 0))
        {
          int nRowIndex = XPConvert.ToInteger(aDataValue[0]);
          int nPropertyType = GetRowType(nRowIndex);
          ATreeAS asTree;
          if (m_asOwner.GetSubSpaceExists(GetUniqueString(SUBSPACE_KEY_PICKTREE)))
          {
            asTree = (ATreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_KEY_PICKTREE));
            ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
            XPArrayList mySelectedItems = myTree.GetSelectedItems();
            Object oPickValue = null;
            if (0 < mySelectedItems.GetSize())
            {
              // Get the first selected itme
              String strPickValue = ((TreeLeafNode) mySelectedItems.GetElement(0)).GetName();
              // Convert string value to object
              try
              {
                oPickValue = GetPropValueFromString(strPickValue, nPropertyType);
                }
              catch (Exception e)
              {
                String strErrorMsg = GetRowErrorMessage(nRowIndex, m_asOwner.GetString(99,
                 "ptmsgs_portalinfrastructure"));
                UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
                 strErrorMsg, strErrorMsg);
                UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
                 m_asOwner.GetApplication());
                return;
              }
            }
            UpdateRowInList(nRowIndex, oPickValue);
          }
        }
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetNewlySelectedPropertyID()
    {
      return m_nNewAddSelectedPropID;
    }
    
    /// <returns></returns>
    public virtual int GetNumProperties()
    {
      return m_saData.GetCount();
    }
    
    /// <summary>
    /// Returns the icon to display on each row before the  input text. If the
    /// value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    public virtual PTImageType GetRowIcon()
    {
      return m_imgRowIcon;
    }
    
    /// <summary>
    /// If a property has a pick tree or pick list, check that the pick values
    /// can be successfully retrieved.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>True if pick values can be successfully retrieved.</returns>
    public virtual bool CheckPickValuesAreValid(int _nRowIndex)
    {
      try
      {
        int nPropertyID = GetRowPropertyID(_nRowIndex);
        // Open the property
        IPTObjectManager ptOM = m_ptSession.GetProperties();
        bool bLockInitially = false;
        IPTProperty ptProperty = (IPTProperty) ptOM.Open(nPropertyID, bLockInitially);
        if (null != ptProperty)
        {
          // Get pick list
          IPTPickListEditor ptPickList = (IPTPickListEditor) ptProperty.GetPickList();
          IPTTreeIterator ptTreeIterator = (IPTTreeIterator) ptPickList.GetInterfaces("IPTTreeIterator");
          ObjPropModel.ValidateTree(ptTreeIterator, 0);
          return true;
        } else
        {
          return false;
        }
      }
      catch (PTException e)
      {
        return false;
      }
    }
    
    /// <summary>
    /// Return cached pick list values for the property.
    /// </summary>
    /// <param name="_nPropertyID">Property ID</param>
    /// <returns>Pick list values</returns>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.IObjPropModelRO#GetPickListValues(int)"></seealso>
    public virtual Object[][] GetPickListValues(int _nPropertyID)
    {
      if (m_htPickListValues.ContainsKey(_nPropertyID))
      {
        return (Object[][]) m_htPickListValues.GetElement(_nPropertyID);
      }
      return null;
    }
    
    /// <summary>
    /// Return the pick type for the property.
    /// </summary>
    /// <param name="__nRowIndex">Row index</param>
    /// <returns>Pick type</returns>
    public virtual int GetPickType(int _nRowIndex)
    {
      int nPropertyID = GetRowPropertyID(_nRowIndex);
      if (nPropertyID == int.MaxValue)
      {
        return PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE;
      }
      int nPickType = PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE;
      // If pick type is cached, then return cached value.
      if (m_htPickTypes.ContainsKey(nPropertyID))
      {
        return XPConvert.ToInteger(m_htPickTypes.GetElement(nPropertyID));
        }
      // If not then open the property to get pick type, and cache value after we get it.
      try
      {
        // Open the property
        IPTObjectManager ptOM = m_ptSession.GetProperties();
        bool bLockInitially = false;
        IPTProperty ptProperty = (IPTProperty) ptOM.Open(nPropertyID, bLockInitially);
        if (null != ptProperty)
        {
          // Get the pick type
          nPickType = ptProperty.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE);
          // Cache pick type
          m_htPickTypes.PutElement(nPropertyID, nPickType);
          // If we have a pick list then cache the pick list values.
          switch (nPickType){
          case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST:
          case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
          {
            // Get pick list
            IPTPickListEditor ptPickList = (IPTPickListEditor) ptProperty.GetPickList();
            if (null != ptPickList)
            {
              // Get tree iterator from pick list
              IPTTreeIterator ptTreeIterator = (IPTTreeIterator) ptPickList.GetInterfaces("IPTTreeIterator");
              Object[][] aPickListValues = (Object[][]) ptTreeIterator.Children(0,
               -1);
              if (aPickListValues != null)
              {
                m_htPickListValues.PutElement(nPropertyID, aPickListValues);
                }
            }
            break;
          }
          }
        }
      }
      catch (PTException e)
      {
      }
      return nPickType;
    }
    
    /// <summary>
    /// Returns string representation of property value
    /// </summary>
    /// <param name="oValue">Property value as Object</param>
    /// <param name="nPropertyType">Property type</param>
    /// <returns>Property value as string</returns>
    public virtual String GetStringFromObjectValue(Object oValue, int nPropertyType)
    {
      String strValue;
      if (null == oValue)
      {
        strValue = "";
      } else
      {
        switch (nPropertyType){
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
        {
          // Format date value using XPDateFormat
          XPDateTime dtValue = (XPDateTime) oValue;
          XPDateFormat myDateTimeFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM,
           XPDateFormat.SHORT, XPLocale.GetDefault(), XPTimeZone.GetCurrentTimeZone());
          strValue = myDateTimeFormat.Format(dtValue);
          break;
        }
        case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:
        strValue = (String) oValue;
        break;
        case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
        case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
        default:
        strValue = XPConvert.ToString(oValue);
        break;
        }
      }
      return strValue;
    }
    
    /// <returns></returns>
    public override XPSortedDictionary GetUnusedProperties()
    {
      return m_xpUnusedProperties;
    }
    
    /// <param name="_ptSession"></param>
    /// <param name="_ptObject"></param>
    /// <param name="_sSectionTitle"></param>
    /// <param name="_imgAddIcon"></param>
    /// <param name="_sAddLabel"></param>
    /// <param name="_nListKey"></param>
    /// <returns></returns>
    public virtual bool InitializeCardProperties(IPTSession _ptSession, IPTCardPropertyValues ptCardPropValues,
     XPSortedDictionary xpCardProperties, String _sSectionTitle, PTImageType _imgAddIcon,
     String _sAddLabel, int _nListKey)
    {
      m_ptSession = _ptSession;
      m_ptCardPropertyValues = ptCardPropValues;
      m_xpCardProperties = xpCardProperties;
      m_htPickTypes = new XPHashtable();
      m_htPickListValues = new XPHashtable();
      // If object does not support object properties, then return immediately with false value.
      // If object supports GetObjectProperties, then continue with initialization of expandable list.
      InitExpandableList(_sSectionTitle, _imgAddIcon, _sAddLabel, _nListKey);
      // Load the properties only after expandable list is initialized.
      LoadProperties();
      // Create a list of properties that have not been assigned.
      LoadUnusedProperties();
      UpdateDateTimeUniqueKeys();
      return true;
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
    /// mapping and an array of sort. The growable array will always be sorted
    /// by the 1st  column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_COL_PROPID, EXPLIST_COL_VALUE,
       EXPLIST_COL_NAME, EXPLIST_COL_TYPE, EXPLIST_COL_STATUS};
      // JF- Sort array
      // The growable array will always be sorted by the 1st column.
      int[][] arrSort = new int[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_NAME;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_PROPID;
      arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null bellow)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    public override void Finish()
    {
      try
      {
        // Commit Any Newly Added Properties
        CommitNewAddRow();
        if (null != m_ptCardPropertyValues)
        {
          int nRowIndex;
          int nPropID;
          Object oPropValue;
          // Handle Deletes
          int nCount = m_xpDeletedProperties.GetSize();
          for (int i = 0;i < nCount;i++)
          {
            nPropID = XPConvert.ToInteger(m_xpDeletedProperties.GetElement(i));
            m_ptCardPropertyValues.Remove(nPropID);
          }
          // Handle Adds
          XPArrayList xpAddedProperties = GetAddedProperties();
          nCount = xpAddedProperties.GetSize();
          for (int i = 0;i < nCount;i++)
          {
            nRowIndex = XPConvert.ToInteger(xpAddedProperties.GetElement(i));
            nPropID = GetRowPropertyID(nRowIndex);
            oPropValue = GetRowValue(nRowIndex);
            IPTCardPropertyValue ptValue = m_ptCardPropertyValues.Add(nPropID);
            ptValue.SetOverrideValue(oPropValue);
          }
          // Handle Edits
          XPArrayList xpEditedProperties = GetEditedProperties();
          nCount = xpEditedProperties.GetSize();
          for (int i = 0;i < nCount;i++)
          {
            nRowIndex = XPConvert.ToInteger(xpEditedProperties.GetElement(i));
            nPropID = GetRowPropertyID(nRowIndex);
            oPropValue = GetRowValue(nRowIndex);
            IPTCardPropertyValue ptValue = m_ptCardPropertyValues.GetItem(nPropID);
            ptValue.SetOverrideValue(oPropValue);
          }
        }
      }
      catch (Exception e)
      {
        log.Error("EditCardPropModel::Finish " + m_asOwner.GetString(345,
         "ptmsgs_portalbrowsingmsgs") + ". The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(345, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
    }
    
    /// <param name="_ptObjProp"></param>
    /// <returns></returns>
    /// <throws>XPException </throws>
    protected virtual IASQueryResult GetEditCardProperties(IPTObjectProperties _ptObjProp)
    {
      IASQueryResult asqrObjectPropData = null;
      try
      {
        if (null != _ptObjProp)
        {
          IPTQueryResult qrObjectPropData = _ptObjProp.GetPropertyData(PT_PROPIDS.PT_PROPID_ALL);
          asqrObjectPropData = new ASQueryResultWrapper(qrObjectPropData);
          }
      }
      catch (Exception e)
      {
        log.Error("ObjPropModel::GetObjectPropData " + m_asOwner.GetString(344,
         "ptmsgs_portalbrowsingmsgs") + ". The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(344, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return asqrObjectPropData;
    }
    
    /// <param name="_aDataValue"></param>
    /// <returns></returns>
    protected virtual Object[][] GetRowsToAdd(String[] _aDataValue)
    {
      XPArrayList alistRowsToAdd = new XPArrayList();
      int nStatus = ROW_STATUS_ADDED;
      // Retrieve information about rows before adding rows
      for (int i = 0;i < _aDataValue.Length;i++)
      {
        int nRowIndex = XPConvert.ToInteger(_aDataValue[i]);
        // Add row only if it is not read only and is multi-valued
        Object[] oRow = new Object[EXPLIST_COL_MAX];
        oRow[EXPLIST_COL_PROPID] = GetRowPropertyID(nRowIndex);
        oRow[EXPLIST_COL_VALUE] = m_oDefaultValue;
        oRow[EXPLIST_COL_NAME] = GetRowName(nRowIndex);
        oRow[EXPLIST_COL_STATUS] = nStatus;
        oRow[EXPLIST_COL_TYPE] = GetRowType(nRowIndex);
        alistRowsToAdd.Add(oRow);
      }
      Object[][] aRowsToAdd = new Object[alistRowsToAdd.GetSize()][];
      for (int j2c_index = 0;j2c_index < alistRowsToAdd.GetSize();j2c_index++)
      {
        aRowsToAdd[j2c_index] = new Object[EXPLIST_COL_MAX];
      }
      for (int i = 0;i < alistRowsToAdd.GetSize();i++)
      {
        aRowsToAdd[i] = (Object[]) alistRowsToAdd.GetElement(i);
      }
      return aRowsToAdd;
    }
    
    /// <param name="_aDataValue"></param>
    /// <returns></returns>
    protected virtual int[] GetRowsToDelete(String[] _aDataValue)
    {
      XPArrayList alistRowsToDelete = new XPArrayList();
      // Determine which rows we actually want to actually remove from the expandable list.
      for (int i = 0;i < _aDataValue.Length;i++)
      {
        int nRowIndex = XPConvert.ToInteger(_aDataValue[i]);
        int nStatus = GetRowStatus(nRowIndex);
        int nPropID = GetRowPropertyID(nRowIndex);
        // This is for multivalued properties, If user selects to remove
        // a multivalued property then we remove all of the values of multi
        // valued property.
        if (CheckRowIsMultiValued(nRowIndex))
        {
          for (int j = 0;j < m_saData.GetCount();j++)
          {
            if (nPropID == GetRowPropertyID(j))
            {
              alistRowsToDelete.Add(j);
            }
          }
        }
        // Restore this item back to the list of unused properties
        if (nStatus != ROW_STATUS_ADDED_NEW)
        {
          String strPropName = ((IPTProperty) m_ptSession.GetProperties().Open(nPropID,
           false)).GetLocalizedName();
          m_xpUnusedProperties.PutElement(strPropName, nPropID);
        }
        // if this was an original row, then we add it to our list of original properties to delete
        if ((nStatus == ROW_STATUS_MODIFIED) || (nStatus == ROW_STATUS_NO_CHANGE))
        {
          m_xpDeletedProperties.Add(nPropID);
        }
        // The row is always deleted from the list, regardless of whether it is an original or newly added row
        alistRowsToDelete.Add(nRowIndex);
      }
      // Convert array list to int array
      int[] aRowsToDelete = new int[alistRowsToDelete.GetSize()];
      for (int i = 0;i < alistRowsToDelete.GetSize();i++)
      {
        aRowsToDelete[i] = XPConvert.ToInteger(alistRowsToDelete.GetElement(i));
        }
      return aRowsToDelete;
    }
    
    /// <summary>
    /// Override method to save pick list data
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="_htFormData">Form data</param>
    /// <returns>Return key for pick list if row has picklist. Otherwise return regular key.</returns>
    protected override String GetDataKey(int _nRowIndex, XPHashtable _htFormData)
    {
      int nPickType = GetPickType(_nRowIndex);
      if ((PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST == nPickType) || (PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST == nPickType))
      {
        return GetUniqueString(EditCardPropView.HTMLINPUT_SELECT_PICKLIST_PREFIX) + _nRowIndex;
        } else
      {
        return base.GetDataKey(_nRowIndex, _htFormData);
      }
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      String sDataNewRowNameKey = EditCardPropView.HTMLINPUT_SELECT_NEW_PROP;
      // Check if this is a newly added row
      // Dont save newly added rows here.  Just record the propID.  They are saved when an addition row is added and during StoreObjectProperties()
      int nStatus = GetRowStatus(_nRowIndex);
      if (ROW_STATUS_ADDED_NEW == nStatus)
      {
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataNewRowNameKey);
        //int nPropID;
        if ((null != aDataValues) && !(0 == aDataValues.Length))
        {
          m_nNewAddSelectedPropID = XPConvert.ToInteger(aDataValues[0]);
        } else
        // If the new property added is part of multivalued property
        // then we try to get this value from list of properties.
        if (null != m_saData.GetItem(_nRowIndex, EXPLIST_COL_PROPID))
        {
          m_nNewAddSelectedPropID = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex,
           EXPLIST_COL_PROPID));
        } else
        {
          m_nNewAddSelectedPropID = NEW_PROP_DEFAULTVALUE;
        }
        // Save the type, so the Section knows whether to display a Text Box or a Date picker
        int nPropType = GetPropertyType(m_nNewAddSelectedPropID);
        _saData.SetItem(_nRowIndex, EXPLIST_COL_PROPID, m_nNewAddSelectedPropID);
        _saData.SetItem(_nRowIndex, EXPLIST_COL_TYPE, nPropType);
        UpdateDateTimeUniqueKeys();
      }
      // Bug 7816437 Fix for customer "US HOUSE OF REPRESENTATIVES". COLLAB DOES NOT PROPERLY HANDLE NULL CARD PROPERTY DATA 
      // RETURNED BY WS SE
      // Check Card Properties value is not null
      int nPropertyType = GetRowType(_nRowIndex);
      switch (nPropertyType){
      case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
      UIError myError;
      nStatus = RepostControl.PAGE_STATUS_VALID;
      nStatus = m_ptPageMgr.StoreAllUserInput(_htFormData);
      // if the status is invalid, print out error msgs stored in the page manager
      // page mgr holds errors msgs generated from storing all the inputs
      if (nStatus == RepostControl.PAGE_STATUS_INVALID)
      {
        myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         m_ptPageMgr.GetErrorMessages(m_asOwner), m_ptPageMgr.GetErrorMessages(m_asOwner));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      String strUniqueKey = GetUniqueDateTimePickerKey(_nRowIndex);
      XPDateTime myDateTime = GetDateTimeFromDatePicker(strUniqueKey);
      if (myDateTime == null)
      {
        // Generating the current date object in local pattern
        XPDateTime currentDateTime = new XPDateTime();
        XPLocale tempLocale = new XPLocale(m_asOwner.GetLocale());
        XPDateFormat dfLong = XPDateFormat.GetDateInstance(XPDateFormat.LONG,
         tempLocale, XPTimeZone.GetTimeZone(m_asOwner.GetTimeZone()));
        String currDate = dfLong.Format(currentDateTime);
        // Generating the current time object
        XPDateFormat tfLong = XPDateFormat.GetTimeInstance(XPDateFormat.LONG,
         tempLocale, XPTimeZone.GetTimeZone(m_asOwner.GetTimeZone()));
        String currTime = tfLong.Format(currentDateTime);
        JSDateTimePicker dateTimeComponentName = (JSDateTimePicker) m_ptJSDateTimePickerMgr.GetComponent(strUniqueKey);
        // Getting the DateTime component name in the submit form
        String dateComponentName = dateTimeComponentName.GetDateInputName();
        String hoursComponentName = dateTimeComponentName.GetHoursInputName();
        String minComponentName = dateTimeComponentName.GetMinutesInputName();
        String ampmComponentName = dateTimeComponentName.GetAMPMInputName();
        // Setting the current date into the form date input key
        String[] aDateValues = new String[1];
        aDateValues[0] = currDate;
        _htFormData.PutElement(dateComponentName, aDateValues);
        // Creating tempTimePicker object for separate hours, minutes and AMPM from time string
        TimePicker tempTimePicker = new TimePicker();
        tempTimePicker.Init(m_ptJSDateTimePickerMgr.GetPageMgr(), currTime,
         strUniqueKey);
        // Setting the current hours into the form hours input key
        String[] aHoursValues = new String[1];
        aHoursValues[0] = tempTimePicker.GetHours();
        _htFormData.PutElement(hoursComponentName, aHoursValues);
        // Setting the current minutes into the form minutes input key
        String[] aMinValues = new String[1];
        aMinValues[0] = tempTimePicker.GetMinutes();
        _htFormData.PutElement(minComponentName, aMinValues);
        // Setting the current AMPM value into the form AMPM input key
        String[] aAMPMValues = new String[1];
        aAMPMValues[0] = tempTimePicker.GetAMPM();
        _htFormData.PutElement(ampmComponentName, aAMPMValues);
      }
      break;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:
      case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
      case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
      String sDataKey = GetDataKey(_nRowIndex, _htFormData);
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        if (aDataValues.Length > 0)
        {
          String strValue = aDataValues[0];
          if ("".Equals(strValue))
          {
            // Setting a default string for the input form double input key 			
            Object oDataKey = sDataKey;
            aDataValues[0] = m_asOwner.GetString(2022, ResourceConstants.PORTALBROWSINGMSGS);
            _htFormData.PutElement(oDataKey, aDataValues);
          }
        }
      }
      break;
      case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:
      String sPasswordKey = GetPasswordKey(_nRowIndex, _htFormData);
      if (_htFormData.ContainsKey(sPasswordKey))
      {
        String[] aDataValues = (String[]) _htFormData.GetElement(sPasswordKey);
        if (aDataValues.Length > 0)
        {
          String strValue = aDataValues[0];
          if ("".Equals(strValue))
          {
            // Setting a default string for the input form password input key 			
            Object oPasswordKey = sPasswordKey;
            aDataValues[0] = m_asOwner.GetString(2022, ResourceConstants.PORTALBROWSINGMSGS);
            _htFormData.PutElement(oPasswordKey, aDataValues);
          }
        }
      }
      break;
      default:
      break;
      }
      return base.SaveRow(_saData, _nRowIndex, _htFormData);
    }
    
    /// <summary>
    /// Commit Newly Added Row (should only be one)
    /// </summary>
    private void CommitNewAddRow()
    {
      for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
      {
        int nStatus = GetRowStatus(nRowIndex);
        if (ROW_STATUS_ADDED_NEW == nStatus)
        {
          // PropID should already be set
          if (NEW_PROP_PROPID_UNSELECTED == m_nNewAddSelectedPropID)
          {
            log.Error("EditCardPropModel::CommitNewAddRow Unable to determine selected PropID");
            return;
          }
          // Determine Name
          String strName = ((IPTProperty) m_ptSession.GetProperties().Open(m_nNewAddSelectedPropID,
           false)).GetLocalizedName();
          int nAssignedStatus;
          // check if this is multivalued property 
          if (IsExistingProperty(m_nNewAddSelectedPropID) && !CheckRowIsMultiValued(nRowIndex))
          {
            nAssignedStatus = ROW_STATUS_MODIFIED;
          } else
          {
            nAssignedStatus = ROW_STATUS_ADDED;
          }
          //If we are commiting a multivalued property
          if (m_bAddMultiValuedPropSortLater)
          {
            Object[] oNewRow = new Object[EXPLIST_COL_MAX];
            oNewRow[EXPLIST_COL_PROPID] = m_nNewAddSelectedPropID;
            oNewRow[EXPLIST_COL_VALUE] = m_saData.GetItem(nRowIndex, EXPLIST_COL_VALUE);
            oNewRow[EXPLIST_COL_NAME] = strName;
            oNewRow[EXPLIST_COL_STATUS] = nAssignedStatus;
            oNewRow[EXPLIST_COL_TYPE] = m_saData.GetItem(nRowIndex, EXPLIST_COL_TYPE);
            //We have to modify the properties and perserve the pervious order,
            //so that later a value for Multivalued is created at right place and we will sort after 
            //creating that value. This is the reason we remove current row and add new row at same place
            //instead of setting item values which by the way will trigger sort automatically.
            m_saData.RemoveRow(nRowIndex);
            m_saData.AddRowWithoutSort(oNewRow);
          } else
          {
            // Update columns
            m_saData.SetItem(nRowIndex, EXPLIST_COL_PROPID, m_nNewAddSelectedPropID);
            m_saData.SetItem(nRowIndex, EXPLIST_COL_STATUS, nAssignedStatus);
            // If multivalued then we need to add 
            m_saData.SetItem(nRowIndex, EXPLIST_COL_NAME, strName);
          }
          // Remove this item from to the list of unused properties 
          String strPropName = ((IPTProperty) m_ptSession.GetProperties().Open(m_nNewAddSelectedPropID,
           false)).GetLocalizedName();
          m_xpUnusedProperties.RemoveElement(strPropName);
          // Check if this is an original property that was deleted
          //  If so, remove it from that delete list
          if (m_xpDeletedProperties.Contains(m_nNewAddSelectedPropID))
          {
            m_xpDeletedProperties.Remove(m_nNewAddSelectedPropID);
          }
        }
      }
    }
    // Checks whether a given property was an original property of the Card 
    //   (it could have been deleted while in the Editor)
    private bool IsExistingProperty(int nPropertyID)
    {
      IXPEnumerator xpEnum = m_xpCardProperties.GetElements();
      while (xpEnum.MoveNext())
      {
        CardPropertyObject cpo = (CardPropertyObject) xpEnum.GetCurrent();
        int nPropID = cpo.m_nPropID;
        if (nPropertyID == nPropID)
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Returns the array of column titles,  associated column IDs and column
    /// width. This specific implementation checks to see if there is a multi
    /// valued property in the list of properties and adds a new header column
    /// to the list of columns to be shown in UI.
    /// </summary>
    /// <returns>Object[][]</returns>
    public override Object[][] GetArrExpListColInfo()
    {
      for (int k = 0;k < m_saData.GetCount();k++)
      {
        // Check to see if we have a multivalued property
        // in the list of properties
        if (CheckRowIsMultiValued(k))
        //we add an extra row that will allow displaying an empty
        {
          // column header for the Add/remove column of the multivalued
          // property.
          Object[][] arrCardListColInfo = new Object[m_arrExpListColInfo.Length + 1][];
          for (int j2c_index = 0;j2c_index < m_arrExpListColInfo.Length + 1;
          j2c_index++)
          {
            arrCardListColInfo[j2c_index] = new Object[m_arrExpListColInfo[0].Length];
            }
          for (int i = 0;i < m_arrExpListColInfo.Length;i++)
          {
            arrCardListColInfo[i] = m_arrExpListColInfo[i];
          }
          arrCardListColInfo[m_arrExpListColInfo.Length][EXPLIST_COLUMN_ID] = null;
          arrCardListColInfo[m_arrExpListColInfo.Length][EXPLIST_COLUMN_TITLE] = null;
          arrCardListColInfo[m_arrExpListColInfo.Length][EXPLIST_COLUMN_WIDTH] = "10%";
          arrCardListColInfo[m_arrExpListColInfo.Length][EXPLIST_COLUMN_COLSPAN] = "1";
          arrCardListColInfo[m_arrExpListColInfo.Length][EXPLIST_COLUMN_ENABLESORT] = false;
          return arrCardListColInfo;
        }
      }
      return m_arrExpListColInfo;
    }
    
    /// <summary>
    /// Iterate through the list to return the newly added properties
    /// </summary>
    private XPArrayList GetAddedProperties()
    {
      XPArrayList xpAddedProperties = new XPArrayList();
      for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
      {
        int nStatus = GetRowStatus(nRowIndex);
        if (ROW_STATUS_ADDED == nStatus)
        {
          xpAddedProperties.Add(nRowIndex);
        }
      }
      return xpAddedProperties;
    }
    
    /// <summary>
    /// Iterate through the list to return the edited properties
    /// </summary>
    private XPArrayList GetEditedProperties()
    {
      XPArrayList xpEditedProperties = new XPArrayList();
      for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
      {
        int nStatus = GetRowStatus(nRowIndex);
        if (ROW_STATUS_MODIFIED == nStatus)
        {
          xpEditedProperties.Add(nRowIndex);
        }
      }
      return xpEditedProperties;
    }
    
    /// <param name="nPropID"></param>
    /// <returns></returns>
    private int GetPropertyType(int nPropID)
    {
      // Determine Type
      int nPropType;
      IPTQueryResult ptQR = m_ptSession.GetProperties().QuerySingleObject(nPropID);
      if (null != ptQR)
      {
        nPropType = ptQR.ItemAsInt(0, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE);
        } else
      {
        // text
        nPropType = 3;
      }
      return nPropType;
    }
    
    /// <param name="_sSectionTitle"></param>
    /// <param name="_imgAddIcon"></param>
    /// <param name="_sAddLabel"></param>
    /// <param name="_nListKey"></param>
    private void InitExpandableList(String _sSectionTitle, PTImageType _imgAddIcon,
     String _sAddLabel, int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      // The first column will be the property name and will be sortable
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(346,
       "ptmsgs_portalbrowsingmsgs");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "20%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      // The second column will be the property value and will not be sortable
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_VALUE;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(347,
       "ptmsgs_portalbrowsingmsgs");
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "80%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    protected override void LoadProperties()
    {
      int nStatus = EditCardPropModel.ROW_STATUS_NO_CHANGE;
      IXPEnumerator xpEnum;
      CardPropertyObject cpo;
      int nPropID;
      int nPropType;
      String strPropName;
      XPArrayList RowsToAddList = new XPArrayList();
      xpEnum = m_xpCardProperties.GetElements();
      // Here we go through the list of all properties
      // If a property is multivalued then it can have 
      // more than one value so we load all of those values
      // if it is not a multivalued property then we just load
      // one value for that property.
      while (xpEnum.MoveNext())
      {
        cpo = (CardPropertyObject) xpEnum.GetCurrent();
        if (IsPropertyMultiValued(cpo.m_nPropID))
        {
          LoadMultiValuedProperty(cpo);
        } else
        {
          Object[] aRow = new Object[EXPLIST_COL_MAX];
          nPropID = cpo.m_nPropID;
          nPropType = cpo.m_nPropType;
          strPropName = cpo.m_sPropName;
          aRow[EXPLIST_COL_PROPID] = nPropID;
          aRow[EXPLIST_COL_NAME] = strPropName;
          aRow[EXPLIST_COL_STATUS] = nStatus;
          aRow[EXPLIST_COL_TYPE] = nPropType;
          if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == nPropType)
          {
            if (null != cpo.m_dtDateValue)
            {
              aRow[EXPLIST_COL_VALUE] = cpo.m_dtDateValue;
            } else
            {
              aRow[EXPLIST_COL_VALUE] = null;
            }
          } else
          {
            aRow[EXPLIST_COL_VALUE] = cpo.m_sPropValue;
          }
          RowsToAddList.Add(aRow);
        }
      }
      int nSize = RowsToAddList.GetSize();
      Object[][] aRowsToAdd = new Object[nSize][];
      for (int j2c_index = 0;j2c_index < nSize;j2c_index++)
      {
        aRowsToAdd[j2c_index] = new Object[EXPLIST_COL_MAX];
      }
      for (int k = 0;k < nSize;k++)
      {
        aRowsToAdd[k] = (Object[]) RowsToAddList.GetElement(k);
      }
      m_saData.AddRows(aRowsToAdd);
    }
    
    /// <summary>
    /// This method takes care of loading MultiValued Properties,
    /// since Load Properties only loads one property value for each property.
    /// In the case of MuliValued Properties there can be multiple property 
    /// values with same property id. This method takes a multivalued property
    /// as input and loads all of its values.
    /// </summary>
    private void LoadMultiValuedProperty(CardPropertyObject cpo)
    {
      IXPEnumerator propEnum = m_ptCardPropertyValues.GetEnumerator();
      XPArrayList propListWithCurrentID = new XPArrayList();
      while (propEnum.MoveNext())
      {
        IPTCardPropertyValue cpv = (IPTCardPropertyValue) propEnum.GetCurrent();
        // Check if the Prop value is of current prop id.
        if (cpv.GetPropertyID() == cpo.m_nPropID)
        {
          Object[] aRowtoAdd = new Object[EXPLIST_COL_MAX];
          aRowtoAdd[EXPLIST_COL_PROPID] = cpo.m_nPropID;
          aRowtoAdd[EXPLIST_COL_NAME] = cpo.m_sPropName;
          aRowtoAdd[EXPLIST_COL_STATUS] = EditCardPropModel.ROW_STATUS_NO_CHANGE;
          aRowtoAdd[EXPLIST_COL_TYPE] = cpo.m_nPropType;
          if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == cpo.m_nPropType)
          {
            aRowtoAdd[EXPLIST_COL_VALUE] = cpv.GetValueAsXPDateTime();
          } else
          {
            aRowtoAdd[EXPLIST_COL_VALUE] = cpv.GetValueAsString();
          }
          propListWithCurrentID.Add(aRowtoAdd);
        }
      }
      int nSize = propListWithCurrentID.GetSize();
      Object[][] aPropRows = new Object[nSize][];
      for (int j2c_index = 0;j2c_index < nSize;j2c_index++)
      {
        aPropRows[j2c_index] = new Object[EXPLIST_COL_MAX];
      }
      for (int k = 0;k < nSize;k++)
      {
        aPropRows[k] = (Object[]) propListWithCurrentID.GetElement(k);
      }
      m_saData.AddRows(aPropRows);
    }
    private void LoadUnusedProperties()
    {
      // Retrieve the currently assigned property ids
      Object[] arCardPropIDs = (Object[]) m_ptCardPropertyValues.GetPropertyIDs();
      m_xpUnusedProperties = new XPSortedDictionary();
      m_xpDeletedProperties = new XPArrayList();
      Object[][] oFilters = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        oFilters[j2c_index] = new Object[2];
      }
      // only properties with cardprop=1
      oFilters[0][0] = PT_PROPIDS.PT_PROPID_PROP_CARDPROP;
      oFilters[1][0] = PT_FILTEROPS.PT_FILTEROP_EQ;
      oFilters[2][0] = 1;
      // Don't show image uuid
      oFilters[0][1] = PT_PROPIDS.PT_PROPID_OBJECTID;
      oFilters[1][1] = PT_FILTEROPS.PT_FILTEROP_NE;
      oFilters[2][1] = CardPropertyObject.ID_OF_IMAGE_UUID;
      IPTQueryResult ptqrProperties = m_ptSession.GetProperties().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME,
       -1, PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, oFilters);
      // Show all card properties
      for (int i = 0;i < ptqrProperties.RowCount();i++)
      {
        int nPropID = ptqrProperties.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (false == doesPropertyDescribeCard(arCardPropIDs, nPropID))
        {
          String strPropName = ptqrProperties.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
          m_xpUnusedProperties.PutElement(strPropName, nPropID);
        }
      }
    }
    
    /// <param name="arCardPropIDs"></param>
    /// <param name="nPropID"></param>
    /// <returns></returns>
    private bool doesPropertyDescribeCard(Object[] arCardPropIDs, int nPropID)
    {
      for (int i = 0;i < arCardPropIDs.Length;i++)
      {
        if (nPropID == XPConvert.ToInteger(arCardPropIDs[i]))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Returns the value type of the property
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Value type of property</returns>
    public override int GetRowType(int _nRowIndex)
    {
      Object oType = m_saData.GetItem(_nRowIndex, EXPLIST_COL_TYPE);
      if (null != oType)
      {
        return XPConvert.ToInteger(oType);
      } else
      {
        return PT_PROPERTY_TYPES.PT_PROPTYPE_INVALID;
      }
    }
    
    /// <summary>
    /// Returns the status of the row (added, deleted, edited, modified)
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Row status</returns>
    public override int GetRowStatus(int _nRowIndex)
    {
      Object oStatus = m_saData.GetItem(_nRowIndex, EXPLIST_COL_STATUS);
      if (null != oStatus)
      {
        return XPConvert.ToInteger(oStatus);
      } else
      {
        return ROW_STATUS_NO_CHANGE;
      }
    }
    
    /// <summary>
    /// Returns the property ID of the property in the indicated row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Property ID</returns>
    public override int GetRowPropertyID(int _nRowIndex)
    {
      Object oVal = m_saData.GetItem(_nRowIndex, EXPLIST_COL_PROPID);
      if (null != oVal)
      {
        return XPConvert.ToInteger(oVal);
      } else
      {
        return int.MaxValue;
      }
    }
    
    /// <summary>
    /// Returns the value of the requested metadata of the Property.
    /// </summary>
    /// <param name="nPropID">Property ID of the property</param>
    /// <returns>metadata Value of requested property id.</returns>
    private IPTProperty GetPropertyMetaInfo(int nPropID)
    {
      IPTProperty ptProperty = null;
      // If property ID is max value then actual meta info does not exist.
      if (nPropID == int.MaxValue)
      {
        return ptProperty;
      }
      IPTCardPropertyValue cardProp = m_ptCardPropertyValues.GetItem(nPropID);
      if (null != cardProp)
      {
        ptProperty = cardProp.GetMetaDataProperty();
        return ptProperty;
      } else
      {
        // See if it is stored in local cache before getting the property info
        // from the session
        if (null != m_propertyMetaInfoCache)
        {
          if (m_propertyMetaInfoCache.ContainsKey(nPropID))
          {
            return (IPTProperty) m_propertyMetaInfoCache.GetElement(nPropID);
            }
        }
        // Open the property from list of properties since this property
        // is not yet committed to the card.
        if (null == m_ptOM)
        {
          m_ptOM = m_ptSession.GetProperties();
        }
        bool bLockInitially = false;
        ptProperty = (IPTProperty) m_ptOM.Open(nPropID, bLockInitially);
        if (null != ptProperty)
        {
          if (null == m_propertyMetaInfoCache)
          {
            m_propertyMetaInfoCache = new XPHashtable();
          }
          // Adding the property to cache so that we don't need to open session
          // everytime to get property metadata.
          m_propertyMetaInfoCache.PutElement(nPropID, ptProperty);
          return ptProperty;
        }
        // Unable to get Property meta info by any means
        return null;
      }
    }
    
    /// <summary>
    /// Checks to see if the property is multivalued
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if multivalued. Otherwise returns false.</returns>
    /// <seealso cref="com.plumtree.portaluiinfrastructure.editor.dircommon.editdocumentproperty.IEditCardPropModelRO#CheckRowIsMultiValued(int)"></seealso>
    public virtual bool CheckRowIsMultiValued(int _nRowIndex)
    {
      return IsPropertyMultiValued(GetRowPropertyID(_nRowIndex));
    }
    private bool IsPropertyMultiValued(int _nPropID)
    {
      IPTProperty metaProp = GetPropertyMetaInfo(_nPropID);
      if (null != metaProp)
      {
        return (0 != metaProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MULTIVALUED));
        } else
      {
        return false;
      }
    }
    
    /// <summary>
    /// Checks to see if the property is read-only
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if read-only. Otherwise returns false.</returns>
    /// <seealso cref="om.plumtree.portaluiinfrastructure.editor.dircommon.editdocumentproperty.IEditCardPropModelRO#CheckRowIsReadOnly(int)"></seealso>
    public virtual bool CheckRowIsReadOnly(int _nRowIndex)
    {
      IPTProperty metaProp = GetPropertyMetaInfo(GetRowPropertyID(_nRowIndex));
      if (null != metaProp)
      {
        return (0 != metaProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_READONLYVALUE));
        } else
      {
        return false;
      }
    }
    
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    public override bool CheckRowIsMandatory(int _nRowIndex)
    {
      return false;
    }
  }
}