using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty
{
  /// <summary>
  /// This interface is implemented by the Model. It contains all the read-only
  /// mothods of the Model accessed by the Views.
  /// </summary>
  /// <author>stephenc</author>
  public interface IEditCardPropModelRO : IExpListPropModelRO
  {
    
    /// <returns></returns>
    int GetNewlySelectedPropertyID();
    
    /// <returns></returns>
    int GetNumProperties();
    
    /// <returns></returns>
    PTImageType GetRowIcon();
    
    /// <returns></returns>
    XPSortedDictionary GetUnusedProperties();
    
    /// <summary>
    /// If a property has a pick tree or pick list, check that the pick values
    /// can be successfully retrieved.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>True if pick values can be successfully retrieved.</returns>
    bool CheckPickValuesAreValid(int _nRowIndex);
    
    /// <summary>
    /// Returns string representation of property value
    /// </summary>
    /// <param name="oValue">Property value as Object</param>
    /// <param name="nPropertyType">Property type</param>
    /// <returns>Property value as string</returns>
    String GetStringFromObjectValue(Object oValue, int nPropertyType);
    
    /// <summary>
    /// Return pick list values for the property
    /// </summary>
    /// <param name="_nPropertyID">Property ID</param>
    /// <returns>Pick list values</returns>
    Object[][] GetPickListValues(int _nPropertyID);
    
    /// <summary>
    /// Return the pick type for the property.
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Pick type</returns>
    int GetPickType(int nRowIndex);
    
    /// <summary>
    /// Checks to see if the property is multivalued
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if multivalued. Otherwise returns false.</returns>
    bool CheckRowIsMultiValued(int _nRowIndex);
    
    /// <summary>
    /// Checks to see if the property is read-only
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Returns true if read-only. Otherwise returns false.</returns>
    bool CheckRowIsReadOnly(int _nRowIndex);
  }
}