using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty;
using com.plumtree.portalpages.common.documentlanguage;
using com.plumtree.portalpages.common.linksettings;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.editors.document
{
  /// <author>StephenC</author>
  public class CardEditorAS : ObjEditorAS
  {
    public const String STR_MVC_CLASS_NAME = "CardEditor";
    public const String strLinkSettingsPlugInKey = "CardEditorLinkSettingsPlugIn";
    public const String strCardLanguagePlugInKey = "CardEditorCardLanguagePlugIn";
    public const String strEditCardPropertiesPlugInKey = "CardEditorEditCardPropertiesPlugIn";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CardEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (XPResourceManager.FormatMessage(GetString(1705, "ptmsgs_portalbrowsingmsgs"),
       GetObjectName()));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (CardEditorRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = CardEditorModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(CardEditorModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      CardEditorLinkSettingsDP cardLinkDP = new CardEditorLinkSettingsDP();
      cardLinkDP.AddToValidationFunction("CheckNumericLinkValues");
      RegisterPage(cardLinkDP);
      CardEditorMainDP cardMainDP = new CardEditorMainDP();
      cardMainDP.AddToValidationFunction(CardEditorMainView.JAVASCRIPT_CHECKNAME);
      RegisterPage(cardMainDP);
      // Register Views
      RegisterView(CardEditorMainView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(CardEditorDocInfoView.STR_MVC_CLASS_NAME, myModel);
      SetCurrentPage(CardEditorMainDP.STR_MVC_CLASS_NAME);
      // Register Controls
      RegisterControl(CardEditorRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register plug-in sections
      // Link Settings Plug-In
      RegisterModel(LinkSettingsPlugInModel.STR_MVC_CLASS_NAME, strLinkSettingsPlugInKey);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myLinkSettingsPlugInModel = GetModel(strLinkSettingsPlugInKey);
      RegisterView(LinkSettingsPlugInView.STR_MVC_CLASS_NAME, strLinkSettingsPlugInKey,
       myLinkSettingsPlugInModel);
      // Card Language Plug-In
      RegisterModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myCardLanguagePlugInModel = GetModel(strCardLanguagePlugInKey);
      RegisterView(CardLanguagePlugInView.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey,
       myCardLanguagePlugInModel);
      RegisterControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME,
       strCardLanguagePlugInKey, myCardLanguagePlugInModel);
      // Register Plug-In: CardProperties
      RegisterModel(EditCardPropModel.STR_MVC_CLASS_NAME, strEditCardPropertiesPlugInKey);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myEditCardPropertiesPlugInModel = GetModel(strEditCardPropertiesPlugInKey);
      RegisterView(EditCardPropView.STR_MVC_CLASS_NAME, strEditCardPropertiesPlugInKey,
       myEditCardPropertiesPlugInModel);
      RegisterControl(EditCardPropRepostControl.STR_MVC_CLASS_NAME, strEditCardPropertiesPlugInKey,
       myEditCardPropertiesPlugInModel);
      //Sets left nav menu
      // BEGIN Sub menu "Properties"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(190, "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CardEditorMainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CardEditorLinkSettingsDP.STR_MVC_CLASS_NAME);
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1502, "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Properties"
      this.SetHelpTopic("PT_DocumentSettings");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (CardEditorMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Document_MainSettings");
      } else
      if (CardEditorLinkSettingsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_DocumentSettings");
      } else
      if (ObjectSecurityDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Document_Security");
      }
    }
  }
}