using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.editors.dircommon;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.document
{
  /// <author>
  /// StephenC
  /// This Section represents a section of the Card Properties page
  /// of the Card Editor.
  /// This Section is printed out by CardEditorMainDP.
  /// </author>
  public class CardEditorDocInfoView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.document.CardEditorDocInfoView");
    public const String STR_MVC_CLASS_NAME = "CardEditorDocInfo";
    protected AActivitySpace m_asOwner = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CardEditorDocInfoView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      bool bOdd = false;
      try
      {
        HTMLBr br = new HTMLBr();
        HTMLComment myComment = new HTMLComment("Begin: Display CardEditorDocInfoView");
        result.AddInnerHTMLElement(myComment);
        // BEGIN Custom Card Header ROW
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(192,
         "ptmsgs_portalbrowsingmsgs")));
        // END Custom Card Header ROW
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("2");
        myTable.SetCellSpacing("2");
        XPSortedDictionary xpCardInformation = ((ICardEditorModelRO) m_model).GetCardInformation();
        IXPEnumerator xpEnum;
        CardStatisticObject cso;
        String strPropValue;
        String strPropName;
        xpEnum = xpCardInformation.GetElements();
        /////////////////////////
        // Card Information
        // BEGIN Custom Column Headers ROW
        myRow = new HTMLTableRow();
        myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetWidth("25%");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(193, "ptmsgs_portalbrowsingmsgs"));
        myCell = new HTMLTableCell();
        myCell.SetWidth("80%");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(194, "ptmsgs_portalbrowsingmsgs"));
        // END Custom Column Headers ROW
        xpEnum = xpCardInformation.GetElements();
        bOdd = false;
        while (xpEnum.MoveNext())
        {
          cso = (CardStatisticObject) xpEnum.GetCurrent();
          strPropName = cso.m_sPropName;
          strPropValue = cso.m_sPropValue;
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(bOdd ? PTStyleClass.LIST_ITEM_ONE_BG : PTStyleClass.LIST_ITEM_TWO_BG);
          myCell = new HTMLTableCell();
          myCell.SetHeight("25");
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
          mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strPropName));
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
          if (cso.m_bIsMoreLikeThis)
          // special case
          {
            Object[][] oParentFolderPaths = (Object[][]) cso.m_oParentFolderPaths;
            for (int i = 0;i < oParentFolderPaths.Length;i++)
            {
              int nParentFolderID = XPConvert.ToInteger(oParentFolderPaths[i][0]);
              String strParentFolderPath = (String) oParentFolderPaths[i][1];
              ASURL myURL = new ASURL(m_asOwner);
              myURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
              myURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
              myURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID,
               XPConvert.ToString(nParentFolderID));
              myURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, XPConvert.ToString(DirConstants.BROWSE_MODE));
              HTMLAnchor myAnchor = new HTMLAnchor(myURL.GetURLAsString());
              myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strParentFolderPath));
              mySpan.AddInnerHTMLElement(myAnchor);
              mySpan.AddInnerHTMLElement(br);
            }
          } else
          {
            mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strPropValue));
            }
          bOdd = !bOdd;
        }
        // END Card Document Type
        myComment = new HTMLComment("End: Display CardEditorDocInfoView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (HTMLException he)
      //*CRC olegs - Exception is better
      {
        log.Error(he, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + he.Message);
        throw new XPException(m_asOwner.GetString(195, "ptmsgs_portalbrowsingmsgs"),
         he);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      base.Init(model, parent);
      m_asOwner = parent;
    }
  }
}