using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.common.linksettings;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.document
{
  /// <author>
  /// StephenC
  /// This is class is used to print out together the Views for
  /// the Related Resources page of the Property Editor.
  /// </author>
  public class CardEditorLinkSettingsDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "CardEditorLinkSettings";
    
    /// <summary>
    /// Displays some HTML after the body tag and before the form tag.
    /// For example this is used by pages using a DHTML calendar to display the div tag.
    /// The function is optional.  If it exists, it will be called by the framework, and
    /// the resulting HTMLElement will be added in the right place.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElementCollection DisplayHTMLBeforeForm()
    {
      HTMLElementCollection myHTMLBeforeForm = null;
      try
      {
        //Display the DIV tag required for the Date picker control
        ILinkSettingsPlugInModelRO ptROModel = (ILinkSettingsPlugInModelRO) m_asOwner.GetModel(CardEditorAS.strLinkSettingsPlugInKey);
        myHTMLBeforeForm = ptROModel.GetDateTimePickerControlManager().GetPagePreFormContent();
        }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(697, "ptmsgs_portalcommonmsgs"), "");
        myError.SetActivitySpace(m_asOwner.GetName());
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return myHTMLBeforeForm;
    }
    
    /// <summary>
    /// Returns the HTML that is placed in the HEAD section of this HTML page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElementCollection DisplayHTMLinHEAD()
    {
      HTMLElementCollection retVal = new HTMLElementCollection();
      try
      {
        ILinkSettingsPlugInModelRO ptROModel = (ILinkSettingsPlugInModelRO) m_asOwner.GetModel(CardEditorAS.strLinkSettingsPlugInKey);
        JSDateTimePickerMgr ptDatePickerMgr = ptROModel.GetDateTimePickerControlManager();
        retVal.AddInnerHTMLElement(ptDatePickerMgr.GetJSIncludes());
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(697, "ptmsgs_portalcommonmsgs"), "");
        myError.SetActivitySpace(m_asOwner.GetName());
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      //Get access to the PTDate.js file for formatting date strings
      retVal.AddInnerHTMLElement(ConfigHelper.GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSDATEPICKER,
       GetOwner()));
      return retVal;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(196, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the Advanced Settings page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strLinkSettingsPlugInKey).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strLinkSettingsPlugInKey).DisplayJavascript());
      return myScripts;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    /// <throws>XPException </throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      ObjEditorModel asModel = (ObjEditorModel) m_asOwner.GetModel(CardEditorModel.STR_MVC_CLASS_NAME);
      String strCardName = asModel.GetObjectName();
      return HTMLConstructHelpers.GetSubHeader(XPHttpUtility.HtmlEncode(strCardName),
       this.m_asOwner);
    }
  }
}