using System;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.document
{
  /// <author>
  /// StephenC
  /// This is class is used to print out together the Views for
  /// the General Info page of the Property Editor.
  /// </author>
  public class CardEditorMainDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "CardEditorMain";
    
    /// <summary>
    /// Displays some HTML after the body tag and before the form tag. For
    /// example this is used by pages using a DHTML calendar to display the div
    /// tag. The function is optional.  If it exists, it will be called by the
    /// framework, and the resulting HTMLElement will be added in the right
    /// place.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException </throws>
    public override HTMLElementCollection DisplayHTMLBeforeForm()
    {
      IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey);
      return iModelRO.GetDateTimePickerControlManager().GetPagePreFormContent();
      }
    
    /// <summary>
    /// Returns the HTML that is placed in the HEAD section of this HTML page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException </throws>
    public override HTMLElementCollection DisplayHTMLinHEAD()
    {
      IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey);
      return iModelRO.GetDateTimePickerControlManager().GetJSIncludes();
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(198, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CardEditorMainView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strCardLanguagePlugInKey).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strEditCardPropertiesPlugInKey).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CardEditorDocInfoView.STR_MVC_CLASS_NAME)).Display());
      //Add the Object Properties view
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_KEYWORDS)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strEditCardPropertiesPlugInKey).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(CardEditorMainView.STR_MVC_CLASS_NAME).DisplayJavascript());
      return myScripts;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1453, "ptmsgs_portalbrowsingmsgs"),
       this.m_asOwner);
    }
  }
}