using System;
// Framework Imports
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.editportletprefs
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the Misc Settings page of the Misc Editor.
  /// </summary>
  /// <author>Dusting Ang</author>
  public class EditPortletPrefsDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.editportletprefs.EditPortletPrefsDP");
    public const String STR_MVC_CLASS_NAME = "EditPortletPrefs";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      EditPortletPrefsModel iModel = (EditPortletPrefsModel) m_asOwner.GetModel(EditPortletPrefsModel.STR_MVC_CLASS_NAME);
      if (iModel.GetCommunityID() == 0)
      {
        return (m_asOwner.GetString(380, "ptmsgs_portalbrowsingmsgs"));
      } else
      {
        return (m_asOwner.GetString(379, "ptmsgs_portalbrowsingmsgs"));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for that Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PortletPreferencesView.STR_MVC_CLASS_NAME)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Creates a table with the left nav bar and puts innerElement next to the
    /// left nav bar.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#CreateLeftNavBar()"></seealso>
    /// <param name="_Views"></param>
    /// <returns>HTMLTable</returns>
    public override HTMLTable CreateLeftNavBar(HTMLElement _Views)
    {
      HTMLTable myMainTable;
      HTMLTableRow myMainTableRow;
      HTMLTableCell myMainTableCell;
      EditorLeftNavView myLeftNavView = (EditorLeftNavView) m_asOwner.GetView(EditorLeftNavView.STR_MVC_CLASS_NAME);
      // Start Main table
      myMainTable = new HTMLTable();
      myMainTable.SetBorder("0");
      myMainTable.SetCellPadding("0");
      myMainTable.SetCellSpacing("10");
      myMainTable.SetWidth("100%");
      // Main table 1st Row
      myMainTableRow = new HTMLTableRow();
      myMainTable.AddInnerHTMLElement(myMainTableRow);
      if (!((IEditorModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetHideLeftNav())
      {
        // Row 1 - Cell 1
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetWidth("225");
        myMainTableCell.SetVAlign("top");
        // Display Left Navigation Menu
        myMainTableCell.AddInnerHTMLElement(myLeftNavView.Display());
        myMainTableCell.AddInnerHTMLElement((m_asOwner.GetView(TipsView.STR_MVC_CLASS_NAME).Display()));
        // Display Spacer table
        myMainTableCell.AddInnerHTMLElement(GetSpacerTable());
      }
      // Row 2 - Cell 2
      myMainTableCell = new HTMLTableCell();
      myMainTableRow.AddInnerHTMLElement(myMainTableCell);
      myMainTableCell.SetWidth("100%");
      myMainTableCell.SetVAlign("top");
      //	add the error display view.
      myMainTableCell.AddInnerHTMLElement(m_asOwner.GetView(ErrorView.STR_MVC_CLASS_NAME).Display());
      myMainTableCell.AddInnerHTMLElement(GetContentHeaderTable(((EditorDP) m_asOwner.GetCurrentPage()).GetPageTitle()));
      HTMLElement myHTML = GetHTMLBelowSubHeader();
      if (null != myHTML)
      {
        // JF- Banner with help link and instructions
        myMainTableCell.AddInnerHTMLElement(myHTML);
      }
      // Editor Content table
      //HTMLTable myTable = new HTMLTable();
      myMainTableCell.AddInnerHTMLElement(_Views);
      /*myTable.SetWidth("100%");
       myTable.SetBorder("0");
       myTable.SetCellPadding("0");
       myTable.SetCellSpacing(this.m_sContentTableCellSpacing);
       
       // 1st Row
       HTMLTableRow myRow = new HTMLTableRow();
       myTable.AddInnerHTMLElement(myRow);
       
       HTMLTableCell myCell = new HTMLTableCell();
       myRow.AddInnerHTMLElement(myCell);
       
       // Editor content
       myCell.AddInnerHTMLElement(_Views);*/
       
      return myMainTable;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = null;
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        myScripts = base.DisplayJavaScriptFromChild();
        myScripts.AddInnerHTMLElement(m_asOwner.GetView(PortletPreferencesView.STR_MVC_CLASS_NAME).DisplayJavascript());
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) + "opennewwindow.js");
        myScripts.AddInnerHTMLElement(script);
      }
      return myScripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetContentHeaderTable()"></seealso>
    /// <param name="_sTitle"></param>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetContentHeaderTable(String _sTitle)
    {
      HTMLElementCollection myResult = new HTMLElementCollection();
      PTConstruct myContentHeader;
      try
      {
        myResult.AddInnerHTMLString("\n");
        HTMLComment myComment = new HTMLComment("Begin: Editor Page header with page title");
        myResult.AddInnerHTMLElement(myComment);
        myResult.AddInnerHTMLString("\n");
        if (m_asOwner.GetIsAccessStyleStandard())
        {
          myContentHeader = UIConstructFactory.GetConstruct(PTBannerType.WIDE);
          myContentHeader.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE.TITLE_ELEMENT_NAME,
           _sTitle);
        } else
        {
          myContentHeader = UIConstructFactory.GetConstruct(PTBannerType.WIDE_508);
          myContentHeader.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE_508.TITLE_ELEMENT_NAME,
           _sTitle);
        }
        myResult.AddInnerHTMLElement(myContentHeader.GetHTMLElement());
        myResult.AddInnerHTMLString("\n");
        myComment = new HTMLComment("End: Editor Page header with page title");
        myResult.AddInnerHTMLElement(myComment);
        myResult.AddInnerHTMLString("\n");
      }
      catch (Exception e)
      {
        log.Error(e, "EditorDP::GetContentHeaderTable The following error occured when trying to display the HTML: " + e.Message);
        }
      return myResult;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetSpacerTable()"></seealso>
    /// <returns>HTMLElement</returns>
    private HTMLElement GetSpacerTable()
    {
      HTMLElementCollection myResult = new HTMLElementCollection();
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        myResult.AddInnerHTMLString("\n");
        HTMLComment myComment = new HTMLComment("Begin: Spacer table");
        myResult.AddInnerHTMLElement(myComment);
        myResult.AddInnerHTMLString("\n");
        myTable = new HTMLTable();
        myResult.AddInnerHTMLElement(myTable);
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // 1st Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetWidth("225");
        myImage.SetHeight("1");
        myImage.SetBorder("0");
        myCell.AddInnerHTMLElement(myImage);
        myResult.AddInnerHTMLString("\n");
        myComment = new HTMLComment("End: Spacer table");
        myResult.AddInnerHTMLElement(myComment);
        myResult.AddInnerHTMLString("\n");
      }
      catch (Exception e)
      {
        log.Error(e, "EditorDP::GetSpacerTable The following error occured when trying to display the HTML: " + e.Message);
        }
      return myResult;
    }
  }
}