using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.folder
{
  /// <author>
  /// joseq
  /// Creates the html for the popup asking if folder ACL changes should 
  /// propagate to its children.
  /// </author>
  public class FolderEditorACLPropagateView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.folder.FolderEditorACLPropagateView");
    public const String STR_MVC_CLASS_NAME = "FolderEditorACLProp";
    
    /// <summary>
    /// html button constants 
    /// </summary>
    public const String HTMLBUTTON_YES = "in_bu_yes";
    public const String HTMLBUTTON_NO = "in_bu_no";
    public const String HTMLBUTTON_CANCEL = "in_bu_cancel";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new FolderEditorACLPropagateView();
    }
    
    /// <summary>
    /// Helper methods that returns the property type name
    /// corresponding to the property type ID passed in argument.
    /// </summary>
    /// <param name="_nPropType"></param>
    /// <returns>String</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display FolderEditorACLPropagateView");
        result.AddInnerHTMLElement(myComment);
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // Header Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1692, "ptmsgs_portalbrowsingmsgs"));
        // instructions ROW
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(1811, "ptmsgs_portalbrowsingmsgs"));
        // spacer ROW
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        // buttons ROW
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign(CommonHTMLStrings.CENTER);
        /* yes */
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_YES, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1694, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        myInput.SetOnClick("window.opener." + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + FolderEditorRepostControl.POSTTOSELF_ACTION_PROPAGATE + ");window.close();");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        /* no */
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_YES, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1695, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        myInput.SetOnClick("window.opener." + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + FolderEditorRepostControl.POSTTOSELF_ACTION_NO_PROPAGATE + ");window.close();");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        /* cancel */
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_YES, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(1696, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        myInput.SetOnClick("window.opener." + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + FolderEditorRepostControl.POSTTOSELF_ACTION_CANCEL_PROPAGATE + ");window.close();");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myComment = new HTMLComment("End: Display FolderEditorACLPropagateView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (HTMLException he)
      {
        log.Error(he, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + he.Message);
        throw new XPException(m_asOwner.GetString(1697, "ptmsgs_portalbrowsingmsgs"),
         he);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}