using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.folder
{
  /// <author>
  /// StephenC
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Property Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </author>
  public class FolderEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.folder.FolderEditorAS");
    public const String STR_MVC_CLASS_NAME = "FolderEditor";
    public const String strSelectFilters = "SelectFilters";
    public const String strSelectRRCommunity = "SelectRRCommunity";
    public const String strSelectRRFolder = "SelectRRFolder";
    public const String strSelectRRPortlet = "SelectRRGadget";
    public const String strSelectRRExpert = "SelectRRExpert";
    public const String strSelectRRContentManager = "SelectRRContentManager";
    public const String strStoragePlugInKey = "FolderSamplePlugIn";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new FolderEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return (GetString(384, "ptmsgs_portalbrowsingmsgs"));
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(1706, "ptmsgs_portalbrowsingmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (FolderEditorRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = FolderEditorModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(FolderEditorModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      FolderEditorMainDP folderMainDP = new FolderEditorMainDP();
      folderMainDP.AddToValidationFunction("CheckName");
      RegisterPage(folderMainDP);
      RegisterPage(new FolderEditorAdvancedSettingsDP());
      RegisterPage(new FolderEditorRelatedResourcesDP());
      RegisterPage(new FolderEditorACLPropagateDP());
      // Register Views
      RegisterView(FolderEditorMainView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderEditorSortingView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderEditorDataSourceView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderEditorFilterSettingsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderEditorACLPropagateView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(FolderEditorRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectFilters);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectFilters,
       GetModel(strSelectFilters));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectFilters,
       GetModel(strSelectFilters));
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectRRCommunity);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectRRCommunity,
       GetModel(strSelectRRCommunity));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRCommunity,
       GetModel(strSelectRRCommunity));
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectRRFolder);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectRRFolder,
       GetModel(strSelectRRFolder));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRFolder,
       GetModel(strSelectRRFolder));
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectRRPortlet);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectRRPortlet,
       GetModel(strSelectRRPortlet));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRPortlet,
       GetModel(strSelectRRPortlet));
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectRRExpert);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectRRExpert,
       GetModel(strSelectRRExpert));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRExpert,
       GetModel(strSelectRRExpert));
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectRRContentManager);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectRRContentManager,
       GetModel(strSelectRRContentManager));
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRContentManager,
       GetModel(strSelectRRContentManager));
      // Set default page
      SetCurrentPage(FolderEditorMainDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(386, "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, FolderEditorMainDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, FolderEditorRelatedResourcesDP.STR_MVC_CLASS_NAME);
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, FolderEditorAdvancedSettingsDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1240, "ptmsgs_portalbrowsingmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          int iTitleId = 93;
          int iTipId = 94;
          int iSecondaryTipId = 95;
          tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           "ptmsgs_tips"));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
      //	Got the tips model
      this.SetHelpTopic("PT_Folder_MainSettings");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (FolderEditorMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Folder_MainSettings");
      } else
      if (FolderEditorAdvancedSettingsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Folder_AdvancedSettings");
      } else
      if (FolderEditorRelatedResourcesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_Folder_RelatedResources");
      }
    }
  }
}