using System;
// Plumtree Server
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.folder
{
  /// <author>
  /// StephenC This Section represents a section of the Main Settings page
  /// of the Folder Editor. This Section is printed out by
  /// FolderEditorMainDP.
  /// </author>
  public class FolderEditorDataSourceView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.folder.FolderEditorDataSourceView");
    public const String STR_MVC_CLASS_NAME = "FolderEditorDataSource";
    public const String HTMLRADIO_DEFAULTDATASOURCE = "in_ra_DefaultDataSource";
    public const String HTMLSELECT_DEFAULTDATASOURCE = "in_se_DefaultDataSource";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new FolderEditorDataSourceView();
    }
    
    /// <summary>
    /// Helper methods that returns the property type name  corresponding to the
    /// property type ID passed in argument.
    /// </summary>
    /// <returns>String</returns>
    /// <throws>XPException </throws>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSelect mySelect;
      HTMLOption myOption;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display FolderEditorDataSourceView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(392,
         "ptmsgs_portalbrowsingmsgs")));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing("0");
        // BEGIN Default Datasource Instructions
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(393, "ptmsgs_portalbrowsingmsgs"));
        // END Default Datasource Instructions
        // BEGIN Default Datasource Option Parent Folder Row
        bool bRootFolder = ((IFolderEditorModelRO) m_model).IsRootFolder();
        int nDefaultDataSource = ((IFolderEditorModelRO) m_model).GetDefaultDataSource();
        String strDefaultDataSource = ((IFolderEditorModelRO) m_model).GetParentDefaultDataSourceNameRecursive();
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        if (false == bRootFolder)
        {
          // Only display this option if this is not the root folder
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_DEFAULTDATASOURCE,
           "");
          myInput.SetValue("" + 0);
          myCell.AddInnerHTMLElement(myInput);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);
          mySpan.AddInnerHTMLString(m_asOwner.GetString(394, "ptmsgs_portalbrowsingmsgs") + " (" + XPHttpUtility.HtmlEncode(strDefaultDataSource) + ")");
          if (0 == nDefaultDataSource)
          {
            myInput.SetChecked(true);
          }
        }
        // END Default Datasource Option Parent Folder Row
        // BEGIN Default Datasource Option THIS Row
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        myInput = null;
        if (false == bRootFolder)
        // no radio button for the root folder
        {
          myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_DEFAULTDATASOURCE,
           "");
          myInput.SetValue("" + 1);
          myCell.AddInnerHTMLElement(myInput);
        }
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(395, "ptmsgs_portalbrowsingmsgs"));
        if (false == bRootFolder)
        // no radio button for the root folder
        {
          if (0 != nDefaultDataSource)
          {
            myInput.SetChecked(true);
          }
        }
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE + CommonHTMLStrings.SPACE);
        // begin datasource dropdown
        mySelect = new HTMLSelect(HTMLSELECT_DEFAULTDATASOURCE, "e");
        mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        myCell.AddInnerHTMLElement(mySelect);
        // Iterate through all the supported datasources
        IASQueryResult asqrFilters = ((IFolderEditorModelRO) m_model).GetFilteredDataSources();
        if (null != asqrFilters)
        {
          int nDataSourceCount = asqrFilters.GetCount();
          for (int i = 0;i < nDataSourceCount;i++)
          {
            int nDataSourceID = XPConvert.ToInteger(asqrFilters.GetFields(i,
             PT_PROPIDS.PT_PROPID_OBJECTID));
            String strPropName = ((IFolderEditorModelRO) m_model).GetDataSourceName(nDataSourceID);
            myOption = new HTMLOption(XPConvert.ToString(nDataSourceID));
            mySpan = new HTMLSpan();
            myOption.AddInnerHTMLElement(mySpan);
            mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strPropName));
            mySelect.AddInnerHTMLElement(myOption);
            if (nDataSourceID == nDefaultDataSource)
            {
              myOption.SetSelected(true);
            }
          }
        }
        // END Default Datasource Option THIS Row
        myComment = new HTMLComment("End: Display FolderEditorDataSourceView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (HTMLException he)
      {
        log.Error(he, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + he.Message);
        throw new XPException(m_asOwner.GetString(396, "ptmsgs_portalbrowsingmsgs"),
         he);
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}