using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.folder
{
  /// <author>
  /// StephenC
  /// This Section represents a section of the Main Settings page
  /// of the Folder Editor.
  /// This Section is printed out by FolderEditorMainDP.
  /// </author>
  public class FolderEditorMainView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.folder.FolderEditorMainView");
    public const String STR_MVC_CLASS_NAME = "FolderEditorMain";
    // HTML Object names.
    public const String HTMLINPUT_FOLDER_NAME = "in_tx_Name";
    public const String HTMLINPUT_FOLDER_DESCRIPTION = "in_tx_Description";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new FolderEditorMainView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display FolderEditorMainView MainView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(415,
         "ptmsgs_portalbrowsingmsgs")));
        result.AddInnerHTMLElement(DirConstants.CreateSpacerImage(2, 1));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        // BEGIN Folder Name
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("25%");
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(413, "ptmsgs_portalbrowsingmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_FOLDER_NAME,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetValue(((IFolderEditorModelRO) m_model).GetPrimaryName());
        myInput.SetMaxLength(63);
        myInput.SetSize(60);
        // END Folder Name
        // BEGIN Folder Description
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(414, "ptmsgs_portalbrowsingmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetNoWrap(true);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_FOLDER_DESCRIPTION,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetValue(((IFolderEditorModelRO) m_model).GetPrimaryDesc());
        myInput.SetMaxLength(255);
        myInput.SetSize(60);
        // END Folder Description
        myComment = new HTMLComment("End: Display FolderEditorMainView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (HTMLException he)
      {
        log.Error(he, STR_MVC_CLASS_NAME + "::MainView::Display The following error occured when trying to display the HTML: " + he.Message);
        throw new XPException(m_asOwner.GetString(416, "ptmsgs_portalbrowsingmsgs"),
         he);
      }
      return result;
    }
    
    /// <summary>
    /// Returns Java Script for that Section.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript;
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        myScript = new HTMLScript("text/javaScript");
        // The JavaScript below checks if the Folder Name is empty.
        sb.Append("function CheckName()\n");
        sb.Append("{\n");
        sb.Append("  if (\"\" == document." + EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_FOLDER_NAME + ".value)\n");
        sb.Append("  {\n");
        sb.Append("      alert(\"" + m_asOwner.GetString(417, "ptmsgs_portalbrowsingmsgs") + "\");\n");
        sb.Append("      return false;\n");
        sb.Append("  }\n");
        sb.Append("  return true;\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, STR_MVC_CLASS_NAME + "::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException(m_asOwner.GetString(418, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}