using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.folder
{
  /// <author>
  /// StephenC
  /// This is class is used to print out together the Views for
  /// the Related Resources page of the Property Editor.
  /// </author>
  public class FolderEditorRelatedResourcesDP : EditorDP
  {
    public const String STR_MVC_CLASS_NAME = "FolderEditorRR";
    private IFolderEditorModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(451, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the Advanced Settings page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      m_asModel = (IFolderEditorModelRO) m_asOwner.GetModel(FolderEditorModel.STR_MVC_CLASS_NAME);
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // Show Communities
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(FolderEditorAS.strSelectRRCommunity)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Show Related Folders
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(FolderEditorAS.strSelectRRFolder)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Show Related Portlets
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(FolderEditorAS.strSelectRRPortlet)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Show Related Experts
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(FolderEditorAS.strSelectRRExpert)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      // Show Related Content Managers
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(FolderEditorAS.strSelectRRContentManager)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(FolderEditorAS.strSelectRRCommunity).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(FolderEditorAS.strSelectRRFolder).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(FolderEditorAS.strSelectRRPortlet).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(FolderEditorAS.strSelectRRExpert).DisplayJavascript());
      myScripts.AddInnerHTMLElement(m_asOwner.GetView(FolderEditorAS.strSelectRRContentManager).DisplayJavascript());
      return myScripts;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    /// <throws>XPException </throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(452, "ptmsgs_portalbrowsingmsgs"),
       this.m_asOwner);
    }
  }
}