using System;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.resultwrapper;
namespace com.plumtree.portalpages.browsing.editors.folder
{
  /// <author>
  /// StephenC
  /// This interface is implemented by FolderEditorModel.
  /// It contains all the read-only mothods of FolderEditorModel.
  /// </author>
  public interface IFolderEditorModelRO : IObjEditorModelRO
  {
    
    /// <summary>
    /// Returns the propID to order by when BROWSING
    /// </summary>
    int GetBrowsingOrderBy();
    
    /// <summary>
    /// Returns a query result of the card properties to sort by when BROWSING
    /// </summary>
    IASQueryResult GetBrowsingOrderByProperties();
    
    /// <summary>
    /// returns the value of the Folder's ClassificationFiltersOperator Setting
    /// </summary>
    int GetClassificationFiltersOperator();
    
    /// <summary>
    /// returns the name of a given datasource.
    /// </summary>
    String GetDataSourceName(int nDataSourceID);
    
    /// <summary>
    /// returns the name of the Default DataSource for this folder.  (non-recursive)
    /// </summary>
    int GetDefaultDataSource();
    
    /// <summary>
    /// Returns the propID to order by when EDITING
    /// </summary>
    int GetEditingOrderBy();
    
    /// <summary>
    /// returns a list of data sources that support Card Submission
    /// </summary>
    IASQueryResult GetFilteredDataSources();
    
    /// <summary>
    /// returns the value of a particular Folder Setting
    /// </summary>
    Object GetFolderSetting(int nValueName);
    
    /// <summary>
    /// returns the name of the Default DataSource for this folder.  It will recursively search up the ancestors to get this.
    /// </summary>
    String GetParentDefaultDataSourceNameRecursive();
    
    /// <summary>
    /// Returns a query result of the sub-folders
    /// </summary>
    IASQueryResult GetSubFolders();
    
    /// <summary>
    /// returns whether this is the root folder
    /// </summary>
    bool IsRootFolder();
    
    /// <summary>
    /// returns primary name
    /// </summary>
    String GetPrimaryName();
    
    /// <summary>
    /// returns primary name
    /// </summary>
    String GetPrimaryDesc();
  }
}