using System;
// Framework Imports
using com.plumtree.portalpages.common.linksettings;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.editors.multipledocumentlinksettings
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the MultipleCardLinkSettings Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>StephenC</author>
  public class MultipleCardLinkSettingsAS : ObjEditorAS
  {
    public const String STR_MVC_CLASS_NAME = "MultipleCardLinkSettings";
    public const String strLinkSettingsPlugInKey = "MultipleCardLinkSettingsPlugIn";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MultipleCardLinkSettingsAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return (GetString(464, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = MultipleCardLinkSettingsModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      // Register DisplayPages
      // Main DP
      MultipleCardLinkSettingsMainDP myMainDP = new MultipleCardLinkSettingsMainDP();
      myMainDP.AddToValidationFunction("CheckNumericLinkValues");
      RegisterPage(myMainDP);
      RegisterModel(LinkSettingsPlugInModel.STR_MVC_CLASS_NAME, strLinkSettingsPlugInKey);
      IModel myPlugInModel = GetModel(strLinkSettingsPlugInKey);
      RegisterView(LinkSettingsPlugInView.STR_MVC_CLASS_NAME, strLinkSettingsPlugInKey,
       myPlugInModel);
      SetCurrentPage(MultipleCardLinkSettingsMainDP.STR_MVC_CLASS_NAME);
      // This editor only has one page so we can set the help here
      this.SetHelpTopic("PT_DocumentSettings");
      //Sets left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(465, "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MultipleCardLinkSettingsMainDP.STR_MVC_CLASS_NAME);
      }
  }
}
// END Sub menu "General Settings"
