using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.common.linksettings;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.editors.multipledocumentlinksettings
{
  /// <author>StephenC</author>
  public class MultipleCardLinkSettingsModel : ObjEditorModel,IMultipleCardLinkSettingsModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.multipledocumentlinksettings.MultipleCardLinkSettingsModel");
    public const String STR_MVC_CLASS_NAME = "MultipleCardLinkSettings";
    public const String QS_CARD_IDS = "CardIDs";
    public IPTCardRefreshAgent m_ptCardRefreshAgent = null;
    public IPTSession m_ptSession = null;
    public String m_strCardNames = "";
    public int[] m_arCardIDs;
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      String[] data;
      // CARDIDS
      data = (String[]) _htFormData.GetElement(QS_CARD_IDS);
      if ((null != data) && !(0 == data.Length))
      {
        String strCardIDs = data[0];
        int nCardCount = 1;
        int nPos = 0;
        int nLastPos;
        while (-1 != (nPos = XPStringUtility.IndexOf(strCardIDs, ",", nPos + 1)))
        {
          nCardCount++;
        }
        nPos = 0;
        String strCardID;
        m_arCardIDs = new int[nCardCount];
        for (int nCardIndex = 0;nCardIndex < nCardCount;nCardIndex++)
        {
          nLastPos = nPos;
          nPos = XPStringUtility.IndexOf(strCardIDs, ",", nLastPos + 1);
          if (-1 == nPos)
          {
            // Read last CardID
            strCardID = XPStringUtility.Substring(strCardIDs, nLastPos);
            m_arCardIDs[nCardIndex] = XPConvert.ToInteger(strCardID);
          } else
          {
            strCardID = XPStringUtility.Substring(strCardIDs, nLastPos, nPos);
            m_arCardIDs[nCardIndex] = XPConvert.ToInteger(strCardID);
            nPos++;
          }
        }
      } else
      {
        log.Warn("MultipleCardLinkSettingsModel::StartEditor CardIDs not found in Query String.");
        }
      return base.CheckEditorAccessAndStart(_htFormData);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MultipleCardLinkSettingsModel();
    }
    public override void DoTaskBeforeStore()
    {
      // Get the settings back from the plug-in Model and sets them on the Object before the Framework stores it.
      IPTCardRefreshInfo ptCardRefreshInfo = ((LinkSettingsPlugInModel) m_asOwner.GetModel(MultipleCardLinkSettingsAS.strLinkSettingsPlugInKey)).GetCardRefreshInfo();
      IPTPersist ptCardRefreshInfoPersist = (IPTPersist) ptCardRefreshInfo.GetInterfaces("IPTPersist");
      // Save Refresh Info for each Card
      for (int i = 0;i < m_arCardIDs.Length;i++)
      {
        int nObjectID = m_arCardIDs[i];
        try
        {
          m_ptCardRefreshAgent.SetCardRefreshInfo(nObjectID, ptCardRefreshInfoPersist.SaveToXML(0));
          }
        catch (XPException xpe)
        {
          log.Error(xpe, STR_MVC_CLASS_NAME + "::DoTaskBeforeStore(): Unable to store link settings for Card " + nObjectID);
          }
      }
    }
    
    /// <summary>
    /// Initializes the property type member variable with
    /// the one from IPTProperty in Edit mode and the default
    /// value in create mode.
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      try
      {
        // Concatenate Card Names
        // limit of 50 characters
        int nCardNamesCharLimit = 50;
        for (int i = 0;i < m_arCardIDs.Length;i++)
        {
          IPTCard ptCard;
          try
          {
            ptCard = m_ptSession.GetCatalog().OpenCard(m_arCardIDs[i], false);
            }
          catch (XPException xpe)
          {
            log.Warn(xpe, STR_MVC_CLASS_NAME + "::DoTaskOnStartEditor Unable to open card  " + m_arCardIDs[i]);
            break;
          }
          if (i > 0)
          {
            m_strCardNames+=", ";
          }
          m_strCardNames+=ptCard.GetLocalizedName();
          if (m_strCardNames.Length > nCardNamesCharLimit)
          {
            m_strCardNames = XPStringUtility.Substring(m_strCardNames, 0,
             nCardNamesCharLimit);
            m_strCardNames+="...";
            break;
          }
        }
        // Get the Card Refresh Info
        m_ptCardRefreshAgent = (IPTCardRefreshAgent) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_CARD_REFRESH_AGENT,
         false);
        IPTCardRefreshInfo ptCardRefreshInfo = m_ptCardRefreshAgent.GetCardRefreshInfo(this.m_nObjectID);
        ((LinkSettingsPlugInModel) m_asOwner.GetModel(MultipleCardLinkSettingsAS.strLinkSettingsPlugInKey)).InitializePlugIn(true,
         ptCardRefreshInfo);
      }
      catch (XPException xpe)
      {
        log.Error(xpe, STR_MVC_CLASS_NAME + "::DoTaskOnStartEditor Unable to retrieve Card Refresh Settings for card " + this.m_nObjectID);
        }
    }
    
    /// <returns></returns>
    public virtual String GetCardNames()
    {
      return m_strCardNames;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_ptSession = (IPTSession) parent.GetUserSession();
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(MultipleCardLinkSettingsMainDP.STR_MVC_CLASS_NAME))
      {
        ((LinkSettingsPlugInModel) m_asOwner.GetModel(MultipleCardLinkSettingsAS.strLinkSettingsPlugInKey)).SaveSection(_htFormData);
        }
      return nPageStatus;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public override Redirect GetRedirectAfterFinish()
    {
      Redirect redirect = base.GetRedirectAfterFinish();
      if (redirect.GetSpaceName().Equals(DirAS.STR_MVC_CLASS_NAME))
      {
        redirect.SetDisplayPage(DirAS.DIR_EDITOR_FINISH);
      }
      return redirect;
    }
  }
}