using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.browsing.editors.objectdelivery.common
{
  /// <author>adolfoc</author>
  public class ObjectDeliveryHelper
  {
    // AGC- This ordering is important! Don't change it!
    // Dependent objects must be listed before the objects that
    // depend on them. This ordering is required for Import
    // to properly map object IDs to related objects.
    public static readonly int[] m_arSupportedCLASSIDS = new int[]{PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID,
     PT_CLASSIDS.PT_WEBSERVICE_ID, PT_CLASSIDS.PT_GADGETTEMPLATE_ID, PT_CLASSIDS.PT_GADGET_ID,
     PT_CLASSIDS.PT_DATASOURCE_ID, PT_CLASSIDS.PT_CRAWLER_ID, PT_CLASSIDS.PT_AUTHSOURCE_ID,
     PT_CLASSIDS.PT_PROFILESOURCE_ID, PT_CLASSIDS.PT_FEDERATEDPORTAL_ID, PT_CLASSIDS.PT_GADGETBUNDLE_ID};
    // AGC- This lists CLASSIDS that are not only unsupported, but should
    // also not be noted in warnings or errors. Order is not important.
    // These are generally hidden because they are objects that the user
    // cannot change or will be automatically updated on import.
    public static readonly int[] m_arHiddenCLASSIDS = new int[]{PT_CLASSIDS.PT_ADMIN_CATALOG_ID,
     PT_CLASSIDS.PT_ADMIN_FOLDER_ID, PT_CLASSIDS.PT_ACTIVITY_ID, PT_CLASSIDS.PT_GLOBALOBJECT_ID,
     PT_CLASSIDS.PT_USER_ID, PT_CLASSIDS.PT_USERGROUP_ID, PT_CLASSIDS.PT_USERINTERFACE_ID,
     PT_CLASSIDS.PT_DOCUMENTTYPE_ID};
    // AGC- Similar to the list of hidden CLASSIDS is the list of hidden
    // dependency types. Some dependencies should just be ignored.
    public static readonly int[] m_arHiddenDependencyTypes = new int[]{PT_OBJECT_DEPENDENCY_TYPES.PT_OBJECT_DEPENDENCY_INFOLDER,
     PT_OBJECT_DEPENDENCY_TYPES.PT_OBJECT_DEPENDENCY_ACL};
    
    /// <summary>
    /// Pre-defined strings for setting/retrieving custom package data.
    /// </summary>
    public const String PACKAGE_EXPORT_SOURCE_NAME = "_Export_Source_UUID";
    public const String PACKAGE_EXPORT_SOURCE_VALUE = "{1737F42C-76F3-47e0-918D-2EC8305398F7}";
    public const String PACKAGE_NAME = "Package_Name";
    public const String PACKAGE_DESCRIPTION = "Package_Description";
    public const String PUBLISHER_NAME = "Publisher_Name";
    
    /// <summary>
    /// Pre-defined strings for customizing export/import.
    /// </summary>
    public const String PT_MIGRATEFLAG_EXPORT_ACLS = "PT_MIGRATEFLAG_EXPORT_ACLS";
    public const String PT_MIGRATEFLAG_EXPORT_EOD = "PT_MIGRATEFLAG_EXPORT_EOD";
    public const String PT_MIGRATEFLAG_IMPORT_ACLS = "PT_MIGRATEFLAG_IMPORT_ACLS";
    public const String PT_MIGRATEFLAG_IMPORT_EOD = "PT_MIGRATEFLAG_IMPORT_EOD";
    
    /// <summary>
    /// Returns whether or not the passed in classid is supported
    /// (is in m_arSupportedCLASSIDS)
    /// </summary>
    /// <returns>boolean</returns>
    public static bool IsSupported(int nCLASSID)
    {
      for (int nIndex = 0;nIndex < ObjectDeliveryHelper.m_arSupportedCLASSIDS.Length;
      nIndex++)
      {
        if (nCLASSID == ObjectDeliveryHelper.m_arSupportedCLASSIDS[nIndex])
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Returns whether or not the passed in classid is hidden
    /// (is in m_arHiddenCLASSIDS)
    /// </summary>
    /// <returns>boolean</returns>
    public static bool IsHidden(int nCLASSID)
    {
      for (int nIndex = 0;nIndex < ObjectDeliveryHelper.m_arHiddenCLASSIDS.Length;
      nIndex++)
      {
        if (nCLASSID == ObjectDeliveryHelper.m_arHiddenCLASSIDS[nIndex])
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Returns whether or not the passed in dependency type should be ignored.
    /// </summary>
    /// <returns>boolean</returns>
    public static bool IsHiddenDependencyType(int nDependencyType)
    {
      for (int nIndex = 0;nIndex < ObjectDeliveryHelper.m_arHiddenDependencyTypes.Length;
      nIndex++)
      {
        if (0 != (nDependencyType & m_arHiddenDependencyTypes[nIndex]))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <param name="strIn"></param>
    /// <returns></returns>
    public static String MakeHReadable(String strIn)
    {
      String strResult = strIn;
      while (0 <= XPStringUtility.IndexOf(strResult, '_'))
      {
        strResult = GeneralHelpers.Replace(strResult, "_", " ");
      }
      return strResult;
    }
  }
}