using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.browsing.editors.sitemap
{
  /// <author>NaveenP</author>
  public class SiteMapFolderCheckAccessControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.sitemap.SiteMapFolderCheckAccessControl");
    
    /// <summary>
    /// name of the refresh object selection control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapFolderCheckAccess";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Internal data *
    /// </summary>
    protected SiteMapFolderModel m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      if (!((EditorModel) m_asModel).GetUserHasAccessToEditor())
      {
        Redirect myRedirectToLogin = new Redirect();
        myRedirectToLogin.SetIsErrorRedirect(true);
        myRedirectToLogin.SetLinkCreateNewSpace(m_asOwner.GetName(), m_asOwner);
        myRedirectToLogin.SetControl(STR_MVC_CLASS_NAME);
        myRedirectToLogin.AddControlArguments(arguments);
        return myRedirectToLogin;
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SiteMapFolderCheckAccessControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      try
      {
        m_asModel = (SiteMapFolderModel) model;
      }
      catch (Exception e)
      {
        log.Error(e, "SiteMapFolderCheckAccessControl::Init Unable to cast the Object " + model + " to SiteMapFolderModel. The following exception occured: " + e.Message);
        // JF- No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + model + " to SiteMapFolderModel.",
         e);
      }
      m_asOwner = space;
    }
  }
}