using System;
// Framework Imports
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.browsing.editors.sitemap
{
  /// <summary>
  /// File: SiteMapFolderEditorAS.java
  /// --------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SiteMapFolderEditorAS : ObjEditorAS
  {
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapFolderEditor";
    
    /// <summary>
    /// Unique identifier for sitemap folder links plug-in section 
    /// </summary>
    public const String STR_MVC_SITEMAP_PLUGIN = "SiteMapFolderPlugIn";
    public int m_nMenuGeneralID;
    public int m_nMenuStandardID;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapFolderEditorAS();
    }
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bAccess = base.CheckBasicAccess(strPage, strControl, bSameSpace);
      if ((null != strControl) && (strControl.Equals(SiteMapFolderCheckAccessControl.STR_MVC_CLASS_NAME)))
      {
        return true;
      }
      return bAccess;
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      SiteMapFolderModel iModel = (SiteMapFolderModel) GetModel(SiteMapFolderModel.STR_MVC_CLASS_NAME);
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        if (iModel.GetStartedInSiteMap())
        {
          return (GetString(537, "ptmsgs_portalbrowsingmsgs"));
        } else
        {
          return (GetString(535, "ptmsgs_portalbrowsingmsgs"));
        }
      } else
      {
        if (iModel.GetStartedInSiteMap())
        {
          return (XPResourceManager.FormatMessage(GetString(1708, "ptmsgs_portalbrowsingmsgs"),
           GetObjectName()));
        } else
        {
          return (XPResourceManager.FormatMessage(GetString(1707, "ptmsgs_portalbrowsingmsgs"),
           GetObjectName()));
        }
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SiteMapFolderRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SiteMapFolderModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(SiteMapFolderModel.STR_MVC_CLASS_NAME);
      SiteMapFolderEditLinksDP smEditDP = new SiteMapFolderEditLinksDP();
      RegisterPage(smEditDP);
      // Register Controls
      RegisterControl(SiteMapFolderRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SiteMapFolderCheckAccessControl.STR_MVC_CLASS_NAME,
       myModel);
      //Sitemap link plug-in
      RegisterModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME, STR_MVC_SITEMAP_PLUGIN);
      IModel mySiteMapPluginModel = GetModel(STR_MVC_SITEMAP_PLUGIN);
      RegisterView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME, STR_MVC_SITEMAP_PLUGIN,
       mySiteMapPluginModel);
      RegisterControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME, STR_MVC_SITEMAP_PLUGIN,
       mySiteMapPluginModel);
      // Set default page
      SetCurrentPage(SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      m_nMenuGeneralID = m_mEditorMenu.StartNewSubMenu(GetString(1866, "ptmsgs_portaladminmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(m_nMenuGeneralID, SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
      // BEGIN Sub menu "Standard Settings"
      m_nMenuStandardID = m_mEditorMenu.StartNewSubMenu(GetString(1867, "ptmsgs_portaladminmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(m_nMenuStandardID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(m_nMenuStandardID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(m_nMenuStandardID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      }
  }
}
// END Sub menu "Standard Settings"
