using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.sitemap
{
  /// <summary>
  /// File: SiteMapFolderModel.java
  /// -----------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SiteMapFolderModel : ObjEditorModel,ISiteMapFolderRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.sitemap.SiteMapFolderModel");
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapFolder";
    
    /// <summary>
    /// The parent folder id query string argment 
    /// </summary>
    public const String QS_PARENTFOLDERID = "ParentFolderID";
    
    /// <summary>
    /// The edit type query string argument 
    /// </summary>
    public const String QS_NAMEORSECURITY = "EditType";
    
    /// <summary>
    /// Query string argument indicating the starting context for the editor 
    /// </summary>
    public const String QS_STARTEDINSITEMAP = "StartedInSiteMap";
    
    /// <summary>
    /// Query string argument indicating to show localized names page only 
    /// </summary>
    public const String QS_LOCALIZEDNAME = "LocalizeNamePage";
    
    /// <summary>
    /// Constant representing the name and description page 
    /// </summary>
    public const int EDIT_TYPE_NAME_DESC = 0;
    
    /// <summary>
    /// Constant representing the security page 
    /// </summary>
    public const int EDIT_TYPE_SECURITY = 1;
    
    /// <summary>
    /// Constant indicating no parent admin folder 
    /// </summary>
    public const int NO_PARENT = -1;
    //Member variables
    private IPTSiteMapFolder m_ptParentFolder;
    private bool m_bStartedInSiteMap = false;
    private bool m_bFromSubportalNav = false;
    private int m_nNameOrSecurity = -1;
    // this should be NO_PARENT, but in order for the j2c tool to work properly i just set the real value here.
    private int m_nParentSiteMapFolderID = -1;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapFolderModel();
    }
    
    /// <summary>
    /// This function cleans up the folder created at the outset if the user
    /// cancels the editor
    /// </summary>
    public virtual void DeleteFolderOnCancel()
    {
      if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
      {
        IPTServerContext objSC = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
        int nObjectID = objSC.GetObjectID();
        IPTObjectManager objOM = m_Session.GetSiteMapFolders();
        objOM.Delete(nObjectID);
      }
    }
    
    /// <summary>
    /// This function saves the site map link folder at the outset, at least
    /// temporarily, so we can add links to it.
    /// </summary>
    public virtual void DoInitialStore()
    {
      m_ptObject.SetAdminFolderID(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
      IPTServerContext objSC = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
      objSC.Store();
      objSC.UnlockObject();
    }
    
    /// <summary>
    /// Initializes member variables when the editor starts
    /// </summary>
    /// <param name="_htFormData"></param>
    public override void DoTaskOnStartEditor(XPHashtable _htFormData)
    {
      InitializeSiteMapPlugIn();
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(m_bFromSubportalNav,
         ObjectSecurityDP.STR_MVC_CLASS_NAME);
      } else
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
      {
        if (NO_PARENT == m_nParentSiteMapFolderID)
        {
          DoInitialStore();
        }
      }
      if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
      {
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        }
    }
    
    /// <summary>
    /// Helper method to initialize the plug-in section for navigation link
    /// creation
    /// </summary>
    public virtual void InitializeSiteMapPlugIn()
    {
      SiteMapFolderPlugInModel mySiteMapFolderModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderEditorAS.STR_MVC_SITEMAP_PLUGIN);
      try
      {
        mySiteMapFolderModel.InitializePlugIn((IPTSiteMapFolder) m_ptObject);
        }
      catch (Exception e)
      {
        log.Error("SiteMapFolderModel::InitializeSiteMapPlugIn " + m_asOwner.GetString(1457,
         "ptmsgs_portalbrowsingmsgs") + e);
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1457, "ptmsgs_portalbrowsingmsgs"), "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <returns>boolean</returns>
    public virtual bool FolderHasParent()
    {
      return (NO_PARENT != m_nParentSiteMapFolderID);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // END ***************** repost action methods ***************** 
    
    /// <summary>
    /// Returns Redirect object where the Framework should
    /// redirect to on Finish.
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect GetRedirectAfterFinish()
    {
      if ((NO_PARENT != m_nParentSiteMapFolderID) || (-1 != m_nNameOrSecurity))
      {
        Redirect redirect = new Redirect();
        ClosePopUpDP closePopup = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
        HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        try
        {
          script.AddInnerHTMLString(
          //location.reload(true);");
          "window.opener.postToSelf(" + RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");");
          }
        //DCA - changed to get rid of page refresh warning
        catch (HTMLException he)
        {
          log.Error(he, he.Message);
        }
        closePopup.SetScript(script);
        redirect.SetLinkGetCachedSpace(m_asOwner);
        redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
        redirect.SetControl(SiteMapFolderCheckAccessControl.STR_MVC_CLASS_NAME);
        return redirect;
      } else
      {
        return base.GetRedirectAfterFinish();
      }
    }
    
    /// <returns></returns>
    public virtual bool GetStartedInSiteMap()
    {
      return m_bStartedInSiteMap;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nPageStatus = base.SavePage(_sPageName, _htFormData);
      if (_sPageName.Equals(SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME))
      {
        SaveEditLinkPage(_htFormData);
      }
      return nPageStatus;
    }
    
    /// <summary>
    /// Helper method to check the current user rights to this Object Editor.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    /// <returns>boolean</returns>
    protected override bool CheckEditorAccess(XPHashtable _htFormData)
    {
      String[] values = (String[]) _htFormData.GetElement(QS_PARENTFOLDERID);
      if (values != null)
      {
        m_nParentSiteMapFolderID = XPConvert.ToInteger(values[0]);
        ((EditorAS) m_asOwner).SetCurrentPage(LocNamesDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
        }
      values = (String[]) _htFormData.GetElement(QS_NAMEORSECURITY);
      if (values != null)
      {
        m_nNameOrSecurity = XPConvert.ToInteger(values[0]);
      }
      if (m_nNameOrSecurity == EDIT_TYPE_NAME_DESC)
      {
        ((EditorAS) m_asOwner).SetCurrentPage(LocNamesDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideSubMenu(true, ((SiteMapFolderEditorAS) m_asOwner).m_nMenuGeneralID);
        } else
      if (m_nNameOrSecurity == EDIT_TYPE_SECURITY)
      {
        ((EditorAS) m_asOwner).SetCurrentPage(ObjectSecurityDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, LocNamesDP.STR_MVC_CLASS_NAME);
        ((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
        }
      values = (String[]) _htFormData.GetElement(QS_STARTEDINSITEMAP);
      if (values != null)
      {
        // we came from the site map, so change the title to "Edit Folder" or "Create Folder".
        SetStartedInSiteMap(true);
      }
      values = (String[]) _htFormData.GetElement(QS_LOCALIZEDNAME);
      if (values != null)
      {
        // we only want to show the name page.
        m_bFromSubportalNav = true;
      }
      // JF- In create mode and from site map page, check parent folder access rights
      if ((EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType) && (NO_PARENT != m_nParentSiteMapFolderID))
      {
        IPTObjectManager ptOM = m_Session.GetSiteMapFolders();
        m_ptParentFolder = (IPTSiteMapFolder) ptOM.Open(m_nParentSiteMapFolderID,
         false);
        return (ptOM.IsObjectAccessible(m_nParentSiteMapFolderID, m_Session.GetSessionInfo().GetCurrentUserID(),
         PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT));
      } else
      {
        return base.CheckEditorAccess(_htFormData);
      }
    }
    
    /// <summary>
    /// Initializes the object being created or edited with this editor
    /// </summary>
    protected override void InitPTObject(XPHashtable _htFormData)
    {
      if ((EDITOR_OBJECTID_UNKNOWN == m_nObjectID) && (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType()))
      {
        if (NO_PARENT == m_nParentSiteMapFolderID)
        {
          m_ptObject = (IPTObject) m_Session.GetObjectManagers(m_nClassID).Create(m_nFolderID);
          m_ptObject.SetName(m_asOwner.GetString(1443, "ptmsgs_portalbrowsingmsgs"));
          } else
        {
          try
          {
            m_ptObject = (IPTObject) m_ptParentFolder.CreateSubfolder(m_asOwner.GetString(548,
             "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(549, "ptmsgs_portalbrowsingmsgs"));
            }
          catch (Exception e)
          {
            log.Error(e, "Unable to create child folder in parent.  Either parent could not be opened, or child creation failed: " + e.Message);
            }
        }
      } else
      if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
      {
        m_ptObject = (IPTObject) m_Session.GetObjectManagers(m_nClassID).Open(m_nObjectID,
         false);
      }
      IPTServerContext objSC = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
      m_nObjectID = objSC.GetObjectID();
    }
    
    /// <summary>
    /// Saves the values from the edit link page into member variables.  In this
    /// case, it actually just replaces the copy of the object we have with the
    /// one it retrieves from the plug-in section.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int</returns>
    protected virtual int SaveEditLinkPage(XPHashtable _htFormData)
    {
      int nPageStatus = RepostControl.PAGE_STATUS_VALID;
      //Save the links
      try
      {
        ((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderEditorAS.STR_MVC_SITEMAP_PLUGIN)).SaveSection(_htFormData);
        m_ptObject = ((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderEditorAS.STR_MVC_SITEMAP_PLUGIN)).GetPTObject();
        }
      catch (Exception e)
      {
        log.Error("SiteMapFolderModel::SaveEditLinkPage " + m_asOwner.GetString(1458,
         "ptmsgs_portalbrowsingmsgs") + e);
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1458, "ptmsgs_portalbrowsingmsgs") + e,
         "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        nPageStatus = RepostControl.PAGE_STATUS_INVALID;
      }
      return nPageStatus;
    }
    // BEGIN ***************** helper methods ***************** 
    // END ***************** helper methods ***************** 
    private void SetStartedInSiteMap(bool bStartedInSiteMap)
    {
      m_bStartedInSiteMap = bStartedInSiteMap;
    }
  }
}