using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
namespace com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin
{
  /// <author>
  /// John Hogan
  /// This interface is implemented by the Model.
  /// It contains all the read-only mothods of the Model
  /// accessed by the Views.
  /// </author>
  public interface ISiteMapFolderPlugInModelRO
  {
    
    /// <summary>
    /// Returns the Links
    /// </summary>
    /// <returns>ASQueryResultWrapper</returns>
    XPArrayList GetLinks();
    
    /// <summary>
    /// Returns the Links sorted alphabetically
    /// </summary>
    /// <returns>PTSortedArrayWrapper</returns>
    PTSortedArrayWrapper GetLinksAlphaSorted();
    
    /// <summary>
    /// Returns the IPTSiteMapFolder object being manipulated
    /// </summary>
    IPTSiteMapFolder GetPTObject();
    
    /// <summary>
    /// Returns the objectID for the site map folder being edited
    /// </summary>
    /// <returns>int</returns>
    int GetObjectID();
    
    /// <summary>
    /// Returns true if the site map folder is used on multiple subportals
    /// </summary>
    /// <returns>boolean</returns>
    bool IsDuplicated();
    
    /// <summary>
    /// Returns the subspace ID used by the Expert tree control.  This is used to
    /// ensure that trees that already exist in memory are reused instead of
    /// recreated.
    /// </summary>
    /// <returns>String</returns>
    String GetExpertSubSpaceID();
    
    /// <summary>
    /// Returns the subspace ID used by the Document tree control.  This is used
    /// to ensure that trees that already exist in memory are reused instead of
    /// recreated.
    /// </summary>
    /// <returns>String</returns>
    String GetDocumentSubSpaceID();
    
    /// <summary>
    /// Returns the subspace ID used by the Community Page tree control.  This is
    /// used to ensure that trees that already exist in memory are reused instead
    /// of recreated.
    /// </summary>
    /// <returns>String</returns>
    String GetCommPageSubSpaceID();
    
    /// <summary>
    /// Returns a 2D array of strings containing all of the web link information
    /// </summary>
    /// <returns>String[][]</returns>
    String[][] GetWebLinks();
    
    /// <summary>
    /// Returns the description of the web link we are working on.
    /// </summary>
    /// <returns>String</returns>
    String GetWebLinkDesc();
    
    /// <summary>
    /// Returns the name of the web link we are working on.
    /// </summary>
    /// <returns>String</returns>
    String GetWebLinkName();
    
    /// <summary>
    /// Returns the URL of the web link we are working on.
    /// </summary>
    /// <returns>String</returns>
    String GetWebLinkURL();
    
    /// <summary>
    /// Returns the unique identifier for the web link that the user is
    /// currently editing (if any).  If no link is being edited, the member
    /// variable should contain an empty string.
    /// </summary>
    /// <returns>String</returns>
    String GetEditedID();
    
    /// <summary>
    /// Helper method to return the number of links currently cached in the working list
    /// </summary>
    /// <returns>int</returns>
    int GetWebLinkCount();
    
    /// <summary>
    /// Get the selected users for the tree in the "classid, object format"
    /// </summary>
    /// <returns>String</returns>
    String GetSelectedUsersString();
    
    /// <summary>
    /// Get the selected docs and folders for the tree in the "classid, objectid"
    /// format
    /// </summary>
    /// <returns>String</returns>
    String GetSelectedDirItemsAsString();
    
    /// <summary>
    /// Get the selected community pages for the tree in
    /// "communityid,pageid;communityid,pageid" format
    /// (this is how the comm page tree is set to display
    /// the locations)
    /// </summary>
    /// <returns>String</returns>
    String GetSelectedCommPagesAsString();
    
    /// <summary>
    /// Is the directory enabled for this subportal?
    /// </summary>
    /// <returns>boolean</returns>
    bool IsDirectoryEnabled();
    
    /// <summary>
    /// Are communities enabled for this subportal?
    /// </summary>
    /// <returns>boolean</returns>
    bool AreCommunitiesEnabled();
  }
}