using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portalpages.portlets.sitemap.prefs;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin
{
  /// <summary>
  /// This Control contains the repost actions for the Site Map Folder plug-in
  /// section.
  /// </summary>
  /// <author>John Hogan</author>
  public class SiteMapFolderPlugInControl : EditorHelperRepostControl
  {
    
    /// <summary>
    /// Unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapFolderPlugInControl";
    
    /// <summary>
    /// Delete the selected links from the list 
    /// </summary>
    public const int POSTTOSELF_ACTION_DELETE = 11;
    
    /// <summary>
    /// Detach this site map folder from other subportals that may be sharing it 
    /// </summary>
    public const int POSTTOSELF_ACTION_DETACH = 12;
    
    /// <summary>
    /// Submit chosen experts from the expert choosing tree and add them to the links list 
    /// </summary>
    public const int POSTTOSELF_ACTION_EXPERTTREESUBMIT = 13;
    
    /// <summary>
    /// Submit chosen pages from the Community Page choosing tree and add them to the links list 
    /// </summary>
    public const int POSTTOSELF_ACTION_COMMPAGETREESUBMIT = 14;
    
    /// <summary>
    /// Cancel action - clears the temporary list of links 
    /// </summary>
    public const int POSTTOSELF_ACTION_CANCEL = 15;
    
    /// <summary>
    /// Submit chosen documents or folders from the folder/document choosing tree and add them to the links list 
    /// </summary>
    public const int POSTTOSELF_ACTION_DOCUMENTTREESUBMIT = 16;
    
    /// <summary>
    /// Add a web link to the working set of web links 
    /// </summary>
    public const int POSTTOSELF_ACTION_ADDLINK = 17;
    
    /// <summary>
    /// Commit changes to the working set of web links 
    /// </summary>
    public const int POSTTOSELF_ACTION_SAVELINKS = 18;
    
    /// <summary>
    /// Remove checked links from the working set of web links 
    /// </summary>
    public const int POSTTOSELF_ACTION_REMOVELINKS = 19;
    
    /// <summary>
    /// Change a selected web link to 'Edit' mode 
    /// </summary>
    public const int POSTTOSELF_ACTION_EDITLINK = 20;
    
    /// <summary>
    /// Change a selected web link to 'Edit' mode 
    /// </summary>
    public const int POSTTOSELF_ACTION_OPENWEBLINKS = 71;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapFolderPlugInControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Performs the requested action on repost.
    /// </summary>
    /// <param name="_nAction"></param>
    /// <param name="_htFormData"></param>
    public override void PerformRepostAction(int _nAction, XPHashtable _htFormData)
    {
      SiteMapPortletPrefsSortedLinksModel smPrefsSortedLinksModel = null;
      if (m_asOwner.GetModelExists(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME))
      {
        smPrefsSortedLinksModel = (SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME);
        }
      bool bInPrefsEditor = smPrefsSortedLinksModel != null;
      SiteMapModel smPageModel = null;
      if (m_asOwner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME))
      {
        smPageModel = (SiteMapModel) m_asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
        }
      bool bInSiteMapPage = smPageModel != null;
      switch (_nAction){
      case POSTTOSELF_ACTION_DELETE:
      ((SiteMapFolderPlugInModel) m_model).DeleteLinks();
      if (bInPrefsEditor)
      {
        smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
      }
      break;
      case POSTTOSELF_ACTION_DETACH:
      ((SiteMapFolderPlugInModel) m_model).DetachLinks();
      break;
      case POSTTOSELF_ACTION_EXPERTTREESUBMIT:
      ((SiteMapFolderPlugInModel) m_model).RefreshItemFromTree(POSTTOSELF_ACTION_EXPERTTREESUBMIT,
       SiteMapFolderPlugInView.EXPERT_TREE_SUBSPACE);
      if (bInPrefsEditor)
      {
        smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
        smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
      }
      if (bInSiteMapPage)
      {
        try
        {
          ((SiteMapFolderPlugInModel) m_model).StoreLinks();
        }
        catch (Exception e)
        {
        }
      }
      break;
      case POSTTOSELF_ACTION_DOCUMENTTREESUBMIT:
      ((SiteMapFolderPlugInModel) m_model).RefreshItemFromTree(POSTTOSELF_ACTION_DOCUMENTTREESUBMIT,
       SiteMapFolderPlugInView.DOCUMENT_TREE_SUBSPACE);
      if (bInPrefsEditor)
      {
        smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
        smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
      }
      if (bInSiteMapPage)
      {
        try
        {
          ((SiteMapFolderPlugInModel) m_model).StoreLinks();
        }
        catch (Exception e)
        {
        }
      }
      break;
      case POSTTOSELF_ACTION_COMMPAGETREESUBMIT:
      ((SiteMapFolderPlugInModel) m_model).RefreshItemFromTree(POSTTOSELF_ACTION_COMMPAGETREESUBMIT,
       SiteMapFolderPlugInView.COMMPAGE_TREE_SUBSPACE);
      if (bInPrefsEditor)
      {
        smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
        smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
      }
      if (bInSiteMapPage)
      {
        try
        {
          ((SiteMapFolderPlugInModel) m_model).StoreLinks();
        }
        catch (Exception e)
        {
        }
      }
      break;
      case POSTTOSELF_ACTION_ADDLINK:
      ((SiteMapFolderPlugInModel) m_model).AddWebLink(_htFormData);
      break;
      case POSTTOSELF_ACTION_SAVELINKS:
      ((SiteMapFolderPlugInModel) m_model).AddWebLink(_htFormData);
      ((SiteMapFolderPlugInModel) m_model).SaveWebLinks(_htFormData);
      if (bInPrefsEditor)
      {
        smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
        smPrefsSortedLinksModel.UpdateRowsOnRepost(_htFormData);
        smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
      }
      if (bInSiteMapPage)
      {
        try
        {
          ((SiteMapFolderPlugInModel) m_model).StoreLinks();
        }
        catch (Exception e)
        {
        }
      }
      break;
      case POSTTOSELF_ACTION_REMOVELINKS:
      ((SiteMapFolderPlugInModel) m_model).RemoveLinks(_htFormData);
      break;
      case POSTTOSELF_ACTION_EDITLINK:
      ((SiteMapFolderPlugInModel) m_model).EditWebLink(_htFormData);
      break;
      case POSTTOSELF_ACTION_CANCEL:
      ((SiteMapFolderPlugInModel) m_model).ClearLinks();
      break;
      }
    }
  }
}