using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.subportal;
using com.plumtree.portalpages.browsing.editors.sitemap;
using com.plumtree.portalpages.browsing.sitemap.linkselector;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portalpages.portlets.sitemap.prefs;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin
{
  /// <summary>
  /// This Section contains the HTML for the plug-in section.
  /// PAI - DO NOT make calls to m_asOwner in this class.  Use GetASOwner().
  /// </summary>
  /// <author>John Hogan</author>
  public class SiteMapFolderPlugInView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.SiteMapFolderPlugInView");
    
    /// <summary>
    /// The unique name for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapFolderPlugInView";
    //Subspace keys for popup trees
    
    /// <summary>
    /// Subspace key for Expert tree popup 
    /// </summary>
    public const String EXPERT_TREE_SUBSPACE = "ExpertTreeSubspace";
    
    /// <summary>
    /// Subspace key for Community Page tree popup 
    /// </summary>
    public const String COMMPAGE_TREE_SUBSPACE = "CommPageTreeSubspace";
    
    /// <summary>
    /// Subspace key for Expert tree popup 
    /// </summary>
    public const String DOCUMENT_TREE_SUBSPACE = "DocumentTreeSubspace";
    //Javascript function names
    
    /// <summary>
    /// Javascript function name - openServerExpertTree *
    /// </summary>
    private const String JAVASCRIPT_SERVER_EXPERTTREE = "openServerExpertTree";
    
    /// <summary>
    /// Javascript function name - submitExpert *
    /// </summary>
    private const String JAVASCRIPT_SERVER_EXPERTSUBMIT = "submitExpert";
    
    /// <summary>
    /// Javascript function name - openServerDocumentTree *
    /// </summary>
    private const String JAVASCRIPT_SERVER_DOCUMENTTREE = "openServerDocumentTree";
    
    /// <summary>
    /// Javascript function name - submitDocument *
    /// </summary>
    private const String JAVASCRIPT_SERVER_DOCUMENTSUBMIT = "submitDocument";
    
    /// <summary>
    /// Javascript function name - openServerCommPageTree *
    /// </summary>
    private const String JAVASCRIPT_SERVER_COMMPAGETREE = "openServerCommPageTree";
    
    /// <summary>
    /// Javascript function name - submitCommPage *
    /// </summary>
    private const String JAVASCRIPT_SERVER_COMMPAGESUBMIT = "submitCommPage";
    
    /// <summary>
    /// Javascript function to open the create web links dialog 
    /// </summary>
    private const String JAVASCRIPT_CREATELINKS = "openCreateWebLinks";
    
    /// <summary>
    /// Javascript function to validate the Navigation Link's Name 
    /// </summary>
    public const String JAVASCRIPT_CHECKNAVLINKNAME = "checkNavLinkName";
    
    /// <summary>
    /// Javascript function name - onDelete *
    /// </summary>
    public const String JAVASCRIPT_DELETE = "onDelete";
    
    /// <summary>
    /// Javascript function name - checkObjectsSelected *
    /// </summary>
    public const String JAVASCRIPT_CHECK_OBJECTS_SELECTED = "checkObjectsSelected";
    // HTML Object names.
    
    /// <summary>
    /// Hidden element for expert space ID 
    /// </summary>
    public const String HTMLHIDDEN_EXPERT_SPACE = "in_hi_HiddenExpertSpace";
    
    /// <summary>
    /// Hidden element for document space ID 
    /// </summary>
    public const String HTMLHIDDEN_DOCUMENT_SPACE = "in_hi_HiddenDocumentSpace";
    
    /// <summary>
    /// Hidden element for community page space ID 
    /// </summary>
    public const String HTMLHIDDEN_COMMPAGE_SPACE = "in_hi_HiddenCommPageSpace";
    
    /// <summary>
    /// Folder name input box 
    /// </summary>
    public const String HTMLINPUT_SMFOLDER_NAME = "in_tx_Name";
    
    /// <summary>
    /// Folder description input box 
    /// </summary>
    public const String HTMLINPUT_SMFOLDER_DESCRIPTION = "in_ta_Description";
    
    /// <summary>
    /// Repost button 
    /// </summary>
    public const String HTMLBUTTON_REPOST = "in_bu_repost";
    
    /// <summary>
    /// Check all checkbox 
    /// </summary>
    public const String HTMLCHECKBOX_CHECKALL = "in_cb_CheckAll";
    
    /// <summary>
    /// Checkbox marking rows to delete 
    /// </summary>
    public const String HTMLCHECKBOX_DELROW = "in_cb_DelRow";
    
    /// <summary>
    /// Input box for the name of the Navigation Links folder 
    /// </summary>
    public const String HTMLINPUT_FOLDERNAME = "in_tx_FolderName";
    
    /// <summary>
    /// Button to add localized names 
    /// </summary>
    public const String HTMLBUTTON_LOCALIZE_NAME = "in_bu_LocalizeName";
    private SiteMapAS m_asMyOwner;
    //	private final String _ui_HelpSeparate = "Warning:  This set of links is shared " +
    //		"by other subportals.  Changes to this list will be reflected in those subportals.  Click " +
    //		"Separate to create a unique list for this subportal.";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapFolderPlugInView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      if (parent.GetName().Equals(SiteMapAS.STR_MVC_CLASS_NAME))
      {
        m_model = model;
        m_asMyOwner = (SiteMapAS) parent;
        m_asOwner = null;
      } else
      {
        base.Init(model, parent);
      }
    }
    
    /// <summary>
    /// WARNING - you must use this function in this class - you should never use
    /// m_asOwner.  
    /// The reason for this function is that m_asOwner is cast to an EditorAS by the
    /// framework, because this is an EditorView.  However, we need this class in 
    /// non-editor places, so we override the Init (above), and use a different
    /// variable if we need to.  Calling GetASOwner() will give the appropriate space.
    /// </summary>
    /// <returns>AActivitySpace</returns>
    private AActivitySpace GetASOwner()
    {
      if (m_asOwner == null)
      {
        return m_asMyOwner;
      } else
      {
        return m_asOwner;
      }
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      try
      {
        // JF- Get the Object array from the Model.
        PTSortedArrayWrapper arrLinks = ((ISiteMapFolderPlugInModelRO) m_model).GetLinksAlphaSorted();
        HTMLComment myComment = new HTMLComment("Display SiteMapFolderEditLinksView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(base.GetHeaderView(GetASOwner().GetString(528,
         "ptmsgs_portalbrowsingmsgs")));
        result.AddInnerHTMLElement(GetHTMLForActionBar(arrLinks.GetCount()));
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing(CommonHTMLStrings.TWO);
        if (0 != arrLinks.GetCount())
        {
          if (((ISiteMapFolderPlugInModelRO) m_model).IsDuplicated())
          {
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetAutoFit(true);
            HTMLSpan mySpan = new HTMLSpan();
            mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
            //_ui_HelpSeparate
            mySpan.AddInnerHTMLString(GetASOwner().GetString(1552, "ptmsgs_portalbrowsingmsgs"));
            myCell.AddInnerHTMLElement(mySpan);
          }
          //Display the input box for the site map folder name
          myTable.AddInnerHTMLElement(GetHTMLForNameRow());
          // 1st Row begin - sub Header
          myTable.AddInnerHTMLElement(GetHTMLForSubHeader());
          // 1st Row end - sub Header
          // JF- Loop through the list and display the rows.
          for (int nRowIndex = 0;nRowIndex < arrLinks.GetCount();nRowIndex++)
          {
            // Row nRowIndex - begin
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            // JF- Set row background
            if (0 == (nRowIndex % 2))
            {
              myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
            } else
            {
              myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
            }
            // Display delete checkbox
            myRow.AddInnerHTMLElement(GetHTMLForCheckBox((PTLink) arrLinks.GetItem(nRowIndex,
             SiteMapLinkContainer.LINK_COLUMN)));
            // Display rest of the row
            myRow.AddInnerHTMLElement(GetHTMLForRow(arrLinks, nRowIndex));
            }
        } else
        // Row nRowIndex - end
        {
          myCell = new HTMLTableCell();
          myCell.SetColSpan(CommonHTMLStrings.TWO);
          myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
          myCell.AddInnerHTMLString(GetASOwner().GetString(534, "ptmsgs_portalbrowsingmsgs"));
          myRow = new HTMLTableRow();
          myRow.AddInnerHTMLElement(myCell);
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetColSpan(CommonHTMLStrings.TWO);
          myCell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
          myCell.AddInnerHTMLString(GetASOwner().GetString(533, "ptmsgs_portalbrowsingmsgs"));
          myRow = new HTMLTableRow();
          myRow.AddInnerHTMLElement(myCell);
          myTable.AddInnerHTMLElement(myRow);
        }
        myComment = new HTMLComment("End: Display SiteMapFolderEditLinksView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        // ***CHANGE_HERE*** Update the error messages (log and exception).
        log.Error(e, "SiteMapFolderEditLinksView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(GetASOwner().GetString(532, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Returns Java Script for that Section.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript;
      myScript = new HTMLScript("text/javaScript");
      ISiteMapFolderPlugInModelRO plugInModelRO = (ISiteMapFolderPlugInModelRO) m_model;
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        // JavaScript to check all the rows
        sb.Append("function CheckRows()\n");
        sb.Append("{ \n");
        sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME + "; \n");
        sb.Append("  var len = frm.elements.length; \n");
        sb.Append("  var nValue = frm." + HTMLCHECKBOX_CHECKALL + ".checked; \n");
        sb.Append("  var i = 0; \n");
        sb.Append("  \n");
        sb.Append("  for(i=0 ; i<len ; i++) \n");
        sb.Append("  { \n");
        sb.Append("    if (frm.elements[i].name == \'" + HTMLCHECKBOX_DELROW + "\') \n");
        sb.Append("    { \n");
        sb.Append("       frm.elements[i].checked = nValue;\n");
        sb.Append("    } \n");
        sb.Append("  } \n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // The URL to open as the pop-up
        ASURL myPopUp = new ASURL(GetASOwner());
        myPopUp.SetLinkGetCachedSpace(GetASOwner());
        myPopUp.SetDisplayPage(SiteMapCreateWebLinkDP.STR_MVC_CLASS_NAME);
        //JH- We want to pass the data to our repost control so that it can be stored
        myPopUp.SetControl(((IFormAS) GetASOwner()).GetRepostControlName());
        myPopUp.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF, SiteMapFolderPlugInControl.POSTTOSELF_ACTION_OPENWEBLINKS);
        sb = new XPStringBuilder(200);
        sb.Append("function " + JAVASCRIPT_CREATELINKS + "()\n");
        sb.Append("{\n");
        //JH- We have to build an URL that contains the querystring argument (which contains the
        //	row number we're viewing.)
        sb.Append("\t\topenURL = \'").Append(myPopUp.GetURLAsString()).Append("\';\n");
        sb.Append("\t\twindow.open(openURL,\'weblinks\',\'status=no,toolbar=yes,menubar=no,resizable=yes,scrollbars=yes,location=no,width=800,height=600\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "SiteMapFolderEditLinksView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException("No JS to display yet", e);
      }
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        // The url to open a previously opened User (expert) tree
        // This needs to have the SpaceID added to it.
        ASURL oldExpertTree = new ASURL(GetASOwner());
        oldExpertTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, GetASOwner());
        oldExpertTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
        oldExpertTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         plugInModelRO.GetSelectedUsersString());
        oldExpertTree.IsSubSpace();
        // The URL to open a new server communities tree
        ASURL newExpertTree = new ASURL(GetASOwner());
        newExpertTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, GetASOwner());
        newExpertTree.SetSubSpaceKey(SiteMapFolderPlugInView.EXPERT_TREE_SUBSPACE);
        newExpertTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        newExpertTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
        newExpertTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
        newExpertTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFSELECT));
        newExpertTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
        newExpertTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
         AFormDP.HTMLFORM_NAME);
        newExpertTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
         HTMLHIDDEN_EXPERT_SPACE);
        newExpertTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
         JAVASCRIPT_SERVER_EXPERTSUBMIT);
        newExpertTree.AddControlArgument(StartTreeControl.TITLE, GetASOwner().GetString(442,
         "ptmsgs_portalbrowsingmsgs"));
        newExpertTree.AddControlArgument(StartTreeControl.HELP_TOPIC, "PT_SelectLinks_Experts");
        newExpertTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
         GetASOwner().GetString(442, "ptmsgs_portalbrowsingmsgs"));
        newExpertTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
         XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
        newExpertTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         plugInModelRO.GetSelectedUsersString());
        // Submit function
        sb.Append("function ").Append(JAVASCRIPT_SERVER_EXPERTSUBMIT).Append("()\n");
        sb.Append("{\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SiteMapFolderPlugInControl.POSTTOSELF_ACTION_EXPERTTREESUBMIT).Append(");\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
        // Open server user tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JAVASCRIPT_SERVER_EXPERTTREE).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    " + strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'").Append(newExpertTree.GetURLAsString()).Append("\',\'TREE\',400,400,false); return false;\n");
        sb.Append("  } else {\n");
        sb.Append("    " + strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'").Append(oldExpertTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(",\'TREE\',400,400,false); return false;\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // The url to open a previously opened Catalog tree
        // This needs to have the SpaceID added to it.
        ASURL oldDocumentTree = new ASURL(GetASOwner());
        oldDocumentTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, GetASOwner());
        oldDocumentTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
        oldDocumentTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         plugInModelRO.GetSelectedDirItemsAsString());
        oldDocumentTree.IsSubSpace();
        // The URL to open a new server catalog tree
        ASURL newDocumentTree = new ASURL(GetASOwner());
        newDocumentTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, GetASOwner());
        newDocumentTree.SetSubSpaceKey(SiteMapFolderPlugInView.DOCUMENT_TREE_SUBSPACE);
        newDocumentTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        newDocumentTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
        newDocumentTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
         XPConvert.ToString(true));
        newDocumentTree.AddControlArgument(StartTreeControl.SELECT_MODE, XPConvert.ToString(TreeConstants.N_LEAFCOMPOSITESELECT));
        newDocumentTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
        newDocumentTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
         AFormDP.HTMLFORM_NAME);
        newDocumentTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
         HTMLHIDDEN_DOCUMENT_SPACE);
        newDocumentTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
         JAVASCRIPT_SERVER_DOCUMENTSUBMIT);
        newDocumentTree.AddControlArgument(StartTreeControl.TITLE, GetASOwner().GetString(1627,
         "ptmsgs_portalbrowsingmsgs"));
        newDocumentTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
         GetASOwner().GetString(1627, "ptmsgs_portalbrowsingmsgs"));
        newDocumentTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
         XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
        newDocumentTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         plugInModelRO.GetSelectedDirItemsAsString());
        newDocumentTree.AddControlArgument(StartTreeControl.DIRECTORY_MODE,
         DirectoryTreeModel.BROWSE_MODE);
        newDocumentTree.AddControlArgument(StartTreeControl.HELP_TOPIC, "PT_SelectLinks_Documents");
        // Submit function
        sb.Append("function ").Append(JAVASCRIPT_SERVER_DOCUMENTSUBMIT).Append("()\n");
        sb.Append("{\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SiteMapFolderPlugInControl.POSTTOSELF_ACTION_DOCUMENTTREESUBMIT).Append(");\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // Open server user tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JAVASCRIPT_SERVER_DOCUMENTTREE).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    " + strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'").Append(newDocumentTree.GetURLAsString()).Append("\',\'TREE\',400,400,false); return false;\n");
        sb.Append("  } else {\n");
        sb.Append("    " + strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'").Append(oldDocumentTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(",\'TREE\',400,400,false); return false;\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(300);
        // The url to open a previously opened Community Page tree
        // This needs to have the SpaceID added to it.
        ASURL oldCommPageTree = new ASURL(GetASOwner());
        oldCommPageTree.SetLinkCreateNewSpace(ServerTreeAS.STR_MVC_CLASS_NAME,
         GetASOwner());
        oldCommPageTree.SetControl(ServerRefreshTreeControl.STR_MVC_CLASS_NAME);
        oldCommPageTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         plugInModelRO.GetSelectedCommPagesAsString());
        oldCommPageTree.IsSubSpace();
        // The URL to open a new server catalog tree
        ASURL newCommPageTree = new ASURL(GetASOwner());
        newCommPageTree.SetLinkCreateNewSpace(ServerTreeAS.STR_MVC_CLASS_NAME,
         GetASOwner());
        newCommPageTree.SetSubSpaceKey(SiteMapFolderPlugInView.COMMPAGE_TREE_SUBSPACE);
        newCommPageTree.SetControl(ServerStartTreeControl.STR_MVC_CLASS_NAME);
        newCommPageTree.AddControlArgument(ServerStartTreeControl.INTERFACE_TYPE,
         ServerTreeModel.m_nCOMMPAGE_TREE);
        newCommPageTree.AddControlArgument(ServerStartTreeControl.INIT_DATA,
         PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
        //			newCommPageTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        //			newCommPageTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
        newCommPageTree.AddControlArgument(AStartTreeControl.MULTI_SELECT,
         XPConvert.ToString(true));
        newCommPageTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
         XPConvert.ToString(TreeConstants.N_LEAFSELECT));
        newCommPageTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
         XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
        newCommPageTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
         AFormDP.HTMLFORM_NAME);
        newCommPageTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
         HTMLHIDDEN_COMMPAGE_SPACE);
        newCommPageTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
         JAVASCRIPT_SERVER_COMMPAGESUBMIT);
        newCommPageTree.AddControlArgument(AStartTreeControl.TITLE, GetASOwner().GetString(1626,
         "ptmsgs_portalbrowsingmsgs"));
        newCommPageTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE,
         GetASOwner().GetString(1626, "ptmsgs_portalbrowsingmsgs"));
        newCommPageTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         plugInModelRO.GetSelectedCommPagesAsString());
        newCommPageTree.AddControlArgument(StartTreeControl.HELP_TOPIC, "PT_SelectLinks_CommunityPages");
        //			newCommPageTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
        //				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
        // Submit function
        sb.Append("function ").Append(JAVASCRIPT_SERVER_COMMPAGESUBMIT).Append("()\n");
        sb.Append("{\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(SiteMapFolderPlugInControl.POSTTOSELF_ACTION_COMMPAGETREESUBMIT).Append(");\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        // Open server user tree function
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(JAVASCRIPT_SERVER_COMMPAGETREE).Append("(myInput)\n");
        sb.Append("{\n");
        sb.Append("  if (myInput.value == \'\') {\n");
        sb.Append("    " + strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'").Append(newCommPageTree.GetURLAsString()).Append("\',\'TREE\',400,400,false); return false;\n");
        sb.Append("  } else {\n");
        sb.Append("    " + strJSUtilVersionPrefix + "PTWindowUtil.openWindow(\'").Append(oldCommPageTree.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=\' + myInput.value").Append(",\'TREE\',400,400,false); return false;\n");
        sb.Append("  }\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        sb = new XPStringBuilder(200);
        sb.Append("function IsValidFolderName(strString) ");
        sb.Append("{ \n");
        sb.Append("   var bResult = true; \n");
        sb.Append("\n");
        sb.Append("   if (strString.length == 0) return true; \n");
        sb.Append("\n");
        sb.Append("   if (-1 != strString.lastIndexOf(\"\\\\\") || -1 != strString.lastIndexOf(\"\\t\") || -1 != strString.lastIndexOf(\"\\n\")) \n");
        sb.Append("   { \n");
        sb.Append("      bResult = false;\n");
        sb.Append("   }\n");
        sb.Append("   return bResult;\n");
        sb.Append("}\n");
        sb.Append("function " + JAVASCRIPT_CHECKNAVLINKNAME + "()\n");
        sb.Append("{\n");
        XPArrayList arrLinks = ((ISiteMapFolderPlugInModelRO) m_model).GetLinks();
        if (GetASOwner().GetName() == SubPortalAS.STR_MVC_CLASS_NAME && arrLinks.GetSize() != 0)
        {
          sb.Append("  if (document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_FOLDERNAME + ".value == \'\') { \n");
          sb.Append("\t\talert(\"" + m_asOwner.GetString(2552, "ptmsgs_portaladminmsgs") + "\");\n");
          sb.Append("      return false;\n");
          sb.Append("  }\n");
          sb.Append("  if (!IsValidFolderName(document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_FOLDERNAME + ".value)) { \n");
          sb.Append("\t\talert(\"" + m_asOwner.GetString(2553, "ptmsgs_portaladminmsgs") + "\");\n");
          sb.Append("      return false;\n");
          sb.Append("  }\n");
        }
        sb.Append("  return true;\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "FeaturesView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException(GetASOwner().GetString(888, "ptmsgs_portaladminmsgs"),
         e);
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns Java Script for the Delete Section. 
    /// This method should be called if the GetHTMLForDeleteAction() is shown.
    /// </summary>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayDeleteJavascript()
    {
      HTMLScript myScript;
      myScript = new HTMLScript("text/javaScript");
      try
      {
        XPStringBuilder sb = new XPStringBuilder(300);
        // JavaScript to check if any rows have been selected
        sb.Append("function ").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("()\n");
        sb.Append("{ \n");
        sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME + "; \n");
        sb.Append("  var len = frm.elements.length; \n");
        sb.Append("  var i = 0; \n");
        sb.Append("  for(i=0 ; i<len ; i++) \n");
        sb.Append("  { \n");
        sb.Append("    if (frm.elements[i].name.indexOf(\'" + HTMLCHECKBOX_DELROW + "\') >= 0) \n");
        sb.Append("    { \n");
        sb.Append("       if (frm.elements[i].checked)\n");
        sb.Append("    \t  { \n");
        sb.Append("    \t\t return true; \n");
        sb.Append("       } \n");
        sb.Append("    } \n");
        sb.Append("  } \n");
        sb.Append("  return false; \n");
        sb.Append("}\n");
        sb.Append("function ").Append(JAVASCRIPT_DELETE).Append("()\n");
        sb.Append("{\n");
        sb.Append("  if (").Append(JAVASCRIPT_CHECK_OBJECTS_SELECTED).Append("() != true)\n");
        sb.Append("  {\n");
        // And display an error if nothing is selected
        sb.Append("    alert(\'").Append(m_asOwner.GetString(2577, "ptmsgs_portaladminmsgs")).Append("\');\n");
        sb.Append("    return false;\n");
        sb.Append("  }\n");
        sb.Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(\'").Append(SiteMapFolderPlugInControl.POSTTOSELF_ACTION_DELETE).Append("\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
        return myScript;
      }
      catch (Exception e)
      {
        log.Error(e, "SiteMapFolderEditLinksView::DisplayJavascript The following error occured when trying to display the JavaScript: " + e.Message);
        throw new XPException("JS for Delete Action was not Displayed", e);
        }
    }
    
    /// <summary>
    /// GetHTMLForRow
    /// </summary>
    /// <param name="_qrData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement GetHTMLForRow(PTSortedArrayWrapper _arrLinks,
     int _nRowIndex)
    {
      HTMLImg linkImage = null;
      PTConstruct myConstruct;
      String linkName = "";
      PTLink currLink = (PTLink) _arrLinks.GetItem(_nRowIndex, SiteMapLinkContainer.LINK_COLUMN);
      int linkType = currLink.nType;
      switch (linkType){
      case PT_CLASSIDS.PT_USER_ID:
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_USER,
       true, this.GetASOwner());
      linkImage = (HTMLImg) myConstruct.GetHTMLElement();
      linkImage.SetAlt(GetASOwner().GetString(904, "ptmsgs_portalbrowsingmsgs"));
      linkName = currLink.strName;
      break;
      case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_URL,
       true, this.GetASOwner());
      linkImage = (HTMLImg) myConstruct.GetHTMLElement();
      linkImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      linkImage.SetAlt(GetASOwner().GetString(952, "ptmsgs_portalbrowsingmsgs"));
      linkName = currLink.strName;
      break;
      case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER,
       true, this.GetASOwner());
      linkImage = (HTMLImg) myConstruct.GetHTMLElement();
      linkImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      linkImage.SetAlt(GetASOwner().GetString(857, "ptmsgs_portalbrowsingmsgs"));
      linkName = currLink.strName;
      break;
      case PT_CLASSIDS.PT_CATALOGCARD_ID:
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT,
       true, this.GetASOwner());
      linkImage = (HTMLImg) myConstruct.GetHTMLElement();
      linkImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      linkImage.SetAlt(GetASOwner().GetString(184, "ptmsgs_portalbrowsingmsgs"));
      linkName = currLink.strName;
      break;
      case PT_CLASSIDS.PT_COMMUNITY_ID:
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
       true, this.GetASOwner());
      linkImage = (HTMLImg) myConstruct.GetHTMLElement();
      linkImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      linkImage.SetAlt(GetASOwner().GetString(901, "ptmsgs_portalbrowsingmsgs"));
      linkName = currLink.strPageName;
      break;
      }
      HTMLTableCell myCell = new HTMLTableCell();
      try
      {
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetHeight("25");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        if (null != linkImage)
        {
          myCell.AddInnerHTMLElement(linkImage);
        }
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLEncodedString(linkName);
      }
      catch (HTMLException e)
      {
        log.Error(e.Message);
      }
      return myCell;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    public virtual HTMLTable GetHTMLForActionBar(int nRowCount)
    {
      ISiteMapFolderPlugInModelRO plugInModelRO = (ISiteMapFolderPlugInModelRO) m_model;
      bool bIsSiteMapPage = GetASOwner().GetName().Equals(SiteMapAS.STR_MVC_CLASS_NAME);
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myTable = new HTMLTable();
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      // 1st Row begin (there is only one row)
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      if (bIsSiteMapPage)
      {
        myRow.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_BG);
      } else
      {
        myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      }
      // Add icon cell
      myRow.AddInnerHTMLElement(GetHTMLForAddWebLinkAction());
      // Empty Cell
      if (!bIsSiteMapPage)
      {
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      }
      // Add icon cell
      myRow.AddInnerHTMLElement(GetHTMLForAddExpertAction());
      // Empty Cell
      if (!bIsSiteMapPage)
      {
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      }
      if (plugInModelRO.IsDirectoryEnabled())
      {
        // Add icon cell
        myRow.AddInnerHTMLElement(GetHTMLForAddDocumentAction());
        // Empty Cell
        if (!bIsSiteMapPage)
        {
          myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        }
      }
      if (plugInModelRO.AreCommunitiesEnabled())
      {
        // Add icon cell
        myRow.AddInnerHTMLElement(GetHTMLForAddCommPageAction());
        // Empty Cell
        if (!bIsSiteMapPage)
        {
          myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        }
      }
      if (nRowCount != 0)
      {
        if (GetASOwner().GetName() == SubPortalAS.STR_MVC_CLASS_NAME || GetASOwner().GetName() == SiteMapPortletPrefsEditorAS.STR_MVC_CLASS_NAME)
        {
          // Add Localized Name icon cell
          myRow.AddInnerHTMLElement(GetHTMLForAddLocalizedNameAction());
          // Empty Cell
          myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
        }
        // Delete icon cell
        myRow.AddInnerHTMLElement(GetHTMLForDeleteAction());
        // Empty Cell
        myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());
      }
      if (((ISiteMapFolderPlugInModelRO) m_model).IsDuplicated())
      {
        myRow.AddInnerHTMLElement(GetHTMLForDetachAction());
      }
      // Last Empty Cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetHeight("25");
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // 1st Row ends
      return myTable;
    }
    protected virtual HTMLTableCell GetHTMLForDetachAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Detach icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_UNLOCK,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(GetASOwner().GetString(1517, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + SiteMapFolderPlugInControl.POSTTOSELF_ACTION_DETACH + "); return false;");
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(GetASOwner().GetString(1517, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAddWebLinkAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.GetASOwner());
      myAddImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAddImage.SetAlt("");
      myAddImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // Web Link icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_URL,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(GetASOwner().GetString(529, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(JAVASCRIPT_CREATELINKS + "(); return false;");
      myAnchor.AddInnerHTMLElement(myAddImage);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(GetASOwner().GetString(529, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAddExpertAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.GetASOwner());
      myAddImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAddImage.SetAlt("");
      myAddImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // User icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_USER,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(GetASOwner().GetString(442, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      ////// Community Tree Control
      // Hidden input for the Space ID for the tree.  That way if you hit the folder
      // tree link twice, it will open the same tree both times.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_EXPERT_SPACE,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((ISiteMapFolderPlugInModelRO) m_model).GetExpertSubSpaceID());
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(JAVASCRIPT_SERVER_EXPERTTREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_EXPERT_SPACE + "); return false;");
      myAnchor.AddInnerHTMLElement(myAddImage);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(GetASOwner().GetString(442, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAddDocumentAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.GetASOwner());
      myAddImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAddImage.SetAlt("");
      myAddImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // Document icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(GetASOwner().GetString(1495, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // Hidden input for the Space ID for the tree.  That way if you hit the folder
      // tree link twice, it will open the same tree both times.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_DOCUMENT_SPACE,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((ISiteMapFolderPlugInModelRO) m_model).GetDocumentSubSpaceID());
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(JAVASCRIPT_SERVER_DOCUMENTTREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_DOCUMENT_SPACE + "); return false;");
      myAnchor.AddInnerHTMLElement(myAddImage);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(GetASOwner().GetString(1495, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAddCommPageAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.GetASOwner());
      myAddImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAddImage.SetAlt("");
      myAddImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // Community icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(GetASOwner().GetString(1496, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      ////// Community Tree Control
      // Hidden input for the Space ID for the tree.  That way if you hit the folder
      // tree link twice, it will open the same tree both times.
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_COMMPAGE_SPACE,
       "");
      myCell.AddInnerHTMLElement(myInput);
      myInput.SetValue(((ISiteMapFolderPlugInModelRO) m_model).GetCommPageSubSpaceID());
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(JAVASCRIPT_SERVER_COMMPAGETREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_COMMPAGE_SPACE + "); return false;");
      myAnchor.AddInnerHTMLElement(myAddImage);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(GetASOwner().GetString(1496, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the add cell in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForAddLocalizedNameAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLImg myAddImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, this.GetASOwner());
      myAddImage = (HTMLImg) myConstruct.GetHTMLElement();
      myAddImage.SetAlt("");
      myAddImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      // Web Link icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_LOCALE_SETTINGS,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(GetASOwner().GetString(529, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      ASURL editNameURL = new ASURL(m_asOwner);
      editNameURL.SetLinkCreateNewSpace(SiteMapFolderEditorAS.STR_MVC_CLASS_NAME,
       m_asOwner);
      editNameURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
      editNameURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_EDIT);
      editNameURL.AddControlArgument(SiteMapFolderModel.EDITOR_QS_INT_CLASS_ID,
       PT_CLASSIDS.PT_SITEMAPFOLDER_ID);
      editNameURL.AddControlArgument(SiteMapFolderModel.QS_NAMEORSECURITY,
       
      // DCA - only show name and security page
      SiteMapFolderModel.EDIT_TYPE_NAME_DESC);
      editNameURL.AddControlArgument(SiteMapFolderModel.QS_LOCALIZEDNAME,
       
      // DCA - do not show security page
      1);
      editNameURL.AddControlArgument(SiteMapFolderModel.EDITOR_QS_INT_QS_OBJECT_ID,
       ((ISiteMapFolderPlugInModelRO) m_model).GetObjectID());
      editNameURL.SetSubSpaceKey(STR_MVC_CLASS_NAME);
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("OpenLargePreviewWindow(\'" + editNameURL.GetURLAsString() + "\');return false;");
      myAnchor.AddInnerHTMLElement(myAddImage);
      myAnchor.AddInnerHTMLElement(myImage);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      // Add label
      mySpan.AddInnerHTMLString(GetASOwner().GetString(1739, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the checkbox on row _nRowIndex.
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLTableCell GetHTMLForCheckBox(PTLink link)
    {
      HTMLTableCell myCell;
      HTMLInput myInput;
      int nUniqueID;
      if (link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID)
      {
        nUniqueID = link.nObjectID;
      } else
      if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID)
      {
        nUniqueID = link.nPageID;
      } else
      {
        nUniqueID = link.nLinkObjectID;
      }
      myCell = new HTMLTableCell();
      myCell.SetWidth("20");
      myCell.SetHeight("30");
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      // checkbox
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_DELROW,
       GetASOwner().GetString(531, "ptmsgs_portalbrowsingmsgs"));
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetValue(link.nType + "," + nUniqueID);
      myCell.AddInnerHTMLElement(myInput);
      return (myCell);
    }
    
    /// <summary>
    /// Returns the HTML for the delete cell in the action bar. 
    /// If you call this method, it is necessary to add DisplayDeleteJavascript() to the DP.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForDeleteAction()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      // Delete icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_REMOVE,
       true, this.GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick(JAVASCRIPT_DELETE + "(); return false;");
      myAnchor.AddInnerHTMLElement(myImage);
      myCell.AddInnerHTMLElement(myAnchor);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Helper method for empty cell between actions
    /// in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForEmptyCellInActionBar()
    {
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER, true,
       GetASOwner());
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetWidth(CommonHTMLStrings.ONE);
      myImage.SetHeight(CommonHTMLStrings.ONE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myCell.AddInnerHTMLElement(myImage);
      return myCell;
    }
    
    /// <summary>
    /// Returns the HTML for the sub header.
    /// </summary>
    /// <returns>HTMLTableRow</returns>
    /// <throws>Exception</throws>
    public virtual HTMLTableRow GetHTMLForNameRow()
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      // Row 1 - Cell 1 - input box for the site map folder name
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetNoWrap(true);
      myCell.SetColSpan("2");
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
      mySpan.AddInnerHTMLString(GetASOwner().GetString(1488, "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLElement(mySpan);
      myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_FOLDERNAME, GetASOwner().GetString(1488,
       "ptmsgs_portalbrowsingmsgs"));
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      myInput.SetSize("30");
      myInput.SetMaxLength("63");
      myInput.SetValue(((ISiteMapFolderPlugInModelRO) m_model).GetPTObject().GetLocalizedName());
      myCell.AddInnerHTMLElement(myInput);
      return myRow;
    }
    
    /// <summary>
    /// Returns the HTML for the sub header.
    /// </summary>
    /// <returns>HTMLTableRow</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableRow GetHTMLForSubHeader()
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      // Row 1 - Cell 1 - checkbox
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      myCell = new HTMLTableCell();
      myCell.SetColSpan(CommonHTMLStrings.TWO);
      myRow.AddInnerHTMLElement(myCell);
      //myCell.SetWidth("20");
      //myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      // checkbox
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_CHECKALL,
       GetASOwner().GetString(530, "ptmsgs_portalbrowsingmsgs"));
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetOnClick("CheckRows();");
      myCell.AddInnerHTMLElement(myInput);
      return myRow;
    }
  }
}