using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.browsing.editors.smartsort
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Smart Sort Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>OlegS</author>
  public class SmartSortEditorAS : ObjEditorAS
  {
    public const String STR_MVC_CLASS_NAME = "SmartSortEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SmartSortEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
      {
        return (GetString(551, "ptmsgs_portalbrowsingmsgs"));
      } else
      {
        return (XPResourceManager.FormatMessage(GetString(1709, "ptmsgs_portalbrowsingmsgs"),
         GetObjectName()));
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Smart Sort Editor Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SmartSortEditorRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SmartSortEditorModel.STR_MVC_CLASS_NAME;
      // Warning: m_myModel must be initialized before super.Init() is called.
      base.Init();
      /* job is auto created
       // Register plug-in sections
       RegisterPage(new SetJobDP());
       
       // Register classes for the set job and for the object owner
       RegisterModel(SetJobModel.STR_MVC_CLASS_NAME);
       RegisterControl(SetJobRepostControl.STR_MVC_CLASS_NAME,GetModel(SetJobModel.STR_MVC_CLASS_NAME));
       RegisterView(ObjectOwnerView.STR_MVC_CLASS_NAME,GetModel(SetJobModel.STR_MVC_CLASS_NAME));
       
       // Register classes for Job selector
       RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
       SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB);
       RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
       SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
       GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
       RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
       SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
       GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
       */
       
      IModel myModel = GetModel(SmartSortEditorModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      RegisterPage(new SmartSortEditorMainDP());
      // Register Views
      RegisterView(SmartSortEditorMainView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(SmartSortEditorRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      // (It will be the page selected by default when the user starts the Editor).
      SetCurrentPage(SmartSortEditorMainDP.STR_MVC_CLASS_NAME);
      // set left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(553, "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SmartSortEditorMainDP.STR_MVC_CLASS_NAME);
      /* job is auto created
       m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SetJobDP.STR_MVC_CLASS_NAME);
       */
       
      // BEGIN Sub menu "Standard Settings"
      int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1242, "ptmsgs_portalbrowsingmsgs"));
      //Properties and Names
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
      //Security
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
      //Migration History
      m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
      // END Sub menu "Standard Settings"
      // END Sub menu "Properties"
      this.SetHelpTopic("PT_Smartsort_MainSettings");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SmartSortEditorMainDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_SmartSort_MainSettings");
      }
    }
  }
}
/* job is auto created
 else if(SetJobDP.STR_MVC_CLASS_NAME.equals(sPageName))
 SetHelpTopic("PT_SetJob");
 */
 
