using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portalpages.common.objects.sort;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.smartsort
{
  /// <summary>
  /// This Section contains the HTML for the Smart Sort Editor.
  /// This Section is printed out by SmartSortEditorMainDP.
  /// </summary>
  /// <author>OlegS</author>
  public class SmartSortEditorMainView : EditorView,IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.smartsort.SmartSortEditorMainView");
    public const String STR_MVC_CLASS_NAME = "SmartSortEditorMain";
    // +group, value is folder id or -1 for all
    public const String HTMLCHECKBOX_FOLDER = "in_cb_folder_";
    public const String HTMLCHECKBOX_RECOURSIVE = "in_cb_recoursive";
    public const String HTMLCHECKBOX_MOVE = "in_cb_move";
    public const String HTMLCHECKBOX_APPROVE = "in_cb_approve";
    public const String HTMLCHECKBOX_FILTER = "in_cb_filter";
    public const String HTMLHIDDEN_SPACEID = "in_hi_CatalogFolderSpaceID";
    public const String HTMLHIDDEN_TREEREPOST = "in_hi_CatalogFolderRepostAction";
    // +group
    public const String HTMLHIDDEN_CHECKALL_CNT = "in_hi_checkall_";
    public const String JAVASCRIPT_CATALOGFOLDERTREE = "openCatalogFolderTree";
    public const String JAVASCRIPT_CHECKALLFOLDERS = "checkAllFolderRows";
    
    /// <summary>
    /// A name for the sub activity space for the admin folder tree 
    /// </summary>
    public const String DESTINATION_FOLDERTREESPACE = "FolderTreeDestination";
    public const String SOURCE_FOLDERTREESPACE = "FolderTreeSource";
    protected static readonly Spacer spacer15 = new Spacer("15");
    // member variables
    protected PTStyleClass m_styleListItem = null;
    
    /// <param name="type"></param>
    /// <param name="alt"></param>
    /// <param name="w"></param>
    /// <param name="h"></param>
    /// <returns></returns>
    public virtual HTMLImg GetImage(PTImageType type, String alt, String w,
     String h)
    {
      try
      {
        PTConstruct myConstruct = UIConstructFactory.GetConstruct(type, true,
         this.m_asOwner);
        HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();
        myImg.SetAlt(alt);
        myImg.SetBorder("0");
        myImg.SetWidth(w);
        myImg.SetHeight(h);
        return myImg;
      }
      catch (Exception e)
      {
        log.Error(e, "SmartSortEditorMainView.GetImage couldn\'t get image: " + e.Message);
        throw new XPException(m_asOwner.GetString(562, "ptmsgs_portalbrowsingmsgs") + " (Image)",
         e);
      }
    }
    // Strings to localize.
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SmartSortEditorMainView();
    }
    
    /// <returns></returns>
    public override HTMLElement Display()
    {
      try
      {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLComment myComment = new HTMLComment("Begin: Display SmartSortEditorMainView");
        result.AddInnerHTMLElement(myComment);
        DisplayHiddenInputs(result);
        // source folders
        int group = SmartSortEditorModel.SOURCE_FOLDER_GROUP;
        DisplayObjectHeader(result, m_asOwner.GetString(557, "ptmsgs_portalbrowsingmsgs"));
        DisplayActionBar(result, group);
        DisplayFolderList(result, group);
        spacer15.display(result);
        DisplaySrcOptions(result);
        DisplayBreak(result);
        // destination folders
        group = SmartSortEditorModel.DESTINATION_FOLDER_GROUP;
        DisplayObjectHeader(result, m_asOwner.GetString(558, "ptmsgs_portalbrowsingmsgs"));
        DisplayActionBar(result, group);
        DisplayFolderList(result, group);
        spacer15.display(result);
        DisplayDstOptions(result);
        myComment = new HTMLComment("End: Display SmartSortEditorMainView");
        result.AddInnerHTMLElement(myComment);
        return result;
      }
      catch (Exception e)
      {
        log.Error("SmartSortEditorMainView::Display The following error occured when trying to display the HTML: " + /*.getMessage()*/
        e);
        throw new XPException(m_asOwner.GetString(562, "ptmsgs_portalbrowsingmsgs"),
         e);
      }
    }
    
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      try
      {
        myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(m_asOwner,
         DESTINATION_FOLDERTREESPACE, HTMLHIDDEN_SPACEID, HTMLHIDDEN_TREEREPOST,
         m_asOwner.GetString(560, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(565,
         "ptmsgs_portalbrowsingmsgs"), PT_CLASSIDS.PT_CATALOGFOLDER_ID, PT_INTRINSICS.PT_FOLDER_ROOTFOLDER,
         TreeConstants.N_COMPOSITESELECT, true, true, null, GetModel().makeListOfDestinationFoldersAlreadyShown()));
        myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(m_asOwner,
         SOURCE_FOLDERTREESPACE, HTMLHIDDEN_SPACEID, HTMLHIDDEN_TREEREPOST,
         m_asOwner.GetString(560, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(565,
         "ptmsgs_portalbrowsingmsgs"), PT_CLASSIDS.PT_CATALOGFOLDER_ID, PT_INTRINSICS.PT_FOLDER_ROOTFOLDER,
         TreeConstants.N_COMPOSITESELECT, true, true, null, GetModel().makeListOfSourceFoldersAlreadyShown()));
        XPStringBuilder sb = new XPStringBuilder(300);
        // JavaScript to check all the rows
        sb.Append("function " + JAVASCRIPT_CHECKALLFOLDERS + "(item, group)\n");
        sb.Append("{ \n");
        sb.Append("  var checkBoxes = document.getElementsByName(item.name); \n");
        sb.Append("  var counter = document.getElementById(\'" + HTMLHIDDEN_CHECKALL_CNT + "\'+group); \n");
        sb.Append("\n");
        sb.Append("\t if (-1 == counter.value)\t// first time, initialize\n");
        sb.Append("\t {\n");
        sb.Append("\t   counter.value=0;\n");
        sb.Append("\t   for(i = 0; i < checkBoxes.length; i++)\n");
        sb.Append("\t   {\n");
        sb.Append("\t\t if(checkBoxes[i].checked)\n");
        sb.Append("\t\t   counter.value++;\n");
        sb.Append("\t   }\n");
        sb.Append("\t }\n");
        sb.Append("\n");
        sb.Append("  if (-1==item.value) /*checkall*/ \n");
        sb.Append("  { \n");
        sb.Append("    for(i=0 ; i<checkBoxes.length; i++) \n");
        sb.Append("    { \n");
        sb.Append("      checkBoxes[i].checked = item.checked;\n");
        sb.Append("    } \n");
        sb.Append("\n");
        sb.Append("    if(item.checked) \n");
        sb.Append("    { \n");
        sb.Append("    \t counter.value = checkBoxes.length;\n");
        sb.Append("    }\n");
        sb.Append("    else\n");
        sb.Append("    {\n");
        sb.Append("      counter.value = 1;\n");
        sb.Append("    }\n");
        sb.Append("  } \n");
        sb.Append("  else\n");
        sb.Append("  {\n");
        sb.Append("    if(item.checked)\n");
        sb.Append("      counter.value++;\n");
        sb.Append("    else\n");
        sb.Append("      counter.value--;\n");
        sb.Append("  }\n");
        sb.Append("\n");
        sb.Append("document.getElementById(\'" + HTMLCHECKBOX_FOLDER + "\'+group+\'all\').checked = (counter.value==checkBoxes.length);\n");
        sb.Append("\n");
        sb.Append("return true;");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "SmartSortEditorMainView.DisplayJavascript couldn\'t add javascript to the HTMLScript element: " + e.Message);
        throw new XPException(m_asOwner.GetString(562, "ptmsgs_portalbrowsingmsgs") + " (Javascript)",
         e);
      }
      return myScript;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="result"></param>
    /// <param name="group"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayActionBar(HTMLElementCollection result,
     int group)
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLAnchor myAnchor;
      HTMLImg myImg;
      HTMLComment myComment = new HTMLComment("Begin: DisplayActionBar SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("0");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      // add folder		
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();
      if (SmartSortEditorModel.SOURCE_FOLDER_GROUP == group)
      {
        myAnchor = TreeHelper.makeTreeAnchor(SOURCE_FOLDERTREESPACE, HTMLHIDDEN_SPACEID,
         SmartSortEditorRepostControl.ACTION_ADD + SmartSortEditorRepostControl.GROUP_SHIFT * group,
         strLang);
      } else
      {
        myAnchor = TreeHelper.makeTreeAnchor(DESTINATION_FOLDERTREESPACE,
         HTMLHIDDEN_SPACEID, SmartSortEditorRepostControl.ACTION_ADD + SmartSortEditorRepostControl.GROUP_SHIFT * group,
         strLang);
      }
      myCell.AddInnerHTMLElement(myAnchor);
      myImg = GetImage(PTImageType.ACTION_ADD, m_asOwner.GetString(560, "ptmsgs_portalbrowsingmsgs"),
       "6", "25");
      myImg.SetAlign("absMiddle");
      myAnchor.AddInnerHTMLElement(myImg);
      myImg = GetImage(PTImageType.ICON_FOLDER, m_asOwner.GetString(565, "ptmsgs_portalbrowsingmsgs"),
       "18", "20");
      myImg.SetAlign("absMiddle");
      myAnchor.AddInnerHTMLElement(myImg);
      myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mySpan = new HTMLSpan();
      myAnchor.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      mySpan.AddInnerHTMLString(m_asOwner.GetString(560, "ptmsgs_portalbrowsingmsgs") + "&nbsp;" + "&nbsp;");
      // divider
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
      myImg = GetImage(PTImageType.SPACER, "", "1", "1");
      myCell.AddInnerHTMLElement(myImg);
      // delete folder	
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.SetNoWrap(true);
      // mj: replaced the following line with a blank constructur and SetOnClick()
      // myAnchor = new HTMLAnchor("postToSelf(" +
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("postToSelf(" + ((SmartSortEditorRepostControl.GROUP_SHIFT * group) + SmartSortEditorRepostControl.ACTION_DEL) + "); return false;");
      myCell.AddInnerHTMLElement(myAnchor);
      myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myImg = GetImage(PTImageType.ACTION_DELETE, m_asOwner.GetString(559,
       "ptmsgs_portalbrowsingmsgs"), "25", "25");
      myImg.SetAlign("absMiddle");
      myAnchor.AddInnerHTMLElement(myImg);
      // divider
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
      myImg = GetImage(PTImageType.SPACER, "", "1", "1");
      myCell.AddInnerHTMLElement(myImg);
      // last
      myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetWidth("100%");
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myRow.AddInnerHTMLElement(myCell);
      myComment = new HTMLComment("End: DisplayActionBar SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
    }
    
    /// <param name="result"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayBreak(HTMLElementCollection result)
    {
      result.AddInnerHTMLElement(new HTMLBr());
    }
    
    /// <param name="result"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayDstOptions(HTMLElementCollection result)
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLComment myComment = new HTMLComment("Begin: DisplayDstOptions SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_APPROVE,
       "");
      myInput.SetChecked(GetModel().GetSetting(PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_ADD_CARDS_TO_FOLDERS_APPROVED));
      myInput.SetValue("1");
      myCell.AddInnerHTMLElement(myInput);
      myCell.AddInnerHTMLString(m_asOwner.GetString(569, "ptmsgs_portalbrowsingmsgs"));
      myCell.AddInnerHTMLElement(new HTMLBr());
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_FILTER,
       "");
      // checkbox displays inverted setting
      myInput.SetChecked(!GetModel().GetSetting(PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_ONLY_APPLY_SUBFOLDER_FILTERS));
      myInput.SetValue("1");
      myCell.AddInnerHTMLElement(myInput);
      myCell.AddInnerHTMLString(m_asOwner.GetString(570, "ptmsgs_portalbrowsingmsgs"));
      myComment = new HTMLComment("End: DisplayDstOptions SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
    }
    
    /// <param name="result"></param>
    /// <param name="group"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayFolderList(HTMLElementCollection result,
     int group)
    {
      HTMLTable myTable;
      HTMLComment myComment = new HTMLComment("Begin: DisplayFolderList SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("0");
      myTable.SetCellSpacing("2");
      // items
      Object[] folderIDs = GetModel().GetFolderIDs(group);
      PTObjectIdNamePair[] folderIdNamePairs = SortObjectByName(folderIDs,
       GetModel().GetSortAscending(group));
      if ((folderIdNamePairs == null) || (folderIdNamePairs.Length == 0))
      {
        DisplayRowForEmptyList(myTable);
      } else
      {
        m_styleListItem = null;
        DisplayFolderListHeader(myTable, group);
        for (int i = 0;i < folderIdNamePairs.Length;i++)
        {
          int folderId = folderIdNamePairs[i].id;
          String folderName = (folderIdNamePairs[i].name == null) ? GetFolderName(folderId) : folderIdNamePairs[i].name;
          DisplayFolderListItem(myTable, group, folderId, folderName);
        }
      }
      myComment = new HTMLComment("End: DisplayFolderList SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
    }
    
    /// <param name="myTable"></param>
    /// <param name="group"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayFolderListHeader(HTMLTable myTable, int group)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLAnchor myAnchor;
      HTMLImg myImg;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetWidth("20");
      myCell.SetVAlign("center");
      myCell.SetAlign("middle");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      String sInputName = HTMLHIDDEN_CHECKALL_CNT + XPConvert.ToString(group);
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, sInputName, "");
      myInput.SetID(sInputName);
      myInput.SetValue("-1");
      myCell.AddInnerHTMLElement(myInput);
      sInputName = HTMLCHECKBOX_FOLDER + XPConvert.ToString(group);
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, sInputName, m_asOwner.GetString(563,
       "ptmsgs_portalbrowsingmsgs"));
      myInput.SetID(sInputName + "all");
      // all
      myInput.SetValue("-1");
      // checkall
      myInput.SetOnClick(JAVASCRIPT_CHECKALLFOLDERS + "(this, \'" + XPConvert.ToString(group) + "\');");
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myCell.AddInnerHTMLElement(myInput);
      myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      myRow.AddInnerHTMLElement(myCell);
      // mj: replaced the following line with a blank constructur and SetOnClick()
      // myAnchor = new HTMLAnchor("postToSelf(" +
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      myAnchor.SetOnClick("postToSelf(" + ((SmartSortEditorRepostControl.GROUP_SHIFT * group) + SmartSortEditorRepostControl.ACTION_SORT) + "); return false;");
      myAnchor.AddInnerHTMLString(m_asOwner.GetString(561, "ptmsgs_portalbrowsingmsgs"));
      myCell.AddInnerHTMLElement(myAnchor);
      myImg = GetImage(GetModel().GetSortAscending(group) ? PTImageType.ICON_ARROW_DESCEND : PTImageType.ICON_ARROW_ASCEND,
       m_asOwner.GetString(566, "ptmsgs_portalbrowsingmsgs"), "11", "20");
      myImg.SetAlign("absMiddle");
      myAnchor.AddInnerHTMLElement(myImg);
    }
    
    /// <param name="myTable"></param>
    /// <param name="group"></param>
    /// <param name="id"></param>
    /// <param name="name"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayFolderListItem(HTMLTable myTable, int group,
     int id, String name)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLImg myImg;
      myRow = new HTMLTableRow();
      m_styleListItem = ((m_styleListItem == null) || (m_styleListItem == PTStyleClass.LIST_ITEM_ONE_BG)) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG;
      myRow.SetStyleClass(m_styleListItem);
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myCell.SetWidth("20");
      myCell.SetVAlign("center");
      myCell.SetAlign("middle");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myRow.AddInnerHTMLElement(myCell);
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_FOLDER + XPConvert.ToString(group),
       m_asOwner.GetString(564, "ptmsgs_portalbrowsingmsgs") + " \"" + name + "\"");
      myInput.SetChecked(false);
      myInput.SetValue(XPConvert.ToString(id));
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetOnClick(JAVASCRIPT_CHECKALLFOLDERS + "(this, \'" + XPConvert.ToString(group) + "\');");
      myCell.AddInnerHTMLElement(myInput);
      myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("20");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myRow.AddInnerHTMLElement(myCell);
      // mj: replaced the following line with a blank constructur and SetOnClick()
      // myAnchor     = new HTMLAnchor("postToSelf(" +
      myImg = GetImage(PTImageType.ICON_FOLDER, m_asOwner.GetString(565, "ptmsgs_portalbrowsingmsgs"),
       "18", "20");
      myImg.SetAlign("absMiddle");
      myCell.AddInnerHTMLElement(myImg);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(name));
    }
    
    /// <param name="result"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayHiddenInputs(HTMLElementCollection result)
    {
      HTMLInput myInput;
      // Hidden input for the Space ID for the tree.  That way if you hit the folder
      // tree link twice, it will open the same tree both times.
      // olegs: cool but dangerous; if you restart server you get a blank tree window
      // due to null root pointer in TreeCompositeIterator.<init>
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_SPACEID, "");
      result.AddInnerHTMLElement(myInput);
      myInput.SetValue((GetModel().GetLastTreeSpaceId() == null) ? "" : GetModel().GetLastTreeSpaceId());
      // hidden input to hold repost action on tree submit
      myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_TREEREPOST,
       "");
      result.AddInnerHTMLElement(myInput);
      myInput.SetValue("");
    }
    
    /// <param name="result"></param>
    /// <param name="name"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayObjectHeader(HTMLElementCollection result,
     String name)
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLComment myComment = new HTMLComment("Begin: DisplayObjectHeader SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("0");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetHeight("20");
      myCell.SetVAlign("center");
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
      mySpan.AddInnerHTMLString(name);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("10");
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myComment = new HTMLComment("End: DisplayObjectHeader SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
    }
    
    /// <param name="myTable"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayRowForEmptyList(HTMLTable myTable)
    {
      HTMLTableRow myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      HTMLTableCell myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetStyleClass(PTStyleClass.TIPS_TEXT);
      HTMLP myParagraph = new HTMLP();
      myCell.AddInnerHTMLElement(myParagraph);
      HTMLSpan mySpan = new HTMLSpan();
      myParagraph.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
      mySpan.AddInnerHTMLString(GetModel().GetEmptyListMainMessage());
      myParagraph.AddInnerHTMLElement(new HTMLBr());
      myParagraph.AddInnerHTMLString(GetModel().GetEmptyListInstructions());
      }
    
    /// <param name="result"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplaySrcOptions(HTMLElementCollection result)
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLComment myComment = new HTMLComment("Begin: DisplaySrcOptions SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
      myTable = new HTMLTable();
      result.AddInnerHTMLElement(myTable);
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth("100%");
      myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_RECOURSIVE,
       "");
      myInput.SetChecked(GetModel().GetSetting(PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_TAXONOMIZE_FOLDER_BRANCH));
      myInput.SetValue("1");
      myCell.AddInnerHTMLElement(myInput);
      myCell.AddInnerHTMLString(m_asOwner.GetString(567, "ptmsgs_portalbrowsingmsgs"));
      myCell.AddInnerHTMLElement(new HTMLBr());
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_MOVE,
       "");
      myInput.SetChecked(GetModel().GetSetting(PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_REMOVE_CARDS_FROM_PRESENT_LOCATION));
      myInput.SetValue("1");
      myCell.AddInnerHTMLElement(myInput);
      myCell.AddInnerHTMLString(m_asOwner.GetString(568, "ptmsgs_portalbrowsingmsgs"));
      myComment = new HTMLComment("End: DisplaySrcOptions SmartSortEditorMainView");
      result.AddInnerHTMLElement(myComment);
    }
    
    /// <param name="id"></param>
    /// <returns></returns>
    protected virtual String GetFolderName(int id)
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTFolder ptFolder = ptSession.GetCatalog().OpenFolder(id, false);
      return ptFolder.GetLocalizedName();
    }
    
    /// <returns></returns>
    protected virtual ISmartSortEditorModelRO GetModel()
    {
      return (ISmartSortEditorModelRO) m_model;
    }
    
    /// <param name="ids"></param>
    /// <param name="ascending"></param>
    /// <returns></returns>
    protected virtual PTObjectIdNamePair[] SortObjectByName(Object[] ids,
     bool ascending)
    {
      if (ids == null)
      {
        return null;
      }
      XPArrayList pairs = new XPArrayList(ids.Length);
      for (int i = 0;i < ids.Length;i++)
      {
        int folderId = XPConvert.ToInteger(ids[i]);
        pairs.Add(new PTObjectIdNamePair(folderId));
      }
      XPCollections.Sort(pairs, new PTObjectNameComparator((IPTObjectNameGetter) new PTFolderObjectNameGetter(),
       (IPTSession) m_asOwner.GetUserSession(), ascending));
      // (fails on .NET, replaced below) return (PTObjectIdNamePair[]) pairs.ToArray(result);
      PTObjectIdNamePair[] result = new PTObjectIdNamePair[ids.Length];
      for (int i = 0;i < ids.Length;i++)
      {
        result[i] = (PTObjectIdNamePair) pairs.GetElement(i);
      }
      return result;
    }
  }
}
// we don't change source array, but if we wantewd to:
// for(int i=0; i<ids.length; i++)	ids[i]=new Integer(pairs[i].id);
