using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.userprofile
{
  /// <author>
  /// jennifersu
  /// This is the General Info Section display that dynamically draws all Profile
  /// Sections
  /// </author>
  public class GeneralInfoView : ObjPropEditView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.editors.userprofile.GeneralInfoView");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GeneralInfo";
    
    /// <summary>
    /// JavaScript function to add or remove a property value. 
    /// </summary>
    private const String JAVASCRIPT_UP_ADD_REMOVE_PROPERTY_VALUE = "addUPRemovePropertyValue";
    public const String HTMLHIDDEN_PROPERTYINDEX = "in_hi_PropertyIndex";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new GeneralInfoView();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// GetHTMLForActionBar
    /// </summary>
    protected override HTMLTable GetHTMLForActionBar()
    {
      return null;
    }
    
    /// <returns></returns>
    protected override HTMLTable GetHTMLBelowActionBar()
    {
      return null;
    }
    
    /// <returns></returns>
    protected override HTMLTableRow GetHTMLForSubHeader()
    {
      return new HTMLTableRow();
    }
    
    /// <summary>
    /// Helper method to determine whether or not row is visible.  This method
    /// is used by Display().  This method overrides the default behavior of
    /// the ExpListView, where all rows are visible.
    /// The name and description rows are NOT hidden as it is in the parent class's 
    /// ObjPropEditView::CheckRowIsVisible().
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>True if row should be displayed, otherwise false.</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#CheckRowIsVisible(int)"></seealso>
    protected override bool CheckRowIsVisible(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      // Display the row if the property is visible and the row has not been deleted.
      if ((iOPModel.CheckRowIsVisible(_nRowIndex)) && (ObjPropModel.ROW_STATUS_DELETED != iOPModel.GetRowStatus(_nRowIndex)))
      {
        return true;
      } else
      {
        return false;
      }
    }
    
    /// <summary>
    /// Returns HTML for display date/time value
    /// </summary>
    /// <param name="_nRowIndex"></param>
    /// <returns>
    /// HTML for date value
    /// public JSDateTimePicker(String _strFormName, XPDateTime _dtDefaultDateTime, ComponentMgr _ptComponentMgr, String _strUniqueInstanceID)
    /// </returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLForDate(int _nRowIndex)
    {
      UserProfileObjEditModel model = (UserProfileObjEditModel) m_model;
      String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
      PageMgr myPageMgr = new PageMgr(m_asOwner.GetAccessStyle(), PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
       PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner),
       strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      Object value = model.GetRowValue(_nRowIndex);
      String strUniqueKey = model.GetUniqueDateTimePickerKey(_nRowIndex);
      ADatePickerComponent datePicker = (ADatePickerComponent) myPageMgr.AddPageControl("DateTimePicker");
      datePicker.Init(AFormDP.HTMLFORM_NAME, (XPDateTime) value, myPageMgr,
       strUniqueKey);
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(datePicker.GetComponentHTML());
      return result;
    }
    
    /// <summary>
    /// Returns table cell for adding a value or deleting a value.
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Table cell for action</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForRowAction(int _nRowIndex)
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLTableCell myCell;
      HTMLAnchor myAnchor;
      myCell = new HTMLTableCell();
      myCell.SetHeight(m_strRowHeight);
      myCell.SetWidth("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      // Get cell containing add or remove button
      if (!iOPModel.CheckRowIsReadOnly(_nRowIndex))
      {
        if (CheckRowIsFirstForProperty(_nRowIndex) && iOPModel.CheckRowIsMultiValued(_nRowIndex))
        {
          if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
          {
            myAnchor = GetAddAnchor(_nRowIndex);
            myCell.AddInnerHTMLElement(myAnchor);
          } else
          {
            HTMLElementCollection addCollection = Get508AddSubmit(_nRowIndex);
            myCell.AddInnerHTMLElement(addCollection);
          }
        } else
        if (CheckRowIsRemovable(_nRowIndex))
        {
          if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
          {
            myAnchor = GetDeleteAnchor(_nRowIndex);
            myCell.AddInnerHTMLElement(myAnchor);
          } else
          {
            HTMLElementCollection removeCollection = Get508RemoveSubmit(_nRowIndex);
            myCell.AddInnerHTMLElement(removeCollection);
          }
        }
      }
      return myCell;
    }
    protected virtual HTMLElementCollection Get508AddSubmit(int _nRowIndex)
    {
      HTMLElementCollection addCollection = new HTMLElementCollection();
      HTMLInput buttonAdd;
      HTMLInput hiddenRowIndex;
      HTMLInput hiddenPropertyIndex;
      UserProfileObjEditModel listModel = (UserProfileObjEditModel) m_model;
      hiddenRowIndex = new HTMLInput(HTMLInputTypes.HIDDEN, listModel.GetUniqueString(HTMLHIDDEN_ROWINDEX) + "_" + _nRowIndex,
       "");
      hiddenRowIndex.SetValue(XPConvert.ToString(_nRowIndex));
      addCollection.AddInnerHTMLElement(hiddenRowIndex);
      hiddenPropertyIndex = new HTMLInput(HTMLInputTypes.HIDDEN, listModel.GetUniqueString(HTMLHIDDEN_PROPERTYINDEX) + "_" + _nRowIndex,
       "");
      hiddenPropertyIndex.SetValue(XPConvert.ToString(listModel.GetRowID(_nRowIndex)));
      addCollection.AddInnerHTMLElement(hiddenPropertyIndex);
      buttonAdd = new HTMLInput(HTMLInputTypes.SUBMIT, UserProfileRepostControl.HTMLSUBMIT_508_ADDREMOVEROW + listModel.GetUniqueInt(UserProfileRepostControl.POSTTOSELF_ACTION_508_ADDROW) + "_" + _nRowIndex,
       m_asOwner.GetString(366, "ptmsgs_portalinfrastructure"));
      buttonAdd.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
      buttonAdd.SetValue(m_asOwner.GetString(366, "ptmsgs_portalinfrastructure"));
      addCollection.AddInnerHTMLElement(buttonAdd);
      return addCollection;
    }
    protected virtual HTMLElementCollection Get508RemoveSubmit(int _nRowIndex)
    {
      HTMLElementCollection addCollection = new HTMLElementCollection();
      HTMLInput buttonAdd;
      HTMLInput hiddenRowIndex;
      HTMLInput hiddenPropertyIndex;
      UserProfileObjEditModel listModel = (UserProfileObjEditModel) m_model;
      hiddenRowIndex = new HTMLInput(HTMLInputTypes.HIDDEN, listModel.GetUniqueString(HTMLHIDDEN_ROWINDEX) + "_" + _nRowIndex,
       "");
      hiddenRowIndex.SetValue(XPConvert.ToString(_nRowIndex));
      addCollection.AddInnerHTMLElement(hiddenRowIndex);
      hiddenPropertyIndex = new HTMLInput(HTMLInputTypes.HIDDEN, listModel.GetUniqueString(HTMLHIDDEN_PROPERTYINDEX) + "_" + _nRowIndex,
       "");
      hiddenPropertyIndex.SetValue(XPConvert.ToString(listModel.GetRowID(_nRowIndex)));
      addCollection.AddInnerHTMLElement(hiddenPropertyIndex);
      buttonAdd = new HTMLInput(HTMLInputTypes.SUBMIT, UserProfileRepostControl.HTMLSUBMIT_508_ADDREMOVEROW + listModel.GetUniqueInt(UserProfileRepostControl.POSTTOSELF_ACTION_508_REMOVEROW) + "_" + _nRowIndex,
       m_asOwner.GetString(18, "ptmsgs_portalbrowsingmsgs"));
      buttonAdd.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
      buttonAdd.SetValue(m_asOwner.GetString(18, "ptmsgs_portalbrowsingmsgs"));
      addCollection.AddInnerHTMLElement(buttonAdd);
      return addCollection;
    }
    
    /// <summary>
    /// Returns anchor for add button
    /// </summary>
    /// <param name="_nRowIndex">Current row index</param>
    /// <returns>Anchor for add button</returns>
    /// <throws>Exception</throws>
    protected override HTMLAnchor GetAddAnchor(int _nRowIndex)
    {
      UserProfileObjEditModel listModel = (UserProfileObjEditModel) m_model;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      // Add icon
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
       true, m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myAnchor.AddInnerHTMLElement(myImage);
      myAnchor.AddInnerHTMLString(m_asOwner.GetString(366, "ptmsgs_portalinfrastructure"));
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append(listModel.GetUniqueString(JAVASCRIPT_UP_ADD_REMOVE_PROPERTY_VALUE));
      sb.Append("(\'");
      sb.Append(listModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD));
      sb.Append("\', \'");
      sb.Append(_nRowIndex);
      sb.Append("\', \'");
      sb.Append(XPConvert.ToInteger(listModel.GetRowID(_nRowIndex)));
      sb.Append("\'); return false;");
      myAnchor.SetOnClick(sb.ToString());
      return myAnchor;
    }
    
    /// <summary>
    /// JavaScript for opening tree selectors and retrieving values on return
    /// from tree.
    /// </summary>
    /// <returns>JavaScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      IObjPropModelRO iOPModel = (IObjPropModelRO) m_model;
      HTMLScript result = base.DisplayJavascript();
      XPStringBuilder sb;
      try
      {
        // JavaScript to add or remove property values
        sb = new XPStringBuilder(200);
        sb.Append("function ").Append(iOPModel.GetUniqueString(JAVASCRIPT_UP_ADD_REMOVE_PROPERTY_VALUE)).Append("(varAction, varRowIndex, varPropertyIndex)\n");
        sb.Append("{\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
        sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(iOPModel.GetUniqueString(HTMLHIDDEN_PROPERTYINDEX)).Append(".value = varPropertyIndex;\n");
        sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append("varAction").Append(");\n");
        sb.Append("}\n");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element.");
        }
      return result;
    }
    
    /// <summary>
    /// Returns the HTML for the View.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public override HTMLElement Display()
    {
      HTMLElement result = base.Display();
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_PROPERTYINDEX),
       "");
      result.AddInnerHTMLElement(myInput);
      return result;
    }
  }
}