using System;
using com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties;
using com.plumtree.portaluiinfrastructure.expandablelist.properties;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.editors.userprofile
{
  /// <author>
  /// jennifersu
  /// This is the General Profile Display Page that will be used to display all of
  /// the Profile Sections.   It will retrieve the title and
  /// names from the different sections.
  /// </author>
  public class GeneralProfileDP : EditorDP
  {
    
    /// <summary>
    /// object name it is overridden below*
    /// </summary>
    public String STR_MVC_CLASS_NAME = "GeneralProfile";
    
    /// <summary>
    /// object title - it is overridden below *
    /// </summary>
    public String _ui_PageTitle = "";
    
    /// <summary>
    /// This is the IPTProfilePage that is passed in for the first time and contains all the Sections 
    /// </summary>
    protected IPTProfilePage m_profilePage = null;
    
    /// <summary>
    /// This is the index of the specific view which contains all the Sections 
    /// </summary>
    protected int m_profilePageIndex = 0;
    
    /// <summary>
    /// Flag used to update mandatory page status only the first time the left nav string is retrieved 
    /// </summary>
    protected bool bFirstTimeOnPage = true;
    private String subHeaderResourceStr = null;
    
    /// <summary>
    /// We need to have a constructor that takes in the IPTProfilePage object associated
    /// with this Display Page.
    /// </summary>
    /// <param name="subHeaderResourceStr">The</param>
    public GeneralProfileDP(IPTProfilePage profilepage, int index, String name,
     String uiName, String subHeaderResourceStr) : base()
    {
      m_profilePage = profilepage;
      m_profilePageIndex = index;
      STR_MVC_CLASS_NAME = name;
      _ui_PageTitle = uiName;
      this.subHeaderResourceStr = subHeaderResourceStr;
    }
    
    /// <summary>
    /// Displays some HTML after the body tag and before the form tag. For
    /// example this is used by pages using a DHTML calendar to display the div
    /// tag. The function is optional.  If it exists, it will be called by the
    /// framework, and the resulting HTMLElement will be added in the right
    /// place.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElementCollection DisplayHTMLBeforeForm()
    {
      IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + "0");
      return iModelRO.GetDateTimePickerControlManager().GetPagePreFormContent();
      }
    
    /// <summary>
    /// Returns the HTML that is placed in the HEAD section of this HTML page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElementCollection DisplayHTMLinHEAD()
    {
      IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + "0");
      if (m_asOwner.GetAccessStyle().Equals(AccessStyles.STANDARD))
      {
        return iModelRO.GetDateTimePickerControlManager().GetJSIncludes();
        }
      return null;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      // Update mandatory page status the first time left nav string is retrieved.
      UpdateMandatoryPageStatus();
      return _ui_PageTitle;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      if (subHeaderResourceStr == null)
      {
        // Safety. subHeaderResourceStr should always be non-null but we prevent it from being so.
        subHeaderResourceStr = m_asOwner.GetString(1804, ResourceConstants.PORTALBROWSINGMSGS);
        }
      return HTMLConstructHelpers.GetSubHeader(subHeaderResourceStr, m_asOwner);
      }
    
    /// <summary>
    /// Returns the Profile Page that contains all of the section and property
    /// information.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual IPTProfilePage GetProfilePage()
    {
      return m_profilePage;
    }
    
    /// <returns></returns>
    public virtual int GetProfilePageIndex()
    {
      return m_profilePageIndex;
    }
    
    /// <summary>
    /// Dynamically update mandatory page status. In this case, all of the Profile Sections
    /// to see if there are any mandatory properties.
    /// </summary>
    public virtual void UpdateMandatoryPageStatus()
    {
      if (bFirstTimeOnPage)
      {
        bool bPageIsMandatory = false;
        Object[] arSectionIDs = m_profilePage.GetChildSections();
        for (int indSection = 0;indSection < arSectionIDs.Length;indSection++)
        {
          IObjPropModelRO iModel = (IObjPropModelRO) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + indSection);
          if (iModel.CheckDisplayPageIsMandatory())
          {
            bPageIsMandatory = true;
          }
        }
        ((EditorAS) m_asOwner).GetLeftMenu().SetMandatoryPage(bPageIsMandatory,
         GetName());
        bFirstTimeOnPage = false;
      }
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      // set the profile page so that the model knows which page to save
      UserProfileModel profileModel = (UserProfileModel) m_asOwner.GetModel(((EditorAS) m_asOwner).m_strModelName);
      profileModel.SetCurrentProfilePage(m_profilePageIndex);
      // loop through the page and add the various sections as EditorViews
      Object[] arSectionIDs = m_profilePage.GetChildSections();
      for (int indSection = 0;indSection < arSectionIDs.Length;indSection++)
      {
        // store the section in the XPHashtable
        views.AddInnerHTMLElement(((GeneralInfoView) m_asOwner.GetView(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + indSection)).Display());
        // add a spacer table if there are more sections
        if ((indSection + 1) < arSectionIDs.Length)
        {
          views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        }
      }
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      if (AccessStyles.STANDARD != m_asOwner.GetAccessStyle())
      {
        m_asOwner.GetLeftMenu().RemovePageFromMandatoryArray(m_asOwner.GetCurrentPage().GetName());
        }
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      Object[] arSectionIDs = m_profilePage.GetChildSections();
      for (int indSection = 0;indSection < arSectionIDs.Length;indSection++)
      {
        myScripts.AddInnerHTMLElement(m_asOwner.GetView(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + indSection).DisplayJavascript());
        }
      return myScripts;
    }
  }
}