using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server.portalpagesperf;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.gateway
{
  /// <author>daniilk</author>
  public class GatewayBinaryDP : IDisplayPage
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.gateway.GatewayBinaryDP");
    public const String STR_MVC_CLASS_NAME = "GatewayBinary";
    private AActivitySpace m_asOwner = null;
    
    /// <param name="webData"></param>
    public virtual void Display(IWebData webData)
    {
      IGatewayModelRO gwModel = (IGatewayModelRO) m_asOwner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
      String strRawHeaders = gwModel.GetHeaders();
      String strContentType = gwModel.GetContentType();
      int iStatus = gwModel.GetStatus();
      bool bIsText = gwModel.IsText();
      log.Debug("Display(): " + "Setting HTTP status on the response to [" + iStatus + "]");
      webData.SetStatus(iStatus);
      if (304 == iStatus)
      {
        log.Info("Display(): " + "Returning [304 Not Modified] response to the browser");
        }
      log.Debug("Display(): " + "Setting headers on WebData object \r\n[" + strRawHeaders + "]");
      if (null != strRawHeaders)
      {
        GatewayUtils.AddHeadersToResponse(strRawHeaders, webData, !bIsText);
        }
      log.Debug("Display(): " + "Content-Type is [" + strContentType + "]");
      // increment perfcounter
      PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_CLICKTHROUGHS);
      /* if the content type is text */
      if (bIsText)
      {
        log.Debug("Display(): treating gateway response as text.");
        HTMLElement result = gwModel.GetDisplayElement();
        String strHTML = null;
        if (null != result)
        {
          strHTML = result.GetDisplayString();
        }
        if (null != strHTML)
        {
          webData.SetData(strHTML);
        } else
        {
          webData.SetData("<B>" + m_asOwner.GetString(623, "ptmsgs_portalbrowsingmsgs") + "</B>\r\n" + 
          // the following line can stay non-localized, since it's going to be in the HTML comments
          // and will not be displayed in the browser.
          "<!-- GetTextBody call returned NULL. There was a problem accessing gateway content. -->");
          }
      } else
      /* if the content type is binary */
      {
        log.Debug("Display(): treating gateway response as binary.");
        byte[] arrBinaryBody = gwModel.GetBinaryBody();
        if (null != arrBinaryBody)
        {
          webData.SetData(arrBinaryBody);
        }
      }
      return;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual AActivitySpace GetOwner()
    {
      return m_asOwner;
    }
    
    /// <param name="parent"></param>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()"></seealso>
    public virtual HTMLElement PageDisplay()
    {
      return null;
    }
  }
}