using System;/* Need this for the IWebData interface */
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tags.displaytree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.gateway
{
  /// <author>josephs, daniilk</author>
  public class GatewayUtils
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_GATEWAY),
     "com.plumtree.portalpages.browsing.gateway.GatewayUtils");
    private const String m_strContentEncodingHeader = "content-encoding";
    private const String m_strNewline = "\r\n";
    private const String m_strBreak = "<br>";
    public static int AddHeadersToResponse(String strRawHeaders, IWebData webData)
    {
      return AddHeadersToResponse(strRawHeaders, webData, false);
    }
    
    /// <param name="strRawHeaders"></param>
    /// <param name="webData"></param>
    /// <returns></returns>
    public static int AddHeadersToResponse(String strRawHeaders, IWebData webData,
     bool bStreaming)
    {
      if (null != strRawHeaders)
      {
        int iHeaderStart = 0;
        int iHeaderEnd = XPStringUtility.IndexOf(strRawHeaders, "\r\n");
        while (iHeaderEnd > -1)
        {
          String strHeaderName = "";
          String strHeaderValue = "";
          /* Get the current header */
          String strHeader = XPStringUtility.Substring(strRawHeaders, iHeaderStart,
           iHeaderEnd);
          /* move to the next header, since we are not using this variables later
           * in the loop anyways and they need to be updated no-matter-what, so
           * i'm updating them here.
           */
           
          iHeaderStart = iHeaderEnd + 2;
          iHeaderEnd = XPStringUtility.IndexOf(strRawHeaders, "\r\n", iHeaderStart);
          int iHeaderNameEnd = XPStringUtility.IndexOf(strHeader, ":");
          if (iHeaderNameEnd < 0)
          {
            /* skip this wierd line with no ":". BTW, this will happen for the
             * first line as it contains the status code and looks like
             * HTTP/1.1 200 OK and obviously does not contain a colon.
             */
             
            continue;
          }
          strHeaderName = XPStringUtility.Substring(strHeader, 0, iHeaderNameEnd);
          /* we want to skip ":", hence "+1" */
          strHeaderValue = XPStringUtility.Substring(strHeader, iHeaderNameEnd + 1,
           strHeader.Length);
          /* Get rid of extra spaces at the beginnging and end of the header value */
          if (null != strHeaderValue && strHeaderValue.Length > 0)
          {
            strHeaderValue = XPStringUtility.Trim(strHeaderValue);
          }
          log.Debug("AddHeadersToResponse(): " + "Will try to add [" + strHeaderName + ": " + strHeaderValue + "]");
          /* Fix the Content-Type header */
          if (!bStreaming && XPStringUtility.CompareIgnoreCase(XPStringUtility.Trim(strHeaderName),
           "content-type") == 0)
          {
            if (XPStringUtility.IndexOf(XPStringUtility.ToLowerCase(strHeaderValue),
             "text/html") != -1)
            {
              strHeaderValue = "text/html; charset=" + LinkConstants.UTF_8_ENCODING;
              }
          }
          if (XPStringUtility.CompareIgnoreCase(XPStringUtility.Trim(strHeaderName),
           "PT-Stream-ID") == 0)
          {
            XPCookie cookie = new XPCookie("PT-Stream-ID", strHeaderValue);
            log.Debug("AddHeadersToResponse(): Converting custom PT-Stream-ID header into a cookie with value [{0}]",
             strHeaderValue);
            webData.AddCookie(cookie);
          } else
          {
            log.Debug("AddHeadersToResponse(): " + "Writing out [" + strHeaderName + ": " + strHeaderValue + "]");
            webData.SetHeader(strHeaderName, strHeaderValue);
          }
        }
      }
      return 0;
    }
    public static bool SetRedirectToLastHostedPage(AActivitySpace asOwner,
     IGatewayModel gwModel)
    {
      log.Info("Gateway is used as parent space. Not good.");
      String strUserURL = (String) asOwner.GetSubSession().GetAttribute(GatewayHelpers.LAST_VISITED_HOSTED_PAGE);
      if (null != strUserURL)
      {
        gwModel.SetReturnURIContent(302, "Location: " + strUserURL + "\r\n\r\n",
         null);
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// The "UI Transformer", see Transformers and Markup DSD in IWS
    /// This function converts a markup array as returned by the HTTP GP into HTML elements
    /// and converts PT XML tags into HTML -jas
    /// This method outputs the shared JavaScript in the resulting markup, and the
    /// GetSharedJavaScriptFromMarkup method should not be called when this method is used.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_objArrMarkup">markup array in PT_MARKUP_ARRAY_COLS format</param>
    /// <param name="_result">markup is added to this element</param>
    public static void AddMarkupToElement(AActivitySpace _asOwner, Object[][] _objArrMarkup,
     HTMLElement _result)
    {
      _result.AddInnerHTMLElement(AddMarkupToSingleElement(_asOwner, _objArrMarkup));
      }
    
    /// <summary>
    /// The "UI Transformer", see Transformers and Markup DSD in IWS
    /// This function converts a markup array as returned by the HTTP GP into HTML elements
    /// and converts PT XML tags into HTML -jas
    /// This method returns the shared JavaScript in its output, and the
    /// GetSharedJavaScriptFromMarkup method should not be called when this method is used.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_objArrMarkup">markup array in PT_MARKUP_ARRAY_COLS format</param>
    /// <returns>HTMLElement The transformed markup.</returns>
    public static HTMLElement AddMarkupToSingleElement(AActivitySpace _asOwner,
     Object[][] _objArrMarkup)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLElement tagOutput = AddMarkupToElement(_asOwner, _objArrMarkup);
      HTMLElement scriptOutput = GetSharedJavaScriptFromMarkup(_asOwner);
      result.AddInnerHTMLElement(scriptOutput);
      result.AddInnerHTMLElement(tagOutput);
      return result;
    }
    
    /// <summary>
    /// The "UI Transformer", see Transformers and Markup DSD in IWS
    /// This function converts a markup array as returned by the HTTP GP into HTML elements
    /// and converts PT XML tags into HTML -jas
    /// This method is designed to be used when there are multiple elements that need markup
    /// transformed.  All of these elements share a single JavaScript collection for shared
    /// JavaScript.  This collection must be displayed in the page before the first markup
    /// element is displayed, otherwise there may be JavaScript errors.
    /// When using this method to transform markup the oiutput of the GetSharedJavaScriptFromMarkup
    /// method must be displayed prior to the transformed elements.
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <param name="_objArrMarkup">markup array in PT_MARKUP_ARRAY_COLS format</param>
    /// <returns>HTMLElement The transformed markup.</returns>
    public static HTMLElement AddMarkupToElement(AActivitySpace _asOwner,
     Object[][] _objArrMarkup)
    {
      HTMLElement result;
      try
      {
        result = DisplayTree.ProcessTagMarkup(_asOwner, _objArrMarkup);
      }
      catch (Exception e)
      {
        log.Warn(e, "Error rendering markup for portlets.");
        XPException xpE = XPException.GetInstance(e);
        result = new HTMLComment("error rendering markup: " + e.Message + " : " + xpE.GetStackTrace());
        }
      return result;
    }
    
    /// <summary>
    /// This method returns a single shared JavaScript collection for all of the transformed
    /// markup elements on a page.  This collection must be displayed in the page before the
    /// first markup element is displayed, otherwise there may be JavaScript errors.
    /// This method should only be used in conjunction with AddMarkupToElement().  It is not
    /// needed when using AddMarkupToSingleElement().
    /// </summary>
    /// <param name="_asOwner">Activity Space</param>
    /// <returns>HTMLElement The shared JavaScript collection.</returns>
    public static HTMLElement GetSharedJavaScriptFromMarkup(AActivitySpace _asOwner)
    {
      HTMLElement result;
      try
      {
        result = DisplayTree.GetSharedJavaScriptFromMarkup(_asOwner);
      }
      catch (Exception e)
      {
        log.Warn(e, "Error retrieving shared JavaScript collection for tag markup display.");
        XPException xpE = XPException.GetInstance(e);
        result = new HTMLComment("Error retrieving shared JavaScript collection for tag markup display: " + e.Message + " : " + xpE.GetStackTrace());
        }
      return result;
    }
    /*
     * Returns true if the markup array has error information in it.
     */
     
    public static bool IsErrorContentArray(Object[][] objArrMarkup)
    {
      PortletErrorHelper errorHelper = new PortletErrorHelper();
      return errorHelper.IsErrorContentArray(objArrMarkup);
    }
    /*
     * Returns true if an http response is included along with error information.
     */
     
    public static bool ResponseReceivedForErrors(Object[][] objArrMarkup)
    {
      //If the length is 2, that means we didn't get a valid response back.
      if (objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE].Length <= 2)
      {
        return false;
      }
      //if we are here, it means length is at least 2.
      //now, let's make sure that the response body is there
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_RESBODY)
      {
        return true;
      }
      return false;
    }
    /*
     * Returns true if timeout occured and extra timeout info is included along with error information.
     */
     
    public static bool TimeoutErrorReceived(Object[][] objArrMarkup)
    {
      int iErrorCode = GetErrorCode(objArrMarkup);
      if (iErrorCode == PT_RESULTCODES.PT_E_GADGET_TIMEOUT && objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE].Length > 2)
      {
        return true;
      }
      return false;
    }
    /*
     * Returns true if exception stack is included along with error information in the array.
     */
     
    public static bool ExceptionStackReceived(Object[][] objArrMarkup)
    {
      int iErrorCode = GetErrorCode(objArrMarkup);
      if (iErrorCode == PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR && objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE].Length > 2)
      {
        int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2]);
        if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_EXCEPTIONSTACK)
        {
          return true;
        }
      }
      return false;
    }
    /*
     * Returns the error code from the markup array.
     */
     
    public static int GetErrorCode(Object[][] objArrMarkup)
    {
      PortletErrorHelper errorHelper = new PortletErrorHelper();
      return errorHelper.GetErrorCode(objArrMarkup);
    }
    /*
     * Returns the error message from the markup array.
     */
     
    public static String GetErrorMessage(Object[][] objArrMarkup)
    {
      PortletErrorHelper errorHelper = new PortletErrorHelper();
      return errorHelper.GetErrorMessage(objArrMarkup);
    }
    /*
     * Returns the response body from the markup array.
     */
     
    public static String GetResponseBody(Object[][] objArrMarkup)
    {
      if (!ResponseReceivedForErrors(objArrMarkup))
      {
        return null;
      }
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_RESBODY)
      {
        String strResponseBody = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][2];
        return strResponseBody;
      }
      return null;
    }
    /*
     * Returns the response status from the markup array.
     */
     
    public static String GetResponseStatus(Object[][] objArrMarkup)
    {
      if (!ResponseReceivedForErrors(objArrMarkup))
      {
        return null;
      }
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][3]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_RESSTATUS)
      {
        String strResponseStatus = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][3];
        return strResponseStatus;
      }
      return null;
    }
    /*
     * Returns the portlet timeout from the markup array.
     */
     
    public static String GetPortletTimeout(Object[][] objArrMarkup)
    {
      if (!TimeoutErrorReceived(objArrMarkup))
      {
        return null;
      }
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PORTLET_TIMEOUT)
      {
        return (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][2];
        }
      return null;
    }
    /*
     * Returns the effective portlet timeout from the markup array.
     */
     
    public static String GetEffectivePortletTimeout(Object[][] objArrMarkup)
    {
      if (!TimeoutErrorReceived(objArrMarkup))
      {
        return null;
      }
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][3]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_EFFECTIVE_PORTLET_TIMEOUT)
      {
        return (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][3];
        }
      return null;
    }
    /*
     * Returns the shorter timeout between the portal timeout and the user page timeout
     */
     
    public static String GetShorterPortletTimeout(String portletTimeout, int pageTimeout)
    {
      if (XPConvert.ToInteger(portletTimeout) > pageTimeout)
      {
        return XPConvert.ToString(pageTimeout);
      } else
      {
        return portletTimeout;
      }
    }
    /*
     * Returns the exception stack trace body from the markup array.
     */
     
    public static String GetExcepionStackTrace(Object[][] objArrMarkup)
    {
      if (!ExceptionStackReceived(objArrMarkup))
      {
        return null;
      }
      int iType = XPConvert.ToInteger(objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][2]);
      if (iType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_EXCEPTIONSTACK)
      {
        String strExceptionStackTrace = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][2];
        return strExceptionStackTrace;
      }
      return null;
    }
    
    /// <summary>
    /// Check to see whether the given gadget has a particular kind of
    /// preferences.
    /// </summary>
    /// <param name="ID">of Portlet</param>
    /// <param name="PersonalizationType"></param>
    /// <param name="IPTSession"></param>
    /// <returns>
    /// True if the portlet has prefs, false if it does not, or if there
    /// was a problem opening the web service.
    /// </returns>
    public static bool GetPortletSupportsPersonalization(int nPortletID, int nPersonalizationType,
     IPTSession ptSession)
    {
      if (nPortletID <= 0)
      {
        return false;
      }
      try
      {
        IPTGadget ptPortlet = (IPTGadget) ptSession.GetGadgets().Open(nPortletID,
         false);
        int nWebServiceID = ptPortlet.GetWebServiceID();
        return GetWebServiceSupportsPersonalization(nWebServiceID, nPersonalizationType,
         ptSession);
      }
      catch (Exception e)
      {
        log.Warn("GatewayUtils.GetPortletSupportsPersonalization: Couldn\'t open the gadget with ID: " + nPortletID + ". Will return false.");
        return false;
      }
    }
    
    /// <returns></returns>
    public static String GetSavedPortletName()
    {
      return GatewayHelpers.PORTLET_SAVED_ON_SESSION;
    }
    
    /// <summary>
    /// Check to see whether the given web service has a particular kind of
    /// preferences.
    /// </summary>
    /// <param name="ID">of WebService</param>
    /// <param name="PersonalizationType"></param>
    /// <param name="IPTSession"></param>
    /// <returns>
    /// True if the portlet has prefs, false if it does not, or if there
    /// was a problem opening the web service.
    /// </returns>
    public static bool GetWebServiceSupportsPersonalization(int nWebServiceID,
     int nPersonalizationType, IPTSession ptSession)
    {
      if (nWebServiceID <= 0)
      {
        return false;
      }
      try
      {
        IPTWebService ptWebService = (IPTWebService) ptSession.GetWebServices().Open(nWebServiceID,
         false);
        int nWebServicePersonalization = ptWebService.GetSupportsPersonalization();
        if (0 == (nPersonalizationType & nWebServicePersonalization))
        {
          return false;
        } else
        {
          return true;
        }
      }
      catch (Exception e)
      {
        log.Warn("GatewayUtils.GetWebServiceSupportsPersonalization: Couldn\'t open the web service with ID: " + nWebServiceID + ". Will return false.");
        return false;
      }
    }
  }
}