using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.tags.xml;
using com.plumtree.server;
using com.plumtree.server.impl.portlet.providers;
namespace com.plumtree.portalpages.browsing.gateway
{
  /// <summary>
  /// This class contains utilities for the integration between the
  /// Gateway and the Tag Engine.
  /// </summary>
  public class TagEngineUtils
  {
    
    /// <summary>
    /// This method determines whether or not we will need to include the
    /// JS includes data in the head.  If this page is hosted, then the
    /// portal banner will handle the JS includes and we don't have to.
    /// Hosted mode will make this method return false.
    /// </summary>
    /// <param name="_markupList"></param>
    /// <returns>true if we need to add the JSIncludes data.</returns>
    public virtual bool NeedsCSAPIinNonHostedPage(XPArrayList _markupList)
    {
      bool bHostedMode = false;
      bool bNeedsCSAPI = false;
      // Search the fragments for the CSAPI include & display mode tags
      // We need to loop through the whole page, because we only use the last
      // display mode tag.
      for (int i = 0;i < _markupList.GetSize();i++)
      {
        IMarkupFragment fragment = (IMarkupFragment) _markupList.GetElement(i);
        if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
        {
          // Found a PTXML tag
          if (TagConstants.DISPLAY_MODE_TAG_FULL_NAME.Equals(fragment.GetXMLFragment().GetName(0)))
          {
            bHostedMode = IsHostedModeTag(fragment.GetXMLFragment());
          } else
          if (AutoJSTransformTagConstants.TAG_FULL_NAME.Equals(fragment.GetXMLFragment().GetName(0)))
          {
            bNeedsCSAPI = true;
          }
        }
      }
      return !bHostedMode && bNeedsCSAPI;
    }
    
    /// <summary>
    /// This method determines whether or not we will need to include the
    /// JS includes data in the head.  If this page is hosted, then the
    /// portal banner will handle the JS includes and we don't have to.
    /// Hosted mode will make this method return false.
    /// </summary>
    /// <param name="_objArrMarkup">The markup</param>
    /// <returns>true if we need to add the JSIncludes data.</returns>
    public virtual bool NeedsCSAPIinNonHostedPage(Object[][] _objArrMarkup)
    {
      bool bHostedMode = false;
      bool bNeedsCSAPI = false;
      // Search the fragments for the CSAPI include & display mode tags
      // We need to loop through the whole page, because we only use the last
      // display mode tag.
      for (int i = 0;i < _objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE].Length;
      i++)
      {
        int nFragmentType = XPConvert.ToInteger(_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i]);
        if (nFragmentType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
        {
          Object[][] arrXML = (Object[][]) _objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i];
          // Assume the name is the first attribute				
          String strName = XPConvert.ToString(arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][0]);
          // Found a PTXML tag
          if (TagConstants.DISPLAY_MODE_TAG_FULL_NAME.Equals(strName))
          {
            bHostedMode = IsHostedModeTag(arrXML);
          } else
          if (AutoJSTransformTagConstants.TAG_FULL_NAME.Equals(strName))
          {
            bNeedsCSAPI = true;
          }
        }
      }
      return !bHostedMode && bNeedsCSAPI;
    }
    
    /// <summary>
    /// This helper method determines whether or not the given display mode tag
    /// is set to hosted mode.
    /// </summary>
    /// <param name="_tag"></param>
    /// <returns>whether or not the given display mode tag is set to hosted mode.</returns>
    public virtual bool IsHostedModeTag(IXMLFragment _tag)
    {
      for (int i = 0;i < _tag.GetNumberOfRows();i++)
      {
        if (_tag.GetType(i) == PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT)
        {
          if (XPStringUtility.EqualsIgnoreCase(XPStringUtility.Trim(_tag.GetName(i)),
           (TagConstants.DISPLAY_MODE_ATTRIBUTE_HOSTED_VALUE)))
          {
            return true;
          }
        }
      }
      return false;
    }
    
    /// <summary>
    /// This helper method determines whether or not the given display mode tag
    /// is set to hosted mode.
    /// </summary>
    /// <param name="_tag"></param>
    /// <returns>whether or not the given display mode tag is set to hosted mode.</returns>
    public virtual bool IsHostedModeTag(Object[][] _arrXML)
    {
      for (int i = 0;i < _arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE].Length;
      i++)
      {
        // If it's an attribute
        if (XPConvert.ToInteger(_arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][i]) == PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT)
        {
          // and the name is "mode"
          if (XPStringUtility.EqualsIgnoreCase(XPStringUtility.Trim(XPConvert.ToString(_arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][i])),
           (TagConstants.DISPLAY_MODE_TAG_MODE_ATTRIBUTE)))
          {
            // and the value is "Hosted"
            if (XPStringUtility.EqualsIgnoreCase(XPStringUtility.Trim(XPConvert.ToString(_arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][i])),
             (TagConstants.DISPLAY_MODE_ATTRIBUTE_HOSTED_VALUE)))
            {
              return true;
            }
          }
        }
      }
      return false;
    }
  }
}