using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.layoutselection
{
  /// <author>michaeld</author>
  public class LayoutSelectionEditorAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LayoutSelectionEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String,java.lang.String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bAccess = base.CheckBasicAccess(strPage, strControl, bSameSpace);
      // MJD- Otherwise make sure this is the refresh control. The access will be checked by those controls.
      if ((null != strControl) && (strControl.Equals(RefreshLayoutSelectControl.STR_MVC_CLASS_NAME)))
      {
        bAccess = true;
      }
      return bAccess;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LayoutSelectionEditorAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      return GetString(628, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (LayoutSelectionRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      log.Info("Layout Selection Editor Activity Space");
      // Layout Selection Model
      m_strModelName = LayoutSelectionModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(LayoutSelectionModel.STR_MVC_CLASS_NAME);
      // Model has to be initialized in Init method because it requires PTSession.
      log.Info("Registered model");
      // Layout Selection DisplayPages
      AFormDP myPage = new LayoutSelectionDP();
      myPage.AddToValidationFunction(LayoutSelectionView.JAVASCRIPT_SUBMIT_TO_PARENT);
      RegisterPage(myPage);
      log.Info("Registered page");
      // Layout Selection Views
      RegisterView(LayoutSelectionView.STR_MVC_CLASS_NAME, myModel);
      log.Info("Registered views");
      // Layout Selection Controls
      RegisterControl(LayoutSelectionRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(RefreshLayoutSelectControl.STR_MVC_CLASS_NAME, myModel);
      log.Info("Registered controls");
      // Set default page
      SetCurrentPage(LayoutSelectionDP.STR_MVC_CLASS_NAME);
      SetHelpTopic("PT_ChooseLayout");
    }
  }
}