using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.layoutselection
{
  /// <author>michaeld</author>
  public class LayoutSelectionModel : EditorModel,ILayoutSelectionModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionModel");
    
    /// <summary>
    /// Object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "LayoutSelection";
    
    /// <summary>
    /// Parent Form Name 
    /// </summary>
    private String m_strParentFormName = "";
    
    /// <summary>
    /// Parent Form Select Input 
    /// </summary>
    private String m_strParentFormSelectInput = "";
    
    /// <summary>
    /// Parent Form Space ID 
    /// </summary>
    private String m_strParentFormSpaceID = "";
    
    /// <summary>
    /// Parent Form Submit Function 
    /// </summary>
    private String m_strParentFormSubmitFunction = "";
    
    /// <summary>
    /// Selector has free form portlet? 
    /// </summary>
    private bool m_bHasFreeFormPortlet;
    
    /// <summary>
    /// Layout Column Count 
    /// </summary>
    private int m_nLayoutColumnCount = 4;
    
    /// <summary>
    /// Selector allows free form layouts 
    /// </summary>
    private bool m_bFreeFormLayoutAllowed;
    
    /// <summary>
    /// Selected Layout 
    /// </summary>
    private int m_nSelectedLayout;
    protected IPTQueryResult m_layouts;
    // END ***************** save DP methods ***************** 
    // ***CHANGE_HERE*** Implement the repost action methods that you 
    //      will call from your Repost Control.
    // BEGIN ***************** repost action methods ***************** 
    
    /// <summary>
    /// Modifies the object name on repost.
    /// </summary>
    public virtual void ActionOnRepost()
    {
    }
    
    /// <summary>
    /// Initializes the list of layouts
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public override void Init(AActivitySpace owner)
    {
      ILayoutChooser chooser = LayoutService.getChooserInstance();
      if (chooser.GetPortletLayoutsEnabled(owner))
      {
        IPTQueryResult layouts = chooser.GetAvailableWebServices(Layouts.PORTLET,
         owner);
        m_layouts = layouts;
      } else
      {
        m_layouts = null;
      }
    }
    // END ***************** helper methods ***************** 
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      SetValuesFromQueryString(_htFormData);
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LayoutSelectionModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetLayoutColumnCount()"></seealso>
    public virtual int GetLayoutColumnCount()
    {
      return m_nLayoutColumnCount;
    }
    ////////////////////////////////////////////////////
    // Read only methods from ILayoutSelectionModelRO
    ////////////////////////////////////////////////////
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetPageHasFreeFormPortlet()"></seealso>
    public virtual bool GetPageHasFreeFormPortlet()
    {
      return m_bHasFreeFormPortlet;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetPageSupportsFreeFormSection()"></seealso>
    public virtual bool GetPageSupportsFreeFormSection()
    {
      return m_bFreeFormLayoutAllowed;
    }
    /////////////////////////////////////
    // Read only methods from IModelRO
    /////////////////////////////////////
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormName()"></seealso>
    public virtual String GetParentFormName()
    {
      return m_strParentFormName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormSelectInput()"></seealso>
    public virtual String GetParentFormSelectInput()
    {
      return m_strParentFormSelectInput;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormSpaceID()"></seealso>
    public virtual String GetParentFormSpaceID()
    {
      return m_strParentFormSpaceID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormSubmitFunction()"></seealso>
    public virtual String GetParentFormSubmitFunction()
    {
      return m_strParentFormSubmitFunction;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public override Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetSelectedLayout()"></seealso>
    public virtual int GetSelectedLayout()
    {
      return m_nSelectedLayout;
    }
    
    /// <summary>
    /// Method RefreshHasFreeFormPortlet.
    /// Refreshes the available choices based upon whether the opening page has a
    /// freeform layout or not.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void RefreshHasFreeFormPortlet(XPHashtable _htFormData)
    {
      // Set Selector has free form portlet Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_HAS_FREE_FORM))
      {
        m_bHasFreeFormPortlet = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_HAS_FREE_FORM))[0]);
        }
    }
    // END ***************** repost action methods ***************** 
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      if (_sPageName.Equals(LayoutSelectionDP.STR_MVC_CLASS_NAME))
      {
        SaveMainPage(_htFormData);
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    // BEGIN ***************** save DP methods ***************** 
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
      String[] data;
      // Saving setting1
      data = (String[]) _htFormData.GetElement(LayoutSelectionView.HTMLINPUT_LAYOUT);
      if ((null != data) && !(0 == data.Length))
      {
        m_nSelectedLayout = XPConvert.ToInteger(data[0]);
      }
    }
    
    /// <summary>
    /// Set values of member variable from Query String
    /// </summary>
    /// <param name="XPHashTable">_htFormData</param>
    private void SetValuesFromQueryString(XPHashtable _htFormData)
    {
      RefreshHasFreeFormPortlet(_htFormData);
      // Set Selector has free form portlet Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_HAS_FREE_FORM))
      {
        m_bHasFreeFormPortlet = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_HAS_FREE_FORM))[0]);
        }
      // Set Parent Form Selected Items Name Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_SELECTED_ITEM))
      {
        m_nSelectedLayout = XPConvert.ToInteger(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_SELECTED_ITEM))[0]);
        }
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_FREE_FROM_LAYOUT_ALLOWED))
      {
        m_bFreeFormLayoutAllowed = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_FREE_FROM_LAYOUT_ALLOWED))[0]);
        }
      // Set Parent Form Name Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_PARENT_FORM_NAME))
      {
        // CheckSafeName will throw an exception if the name contains suspicious characters.
        m_strParentFormName = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_FORM_NAME))[0]);
        }
      // Set Parent Form Space ID Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_PARENT_FORM_SPACE_ID))
      {
        // CheckSafeName will throw an exception if the name contains suspicious characters.
        m_strParentFormSpaceID = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_FORM_SPACE_ID))[0]);
        }
      // Set Parent Form Submit Function Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_PARENT_SUBMIT_CALL))
      {
        // CheckSafeName will throw an exception if the name contains suspicious characters.
        m_strParentFormSubmitFunction = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_SUBMIT_CALL))[0]);
        }
      // Set Parent Form Select Input Value
      if (_htFormData.ContainsKey(LayoutSelectionRepostControl.STR_PARENT_FORM_SELECTED_INPUT))
      {
        // CheckSafeName will throw an exception if the name contains suspicious characters.
        m_strParentFormSelectInput = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_FORM_SELECTED_INPUT))[0]);
        }
    }
    
    /// <summary>
    /// A utility method that checks if the parameter name is safe to
    /// protect against cross-site scripting attacks. 
    /// </summary>
    /// <param name="_strName">The name to check.</param>
    /// <returns>The safe name.</returns>
    /// <throws>XPIllegalArgumentException if the name is not safe.</throws>
    public virtual String CheckSafeName(String _strName)
    {
      if (GeneralHelpers.ContainsUnsafeCharacters(_strName, true))
      {
        throw new XPIllegalArgumentException("Unsafe character found in " + "the Layout Selection Model parameters.  Possible hack attempt " + "from parameter \'" + _strName + "\'.");
        }
      return _strName;
    }
    
    /// <returns>Available portlet page layouts, null if adaptive page layouts are disabled</returns>
    public virtual IPTQueryResult GetAdaptiveLayouts()
    {
      return m_layouts;
    }
  }
}