using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.layoutselection
{
  /// <author>michaeld</author>
  public class LayoutSelectionRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionRepostControl");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SelectLayout";
    
    /// <summary>
    /// Selected item will be selected by default. 
    /// </summary>
    public const String STR_SELECTED_ITEM = "SelectedItem";
    // NOTE: The following four QS params (form name, form space ID, parent submit, and
    // parent selected input) need to be protected against cross-site scripting
    // attacks.  Therefore, we screen them for suspicicious characters such as angle
    // brackets, slashes, etc...  We could get rid of the form name, since it's only
    // used once and is the default, but we'd still need to protect the other 3
    // variables.  Bugs#69340 and 69341.
    // These two (form name and form space ID) should be used together or not at all.
    
    /// <summary>
    /// The name of the parent form that you would like the data passed back to.
    /// NOTE: This parameter cannot contain angle brackets, slashes, etc....
    /// </summary>
    public const String STR_PARENT_FORM_NAME = "Form";
    
    /// <summary>
    /// The name of the input in the parent form that you would like the AActivitySpace
    /// ID  of the tree space put into.
    /// NOTE: This parameter cannot contain angle brackets, slashes, etc....
    /// </summary>
    public const String STR_PARENT_FORM_SPACE_ID = "Input";
    
    /// <summary>
    /// The name of the javascript function in the parent page to call when the tree
    /// is  submitted. This should not include the '();'. In  Javascript submit
    /// mode this method should take an array argument which will be made up
    /// of objects with name, ObjectID, and ClassID member  variables. see
    /// ATreeAS for details.
    /// NOTE: This parameter cannot contain angle brackets, slashes, etc....
    /// </summary>
    public const String STR_PARENT_SUBMIT_CALL = "Submit";
    
    /// <summary>
    /// NOTE: This parameter cannot contain angle brackets, slashes, etc....
    /// </summary>
    public const String STR_PARENT_FORM_SELECTED_INPUT = "SelectInput";
    public const String STR_HAS_FREE_FORM = "HasFreeForm";
    
    /// <summary>
    /// Free form layout allowed 
    /// </summary>
    public const String STR_FREE_FROM_LAYOUT_ALLOWED = "ffok";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LayoutSelectionRepostControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call  the associated method for each
    /// action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
    }
    
    /// <summary>
    /// This method is called when we finish a sub Editor.
    /// It takes care of closing the sub Editor pop-up winodws
    /// and repost the main Editor window.
    /// </summary>
    protected override void SetRedirectToCloseSubEditor()
    {
      ((EditorModel) m_model).SetDeleteOnCancel(false);
      // Set up submit function in parent form, if it exists.
      String strOpenerFunction = ((ILayoutSelectionModelRO) m_model).GetParentFormSubmitFunction();
      int nSize = 20;
      if ((strOpenerFunction != null) && (!"".Equals(strOpenerFunction)))
      {
        nSize+=100;
      }
      XPStringBuilder sb = new XPStringBuilder(nSize);
      // Add method to call on opening form, if it exists
      if ((strOpenerFunction != null) && (!"".Equals(strOpenerFunction)))
      {
        sb.Append("  window.opener.").Append(strOpenerFunction).Append("();\n");
        }
      // We are in a frame, so we need to call parent, not window
      sb.Append("window.close();\n");
      HTMLScript myScript = new HTMLScript("text/javaScript");
      try
      {
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error generating JS for ClosePopUpDP.");
      }
      ClosePopUpDP myClosePopUp = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      myClosePopUp.SetScript(myScript);
      // Close the Tree pop-up
      Redirect myRedirect = new Redirect();
      myRedirect.SetLinkGetCachedSpace(m_asOwner);
      myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      SetRedirect(myRedirect);
    }
  }
}