using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openkernel.http;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.condition;
using com.plumtree.portaluiinfrastructure.failover;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.sso;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.errordisplay;
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.login
{
  /// <summary>
  /// This class implements the data handling for login.
  /// </summary>
  /// <author>BenG</author>
  public class LoginModel : AClearModel,IModel,ILoginModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.login.LoginModel");
    public const String STR_MVC_CLASS_NAME = "Login";
    public const String AUTH_SOURCE_USER_SEPARATOR = "\\";
    protected Redirect redirectAfterLogin = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LoginModel();
    }
    
    /// <summary>
    /// This method will make a call to the LoginHelper to process tasks that may
    /// be needed before the Logout has occurred.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.login.LoginHelper#DoTasksBeforeLogout"></seealso>
    /// <returns>
    /// Redirect - The location that a user will be redirected to after
    /// logout.
    /// </returns>
    public virtual Redirect DoTasksBeforeLogout(IXPRequest request, IWebData webData)
    {
      log.Info("Entering DoTasksBeforeLogout()");
      Redirect rReturn = null;
      try
      {
        rReturn = LoginHelper.INSTANCE.DoTasksBeforeLogout(m_asOwner, request,
         webData);
        // ES - if replication is enabled, take out the replication cache entry from the
        // cache
        if (true == ReplicationCache.GetEnabled())
        {
          // remove the cookie
          log.Info("About to remove replication cookie.");
          XPCookie[] cookieArr = request.GetCookies();
          for (int i = 0;i < cookieArr.Length;i++)
          {
            if (XPStringUtility.EqualsIgnoreCase(cookieArr[i].GetName(), LoginHelper.REPLICATION_COOKIE_NAME))
            {
              String replicationToken = cookieArr[i].GetValue();
              if (null == replicationToken)
              {
                log.Warn("Replication cookie is null.");
              } else
              {
                ReplicationCache.Remove(replicationToken);
                log.Info("Replication cookie has been removed");
              }
              // TODO: This should use replication cookie values, not login token values.
              // Set the replication cookie to have a defunct value.
              XPCookie cookie = new XPCookie(LoginHelper.REPLICATION_COOKIE_NAME,
               LoginHelper.LOGIN_TOKEN_COOKIE_DEFUNCT_VALUE);
              cookie.SetPath("");
              cookie.SetSecure(IsLoginTokenSecure());
              webData.AddCookie(cookie);
              break;
            }
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "DoTasksBeforeLogout() failed.");
      }
      return rReturn;
    }
    
    /// <returns></returns>
    public virtual int GetAccessStyle()
    {
      TempData td = (TempData) this.GetTempData();
      int iAccessStyle = td.GetAccessStyle();
      // If this is -1, it means the access style was not set by the login control,
      // which means the user did not have an access style cookie.  Therefore,
      // use the guest user access style.
      if (iAccessStyle == -1)
      {
        // Get this from the user settings stored on the HTTP Session
        // This method gets it from the config file if it's not found on the session,
        // which means it was not found on the SessionInfo object.
        // It also gets it from the config file for the guest user if the config file
        // is set to override the guest user session.
        iAccessStyle = m_asOwner.GetAccessStyle().GetAccessID();
      }
      return iAccessStyle;
    }
    
    /// <summary>
    /// Get Auth Source Mode
    /// </summary>
    /// <returns>
    /// int the AllowDefaultLoginPageAuthSource value
    /// from PTConfig.xml
    /// </returns>
    public virtual int GetAllowDefaultAuthSourceMode()
    {
      TempData td = (TempData) this.GetTempData();
      int nShowAuthSourceMode = td.GetAllowDefaultAuthSource();
      if (nShowAuthSourceMode == -1)
      {
        try
        {
          //	default access style for all users.
          nShowAuthSourceMode = PTConfigHelper.GetConfigVariableAsInt("Authentication",
           "AllowDefaultLoginPageAuthSource", "value", this.m_asOwner);
        }
        catch (Exception ex)
        {
          log.Debug(ex, "Unable to get AllowDefaultLoginPageAuthSource config var as int.");
          nShowAuthSourceMode = 0;
        }
        td.SetAllowDefaultAuthSource(nShowAuthSourceMode);
      }
      return nShowAuthSourceMode;
    }
    
    /// <returns></returns>
    public virtual bool GetDoAttemptLogin()
    {
      TempData td = (TempData) this.GetTempData();
      return td.GetDoAttemptLogin();
    }
    
    /// <returns></returns>
    public virtual bool GetDoAttemptLogout()
    {
      TempData td = (TempData) this.GetTempData();
      return td.GetDoAttemptLogout();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public override Object GetNewTempData()
    {
      return new TempData();
    }
    
    /// <returns></returns>
    public virtual Redirect GetRedirectAfterLogin()
    {
      if (redirectAfterLogin != null)
      {
        log.Debug("Retrieving redirect to page user attempted to view.");
        } else
      {
        log.Debug("Attempting to retrieve user redirect, but none available.");
        }
      return redirectAfterLogin;
    }
    
    /// <returns></returns>
    public virtual IPTSession GetSession()
    {
      TempData td = (TempData) this.GetTempData();
      return td.GetPTSession();
    }
    
    /// <returns></returns>
    public virtual bool GetShowAuthSources()
    {
      TempData td = (TempData) this.GetTempData();
      bool bReturn = true;
      //	This is set in PTConfig.xml
      int i = GetAllowDefaultAuthSourceMode();
      // 0 = no default yes dropdown, 1 = use default, no dropdown,
      // 2 = yes dropdown, set to default, 3 = use default, no dropdown ever
      if ((i == 1) || (i == 3))
      {
        // modes 1 and 3 are essentially the same.
        bReturn = false;
      }
      //	if this has been set, then return the value that it has been set to.
      // mode 3 means never show dropdown.
      if (td.GetShowAuthSourcesSet() && (i != 3))
      {
        bReturn = td.GetShowAuthSources();
      }
      return bReturn;
    }
    
    /// <returns></returns>
    public virtual Redirect GetSubPortalRedirectAfterLogin(IPTSession _session)
    {
      // DCA - need to run Expression Engine to determine the Subportal
      ConditionTypeManager.GetInstance().EvaluateExpressionForLogInDestination(m_asOwner,
       m_asOwner.GetApplication(), m_asOwner.GetCurrentHTTPRequest(), _session);
      return (Redirect) LoginHelper.INSTANCE.GetDefaultPageRedirect(new Redirect(),
       _session, m_asOwner);
    }
    
    /// <param name="i"></param>
    public virtual void SetAccessStyle(int i)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetAccessStyle(i);
    }
    
    /// <param name="i"></param>
    public virtual void SetDefaultAuthSourcePrefix(String s)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetDefaultAuthSourcePrefix(s);
    }
    
    /// <param name="b"></param>
    public virtual void SetDoAttemptLogin(bool b)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetDoAttemptLogin(b);
    }
    
    /// <param name="b"></param>
    public virtual void SetDoAttemptLogout(bool b)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetDoAttemptLogout(b);
    }
    
    /// <param name="b"></param>
    public virtual void SetLoginAttempted(bool b)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetLoginAttempted(b);
    }
    
    /// <param name="b"></param>
    public virtual void SetLoginSucceeded(bool b)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetLoginSucceeded(b);
    }
    
    /// <param name="r"></param>
    public virtual void SetRedirectAfterLogin(Redirect r)
    {
      if (r != null)
      {
        // work around/fix for bug #9460507.
        // These two parameters are not qs parameers but are returned as such by xprequest in RequestData.GetQueryString
        // and are added on to the redirect after login url. RequestHTTPHeaders specifically is used in several places 
        // as HttpUtils.HASHTABLE_CONTROL_KEY_HTTP_HEADERS 
        // Manually remove these two arguments here, which is only called to set urls to redirect to after succesful login
        // where we never want these two parameters on the url
        r.RemoveControlArgument(HttpUtils.HASHTABLE_CONTROL_KEY_HTTP_HEADERS);
        r.RemoveControlArgument("MyURL");
        log.Debug("SetRedirectAfterLogin() - Redirect: " + r.GetDisplayPage());
        } else
      {
        log.Debug("SetRedirectAfterLogin() - Redirect: <null>");
      }
      redirectAfterLogin = r;
    }
    
    /// <param name="s"></param>
    public virtual void SetSession(IPTSession s)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetPTSession(s);
    }
    
    /// <param name="b"></param>
    public virtual void SetShowAuthSources(bool b)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetShowAuthSources(b);
      td.SetShowAuthSourcesSet(true);
    }
    
    /// <summary>
    /// JF- Helper method to figure out if the login cookie should be secure or not.
    /// </summary>
    /// <returns>boolean - true if it should be secure</returns>
    private bool IsLoginTokenSecure()
    {
      return ConfigHelper.IsLoginTokenSecure(m_asOwner.GetCurrentRequestURL());
      }
    
    /// <param name="webData"></param>
    public virtual void Logout(IWebData webData)
    {
      log.Debug("Logout()");
      SetSession(null);
      LoginHelper.INSTANCE.ClearAutologinToken(m_asOwner.GetCurrentRequestURL(),
       webData);
      // Not setting an expires value on a cookie uses the default behaviour in both
      // Java and .NET (deleted when browser is closed).
      // Perhaps this should delete the cookie (0 in Java, time in the past on .NET)
      XPCookie cookie = new XPCookie(LoginHandlers.LOGIN_OCCURED_COOKIE_NAME,
       XPConvert.ToString(false));
      cookie.SetPath("/");
      webData.AddCookie(cookie);
    }
    
    /// <param name="s"></param>
    public virtual void SetAuthSource(String s)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetSelectedAuthSource(s);
    }
    
    /// <param name="b"></param>
    public virtual void SetRememberPassword(bool b)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetRememberPassword(b);
    }
    
    /// <param name="s"></param>
    public virtual void SetToken(String s)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetToken(s);
    }
    
    /// <param name="s"></param>
    public virtual void SetUserName(String s)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetUserName(s);
    }
    
    /// <param name="s"></param>
    public virtual void SetUserPass(String s)
    {
      TempData td = (TempData) this.GetTempData();
      td.SetUserPass(s);
    }
    
    /// <summary>
    /// This method attempts to log the user into the portal.
    /// </summary>
    /// <param name="webData">
    /// Pass an IWebData.  Cookies may be added to this
    /// object if the user wishes to save the username and password.
    /// </param>
    /// <returns>Redirect A redirect, if applicable.</returns>
    public virtual Redirect attemptLogin(IXPRequest request, IWebData webData)
    {
      log.Info("Entering attemptLogin()");
      TempData td = (TempData) this.GetTempData();
      td.SetLoginAttempted(true);
      td.SetLoginSucceeded(true);
      Object oPreviousSessionValidAttribute = m_asOwner.GetSubSession().GetAttribute(Interpreter.USERSESSIONVALID);
      String sUserName = td.GetUserName();
      String sUserPass = td.GetUserPass();
      String sToken = td.GetToken();
      bool bRememberPassword = td.GetRememberPassword();
      String sAuthSource = td.GetSelectedAuthSource(this.m_asOwner);
      // If no auth source was selected by the user
      if (sAuthSource == null)
      {
        // 0 = no default yes dropdown, 1 = use default, no dropdown,
        // 2 = yes dropdown, set to default, 3 = use default, no dropdown ever
        if (GetAllowDefaultAuthSourceMode() != 0)
        {
          sAuthSource = td.GetDefaultAuthSourcePrefix(m_asOwner);
        } else
        {
          log.Error("attemptLogin() - no Auth source set in Auth Source mode 0 (no default, use auth source dropdown).  This should never happen.");
          }
      }
      IPTSession myIPTSession = null;
      log.Debug("attemptLogin() - sUserName: " + sUserName);
      log.Debug("attemptLogin() - sAuthSource: " + sAuthSource);
      log.Debug("attemptLogin() - sToken: " + sToken);
      LoginResult loginResult;
      if ((sToken != null) && (sUserName == null))
      {
        // if we have a login token, and no username, then we'll try to
        //	use the login token.  If we have a username, we'll
        //	assume that the user is attempting to override the
        //	token.
        loginResult = LoginHelper.INSTANCE.AttemptLogin(sToken, m_asOwner,
         request, webData);
      } else
      {
        //	otherwise, we'll just use the username and password
        //	the name that will actually be used to log in.
        String sLoginName = sUserName;
        //	if the user selected an auth source, we prepend the
        //	authsource prefix to the username.
        if ((sAuthSource != null) && (!"".Equals(sAuthSource)))
        {
          sLoginName = sAuthSource + AUTH_SOURCE_USER_SEPARATOR + sUserName;
          }
        log.Debug("attemptLogin() - sLoginName: " + sLoginName);
        loginResult = LoginHelper.INSTANCE.AttemptLogin(sLoginName, sUserPass,
         null, false, m_asOwner, request, webData);
      }
      myIPTSession = (IPTSession) loginResult.m_UserSession;
      if ((myIPTSession != null) && LoginHelper.INSTANCE.GetIsGuestUser(myIPTSession))
      {
        log.Error("Ignoring attempted login for guest user. Possible hack attempt.");
        // You can't specifically log in as guest.
        myIPTSession = null;
        loginResult.m_bSuccess = false;
        loginResult.m_strError = m_asOwner.GetString(1574, ResourceConstants.PORTALBROWSINGMSGS);
        loginResult.m_UserSession = null;
      }
      if (loginResult.m_bSuccess)
      {
        if (!loginResult.m_bRedirectedBeforeLogin)
        {
          td.SetLoginSucceeded(true);
          td.SetPTSession(myIPTSession);
          // Clear the redirect after login entry from sandbox (if any) used by the
          // login portlet and the tag login portlet,
          // as the login is sucessful and this.SetRedirectAfterLogin() must have been 
          // called by LoginControl.CheckActionSecurityAndExecute()
          m_asOwner.GetSubSession().RemoveAttribute("PT_" + ASConstants.REDIRECT_AFTER_LOGIN);
          }
      } else
      {
        //	login failed
        ProcessFailedLogin(loginResult.m_strError, sUserName, oPreviousSessionValidAttribute);
        }
      //	we shouldn't remember the password if the login
      //	didn't succeed.
      if ((td.GetLoginSucceeded()) && !loginResult.m_bRedirectedBeforeLogin)
      {
        // login succeeded
        if (null != webData)
        {
          XPCookie cookie = null;
          // Add the login occurred cookie
          // Not setting an expires value on a cookie uses the default behaviour
          // in both Java and .NET (deleted when browser is closed).
          cookie = new XPCookie(LoginHandlers.LOGIN_OCCURED_COOKIE_NAME, XPConvert.ToString(true));
          cookie.SetPath("/");
          webData.AddCookie(cookie);
          // ES - check if HA is enabled.  If so, generate cookie in browser.
          // Put it in cache.  Tie it to openhttp and sessionprefs.
          if (true == ReplicationCache.GetEnabled())
          {
            log.Info("Failover is enabled.  Adding replication cookie to web browser.");
            // RT - generate a new LoginToken for replication with timeout value based on BrowserTokenExpiration for HA mode.
            //      If BrowserTokenExpiration is 0 then we set the Replication cookie to expire in 2 weeks.
            //      If BrowserTokenExpiration not a 0 value then we set the Replication cookie expiration to BrowserTokenExpiration value.
            int nTokenExpiration = GetBrowserTokenExpiration();
            if (nTokenExpiration <= 0)
            {
              nTokenExpiration = 60 * 24 * 14;
            }
            //MES- Note: this token should last for some time.  It should NOT expire
            //  during any normal user session, or that session won't be able to 
            //  use it for failover!  See bug 54224.
            String strRepToken = myIPTSession.GetToken(nTokenExpiration);
            XPCookie repCookie = new XPCookie(LoginHelper.REPLICATION_COOKIE_NAME,
             strRepToken);
            repCookie.SetPath("");
            webData.AddCookie(repCookie);
            // add the login token to the replicatin cache as key and a 
            // new ReplicationCacheEntry as value
            ReplicationCacheEntry rce = new ReplicationCacheEntry(strRepToken);
            IOKHttpSession session = myIPTSession.GetHttpUserSession();
            // set callback to IOKHttpSession
            session.SetSessionStateChangeCallback(rce);
            // set callback to IPTSessionInfo
            myIPTSession.GetSessionInfo().SetSessionPreferenceChangeCallback(rce);
            log.Info("Failover setup done.");
          }
          if (bRememberPassword)
          {
            log.Debug("attemptLogin() - about to remember my password.");
            // Tells helper method to look it up from config files.
            LoginHelper.INSTANCE.SetAutologinToken(webData, request, myIPTSession,
             -1, true);
          } else
          {
            // Default 0 minutes (no cookie)
            // Positive values mean set a browser token (no expires), but expire the login
            // token after this many minutes.
            int nTokenExpiration = GetBrowserTokenExpiration();
            //RT - Login Token is set only if AllowAutoConnect is enabled
            // We check if AllowAutoConect is '1' in portal config before
            // setting the login token cookie.
            bool bAllowAutoConnect = PTLoginHelper.ShowRememberMyPassword();
            if (nTokenExpiration > 0 && bAllowAutoConnect)
            {
              // false means not setting an expires value on a cookie uses the default behaviour
              // in both Java and .NET (deleted when browser is closed).  Unless
              // RMP is occurring, we want the cookie to expire with the browser session.
              LoginHelper.INSTANCE.SetAutologinToken(webData, request, myIPTSession,
               nTokenExpiration, false);
            }
          }
        } else
        {
          log.Error("attemptLogin() - webdata is null, cannot set cookies.");
          }
        if (SSOIntegrator.IsCaptureBasicAuthEnabled())
        {
          IPTSSOInfo ptSSOInfo = PortalObjectsFactory.CreateSSOInfo();
          ptSSOInfo.SetBasicAuthName(sUserName);
          ptSSOInfo.SetBasicAuthPassword(sUserPass);
          this.m_asOwner.GetSubSession().SetAttribute(PlumtreeExtensibility.PT_SSOINFO_ON_STATE,
           ptSSOInfo);
        }
      }
      //	 login succeeded
      return loginResult.m_Redirect;
    }
    
    /// <summary>
    /// This helper method raises a UI error and handles failed
    /// logins in the LoginModel.
    /// </summary>
    /// <param name="_strErrorMessage">The failure error message.</param>
    /// <param name="_strUserName">The user name.</param>
    /// <param name="_oPreviousSessionValidAttribute">
    /// The previous value
    /// of the USERSESSIONVALID attribute.
    /// </param>
    protected virtual void ProcessFailedLogin(String _strErrorMessage, String _strUserName,
     Object _oPreviousSessionValidAttribute)
    {
      // Bug 41762 - Failed login should redirect based on the subportal's login page setting.
      // The login failed, so set this flag to false so that next call to 
      // DefaultLoginControl.CheckActionSecurityAndExecute() will render the login page,
      // otherwise it will attempt to login again (infinite loop). 
      SetDoAttemptLogin(false);
      TempData td = (TempData) this.GetTempData();
      //	login failed
      log.Info("AttemptLogin failed for user " + _strUserName + ": " + _strErrorMessage);
      UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
       null, _strErrorMessage, _strErrorMessage);
      // Bug 41762 - Failed login always redirects user to the default login 
      // space (instead of based on the subportal's login page setting).
      // "Login page" can be the LoginAS or the MyPage AS (for guest MyPage as login page)
      // myError.SetActivitySpace(m_asOwner.GetName());
      // myError.SetClearWithActivitySpaceChange(true);
      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
      td.SetLoginSucceeded(false);
      td.SetPTSession(null);
      // In normal cases, the LoginHelper will handle this, but if login
      // fails, the LoginHelper will set the session as INVALID.  Since we
      // may still be logged in as a valid user, we need to replace this
      // with it's previous value (invalid if the previous user was guest,
      // valid if they were not).
      // TODO: Should this even be here?
      // Guest user / invalid user
      m_asOwner.GetSubSession().SetAttribute(Interpreter.USERSESSIONVALID,
       _oPreviousSessionValidAttribute);
    }
    
    /// <summary>
    /// Helper method to get the browser token cookie expiration value from
    /// the PTconfig files.
    /// Logs an error and returns a reasonable default value if there
    /// are problems.
    /// </summary>
    /// <param name="_tempData"></param>
    /// <returns>int nExpiration in minutes - -1 means do not set the cookie, 0 means browser token.</returns>
    public virtual int GetBrowserTokenExpiration()
    {
      int nExpiration;
      try
      {
        nExpiration = PTConfigHelper.GetConfigVariableAsInt(ConfigConstants.AUTHENTICATION_SECTION,
         PTConfigConstants.BROWSERLOGINTOKENEXPIRATION_SUBSECTION, ConfigConstants.VALUE_ATTRIBUTE,
         m_asOwner);
      }
      catch (Exception e)
      {
        log.Warn(e, "Unable to get valid " + PTConfigConstants.BROWSERLOGINTOKENEXPIRATION_SUBSECTION + " value.  Using default.");
        // Default value - no cookie
        nExpiration = -1;
      }
      return nExpiration;
    }
    
    /// <summary>
    /// This class is used to store the login data on the AClearModel.
    /// This is public so that the login model can be extended and overridden.
    /// C# translation does not allow protected for inner classes.
    /// </summary>
    /// <author>BenG</author>
    public class TempData
    {
      protected IPTSession m_ptSession = null;
      protected bool bDoAttemptLogin = false;
      protected bool bDoAttemptLogout = false;
      protected bool bLoginAttempted = false;
      protected bool bLoginSucceeded = false;
      protected bool bRememberPassword = false;
      protected bool bShowAuthSources = true;
      protected bool bShowAuthSourcesSet = false;
      protected String sSelectedAuthSource = null;
      protected String sToken;
      protected String sUserName;
      protected String sUserPass;
      protected int iAccessStyle = -1;
      protected int iAllowDefaultAuthSource = -1;
      protected String sDefaultAuthSourcePrefix = null;
      public virtual bool GetShowAuthSourcesSet()
      {
        return bShowAuthSourcesSet;
      }
      public virtual void SetShowAuthSourcesSet(bool b)
      {
        bShowAuthSourcesSet = b;
      }
      public virtual String GetDefaultAuthSourcePrefix(AActivitySpace aSpace)
      {
        if (sDefaultAuthSourcePrefix == null)
        {
          try
          {
            //	default access style for all users.
            sDefaultAuthSourcePrefix = PTConfigHelper.GetConfigVariableAsString("Authentication",
             "DefaultAuthSourcePrefix", "value", aSpace);
          }
          catch (Exception ex)
          {
            log.Debug(ex, "LoginModel::GetDefaultAuthSourcePrefix. An exception occured.");
            }
        }
        return sDefaultAuthSourcePrefix;
      }
      public virtual int GetAllowDefaultAuthSource()
      {
        return iAllowDefaultAuthSource;
      }
      
      /// <returns></returns>
      public virtual int GetAccessStyle()
      {
        return iAccessStyle;
      }
      
      /// <returns></returns>
      public virtual String GetSelectedAuthSource(AActivitySpace aSpace)
      {
        return sSelectedAuthSource;
      }
      
      /// <returns></returns>
      public virtual bool GetDoAttemptLogin()
      {
        return bDoAttemptLogin;
      }
      
      /// <returns></returns>
      public virtual bool GetDoAttemptLogout()
      {
        return bDoAttemptLogout;
      }
      
      /// <returns></returns>
      public virtual bool GetLoginAttempted()
      {
        return bLoginAttempted;
      }
      
      /// <returns></returns>
      public virtual bool GetLoginSucceeded()
      {
        return bLoginSucceeded;
      }
      
      /// <returns></returns>
      public virtual IPTSession GetPTSession()
      {
        return m_ptSession;
      }
      
      /// <returns></returns>
      public virtual bool GetRememberPassword()
      {
        return bRememberPassword;
      }
      
      /// <returns></returns>
      public virtual bool GetShowAuthSources()
      {
        return bShowAuthSources;
      }
      
      /// <returns></returns>
      public virtual String GetToken()
      {
        return sToken;
      }
      
      /// <returns></returns>
      public virtual String GetUserName()
      {
        return sUserName;
      }
      
      /// <returns></returns>
      public virtual String GetUserPass()
      {
        return sUserPass;
      }
      
      /// <param name="i"></param>
      public virtual void SetAccessStyle(int i)
      {
        iAccessStyle = i;
      }
      
      /// <param name="s"></param>
      public virtual void SetSelectedAuthSource(String s)
      {
        sSelectedAuthSource = s;
      }
      
      /// <param name="b"></param>
      public virtual void SetDoAttemptLogin(bool b)
      {
        bDoAttemptLogin = b;
      }
      
      /// <param name="b"></param>
      public virtual void SetDoAttemptLogout(bool b)
      {
        bDoAttemptLogout = b;
      }
      
      /// <param name="b"></param>
      public virtual void SetLoginAttempted(bool b)
      {
        bLoginAttempted = b;
      }
      
      /// <param name="b"></param>
      public virtual void SetLoginSucceeded(bool b)
      {
        bLoginSucceeded = b;
      }
      
      /// <param name="s"></param>
      public virtual void SetPTSession(IPTSession s)
      {
        m_ptSession = s;
      }
      
      /// <param name="b"></param>
      public virtual void SetRememberPassword(bool b)
      {
        bRememberPassword = b;
      }
      
      /// <param name="b"></param>
      public virtual void SetShowAuthSources(bool b)
      {
        bShowAuthSources = b;
      }
      
      /// <param name="s"></param>
      public virtual void SetToken(String s)
      {
        sToken = s;
      }
      
      /// <param name="s"></param>
      public virtual void SetUserName(String s)
      {
        sUserName = s;
      }
      
      /// <param name="s"></param>
      public virtual void SetUserPass(String s)
      {
        sUserPass = s;
      }
      public virtual void SetAllowDefaultAuthSource(int i)
      {
        iAllowDefaultAuthSource = i;
      }
      public virtual void SetDefaultAuthSourcePrefix(String s)
      {
        sDefaultAuthSourcePrefix = s;
      }
    }
  }
}