using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openfoundation.security;
using com.plumtree.openlog;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.login.createaccount
{
  /// <summary>
  /// Creates a new user account.  Used by "CreateAccount" linkas well as portal invite.
  /// </summary>
  /// <author>BenG</author>
  /// <author>DavidP overhauled to add support for invite-based create account</author>
  public class CreateAccountModel : IModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.login.createaccount.CreateAccountModel");
    
    /// <summary>
    /// The unique name for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CreateAccountModel";
    protected AActivitySpace m_asOwner = null;
    private String sInvite = null;
    private String sUserName = null;
    private String sUserPass = null;
    private bool bGetSession = false;
    private IPTSession ptSession = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
      ptSession = null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CreateAccountModel();
    }
    
    /// <summary>
    /// Implement the account creation
    /// </summary>
    /// <returns>Redirect</returns>
    public virtual Redirect DoCreateAccount(IXPRequest request, IWebData webData)
    {
      IPTSession mySession = null;
      log.Debug("DoCreateAccount() - sUserName: " + sUserName);
      log.Debug("DoCreateAccount() - sUserPass: " + sUserPass);
      log.Debug("DoCreateAccount() - sInvite: " + sInvite);
      bool bCreateSucceeded = false;
      try
      {
        mySession = (IPTSession) m_asOwner.GetUserSession();
        IPTObjectManager om = mySession.GetUsers();
        IPTUserManager userOm = (IPTUserManager) om.GetInterfaces("IPTUserManager");
        //PEI : OnBeforeCreateAccount
        //BrianH - This set of code will process all of the available OnBeforeCreateAccount PEIs
        //and process each of them before moving on to the actual creation of the account.
        //A error message may be returned, at which point the process will be stopped and returned
        //to the user.
        Object[] oa;
        Object o;
        ICreateAccountActions iActions;
        IApplication application = m_asOwner.GetApplication();
        oa = (Object[]) application.GetCachingManager().GetEntry("CreateAccountActions");
        if (oa != null)
        {
          String sErrorMsgs = "";
          for (int x = 0;x < oa.Length;x++)
          {
            o = oa[x];
            log.Debug("DoCreateAccount() - About to call OnBeforeCreateAccount on an: " + o);
            if (o != null)
            {
              String sError;
              iActions = (ICreateAccountActions) o;
              sError = iActions.OnBeforeCreateAccount(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
               sUserName, sUserPass);
              if ((null != sError) && (sError.Length > 0))
              {
                sErrorMsgs+=sError + " ";
              }
            }
          }
          if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
          {
            UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
             null, sErrorMsgs, sErrorMsgs);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            bCreateSucceeded = false;
            //Lets the Interpreter know that something went wrong.
            bGetSession = false;
            return null;
          }
        }
        //PEI : OnBeforeCreateAccount : END
        IPTUser newUser;
        if (sInvite != null)
        {
          // yes invitation
          log.Debug("DoCreateAccount() - Accepting invitation.");
          IPTSession session = userOm.AcceptInvitation(sInvite, sUserName,
           sUserPass);
          newUser = session.GetUser();
        } else
        {
          // no invitation
          //	todo determine id of default subportal folder
          newUser = (IPTUser) om.Create(PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTSUBPORTAL);
          IPTServerContext mySC = (IPTServerContext) newUser.GetInterfaces("IPTServerContext");
          newUser.SetAuthenticationSourceID(PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE);
          newUser.SetDescription(this.m_asOwner.GetString(1567, "ptmsgs_portalbrowsingmsgs"));
          newUser.SetLoginName(sUserName);
          newUser.SetName(sUserName);
          newUser.SetPassword(sUserPass);
          mySC.SetSettings(PT_SERVERCONTEXT_SETTINGS.PT_SERVERCONTEXT_AUTOUNIQUENAMING,
           0);
          mySC.Store();
        }
        try
        {
          // Set the Last Password Change property for the new user.
          long lNow = XPSystem.GetCurrentTimeMilliSec();
          IPTObjectProperties props = newUser.GetObjectProperties();
          Object[][] propdata = new Object[2][];
          for (int j2c_index = 0;j2c_index < 2;j2c_index++)
          {
            propdata[j2c_index] = new Object[1];
          }
          propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_PROPERTYID][0] = PT_INTRINSICS.PT_PASSWORD_LAST_CHANGED;
          propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_VALUE][0] = lNow;
          props.SetPropertyData(propdata);
        }
        catch (Exception e)
        {
          log.Warn(e, "Unable to set Last Password Change for new user " + sUserName + ". Ignoring error.");
          }
        bCreateSucceeded = true;
      }
      catch (Exception ex)
      {
        //	prevents Interpreter from attempting to 
        //	get the ptsession.
        bGetSession = false;
        String sMessage = m_asOwner.GetString(1248, "ptmsgs_portalbrowsingmsgs");
        if (ex is PTException)
        {
          PTException ptex = (PTException) ex;
          int i = ptex.GetErrorCode();
          if (i == PT_RESULTCODES.PT_E_INVITATIONEXHAUSTED)
          {
            sMessage = this.m_asOwner.GetString(1568, "ptmsgs_portalbrowsingmsgs");
            } else
          if (i == PT_RESULTCODES.PT_E_INVITATIONEXPIRED)
          {
            sMessage = this.m_asOwner.GetString(1569, "ptmsgs_portalbrowsingmsgs");
            } else
          if (i == PT_RESULTCODES.PT_E_INVITATIONINVALID)
          {
            sMessage = this.m_asOwner.GetString(1570, "ptmsgs_portalbrowsingmsgs");
            } else
          if (i == PT_RESULTCODES.PT_E_NAMENOTUNIQUE)
          {
            sMessage = this.m_asOwner.GetString(1670, "ptmsgs_portalbrowsingmsgs");
            } else
          //This actually corresponds to admin folder not existing when invoked from invitations
          if (i == PT_RESULTCODES.PT_E_INVALIDARG)
          {
            sMessage = this.m_asOwner.GetString(1675, "ptmsgs_portalbrowsingmsgs");
            GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Browsing"),
             "CreateAccountModel::DoCreateAccount", ex, true, UIErrorLevel.FRIENDLY,
             sMessage);
          } else
          //Password too long.  Must be 20 characters
          if (i == PT_RESULTCODES.PT_E_PASSWORDINVALID)
          {
            sMessage = this.m_asOwner.GetString(1676, "ptmsgs_portalbrowsingmsgs");
            }
        }
        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Browsing"),
         "CreateAccountModel::DoCreateAccount", ex, false, UIErrorLevel.FRIENDLY,
         sMessage);
      }
      if (bCreateSucceeded)
      {
        int nAccessStyle = m_asOwner.GetAccessStyle().GetAccessID();
        LoginResult loginResult = LoginHelper.INSTANCE.AttemptLogin(sUserName,
         sUserPass, null, false, m_asOwner, request, webData);
        if (loginResult.m_bSuccess)
        {
          //	everything worked
          //	ensures the Interpreter will attempt
          //	to get the ptsession
          bGetSession = true;
          ptSession = (IPTSession) loginResult.m_UserSession;
          if (nAccessStyle != AccessStyles.STANDARD.GetAccessID())
          {
            // if the user created the account from a 508/low-bandwidth login page, then set their access style appropriately.
            ptSession.GetSessionInfo().AddPreference(PersonalSettingNames.ACCESS_STYLE,
             nAccessStyle, 0);
            IApplication application = m_asOwner.GetApplication();
            XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
            PTPersonalSettingsHelper.SetAndCachePersonalSetting(PersonalSettingNames.ACCESS_STYLE,
             nAccessStyle, ptSession, m_asOwner.GetSubSession(), application,
             rm);
          }
        } else
        {
          log.Info("AttemptLogin failed for user " + sUserName + ": " + loginResult.m_strError);
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, loginResult.m_strError, loginResult.m_strError);
          myError.SetActivitySpace(m_asOwner.GetName());
          myError.SetClearWithActivitySpaceChange(true);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          // prevents the interpreter from trying
          // to get the ptsession.
          bGetSession = false;
          ptSession = null;
        }
        // Return the login PEI redirect, if it exists.
        return loginResult.m_Redirect;
      }
      return null;
    }
    
    /// <returns></returns>
    public virtual bool DoGetSession()
    {
      return bGetSession;
    }
    
    /// <returns></returns>
    public virtual IPTSession GetSession()
    {
      return ptSession;
    }
    
    /// <returns></returns>
    public virtual String GetInviteCode()
    {
      return sInvite;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual String GetUserName()
    {
      return sUserName;
    }
    
    /// <returns></returns>
    public virtual String GetUserPass()
    {
      return sUserPass;
    }
    
    /// <summary>
    /// Inits the Model with the Activity Space.
    /// </summary>
    /// <param name="parent"></param>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      ptSession = (IPTSession) parent.GetUserSession();
    }
    
    /// <param name="s"></param>
    public virtual void SetInviteCode(String s)
    {
      sInvite = s;
    }
    
    /// <param name="s"></param>
    public virtual void SetUserName(String s)
    {
      sUserName = s;
    }
    
    /// <param name="s"></param>
    public virtual void SetUserPass(String s)
    {
      sUserPass = s;
    }
    
    /// <summary>
    /// Uses the server setting to generate the crypto token for create account invite
    /// TODO: Generate one based on date, so it will expire rapidly
    /// </summary>
    /// <returns>String token for invite</returns>
    public virtual String GetCreateUserInviteToken()
    {
      // Get the invite cipher key
      IPTSession mySession = (IPTSession) m_asOwner.GetUserSession();
      IPTServerConfigSettings config = (IPTServerConfigSettings) mySession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       true);
      String cipherKey = "";
      Object oValue = config.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_INVITE_CIPHER_KEY);
      if (null != oValue)
      {
        cipherKey = (String) oValue;
      } else
      {
        // The cipher key has not been set
        log.Error("The server config setting for \'internal cipher key\' is missing or has not been set.  Please check your database schema or reinstall (PT_SETTINGNAME_INVITE_CIPHER_KEY)");
        // Unfortunately, this error occurs too late in the page display
        // cycle, and so the error will not be displayed.
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1659, "ptmsgs_portalbrowsingmsgs"), "");
        myError.SetActivitySpace(m_asOwner.GetName());
        myError.SetClearWithActivitySpaceChange(true);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        throw new XPException("The server config setting for \'internal cipher key\' is missing or has not been set.  Please check your database schema or reinstall (PT_SETTINGNAME_INVITE_CIPHER_KEY)");
        }
      // Encrypt the create user invite command		
      IXPCrypto pCrypto = XPCrypto.GetInstance(XPCryptoType.AES_128);
      String argument = pCrypto.Encrypt(CreateAccountControl.INVITE_CREATEUSER_COMMAND,
       cipherKey);
      return argument;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
  }
}