using System;
using XPResourceManager=com.plumtree.openfoundation.internationalization.XPResourceManager;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using ResourceConstants=com.plumtree.portalpages.common.constants.ResourceConstants;
using PasswordValidationHelper=com.plumtree.portalpages.common.passwordvalidation.PasswordValidationHelper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using BrowserType=com.plumtree.uiinfrastructure.activityspace.utils.BrowserType;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.login.createaccount
{
  /// <summary>
  /// Create Account web page, allows user to enter desired username, password
  /// Updated to support intrinsic invite object
  /// </summary>
  /// <author>BenG</author>
  /// <author>DavidP</author>
  public class CreateAccountView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.login.createaccount.CreateAccountView");
    public const String STR_MVC_CLASS_NAME = "CreateAccountView";
    public const String HTMLBUTTON_CREATEACCOUNT = "in_bu_CreateAccount";
    public const String PARAM_DOCREATE_508 = "in_su_CreateAccount_508";
    internal const String STR_FORM_NAME = "lform";
    internal const String STR_FORM_ID = "createAccountFormID";
    private AActivitySpace m_asOwner;
    private CreateAccountModel m_asmModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CreateAccountView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      IPTServerConfigSettings config = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       true);
      bool allowAccountCreation = (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ALLOW_NEW_USER_CREATION_TO_ALL) == 1);
      // If allow account creation is off, send an error unless we have a possible invite code.
      String inviteCode = m_asmModel.GetInviteCode();
      if (!allowAccountCreation && (inviteCode == null || inviteCode.Equals("")))
      {
        String msg = m_asOwner.GetString(1711, "ptmsgs_portalbrowsingmsgs");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        throw new XPException(msg);
      }
      HTMLForm myForm = null;
      HTMLElementCollection eOut = new HTMLElementCollection();
      HTMLTable myTable = new HTMLTable();
      myTable.SetCellPadding("2");
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetAlign(CommonHTMLStrings.CENTER);
      myTable.SetWidth("400");
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      HTMLScript myPasswordValidationScript;
      int nMinimumLength = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_LENGTH);
      bool bIncludeNumbers = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_NUMBERS);
      bool bIncludeCasing = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_CASING);
      bool bIncludePunctuation = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_PUNCTUATION);
      bool bNoUserIds = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_NO_USER_IDS);
      int nReuseHistory = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_REUSE_HISTORY);
      BrowserType bt = new BrowserType(m_asOwner.GetCurrentHTTPRequest());
      String strRuleCellHeight = "20px";
      String invalidIconURL = PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner) + PasswordValidationHelper.STR_INVALID_ICON_FILENAME;
      String warningIconURL = PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner) + PasswordValidationHelper.STR_WARNING_ICON_FILENAME;
      String imgInvalidIconHTML = "<img src=\'" + invalidIconURL + "\' border=\'0\'/>";
      String imgWarningIconHTML = "<img src=\'" + warningIconURL + "\' border=\'0\'/>";
      try
      {
        myForm = new HTMLForm(STR_FORM_ID);
        // Include the javascript file needed for client-side password validation
        myPasswordValidationScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        myPasswordValidationScript.SetSrc(PasswordValidationHelper.GetPasswordValidationJSURL(m_asOwner));
        eOut.AddInnerHTMLElement(new HTMLComment("Begin: Create Account View"));
        eOut.AddInnerHTMLElement(myPasswordValidationScript);
        eOut.AddInnerHTMLElement(myForm);
        myForm.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(),
         m_asOwner.GetName(), m_asOwner.IsSubSpace()));
        myForm.SetMethod(CommonHTMLStrings.POST);
        myForm.SetName(STR_FORM_NAME);
        // Sets the space name for the event to be passed to the server
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACENAME_INPUT,
         ASConstants.SPACENAME_INPUT, "This is an input");
        myInput.SetValue(m_asOwner.GetName());
        myForm.AddInnerHTMLElement(myInput);
        // Sets the space ID for the event to be passed to the server
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACEID_INPUT,
         ASConstants.SPACEID_INPUT, "This is an input");
        myInput.SetValue(m_asOwner.GetSpaceID());
        myForm.AddInnerHTMLElement(myInput);
        // Sets the control name for the event to be passed to the server
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.CONTROL_INPUT,
         ASConstants.CONTROL_INPUT, "This is an input");
        myInput.SetValue(CreateAccountControl.STR_MVC_CLASS_NAME);
        myForm.AddInnerHTMLElement(myInput);
        // Sets the create account invite parameter
        // or uses the passed in invite token
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, CreateAccountControl.CONTROLARGUMENT_INVCODE,
         CreateAccountControl.CONTROLARGUMENT_INVCODE, "This is an input");
        if ((m_asmModel.GetInviteCode() != null) && (m_asmModel.GetInviteCode().Length > 0))
        {
          myInput.SetValue(m_asmModel.GetInviteCode());
        } else
        {
          myInput.SetValue(m_asmModel.GetCreateUserInviteToken());
        }
        myForm.AddInnerHTMLElement(myInput);
        // Sets the dologin parameter
        myInput = new HTMLInput(HTMLInputTypes.HIDDEN, CreateAccountControl.PARAM_DOCREATEACCOUNT,
         CreateAccountControl.PARAM_DOCREATEACCOUNT, "This is an input");
        myInput.SetValue(XPConvert.ToString(false));
        myForm.AddInnerHTMLElement(myInput);
        myForm.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TITLE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(1, "ptmsgs_portalbrowsingmsgs"));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(2, "ptmsgs_portalbrowsingmsgs"));
        myTable = new HTMLTable();
        myForm.AddInnerHTMLElement(myTable);
        myTable.SetCellPadding("2");
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetAlign(CommonHTMLStrings.CENTER);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        // BEGIN *************** Username row, input and status fields **********************
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetColSpan("2");
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("40%");
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell.AddInnerHTMLString(m_asOwner.GetString(3, "ptmsgs_portalbrowsingmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("10%");
        //myCell.SetColSpan("2");
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, CreateAccountControl.PARAM_USERNAME,
         CreateAccountControl.PARAM_USERNAME, m_asOwner.GetString(1796, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetSize("30");
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          // Special Case for IE Browsers. We need to detect backspace key
          // on the OnKeyDown event instead of the OnKeyPress.
          if (bt.IsIE())
          {
            myInput.SetOnKeyDown("return " + PasswordValidationHelper.STR_JS_HANDLE_BACKSPACE_INPUT + "(event, this);");
            }
          // Call key input handler from ptpasswordvalidation.js to provide input feedback.
          myInput.SetOnKeyPress("return " + PasswordValidationHelper.STR_JS_HANDLE_USER_INPUT + "(event, this);");
          }
        myCell.AddInnerHTMLElement(myInput);
        // Add hidden status field
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("50%");
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
        myCell.SetID(PasswordValidationHelper.STR_USERNAME_VALIDATION_STATUS_NAME);
        // END *************** Username row, input and status fields **********************
        // START *************** Password row, input and status fields **********************
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("40%");
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(4, "ptmsgs_portalbrowsingmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("10%");
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.PASSWORD, CreateAccountControl.PARAM_USERPASS,
         CreateAccountControl.PARAM_USERPASS, m_asOwner.GetString(1797, "ptmsgs_portalbrowsingmsgs"));
        myInput.SetSize("30");
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          // Special Case for IE Browsers. We need to detect backspace key
          // on the OnKeyDown event instead of the OnKeyPress.
          if (bt.IsIE())
          {
            myInput.SetOnKeyDown("return " + PasswordValidationHelper.STR_JS_HANDLE_BACKSPACE_INPUT + "(event, this);");
            }
          myInput.SetOnKeyPress("return " + PasswordValidationHelper.STR_JS_HANDLE_USER_INPUT + "(event, this);");
          }
        myCell.AddInnerHTMLElement(myInput);
        // Add hidden status field
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("50%");
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
        myCell.SetID(PasswordValidationHelper.STR_PASSWORD_VALIDATION_STATUS_NAME);
        // END *************** Password row, input and status fields **********************
        // START *************** Confirm Password row, input and status fields **********************
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("40%");
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myCell.AddInnerHTMLString(m_asOwner.GetString(5, "ptmsgs_portalbrowsingmsgs"));
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("60%");
        myCell.SetColSpan("2");
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.PASSWORD, CreateAccountControl.PARAM_CONFIRM_USERPASS,
         CreateAccountControl.PARAM_CONFIRM_USERPASS, m_asOwner.GetString(1798,
         "ptmsgs_portalbrowsingmsgs"));
        myInput.SetSize("30");
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          myInput.SetOnKeyPress("return " + PasswordValidationHelper.STR_JS_HANDLE_USER_INPUT + "(event, this);");
          }
        myCell.AddInnerHTMLElement(myInput);
        // END *************** Confirm Password row, input and status fields **********************
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell = new HTMLTableCell();
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myRow.AddInnerHTMLElement(myCell);
        // START *************** Create Account Button **********************
        HTMLInput myLoginInput;
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          myLoginInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CREATEACCOUNT,
           m_asOwner.GetString(0, "ptmsgs_portalbrowsingmsgs"));
          myLoginInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          myLoginInput.SetOnClick(PasswordValidationHelper.STR_JS_CREATE_ACCOUNT + "(); return false;");
          } else
        {
          myLoginInput = new HTMLInput(HTMLInputTypes.SUBMIT_TYPE, PARAM_DOCREATE_508,
           m_asOwner.GetString(0, "ptmsgs_portalbrowsingmsgs"));
          myLoginInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        }
        myLoginInput.SetValue(m_asOwner.GetString(0, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(myLoginInput);
        // END *************** Create Account Button **********************
        // BEGIN *************** Password Management Rules **********************
        myForm.AddInnerHTMLElement(new HTMLBr());
        myTable = new HTMLTable();
        myForm.AddInnerHTMLElement(myTable);
        myTable.SetCellPadding("2");
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetAlign(CommonHTMLStrings.CENTER);
        myTable.SetWidth("400");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        myCell.SetColSpan("2");
        // Display password restrictions message
        myCell.AddInnerHTMLString(m_asOwner.GetString(2000, "ptmsgs_portalbrowsingmsgs"));
        // Display all the required Password Management Rules
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        myCell = new HTMLTableCell();
        myCell.SetWidth("5%");
        myCell.SetHeight(strRuleCellHeight);
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        // Set a section to display "X" or checkmark icon for reporting feedback.
        mySpan.SetID(PasswordValidationHelper.STR_MIN_MAX_LENGTH_STATUS_NAME);
        // Add valid/invalid icon for rule
        mySpan.AddInnerHTMLString(imgInvalidIconHTML);
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myCell = new HTMLTableCell();
        myCell.SetWidth("95%");
        myCell.SetHeight(strRuleCellHeight);
        myRow.AddInnerHTMLElement(myCell);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        // Password must be between X and 20 chars
        mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1999,
         ResourceConstants.PORTALBROWSINGMSGS), nMinimumLength));
        if (bIncludeNumbers)
        {
          // Display Include Numbers Status Icon and Rule
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myCell = new HTMLTableCell();
          myCell.SetWidth("5%");
          myCell.SetHeight(strRuleCellHeight);
          myCell.SetAlign(CommonHTMLStrings.RIGHT);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          // Set a section to display "X" or checkmark icon for reporting feedback.
          mySpan.SetID(PasswordValidationHelper.STR_NUMBER_STATUS_NAME);
          // Add valid/invalid icon for rule
          mySpan.AddInnerHTMLString(imgInvalidIconHTML);
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell = new HTMLTableCell();
          myCell.SetWidth("95%");
          myCell.SetHeight(strRuleCellHeight);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          // Password must contain a number
          mySpan.AddInnerHTMLString(m_asOwner.GetString(1984, ResourceConstants.PORTALBROWSINGMSGS));
          }
        if (bIncludeCasing)
        {
          // Display Include Uppper and Lower Case Status Icon and Rule
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myCell = new HTMLTableCell();
          myCell.SetWidth("5%");
          myCell.SetHeight(strRuleCellHeight);
          myCell.SetAlign(CommonHTMLStrings.RIGHT);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          // Set a section to display "X" or checkmark icon for reporting feedback.
          mySpan.SetID(PasswordValidationHelper.STR_LOWER_UPPER_CASE_STATUS_NAME);
          // Add valid/invalid icon for rule
          mySpan.AddInnerHTMLString(imgInvalidIconHTML);
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell = new HTMLTableCell();
          myCell.SetWidth("95%");
          myCell.SetHeight(strRuleCellHeight);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          // Password must contain upper and lower case letters
          mySpan.AddInnerHTMLString(m_asOwner.GetString(1983, ResourceConstants.PORTALBROWSINGMSGS));
          }
        if (bIncludePunctuation)
        {
          // Display Include Punctuation Status Icon and Rule
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myCell = new HTMLTableCell();
          myCell.SetWidth("5%");
          myCell.SetHeight(strRuleCellHeight);
          myCell.SetAlign(CommonHTMLStrings.RIGHT);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          // Set a section to display "X" or checkmark icon for reporting feedback.
          mySpan.SetID(PasswordValidationHelper.STR_PUNCTUATION_STATUS_NAME);
          // Add valid/invalid icon for rule
          mySpan.AddInnerHTMLString(imgInvalidIconHTML);
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell = new HTMLTableCell();
          myCell.SetWidth("95%");
          myCell.SetHeight(strRuleCellHeight);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          // Password must contain a punctuation mark
          mySpan.AddInnerHTMLString(m_asOwner.GetString(1985, ResourceConstants.PORTALBROWSINGMSGS));
          }
        if (bNoUserIds)
        {
          // Display Cannot Contain UserId Status Icon and Rule
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          myCell = new HTMLTableCell();
          myCell.SetWidth("5%");
          myCell.SetHeight(strRuleCellHeight);
          myCell.SetAlign(CommonHTMLStrings.RIGHT);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          // Set a section to display "X" or checkmark icon for reporting feedback.
          mySpan.SetID(PasswordValidationHelper.STR_USERNAME_STATUS_NAME);
          // Add valid/invalid icon for rule
          mySpan.AddInnerHTMLString(imgInvalidIconHTML);
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          myCell = new HTMLTableCell();
          myCell.SetWidth("95%");
          myCell.SetHeight(strRuleCellHeight);
          myRow.AddInnerHTMLElement(myCell);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          // Password must contain userid
          mySpan.AddInnerHTMLString(m_asOwner.GetString(1982, ResourceConstants.PORTALBROWSINGMSGS));
          }
        if (nReuseHistory > 0)
        {
        }
        // commenting out as per bug 9308555 
        /*// Display Password Reuse Rule
         myRow = new HTMLTableRow();
         myTable.AddInnerHTMLElement(myRow);
         myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
         myCell = new HTMLTableCell();
         myCell.SetWidth("5%");
         myCell.SetHeight(strRuleCellHeight);
         myCell.SetAlign(CommonHTMLStrings.RIGHT);
         myRow.AddInnerHTMLElement(myCell);
         mySpan = new HTMLSpan();
         // Add warning icon for rule
         mySpan.AddInnerHTMLString(imgWarningIconHTML);
         myCell.AddInnerHTMLElement(mySpan);
         mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
         
         myCell = new HTMLTableCell();
         myCell.SetWidth("95%");
         myCell.SetHeight(strRuleCellHeight);
         myRow.AddInnerHTMLElement(myCell);
         mySpan = new HTMLSpan();
         myCell.AddInnerHTMLElement(mySpan);
         mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
         // Number of password changes before a password can be reused.
         mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(
         m_asOwner.GetString(2007, ResourceConstants.PORTALBROWSINGMSGS), nReuseHistory));*/
         
        eOut.AddInnerHTMLElement(new HTMLComment("End: Create Account View"));
        }
      catch (HTMLException he)
      {
        log.Error(he, "Error displaying Create Account HTML: ");
      }
      catch (Exception ex)
      {
        log.Error(ex, "Error in Create Account: ");
      }
      return eOut;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on
    /// the page.
    /// Generates Javascript constants that are used in ptpasswordvalidation.js for
    /// all validation.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      IPTServerConfigSettings config = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      int nMinimumLength = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_LENGTH);
      bool bIncludeNumbers = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_NUMBERS);
      bool bIncludeCasing = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_CASING);
      bool bIncludePunctuation = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_PUNCTUATION);
      bool bNoUserIds = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_NO_USER_IDS);
      // Generate Javascript constants and i18n strings to be used in client-side validation.
      XPStringBuilder sb = new XPStringBuilder();
      sb.Append("var ").Append(PasswordValidationHelper.STR_PASSWORD_VALIDATION_JS_NAMESPACE).Append(" = function() {\n");
      sb.Append("    return {\n");
      // Current settings for Password Management
      sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_MIN_LENGTH).Append(" : \'").Append(nMinimumLength).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_MAX_LENGTH).Append(" : \'20\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_INCLUDE_NUMBERS).Append(" : \'").Append(bIncludeNumbers).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_INCLUDE_CASING).Append(" : \'").Append(bIncludeCasing).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_INCLUDE_PUNCTUATION).Append(" : \'").Append(bIncludePunctuation).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_NO_USER_IDS).Append(" : \'").Append(bNoUserIds).Append("\',\n");
      // i18n Strings
      sb.Append("        ").Append(PasswordValidationHelper.PASSWORDS_MUST_BE_SAME_I18N).Append(" : \'").Append(m_asOwner.GetString(2001,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.PASSWORDS_MIN_LENGTH_I18N).Append(" : \'").Append(XPResourceManager.FormatMessage(m_asOwner.GetString(2002,
       ResourceConstants.PORTALBROWSINGMSGS), nMinimumLength)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.ENTER_USERNAME_I18N).Append(" : \'").Append(m_asOwner.GetString(2003,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.ENTER_OLD_PASSWORD_I18N).Append(" : \'").Append(m_asOwner.GetString(2004,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.PASSWORD_TOO_SHORT_I18N).Append(" : \'").Append(XPResourceManager.FormatMessage(m_asOwner.GetString(1628,
       ResourceConstants.PORTALBROWSINGMSGS), nMinimumLength)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.PASSWORD_TOO_LONG_I18N).Append(" : \'").Append(m_asOwner.GetString(1291,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.NO_BLANK_SPACES_I18N).Append(" : \'").Append(m_asOwner.GetString(2005,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.MUST_CONTAIN_UPPER_LOWER_CASE_I18N).Append(" : \'").Append(m_asOwner.GetString(1983,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.MUST_CONTAIN_NUMBER_I18N).Append(" : \'").Append(m_asOwner.GetString(1984,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.MUST_CONTAIN_PUNCTUATION_I18N).Append(" : \'").Append(m_asOwner.GetString(1985,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.CANNOT_CONTAIN_USER_ID_I18N).Append(" : \'").Append(m_asOwner.GetString(1982,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.PASSWORD_VALID_I18N).Append(" : \'").Append(m_asOwner.GetString(2006,
       ResourceConstants.PORTALBROWSINGMSGS)).Append("\',\n");
      // Username and Password Input Field Element Id Constants
      sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_USERNAME_ID).Append(" : \'").Append(CreateAccountControl.PARAM_USERNAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_NEW_PASSWSORD_ID).Append(" : \'").Append(CreateAccountControl.PARAM_USERPASS).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_CONFIRM_PASSWORD_ID).Append(" : \'").Append(CreateAccountControl.PARAM_CONFIRM_USERPASS).Append("\',\n");
      // Form and Create Account Button Element Id Constants
      sb.Append("        ").Append(PasswordValidationHelper.STR_CREATE_ACCOUNT_FORM_ID).Append(" : \'").Append(STR_FORM_NAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_DOCREATE_ID).Append(" : \'").Append(CreateAccountControl.PARAM_DOCREATEACCOUNT).Append("\',\n");
      // Username and Password Validation Status Field Element Id Constants
      sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_USERNAME_VALIDATION_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_USERNAME_VALIDATION_STATUS_NAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_PASSWORD_VALIDATION_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_PASSWORD_VALIDATION_STATUS_NAME).Append("\',\n");
      // Icon Element Ids for each of the Client-Side Password Validation Rules
      sb.Append("        ").Append(PasswordValidationHelper.STR_MIN_MAX_LENGTH_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_MIN_MAX_LENGTH_STATUS_NAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_NUMBER_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_NUMBER_STATUS_NAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_LOWER_UPPER_CASE_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_LOWER_UPPER_CASE_STATUS_NAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_PUNCTUATION_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_PUNCTUATION_STATUS_NAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_USERNAME_STATUS_ID).Append(" : \'").Append(PasswordValidationHelper.STR_USERNAME_STATUS_NAME).Append("\',\n");
      // URLs to validation icons for displaying feedback to user
      sb.Append("        ").Append(PasswordValidationHelper.STR_VALID_ICON_URL).Append(" : \'").Append(PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner)).Append(PasswordValidationHelper.STR_VALID_ICON_FILENAME).Append("\',\n");
      sb.Append("        ").Append(PasswordValidationHelper.STR_INVALID_ICON_URL).Append(" : \'").Append(PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner)).Append(PasswordValidationHelper.STR_INVALID_ICON_FILENAME).Append("\'\n");
      sb.Append("    };\n");
      sb.Append("}();\n");
      myScript.AddInnerHTMLString(sb.ToString());
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asmModel = (CreateAccountModel) model;
      m_asOwner = parent;
    }
  }
}