using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.sendinvitation;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.login.createaccount
{
  /// <summary>
  /// Handles incoming invitation request
  /// </summary>
  /// <author>BenG</author>
  /// <author>DavidP</author>
  public class InterceptInvitationControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.login.createaccount.InterceptInvitationControl");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "InterceptInvitationControl";
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// MVC Objects 
    /// </summary>
    private CreateAccountModel m_asModel;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      log.Debug("Execute()");
      Redirect myRedirect = null;
      String[] sValues = null;
      // Invite code
      sValues = (String[]) arguments.GetElement(InvCodesListView.CONTROLARGUMENT_INVCODE);
      if (sValues != null)
      {
        log.Debug("invite code: " + sValues[0]);
        m_asModel.SetInviteCode(sValues[0]);
      }
      // Get all the values from the CreateAccount that are being intercepted 
      // and re-use them on the redirect
      //PEI : OnAfterAcceptInvite
      //BrianH - This set of code will process through all of the available OnAfterAcceptInvite PEIs
      // and process the according functionality.
      Object[] oa;
      Object o;
      ICreateAccountActions iActions;
      IApplication application = m_asOwner.GetApplication();
      oa = (Object[]) application.GetCachingManager().GetEntry("CreateAccountActions");
      if (oa != null)
      {
        for (int x = 0;x < oa.Length;x++)
        {
          o = oa[x];
          log.Debug("CheckActionSecurityAndExecute() - About to call OnAfterAcceptInvite on an: " + o);
          if (o != null)
          {
            iActions = (ICreateAccountActions) o;
            iActions.OnAfterAcceptInvite(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
             sValues[0]);
          }
        }
      }
      //PEI : OnAfterAcceptInvite : END
      //	Now use the create account control.
      myRedirect = new Redirect();
      myRedirect.SetLinkGetSpaceIfCached(CreateAccountAS.STR_MVC_CLASS_NAME,
       this.m_asOwner);
      return myRedirect;
    }
    /////////////
    // IMVCObject
    /////////////
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new InterceptInvitationControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#Init(IModelRW)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (CreateAccountModel) model;
      m_asOwner = space;
    }
  }
}