using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// Control to add or remove a portlet on a given community or my page. 
  /// </summary>
  /// <author>Ravi Tunuguntla/Bobby Tse</author>
  public class AddRemovePortletControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.AddRemovePortletControl");
    public const String STR_MVC_CLASS_NAME = "AddRemovePortlet";
    public const String STR_PORTLET_TO_ADD = "AddThisPortlet";
    public const String STR_PORTLET_TO_REMOVE = "RemoveThisPortlet";
    public const String STR_PORTLET_BUNDLE_TO_ADD = "PortletBundleID";
    
    /// <summary>
    /// Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private IMyPortalModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      if (MyPortalModel.IsGuestSession(m_asOwner))
      {
        return null;
      }
      // Get Page ID.
      String[] saPageID = (String[]) arguments.GetElement(SetPageControl.STR_PAGE_ID);
      if (saPageID == null)
      {
        log.Error("could not find page ID in query string.");
        return null;
      }
      int nPageID = XPConvert.ToInteger(saPageID[0]);
      // Get Community ID
      String[] saCommunityID = (String[]) arguments.GetElement(SetCommunityControl.STR_COMMUNITY_ID);
      int nCommunityID = 0;
      if (saCommunityID == null)
      {
        log.Debug("could not find community ID in query string; will assume this is a mypage.");
        } else
      {
        nCommunityID = XPConvert.ToInteger(saCommunityID[0]);
      }
      // Get whether to add or remove the portlet.
      String[] saAddPortletID = (String[]) arguments.GetElement(STR_PORTLET_TO_ADD);
      String[] saRemovePortletID = (String[]) arguments.GetElement(STR_PORTLET_TO_REMOVE);
      String[] saAddPortletBundleID = (String[]) arguments.GetElement(STR_PORTLET_BUNDLE_TO_ADD);
      String[] saPage = (String[]) arguments.GetElement(ASConstants.PAGE);
      if (null != saPage && saPage[0].Equals(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME))
      {
        m_asOwner.SetIsInPlaceRefreshDisplayOn(true);
      }
      // Add or Remove Portlet on the page.
      if (null != saAddPortletID)
      {
        m_asModel.AddSinglePortlet(nPageID, XPConvert.ToInteger(saAddPortletID[0]));
        if (m_asOwner.GetIsInPlaceRefreshDisplayOn())
        {
          MyPortalPartialPortletsDP page = (MyPortalPartialPortletsDP) m_asOwner.GetPage(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
          page.SetDisplayHelperToAdd();
        }
      } else
      if (null != saRemovePortletID)
      {
        m_asModel.RemoveSinglePortlet(nPageID, XPConvert.ToInteger(saRemovePortletID[0]));
        if (m_asOwner.GetIsInPlaceRefreshDisplayOn())
        {
          MyPortalPartialPortletsDP page = (MyPortalPartialPortletsDP) m_asOwner.GetPage(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
          page.SetDisplayHelperToRemove();
        }
      } else
      if (null != saAddPortletBundleID)
      {
        m_asModel.AddPortletBundle(nPageID, XPConvert.ToInteger(saAddPortletBundleID[0]));
        if (m_asOwner.GetIsInPlaceRefreshDisplayOn())
        {
          MyPortalPartialPortletsDP page = (MyPortalPartialPortletsDP) m_asOwner.GetPage(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
          page.SetDisplayHelperToAdd();
        }
      } else
      {
        log.Error("coud not find portlet index to add or remove in query string.");
        return null;
      }
      // Get the profile user id, if any. This is needed for the user profile community.
      int nProfileID = 0;
      if (nCommunityID == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
      {
        // Default value of -1 indicates the user is looking at their own profile
        // value of 0 would mean this isn't a profile page.
        nProfileID = -1;
        String[] saProfileID = (String[]) arguments.GetElement(SetCommunityControl.PROFILEID);
        if (saProfileID != null)
        {
          nProfileID = XPConvert.ToInteger(saProfileID[0]);
        }
        // dap: force help on user profiel community to appropriate page
        m_asOwner.SetHelpTopic("PT_SectionUserProfile");
      }
      // Set the profile ID.
      bool bSetProfileSuccessful = m_asModel.SetProfileID(nProfileID);
      // Set Raw Headers
      String strHeaders = HttpUtils.GetRawHeaders(m_asOwner.GetCurrentHTTPRequest());
      m_asModel.SetRawHeaders(strHeaders);
      Redirect redirect = null;
      if (0 != nCommunityID)
      {
        // Is a community.
        // GET THE REAL PAGEID AFTER GET COMMUNITY (handles the pageid=0 case)
        bool bSetCommunitySuccessful = false;
        // Avoid useless work if we have to redirect anyway.
        if (bSetProfileSuccessful)
        {
          bSetCommunitySuccessful = m_asModel.SetCommunity(nCommunityID, nPageID);
          }
        // If either SetPage or SetCommunity fails, we want to redirect here.
        if (!bSetProfileSuccessful || !bSetCommunitySuccessful)
        {
          redirect = new Redirect();
          redirect.SetIsErrorRedirect(true);
          redirect.SetLinkGetCachedSpace(m_asOwner);
          redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
          redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
           nCommunityID);
          redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID, nPageID);
          if (nProfileID != -1)
          {
            redirect.AddControlArgument(SetCommunityControl.PROFILEID, nProfileID);
            }
        } else
        if (bSetCommunitySuccessful && !m_asOwner.GetIsInPlaceRefreshDisplayOn())
        {
          redirect = new Redirect();
          IPTURL pturl = TaskAPIUICommunity.CreateCommunityPageCommonOpenerURL(m_asOwner,
           nCommunityID, nPageID, "");
          redirect.SetLinkToExternalURL(pturl.GetFullURL());
        }
      } else
      {
        // Is a my page.
        // Setup the My Page.
        bool bSuccessful = m_asModel.SetPage(nPageID);
        // If setting the my page was not successful, then redirect to an error page.
        if (!bSuccessful)
        {
          redirect = new Redirect();
          redirect.SetIsErrorRedirect(true);
          redirect.SetLinkGetCachedSpace(m_asOwner);
          redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
          redirect.AddControlArgument(SetPageControl.STR_PAGE_ID, nPageID);
          }
      }
      if (null == redirect && !m_asOwner.GetIsInPlaceRefreshDisplayOn())
      {
        redirect = new Redirect();
        IPTURL pturl = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(m_asOwner,
         nPageID, "");
        redirect.SetLinkToExternalURL(pturl.GetFullURL());
      }
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new AddRemovePortletControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (IMyPortalModel) model;
      m_asOwner = space;
    }
  }
}