using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// Model interface used by plugin navigation. All setters and
  /// modifiers should go here.
  /// </summary>
  /// <author>btse</author>
  public interface IMyPortalModel : IMyPortalModelRO
  {
    
    /// <summary>
    /// Adds a single portlet to the page. First opens the page, locks it,
    /// adds the portlet, stores and unlocks the page.
    /// </summary>
    /// <param name="nPageID"></param>
    /// <param name="nPortletID"></param>
    void AddSinglePortlet(int nPageID, int nPortletId);
    
    /// <summary>
    /// Adds a portlet bundle to the page. First opens the page, locks it,
    /// adds the portlets, stores and unlocks the page.
    /// </summary>
    /// <param name="nPageID"></param>
    /// <param name="nPortletBundleID"></param>
    void AddPortletBundle(int nPageID, int nPortletBundleID);
    
    /// <summary>
    /// Collapses the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletID</param>
    void CollapsePortlet(int nCommunityID, int nPageID, int nPortletToCollapse);
    
    /// <summary>
    /// Expands the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletID</param>
    void ExpandPortlet(int nCommunityID, int nPageID, int nPortletToExpand);
    
    /// <summary>
    /// Reassigns the specified column (region) in the page with the given portlet array.
    /// </summary>
    /// <param name="arrPortletIDs">array of portlet IDs</param>
    /// <param name="nColumn">nColumn</param>
    /// <param name="nPageID">nPageID</param>
    void ReassignPortlets(int[] arrPortletIDs, int nColumn, int nPageID);
    
    /// <summary>
    /// Removes single portlet from the page. First opens the page and locks it
    /// Remove the portlet, stores and unlocks the page.
    /// </summary>
    /// <param name="nPageID"></param>
    /// <param name="nPortletIndex"></param>
    void RemoveSinglePortlet(int nPageID, int nPortletIndex);
    
    /// <summary>
    /// Sets the community to be viewed and calls SetPage
    /// </summary>
    /// <param name="nCommunityID">nCommunityID</param>
    /// <param name="nPageID">nPageID</param>
    /// <returns>true if successful, else false</returns>
    bool SetCommunity(int nCommunityID, int nPageID);
    
    /// <summary>
    /// Sets the page to be a preview page or not.
    /// </summary>
    /// <param name="bIsPreviewPage">bIsPreviewPage</param>
    void SetIsPreviewPage(bool bIsPreviewPage);
    
    /// <summary>
    /// Sets up the page of the given ID.
    /// </summary>
    /// <param name="nPageID">nPageID</param>
    /// <returns>true if successful, else false; false requires login redirect</returns>
    bool SetPage(int nPageID);
    
    /// <summary>
    /// Method SetProfileID.  Returns false if the current user doesn't have access to the given profile.
    /// </summary>
    /// <param name="nProfileID"></param>
    /// <returns>true if successful, else false</returns>
    bool SetProfileID(int nProfileID);
    
    /// <summary>
    /// Sets the raw headers from the request.
    /// </summary>
    /// <param name="strRawHeaders"></param>
    void SetRawHeaders(String strRawHeaders);
    
    /// <summary>
    /// Resets the list of recently added portlets.
    /// </summary>
    void ResetRecentlyAddedPortlets();
    
    /// <summary>
    /// Queries the portlet content of the recently added portlets, if
    /// there are any.  Does nothing if there are no recently added portlets
    /// (including not resetting the content data), so be sure to check that
    /// there are recently added portlets before calling this.
    /// </summary>
    bool QueryRecentlyAddedPortletContent();
    
    /// <summary>
    /// Queries the portlet content of the recently collapsed portlets, if
    /// there are any.  Does nothing if there are no recently collapsed portlets
    /// (including not resetting the content data), so be sure to check that
    /// there are recently collapsed portlets before calling this.
    /// </summary>
    bool QueryRecentlyCollapsedExpandedPortletContent();
    
    /// <summary>
    /// Resets the variable to 0
    /// </summary>
    void ResetRecentlyRemovedPortlet();
    
    /// <summary>
    /// Resets the variable to 0
    /// </summary>
    void ResetRecentlyCollapsedExpandedPortlet();
    
    /// <summary>
    /// Register model, view, and control for intrinsic portlet.  Initialize
    /// portlet with the portletID, the IPTMyPortal object, and the
    /// AppDataState object.
    /// </summary>
    /// <param name="_strPortletClass">Class identifier for portlet</param>
    /// <param name="_strStorageName">Storage name for portlet</param>
    /// <param name="_nPortletIndex">Portlet index</param>
    /// <throws>
    /// XPException Exception thrown if model, view, or control is not
    /// registered successfully.
    /// </throws>
    void SetupIntrinsicPortlet(String _strPortletClass, String _strStorageName,
     int _nPortletIndex);
  }
}