using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// Model interface used by plugin navigation
  /// </summary>
  /// <author>MichaelD</author>
  /// <author>DavidP</author>
  public interface IMyPortalModelRO : IModelRO
  {
    
    /// <summary>
    /// Get the community ID of the community we are currently viewing.
    /// </summary>
    /// <returns>int nCommunityID</returns>
    int GetCommunityID();
    
    /// <summary>
    /// Get the name of the community we are currently viewing.
    /// </summary>
    /// <returns>string</returns>
    String GetCommunityName();
    
    /// <summary>
    /// Get the pages in the community.
    /// </summary>
    /// <returns>IPTQueryResult ptqrCommunityPages</returns>
    IPTQueryResult GetCommunityPages();
    
    /// <summary>
    /// Get the first gadget index in the given column.
    /// </summary>
    /// <param name="nPortletColumn">nPortletColumn</param>
    /// <returns>int nPortletIndex</returns>
    int GetFirstPortletIndexInColumn(int nPortletColumn);
    
    /// <summary>
    /// Get the whether the gadget at the given index is collapsed.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletCollapsed</returns>
    bool GetPortletCollapsed(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget column from the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>int nPortletColumn</returns>
    int GetPortletColumnFromIndex(int nPortletIndex);
    
    /// <summary>
    /// Get the number of gadgets on the page we are currently viewing.
    /// </summary>
    /// <returns>int nPortletCount</returns>
    int GetPortletCount();
    
    /// <summary>
    /// Get the gadget's disabled message from the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletDisabledMessage</returns>
    String GetPortletDisabledMessage(int nPortletIndex);
    
    /// <summary>
    /// Get the whether the gadget at the given index is enabled.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletEnabled</returns>
    bool GetPortletEnabled(int nPortletIndex);
    
    /// <summary>
    /// If there was an error, display the gadget header regardless of any other
    /// settings.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bDisplayHeader</returns>
    bool GetDisplayPortletHeaderDueToError(int nPortletIndex);
    
    /// <summary>
    /// If there was an error, display the gadget header regardless of any other
    /// settings.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    void SetDisplayPortletHeaderDueToError(int nPortletIndex, bool bDisplayHeader);
    
    /// <summary>
    /// Get the gadget content from the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletHTMLText</returns>
    Object[][] GetPortletHTMLTextFromIndex(int nGadgetIndex);
    
    /// <summary>
    /// Get whether the gadget at the given index has a help URL.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasHelpURL</returns>
    bool GetPortletHasHelpURL(int nPortletIndex);
    
    /// <summary>
    /// Get whether the gadget at the given index has a Admin Preference URL.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasAdminPrefsURL</returns>
    bool GetPortletHasAdminPrefsURL(int nPortletIndex);
    
    /// <summary>
    /// Get whether the gadget at the given index has a Community Preference URL.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasCommunityPrefsURL</returns>
    bool GetPortletHasCommunityPrefsURL(int nPortletIndex);
    
    /// <summary>
    /// Get whether the gadget at the given index has a User Preference URL.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasUserPrefsURL</returns>
    bool GetPortletHasUserPrefsURL(int nPortletIndex);
    
    /// <summary>
    /// Get whether the gadget at the given index has a Collapse/Expand URL.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasCollapseExpandURL</returns>
    bool GetPortletHasCollapseExpandURL(int nPortletIndex);
    
    /// <summary>
    /// Get the UUID of the portlet.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strUUID</returns>
    String GetPortletUUID(int nPortletIndex);
    
    /// <summary>
    /// Get whether a gadget has a title bar or not.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasTitleBar</returns>
    bool GetPortletHasTitleBar(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget help URL at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletHelpURL</returns>
    String GetPortletHelpURL(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget Admin Preference URL at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletAdminPrefsURL</returns>
    String GetPortletAdminPrefsURL(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget Community Preference URL at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletCommunityPrefsURL</returns>
    String GetPortletCommunityPrefsURL(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget User Preference URL at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletUserPrefsURL</returns>
    String GetPortletUserPrefsURL(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget Collapse/Expand URL at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <param name="strControl">strControl</param>
    /// <returns>String strPortletCollapseExpandURL</returns>
    String GetPortletCollapseExpandURL(int nPortletIndex, String strControl);
    
    /// <summary>
    /// Get the gadget Remove URL at the given index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>String strPortletRemoveURL</returns>
    String GetPortletRemoveURL(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget ID from the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>int nPortletID</returns>
    int GetPortletIDFromIndex(int nPortletIndex);
    
    /// <summary>
    /// Get the whether the gadget at the given index is mandatory.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletIsMandatory</returns>
    bool GetPortletIsMandatory(int nPortletIndex);
    
    /// <summary>
    /// Get the gadget name from the given index.
    /// </summary>
    /// <param name="nPortletColumn">nPortletIndex</param>
    /// <returns>String strPortletName</returns>
    String GetPortletNameFromIndex(int nPortletColumn);
    
    /// <summary>
    /// Get the gadget ID string from the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>String strPortletID</returns>
    String GetIDStringForPortlet(int nPortletIndex);
    
    /// <summary>
    /// Returns whether or not the gadget supports 508 mode
    /// </summary>
    bool GetPortletSupports508(int nPortletIndex);
    
    /// <summary>
    /// Returns a bitmask of the types of personalization this portlet supports. 
    /// </summary>
    int GetPortletSupportsPersonalization(int nPortletIndex);
    
    /// <summary>
    /// Get the helper object for this model.
    /// </summary>
    /// <returns>IMyPortalModelHelper</returns>
    IMyPortalModelHelper GetHelper();
    
    /// <summary>
    /// Get whether the current page is a community page.
    /// </summary>
    /// <returns>boolean bIsCommunityPage</returns>
    bool GetIsCommunityPage();
    
    /// <summary>
    /// Get the last gadget index in the given column.
    /// </summary>
    /// <param name="nPortletColumn">nPortletColumn</param>
    /// <returns>int nPortletIndex</returns>
    int GetLastPortletIndexInColumn(int nPortletColumn);
    
    /// <summary>
    /// Get the ASURL for the page we are on.
    /// </summary>
    /// <returns>ASURL asurlPage</returns>
    ASURL GetPageASURL();
    
    /// <summary>
    /// Get the page ID of the page we are currently viewing.
    /// </summary>
    /// <returns>int nPageID</returns>
    int GetPageID();
    
    /// <summary>
    /// Get the name of the page we are currently viewing.
    /// </summary>
    /// <returns>string</returns>
    String GetPageName();
    
    /// <summary>
    /// Get the page type of the page we are currently viewing.
    /// </summary>
    /// <returns>int nPageType</returns>
    int GetPageType();
    
    /// <returns>The Portlet Layout Webservice Id, or 0 if none is set on this page.</returns>
    int GetPortletLayoutId();
    
    /// <summary>
    /// If the current page has an adaptive Portlet Layout set.
    /// </summary>
    /// <returns></returns>
    bool UsesPortletLayout();
    
    /// <summary>
    /// Get the current IPTSession. This method should only be used by
    /// MyPortalModel.
    /// </summary>
    /// <returns>int nPageID</returns>
    IPTSession GetSession();
    
    /// <summary>
    /// Get the PortletPrefButton boolean from the varpack.
    /// </summary>
    /// <returns>string</returns>
    String GetPortletPrefButtonBoolean();
    
    /// <summary>
    /// Returns whether the portlet at a given index has a Refresh button.
    /// </summary>
    /// <param name="nPortletIndex">nPortletIndex</param>
    /// <returns>boolean bPortletHasRefreshButton</returns>
    bool GetPortletHasRefreshButton(int nPortletIndex);
    
    /// <summary>
    /// Returns the markup which should be displayed in case of a collapsed or error portlet.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>object markup array</returns>
    Object[][] GetCollapsedOrErrorContent(int nPortletIndex);
    
    /// <summary>
    /// Returns the id of the portlet that was recently added to the page
    /// </summary>
    /// <returns>a list of the portlets that were recently added to the page.</returns>
    XPArrayList GetRecentlyAddedPortlets();
    
    /// <summary>
    /// Returns the id of the portlet that was recently removed from the page
    /// </summary>
    /// <returns>id of portlet</returns>
    int GetRecentlyRemovedPortlet();
    
    /// <summary>
    /// Returns the id of the portlet that was recently collapsed from the page
    /// </summary>
    /// <returns>id of portlet</returns>
    int GetRecentlyCollapsedExpandedPortlet();
    
    /// <summary>
    /// Get the profile ID of the user being viewed on the user profile community.
    /// </summary>
    /// <returns>the user ID of the profile being viewed, 0 if not used.</returns>
    int GetProfileID();
    
    /// <summary>
    /// Get the portlet pref actions.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>list of FullURLs</returns>
    IXPList GetPortletPreferenceActionsData(int nPortletIndex);
  }
}