using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server.portalpagesperf;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// Main display page for community and my pages
  /// </summary>
  /// <author>MichaelD</author>
  public class MyPortalDP : PlumtreeDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.MyPortalDP");
    public const String STR_MVC_CLASS_NAME = "MyPortal";
    public const String AUTOREFRESH = "autorefresh=1";
    public const String REFRESH = "refresh";
    public const String EMPTYSTRING = "";
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      parent.SetHelpTopic("PT_MyPages");
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1448, "ptmsgs_portalbrowsingmsgs"),
       this.m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()"></seealso>
    public override String GetSubtitleForBanner()
    {
      NavigationModel modelNavigation = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      String strPageName = EMPTYSTRING;
      strPageName = modelNavigation.GetCurPageName();
      return strPageName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()"></seealso>
    public override String GetTitleForBanner()
    {
      NavigationModel modelNavigation = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      String strTitle = EMPTYSTRING;
      if (modelNavigation.IsCommunityPage())
      {
        strTitle = modelNavigation.GetCurCommunityName();
      } else
      if (modelNavigation.IsMyPage())
      {
        strTitle = m_asOwner.GetString(672, "ptmsgs_portalbrowsingmsgs");
        }
      //strTitle = modelNavigation.GetCurPageName();
      return strTitle;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()"></seealso>
    public override String GetFormTitle()
    {
      MyPortalModel model = (MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
      if (model.GetIsCommunityPage())
      {
        return GetTitleForBanner();
      }
      return GetSubtitleForBanner();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AformDP#PageDisplay()"></seealso>
    public override HTMLElement PageDisplay()
    {
      // Increment the performance counters only if info is on for commonlib	
      NavigationModel modelNavigation = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      if (modelNavigation.IsCommunityPage())
      {
        PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_COMMUNITY_PAGES);
        } else
      {
        PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_MYPAGES);
        }
      // Display the join community confirmation page if the user just joined a community
      MyPortalModel portalMod = (MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
      if (portalMod.ShowJoinConfirmPage())
      {
        return m_asOwner.GetView(CommunityInvitationJoinView.STR_MVC_CLASS_NAME).Display();
        }
      if (portalMod.ShowUnsubscribeConfirmPage())
      {
        return m_asOwner.GetView(CommunityUnsubscribeView.STR_MVC_CLASS_NAME).Display();
        }
      if (portalMod.IsPageAvailable())
      {
        int webServId = LayoutService.getChooserInstance().GetLayoutWebService(Layouts.PORTLET,
         m_asOwner);
        // are portlet layouts enabled on this page and do we use them?
        if ((LayoutService.getChooserInstance().GetPortletLayoutsEnabled(m_asOwner) && portalMod.UsesPortletLayout()) || (webServId > -1))
        {
          // Check if there is an Experience Definition portlet layout override.
          // -1 means no override.
          if (webServId == -1)
          {
            // No XD override, use the one defined in the page.
            webServId = portalMod.GetPortletLayoutId();
            log.Debug("Using portlet layout on Portal page with id:" + portalMod.GetPageID() + " and webservice id:" + webServId);
            } else
          {
            log.Debug("Using portlet layout override from XD on Portal page with id:" + portalMod.GetPageID() + " and webservice id:" + webServId);
            }
          // false means this is not a main page
          HTMLElement portletsContent = DisplayLayout(webServId, false);
          if (portletsContent == null)
          {
            log.Info("No portlets layout contet was received from webservice id:" + webServId);
            return new HTMLComment("No content was received for Portlets layout Area.");
            } else
          {
            return portletsContent;
          }
        } else
        {
          return m_asOwner.GetView(MyPortalContentView.STR_MVC_CLASS_NAME).Display();
          }
      }
      log.Debug("Portal page " + portalMod.GetPageID() + " is not available.");
      return null;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from AFormDP can
    /// override if they like.  The method provides a hook into the head so
    /// that DP's can add javascript. Simply override and return and
    /// HTMLScript.  Also, it is best to return the results of the
    /// DisplayJavaScript functions from the appropriate views.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#DisplayJavaScriptFromChild()"></seealso>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection scripts = new HTMLScriptCollection();
      if (m_asOwner.GetAccessStyle() != AccessStyles.SECTION_508)
      {
        scripts.AddInnerHTMLElement(m_asOwner.GetView(MyPortalContentView.STR_MVC_CLASS_NAME).DisplayJavascript());
        // Aggregate all of the intrinsic portlet Javascript. Now iterate through intrinsic
        // portlet views and call DisplayJavascript for each.
        IXPEnumerator enumViews = m_asOwner.GetViewsEnumerator();
        while (enumViews.MoveNext())
        {
          IView currentView = (IView) enumViews.GetCurrent();
          if (currentView is IntrinsicPortletView)
          {
            IntrinsicPortletView iPortletView = (IntrinsicPortletView) currentView;
            try
            {
              HTMLScript portletJavascript = iPortletView.DisplayJavascript();
              if (null != portletJavascript)
              {
                scripts.AddInnerHTMLElement(portletJavascript);
              }
            }
            catch (Exception e)
            {
              log.Error(e, "An error occured while trying to display the javascript for " + iPortletView.GetName());
              }
          }
        }
      }
      return scripts;
    }
    
    /// <summary>
    /// Forms meta-refresh tag for MyPage auto refreshing based on personal settings value.
    /// Adds the parameter "autorefresh=1" to the querystring of the refresh URL to distinguish
    /// between urls that are arrived at via autorefresh and those that aren't.
    /// </summary>
    /// <returns>HTMLMeta to be included</returns>
    public override HTMLMeta GetMetaRefresh()
    {
      Object ret = PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.MY_PAGE_REFRESH_RATE,
       m_asOwner);
      int iRefreshRate = 0;
      if (ret != null)
      {
        iRefreshRate = XPConvert.ToInteger(ret);
      }
      if (iRefreshRate != 0)
      {
        String sRefreshrate = XPConvert.ToString(iRefreshRate * 60);
        XPStringBuilder metaContent = new XPStringBuilder(sRefreshrate);
        metaContent.Append(";URL=");
        // SE: Bug 63169: do not use the current request URL but rather use this URL to derive the application url using URL mapping
        // See the "BaseURL tester guide" for more information on URL mapping
        // Here is the link: http://portal.plumtree.com/portal/server.pt/gateway/PTARGS_0_0_9405_0_0_47/http;/prodgadget12.plumtree.com/collab/docman/download/230347/0/0/0/BaseURL%20Tester%20guide.doc?qid=86588274&rank=1
        // Note: the GetApplicationBaseURL helper will figure out if the URL should use HTTP or HTTPS.
        String strBaseURL = ConfigHelper.GetApplicationBaseURL(m_asOwner);
        String strEntryPoint = ConfigHelper.GetHTTPEntryPoint();
        String strRequestURL = m_asOwner.GetCurrentRequestURL();
        int nStartIndex = XPStringUtility.IndexOf(strRequestURL, strEntryPoint);
        int nEndIndex = XPStringUtility.IndexOf(strRequestURL, "?");
        // Friendly URLs include information in the URL between the endpoint and the query string.
        // I.E. http://donh-w2k3:8080/portal/server.pt/mypage/home_page/100
        if (nStartIndex >= 0)
        {
          nStartIndex+=strEntryPoint.Length;
          if (nEndIndex < 0)
          {
            nEndIndex = strRequestURL.Length;
          }
          String strFriendlyInfo = XPStringUtility.Substring(strRequestURL,
           nStartIndex, nEndIndex);
          // NOTE: application base URL ends with '?'
          strBaseURL = XPStringUtility.Substring(strBaseURL, 0, strBaseURL.Length - 1) + strFriendlyInfo + "?";
          }
        metaContent.Append(strBaseURL);
        String queryString = m_asOwner.GetCurrentHTTPRequest().GetQueryString();
        // if the query string is empty add the autorefresh parameter
        if (null == queryString || queryString.Equals("null") || queryString.Equals(EMPTYSTRING))
        {
          metaContent.Append(AUTOREFRESH);
        } else
        // if the query string is empty but and doesn't have the autorefres parameter, add it.
        if (XPStringUtility.IndexOf(queryString, AUTOREFRESH) == -1)
        {
          metaContent.Append(queryString);
          metaContent.Append("&");
          metaContent.Append(AUTOREFRESH);
        } else
        // the query string already has the autorefresh parameter no need to add it. 
        {
          metaContent.Append(queryString);
        }
        HTMLMeta metaRefresh = new HTMLMeta(metaContent.ToString());
        metaRefresh.SetHTTPEquiv(REFRESH);
        return metaRefresh;
      }
      return null;
    }
    /*
     *
     * This method determines whether to use Javascript.  On most pages,
     * only the STANDARD portal uses JS.  However, on portal, community, and
     * the default profile pages, the low-bandwidth portal can display JS.  In these
     * cases, this method is overridden to allow JS for Standard and LB (which is the
     * same as NOT 5_08).
     *
     * @return boolean
     */
     
    public override bool GetUseJavascript()
    {
      return (GetOwner().GetAccessStyle() != AccessStyles.SECTION_508);
    }
  }
}