using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.sso;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.impl.community;
using com.plumtree.server.marshalers;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <author>MichaelD</author>
  public class MyPortalModel : AClearModel,IModel,IMyPortalModelRO,IMyPortalModel,
  IRepostModel,IJoinPreviewCommunityModel,IUnsubscribeCommunityModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.MyPortalModel");
    
    /// <summary>
    /// Class Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MyPortal";
    public const String PROFILEDATA_SESSIONVAR_NAME = "LastProfileData";
    
    /// <summary>
    /// Content Canvas Column 
    /// </summary>
    public const int N_CONTENTCANVAS_COLUMN = 3;
    
    /// <summary>
    /// User Interface 508 
    /// </summary>
    private const String STR_USERINTERFACE_508 = "http://www.plumtree.com/uis/section508";
    
    /// <summary>
    /// My Portal Model Helper 
    /// </summary>
    private IMyPortalModelHelper m_myPortalModelHelper = null;
    
    /// <summary>
    /// Session 
    /// </summary>
    private IPTSession m_ptSession = null;
    
    /// <summary>
    /// Community ID 
    /// </summary>
    public int m_nCommunityID = NavigationModel.NO_CURRENT_COMMID;
    
    /// <summary>
    /// Page ID 
    /// </summary>
    public int m_nPageID = 0;
    
    /// <summary>
    /// Page Name *
    /// </summary>
    public String m_strPageName = null;
    
    /// <summary>
    /// mj: true if this is a user profile community page 
    /// </summary>
    public bool m_bIsProfilePage = false;
    
    /// <summary>
    /// Profile ID, 0 if not used. *
    /// </summary>
    private int m_nProfileID = 0;
    private IPTProfileManager m_ptProfileManager = null;
    
    /// <summary>
    /// Is Preview Page 
    /// </summary>
    public bool m_bIsPreviewPage = false;
    
    /// <summary>
    /// Raw Headers 
    /// </summary>
    public String m_strRawHeaders = "";
    private int m_nRecentlyRemovedPortlet = 0;
    private int m_nRecentlyCollapsedExpandedPortlet = 0;
    private XPArrayList m_nRecentlyAddedPortlets = new XPArrayList();
    public const String PORTLET_PREF_TYPE = "portletpreftype";
    public const String PERSONAL_PREF_TYPE = "0";
    public const String COMMUNITY_PREF_TYPE = "1";
    public const String ADMIN_PREF_TYPE = "2";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public override void CleanupTempData()
    {
      if (m_bIsProfilePage)
      {
        // mj: clean up user profile community settings in UserInfo
        if (m_ptProfileManager == null)
        {
          m_ptProfileManager = (IPTProfileManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER,
           false);
        }
        m_ptProfileManager.CleanupProfileCommunity();
      }
      m_strRawHeaders = "";
      base.CleanupTempData();
    }
    
    /// <summary>
    /// Collapses the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletID</param>
    public virtual void CollapsePortlet(int nCommunityID, int nPageID, int nPortletToCollapse)
    {
      log.Debug("MyPortalModel::CollapsePortlet");
      String strCollapsedPortletsPrefName = m_myPortalModelHelper.GetCollapsedPortletsPrefName();
      Object objSetting = PTPersonalSettingsHelper.GetPersonalSettingValue(strCollapsedPortletsPrefName,
       m_asOwner);
      XPStringBuilder sbCollapsedPortlets;
      if (objSetting != null)
      {
        sbCollapsedPortlets = new XPStringBuilder(XPConvert.ToString(objSetting));
        } else
      {
        sbCollapsedPortlets = new XPStringBuilder();
      }
      // the first token is null, but the tokenizer skips it
      XPStringTokenizer st = new XPStringTokenizer(sbCollapsedPortlets.ToString(),
       ",");
      // make sure the gadget isn't already in the array
      bool bFound = false;
      if (st.GetTokenCount() > 0)
      {
        while (st.HasMoreTokens())
        {
          int nPortletID = XPConvert.ToInteger(st.GetNextToken());
          if (nPortletID == nPortletToCollapse)
          {
            bFound = true;
          }
        }
      }
      if (!bFound)
      {
        // always append the comma before adding the gadget.  StringTokenizer thinks that "300" has zero tokens, ",300"
        // has one token.  If that's what it wants, that's what we'll do.  -bjf
        sbCollapsedPortlets.Append(",");
        sbCollapsedPortlets.Append(nPortletToCollapse);
        // DCA - mark portlet as recently collapsed
        m_nRecentlyCollapsedExpandedPortlet = nPortletToCollapse;
      }
      // Add to personal preference setting
      PTPersonalSettingsHelper.SetAndCachePersonalSetting(strCollapsedPortletsPrefName,
       sbCollapsedPortlets.ToString(), m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetRecentlyCollapsedExpandedPortlet()"></seealso>
    public virtual int GetRecentlyCollapsedExpandedPortlet()
    {
      return m_nRecentlyCollapsedExpandedPortlet;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#ResetRecentlyCollapsedExpandedPortlet()"></seealso>
    public virtual void ResetRecentlyCollapsedExpandedPortlet()
    {
      m_nRecentlyCollapsedExpandedPortlet = 0;
    }
    
    /// <summary>
    /// Expands the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex">nPortletID</param>
    public virtual void ExpandPortlet(int nCommunityID, int nPageID, int nPortletToExpand)
    {
      log.Debug("MyPortalModel::ExpandPortlet");
      String strCollapsedPortletsPrefName = m_myPortalModelHelper.GetCollapsedPortletsPrefName();
      Object objSetting = PTPersonalSettingsHelper.GetPersonalSettingValue(strCollapsedPortletsPrefName,
       m_asOwner);
      XPStringBuilder sbOriginalCollapsedPortlets;
      if (objSetting != null)
      {
        sbOriginalCollapsedPortlets = new XPStringBuilder(XPConvert.ToString(objSetting));
        } else
      {
        sbOriginalCollapsedPortlets = new XPStringBuilder();
      }
      // the first token is null, but the tokenizer skips it
      XPStringTokenizer st = new XPStringTokenizer(sbOriginalCollapsedPortlets.ToString(),
       ",");
      XPStringBuilder sbNewCollapsedPortlets = new XPStringBuilder();
      // if the PortletToExpand is in the array, take it out
      if (st.GetTokenCount() > 0)
      {
        while (st.HasMoreTokens())
        {
          int nPortletID = XPConvert.ToInteger(st.GetNextToken());
          if (nPortletID != nPortletToExpand)
          {
            sbNewCollapsedPortlets.Append(",");
            sbNewCollapsedPortlets.Append(nPortletID);
          }
        }
      }
      // Add to personal preference setting
      PTPersonalSettingsHelper.SetAndCachePersonalSetting(strCollapsedPortletsPrefName,
       sbNewCollapsedPortlets.ToString(), m_asOwner);
      // DCA - mark portlet as recently expanded
      m_nRecentlyCollapsedExpandedPortlet = nPortletToExpand;
    }
    
    /// <summary>
    /// Adds the specified portlet.
    /// </summary>
    /// <param name="nPageID">nPageID</param>
    /// <param name="nPortletID">nPortletID</param>
    public virtual void AddSinglePortlet(int nPageID, int nPortletID)
    {
      log.Debug("MyPortalModel::AddSinglePortlet " + nPortletID + " to page " + nPageID);
      IPTPage ptPage = (IPTPage) m_ptSession.GetPages().Open(nPageID, false);
      //list of gadgets in the portal
      IPTQueryResult gadgetsInPage = ptPage.QueryPortlets();
      // Check to see if gadget is already in the page
      int intPortlet;
      bool bIsInPage = false;
      for (int i = 0;i < gadgetsInPage.RowCount();i++)
      {
        intPortlet = gadgetsInPage.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (intPortlet == nPortletID)
        {
          bIsInPage = true;
          break;
        }
      }
      if (!bIsInPage)
      {
        // Opens the Page in Locked Mode
        ptPage = (IPTPage) m_ptSession.GetPages().Open(nPageID, true);
        try
        {
          // DCA - always add to the first region for now, when we can tell what regions are wide, uncomment this
          // add the gadget to the correct column in the page
          /*int nPageType = myPage.GetPageType();
           int nColumnForPortlet = 0;
           
           IPTGadget objPortlet = (IPTGadget)m_ptSession.GetGadgets().Open(nPortletID, false);
           
           // If the portlet is narrow, add it to the first narrow column. Otherwise add it to the first
           // wide column (region).
           if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW == objPortlet.GetAlignment())
           {
           nColumnForPortlet = PortletColumnConstants.NARROW_ONE.ToInt();
           
           if (nPageType == PageTypeConstants.ONE_COLUMN)
           {
           nColumnForPortlet = PortletColumnConstants.WIDE_ONE.ToInt();
           }
           }
           else
           {
           nColumnForPortlet = PortletColumnConstants.WIDE_ONE.ToInt();
           }*/
           
          int nColumnForPortlet = PortletColumnConstants.NARROW_ONE.ToInt();
          ptPage.AddPortlet(nPortletID, nColumnForPortlet);
          ptPage.Store();
        }
        catch (XPException xpe)
        {
          log.Error(xpe, "Unable to add portlet " + nPortletID + " to page " + nPageID);
          throw (xpe);
        }
        finally
        {
          // We need to unlock the object if anything fails after we lock it.
          ptPage.UnlockObject();
        }
        // DCA - mark portlet as recently added
        XPArrayList newPortlet = new XPArrayList();
        newPortlet.Add(nPortletID);
        m_nRecentlyAddedPortlets = newPortlet;
      }
    }
    
    /// <summary>
    /// Adds the portlet bundle.
    /// </summary>
    /// <param name="nPageID">nPageID</param>
    /// <param name="nPortletBundleID">nPortletID</param>
    public virtual void AddPortletBundle(int nPageID, int nPortletBundleID)
    {
      log.Debug("MyPortalModel::AddPortletBundle " + nPortletBundleID + " to page " + nPageID);
      IPTPage ptPage = (IPTPage) m_ptSession.GetPages().Open(nPageID, false);
      bool bIsMyPage = (PTPage.GetPageContainerClassID(ptPage.GetAdminFolderID()) == PT_CLASSIDS.PT_MYPAGESCONTAINER_ID);
      //list of gadgets in the portal
      IPTQueryResult gadgetsInPage = ptPage.QueryPortlets();
      int[] nBundledPortlets = GetPortletsInBundle(nPortletBundleID, bIsMyPage);
      XPArrayList newPortlets = new XPArrayList();
      // Check to see which portlets are already on the page
      for (int i = 0;i < nBundledPortlets.Length;i++)
      {
        bool bOnPage = false;
        for (int j = 0;j < gadgetsInPage.RowCount();j++)
        {
          int nPortletID = gadgetsInPage.ItemAsInt(j, PT_PROPIDS.PT_PROPID_OBJECTID);
          if (nBundledPortlets[i] == nPortletID)
          {
            bOnPage = true;
            break;
          }
        }
        if (!bOnPage)
        {
          newPortlets.Add(nBundledPortlets[i]);
        }
      }
      // Add the portlets to the page.
      if (!newPortlets.IsEmpty())
      {
        // Opens the Page in Locked Mode
        ptPage = (IPTPage) m_ptSession.GetPages().Open(nPageID, true);
        int nPortletID = -1;
        try
        {
          // add the portlets to the correct column in the page
          //int nPageType = myPage.GetPageType();
          IXPEnumerator portlets = newPortlets.GetEnumerator();
          while (portlets.MoveNext())
          {
            nPortletID = XPConvert.ToInteger((int) portlets.GetCurrent());
            //IPTGadget objPortlet = (IPTGadget)m_ptSession.GetGadgets().Open(nPortletID, false);
            int nColumnForPortlet = PortletColumnConstants.NARROW_ONE.ToInt();
            // DCA - always add to the first region for now, when we can tell what regions are wide, uncomment this
            // If the portlet is narrow, add it to the first narrow column. Otherwise add it to the first
            // wide column (region).
            /*if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW == objPortlet.GetAlignment())
             {
             nColumnForPortlet = PortletColumnConstants.NARROW_ONE.ToInt();
             
             if (nPageType == PageTypeConstants.ONE_COLUMN)
             {
             nColumnForPortlet = PortletColumnConstants.WIDE_ONE.ToInt();
             }
             }
             else
             {
             nColumnForPortlet = PortletColumnConstants.WIDE_ONE.ToInt();
             }*/
             
            ptPage.AddPortlet(nPortletID, nColumnForPortlet);
          }
          ptPage.Store();
        }
        catch (XPException xpe)
        {
          String strError = "Unable to add portlet " + nPortletID + " to page " + nPageID + " from portlet bundle " + nPortletBundleID;
          log.Error(xpe, strError);
          throw (new XPException(strError, xpe));
        }
        finally
        {
          // We need to unlock the object if anything fails after we lock it.
          ptPage.UnlockObject();
        }
        // DCA - mark portlet as recently added
        m_nRecentlyAddedPortlets = newPortlets;
      }
    }
    
    /// <summary>
    /// This helper method gets the portlets in a bundle.
    /// This method is only public so it can be unit-tested.  It should
    /// not be used outside of the MyPortalModel class.
    /// </summary>
    /// <param name="_nPortletBundleID">The ID of the bundle to open.</param>
    /// <param name="_bIsMyPage">whether or not the containing page is a mypage.</param>
    /// <returns>the portlets in the bundle.</returns>
    public virtual int[] GetPortletsInBundle(int _nPortletBundleID, bool _bIsMyPage)
    {
      IPTGadgetBundle bundle = (IPTGadgetBundle) m_ptSession.GetGadgetBundles().Open(_nPortletBundleID,
       false);
      Object[] aoPortletTypes;
      if (_bIsMyPage)
      {
        // If for my page set gadget type filter to personal
        aoPortletTypes = new Object[]{PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL};
        } else
      {
        aoPortletTypes = new Object[0];
      }
      IPTQueryResult bundledPortlets = bundle.QueryGadgets(aoPortletTypes);
      int[] nBundledPortlets = new int[bundledPortlets.RowCount()];
      for (int i = 0;i < bundledPortlets.RowCount();i++)
      {
        nBundledPortlets[i] = bundledPortlets.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        }
      return nBundledPortlets;
    }
    
    /// <summary>
    /// Reassigns the specified column (region) in the page with the given portlet array.
    /// </summary>
    /// <param name="arrPortletIDs">array of portlet IDs</param>
    /// <param name="nColumn">nColumn</param>
    /// <param name="nPageID">nPageID</param>
    public virtual void ReassignPortlets(int[] arrPortletIDs, int nColumn,
     int nPageID)
    {
      log.Debug("MyPortalModel::ReassignPortlets - Reordering column " + nColumn + " on page " + nPageID);
      // Opens the Page in Locked Mode		
      IPTPage myPage = (IPTPage) m_ptSession.GetPages().Open(nPageID, true);
      try
      {
        // This will remove the current portlets in the column first before
        // adding the portlets in arrPortletIDs.
        myPage.AssignPortlets(arrPortletIDs, nColumn);
        myPage.Store();
      }
      catch (XPException xpe)
      {
        log.Error(xpe, "Unable to reorder column " + nColumn + " on page " + nPageID);
        throw (xpe);
      }
      finally
      {
        // We need to unlock the object if anything fails after we lock it.
        myPage.UnlockObject();
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetRecentlyAddedPortlet()"></seealso>
    public virtual XPArrayList GetRecentlyAddedPortlets()
    {
      return m_nRecentlyAddedPortlets;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#ResetRecentlyAddedPortlet()"></seealso>
    public virtual void ResetRecentlyAddedPortlets()
    {
      m_nRecentlyAddedPortlets = new XPArrayList();
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModel#QueryRecentlyAddedPortletContent()"></seealso>
    public virtual bool QueryRecentlyAddedPortletContent()
    {
      // DCA - for adding through ajax (not currently used)
      return QuerySpcificPortletContent(m_nRecentlyAddedPortlets);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModel#QueryRecentlyCollapsedExpandedPortletContent()"></seealso>
    public virtual bool QueryRecentlyCollapsedExpandedPortletContent()
    {
      // DCA - for collapsing/expanding through ajax (not currently used)
      if (m_nRecentlyCollapsedExpandedPortlet > 0)
      {
        IXPList xpList = new XPArrayList();
        xpList.Add(XPConvert.ToString(m_nRecentlyCollapsedExpandedPortlet));
        return QuerySpcificPortletContent(xpList);
      } else
      {
        return false;
      }
    }
    protected virtual bool QuerySpcificPortletContent(IXPList xpPortletIds)
    {
      if (xpPortletIds.IsEmpty())
      {
        return false;
      }
      try
      {
        int[] nPortletIds = new int[xpPortletIds.GetSize()];
        for (int i = 0;i < xpPortletIds.GetSize();i++)
        {
          nPortletIds[i] = XPConvert.ToInteger(xpPortletIds.GetElement(i));
          }
        MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
        objTempData.InitializePortletContent(this, nPortletIds);
      }
      catch (Exception e)
      {
        log.Error(e, "MyPortalModel:QuerySpcificPortletContent An error occured while trying to get portlet contents.");
        return false;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new MyPortalModel();
    }
    
    /// <summary>
    /// Method DeletePage.
    /// Deletes page with given id.
    /// </summary>
    /// <param name="nPageID"></param>
    /// <returns>boolean</returns>
    public virtual void DeletePage(int nPageID)
    {
      log.Debug("MyPortalModel::DeletePage");
      try
      {
        if (m_ptSession.GetSessionInfo().GetCurrentMyPages().RowCount() <= 1)
        {
          throw new XPException("The last page of your mypages cannot be deleted");
          }
        if (nPageID <= 0)
        {
          // cannot home page
          throw new XPException("Home page cannot be deleted.");
        }
        try
        {
          // UserProfileActions PEI
          // BrianH: All of the following code will load all of the available UserProfileAction
          // PEIs and process through them. If they return a false string an error will
          // appear and the saving of the user profile information will stop.
          Object[] oa;
          Object o;
          IMyPortalPageActions iActions;
          IApplication application = m_asOwner.GetApplication();
          oa = (Object[]) application.GetCachingManager().GetEntry("MyPortalPageActions");
          if (oa != null)
          {
            String sErrorMsgs = "";
            for (int x = 0;x < oa.Length;x++)
            {
              o = oa[x];
              log.Debug("DeletePage() - About to call OnBeforeRemoveMyPortalPage on an: " + o);
              if (o != null)
              {
                String sError;
                iActions = (IMyPortalPageActions) o;
                sError = iActions.OnBeforeRemoveMyPortalPage(m_asOwner, m_ptSession,
                 nPageID);
                if ((null != sError) && (sError.Length > 0))
                {
                  sErrorMsgs+=sError + " ";
                }
              }
            }
            if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
            {
              UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER,
               null, sErrorMsgs, sErrorMsgs);
              UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
               m_asOwner.GetApplication());
              return;
            }
          }
          //PEI : OnBeforeRemoveMyPortalPage : END
          m_ptSession.GetPages().Delete(nPageID);
          //PEI : OnAfterRemoveMyPortalPage : BEFORE					
          if (oa != null)
          {
            for (int x = 0;x < oa.Length;x++)
            {
              o = oa[x];
              log.Debug("DeletePage() - About to call OnAfterRemoveMyPortalPage on an: " + o);
              if (o != null)
              {
                iActions = (IMyPortalPageActions) o;
                iActions.OnAfterRemoveMyPortalPage(m_asOwner, m_ptSession,
                 nPageID);
              }
            }
          }
        }
        //PEI : OnAfterRemoveMyPortalPage : END
        catch (Exception xpe)
        {
          log.Warn(xpe, "MyPortalModel.DeletePage: Deleting page " + nPageID + " was not successful");
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           xpe, m_asOwner.GetString(681, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(682,
           "ptmsgs_portalbrowsingmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
      }
      catch (XPException xpe)
      {
        log.Warn(xpe, "MyPortalModel.DeletePage: Deleting page " + nPageID + " was not successful");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         xpe, m_asOwner.GetString(683, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(684,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    public virtual void Finish()
    {
    }
    public virtual AActivitySpace GetParentSpace()
    {
      return m_asOwner;
    }
    public virtual String GetPortletPrefButtonBoolean()
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_strPortletPrefButton;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetCommunityID()"></seealso>
    public virtual int GetCommunityID()
    {
      return m_nCommunityID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetCommunityName()"></seealso>
    public virtual String GetCommunityName()
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      if (GetIsCommunityPage())
      {
        return objTempData.m_strCommunityName;
      }
      return m_asOwner.GetString(678, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetLastPortletIndexInColumn()"></seealso>
    public virtual IPTQueryResult GetCommunityPages()
    {
      log.Debug("MyPortalModel::GetCommunityPages");
      return m_myPortalModelHelper.GetCommunityPages(m_nCommunityID);
    }
    
    /// <returns></returns>
    public virtual String GetCurCommName()
    {
      log.Debug("MyPortalModel::GetCurCommName");
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_strCommunityName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetFirstPortletIndexInColumn(int)"></seealso>
    public virtual int GetFirstPortletIndexInColumn(int nPortletColumn)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arFirstPortletIndex[nPortletColumn];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCollapsed(int)"></seealso>
    public virtual bool GetPortletCollapsed(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arPortletCollapsed[nPortletIndex];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#RemoveSinglePortlet(int,int)"></seealso>
    public virtual void RemoveSinglePortlet(int nPageID, int nPortletID)
    {
      log.Debug("MyPortalModel::RemoveSinglePortlet " + nPortletID + " from page " + nPageID);
      // Opens the Page in Locked Mode
      IPTPage myPage = (IPTPage) GetSession().GetPages().Open(nPageID, true);
      try
      {
        myPage.RemovePortlet(nPortletID);
        myPage.Store();
      }
      catch (XPException xpe)
      {
        log.Error("Unable to remove portlet " + nPortletID + " from page " + nPageID);
        throw (xpe);
      }
      finally
      {
        // We need to unlock the object if there was an error removing or storing it.
        myPage.UnlockObject();
      }
      // DCA - mark portlet as recently removed
      m_nRecentlyRemovedPortlet = nPortletID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetRecentlyRemovedPortlet()"></seealso>
    public virtual int GetRecentlyRemovedPortlet()
    {
      return m_nRecentlyRemovedPortlet;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#ResetRecentlyRemovedPortlet()"></seealso>
    public virtual void ResetRecentlyRemovedPortlet()
    {
      m_nRecentlyRemovedPortlet = 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletColumnFromIndex(int)"></seealso>
    public virtual int GetPortletColumnFromIndex(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arPortletColumns[nPortletIndex];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCount()"></seealso>
    public virtual int GetPortletCount()
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_nPortletCount;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletDisabledMessage(int)"></seealso>
    public virtual String GetPortletDisabledMessage(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return (objTempData.m_portletcontent.GetDisabledMessage(nPortletIndex));
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletEnabled(int)"></seealso>
    public virtual bool GetPortletEnabled(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetEnabled(nPortletIndex);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHTMLTextFromIndex(int)"></seealso>
    public virtual Object[][] GetPortletHTMLTextFromIndex(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetContent(nPortletIndex);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasHelpURL(int)"></seealso>
    public virtual bool GetPortletHasHelpURL(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetHasHelpURL(nPortletIndex);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasRefreshButton(int)"></seealso>
    public virtual bool GetPortletHasRefreshButton(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetHasRefreshButton(nPortletIndex);
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasAdminPrefsURL(int)"></seealso>
    public virtual bool GetPortletHasAdminPrefsURL(int nPortletIndex)
    {
      int nPrefsBitMask = GetPortletSupportsPersonalization(nPortletIndex);
      int nCurPortletID = GetPortletIDFromIndex(nPortletIndex);
      bool bIsGuestUser = IsGuestSession(m_asOwner);
      bool bHasAdminAccessToPortlet = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckGadgetAccess(nCurPortletID) >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
      bool bHasAdminPrefs = false;
      if (!bIsGuestUser)
      {
        bHasAdminPrefs = (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR & nPrefsBitMask) > 0 && bHasAdminAccessToPortlet;
        }
      return bHasAdminPrefs;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasCommunityPrefsURL(int)"></seealso>
    public virtual bool GetPortletHasCommunityPrefsURL(int nPortletIndex)
    {
      int nPrefsBitMask = GetPortletSupportsPersonalization(nPortletIndex);
      int nCurCommunityID = GetCommunityID();
      bool bIsCommunityPage = nCurCommunityID > 0;
      bool bIsGuestUser = IsGuestSession(m_asOwner);
      bool bHasCommPrefs = false;
      if (!bIsGuestUser)
      {
        bHasCommPrefs = bIsCommunityPage && (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER & nPrefsBitMask) > 0 && TaskAPIUICommunity.IsCurrentUserCommunityOwner(m_asOwner);
        }
      return bHasCommPrefs;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasUserPrefsURL(int)"></seealso>
    public virtual bool GetPortletHasUserPrefsURL(int nPortletIndex)
    {
      int nPrefsBitMask = GetPortletSupportsPersonalization(nPortletIndex);
      bool bIsGuestUser = IsGuestSession(m_asOwner);
      bool bHasPersonalPrefs = (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER & nPrefsBitMask) > 0;
      bool bHasUserPrefs = false;
      if (!bIsGuestUser && bHasPersonalPrefs)
      {
        bHasUserPrefs = true;
      }
      return bHasUserPrefs;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasCollapseExpandURL(int)"></seealso>
    public virtual bool GetPortletHasCollapseExpandURL(int nPortletIndex)
    {
      bool bHasCollapseExpandURL = false;
      // Only allow collapse/expand if portlet is not mandatory
      if (!GetPortletIsMandatory(nPortletIndex) && !IsGuestSession(m_asOwner))
      {
        bHasCollapseExpandURL = true;
      }
      return bHasCollapseExpandURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHasTitleBar(int)"></seealso>
    public virtual bool GetPortletHasTitleBar(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arPortletHasTitleBar[nPortletIndex];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#SetDisplayPortletHeaderDueToError(int)"></seealso>
    public virtual bool GetDisplayPortletHeaderDueToError(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arDisplayPortletHeaderDueToError[nPortletIndex];
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#SetDisplayPortletHeaderDueToError(int)"></seealso>
    public virtual void SetDisplayPortletHeaderDueToError(int nPortletIndex,
     bool bDisplayHeader)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      // If this array isn't initialized, it means we're not using it (in flyout, probably).
      if (objTempData.m_arDisplayPortletHeaderDueToError != null)
      {
        objTempData.m_arDisplayPortletHeaderDueToError[nPortletIndex] = bDisplayHeader;
        }
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletHelpURL(int)"></seealso>
    public virtual String GetPortletHelpURL(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      String strHelpURL = GatewayHelpers.ConstructHelpLink(m_asOwner, objTempData.m_portletcontent.GetGadgetID(nPortletIndex),
       (m_nCommunityID > 0) ? m_nCommunityID : 0, m_nPageID, m_asOwner.GetAccessStyle() == AccessStyles.STANDARD);
      return strHelpURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletAdminPrefsURL(int)"></seealso>
    public virtual String GetPortletAdminPrefsURL(int nPortletIndex)
    {
      String strAdminPrefsURL;
      if (GetPortletHasAdminPrefsURL(nPortletIndex))
      {
        int nCurPortletID = GetPortletIDFromIndex(nPortletIndex);
        strAdminPrefsURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_GADGET_ID,
         nCurPortletID, IPTOpenerConstants.OPENER_MODE_EDIT, m_asOwner);
      } else
      {
        strAdminPrefsURL = "";
      }
      return strAdminPrefsURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCommunityPrefsURL(int)"></seealso>
    public virtual String GetPortletCommunityPrefsURL(int nPortletIndex)
    {
      String strCommunityPrefsURL;
      if (GetPortletHasCommunityPrefsURL(nPortletIndex))
      {
        int nCurPortletID = GetPortletIDFromIndex(nPortletIndex);
        int nCurCommunityID = GetCommunityID();
        int nCurPageID = GetPageID();
        bool bUsePopup = (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD);
        strCommunityPrefsURL = GatewayHelpers.ConstructCommunityPrefsLink(m_asOwner,
         nCurPortletID, nCurCommunityID, nCurPageID, bUsePopup);
      } else
      {
        strCommunityPrefsURL = "";
      }
      return strCommunityPrefsURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletUserPrefsURL(int)"></seealso>
    public virtual String GetPortletUserPrefsURL(int nPortletIndex)
    {
      String strUserPrefsURL;
      if (GetPortletHasUserPrefsURL(nPortletIndex))
      {
        int nCurPortletID = GetPortletIDFromIndex(nPortletIndex);
        int nCurCommunityID = GetCommunityID();
        int nCurPageID = GetPageID();
        bool bIsCommunityPage = nCurCommunityID > 0;
        bool bUsePopup = (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD);
        // link to the community-user-gadget prefs page, because this is a user clicking on edit preferences
        // from within a community
        if (bIsCommunityPage)
        {
          strUserPrefsURL = GatewayHelpers.ConstructPortletUserCommunityPrefsLink(m_asOwner,
           nCurPortletID, nCurCommunityID, bUsePopup);
        } else
        {
          strUserPrefsURL = GatewayHelpers.ConstructPortletPrefsLink(m_asOwner,
           nCurPortletID, nCurPageID, bUsePopup);
        }
      } else
      {
        strUserPrefsURL = "";
      }
      return strUserPrefsURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletCollapseExpandURL(int)"></seealso>
    public virtual String GetPortletCollapseExpandURL(int nPortletIndex, String strControl)
    {
      String strCollapseExpandURL;
      if (GetPortletHasCollapseExpandURL(nPortletIndex))
      {
        // Build URL for Collapse Or Expand
        ASURL collURL = GetPageASURL();
        collURL.AddControlArgument(CollapsePortletControl.STR_PORTLET_TO_COLLAPSE_EXPAND,
         GetPortletIDFromIndex(nPortletIndex));
        collURL.SetControl(strControl);
        strCollapseExpandURL = collURL.GetURLAsString();
      } else
      {
        strCollapseExpandURL = "";
      }
      return strCollapseExpandURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletRemoveURL(int)"></seealso>
    public virtual String GetPortletRemoveURL(int nPortletIndex)
    {
      String strRemoveURL;
      if (!GetPortletIsMandatory(nPortletIndex) && !IsGuestSession(m_asOwner))
      {
        // Build URL for Remove Portlet
        ASURL remURL = GetPageASURL();
        remURL.AddControlArgument(AddRemovePortletControl.STR_PORTLET_TO_REMOVE,
         GetPortletIDFromIndex(nPortletIndex));
        remURL.SetControl(AddRemovePortletControl.STR_MVC_CLASS_NAME);
        strRemoveURL = remURL.GetURLAsString();
      } else
      {
        strRemoveURL = "";
      }
      return strRemoveURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletIDFromIndex(int)"></seealso>
    public virtual int GetPortletIDFromIndex(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arPortletIDs[nPortletIndex];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletIsMandatory(int)"></seealso>
    public virtual bool GetPortletIsMandatory(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arPortletIsMandatory[nPortletIndex];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletNameFromIndex(int)"></seealso>
    public virtual String GetPortletNameFromIndex(int nPortletColumn)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetGadgetName(nPortletColumn);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetIDStringForPortlet(int)"></seealso>
    public virtual String GetIDStringForPortlet(int nPortletIndex)
    {
      return PTStyleID.GetIDStringForPortlet(GetPortletIDFromIndex(nPortletIndex));
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletUUID(int)"></seealso>
    public virtual String GetPortletUUID(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetGadgetUUID(nPortletIndex);
    }
    
    /// <summary>
    /// Method GetPortletSupports508.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>boolean</returns>
    public virtual bool GetPortletSupports508(int nPortletIndex)
    {
      if (m_asOwner.GetAccessStyle() != AccessStyles.SECTION_508)
      {
        return false;
      }
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetSupportsUserInterface(nPortletIndex);
      }
    
    /// <summary>
    /// Method GetPortletSupportsPersonalization.
    /// Compare the returned bitmask to the PT_GADGETPERSONALIZATION_ROLES constants.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>A bitmask of the types of personalization that this portlet supports.</returns>
    public virtual int GetPortletSupportsPersonalization(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetSupportsPersonalization(nPortletIndex);
      }
    
    /// <summary>
    /// Method GetPortletCollapsedOrErrorContent.
    /// Returns markup which should be displayed in case of an error or collapsed portlet.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>object markup array</returns>
    public virtual Object[][] GetCollapsedOrErrorContent(int nPortletIndex)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_portletcontent.GetCollapsedOrErrorContent(nPortletIndex);
      }
    
    /// <returns></returns>
    public virtual IMyPortalModelHelper GetHelper()
    {
      return m_myPortalModelHelper;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetIsCommunityPage()"></seealso>
    public virtual bool GetIsCommunityPage()
    {
      //MyPortalModelTempData objTempData = (MyPortalModelTempData)GetTempData();
      return m_myPortalModelHelper.GetIsCommunityPage();
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetLastPortletIndexInColumn(int)"></seealso>
    public virtual int GetLastPortletIndexInColumn(int nPortletColumn)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_arLastPortletIndex[nPortletColumn];
    }
    ///////////////////////////////////////
    // Read only methods from IModelRO
    ///////////////////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModelRO#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This method returns a new temporary data object.  It is called at the beginning
    /// of a new HTTP Request.  This method can perform initialization on the data
    /// object if necessary.
    /// </summary>
    /// <returns>Object the new temporary data object</returns>
    public override Object GetNewTempData()
    {
      MyPortalModelTempData ptTempData = new MyPortalModelTempData(this);
      return ptTempData;
    }
    ////////////////////////////////////////////
    // Read only methods from IMyPortalModelRO
    ////////////////////////////////////////////
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageASURL()"></seealso>
    public virtual ASURL GetPageASURL()
    {
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkGetCachedSpace(m_asOwner);
      if (!(m_asOwner.GetName()).Equals(MyPageAS.STR_MVC_CLASS_NAME))
      {
        url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, XPConvert.ToString(m_nCommunityID));
        }
      url.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(GetPageID()));
      if (m_bIsProfilePage)
      {
        url.AddControlArgument(SetCommunityControl.PROFILEID, m_nProfileID);
        }
      return url;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageID()"></seealso>
    public virtual int GetPageID()
    {
      return m_nPageID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageName()"></seealso>
    public virtual String GetPageName()
    {
      // rob: if we have a cached page name, use it
      if (m_strPageName != null)
      {
        return m_strPageName;
      }
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_ptPageInfo.GetName();
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPageType()"></seealso>
    public virtual int GetPageType()
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_nPageType;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetPortletLayoutId()"></seealso>
    public virtual int GetPortletLayoutId()
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      if (objTempData.m_nPageType >= 0)
      {
        return 0;
      }
      // make the return value positive since the id is stored as a negative value
      return -objTempData.m_nPageType;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#UsesPortletLayout()"></seealso>
    public virtual bool UsesPortletLayout()
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      return objTempData.m_nPageType < 0;
    }
    
    /// <summary>
    /// Returns the Redirect object  (this is were we need to go at the end of
    /// the Editor).
    /// </summary>
    /// <returns>Redirect</returns>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetSession()"></seealso>
    public virtual IPTSession GetSession()
    {
      return m_ptSession;
    }
    /////////////////////////
    // Methods from IModel
    /////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public override void Init(AActivitySpace parent)
    {
      //MyPortalModelTempData objTempData = (MyPortalModelTempData)GetTempData();
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      m_asOwner.SetIsInPlaceRefreshEnabled(true);
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Checks if access to communities is enabled or not in experience definition
    /// </summary>
    /// <returns>true if access to communities is enabled, returns false if it is disabled.</returns>
    private bool IsCommunitiesEnabled()
    {
      IPTSubPortalInfo subportalinfo = m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
      int intAccessType = subportalinfo.GetAccessType();
      return ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS & intAccessType) != 0);
      }
    
    /// <summary>
    /// Sets the community to be viewed and calls SetPage
    /// </summary>
    /// <param name="nCommunityID">nCommunityID</param>
    /// <param name="nPageID">nPageID</param>
    /// <returns>true if successful, else false</returns>
    public virtual bool SetCommunity(int nCommunityID, int nPageID)
    {
      // Checks to see if access to communities is enabled or not
      // in experience definition, if disabled we raise an error for 
      // user stating the community can not be accessed.
      if (!IsCommunitiesEnabled())
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(661, "ptmsgs_portalbrowsingmsgs"), null);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        throw new XPException("current user does not have access to this community.");
        }
      m_nCommunityID = nCommunityID;
      log.Info("MyPortalModel.setCommunity: Set community to " + m_nCommunityID);
      return SetPage(nPageID);
    }
    
    /// <summary>
    /// Sets the host page URI that is later used to initialize the
    /// AppDataObject
    /// </summary>
    /// <param name="strHostPageURI">strHostPageURI</param>
    public virtual void SetHostPageURI(String strHostPageURI)
    {
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      objTempData.m_strHostPageURI = strHostPageURI;
    }
    
    /// <summary>
    /// Sets the MyPortalModelHelper that will be used. Init must be called
    /// before this (Init is called by RegisterModel).
    /// </summary>
    /// <param name="myPortalModelHelper">myPortalModelHelper</param>
    public virtual void SetMyPortalModelHelper(IMyPortalModelHelper myPortalModelHelper)
    {
      m_myPortalModelHelper = myPortalModelHelper;
      m_myPortalModelHelper.Init(m_ptSession, m_asOwner);
    }
    ////////////////////////
    // Control methods
    ////////////////////////
    
    /// <summary>
    /// Sets up the page of the given ID.
    /// </summary>
    /// <param name="nPageID">nPageID</param>
    /// <returns>true if successful, else false; false requires login redirect</returns>
    public virtual bool SetPage(int nPageID)
    {
      log.Debug("MyPortalModel::SetPage");
      bool bSuccessful = true;
      m_nPageID = nPageID;
      try
      {
        GetTempData();
      }
      catch (Exception e)
      {
        bSuccessful = false;
        log.Warn(e, "MyPortalModel.setPage: Setting page to " + nPageID + " was not successful");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(681, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(682,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return bSuccessful;
    }
    
    /// <summary>
    /// Method SetProfileID.  Returns false if the current user doesn't have access to the given profile.
    /// </summary>
    /// <param name="nProfileID"></param>
    /// <returns>true if successful, else false</returns>
    public virtual bool SetProfileID(int nProfileID)
    {
      log.Debug("MyPortalModel::SetProfileID");
      if (nProfileID == 0)
      {
        m_bIsProfilePage = false;
      } else
      {
        // mj: set user profile id on userinfo, and a boolean so we'll remember to take it off
        m_bIsProfilePage = true;
        // mj: -1 is special value indicating that the user is looking at their own profile
        if (nProfileID == -1)
        {
          m_nProfileID = m_ptSession.GetSessionInfo().GetCurrentUserID();
          } else
        {
          m_nProfileID = nProfileID;
        }
        try
        {
          m_ptProfileManager = (IPTProfileManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER,
           false);
          m_ptProfileManager.SetupProfileCommunity(m_nProfileID);
        }
        catch (Exception e)
        {
          log.Warn(e, "MyPortalModel.SetProfileID: viewing profile of user id" + m_nProfileID + " was not successful");
          // mj: if this method fails, it means we don't have access to this user
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           e, m_asOwner.GetString(681, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(682,
           "ptmsgs_portalbrowsingmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          return false;
        }
      }
      // Fix for bug #66477 - Need to cache the profile data since gateway requests don't pass along
      // that information.
      // Set profile data on the session, used by gatewaycontrol for profile page portlets
      // the profile data of the last viewed profile page is stored in the session so browsing
      // two profile pages at the same time in two browsers with the same session might result
      // in getting the wrong wrong profile page 
      IPTUserInfo profileInfo = m_ptSession.GetUserInfo();
      XPHashtable map = new XPHashtable();
      map.PutElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERID, profileInfo.GetProfileUserID() + "");
      map.PutElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERNAME, profileInfo.GetSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERNAME));
      map.PutElement(PlumtreeExtensibility.PT_USERINFO_PROFILEDESCRIPTION,
       profileInfo.GetSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEDESCRIPTION));
      map.PutElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUNIQUENAME,
       profileInfo.GetSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEUNIQUENAME));
      map.PutElement(PlumtreeExtensibility.PT_USERINFO_PROFILEAUTHNAME, profileInfo.GetSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEAUTHNAME));
      map.PutElement(PlumtreeExtensibility.PT_USERINFO_PROFILELOGINNAME, profileInfo.GetSetting(PlumtreeExtensibility.PT_USERINFO_PROFILELOGINNAME));
      log.Debug("Storing profile data for user with id: {0} on ActivitySpace session by user with id: {1}",
       profileInfo.GetProfileUserID(), m_ptSession.GetSessionInfo().GetCurrentUserID());
      ISessionManager asSession = m_asOwner.GetSubSession();
      asSession.SetAttribute(PROFILEDATA_SESSIONVAR_NAME, map);
      return true;
    }
    public virtual int GetProfileID()
    {
      return m_nProfileID;
    }
    
    /// <param name="strRawHeaders"></param>
    public virtual void SetRawHeaders(String strRawHeaders)
    {
      m_strRawHeaders = strRawHeaders;
    }
    
    /// <summary>
    /// Register model, view, and control for intrinsic portlet.  Initialize
    /// portlet with the portletID, the IPTMyPortal object, and the
    /// AppDataState object.
    /// </summary>
    /// <param name="_strPortletClass">Class identifier for portlet</param>
    /// <param name="_strStorageName">Storage name for portlet</param>
    /// <param name="_nPortletIndex">Portlet index</param>
    /// <throws>
    /// XPException Exception thrown if model, view, or control is not
    /// registered successfully.
    /// </throws>
    public virtual void SetupIntrinsicPortlet(String _strPortletClass, String _strStorageName,
     int _nPortletIndex)
    {
      log.Debug("MyPortalModel::SetupIntrinsicPortlet");
      MyPortalModelTempData objTempData = (MyPortalModelTempData) GetTempData();
      int nPortletID = GetPortletIDFromIndex(_nPortletIndex);
      // Register Model
      if (!m_asOwner.GetModelExists(_strStorageName))
      {
        bool bModelRegistered = m_asOwner.RegisterModel(_strPortletClass,
         _strStorageName);
        if (!bModelRegistered)
        {
          log.Error("MyPortalModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(676,
           "ptmsgs_portalbrowsingmsgs"));
          throw new XPException(m_asOwner.GetString(676, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      IntrinsicPortletModel iPortletModel = (IntrinsicPortletModel) m_asOwner.GetModel(_strStorageName);
      // Register Section
      if (!m_asOwner.GetViewExists(_strStorageName))
      {
        bool bViewRegistered = m_asOwner.RegisterView(_strPortletClass, _strStorageName,
         iPortletModel);
        if (!bViewRegistered)
        {
          log.Error("MyPortalModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(677,
           "ptmsgs_portalbrowsingmsgs"));
          throw new XPException(m_asOwner.GetString(677, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      // Register Control
      if (iPortletModel.ControlExists())
      {
        if (!m_asOwner.GetControlExists(_strStorageName))
        {
          bool bControlRegistered = m_asOwner.RegisterControl(_strPortletClass,
           _strStorageName, iPortletModel);
          if (!bControlRegistered)
          {
            log.Error("MyPortalModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(675,
             "ptmsgs_portalbrowsingmsgs"));
            throw new XPException(m_asOwner.GetString(675, "ptmsgs_portalbrowsingmsgs"));
            }
        }
      }
      // TODOCR - DonH: presumably this only needs to get set if we are initializing
      // this for the first time.  In fact, if the model for this portlet does not
      // exist, then we can assume that the view and control don't either, and put
      // this all in a single if statement for initialization.  This may be useful
      // because this method gets called once for every page hit.
      // Get the portlet object from the IPTMyPortalPortletContent
      IPTGadget ptPortlet = objTempData.m_portletcontent.GetGadget(_nPortletIndex);
      // Initialize portlet model
      iPortletModel.InitPortlet(objTempData.m_ptPageInfo, objTempData.m_objAppDataState,
       ptPortlet, nPortletID);
    }
    // TODOCR - DonH: It looks like there is currently no way to clean up intrinsic
    // portlets from the myportal space until the entire space is cleaned up.  This
    // means that if an intrinsic portlet is viewed once at the beginning of the
    // session, and then the user browses pages without any intrinsic portlets for
    // the rest of their session, the model, view, and control for that intrinsic
    // portlet will remain on the ActivitySpace for the rest of the session.  This
    // use case may or may not be common, but it's worth looking into since these
    // models contain IPTObjects.  Perhaps those could get garbage collected if
    // the portlet isn't used for a while?
    public virtual bool IsPreviewPage()
    {
      return m_bIsPreviewPage;
    }
    public virtual void SetIsPreviewPage(bool bIsPreviewPage)
    {
      m_bIsPreviewPage = bIsPreviewPage;
    }
    
    /// <summary>
    /// Static utility function for determining if we are using is a guest session
    /// Note that it returns false if editing the guest user via edit default profile
    /// </summary>
    public static bool IsGuestSession(AActivitySpace asOwner)
    {
      return (LoginHelper.INSTANCE.GetIsGuestUser(asOwner.GetUserSession()) && !PlumtreeHelpers.IsEditingDefaultProfile(asOwner));
      }
    
    /// <summary>
    /// Is Error Page
    /// </summary>
    public virtual bool CommunityJoinFailed()
    {
      return ((MyPortalModelTempData) GetTempData()).m_bCommJoinFailed;
    }
    
    /// <summary>
    /// Joins the current community
    /// If the join failed, set the m_bCommJoinFailed flag.
    /// </summary>
    /// <returns>boolean	False if user is already a member, true if succesful</returns>
    public virtual bool JoinCommunity()
    {
      if (!GetIsCommunityPage())
      {
        return false;
      }
      IPTCommunityManager myCommunities = (IPTCommunityManager) m_ptSession.GetCommunities();
      int nCommunityID = GetCommunityID();
      try
      {
        myCommunities.JoinCommunity(nCommunityID, PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE);
        try
        {
          //PEI : CommunityActions
          // MJD: All of the following code will load all of the available CommunityAction
          // PEIs and process through them.
          IApplication application = m_asOwner.GetApplication();
          Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
          if (oa != null)
          {
            for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
            {
              Object o = oa[iCommAction];
              if (o != null)
              {
                ICommunityActions iActions = (ICommunityActions) o;
                iActions.OnAfterUserJoinsCommunity(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                 new int[]{nCommunityID});
              }
            }
          }
        }
        //PEI : CommunityActions : END
        catch (Exception ex)
        {
          log.Error(ex, "OnAfterUserJoinsCommunity PEI failed.");
        }
      }
      catch (Exception e)
      {
        // Should never get here
        log.Error(e, "Unable to join the community. User probably already member");
        ((MyPortalModelTempData) GetTempData()).m_bCommJoinFailed = true;
        return false;
      }
      return true;
    }
    
    /// <summary>
    /// Get invited or preview community URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetCommunityURL()
    {
      int nCommID = GetCommunityID();
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      url.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
      url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, XPConvert.ToString(nCommID));
      url.AddControlArgument(SetCommunityControl.STR_PAGE_ID, XPConvert.ToString(-nCommID));
      return (url.GetURLAsString());
    }
    
    /// <summary>
    /// Get User's default community URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetDefaultCommunityURL()
    {
      IPTQueryResult myCommunities = m_ptSession.GetSessionInfo().GetCurrentCommunityMembership();
      int defCommunityID = myCommunities.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      url.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
      url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, XPConvert.ToString(defCommunityID));
      url.AddControlArgument(SetCommunityControl.STR_PAGE_ID, XPConvert.ToString(-defCommunityID));
      return (url.GetURLAsString());
    }
    
    /// <param name="show"></param>
    public virtual void SetShowJoinCommConfirmPage(bool show)
    {
      ((MyPortalModelTempData) GetTempData()).m_bShowJoinCommConfirmPage = show;
      }
    
    /// <summary>
    /// Show the join community confirmation page or the regular community page.
    /// Only valid on a community page.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool ShowJoinConfirmPage()
    {
      return this.GetIsCommunityPage() && ((MyPortalModelTempData) GetTempData()).m_bShowJoinCommConfirmPage;
      }
    public virtual bool IsPageAvailable()
    {
      return ((MyPortalModelTempData) GetTempData()).m_bIsPageAvailable;
    }
    public virtual void InitializePortletContent()
    {
      ((MyPortalModelTempData) GetTempData()).InitializePortletContent(this,
       null);
    }
    
    /// <summary>
    /// Is Error Page
    /// </summary>
    public virtual bool CommunityUnsubscribeFailed()
    {
      return ((MyPortalModelTempData) GetTempData()).m_bCommUnsubscribeFailed;
      }
    
    /// <summary>
    /// Unsubscribes/quits the current community
    /// If the unsubscribe failed, set the m_bCommUnsubscribeFailed flag.
    /// </summary>
    /// <returns>boolean	False if user is already not a member, true if successful</returns>
    public virtual bool UnsubscribeCommunity()
    {
      if (!GetIsCommunityPage())
      {
        return false;
      }
      IPTCommunityManager myCommunities = (IPTCommunityManager) m_ptSession.GetCommunities();
      int nCommunityID = GetCommunityID();
      try
      {
        myCommunities.QuitCommunity(nCommunityID);
        try
        {
          //PEI : CommunityActions
          // MJD: All of the following code will load all of the available CommunityAction
          // PEIs and process through them.
          IApplication application = m_asOwner.GetApplication();
          Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
          if (oa != null)
          {
            for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
            {
              Object o = oa[iCommAction];
              if (o != null)
              {
                ICommunityActions iActions = (ICommunityActions) o;
                iActions.OnAfterUserQuitsCommunity(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                 new int[]{nCommunityID});
              }
            }
          }
        }
        //PEI : CommunityActions : END
        catch (Exception ex)
        {
          log.Error(ex, "OnAfterUserQuitsCommunity PEI failed.");
        }
      }
      catch (Exception e)
      {
        // Should never get here
        log.Error(e, "Unable to quit the community. User probably already unsubscribed");
        ((MyPortalModelTempData) GetTempData()).m_bCommUnsubscribeFailed = true;
        return false;
      }
      return true;
    }
    
    /// <param name="show"></param>
    public virtual void SetShowUnsubscribeCommConfirmPage(bool show)
    {
      ((MyPortalModelTempData) GetTempData()).m_bShowUnsubscribeCommConfirmPage = show;
      }
    
    /// <summary>
    /// Show the unsubscribe community confirmation page or the regular community page.
    /// Only valid on a community page.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool ShowUnsubscribeConfirmPage()
    {
      return this.GetIsCommunityPage() && ((MyPortalModelTempData) GetTempData()).m_bShowUnsubscribeCommConfirmPage;
      }
    
    /// <summary>
    /// Obtain the Preference Button from the portlet header given the 
    /// portlet index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    public virtual IXPList GetPortletPreferenceActionsData(int nPortletIndex)
    {
      IXPList arPrefActions = new XPArrayList();
      /*
       * Page preference button and dropdown twizzle
       */
       
      String strBool = GetPortletPrefButtonBoolean();
      bool bDisplayPrefButton = "1".Equals(strBool);
      bool bIsGuestUser = MyPortalModel.IsGuestSession(m_asOwner);
      if (bDisplayPrefButton && !bIsGuestUser)
      {
        int nPrefsBitMask = GetPortletSupportsPersonalization(nPortletIndex);
        String strPrefsButtonURL = null;
        String strPrefsButtonTitle = null;
        String strImageServerURL = PTConfigHelper.GetImageServerBaseURL(m_asOwner);
        int nCurPortletID = GetPortletIDFromIndex(nPortletIndex);
        int nCurCommunityID = GetCommunityID();
        bool bIsCommunityPage = nCurCommunityID > 0;
        bool bHasPersonalPrefs = (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER & nPrefsBitMask) > 0;
        bool bHasCommPrefs = bIsCommunityPage && (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER & nPrefsBitMask) > 0 && TaskAPIUICommunity.IsCurrentUserCommunityOwner(m_asOwner);
        bool bHasAdminAccessToPortlet = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckGadgetAccess(nCurPortletID) >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN;
        bool bHasAdminPrefs = (PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ADMINISTRATOR & nPrefsBitMask) > 0 && bHasAdminAccessToPortlet;
        if (bHasPersonalPrefs)
        {
          // get link to the community-user-gadget prefs page, because this is a user clicking on edit preferences
          // from within a community or just regular user preference link
          strPrefsButtonURL = GetPortletUserPrefsURL(nPortletIndex);
          strPrefsButtonTitle = m_asOwner.GetString(1846, "ptmsgs_portalbrowsingmsgs");
          // Add to list
          FullURL url = new FullURL(strPrefsButtonTitle, strPrefsButtonURL);
          url.SetURLImageType(PTImageType.ACTION_PORTLET_EDIT, strImageServerURL);
          url.SetURLData(PORTLET_PREF_TYPE, PERSONAL_PREF_TYPE);
          arPrefActions.Add(url);
        }
        if (bHasCommPrefs)
        {
          String strCommPrefsURL = GetPortletCommunityPrefsURL(nPortletIndex);
          String strCommPrefsTitle = m_asOwner.GetString(1847, "ptmsgs_portalbrowsingmsgs");
          // Add to list
          FullURL url = new FullURL(strCommPrefsTitle, strCommPrefsURL);
          url.SetURLImageType(PTImageType.ACTION_PORTLET_EDIT, strImageServerURL);
          url.SetURLData(PORTLET_PREF_TYPE, COMMUNITY_PREF_TYPE);
          arPrefActions.Add(url);
        }
        if (bHasAdminPrefs)
        {
          String strAdminPrefsURL = GetPortletAdminPrefsURL(nPortletIndex);
          String strAdminTitle = m_asOwner.GetString(1848, "ptmsgs_portalbrowsingmsgs");
          // Add to list
          FullURL url = new FullURL(strAdminTitle, strAdminPrefsURL);
          url.SetURLImageType(PTImageType.ACTION_PORTLET_EDIT, strImageServerURL);
          url.SetURLData(PORTLET_PREF_TYPE, ADMIN_PREF_TYPE);
          arPrefActions.Add(url);
        }
      }
      return arPrefActions;
    }
    
    /// <summary>
    /// temp object 
    /// </summary>
    private class MyPortalModelTempData
    {
      
      /// <summary>
      /// Cache the PortletPrefButton boolean string from VarPack 
      /// </summary>
      public String m_strPortletPrefButton = "";
      public bool m_bFlagPortletPrefButton = false;
      
      /// <summary>
      /// Display the regular Community or the join community confirmation page.
      /// </summary>
      public bool m_bShowJoinCommConfirmPage = false;
      
      /// <summary>
      /// Joining this community failed.
      /// </summary>
      public bool m_bCommJoinFailed = false;
      
      /// <summary>
      /// Display the regular Community or the join community confirmation page.
      /// </summary>
      public bool m_bShowUnsubscribeCommConfirmPage = false;
      
      /// <summary>
      /// Unsubscribing this community failed.
      /// </summary>
      public bool m_bCommUnsubscribeFailed = false;
      
      /// <summary>
      /// Community Name 
      /// </summary>
      public String m_strCommunityName = null;
      
      /// <summary>
      /// Page Info Object 
      /// </summary>
      public IPTPageInfo m_ptPageInfo = null;
      
      /// <summary>
      /// Portlet Content 
      /// </summary>
      public IPTMyPortalGadgetContent m_portletcontent = null;
      
      /// <summary>
      /// Object Application Data State 
      /// </summary>
      public IPTState m_objAppDataState = null;
      
      /// <summary>
      /// Portlet Column Count 
      /// </summary>
      public PortletColumnCountConstants m_PortletColumnCount = PortletColumnCountConstants.NONE;
      
      /// <summary>
      /// Host Page URI 
      /// </summary>
      public String m_strHostPageURI;
      
      /// <summary>
      /// First Portlet Index Array 
      /// </summary>
      public int[] m_arFirstPortletIndex = null;
      
      /// <summary>
      /// Portlet Is Collapsed Array 
      /// </summary>
      public bool[] m_arPortletCollapsed = null;
      
      /// <summary>
      /// Display gadget header because there was an error 
      /// </summary>
      public bool[] m_arDisplayPortletHeaderDueToError = null;
      
      /// <summary>
      /// Portlet Column Array 
      /// </summary>
      public int[] m_arPortletColumns = null;
      
      /// <summary>
      /// Portlet Has Title Bar Array 
      /// </summary>
      public bool[] m_arPortletHasTitleBar = null;
      
      /// <summary>
      /// Portlet ID Array 
      /// </summary>
      public int[] m_arPortletIDs = null;
      
      /// <summary>
      /// Portlet Is Mandatory Array 
      /// </summary>
      public bool[] m_arPortletIsMandatory = null;
      
      /// <summary>
      /// Last Portlet Index Array 
      /// </summary>
      public int[] m_arLastPortletIndex = null;
      
      /// <summary>
      /// Collapsed Portlets Array 
      /// </summary>
      public Object[] m_arCollapsedPortletsForAppDataState = null;
      
      /// <summary>
      /// Portlet Count 
      /// </summary>
      public int m_nPortletCount = 0;
      
      /// <summary>
      /// Page Type 
      /// </summary>
      public int m_nPageType = -1;
      
      /// <summary>
      /// Is the a page available in this container 
      /// </summary>
      public bool m_bIsPageAvailable = true;
      public MyPortalModelTempData(MyPortalModel _model)
      {
        // Build Host Page URI
        ASURL myASURL = new ASURL(_model.m_asOwner);
        myASURL.SetLinkGetCachedSpace(_model.m_asOwner);
        myASURL.AddControlArgument(SetPageControl.STR_PAGE_ID, _model.m_nPageID);
        if ((_model.m_asOwner.GetName()).Equals(MyPageAS.STR_MVC_CLASS_NAME))
        {
          myASURL.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
        } else
        {
          myASURL.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
          myASURL.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
           _model.m_nCommunityID);
          if (_model.m_bIsProfilePage)
          {
            myASURL.AddControlArgument(SetCommunityControl.PROFILEID, _model.GetSession().GetUserInfo().GetProfileUserID());
            }
        }
        // Set Host Page URI
        m_strHostPageURI = myASURL.GetURLAsString() + LinkConstants.AMPERSAND;
        // This will init the NavigationModelTempData so that we only have to check for last modified on the community info object there.
        NavigationModel navModel = (NavigationModel) _model.m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
        if (navModel.IsCommunityPage())
        {
          m_strCommunityName = navModel.GetCurCommunityName();
        }
        IPTPageInfo temp = null;
        try
        {
          temp = _model.GetHelper().OpenPage(_model.m_nCommunityID, _model.m_nPageID);
          }
        catch (PTException ex)
        {
          String strErrorMsg = null;
          if (PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_PAGE == ex.GetErrorCode() || PT_RESULTCODES.PT_E_MYPAGES_PAGE_DOES_NOT_EXIST == ex.GetErrorCode())
          {
            if (PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_PAGE == ex.GetErrorCode())
            {
              strErrorMsg = XPResourceManager.FormatMessage(_model.m_asOwner.GetString(1820,
               "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(_model.m_nPageID),
               XPConvert.ToString(_model.m_nCommunityID));
            }
            temp = _model.GetHelper().OpenPage(_model.m_nCommunityID, 0);
            } else
          if (PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_ALL_PAGES == ex.GetErrorCode() || PT_RESULTCODES.PT_E_MYPAGES_NO_PAGES == ex.GetErrorCode())
          {
            if (PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_ALL_PAGES == ex.GetErrorCode())
            {
              strErrorMsg = XPResourceManager.FormatMessage(_model.m_asOwner.GetString(1822,
               "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(_model.m_nCommunityID));
              } else
            {
              strErrorMsg = _model.m_asOwner.GetString(1823, "ptmsgs_portalbrowsingmsgs");
              }
            m_bIsPageAvailable = false;
          } else
          {
            throw ex;
          }
          if (null != strErrorMsg)
          {
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             ex, strErrorMsg, strErrorMsg);
            myError.SetDisplayOnSeparatePage(false);
            UIErrorHandler.RaiseError(myError, _model.m_asOwner.GetSubSession(),
             _model.m_asOwner.GetApplication());
          }
        }
        if (temp != null)
        {
          // Only set if we got a valid page
          // the page may have changed, if the passed in page id was 0 or a page the current user did not have access to
          _model.m_nPageID = temp.GetObjectID();
          m_ptPageInfo = temp;
          InitPageSpecificVariables(_model);
          log.Info("MyPortalModel.setPage: Setting page to " + _model.m_nPageID);
          // JYS: Update SSO cookie header
          // SSOIntegrator takes care of checking that 
          // SSO is enabled for the current subportal.
          SSOIntegrator.UpdateSSOCookieHeader(_model.m_asOwner);
        } else
        {
          _model.m_nPageID = NavigationModel.NO_CURRENT_PAGEID;
        }
        if (!m_bFlagPortletPrefButton)
        {
          m_strPortletPrefButton = (String) _model.GetParentSpace().GetApplication().GetVarPackManager().GetVariablePackage(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(PTNavSettingsVarPack.INTMYPORTLETPREFBUTTON_IN_PORTLETHEADER);
          m_bFlagPortletPrefButton = true;
        }
      }
      public virtual void InitializePortletContent(MyPortalModel _model, int[] nPortletIds)
      {
        log.Debug("MyPortalModel::InitPortletContent");
        // Process collapsed gadgets for the server.
        ProcessCollapsedPortletsForServer(_model);
        // Create Application Data Object
        // TODO-MJD : should this take the container class id and object id instead of community id?
        this.m_objAppDataState = AppDataObject.GetAppDataObject(_model.m_nCommunityID,
         _model.m_nPageID, this.m_strHostPageURI, _model.m_asOwner, false);
        this.m_objAppDataState.Add(AppDataObject.PT_COLLAPSEDGADGETS, this.m_arCollapsedPortletsForAppDataState,
         0, true);
        //			this.m_objAppDataState.Add(PlumtreeExtensibility.PT_HEADERS_KEY,
        //				_model.m_strRawHeaders, 0, true);
        //Get the information for CanSetCommunity
        NavigationModel navModel = (NavigationModel) _model.m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
        bool bCanSetCommunity = ((_model.m_nCommunityID > 0) && navModel.IsCurCommOwner());
        if (bCanSetCommunity)
        {
          this.m_objAppDataState.Add(PlumtreeExtensibility.PT_CAN_SET_COMMUNITY_KEY,
           PlumtreeExtensibility.PT_CAN_SET, 0, true);
        }
        HttpUtils.SetReturnURI(this.m_strHostPageURI, _model.m_asOwner.GetSubSession());
        // Use Application Data Object to get gadget content
        String userInterface = "";
        if (_model.m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
        {
          userInterface = STR_USERINTERFACE_508;
        }
        if (null == nPortletIds)
        {
          this.m_portletcontent = this.m_ptPageInfo.QueryPortletContent(this.m_objAppDataState,
           userInterface, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, true);
        } else
        {
          this.m_portletcontent = this.m_ptPageInfo.QuerySpecificPortletContent(nPortletIds,
           this.m_objAppDataState, userInterface, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME);
          }
        // Get the number of gadgets on the page from gadget content
        this.m_nPortletCount = this.m_portletcontent.GetCount();
        // Initialize the size of the gadget arrays
        this.m_arPortletIDs = new int[this.m_nPortletCount];
        this.m_arPortletColumns = new int[this.m_nPortletCount];
        this.m_arPortletCollapsed = new bool[this.m_nPortletCount];
        this.m_arDisplayPortletHeaderDueToError = new bool[this.m_nPortletCount];
        this.m_arPortletHasTitleBar = new bool[this.m_nPortletCount];
        this.m_arPortletIsMandatory = new bool[this.m_nPortletCount];
        this.m_arFirstPortletIndex = new int[4];
        this.m_arLastPortletIndex = new int[4];
        int nColumnID;
        // initialize the first/last gadget with -1
        for (int i = 0;i < 4;i++)
        {
          this.m_arFirstPortletIndex[i] = -1;
          this.m_arLastPortletIndex[i] = -1;
        }
        int nColumnZeroMandatoryPortlets = 0;
        int nColumnOneMandatoryPortlets = 0;
        int nColumnTwoMandatoryPortlets = 0;
        for (int i = 0;i < this.m_nPortletCount;i++)
        {
          this.m_arPortletIDs[i] = this.m_portletcontent.GetGadgetID(i);
          this.m_arDisplayPortletHeaderDueToError[i] = false;
          // note -- the server function is SuppressTitleBar, the opposite of HasTitleBar.
          if (this.m_portletcontent.GetSuppressTitleBar(i) == true)
          {
            this.m_arPortletHasTitleBar[i] = false;
          } else
          {
            this.m_arPortletHasTitleBar[i] = true;
          }
          Object[][] objArrMarkup = null;
          try
          {
            // don't process collapsed portlet
            if (this.m_portletcontent.GetEnabled(i))
            {
              // BT: Bug 64737 - Register MVC for intrinsic portlets so that javascript
              // can be included in the HTML. This is needed because the Tag Engine
              // displays javascript for a tag first and then displays the content. Since
              // the ContentTag is responsible for displaying the main content area on a 
              // base page, this means that the MyPortalDP JS will be added before the content
              // (and hence before the layout).
              //
              // Note this bug occurs in layout mode only due to the above. In classic mode, 
              // the body is constructed before the head which registers the intrinsic portlets first.
              IPTGadget gadget = this.m_portletcontent.GetGadget(i);
              if (gadget.GetGadgetProviderCLSID().Equals(PT_PROVIDER_CLSIDS.PT_INTRINSICPORTLET_PROVIDER))
              {
                // BT: Bug 8446935 - Only call this.m_portletcontent.GetContent for intrinsic portlets. Before
                // it was calling CSPPortletProvider.GetHTMLText for remote gadgets and it would generate an additional
                // Portlet View event for Analytics not to mention unnecessary calls to the transformers as well.
                objArrMarkup = this.m_portletcontent.GetContent(i);
                String strPortletClass = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0];
                int nPortletID = this.m_portletcontent.GetGadgetID(i);
                String strStorageName = strPortletClass + nPortletID;
                _model.SetupIntrinsicPortlet(strPortletClass, strStorageName,
                 i);
              }
            }
          }
          catch (PTException ex)
          {
            log.Warn(ex, "Unable to setup intrinsic portlet for portlet ID: " + m_arPortletIDs[i]);
            }
          // Set up gadget columns
          if ((PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER == this.m_portletcontent.GetGadgetAlignment(i)) || (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER == this.m_portletcontent.GetGadgetAlignment(i)))
          {
            this.m_arPortletColumns[i] = PortletColumnConstants.SKIP.ToInt();
            try
            {
              objArrMarkup = this.m_portletcontent.GetContent(i);
              HTMLElement result = new HTMLElementCollection();
              // DAP 2-2-04: handle intrinsic headers + footers also
              if (IntrinsicPortletModel.IsIntrinsicPortlet(objArrMarkup))
              {
                // it's an intrinsic portlet, so no markup is supported
                result.AddInnerHTMLElement(navModel.GetIntrinsicPortletContentWithErrorHandling(i,
                 this.m_arPortletIDs[i], objArrMarkup, this.m_portletcontent.GetGadget(i),
                 this.m_objAppDataState, this.m_portletcontent.GetGadgetName(i)));
                } else
              {
                // it's a standard remote portlet, so process the markup transformer tags
                // NOTE: the shared JS needs to be displayed before all portlets
                result.AddInnerHTMLElement(GatewayUtils.AddMarkupToElement(_model.m_asOwner,
                 objArrMarkup));
              }
              // only set banner in standard mode.  low band/508 will not set it now, then
              // get it from the subportal banner, which has the low band/508 check as well.
              if (_model.m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
              {
                if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER == this.m_portletcontent.GetGadgetAlignment(i))
                {
                  navModel.SetHeaderElement(true, result);
                } else
                {
                  navModel.SetFooterElement(true, result);
                }
              }
            }
            catch (Exception e)
            {
              // do nothing, the subportal Footer will be used.
              log.Warn(e, "Unable to set the header and footer elements.  Using subportal footer.");
              }
          } else
          // Figure out what column to put portlets in if layout has changed
          if (-1 == this.m_portletcontent.GetTopicPos(i))
          {
            // This is a mandatory gadget.
            this.m_arPortletIsMandatory[i] = true;
            if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE == this.m_portletcontent.GetGadgetAlignment(i) || PortletColumnCountConstants.ONE == this.m_PortletColumnCount)
            {
              // Put wide mandatory gadgets in the wide column.
              this.m_arPortletColumns[i] = PortletColumnConstants.WIDE_ONE.ToInt();
              nColumnOneMandatoryPortlets++;
            } else
            {
              // Put narrow mandatory gadgets in the narrow column with the least mandatory gadgets in it.
              if ((PortletColumnCountConstants.THREE == this.m_PortletColumnCount) && (nColumnTwoMandatoryPortlets < nColumnZeroMandatoryPortlets))
              {
                this.m_arPortletColumns[i] = PortletColumnConstants.NARROW_TWO.ToInt();
                nColumnTwoMandatoryPortlets++;
              } else
              {
                this.m_arPortletColumns[i] = PortletColumnConstants.NARROW_ONE.ToInt();
                nColumnZeroMandatoryPortlets++;
              }
            }
          } else
          // Just get the stored column the portlets are stored in 
          {
            this.m_arPortletIsMandatory[i] = false;
            this.m_arPortletColumns[i] = this.m_portletcontent.GetGadgetColumn(i);
            if (this.m_arPortletColumns[i] != PortletColumnConstants.FREE_FORM.ToInt() && PortletColumnCountConstants.ONE == this.m_PortletColumnCount)
            {
              this.m_arPortletColumns[i] = PortletColumnConstants.WIDE_ONE.ToInt();
              }
          }
          // Initially set gadget to not collapsed
          this.m_arPortletCollapsed[i] = false;
          if (this.m_arPortletColumns[i] != PortletColumnConstants.SKIP.ToInt())
          {
            if (-1 == this.m_arPortletColumns[i])
            {
              nColumnID = N_CONTENTCANVAS_COLUMN;
            } else
            {
              nColumnID = this.m_arPortletColumns[i];
            }
            // the first time we fill it in will be the first gadget
            if (this.m_arFirstPortletIndex[nColumnID] == -1)
            {
              this.m_arFirstPortletIndex[nColumnID] = i;
            }
            // always put in the last gadget into the array
            this.m_arLastPortletIndex[nColumnID] = i;
          }
        }
        ProcessCollapsedPortlets();
        ProcessPortletTitleBars(_model);
      }
      private void InitPageSpecificVariables(MyPortalModel _model)
      {
        log.Debug("MyPortalModel::InitPageSpecificVariables");
        // rob: cache the page name on the model, specifically used in the FlyoutPortletAS rename functionality 
        // to get the name of the page 
        _model.m_strPageName = this.m_ptPageInfo.GetName();
        // set boolean that controls forced single-column view
        this.m_nPageType = this.m_ptPageInfo.GetPageType();
        if (_model.m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
        {
          if (this.m_nPageType >= PageTypeConstants.ONE_COLUMN_WITH_FREE_FORM_CONTENT)
          {
            this.m_nPageType = PageTypeConstants.ONE_COLUMN_WITH_FREE_FORM_CONTENT;
            } else
          {
            this.m_nPageType = PageTypeConstants.ONE_COLUMN;
          }
        }
        // Set m_nPortletColumnCount based upon m_nPageType
        switch (this.m_nPageType){
        case PageTypeConstants.ONE_COLUMN:
        case PageTypeConstants.ONE_COLUMN_WITH_FREE_FORM_CONTENT:
        this.m_PortletColumnCount = PortletColumnCountConstants.ONE;
        break;
        case PageTypeConstants.TWO_COLUMN_NARROW_WIDE:
        case PageTypeConstants.TWO_COLUMN_WIDE_NARROW:
        case PageTypeConstants.TWO_COLUMN_NARROW_WIDE_WFFC:
        case PageTypeConstants.TWO_COLUMN_WIDE_WFFC_NARROW:
        case PageTypeConstants.TWO_COLUMN_WFFC_NARROW_WIDE:
        case PageTypeConstants.TWO_COLUMN_WFFC_WIDE_NARROW:
        this.m_PortletColumnCount = PortletColumnCountConstants.TWO;
        break;
        case PageTypeConstants.THREE_COLUMN:
        case PageTypeConstants.THREE_COLUMN_NARROW_WIDE_WFF_NARROW:
        case PageTypeConstants.THREE_COLUMN_WITH_FREE_FORM_CONTENT:
        case PageTypeConstants.THREE_COLUMN_NARROW_WIDENARROW_WFFC:
        case PageTypeConstants.THREE_COLUMN_NARROWWIDE_WFFC_NARROW:
        this.m_PortletColumnCount = PortletColumnCountConstants.THREE;
        break;
        default:
        if (this.m_nPageType < 0)
        {
          this.m_PortletColumnCount = PortletColumnCountConstants.THREE;
        } else
        {
          throw new XPException("MyPortalModel - InitPageSpecificVariables(): Not a valid page type.");
          }
        break;
        }
      }
      
      /// <summary>
      /// Process through the pref that holds collapsed gadgets, and modify
      /// m_arrPortletCollapsed as necessary. Must be called at the end of InitializePortletContent.
      /// </summary>
      private void ProcessCollapsedPortlets()
      {
        log.Debug("MyPortalModel::ProcessCollapsedPortletsForUI");
        try
        {
          for (int j = 0;j < this.m_arCollapsedPortletsForAppDataState.Length;
          j++)
          {
            int nPortletID = XPConvert.ToInteger(m_arCollapsedPortletsForAppDataState[j]);
            for (int i = 0;i < this.m_nPortletCount;i++)
            {
              if (nPortletID == this.m_arPortletIDs[i] && !this.m_arPortletIsMandatory[i])
              {
                this.m_arPortletCollapsed[i] = true;
                // we are done
                break;
              }
            }
          }
        }
        catch (XPException e)
        {
          // we don't really care why this crashes. we will just show every gadget as expanded..
          log.Warn(e, "MyPortalModel.initPortletContent: Exception when getting collapsed gadgets -- probably are none");
          }
      }
      
      /// <summary>
      /// Process through the pref that holds collapsed gadgets, and we will then
      /// pass this into QueryPortletContent via AppDataObject so that the server
      /// can skip processing these gadgets.
      /// </summary>
      private void ProcessCollapsedPortletsForServer(MyPortalModel _model)
      {
        log.Debug("MyPortalModel::ProcessCollapsedPortletsForServer");
        // Get the collapsed gadgets
        String strCollapsedPortletsPrefName = _model.GetHelper().GetCollapsedPortletsPrefName();
        Object oCollapsedPortlets = PTPersonalSettingsHelper.GetPersonalSettingValue(strCollapsedPortletsPrefName,
         _model.m_asOwner);
        String strCollapsedPortlets;
        if (null == oCollapsedPortlets)
        {
          strCollapsedPortlets = "";
        } else
        {
          strCollapsedPortlets = (String) oCollapsedPortlets;
        }
        //	String strCollapsedPortlets = (String)cptuSettings.GetPersonalSetting(m_strServerName, prefsSetting, m_jspSession, getPortal(), m_ptApplication);
        // for each item in the collapsed, loop through
        // this will save time b/c usually there are no collapsed gadgets
        // make an XPArrayList to hold the ids of all gadgets on the page that are collapsed.  We will
        // turn this into an Object[] array, stick it on TempData, and then eventually put it
        // onto AppDataStateObject, where it will be passed into the server.  The server will then
        // skip all processing for collapsed gadgets, an efficiency gain.  -bjf
        XPArrayList arrlistCollapsedPortletsForAppDataState = new XPArrayList();
        try
        {
          // the first token is null, but the tokenizer skips it
          XPStringTokenizer st = new XPStringTokenizer(strCollapsedPortlets,
           ",");
          if (st.GetTokenCount() > 0)
          {
            // commented out for reason above
            //st.nextToken(); // need to advance one b/c the first one is an empty ,
            while (st.HasMoreTokens())
            {
              int nPortletID = XPConvert.ToInteger(st.GetNextToken());
              arrlistCollapsedPortletsForAppDataState.Add(nPortletID);
            }
          }
        }
        catch (XPException e)
        {
          // we don't really care why this crashes. we will just ignore the collapse state.
          log.Warn(e, "MyPortalModel.initPortletContent: Exception when getting collapsed gadgets -- probably are none");
          }
        if (arrlistCollapsedPortletsForAppDataState != null)
        {
          this.m_arCollapsedPortletsForAppDataState = arrlistCollapsedPortletsForAppDataState.ToArray();
          }
      }
      
      /// <summary>
      /// Process through the pref that holds title bar state for gadgets, and
      /// modify m_arrPortletHasTitleBar as necessary. Must be called at the end of InitializePortletContent.
      /// </summary>
      private void ProcessPortletTitleBars(MyPortalModel _model)
      {
        log.Debug("MyPortalModel::ProcessPortletTitleBars");
        // skip all of this for my pages -- individual users can't get rid of title bars.
        if (_model.GetHelper().GetIsCommunityPage() == false)
        {
          return;
        }
        // Get the collapsed gadgets
        Object[][] aoPortletHasNoTitleBar = _model.GetHelper().GetPortletHasNoTitleBar(_model.m_nCommunityID);
        Object oPortletHasNoTitleBar = aoPortletHasNoTitleBar[1][0];
        String strPortletHasNoTitleBar;
        if (null == oPortletHasNoTitleBar)
        {
          strPortletHasNoTitleBar = "";
        } else
        {
          strPortletHasNoTitleBar = (String) oPortletHasNoTitleBar;
        }
        // for each item in the array of gadgets with no title bar, loop through
        try
        {
          // the first token is null, but the tokenizer skips it
          XPStringTokenizer st = new XPStringTokenizer(strPortletHasNoTitleBar,
           ",");
          if (st.GetTokenCount() > 0)
          {
            // commented out for reason above
            //st.nextToken(); // need to advance one b/c the first one is an empty ,
            while (st.HasMoreTokens())
            {
              int nPortletID = XPConvert.ToInteger(st.GetNextToken());
              for (int i = 0;i < this.m_nPortletCount;i++)
              {
                // if the gadget is in the array, then disable the title bar
                if (nPortletID == this.m_arPortletIDs[i])
                {
                  this.m_arPortletHasTitleBar[i] = false;
                  // we are done
                  break;
                }
              }
            }
          }
        }
        catch (XPException e)
        {
          // we don't really care why this crashes. we will just show every gadget as expanded..
          log.Warn(e, "MyPortalModel.initPortletContent: Exception when getting gadgets with no title bars -- probably are none");
          }
      }
    }
  }
}