using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// This object is primarily used for the IMyPortalPageActions as the return parameter
  /// of the OnCreateMyPortalPage. It will contain a page name and page type that will refer
  /// to one of the valid PageTypeConstants.
  /// Created: April 27, 2003
  /// </summary>
  /// <author>Brian C. Harrison</author>
  public class MyPortalPageArguments
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.MyPortalPageArguments");
    //Member variable String corresponding to the Page Name.
    private String m_MYPAGE_NAME = "";
    //Member variable int corresponding to a valid PageTypeConstant.
    private int m_MYPAGE_TYPE;
    
    /// <summary>
    /// Return the Page Name
    /// </summary>
    /// <returns>- return the member variable of the object corresponding to the Page Name.</returns>
    public virtual String GetMyPortalPageName()
    {
      return m_MYPAGE_NAME;
    }
    
    /// <summary>
    /// Return the Page Type
    /// </summary>
    /// <returns>- return the member variable of the object corresponding to the Page Type.</returns>
    public virtual int GetMyPortalPageType()
    {
      return m_MYPAGE_TYPE;
    }
    
    /// <summary>
    /// This method will set a Page Name for a possible modified My Portal Page.
    /// </summary>
    /// <param name="_strPageName">- String corrsponding to a Page Name.</param>
    public virtual void SetMyPortalPageName(String _strPageName)
    {
      m_MYPAGE_NAME = _strPageName;
    }
    
    /// <summary>
    /// This method will allow for a Page Type to be set
    /// </summary>
    /// <param name="_ptcPageType">- int type that must correspond to a valid Page Type Constant.</param>
    public virtual void SetMyPortalPageType(int _ptcPageType)
    {
      if (_ptcPageType < 0 || _ptcPageType > 12)
      {
        log.Error("MyPortalPageArguments.SetMyPortalPage - Invalid Page Type value.");
        } else
      {
        m_MYPAGE_TYPE = _ptcPageType;
      }
    }
  }
}