using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// Display page for community and my pages displaying partial portlet content.
  /// I.E. Recently added portlets.
  /// </summary>
  /// <author>DustinA</author>
  public class MyPortalPartialPortletsDP : AFormDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.MyPortalPartialPortletsDP");
    public const String STR_MVC_CLASS_NAME = "MyPortalPartialPortlets";
    private IPartialContentDisplayHelper m_pcDsiplayHelper = null;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()"></seealso>
    public override String GetFormTitle()
    {
      // DCA - not needed
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()"></seealso>
    public override HTMLElement PageDisplay()
    {
      // DCA - not needed
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#PartialContentDisplay()"></seealso>
    public override HTMLElement PartialContentDisplay()
    {
      return m_pcDsiplayHelper.PartialContentDisplay(m_asOwner);
    }
    public virtual void SetDisplayHelperToAdd()
    {
      m_pcDsiplayHelper = new AddPotletsPartialContentDisplayHelper();
    }
    public virtual void SetDisplayHelperToRemove()
    {
      m_pcDsiplayHelper = new RemovePotletPartialContentDisplayHelper();
    }
    public virtual void SetDisplayHelperToCollapseExpand()
    {
      m_pcDsiplayHelper = new CollapseExpandPotletPartialContentDisplayHelper();
      }
    
    /// <summary>
    /// Helper class to distinguish whether we're adding, removing, collapsing, or expanding portlet(s)
    /// </summary>
    /// <author>duang</author>
    private interface IPartialContentDisplayHelper
    {
      HTMLElement PartialContentDisplay(AActivitySpace asOwner);
    }
    private class AddPotletsPartialContentDisplayHelper : IPartialContentDisplayHelper
    {
      public virtual HTMLElement PartialContentDisplay(AActivitySpace asOwner)
      {
        HTMLElement result = new HTMLElementCollection();
        IMyPortalModel myPortalModel = (IMyPortalModel) asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        log.Debug("MyPortalPartialPortletsDP:PartialContentDisplay Getting portlet content for recently added portlets");
        bool bSuccess = myPortalModel.QueryRecentlyAddedPortletContent();
        if (bSuccess)
        {
          //MyPortalContentView myPortalContentview = (MyPortalContentView) asOwner.GetView(MyPortalContentView.STR_MVC_CLASS_NAME);
          for (int i = 0;i < myPortalModel.GetPortletCount();i++)
          {
            try
            {
              Object[][] objArrMarkup = myPortalModel.GetPortletHTMLTextFromIndex(i);
              if (IntrinsicPortletModel.IsIntrinsicPortlet(objArrMarkup))
              {
                String strPortletClass = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0];
                int nPortletID = myPortalModel.GetPortletIDFromIndex(i);
                String strStorageName = strPortletClass + nPortletID;
                myPortalModel.SetupIntrinsicPortlet(strPortletClass, strStorageName,
                 i);
              }
            }
            catch (Exception ex)
            {
              log.Warn(ex, "Unable to get portlet content.");
            }
            // 0 means display the content in the first column
            // DCA - not getting real content for now because of bug 66132
            //HTMLElement portletContent = myPortalContentview.DisplaySinglePortletContent(0, i);
            result.AddInnerHTMLElement(AddPortletLayout(null, asOwner, i));
            }
        }
        // DCA - reset the recently added portlet list
        myPortalModel.ResetRecentlyAddedPortlets();
        return result;
      }
      private HTMLElement AddPortletLayout(HTMLElement portletContent, AActivitySpace asOwner,
       int nPortletIndex)
      {
        MyPortalContentView myPortalContentview = (MyPortalContentView) asOwner.GetView(MyPortalContentView.STR_MVC_CLASS_NAME);
        IMyPortalModel myPortalModel = (IMyPortalModel) asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        XPStringBuilder sb = new XPStringBuilder(200);
        sb.Append("<div class=\'ali-portlet-regionone\' id=\'").Append(myPortalModel.GetIDStringForPortlet(nPortletIndex)).Append("\'>\n");
        sb.Append("<!-- Display Portlet Header -->\n");
        sb.Append("<div class=\'ali-portlet-new-toolbar\'>\n");
        sb.Append("  <div class=\'ali-portlet-new-cornerleft\'></div>\n");
        sb.Append("  <div class=\'ali-portlet-new-cornerright\'></div>\n");
        HTMLElement button = myPortalContentview.GetPortletRemoveButtonContent(nPortletIndex);
        button.SetImgBaseUrl(PTConfigService.getPTInstance().GetImageServerBaseURL(asOwner));
        sb.Append("  <div class=\'ali-portlet-controlone\'>").Append(button.GetDisplayString()).Append("</div>\n");
        button = myPortalContentview.GetPortletHelpButtonContent(nPortletIndex);
        button.SetImgBaseUrl(PTConfigService.getPTInstance().GetImageServerBaseURL(asOwner));
        sb.Append("  <div class=\'ali-portlet-controlone\'>").Append(button.GetDisplayString()).Append("</div>\n");
        sb.Append("  <div class=\'ali-portlet-controlone\'></div>\n");
        sb.Append("  <div class=\'ali-portlet-title\'>").Append(myPortalModel.GetPortletNameFromIndex(nPortletIndex)).Append("</div>\n");
        sb.Append("</div>\n");
        sb.Append("<!-- Display Portlet Content Body -->\n");
        sb.Append("<div class=\'ali-portlet-new-content\'>\n");
        if (null != portletContent)
        {
          sb.Append(portletContent.GetInnerHTMLDisplayString());
        }
        sb.Append("</div>\n");
        sb.Append("<div class=\'ali-portlet-new-footer\'>\n");
        sb.Append("   <div class=\'ali-portlet-new-botleft\'></div>\n");
        sb.Append("   <div class=\'ali-portlet-new-botright\'></div>\n");
        sb.Append("  </div>\n");
        sb.Append("</div>\n");
        HTMLGenericElement portlet = new HTMLGenericElement(sb.ToString());
        return portlet;
      }
    }
    private class RemovePotletPartialContentDisplayHelper : IPartialContentDisplayHelper
    {
      public virtual HTMLElement PartialContentDisplay(AActivitySpace asOwner)
      {
        HTMLElement result = new HTMLElementCollection();
        IMyPortalModel myPortalModel = (IMyPortalModel) asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        int nRemovedPortletId = myPortalModel.GetRecentlyRemovedPortlet();
        if (nRemovedPortletId > 0)
        {
          String strId = PTStyleID.GetIDStringForPortlet(nRemovedPortletId);
          result = new HTMLGenericElement(strId);
        }
        // DCA - reset the recently removed portlet
        myPortalModel.ResetRecentlyRemovedPortlet();
        return result;
      }
    }
    private class CollapseExpandPotletPartialContentDisplayHelper : IPartialContentDisplayHelper
    {
      public virtual HTMLElement PartialContentDisplay(AActivitySpace asOwner)
      {
        HTMLElement result = new HTMLElementCollection();
        IMyPortalModel myPortalModel = (IMyPortalModel) asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        log.Debug("MyPortalPartialPortletsDP:PartialContentDisplay Getting portlet content for recently collapsed or expanded portlets");
        bool bSuccess = myPortalModel.QueryRecentlyCollapsedExpandedPortletContent();
        if (bSuccess)
        {
          MyPortalContentView myPortalContentview = (MyPortalContentView) asOwner.GetView(MyPortalContentView.STR_MVC_CLASS_NAME);
          for (int i = 0;i < myPortalModel.GetPortletCount();i++)
          {
            try
            {
              Object[][] objArrMarkup = myPortalModel.GetPortletHTMLTextFromIndex(i);
              if (IntrinsicPortletModel.IsIntrinsicPortlet(objArrMarkup))
              {
                String strPortletClass = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0];
                int nPortletID = myPortalModel.GetPortletIDFromIndex(i);
                String strStorageName = strPortletClass + nPortletID;
                myPortalModel.SetupIntrinsicPortlet(strPortletClass, strStorageName,
                 i);
              }
            }
            catch (Exception ex)
            {
              log.Warn(ex, "Unable to get portlet content.");
            }
            // 0 means display the content in the first column
            HTMLElement portletContent = myPortalContentview.DisplaySinglePortletContent(0,
             i);
            result.AddInnerHTMLElement(portletContent);
            HTMLElement expandButton = myPortalContentview.GetPortletCollapseExpandButtonContent(i);
            result.AddInnerHTMLElement(expandButton);
          }
        }
        // DCA - reset the recently collapsed portlet list
        myPortalModel.ResetRecentlyCollapsedExpandedPortlet();
        return result;
      }
    }
  }
}