using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.myportal
{
  /// <summary>
  /// Handles the MyPage control flow
  /// </summary>
  /// <author>MichaelD</author>
  public class SetPageControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.SetPageControl");
    
    /// <summary>
    /// Class Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SetPage";
    
    /// <summary>
    /// Page ID 
    /// </summary>
    public const String STR_PAGE_ID = "PageID";
    
    /// <summary>
    /// Home Page ID constant 
    /// </summary>
    public const int N_HOME_PAGE_ID = 0;
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private IMyPortalModel m_asModel;
    
    /// <summary>
    /// Constructor for SetPageControl.
    /// </summary>
    public SetPageControl() : base()
    {
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // Get Page ID.
      String[] saPageID = (String[]) arguments.GetElement(STR_PAGE_ID);
      if (saPageID == null)
      {
        log.Error("could not find page ID in query string.");
        return null;
      }
      int nPageID = XPConvert.ToInteger(saPageID[0]);
      // My Pages are never previewable.
      m_asModel.SetIsPreviewPage(false);
      // My Pages never receive a profile ID.
      m_asModel.SetProfileID(0);
      // Set Raw Headers.
      String strHeaders = HttpUtils.GetRawHeaders(m_asOwner.GetCurrentHTTPRequest());
      m_asModel.SetRawHeaders(strHeaders);
      // Setup the My Page.
      bool bSuccessful = m_asModel.SetPage(nPageID);
      Redirect redirect = null;
      // If setting the my page was not successful, then redirect to an error page.
      if (!bSuccessful)
      {
        redirect = new Redirect();
        redirect.SetIsErrorRedirect(true);
        redirect.SetLinkGetCachedSpace(m_asOwner);
        redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
        redirect.AddControlArgument(SetPageControl.STR_PAGE_ID, nPageID);
        }
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SetPageControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#getName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (IMyPortalModel) model;
      m_asOwner = space;
    }
  }
}