using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: CommunityInvitationJoinView.java
  /// --------------------------------------
  /// Section for joining a community via an invitation.  This
  /// view displays a congratulations message if the user successfully
  /// joined, and an error message if the user is already a member
  /// of the community.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class CommunityInvitationJoinView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.communities.CommunityInvitationJoinView");
    public const String STR_MVC_CLASS_NAME = "CommunityInvitationJoin";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private IJoinPreviewCommunityModel m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CommunityInvitationJoinView();
    }
    
    /// <summary>
    /// Method createConfirmOfJoinPage - displays page that confirms the joining
    /// of community and allows to view the joined community
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public virtual HTMLElement CreateConfirmOfJoinPage()
    {
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow1 = new HTMLTableRow();
      HTMLTableRow mainRow2 = new HTMLTableRow();
      HTMLTableRow mainRow3 = new HTMLTableRow();
      HTMLTableCell mainRow1Cell = new HTMLTableCell();
      HTMLTableCell mainRow2Cell = new HTMLTableCell();
      HTMLTableCell mainRow3Cell = new HTMLTableCell();
      //congratsTable componenets
      HTMLTable congratsTable = new HTMLTable();
      HTMLTableRow congratsRow = new HTMLTableRow();
      HTMLTableCell congratsCell = new HTMLTableCell();
      //linksTable components
      HTMLTable linksTable = new HTMLTable();
      HTMLTableRow linksRow1 = new HTMLTableRow();
      HTMLTableRow linksRow2 = new HTMLTableRow();
      HTMLTableRow linksRow3 = new HTMLTableRow();
      HTMLTableCell linksRow1Cell = new HTMLTableCell();
      HTMLTableCell linksRow2Cell = new HTMLTableCell();
      HTMLTableCell linksRow3Cell = new HTMLTableCell();
      //Anchors
      String strNewCommURL = m_asModel.GetCommunityURL();
      HTMLAnchor newCommAnchor = new HTMLAnchor(strNewCommURL);
      newCommAnchor.AddInnerHTMLString(m_asOwner.GetString(644, "ptmsgs_portalbrowsingmsgs"));
      //Community Name
      String strCommName = m_asModel.GetCommunityName();
      //Specifying mainTable attributes
      mainTable.SetAlign("center");
      mainTable.SetBorder("0");
      mainTable.SetCellPadding("0");
      mainTable.SetWidth("90%");
      mainTable.SetHeight("30%");
      //Specifying congratsTable attributes
      congratsTable.SetBorder("0");
      congratsTable.SetCellPadding("0");
      congratsTable.SetWidth("100%");
      //Specifying linksTable attributes
      linksTable.SetBorder("0");
      linksTable.SetCellPadding("0");
      linksTable.SetWidth("100%");
      //Setting up congratulations table
      congratsCell.SetStyleClass(PTStyleClass.DIALOGUE_TITLE);
      congratsCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(643,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strCommName)));
      PreviewCommunityView.addRowCell(congratsTable, congratsRow, congratsCell);
      //Setting up linksTable
      linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow1Cell.AddInnerHTMLElement(newCommAnchor);
      PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);
      //Setting up the Main Table
      mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mainRow2Cell.AddInnerHTMLElement(congratsTable);
      mainRow3Cell.AddInnerHTMLElement(linksTable);
      PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
      //display page
      return mainTable;
    }
    
    /// <summary>
    /// Method createErrorPage - displays the error page if user is already a
    /// member of the community specified
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public virtual HTMLElement CreateErrorPage()
    {
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow1 = new HTMLTableRow();
      HTMLTableRow mainRow2 = new HTMLTableRow();
      HTMLTableRow mainRow3 = new HTMLTableRow();
      HTMLTableCell mainRow1Cell = new HTMLTableCell();
      HTMLTableCell mainRow2Cell = new HTMLTableCell();
      HTMLTableCell mainRow3Cell = new HTMLTableCell();
      //errorTable componenets
      HTMLTable errorTable = new HTMLTable();
      HTMLTableRow errorRow = new HTMLTableRow();
      HTMLTableCell errorCell = new HTMLTableCell();
      //linksTable components
      HTMLTable linksTable = new HTMLTable();
      HTMLTableRow linksRow1 = new HTMLTableRow();
      HTMLTableRow linksRow2 = new HTMLTableRow();
      HTMLTableRow linksRow3 = new HTMLTableRow();
      HTMLTableCell linksRow1Cell = new HTMLTableCell();
      HTMLTableCell linksRow2Cell = new HTMLTableCell();
      HTMLTableCell linksRow3Cell = new HTMLTableCell();
      //Anchors
      String strNewCommName = m_asModel.GetCommunityName();
      String strNewCommURL = m_asModel.GetCommunityURL();
      HTMLAnchor newCommAnchor = new HTMLAnchor(strNewCommURL);
      newCommAnchor.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(647,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strNewCommName)));
      //Specifying mainTable attributes
      //align="center" border="0" cellpadding="0" width="90%" height="30%"
      mainTable.SetAlign("center");
      mainTable.SetBorder("0");
      mainTable.SetCellPadding("0");
      mainTable.SetWidth("90%");
      mainTable.SetHeight("30%");
      //Specifying errorTable attributes
      errorTable.SetBorder("0");
      errorTable.SetCellPadding("0");
      errorTable.SetWidth("100%");
      //Specifying linksTable attributes
      linksTable.SetBorder("0");
      linksTable.SetCellPadding("0");
      linksTable.SetWidth("100%");
      //Setting up errorTable
      errorCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
      errorCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(646,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strNewCommName)));
      PreviewCommunityView.addRowCell(errorTable, errorRow, errorCell);
      //Setting up linksTable
      linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow1Cell.AddInnerHTMLElement(newCommAnchor);
      PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);
      //Setting up the Main Table
      mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mainRow2Cell.AddInnerHTMLElement(errorTable);
      mainRow3Cell.AddInnerHTMLElement(linksTable);
      PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
      //display page
      return mainTable;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement page = null;
      try
      {
        if (m_asModel.CommunityJoinFailed())
        {
          page = CreateErrorPage();
        } else
        {
          page = CreateConfirmOfJoinPage();
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error displaying page.");
      }
      return page;
    }
    
    /// <summary>
    /// Display JavaScript
    /// </summary>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IJoinPreviewCommunityModel) model;
      m_asOwner = parent;
    }
  }
}