using System;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <author>MichaelD</author>
  public class CommunityMyPortalModelHelper : IMyPortalModelHelper
  {
    public const String COMCOLLAPSEDGADGETS = "COMCollapsedGadgets";
    public const String COMGADGETHASNOTITLEBAR = "COMPortletHasNoTitleBar";
    private AActivitySpace m_asOwner = null;
    private IPTCommunityManager m_ptCommunityManager = null;
    
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetCollapsedPortletsPrefName()"></seealso>
    public virtual String GetCollapsedPortletsPrefName()
    {
      return COMCOLLAPSEDGADGETS;
    }
    
    /// <summary>
    /// Return the access level for the community.
    /// </summary>
    public virtual int GetCommunityAccessLevel(int nCommunityID)
    {
      try
      {
        return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID,
         false).GetAccessLevel();
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1518, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1519,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE;
    }
    
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetCommunityPages(int)"></seealso>
    public virtual IPTQueryResult GetCommunityPages(int nCommunityID)
    {
      return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).GetPages();
      }
    
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetPortletHasNoTitleBar(int)"></seealso>
    public virtual Object[][] GetPortletHasNoTitleBar(int nCommunityID)
    {
      return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).LookupPreference(COMGADGETHASNOTITLEBAR,
       0, PT_PREF_TYPES.PT_PREFTYPE_ALL_USERS);
    }
    
    /// <summary>
    /// Return the headerID for the community; used when processing the style
    /// sheet.
    /// </summary>
    public virtual int GetHeaderID(int nCommunityID)
    {
      try
      {
        return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID,
         false).GetHeaderID();
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1520, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1521,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return 0;
    }
    
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetIsCommunityPage()"></seealso>
    public virtual bool GetIsCommunityPage()
    {
      return true;
    }
    
    /// <summary>
    /// Return the stylesheet for the community; used when processing the style
    /// sheet.
    /// </summary>
    public virtual String GetStyleSheet(int nCommunityID)
    {
      try
      {
        return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID,
         false).GetStyleSheet();
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1522, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1523,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return "";
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public virtual void Init(IPTSession ptSession, AActivitySpace parent)
    {
      m_ptCommunityManager = (IPTCommunityManager) ptSession.GetCommunities().GetInterfaces("IPTCommunityManager");
      m_asOwner = parent;
    }
    //////////////////////////////////////
    // Methods from IMyPortalModelHelper
    //////////////////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#OpenPage(int,int)"></seealso>
    public virtual IPTPageInfo OpenPage(int nCommunityID, int nPageID)
    {
      try
      {
        return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID,
         false).GetPage(nPageID);
      }
      catch (PTException ptex)
      {
        if (PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_PAGE != ptex.GetErrorCode() && PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_ALL_PAGES != ptex.GetErrorCode())
        {
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           ptex, m_asOwner.GetString(1524, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1525,
           "ptmsgs_portalbrowsingmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
        // TODO: Won't this just cause the error to be displayed anyway down below,
        // even though the above if statement doesn't want it to be displayed?
        throw ptex;
      }
      catch (Exception ex)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         ex, m_asOwner.GetString(1524, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1525,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelHelper#GetCommunityName(int)"></seealso>
    /// <deprecated>Use NavigationModel.GetCurCommunityName instead.</deprecated>
    public virtual String GetCommunityName(int nCommunityID)
    {
      return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).GetName();
      }
  }
}