using System;
using XPResourceManager=com.plumtree.openfoundation.internationalization.XPResourceManager;
using XPHttpUtility=com.plumtree.openfoundation.web.XPHttpUtility;
using OpenLogService=com.plumtree.openlog.OpenLogService;
using OpenLogger=com.plumtree.openlog.OpenLogger;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using IModelRO=com.plumtree.uiinfrastructure.activityspace.IModelRO;
using IView=com.plumtree.uiinfrastructure.activityspace.IView;
using PTStyleClass=com.plumtree.xpshared.htmlconstructs.PTStyleClass;
using CommonHTMLStrings=com.plumtree.xpshared.htmlelements.CommonHTMLStrings;
using HTMLAnchor=com.plumtree.xpshared.htmlelements.HTMLAnchor;
using HTMLElement=com.plumtree.xpshared.htmlelements.HTMLElement;
using HTMLException=com.plumtree.xpshared.htmlelements.HTMLException;
using HTMLScript=com.plumtree.xpshared.htmlelements.HTMLScript;
using HTMLTable=com.plumtree.xpshared.htmlelements.HTMLTable;
using HTMLTableCell=com.plumtree.xpshared.htmlelements.HTMLTableCell;
using HTMLTableRow=com.plumtree.xpshared.htmlelements.HTMLTableRow;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// Section for unsubscribing/quitting from a community via UnsubscribeCurCommunityControl. 
  /// This view displays a successful message if the user successfully unsubscribed, and an 
  /// error message if the user is already unsubscribed from the community.
  /// </summary>
  /// <author>btse</author>
  public class CommunityUnsubscribeView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.communities.CommunityUnsubscribeView");
    public const String STR_MVC_CLASS_NAME = "CommunityUnsubscribe";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private IUnsubscribeCommunityModel m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CommunityUnsubscribeView();
    }
    
    /// <summary>
    /// Method CreateConfirmOfUnsubscribePage - displays page that confirms the unsubscribing
    /// of community and allows to view the unsubscribed community
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public virtual HTMLElement CreateConfirmOfUnsubscribePage()
    {
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow1 = new HTMLTableRow();
      HTMLTableRow mainRow2 = new HTMLTableRow();
      HTMLTableRow mainRow3 = new HTMLTableRow();
      HTMLTableCell mainRow1Cell = new HTMLTableCell();
      HTMLTableCell mainRow2Cell = new HTMLTableCell();
      HTMLTableCell mainRow3Cell = new HTMLTableCell();
      //congratsTable componenets
      HTMLTable confirmationTable = new HTMLTable();
      HTMLTableRow confirmationRow = new HTMLTableRow();
      HTMLTableCell confirmationCell = new HTMLTableCell();
      //linksTable components
      HTMLTable linksTable = new HTMLTable();
      HTMLTableRow linksRow1 = new HTMLTableRow();
      HTMLTableRow linksRow2 = new HTMLTableRow();
      HTMLTableRow linksRow3 = new HTMLTableRow();
      HTMLTableCell linksRow1Cell = new HTMLTableCell();
      HTMLTableCell linksRow2Cell = new HTMLTableCell();
      HTMLTableCell linksRow3Cell = new HTMLTableCell();
      //Anchors
      String strNewCommURL = m_asModel.GetCommunityURL();
      HTMLAnchor newCommAnchor = new HTMLAnchor(strNewCommURL);
      newCommAnchor.AddInnerHTMLString(m_asOwner.GetString(1922, "ptmsgs_portalbrowsingmsgs"));
      //Community Name
      String strCommName = m_asModel.GetCommunityName();
      //Specifying mainTable attributes
      mainTable.SetAlign("center");
      mainTable.SetBorder("0");
      mainTable.SetCellPadding("0");
      mainTable.SetWidth("90%");
      mainTable.SetHeight("30%");
      //Specifying confirmationTable attributes
      confirmationTable.SetBorder("0");
      confirmationTable.SetCellPadding("0");
      confirmationTable.SetWidth("100%");
      //Specifying linksTable attributes
      linksTable.SetBorder("0");
      linksTable.SetCellPadding("0");
      linksTable.SetWidth("100%");
      //Setting up confirmation table
      confirmationCell.SetStyleClass(PTStyleClass.DIALOGUE_TITLE);
      confirmationCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1921,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strCommName)));
      PreviewCommunityView.addRowCell(confirmationTable, confirmationRow,
       confirmationCell);
      //Setting up linksTable
      linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow1Cell.AddInnerHTMLElement(newCommAnchor);
      PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);
      //Setting up the Main Table
      mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mainRow2Cell.AddInnerHTMLElement(confirmationTable);
      mainRow3Cell.AddInnerHTMLElement(linksTable);
      PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
      //display page
      return mainTable;
    }
    
    /// <summary>
    /// Method createErrorPage - displays the error page if user is already a
    /// member of the community specified
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public virtual HTMLElement CreateErrorPage()
    {
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow1 = new HTMLTableRow();
      HTMLTableRow mainRow2 = new HTMLTableRow();
      HTMLTableRow mainRow3 = new HTMLTableRow();
      HTMLTableCell mainRow1Cell = new HTMLTableCell();
      HTMLTableCell mainRow2Cell = new HTMLTableCell();
      HTMLTableCell mainRow3Cell = new HTMLTableCell();
      //errorTable componenets
      HTMLTable errorTable = new HTMLTable();
      HTMLTableRow errorRow = new HTMLTableRow();
      HTMLTableCell errorCell = new HTMLTableCell();
      //linksTable components
      HTMLTable linksTable = new HTMLTable();
      HTMLTableRow linksRow1 = new HTMLTableRow();
      HTMLTableRow linksRow2 = new HTMLTableRow();
      HTMLTableRow linksRow3 = new HTMLTableRow();
      HTMLTableCell linksRow1Cell = new HTMLTableCell();
      HTMLTableCell linksRow2Cell = new HTMLTableCell();
      HTMLTableCell linksRow3Cell = new HTMLTableCell();
      //Anchors
      String strNewCommName = m_asModel.GetCommunityName();
      String strNewCommURL = m_asModel.GetCommunityURL();
      HTMLAnchor newCommAnchor = new HTMLAnchor(strNewCommURL);
      newCommAnchor.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1924,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strNewCommName)));
      //Specifying mainTable attributes
      //align="center" border="0" cellpadding="0" width="90%" height="30%"
      mainTable.SetAlign("center");
      mainTable.SetBorder("0");
      mainTable.SetCellPadding("0");
      mainTable.SetWidth("90%");
      mainTable.SetHeight("30%");
      //Specifying errorTable attributes
      errorTable.SetBorder("0");
      errorTable.SetCellPadding("0");
      errorTable.SetWidth("100%");
      //Specifying linksTable attributes
      linksTable.SetBorder("0");
      linksTable.SetCellPadding("0");
      linksTable.SetWidth("100%");
      //Setting up errorTable
      errorCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
      errorCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1923,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strNewCommName)));
      PreviewCommunityView.addRowCell(errorTable, errorRow, errorCell);
      //Setting up linksTable
      linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow1Cell.AddInnerHTMLElement(newCommAnchor);
      PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);
      //Setting up the Main Table
      mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mainRow2Cell.AddInnerHTMLElement(errorTable);
      mainRow3Cell.AddInnerHTMLElement(linksTable);
      PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
      //display page
      return mainTable;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement page = null;
      try
      {
        if (m_asModel.CommunityUnsubscribeFailed())
        {
          page = CreateErrorPage();
        } else
        {
          page = CreateConfirmOfUnsubscribePage();
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error displaying page.");
      }
      return page;
    }
    
    /// <summary>
    /// Display JavaScript
    /// </summary>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IUnsubscribeCommunityModel) model;
      m_asOwner = parent;
    }
  }
}