using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: JoinCommunityControl.java
  /// -------------------------------
  /// Control that decides whether the user is already
  /// a member of the community.  If so, set the page
  /// to be an error page, otherwise join the community
  /// and congratulate the user.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class JoinCommunityControl : IControl
  {
    public const String STR_MVC_CLASS_NAME = "JoinCommunity";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_CommunityID = "CommunityID";
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private PreviewCommunityBarModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      if (!m_asModel.IsCommunityMember())
      {
        m_asModel.SetErrorPage(false);
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          m_asModel.AddCommunity();
        } else
        {
          if (arguments.GetElement(RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH) != null)
          {
            m_asModel.AddCommunity();
          }
        }
      } else
      {
        m_asModel.SetErrorPage(true);
      }
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        return null;
      }
      Redirect redirect = new Redirect();
      redirect.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
      redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, m_asModel.GetCommunityID());
      redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID, 0);
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new JoinCommunityControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asOwner = space;
      m_asModel = (PreviewCommunityBarModel) model;
    }
  }
}