using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: PreviewCommunityControl.java
  /// ----------------------------------
  /// Control that sets the community and page IDs
  /// and sets the preview type.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class PreviewCommunityBarControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityBarControl");
    public const String STR_MVC_CLASS_NAME = "PreviewCommunityBar";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_CommunityID = "CommunityID";
    
    /// <summary>
    /// Community PageID Query String Param 
    /// </summary>
    public const String m_PageID = "PageID";
    
    /// <summary>
    /// Preview Type Query String Param 
    /// </summary>
    public const String m_PreviewType = "PreviewType";
    
    /// <summary>
    /// Community Index Query String Param 
    /// </summary>
    public const String m_CommunityIndex = "CommunityIndex";
    
    /// <summary>
    /// Community Checked Query String Param 
    /// </summary>
    public const String m_CommunityChecked = "CommunityChecked";
    
    /// <summary>
    /// QueryString Parameter for the Join Community Javascript override 
    /// </summary>
    public const String m_strJoinCommunityJavascriptOverride = "JoinCommunityJS";
    
    /// <summary>
    /// model 
    /// </summary>
    private PreviewCommunityBarModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String[] sValues = (String[]) arguments.GetElement(m_CommunityID);
      if (sValues == null)
      {
        log.Error("could not find community ID in query string.");
        return null;
      }
      m_asModel.SetCommunityIDAndOpen(XPConvert.ToInteger(sValues[0]));
      sValues = (String[]) arguments.GetElement(m_PreviewType);
      if (sValues == null)
      {
        log.Error("could not find preview type in query string.");
        return null;
      }
      int nPreviewType = XPConvert.ToInteger(sValues[0]);
      if (nPreviewType == PreviewCommunityBarModel.SELECTIONPREVIEWHEADER)
      {
        m_asModel.SetCommunityToSelectionPreviewPage();
        sValues = (String[]) arguments.GetElement(m_CommunityIndex);
        if (sValues == null)
        {
          log.Error("could not find community index in query string.");
          return null;
        }
        int nCommunityIndex = XPConvert.ToInteger(sValues[0]);
        m_asModel.SetCommunityIndex(nCommunityIndex);
        sValues = (String[]) arguments.GetElement(m_CommunityChecked);
        if (sValues != null)
        {
          bool bCommunityChecked = XPConvert.ToBoolean(sValues[0]);
          m_asModel.SetCommunityChecked(bCommunityChecked);
        }
      } else
      if (nPreviewType == PreviewCommunityBarModel.INVITEHEADER)
      {
        m_asModel.SetCommunityToInvitePage();
      } else
      {
        m_asModel.SetCommunityToPreviewPage();
      }
      // Check for a Javascript override for the JoinCommunity function
      sValues = (String[]) arguments.GetElement(m_strJoinCommunityJavascriptOverride);
      if ((sValues != null) && (sValues[0] != null) && (sValues[0].Length > 0))
      {
        m_asModel.SetJoinCommunityJavaScriptOverride(sValues[0]);
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PreviewCommunityBarControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (PreviewCommunityBarModel) model;
    }
  }
}