using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: CommunityInvitationModelHelper.java
  /// -----------------------------------------
  /// ModelHelper for Community Preview/Invitations
  /// This is necessary because we don't need this
  /// for all MyPortal Pages, yet we want it on the
  /// MyPortal Model.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class PreviewCommunityBarModel : IModel,IModelRO,IJoinPreviewCommunityModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityBarModel");
    public const String STR_MVC_CLASS_NAME = "PreviewCommunityBar";
    
    /// <summary>
    /// Constant: No Preview Header Bar 
    /// </summary>
    public const int NOPREVIEWHEADER = 0;
    
    /// <summary>
    /// Constant: Preview Header Bar for Selection Page
    /// </summary>
    public const int SELECTIONPREVIEWHEADER = 1;
    
    /// <summary>
    /// Constant: Invite Header Bar 
    /// </summary>
    public const int INVITEHEADER = 2;
    
    /// <summary>
    /// Constant: Preview Header Bar for preview only (as in Community Editor)
    /// </summary>
    public const int PREVIEWHEADER = 3;
    
    /// <summary>
    /// Join Community Javascript override *
    /// </summary>
    public String m_strJavascriptOverride = null;
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner = null;
    
    /// <summary>
    /// Session 
    /// </summary>
    private IPTSession m_ptSession;
    
    /// <summary>
    /// Community Checked 
    /// </summary>
    private bool m_bCommunityChecked;
    
    /// <summary>
    /// Is Error Page 
    /// </summary>
    private bool m_bErrorPage;
    
    /// <summary>
    /// Community ID 
    /// </summary>
    private int m_nCommunityID;
    
    /// <summary>
    /// Community Index for selection page 
    /// </summary>
    private int m_nCommunityIndex;
    
    /// <summary>
    /// Which bar is being used 
    /// </summary>
    private int m_nPreviewStatus;
    
    /// <summary>
    /// Community Name 
    /// </summary>
    private String m_strCommName = "";
    
    /// <summary>
    /// Community Desc 
    /// </summary>
    private String m_strCommDesc = "";
    
    /// <summary>
    /// Check if community exist 
    /// </summary>
    private bool m_bCommunityOpened = true;
    public virtual void CleanupTempData()
    {
    }
    public virtual void CleanupAllData()
    {
    }
    /*public PreviewCommunityModel(IPTSession ptSession, int nCommunityID, String strCommunityName, String nSpaceID)
     {
     m_ptSession        = ptSession;
     m_nCommunityFolderID     = nCommunityID;
     m_strCommunityName = strCommunityName;
     m_nSpaceID = nSpaceID;
     
     m_objCommunityManager = m_ptSession.GetCommunities();
     }*/
     
    
    /// <summary>
    /// Method addCommunity - adds the user into the community's membership list
    /// as a free member
    /// </summary>
    /// <throws>HTMLException</throws>
    public virtual void AddCommunity()
    {
      ((IPTCommunityManager) m_ptSession.GetCommunities()).JoinCommunity(m_nCommunityID,
       PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE);
      try
      {
        //PEI : CommunityActions
        // MJD: All of the following code will load all of the available CommunityAction
        // PEIs and process through them.
        IApplication application = m_asOwner.GetApplication();
        Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
        if (oa != null)
        {
          for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
          {
            Object o = oa[iCommAction];
            if (o != null)
            {
              ICommunityActions iActions = (ICommunityActions) o;
              iActions.OnAfterUserJoinsCommunity(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
               new int[]{m_nCommunityID});
            }
          }
        }
      }
      //PEI : CommunityActions : END
      catch (Exception ex)
      {
        log.Error(ex, "OnAfterUserJoinsCommunity PEI failed.");
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PreviewCommunityBarModel();
    }
    
    /// <summary>
    /// Get community description
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetCommunityDescription()
    {
      return m_strCommDesc;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual int GetCommunityID()
    {
      return m_nCommunityID;
    }
    
    /// <summary>
    /// Get to use for preview from selection page
    /// </summary>
    public virtual int GetCommunityIndex()
    {
      return m_nCommunityIndex;
    }
    
    /// <summary>
    /// Get community Name
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetCommunityName()
    {
      return m_strCommName;
    }
    
    /// <summary>
    /// Get invited or preview community URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetCommunityURL()
    {
      IPTURL url = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(m_asOwner,
       GetCommunityID(), GetCommunityName());
      return (url.GetFullURL());
    }
    
    /// <summary>
    /// Get User's default community URL
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetDefaultCommunityURL()
    {
      IPTQueryResult myCommunities = m_ptSession.GetSessionInfo().GetCurrentCommunityMembership();
      int defCommunityID = myCommunities.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      url.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
      url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, defCommunityID);
      url.AddControlArgument(SetCommunityControl.STR_PAGE_ID, 0);
      return (url.GetURLAsString());
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetDescriptionURL()"></seealso>
    public virtual String GetDescriptionURL()
    {
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkGetCachedSpace(m_asOwner);
      url.SetDisplayPage(PreviewCommunityDescPopupDP.STR_MVC_CLASS_NAME);
      return (url.GetURLAsString());
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetJoinURL()"></seealso>
    public virtual String GetJoinURL()
    {
      ASURL url = new ASURL(m_asOwner);
      url.SetLinkGetCachedSpace(m_asOwner);
      url.SetControl(JoinCommunityControl.STR_MVC_CLASS_NAME);
      url.SetDisplayPage(CommunityInvitationJoinDP.STR_MVC_CLASS_NAME);
      url.AddControlArgument(JoinCommunityControl.m_CommunityID, XPConvert.ToString(m_nCommunityID));
      return (url.GetURLAsString());
    }
    ///////////////////////////////////////
    // Read only methods from IModelRO
    ///////////////////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModelRO#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /////////////////////////
    // Methods from IModel
    /////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <summary>
    /// Get to check if community exist
    /// </summary>
    public virtual bool IsCommunityOpened()
    {
      return m_bCommunityOpened;
    }
    
    /// <summary>
    /// Get to check for selected community
    /// </summary>
    public virtual bool IsCommunityChecked()
    {
      return m_bCommunityChecked;
    }
    
    /// <summary>
    /// Is Community Invite Page
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsCommunityInvitePage()
    {
      return (m_nPreviewStatus == INVITEHEADER);
    }
    public virtual bool IsCommunityMember()
    {
      IPTQueryResult membershipList = m_ptSession.GetSessionInfo().GetCurrentCommunityMembership();
      bool bIsMember = false;
      int communityID;
      for (int i = 0;i < membershipList.RowCount();i++)
      // go through user's list of communities joined
      {
        communityID = membershipList.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        if (communityID == m_nCommunityID)
        // if community specified by commID is in the list
        {
          // user is already a member of community
          bIsMember = true;
          break;
        }
      }
      return bIsMember;
    }
    
    /// <summary>
    /// Is Community Preview Page
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsCommunityPreviewPage()
    {
      return (m_nPreviewStatus == PREVIEWHEADER);
    }
    
    /// <summary>
    /// Is Community Selection Preview Page
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsCommunitySelectionPreviewPage()
    {
      return (m_nPreviewStatus == SELECTIONPREVIEWHEADER);
    }
    
    /// <summary>
    /// Is Error Page
    /// </summary>
    public virtual bool CommunityJoinFailed()
    {
      return m_bErrorPage;
    }
    
    /// <summary>
    /// Set community as selected
    /// </summary>
    public virtual void SetCommunityChecked(bool bCommunityChecked)
    {
      m_bCommunityChecked = bCommunityChecked;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual void SetCommunityIDAndOpen(int nCommunityID)
    {
      m_nCommunityID = nCommunityID;
      // DCA - Open up community to see if exist... Since opening up community, might as well get name and desciption.
      try
      {
        IPTCommunity objComm = (IPTCommunity) m_ptSession.GetCommunities().Open(m_nCommunityID,
         false);
        m_strCommName = objComm.GetLocalizedName();
        m_strCommDesc = objComm.GetLocalizedDescription();
      }
      catch (Exception e)
      {
        m_bCommunityOpened = false;
      }
    }
    
    /// <summary>
    /// Set to use selection page
    /// </summary>
    public virtual void SetCommunityIndex(int nCommunityIndex)
    {
      m_nCommunityIndex = nCommunityIndex;
    }
    
    /// <summary>
    /// Set to use Invite Header
    /// </summary>
    public virtual void SetCommunityToInvitePage()
    {
      m_nPreviewStatus = INVITEHEADER;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual void SetCommunityToPreviewPage()
    {
      m_nPreviewStatus = PREVIEWHEADER;
    }
    
    /// <summary>
    /// Set to use Selection Preview Header
    /// </summary>
    public virtual void SetCommunityToSelectionPreviewPage()
    {
      m_nPreviewStatus = SELECTIONPREVIEWHEADER;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual void SetErrorPage(bool bErrorPage)
    {
      m_bErrorPage = bErrorPage;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual bool UserHasReadAccess()
    {
      return m_ptSession.GetCommunities().IsObjectAccessible(m_nCommunityID,
       m_ptSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
      }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual bool UserHasSelectAccess()
    {
      return m_ptSession.GetCommunities().IsObjectAccessible(m_nCommunityID,
       m_ptSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
      }
    
    /// <summary>
    /// Get Join Community Javascript override.
    /// This javascript should be the name of the javascript function to be
    /// used in the onclick attribute of the join community button.  The function should
    /// take 2 arguments: the community ID, and a reference to the popup window.
    /// (i.e. If the name is "joinCommunity", then the function will look like
    /// this: "joinCommunity(communityID, self)").  This function name can also
    /// include an optional window reference (i.e. "opener.joinCommunity").
    /// </summary>
    /// <returns>
    /// String the name of the javascript function to use when joining the community.
    /// This string will be null if there is no override.
    /// </returns>
    public virtual String GetJoinCommunityJavaScriptOverride()
    {
      return m_strJavascriptOverride;
    }
    
    /// <summary>
    /// Set the Join Community Javascript override.
    /// This javascript should be the name of the javascript function to be
    /// used in the onclick attribute of the join community button.  The function should
    /// take 2 arguments: the community ID, and a reference to the popup window.
    /// (i.e. If the name is "joinCommunity", then the function will look like
    /// this: "joinCommunity(communityID, self)").  This function name can also
    /// include an optional window reference (i.e. "opener.joinCommunity").
    /// Null means to use the default javascript.
    /// </summary>
    public virtual void SetJoinCommunityJavaScriptOverride(String _strOverride)
    {
      m_strJavascriptOverride = _strOverride;
    }
  }
}