using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: PreviewCommunityControl.java
  /// ----------------------------------
  /// Control that sets the community and page IDs
  /// and sets the preview type.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class PreviewCommunityControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityControl");
    public const String STR_MVC_CLASS_NAME = "PreviewCommunity";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_CommunityID = "CommunityID";
    
    /// <summary>
    /// Preview Type Query String Param 
    /// </summary>
    public const String m_PreviewType = "PreviewType";
    
    /// <summary>
    /// Community Index Query String Param 
    /// </summary>
    public const String m_CommunityIndex = "CommunityIndex";
    
    /// <summary>
    /// Community Checked Query String Param 
    /// </summary>
    public const String m_CommunityChecked = "CommunityChecked";
    
    /// <summary>
    /// Activity space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// QueryString Parameter for the Join Community Javascript override 
    /// </summary>
    public const String m_strJoinCommunityJavascriptOverride = "JoinCommunityJS";
    
    /// <summary>
    /// model 
    /// </summary>
    private PreviewCommunityModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      if (!m_asModel.UserHasCommunityAccess())
      {
        Redirect noAccessRedirect = new Redirect();
        noAccessRedirect.SetLinkGetCachedSpace(m_asOwner);
        noAccessRedirect.SetDisplayPage(NoCommunityAccessDP.STR_MVC_CLASS_NAME);
        return noAccessRedirect;
      }
      // Get values
      String[] sValues = (String[]) arguments.GetElement(m_CommunityID);
      if (sValues != null)
      {
        if (TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
        {
          Redirect previewURL = new Redirect();
          previewURL.SetLinkGetCachedSpace(m_asOwner);
          previewURL.SetControl(PreviewCommunityControl.STR_MVC_CLASS_NAME);
          previewURL.AddControlArgument(PreviewCommunityControl.m_PreviewType,
           (XPConvert.ToString(PreviewCommunityModel.INVITEHEADER)));
          previewURL.AddControlArgument(PreviewCommunityControl.m_CommunityID,
           sValues[0]);
          previewURL.SetIsErrorRedirect(true);
          return previewURL;
        }
        m_asModel.SetCommunityID(XPConvert.ToInteger(sValues[0]));
      }
      sValues = (String[]) arguments.GetElement(m_PreviewType);
      if (sValues == null)
      {
        log.Error("could not find preview type in query string.");
        return null;
      }
      int nPreviewType = XPConvert.ToInteger(sValues[0]);
      // if in 508 or low bandwidth, redirect to correct DP
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
      {
        Redirect redirect = new Redirect();
        redirect.SetLinkCreateNewSpace(PreviewCommunityBarAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        redirect.SetControl(PreviewCommunityBarControl.STR_MVC_CLASS_NAME);
        redirect.SetDisplayPage(CommunityInvitationDP_D.STR_MVC_CLASS_NAME);
        redirect.AddControlArgument(m_CommunityID, m_asModel.GetCommunityID());
        redirect.AddControlArgument(PreviewCommunityBarControl.m_PageID, -1 * m_asModel.GetCommunityID());
        redirect.AddControlArgument(PreviewCommunityBarControl.m_CommunityChecked,
         false);
        redirect.AddControlArgument(m_PreviewType, nPreviewType);
        return redirect;
      }
      // Check for a Javascript override for the JoinCommunity function
      sValues = (String[]) arguments.GetElement(m_strJoinCommunityJavascriptOverride);
      if ((sValues != null) && (sValues[0] != null) && (sValues[0].Length > 0))
      {
        m_asModel.SetJoinCommunityJavaScriptOverride(sValues[0]);
      }
      if (nPreviewType == PreviewCommunityBarModel.SELECTIONPREVIEWHEADER)
      {
        m_asModel.SetCommunityToSelectionPreviewPage();
        sValues = (String[]) arguments.GetElement(m_CommunityIndex);
        if (sValues != null)
        {
          int nCommunityIndex = XPConvert.ToInteger(sValues[0]);
          m_asModel.SetCommunityIndex(nCommunityIndex);
        }
        sValues = (String[]) arguments.GetElement(m_CommunityChecked);
        if (sValues != null)
        {
          bool bCommunityChecked = XPConvert.ToBoolean(sValues[0]);
          m_asModel.SetCommunityChecked(bCommunityChecked);
        }
      } else
      if (nPreviewType == PreviewCommunityBarModel.INVITEHEADER)
      {
        m_asModel.SetCommunityToInvitePage();
      } else
      {
        m_asModel.SetCommunityToPreviewPage();
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PreviewCommunityControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (PreviewCommunityModel) model;
      m_asOwner = space;
    }
  }
}