using System;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: PreviewCommunityDescPopupView.java
  /// ----------------------------------------
  /// Section for the community description popup.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class PreviewCommunityDescPopupView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityDescPopupView");
    public const String STR_MVC_CLASS_NAME = "PreviewCommunityDescPopup";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private PreviewCommunityBarModel m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PreviewCommunityDescPopupView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLPage mainPage = null;
      try
      {
        //mainPage components
        mainPage = new HTMLPage();
        HTMLHead pageHead = new HTMLHead();
        HTMLTitle pageTitle = new HTMLTitle(m_asOwner.GetString(651, "ptmsgs_portalbrowsingmsgs"));
        pageHead.AddInnerHTMLElement(pageTitle);
        HTMLBody pageBody = new HTMLBody();
        pageBody.SetStyleClass(PTStyleClass.ALERT_DIALOG_BG);
        //mainTable components
        HTMLTable mainTable = new HTMLTable();
        HTMLTableRow mainRow1 = new HTMLTableRow();
        HTMLTableRow mainRow2 = new HTMLTableRow();
        HTMLTableRow mainRow3 = new HTMLTableRow();
        HTMLTableRow mainRow4 = new HTMLTableRow();
        HTMLTableCell mainRow1Cell = new HTMLTableCell();
        HTMLTableCell mainRow2Cell = new HTMLTableCell();
        HTMLTableCell mainRow3Cell = new HTMLTableCell();
        HTMLTableCell mainRow4Cell = new HTMLTableCell();
        //closeButton
        HTMLInput closeButton = new HTMLInput(1, "in_bu_close", m_asOwner.GetString(648,
         "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(648, "ptmsgs_portalbrowsingmsgs"));
        closeButton.SetValue(m_asOwner.GetString(17, "ptmsgs_portalbrowsingmsgs"));
        closeButton.SetOnClick("self.close()");
        closeButton.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        //Community Name and Description
        String strCommName = m_asModel.GetCommunityName();
        String strCommDes = m_asModel.GetCommunityDescription();
        //Specifying mainTable attributes
        //border="0" cellpadding="4" width="100%"
        mainTable.SetBorder("0");
        mainTable.SetCellPadding("4");
        mainTable.SetWidth("100%");
        //Setting up mainTable
        mainRow1Cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        mainRow1Cell.AddInnerHTMLString("<b>" + m_asOwner.GetString(649, "ptmsgs_portalbrowsingmsgs") + "</b>" + XPHttpUtility.HtmlEncode(strCommName));
        mainRow2Cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        mainRow2Cell.AddInnerHTMLString("<b>" + m_asOwner.GetString(650, "ptmsgs_portalbrowsingmsgs") + "</b>" + XPHttpUtility.HtmlEncode(strCommDes));
        mainRow3Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        mainRow4Cell.SetAlign("center");
        mainRow4Cell.AddInnerHTMLElement(closeButton);
        PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
        PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
        PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
        PreviewCommunityView.addRowCell(mainTable, mainRow4, mainRow4Cell);
        pageBody.AddInnerHTMLElement(mainTable);
        try
        {
          pageHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
        }
        catch (Exception e)
        {
          log.Error(e, e.Message);
        }
        mainPage.SetHead(pageHead);
        mainPage.SetBody(pageBody);
      }
      catch (HTMLException he)
      {
        log.Error(he, he.Message);
      }
      return mainPage;
    }
    
    /// <summary>
    /// Display JavaScript
    /// </summary>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (PreviewCommunityBarModel) model;
      m_asOwner = parent;
    }
  }
}