using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.myportal.communities
{
  /// <summary>
  /// File: CommunityInvitationModelHelper.java
  /// -----------------------------------------
  /// ModelHelper for Community Preview/Invitations
  /// This is necessary because we don't need this
  /// for all MyPortal Pages, yet we want it on the
  /// MyPortal Model.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class PreviewCommunityModel : IModel,IModelRO
  {
    public const String STR_MVC_CLASS_NAME = "PreviewCommunity";
    
    /// <summary>
    /// Constant: No Preview Header Bar 
    /// </summary>
    public const int NOPREVIEWHEADER = 0;
    
    /// <summary>
    /// Constant: Preview Header Bar for Selection Page
    /// </summary>
    public const int SELECTIONPREVIEWHEADER = 1;
    
    /// <summary>
    /// Constant: Invite Header Bar 
    /// </summary>
    public const int INVITEHEADER = 2;
    
    /// <summary>
    /// Constant: Preview Header Bar for preview only (as in Community Editor)
    /// </summary>
    public const int PREVIEWHEADER = 3;
    
    /// <summary>
    /// Which bar is being used 
    /// </summary>
    public int m_nPreviewStatus;
    
    /// <summary>
    /// Join Community Javascript override *
    /// </summary>
    public String m_strJavascriptOverride = null;
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_ActivitySpace = null;
    
    /// <summary>
    /// Session 
    /// </summary>
    private IPTSession m_ptSession;
    
    /// <summary>
    /// Community Checked 
    /// </summary>
    private bool m_bCommunityChecked;
    
    /// <summary>
    /// Community ID 
    /// </summary>
    private int m_nCommunityID;
    
    /// <summary>
    /// Community Index for selection page 
    /// </summary>
    private int m_nCommunityIndex;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PreviewCommunityModel();
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual int GetCommunityID()
    {
      return m_nCommunityID;
    }
    
    /// <summary>
    /// Get to use for preview from selection page
    /// </summary>
    public virtual int GetCommunityIndex()
    {
      return m_nCommunityIndex;
    }
    ///////////////////////////////////////
    // Read only methods from IModelRO
    ///////////////////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModelRO#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /////////////////////////
    // Methods from IModel
    /////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_ActivitySpace = parent;
      m_ptSession = (IPTSession) m_ActivitySpace.GetUserSession();
    }
    
    /// <summary>
    /// Get to check for selected community
    /// </summary>
    public virtual bool IsCommunityChecked()
    {
      return m_bCommunityChecked;
    }
    
    /// <summary>
    /// Set community as selected
    /// </summary>
    public virtual void SetCommunityChecked(bool bCommunityChecked)
    {
      m_bCommunityChecked = bCommunityChecked;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual void SetCommunityID(int nCommunityID)
    {
      m_nCommunityID = nCommunityID;
    }
    
    /// <summary>
    /// Set to use selection page
    /// </summary>
    public virtual void SetCommunityIndex(int nCommunityIndex)
    {
      m_nCommunityIndex = nCommunityIndex;
    }
    
    /// <summary>
    /// Set to use Invite Header
    /// </summary>
    public virtual void SetCommunityToInvitePage()
    {
      m_nPreviewStatus = INVITEHEADER;
    }
    
    /// <summary>
    /// Set to use Preview Header
    /// </summary>
    public virtual void SetCommunityToPreviewPage()
    {
      m_nPreviewStatus = PREVIEWHEADER;
    }
    
    /// <summary>
    /// Set to use Selection Preview Header
    /// </summary>
    public virtual void SetCommunityToSelectionPreviewPage()
    {
      m_nPreviewStatus = SELECTIONPREVIEWHEADER;
    }
    public virtual bool UserHasCommunityAccess()
    {
      IPTSubPortalInfo subPortalInfo = m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
      int nBool = subPortalInfo.GetAccessType() & PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS;
      return nBool != 0;
    }
    
    /// <summary>
    /// Get Join Community Javascript override.
    /// This javascript should be the name of the javascript function to be
    /// used in the onclick attribute of the join community button.  The function should
    /// take 2 arguments: the community ID, and a reference to the popup window.
    /// (i.e. If the name is "joinCommunity", then the function will look like
    /// this: "joinCommunity(communityID, self)").  This function name can also
    /// include an optional window reference (i.e. "opener.joinCommunity").
    /// </summary>
    /// <returns>
    /// String the name of the javascript function to use when joining the community.
    /// This string will be null if there is no override.
    /// </returns>
    public virtual String GetJoinCommunityJavaScriptOverride()
    {
      return m_strJavascriptOverride;
    }
    
    /// <summary>
    /// Set the Join Community Javascript override.
    /// This javascript should be the name of the javascript function to be
    /// used in the onclick attribute of the join community button.  The function should
    /// take 2 arguments: the community ID, and a reference to the popup window.
    /// (i.e. If the name is "joinCommunity", then the function will look like
    /// this: "joinCommunity(communityID, self)").  This function name can also
    /// include an optional window reference (i.e. "opener.joinCommunity").
    /// Null means to use the default javascript.
    /// </summary>
    public virtual void SetJoinCommunityJavaScriptOverride(String _strOverride)
    {
      m_strJavascriptOverride = _strOverride;
    }
  }
}