using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.myportal.editpage
{
  /// <summary>
  /// File: EditMyPagePortletLayoutModel_D.java
  /// ----------------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class EditMyPagePortletLayoutModel_D : EditorModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.editpage.EditMyPagePortletLayoutModel_D");
    
    /// <summary>
    /// Activity space name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditMyPagePortletLayout";
    public const String QS_PAGEID = "PageID";
    public const int ACTIONUP = 0;
    public const int ACTIONDOWN = 1;
    public const int ACTIONDELETE = 2;
    protected ASQueryResultWrapper m_asqrMyPortalPortlets;
    protected ASQueryResultWrapper m_asqrMyPortalMandatoryPortlets;
    protected IPTPage m_ptPage;
    
    /// <summary>
    /// Store session and catalog to retrieve data 
    /// </summary>
    protected IPTSession m_ptSession;
    
    /// <summary>
    /// Logger 
    /// </summary>
    private AActivitySpace m_asOwner = null;
    private XPArrayList m_arrPortletOrder;
    private int m_nPageID = 0;
    private int m_nAction = -1;
    private int m_nIndexToMove = -1;
    private int m_nMandPortletCount = 0;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#CleanupTempData()"></seealso>
    public override void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public override void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EditMyPagePortletLayoutModel_D();
    }
    public override bool CheckEditorAccessAndStart(XPHashtable _htArguemnts)
    {
      try
      {
        String[] sValues = (String[]) _htArguemnts.GetElement(QS_PAGEID);
        int nPageID = 0;
        if (sValues == null)
        {
          log.Info("could not find page ID in query string.");
          log.Error("Page ID not found in query string");
          throw new Exception("Page ID not found");
        }
        nPageID = XPConvert.ToInteger(sValues[0]);
        SetPageID(nPageID);
      }
      catch (Exception e)
      {
        log.Error(e, "Server Error");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return false;
      }
      return true;
    }
    
    /// <throws>Exception </throws>
    public virtual void DoAction()
    {
      int nIndexToMove = m_nIndexToMove - m_nMandPortletCount;
      if ((nIndexToMove > -1) && (m_nAction > -1))
      {
        Object intIndex = m_arrPortletOrder.GetElement(nIndexToMove);
        Object intTemp;
        if (m_nAction == ACTIONUP)
        {
          intTemp = m_arrPortletOrder.GetElement(nIndexToMove - 1);
          m_arrPortletOrder.SetElement(nIndexToMove - 1, intIndex);
          m_arrPortletOrder.SetElement(nIndexToMove, intTemp);
        } else
        if (m_nAction == ACTIONDOWN)
        {
          intTemp = m_arrPortletOrder.GetElement(nIndexToMove + 1);
          m_arrPortletOrder.SetElement(nIndexToMove + 1, intIndex);
          m_arrPortletOrder.SetElement(nIndexToMove, intTemp);
        } else
        if (m_nAction == ACTIONDELETE)
        {
          XPArrayList m_arrNewPortletOrder = new XPArrayList(m_arrPortletOrder.GetSize() - 1);
          for (int i = 0;i < m_arrPortletOrder.GetSize();i++)
          {
            if (i < nIndexToMove || i > nIndexToMove)
            {
              intIndex = m_arrPortletOrder.GetElement(i);
              m_arrNewPortletOrder.Add(intIndex);
            }
          }
          m_arrPortletOrder = m_arrNewPortletOrder;
        }
      } else
      {
        throw new Exception("Invalid arguments for Action.");
      }
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
      int[] arrPortlets = new int[m_arrPortletOrder.GetSize()];
      for (int i = 0;i < arrPortlets.Length;i++)
      {
        int nQueryIndex = XPConvert.ToInteger(m_arrPortletOrder.GetElement(i));
        arrPortlets[i] = XPConvert.ToInteger(m_asqrMyPortalPortlets.GetFields(nQueryIndex,
         PT_PROPIDS.PT_PROPID_OBJECTID));
      }
      m_ptPage.AssignPortlets(new int[0], 0);
      m_ptPage.AssignPortlets(new int[0], 2);
      m_ptPage.AssignPortlets(arrPortlets, 1);
      String strPageName = ((PageNamePlugInModel) m_asOwner.GetModel(EditMyPagePortletLayoutAS_D.strPageNamePlugInKey)).GetPageName();
      if (!(strPageName).Equals(m_ptPage.GetName()))
      {
        IPTServerContext ptSC = (IPTServerContext) m_ptPage.GetInterfaces("IPTServerContext");
        ptSC.LockObject();
        m_ptPage.SetName(strPageName);
        ptSC.Store();
        ptSC.UnlockObject();
      }
    }
    
    /// <returns></returns>
    public virtual int GetPortletCount()
    {
      return m_arrPortletOrder.GetSize() + m_nMandPortletCount;
    }
    
    /// <returns>the mandatory portlet count</returns>
    public virtual int GetMandatoryPortletCount()
    {
      return m_nMandPortletCount;
    }
    
    /// <param name="nIndex"></param>
    /// <returns></returns>
    public virtual String GetPortletName(int nIndex)
    {
      if (nIndex < m_nMandPortletCount)
      {
        return (String) m_asqrMyPortalMandatoryPortlets.GetFields(nIndex,
         PT_PROPIDS.PT_PROPID_NAME);
      }
      int nQueryIndex = XPConvert.ToInteger(m_arrPortletOrder.GetElement(nIndex - m_nMandPortletCount));
      return (String) m_asqrMyPortalPortlets.GetFields(nQueryIndex, PT_PROPIDS.PT_PROPID_NAME);
      }
    ////////////////////////
    /// IModel         /////
    ////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual String GetPageName()
    {
      return m_ptPage.GetName();
    }
    
    /// <summary>
    /// Returns the Redirect object
    /// (this is were we need to go at the end of the Editor).
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect GetRedirectAfterFinish()
    {
      Redirect redirect = new Redirect();
      redirect.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
      redirect.AddControlArgument(SetPageControl.STR_PAGE_ID, m_nPageID);
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public override void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      String[] sValues = (String[]) _htFormData.GetElement(EditMyPagePortletLayoutView_D.QS_INDEX);
      if (RepostControl.PAGE_STATUS_INVALID == ((PageNamePlugInModel) m_asOwner.GetModel(EditMyPagePortletLayoutAS_D.strPageNamePlugInKey)).SaveSection(_htFormData))
      {
        // clear errors here in 508 because otherwise the framework hides them until 
        // after finish, when the error msg is inappropriate.
        return RepostControl.PAGE_STATUS_INVALID;
      }
      if (sValues == null)
      {
        log.Info("could not find index in query string.");
        m_nIndexToMove = -1;
      } else
      {
        m_nIndexToMove = XPConvert.ToInteger(sValues[0]);
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual void SetActionDown()
    {
      m_nAction = ACTIONDOWN;
    }
    public virtual void SetActionUp()
    {
      m_nAction = ACTIONUP;
    }
    public virtual void SetActionDelete()
    {
      m_nAction = ACTIONDELETE;
    }
    
    /// <param name="nPageID"></param>
    /// <throws>Exception </throws>
    public virtual void SetPageID(int nPageID)
    {
      m_nPageID = nPageID;
      m_ptPage = (IPTPage) m_ptSession.GetPages().Open(m_nPageID, false);
      m_nMandPortletCount = 0;
      if (m_nPageID < 0)
      {
        // Add mandatory portlet to home page edit layout
        m_asqrMyPortalMandatoryPortlets = new ASQueryResultWrapper(m_ptSession.GetMyPages().QueryMandatoryGadgets());
        m_nMandPortletCount = m_asqrMyPortalMandatoryPortlets.GetCount();
        }
      // Add regular gadgets to my page as well
      m_asqrMyPortalPortlets = new ASQueryResultWrapper(m_ptPage.QueryPortlets());
      int nPortletCount = m_asqrMyPortalPortlets.GetCount();
      m_arrPortletOrder = new XPArrayList(nPortletCount);
      for (int i = 0;i < nPortletCount;i++)
      {
        m_arrPortletOrder.Add(i);
      }
      PageNamePlugInModel plugInModel = (PageNamePlugInModel) m_asOwner.GetModel(EditMyPagePortletLayoutAS_D.strPageNamePlugInKey);
      plugInModel.InitializePlugIn(m_ptPage.GetName(), "", -1);
    }
  }
}