using System;
// Framework Imports
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.myportal.editpage
{
  /// <summary>
  /// This class is used to register all the Model, Views, Display Pages,
  /// and Controls created for the Edit Page Editor.
  /// This class can also be used to get any of those objects back with
  /// the class name.
  /// </summary>
  /// <author>MichaelD</author>
  public class EditMyPortalPageAS : PTEditorAS
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditMyPortalPage";
    
    /// <summary>
    /// Plug in Key: PageName 
    /// </summary>
    public const String strPageNamePlugInKey = "PageName";
    
    /// <summary>
    /// Layout table top 
    /// </summary>
    public const int LAYOUTTABLE_TOP = 226;
    
    /// <summary>
    /// Layout table left 
    /// </summary>
    public const int LAYOUTTABLE_LEFT = 13;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String,java.lang.String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bAccess = base.CheckBasicAccess(strPage, strControl, bSameSpace);
      // MJD- Otherwise make sure this is the refresh control or the default page creation control. 
      // The access will be checked by those controls.
      if ((null != strControl) && ((strControl.Equals(RefreshEditPageControl.STR_MVC_CLASS_NAME))) || ((strControl.Equals(EditPageCreateDefaultControl.STR_MVC_CLASS_NAME))))
      {
        bAccess = true;
      }
      return bAccess;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EditMyPortalPageAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      if (((EditMyPortalPageModel) GetModel(m_strModelName)).IsCreateMyPage())
      {
        return (GetString(1256, "ptmsgs_portalbrowsingmsgs"));
      }
      return (GetString(664, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (EditPageRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = EditMyPortalPageModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(EditMyPortalPageModel.STR_MVC_CLASS_NAME);
      // Register DisplayPages
      AFormDP myPage = new EditMyPortalPageDP();
      myPage.AddToValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
      myPage.AddToValidationFunction(PageNameView.JS_VALIDATE_PAGENAME_FUNC);
      RegisterPage(myPage);
      // Register Views
      RegisterView(EditCommunityPageView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(EditPageRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(RefreshEditPageControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(EditPageCreateDefaultControl.STR_MVC_CLASS_NAME, myModel);
      // Set default page
      SetCurrentPage(EditMyPortalPageDP.STR_MVC_CLASS_NAME);
      // Register common sections
      //      Register each Section/Model for your plug-in sections
      RegisterModel(PageNamePlugInModel.STR_MVC_CLASS_NAME);
      IModel myPageNameModel = GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME);
      RegisterView(PageNameView.STR_MVC_CLASS_NAME, myPageNameModel);
      RegisterModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
      IModel myPageLayoutModel = GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
      RegisterView(PageLayoutView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterView(PageLayoutHeaderView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterView(PageLayoutAlternateView.STR_MVC_CLASS_NAME, myPageLayoutModel);
      RegisterControl(PageLayoutControl.STR_MVC_CLASS_NAME, myPageLayoutModel);
      }
    
    /// <summary>
    /// Distinguish between community and non-community edit page by checking the
    /// name of the parent form.  Community edit page is launched from the
    /// community editor, so it has a parent, while my page edit page does not
    /// have a parent.  bjf -- also, fixed a bug with this, it was comparing the
    /// parent form name to the empty string, but actually the parent form name
    /// appears to be null.  Now checking for both empty and null.
    /// </summary>
    /// <returns>boolean True if this is a community page.</returns>
    public virtual bool IsCommunityEditPage()
    {
      String strParentFormName = ((IEditMyPortalPageModelRO) GetModel(EditMyPortalPageModel.STR_MVC_CLASS_NAME)).GetParentFormName();
      bool bIsCommunityPage = !("").Equals(strParentFormName) && null != strParentFormName;
      return bIsCommunityPage;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      //		String sPageName = page.GetName();
      if (IsCommunityEditPage())
      {
        SetHelpTopic("PT_Community_EditPage");
      } else
      {
        if (((EditMyPortalPageModel) GetModel(EditMyPortalPageModel.STR_MVC_CLASS_NAME)).IsCreateMyPage())
        {
          SetHelpTopic("PT_CreatePage");
        } else
        {
          SetHelpTopic("PT_MyPage_EditPage");
        }
      }
    }
  }
}