using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
namespace com.plumtree.portalpages.browsing.myportal.editpage
{
  /// <summary>
  /// This is class is used to print out together the Views for
  /// the Edit Page Layout page of the Edit Page Editor.
  /// </summary>
  /// <author>MichaelD</author>
  public class EditMyPortalPageDP : EditorDP
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditMyPortalPage";
    protected EditMyPortalPageAS m_asOwner;
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetEditorTitle();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
      {
        if (m_asOwner.IsCommunityEditPage())
        {
          return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1075,
           "ptmsgs_portalbrowsingmsgs"), this.m_asOwner);
        }
        return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1501,
         "ptmsgs_portalbrowsingmsgs"), this.m_asOwner);
      }
      if (((EditMyPortalPageModel) m_asOwner.GetModel(m_asOwner.m_strModelName)).IsCreateMyPage())
      {
        return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1669,
         "ptmsgs_portalbrowsingmsgs"), this.m_asOwner);
      }
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1799, "ptmsgs_portalbrowsingmsgs"),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Returns the HTML for that Page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement(m_asOwner.GetView(PageNameView.STR_MVC_CLASS_NAME).Display());
      if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
      {
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).Display());
        if (!((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
        {
          views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutAlternateView.STR_MVC_CLASS_NAME).Display());
          }
        if (m_asOwner.IsCommunityEditPage())
        {
          views.AddInnerHTMLElement(m_asOwner.GetView(EditCommunityPageView.STR_MVC_CLASS_NAME).Display());
          }
      }
      result.AddInnerHTMLElement(CreateContentTable(views, null));
      return result;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from PlumtreeDP need
    /// to implement.  The method should add whatever HTML the child class wants to
    /// use the DisplayJavaScript and add it to the head.
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#DisplayJavaScriptFromChild()"></seealso>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      int nLayoutTop = GetLayoutTableTop(m_asOwner.IsCommunityEditPage(),
       m_asOwner);
      ((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).SetLayoutTablePosition(nLayoutTop,
       EditMyPortalPageAS.LAYOUTTABLE_LEFT);
      HTMLScriptCollection result = new HTMLScriptCollection();
      result.AddInnerHTMLElement(((PageNameView) m_asOwner.GetView(PageNameView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
      result.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());
      if (((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout())
      {
        result.AddInnerHTMLElement(((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
        } else
      {
        result.AddInnerHTMLElement(((PageLayoutAlternateView) m_asOwner.GetView(PageLayoutAlternateView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
        }
      if (m_asOwner.IsCommunityEditPage())
      {
        result.AddInnerHTMLElement(m_asOwner.GetView(EditCommunityPageView.STR_MVC_CLASS_NAME).DisplayJavascript());
        }
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLAfterForm()
     */
     
    public override HTMLElementCollection DisplayHTMLAfterForm()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      if (((IPageLayoutModelRO) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout() && AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
      {
        HTMLTable myTable = new HTMLTable();
        myTable.SetOnSelectStart("return false");
        collection.AddInnerHTMLElement(myTable);
        myTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        HTMLTableRow myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        HTMLTableCell myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME).Display());
        }
      collection.AddInnerHTMLElement(base.DisplayHTMLAfterForm());
      return collection;
    }
    
    /// <summary>
    /// Adjust the number of pixels for the drag and drop
    /// based on the page type being edited and the language of the user.
    /// </summary>
    /// <param name="bIsCommunityEditPage"></param>
    /// <param name="asOwner"></param>
    /// <returns>int</returns>
    public static int GetLayoutTableTop(bool bIsCommunityEditPage, AActivitySpace asOwner)
    {
      String strLang = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       asOwner));
      int nLayoutTop = EditMyPortalPageAS.LAYOUTTABLE_TOP;
      if (bIsCommunityEditPage)
      {
        if (strLang.Equals("ja"))
        {
          nLayoutTop+=49;
        } else
        if (strLang.Equals("zh"))
        {
          nLayoutTop+=14;
        } else
        if (strLang.Equals("ko"))
        {
          nLayoutTop+=22;
        } else
        if (strLang.Equals("fr"))
        {
          nLayoutTop+=19;
        } else
        if (strLang.Equals("de"))
        {
          nLayoutTop+=19;
        } else
        if (strLang.Equals("en"))
        {
          nLayoutTop+=7;
        } else
        if (strLang.Equals("it"))
        {
          nLayoutTop+=7;
        } else
        if (strLang.Equals("pt"))
        {
          nLayoutTop+=7;
        } else
        if (strLang.Equals("es"))
        {
          nLayoutTop+=7;
        }
      } else
      {
        if (strLang.Equals("ja"))
        {
          nLayoutTop+=-4;
        } else
        if (strLang.Equals("zh"))
        {
          nLayoutTop+=-4;
        } else
        if (strLang.Equals("ko"))
        {
          nLayoutTop+=-10;
        } else
        if (strLang.Equals("fr"))
        {
          nLayoutTop+=-5;
        } else
        if (strLang.Equals("de"))
        {
          nLayoutTop+=-5;
        } else
        if (strLang.Equals("en"))
        {
          nLayoutTop+=-12;
        } else
        if (strLang.Equals("it"))
        {
          nLayoutTop+=-13;
        } else
        if (strLang.Equals("pt"))
        {
          nLayoutTop+=-14;
        } else
        if (strLang.Equals("es"))
        {
          nLayoutTop+=-14;
        }
      }
      BrowserType browser = (BrowserType) asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      if (browser.IsSunOS() && browser.IsNetscape4())
      {
        nLayoutTop+=23;
      }
      return nLayoutTop;
    }
    
    /// <summary>
    /// Inits the class with the associated activity space passed in argument.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      m_asOwner = (EditMyPortalPageAS) parent;
    }
  }
}