using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.myportal.editpage
{
  /// <author>michaeld</author>
  public class EditMyPortalPageModel : EditorModel,IEditMyPortalPageModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.editpage.EditMyPortalPageModel");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditMyPortalPage";
    
    /// <summary>
    /// The name of the parent form that you would like the data passed back to. 
    /// </summary>
    public const String HTMLINPUT_PARENT_FORM_NAME = "ParentFormName";
    
    /// <summary>
    /// The name of the input in the parent form that you would like the AActivitySpace
    /// ID of the tree space put into. 
    /// </summary>
    public const String HTMLINPUT_PARENT_FORM_SPACE_ID = "ParentFormSpaceID";
    
    /// <summary>
    /// The name of the method in the parent form to call when the tree is submitted 
    /// </summary>
    public const String HTMLINPUT_PARENT_SUBMIT_CALL = "ParentFormSubmit";
    
    /// <summary>
    /// IPTMyPortal 
    /// </summary>
    private IPTPage m_ptPage;
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    private IPTSession m_ptSession;
    
    /// <summary>
    /// Parent Form Name 
    /// </summary>
    private String m_strParentFormName;
    
    /// <summary>
    /// Parent Form Space ID 
    /// </summary>
    private String m_strParentFormSpaceID;
    
    /// <summary>
    /// Parent Form Submit Call 
    /// </summary>
    private String m_strParentFormSubmitCall;
    
    /// <summary>
    /// Create My Page 
    /// </summary>
    private bool m_bCreateMyPage;
    
    /// <summary>
    /// From Community Template 
    /// </summary>
    private bool m_bFromCommTemp;
    
    /// <summary>
    /// Community ID 
    /// </summary>
    private int m_nCommunityID;
    
    /// <summary>
    /// Edit Page Index 
    /// </summary>
    private int m_nEditPageIndex;
    
    /// <summary>
    /// Edit Page Unique ID 
    /// </summary>
    private int m_nEditPageUniqueID;
    
    /// <summary>
    /// Opener Community Folder ID 
    /// </summary>
    private int m_nOpenerCommunityFolderID;
    
    /// <summary>
    /// Opener Community ID 
    /// </summary>
    private int m_nOpenerCommunityID;
    
    /// <summary>
    /// Opener Page ID 
    /// </summary>
    private int m_nOpenerPageID;
    
    /// <summary>
    /// Page ID 
    /// </summary>
    private int m_nPageID;
    
    /// <summary>
    /// Page Template ID 
    /// </summary>
    private int m_nPageTemplate;
    // END ***************** helper methods ***************** 
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#StartEditor(XPHashtable)"></seealso>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      String strPageName;
      int nTableHeight;
      IASQueryResult ptqrOriginalPortlets = null;
      m_nOpenerCommunityID = 0;
      m_nOpenerPageID = 0;
      m_nEditPageIndex = -1;
      m_nPageTemplate = 0;
      SetValuesFromQueryString(_htFormData);
      BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      if (browser.IsNetscape4())
      {
        nTableHeight = 800;
      } else
      {
        nTableHeight = 400;
      }
      // Get session
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      if (m_bCreateMyPage)
      {
        strPageName = m_asOwner.GetString(667, "ptmsgs_portalbrowsingmsgs");
        // Create Page
        m_ptPage = (IPTPage) m_ptSession.GetPages().Create(-m_ptSession.GetSessionInfo().GetCurrentUserID());
        m_ptPage.SetName(strPageName);
        m_ptPage.SetPageTemplateID(0);
        m_ptPage.SetInheritPageTemplate(false);
        // BT: Use default portlet layout if portlet layouts are enabled.
        if (LayoutService.getChooserInstance().GetPortletLayoutsEnabled(m_asOwner) && m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetLayoutEnabled())
        {
          // adaptive layout stores a negative value in the page type (negative value of a webservice layout id)
          m_ptPage.SetPageType(-PT_INTRINSICS.PT_WEBSERVICE_DEFAULT_PORTLET_LAYOUT);
          } else
        {
          m_ptPage.SetPageType(PageTypeConstants.TWO_COLUMN_NARROW_WIDE);
          }
        if (0 == m_ptSession.GetMyPages().QueryPages(0).RowCount())
        {
          // Set is home page
          ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetIsHomeMyPage(true);
          }
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetOpenerPageID(0);
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetAllowFreeFormSection(false);
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn(m_ptPage,
         nTableHeight, null, true, m_ptSession);
        ((PageNamePlugInModel) m_asOwner.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn(strPageName,
         m_asOwner.GetString(668, "ptmsgs_portalbrowsingmsgs"), 0);
      } else
      if (m_nOpenerPageID != 0)
      {
        // Get My Portal
        m_ptPage = (IPTPage) m_ptSession.GetPages().Open(m_nOpenerPageID,
         false);
        if (m_nOpenerCommunityID == 0)
        {
          if (((IPTPageManager) m_ptSession.GetPages()).CachedOpenPageInfo(m_nOpenerPageID,
           true, true).GetIsFirstPageInContainer())
          {
            // Set is home page
            ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetIsHomeMyPage(true);
            }
        }
        // query for gadgets
        ASQueryResultWrapper qrw = new ASQueryResultWrapper(m_ptPage.QueryPortlets());
        ptqrOriginalPortlets = qrw;
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetOpenerPageID(m_nOpenerPageID);
        if (0 > m_ptPage.GetAdminFolderID())
        {
          ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetAllowFreeFormSection(false);
          } else
        {
          ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetAllowFreeFormSection(true);
          }
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn(m_ptPage,
         nTableHeight, ptqrOriginalPortlets, false, m_ptSession);
        ((PageNamePlugInModel) m_asOwner.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn(m_ptPage.GetName(),
         m_asOwner.GetString(668, "ptmsgs_portalbrowsingmsgs"), 0);
      } else
      if (m_nEditPageIndex != -1)
      {
        ASCache myCache = (ASCache) m_asOwner.GetSubSession().GetAttribute(ASConstants.SANDBOXASCACHE);
        AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
         m_asOwner.GetParentSpaceID());
        PageData myPageModel = ((CommunityEditorModel) parentSpace.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).GetPageModelAt(m_nEditPageIndex);
        IPTCommunity myCommunity = (IPTCommunity) ((CommunityEditorModel) parentSpace.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).GetObject();
        m_nPageTemplate = myPageModel.m_nPageTemplateID;
        m_nPageID = myPageModel.m_nPageID;
        if (-1 == myPageModel.m_nCommunityID)
        {
          myPageModel.m_nCommunityID = m_nOpenerCommunityFolderID;
        }
        m_nCommunityID = myPageModel.m_nCommunityID;
        m_bFromCommTemp = myPageModel.m_bFromCommTemp;
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetAllowFreeFormSection(true);
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn(myPageModel,
         myCommunity, nTableHeight, m_ptSession);
        ((PageNamePlugInModel) m_asOwner.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).InitializePlugIn(myPageModel.m_strPageName,
         m_asOwner.GetString(668, "ptmsgs_portalbrowsingmsgs"), 0);
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EditMyPortalPageModel();
    }
    
    /// <summary>
    /// This method will be called when you come back to the main Editor from a sub Editor.
    /// </summary>
    public override void DoTaskOnComeBackFromSubEditor()
    {
      ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).RepostNewPortlet();
      }
    // END ***************** save DP methods ***************** 
    // ***CHANGE_HERE*** Implement the repost action methods that you 
    //      will call from your Repost Control.
    // BEGIN ***************** repost action methods ***************** 
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public override void Finish()
    {
      // Get the settings back from the plug-in Model and sets them on the Object before the Framework stores it.
      // Set page name
      if (-1 == m_nEditPageIndex)
      {
        // Setup PEI variables
        IApplication application = m_asOwner.GetApplication();
        Object[] oa = (Object[]) application.GetCachingManager().GetEntry("MyPortalPageActions");
        // END Setup PEI variables
        String strPageName = ((PageNamePlugInModel) m_asOwner.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).GetPageName();
        int nPageType = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetPageType();
        if (this.m_bCreateMyPage)
        {
          //PEI : MyPortalPageActions
          // BrianH: All of the following code will load all of the available MyPortalPageAction
          // PEIs and process through them. The returned object array will be used to process possible
          // modifications to the page name or page type.
          //PEI : OnBeforeAddMyPortalPage : BEGIN
          if (oa != null)
          {
            for (int iMPPActions = 0;iMPPActions < oa.Length;iMPPActions++)
            {
              Object o = oa[iMPPActions];
              if (o != null)
              {
                MyPortalPageArguments returnPageSettings;
                IMyPortalPageActions iActions = (IMyPortalPageActions) o;
                returnPageSettings = iActions.OnBeforeAddMyPortalPage(m_asOwner,
                 m_ptSession, strPageName, nPageType);
                if (returnPageSettings != null)
                {
                  String returnPageName = returnPageSettings.GetMyPortalPageName();
                  int returnPageType = returnPageSettings.GetMyPortalPageType();
                  if (returnPageName != null && !("").Equals(returnPageName) && returnPageName.Length <= PT_SERVERCONSTANTS.PT_MAX_NAMELENGTH)
                  {
                    strPageName = returnPageName;
                  }
                  //Page type must correspond to a valid Page Type Constant.
                  if (returnPageType < 0 || returnPageType > 12)
                  {
                    UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
                     null, m_asOwner.GetString(571, "ptmsgs_portalbrowsingmsgs"),
                     "MyPortalPageActions PEI Page Type Error");
                    UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
                     m_asOwner.GetApplication());
                  } else
                  {
                    nPageType = returnPageType;
                  }
                }
              }
            }
          }
          //PEI : OnBeforeAddMyPortalPage : END
          m_ptPage.SetName(strPageName);
          m_ptPage.SetPageType(nPageType);
          ((IPTServerContext) m_ptPage).Store();
          ((IPTServerContext) m_ptPage).UnlockObject();
          //PEI : OnAfterAddMyPortalPage : BEGIN
          if (oa != null)
          {
            for (int iMPPActions = 0;iMPPActions < oa.Length;iMPPActions++)
            {
              Object o = oa[iMPPActions];
              if (o != null)
              {
                IMyPortalPageActions iActions = (IMyPortalPageActions) o;
                iActions.OnAfterAddMyPortalPage(m_asOwner, m_ptSession, strPageName,
                 nPageType);
              }
            }
          }
        } else
        //PEI : OnAfterAddMyPortalPage : END				
        {
          try
          {
            //PEI : MyPortalPageActions
            // MJD: All of the following code will load all of the available MyPortalPageAction
            // PEIs and process through them. The returned object array will be used to process possible
            // modifications to the page name or page type.
            if (oa != null)
            {
              for (int iMPPActions = 0;iMPPActions < oa.Length;iMPPActions++)
              {
                Object o = oa[iMPPActions];
                if (o != null)
                {
                  MyPortalPageArguments returnPageSettings;
                  IMyPortalPageActions iActions = (IMyPortalPageActions) o;
                  returnPageSettings = iActions.OnBeforeEditMyPortalPage(m_asOwner,
                   (IPTSession) m_asOwner.GetUserSession(), strPageName, nPageType);
                  if (returnPageSettings != null)
                  {
                    String returnPageName = returnPageSettings.GetMyPortalPageName();
                    int returnPageType = returnPageSettings.GetMyPortalPageType();
                    if (returnPageName != null && !("").Equals(returnPageName) && returnPageName.Length <= PT_SERVERCONSTANTS.PT_MAX_NAMELENGTH)
                    {
                      strPageName = returnPageName;
                    }
                    //Page type must correspond to a valid Page Type Constant.
                    if (returnPageType < 0 || returnPageType > 12)
                    {
                      UIError myError = new UIError(UIErrorLevel.SERIOUS,
                       UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(571,
                       "ptmsgs_portalbrowsingmsgs"), "MyPortalPageActions PEI Page Type Error");
                      UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
                       m_asOwner.GetApplication());
                    } else
                    {
                      nPageType = returnPageType;
                    }
                  }
                }
              }
            }
          }
          //PEI : OnBeforeEditMyPortalPage : END
          catch (Exception ex)
          {
            log.Error(ex, "OnBeforeEditMyPortalPage PEI failed. Page Name = " + strPageName + " and Page Type = " + nPageType);
            }
          // Lock page
          if (!strPageName.Equals(m_ptPage.GetName()) || nPageType != m_ptPage.GetPageType())
          {
            IPTServerContext ptSC = (IPTServerContext) m_ptPage;
            ptSC.LockObject();
            if (!strPageName.Equals(m_ptPage.GetName()))
            {
              if (0 != m_nOpenerPageID)
              {
                m_ptPage.SetName(strPageName);
              }
            }
            // Set page type
            if (nPageType != m_ptPage.GetPageType())
            {
              if (0 != m_nOpenerPageID)
              {
                m_ptPage.SetPageType(nPageType);
              }
            }
            // Store and Unlock page
            ptSC.Store();
            ptSC.UnlockObject();
          }
          try
          {
            //PEI : MyPortalPageActions
            // MJD: All of the following code will load all of the available MyPortalPageAction
            // PEIs and process through them.
            if (oa != null)
            {
              for (int x = 0;x < oa.Length;x++)
              {
                Object o = oa[x];
                if (o != null)
                {
                  IMyPortalPageActions iActions = (IMyPortalPageActions) o;
                  iActions.OnAfterEditMyPortalPage(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
                   strPageName, nPageType);
                }
              }
            }
          }
          //PEI : OnAfterEditMyPortalPage : END
          catch (Exception ex)
          {
            log.Error(ex, "OnAfterEditMyPortalPage PEI failed. Page Name = " + strPageName + " and Page Type = " + nPageType);
            }
        }
        // Set gadget columns
        int[][] annPortletOrder = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetColumnOrder();
        for (int i = PortletColumnConstants.NARROW_ONE.ToInt();i <= PortletColumnConstants.NARROW_TWO.ToInt();
        i++)
        {
          m_ptPage.AssignPortlets(annPortletOrder[i], i);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()"></seealso>
    public override void Cancel()
    {
      // DCA - null out ptPage since we're canceling
      m_ptPage = null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // BEGIN ***************** helper methods ***************** 
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerClassID()"></seealso>
    public virtual int GetOpenerClassID()
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerCommunityFolderID()"></seealso>
    public virtual int GetOpenerCommunityFolderID()
    {
      return m_nOpenerCommunityFolderID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerCommunityID()"></seealso>
    public virtual int GetOpenerCommunityID()
    {
      return m_nOpenerCommunityID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerObjectID()"></seealso>
    public virtual int GetOpenerObjectID()
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.editpage.IEditMyPortalPageModelRO#GetPageModel()"></seealso>
    public virtual PageData GetPageModel()
    {
      PageData editPageModel = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetPageModel();
      editPageModel.m_strPageName = ((PageNamePlugInModel) m_asOwner.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).GetPageName();
      editPageModel.m_nPageTemplateID = m_nPageTemplate;
      editPageModel.m_bFromCommTemp = m_bFromCommTemp;
      editPageModel.m_nPageID = m_nPageID;
      editPageModel.m_nCommunityID = m_nCommunityID;
      editPageModel.m_nUniqueID = m_nEditPageUniqueID;
      return editPageModel;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.editpage.IEditMyPortalPageModelRO#GetPageTemplateSet()"></seealso>
    public virtual int GetPageTemplateSet()
    {
      return m_nPageTemplate;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.editpage.IEditMyPortalPageModelRO#GetParentFormName()"></seealso>
    public virtual String GetParentFormName()
    {
      return m_strParentFormName;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.editpage.IEditMyPortalPageModelRO#GetParentFormSpaceID()"></seealso>
    public virtual String GetParentFormSpaceID()
    {
      return m_strParentFormSpaceID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.myportal.editpage.IEditMyPortalPageModelRO#GetParentFormSubmitFunction()"></seealso>
    public virtual String GetParentFormSubmitFunction()
    {
      return m_strParentFormSubmitCall;
    }
    // END ***************** repost action methods ***************** 
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public override Redirect GetRedirectAfterFinish()
    {
      IPTURL pturl = null;
      Redirect result = new Redirect();
      if (m_nOpenerCommunityID > 0)
      {
        result.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME, m_asOwner);
        result.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
        result.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, m_nOpenerCommunityID);
        } else
      {
        if (m_bCreateMyPage && null != m_ptPage)
        {
          m_nOpenerPageID = m_ptPage.GetObjectID();
        }
        pturl = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(m_asOwner, m_nOpenerPageID,
         "");
        result.SetLinkToExternalURL(pturl.GetFullURL());
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      if (_sPageName.Equals(EditMyPortalPageDP.STR_MVC_CLASS_NAME))
      {
        SaveMainPage(_htFormData);
        if (RepostControl.PAGE_STATUS_INVALID == ((PageNamePlugInModel) m_asOwner.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData))
        {
          // clear errors here in 508 because otherwise the framework hides them until 
          // after finish, when the error msg is inappropriate.
          return RepostControl.PAGE_STATUS_INVALID;
        }
        ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    // BEGIN ***************** save DP methods ***************** 
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
    }
    // ********** private helper functions
    
    /// <summary>
    /// Set values of member variable from Query String
    /// </summary>
    /// <param name="XPHashTable">_htFormData</param>
    private void SetValuesFromQueryString(XPHashtable _htFormData)
    {
      if (_htFormData.ContainsKey(EditPageQueryArguments.HTMLINPUT_EDITPAGE_OPENERCOMMUNITYFOLDERID))
      {
        m_nOpenerCommunityFolderID = XPConvert.ToInteger(((String[]) _htFormData.GetElement(EditPageQueryArguments.HTMLINPUT_EDITPAGE_OPENERCOMMUNITYFOLDERID))[0]);
        }
      if (_htFormData.ContainsKey(EditPageQueryArguments.HTMLINPUT_EDITPAGE_OPENERCOMMUNITYID))
      {
        m_nOpenerCommunityID = XPConvert.ToInteger(((String[]) _htFormData.GetElement(EditPageQueryArguments.HTMLINPUT_EDITPAGE_OPENERCOMMUNITYID))[0]);
        }
      if (_htFormData.ContainsKey(EditPageQueryArguments.HTMLINPUT_EDITPAGE_OPENERPAGEID))
      {
        m_nOpenerPageID = XPConvert.ToInteger(((String[]) _htFormData.GetElement(EditPageQueryArguments.HTMLINPUT_EDITPAGE_OPENERPAGEID))[0]);
        }
      if (_htFormData.ContainsKey(HTMLINPUT_PARENT_FORM_NAME))
      {
        m_strParentFormName = (((String[]) _htFormData.GetElement(HTMLINPUT_PARENT_FORM_NAME))[0]);
        }
      if (_htFormData.ContainsKey(HTMLINPUT_PARENT_FORM_SPACE_ID))
      {
        m_strParentFormSpaceID = (((String[]) _htFormData.GetElement(HTMLINPUT_PARENT_FORM_SPACE_ID))[0]);
        }
      if (_htFormData.ContainsKey(HTMLINPUT_PARENT_SUBMIT_CALL))
      {
        m_strParentFormSubmitCall = (((String[]) _htFormData.GetElement(HTMLINPUT_PARENT_SUBMIT_CALL))[0]);
        }
      if (_htFormData.ContainsKey(PageListView.HTMLINPUT_HI_EDITPAGE))
      {
        m_nEditPageIndex = XPConvert.ToInteger(((String[]) _htFormData.GetElement(PageListView.HTMLINPUT_HI_EDITPAGE))[0]);
        }
      if (_htFormData.ContainsKey(PageListView.PAGE_UNIQUE_ID))
      {
        m_nEditPageUniqueID = XPConvert.ToInteger(((String[]) _htFormData.GetElement(PageListView.PAGE_UNIQUE_ID))[0]);
        }
      if (_htFormData.ContainsKey(EditPageQueryArguments.HTMLINPUT_EDITPAGE_CREATEMYPAGE))
      {
        m_bCreateMyPage = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(EditPageQueryArguments.HTMLINPUT_EDITPAGE_CREATEMYPAGE))[0]);
        }
    }
    
    /// <summary>
    /// Returns true if we're creating a new page.
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsCreateMyPage()
    {
      return m_bCreateMyPage;
    }
    public virtual IPTPage getPTPage()
    {
      return m_ptPage;
    }
  }
}