using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.myportal.editpage
{
  /// <summary>
  /// This class creates a single default page with a one-click operation
  /// </summary>
  /// <author>MattC</author>
  public class EditPageCreateDefaultControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.editpage.EditPageCreateDefaultControl");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditPageCreateDefault";
    
    /// <summary>
    /// Associated Activity Space 
    /// </summary>
    public AActivitySpace m_asOwner;
    
    /// <summary>
    /// Associated Model 
    /// </summary>
    protected EditMyPortalPageModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new EditPageCreateDefaultControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_model = (EditMyPortalPageModel) model;
      m_asOwner = space;
    }
    
    /// <summary>
    /// Simply creates a new page and redirects the browser back to that page
    /// </summary>
    /// <param name="arguments">contains HTTP arguments from the post</param>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      m_model.SetUserHasAccessToEditor(m_model.CheckEditorAccessAndStart(arguments));
      ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(CheckRequiredArgs(arguments));
      m_model.Finish();
      log.Info("EditPageDefaultControl: created new MyPage");
      return m_model.GetRedirectAfterFinish();
    }
    
    /// <summary>
    /// Takes an argument hashtable and returns a new table 
    /// that includes required (but missing) arguments
    /// </summary>
    /// <param name="arguments">contains HTTP arguments from the post</param>
    private XPHashtable CheckRequiredArgs(XPHashtable arguments)
    {
      // initialize a new hashtable for the arguments in case we need to add any
      XPHashtable tempTable = new XPHashtable(arguments);
      String[] data;
      // Page Layout Type
      data = (String[]) arguments.GetElement(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE);
      if ((null == data) || (0 == data.Length))
      {
        // grab the type from the default page already created in the model
        int pageType = m_model.getPTPage().GetPageType();
        tempTable.PutElement(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE,
         new String[]{XPConvert.ToString(pageType)});
      }
      // Portlet To Delete
      data = (String[]) arguments.GetElement(PageLayoutHeaderView.HTMLINPUT_DELETE_GADGETID);
      if ((null == data) || (0 == data.Length))
      {
        tempTable.PutElement(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE,
         new String[]{""});
      }
      // Three gadget order columns
      for (int i = 0;i < 3;i++)
      {
        data = (String[]) arguments.GetElement(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER_PREFIX + XPConvert.ToString(i));
        if ((null == data) || (0 == data.Length))
        {
          tempTable.PutElement(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER_PREFIX + XPConvert.ToString(i),
           new String[]{""});
        }
      }
      return tempTable;
    }
  }
}