using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.common.editpage;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.myportal.editpage
{
  /// <summary>
  /// This class contains the additional repost actions.
  /// The ones specific to the Edit Page Editor (other than
  /// "change page", "finish" and "cancel" actions).
  /// </summary>
  /// <author>MichaelD</author>
  public class EditPageRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.myportal.editpage.EditPageRepostControl");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditPageRepost";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EditPageRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="int"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      // You need to call the PerformRepostAction on the page layout control
      ((PageLayoutControl) m_asOwner.GetControl(PageLayoutControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
       m_htFormData);
    }
    
    /// <summary>
    /// This method is called when we finish a sub Editor.
    /// It takes care of closing the sub Editor pop-up winodws
    /// and repost the main Editor window.
    /// </summary>
    protected override void SetRedirectToCloseSubEditor()
    {
      ((EditorModel) m_model).SetDeleteOnCancel(false);
      String strOpenerFunction = ((IEditMyPortalPageModelRO) m_model).GetParentFormSubmitFunction();
      int nSize = 20;
      if ((strOpenerFunction != null) && (!"".Equals(strOpenerFunction)))
      {
        nSize+=100;
      }
      XPStringBuilder sb = new XPStringBuilder(nSize);
      // Add method to call on opening form, if it exists
      if ((strOpenerFunction != null) && (!"".Equals(strOpenerFunction)))
      {
        sb.Append("  window.opener.").Append(JSHelper.escapeJS(strOpenerFunction)).Append("();\n");
        }
      // We are in a frame, so we need to call parent, not window
      sb.Append("window.close();\n");
      HTMLScript myScript = new HTMLScript("text/javaScript");
      try
      {
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error generating JS for ClosePopUpDP.");
      }
      ClosePopUpDP myClosePopUp = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      myClosePopUp.SetScript(myScript);
      // Close the Tree pop-up
      Redirect myRedirect = new Redirect();
      myRedirect.SetLinkGetCachedSpace(m_asOwner);
      myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      SetRedirect(myRedirect);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorRepostControl#PerformCancelAction()"></seealso>
    protected override void PerformCancelAction()
    {
      // TODO Auto-generated method stub
      base.PerformCancelAction();
      if (!m_asOwner.IsSubSpace() && null == m_rRedirect)
      {
        Redirect result = new Redirect();
        // JF- If the parent space is already in the cache, we redirect to it.
        if (null != m_asOwner.GetParentSpace())
        {
          result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
        } else
        // JF- If not, we redirect to a new one.
        if ((null != m_asOwner.GetParentSpaceName()) && (!"".Equals(m_asOwner.GetParentSpaceName())))
        {
          result.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
          } else
        // If we don't have a parent, just redirect to the mypage
        {
          result.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
          }
        SetRedirect(result);
      }
    }
  }
}