using System;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <summary>
  /// This interface contains the methods on the Object Selection
  /// Model that change the state of the model.  Read Only methods
  /// are on the IObjectSelectionModelRO.
  /// </summary>
  public interface IObjectSelectionModel
  {
    
    /// <summary>
    /// This method is used by the portlet flyout control to switch from browse mode
    /// to search mode.
    /// </summary>
    /// <param name="_bDisplaySearch">whether or not we are in search mode.</param>
    void SetDisplaySearch(bool _bDisplaySearch);
    
    /// <summary>
    /// Sets the index of the object view the page is currently displaying.
    /// Called from the class displaying the different object types.
    /// </summary>
    /// <param name="nObjectViewIndex"></param>
    void SetObjectViewIndex(int nObjectViewIndex);
    
    /// <summary>
    /// This method refreshes the selected objects by requerying for them
    /// on the page.  This should not be necessary in normal operation and
    /// should only be used if the portlets on the page have changed outside
    /// of the editor model (i.e. in the portlet flyout).
    /// </summary>
    void RefreshSelectedObjects();
    
    /// <summary>
    /// Set the first displayable item for pagination in the object selection
    /// model if pagination is used.
    /// </summary>
    /// <param name="_nFirstItem"></param>
    void SetFirstDisplayableItem(int _nFirstItem);
    
    /// <summary>
    /// Set the number of items per page for pagination in the object selection
    /// model if pagination is used.
    /// </summary>
    /// <param name="_nItemsPerPage"></param>
    void SetItemsPerPage(int _nItemsPerPage);
  }
}