using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>michaeld</author>
  public interface IObjectSelectionModelHelper
  {
    
    /// <summary>
    /// Add a unique input to the form input hash table.
    /// </summary>
    /// <param name="htFormData"></param>
    /// <param name="IASQueryResult">asqr</param>
    /// <param name="itn">nObjectViewIndex</param>
    void AddFormInputsForEachObject(XPHashtable htFormData, IASQueryResult asqr,
     int nObjectViewIndex);
    
    /// <summary>
    /// Get object IDs of object not to show in the object selection.
    /// </summary>
    /// <param name="ObjectSelectionModel">model</param>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>XPSortedDictionary</returns>
    XPSortedDictionary GetDoNotShowObjectIDs(ObjectSelectionModel model, int nObjectViewIndex);
    
    /// <summary>
    /// Returns the strings for the headers.
    /// </summary>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>String[]</returns>
    String[] GetHeaders(int nObjectViewIndex);
    
    /// <summary>
    /// Returns the number of object views this model must display.
    /// </summary>
    /// <returns>int</returns>
    int GetNumObjectViews();
    
    /// <summary>
    /// Get the banner title for the object banner.
    /// </summary>
    /// <param name="String">strCurrentFolderName</param>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>String</returns>
    String GetObjectBannerTitle(String strCurrentFolderName, int nObjectViewIndex);
    
    /// <summary>
    /// Gets the object input name
    /// </summary>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>String strObjectInputName</returns>
    String GetObjectInputName(int nObjectViewIndex);
    
    /// <summary>
    /// Gets the an object manager.
    /// </summary>
    /// <param name="IPTSession">ptSession</param>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>IPTObjectManager</returns>
    IPTObjectManager GetObjectMan(IPTSession ptSession, int nObjectViewIndex);
    
    /// <summary>
    /// Gets the object type.
    /// </summary>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>int nObjectType</returns>
    int GetObjectType(int nObjectViewIndex);
    
    /// <summary>
    /// Gets a queryresult of the objects to display.  Used instead of
    /// IPTObjectManager GetObjects when  displaying non managed objects.
    /// </summary>
    /// <param name="IPTSession">ptSession</param>
    /// <param name="IPTAdminFolder">ptFolder</param>
    /// <returns>ASQueryResult</returns>
    IASQueryResult GetObjects(IPTSession ptSession, IPTAdminFolder ptFolder);
    
    /// <summary>
    /// Gets the property IDs to query for.
    /// </summary>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>int nPropIDs</returns>
    int GetPropIDsToQuery(int nObjectViewIndex);
    
    /// <summary>
    /// Get query filter to use when query for selectable objects. The use of the first column
    /// of thise array, [0][0] - [2][0], is reserved for use by ObjectSelectionModel. Start adding filters to the
    /// array at [0][1] - [2][1].
    /// </summary>
    /// <param name="ObjectSelectionModel">model</param>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>Object[][] oQueryFilter</returns>
    Object[][] GetQueryFilter(ObjectSelectionModel model, int nObjectViewIndex);
    
    /// <summary>
    /// Get the redirect for after the editor has finished.
    /// </summary>
    /// <param name="ObjectSelectionModel">model</param>
    /// <param name="int">nObjectViewIndex</param>
    /// <returns>Redirect</returns>
    Redirect GetRedirectAfterFinish(ObjectSelectionModel model);
    
    /// <summary>
    /// Get the title for the search header.
    /// </summary>
    /// <returns>String</returns>
    String GetSearchHeaderTitle();
    
    /// <summary>
    /// Gets the information to store in the selected dictionary.
    /// </summary>
    /// <param name="nIndex"></param>
    /// <param name="ASQueryResult"></param>
    /// <returns>Object[]</returns>
    Object[] GetSelectedInfo(int nIndex, IASQueryResult asqr);
    
    /// <summary>
    /// Get the selected objects
    /// </summary>
    /// <param name="ObjectSelectionModel">model</param>
    /// <returns>Object[][]</returns>
    Object[][] GetSelectedObjects(ObjectSelectionModel model);
    
    /// <summary>
    /// Returns whether the model should save the page on repost.
    /// Currently only community pages returns false.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetShouldSavePage();
    
    /// <summary>
    /// Returns whether the object selection page should start in search mode.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetStartInSearch();
    
    /// <summary>
    /// Initialize the form input hash table.
    /// </summary>
    /// <param name="htFormData"></param>
    void InitializeFormInputs(XPHashtable htFormData);
    
    /// <summary>
    /// Set the selected objects. This may involve in sending them to a parent
    /// editor to be set, or actually setting them here.
    /// </summary>
    /// <param name="ObjectSelectionModel">model</param>
    /// <param name="xpsdOldSelectedObjects">xpsdOldSelectedObjects</param>
    /// <param name="xpsdNewSelectedObjects">xpsdNewSelectedObjects</param>
    void SetSelectedObjects(ObjectSelectionModel model, XPSortedDictionary xpsdOldSelectedObjects,
     XPSortedDictionary xpsdNewSelectedObjects);
    
    /// <param name="nSearch508StringIndex">is the index of the message files index</param>
    /// <returns>the index of the string in the message file from the index passed in</returns>
    int Get508SearchStringMsgIndex(int nSearch508StringIndex);
  }
}