using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.search;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>michaeld</author>
  public interface IObjectSelectionModelRO : IObjectModelRO
  {
    
    /// <summary>
    /// This method returns a 2d query result with folder level, id, and name.
    /// </summary>
    /// <returns>IASQueryResult</returns>
    IASQueryResult GetBreadCrumbPath();
    
    /// <summary>
    /// Returns true if we need to display the search results view.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetDisplaySearch();
    
    /// <summary>
    /// Returns the value of the given input.
    /// </summary>
    /// <param name="String">strInput</param>
    /// <returns>String strValue</returns>
    String GetInputValue(String strInput);
    
    /// <summary>
    /// Get wether we can select multiple or single.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetMultipleSelect();
    
    /// <summary>
    /// Get the name of the parent window's form.
    /// </summary>
    /// <returns>String</returns>
    String GetParentFormName();
    
    /// <summary>
    /// Get the name of the form element for selected items.
    /// </summary>
    /// <returns>String</returns>
    String GetParentFormSelectedItems();
    
    /// <summary>
    /// Get the string that is the parent form space ID.
    /// </summary>
    /// <returns>String</returns>
    String GetParentFormSpaceID();
    
    /// <summary>
    /// Get the string that is the parent form submit function.
    /// </summary>
    /// <returns>String</returns>
    String GetParentFormSubmitFunction();
    
    /// <summary>
    /// Returns true if a search has been initialized.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetSearchStarted();
    
    /// <summary>
    /// Returns the Search Setting Collection.
    /// </summary>
    /// <returns>SearchSettingCollection</returns>
    SearchSettingCollection GetSearchSettingCollection();
    
    /// <summary>
    /// Get the selected names as a string.
    /// </summary>
    /// <returns>String strSelectedNames</returns>
    String GetSelectedNamesAsString();
    
    /// <summary>
    /// Get the selector's class ID.
    /// </summary>
    /// <returns>int nSelectorClassID</returns>
    int GetSelectorClassID();
    
    /// <summary>
    /// Get the selector's community folder ID.
    /// </summary>
    /// <returns>int nSelectorCommunityFolderID</returns>
    int GetSelectorCommunityFolderID();
    
    /// <summary>
    /// Get the selector's community  ID.
    /// </summary>
    /// <returns>int nSelectorCommunityID or 0 if not in a community</returns>
    int GetSelectorCommunityID();
    
    /// <summary>
    /// Get the selector's object ID.
    /// </summary>
    /// <returns>int nSelectorObjectID</returns>
    int GetSelectorObjectID();
    
    /// <summary>
    /// Get the selector's page ID.
    /// </summary>
    /// <returns>int nSelectorPageID</returns>
    int GetSelectorPageID();
    
    /// <summary>
    /// Get the id for object in the invitation pop-up.
    /// </summary>
    /// <returns>int</returns>
    int GetTemporaryInvitationID();
    
    /// <summary>
    /// Get the name for object in the invitation pop-up.
    /// </summary>
    /// <returns>String</returns>
    String GetTemporaryInvitationName();
    
    /// <summary>
    /// Get whether or not to show an object given the objectID
    /// </summary>
    /// <param name="nObjectID"></param>
    /// <returns>boolean</returns>
    bool DoNotShowObjectWithID(int nObjectID);
    
    /// <summary>
    /// Initializes the model. 
    /// Normally just called by the Interpreter, but used by the PortletDataTag when this model
    /// is run in delayed initialization mode.
    /// </summary>
    /// <param name="htFormData"></param>
    /// <returns></returns>
    bool CheckEditorAccessAndStart(XPHashtable htFormData);
    
    /// <summary>
    /// Gets the current property id that the model is ordered by.
    /// </summary>
    /// <returns></returns>
    int GetSortPropertyId();
    bool IsHomeMyPage();
    bool IsMyPage();
    bool IsCommunityPage();
    bool IsPageTemplate();
    
    /// <summary>
    /// Get the first displayable item for pagination in the object selection
    /// model if pagination is used.
    /// </summary>
    /// <returns>the first displayable item.</returns>
    int GetFirstDisplayableItem();
    
    /// <summary>
    /// Get the number of items per page for pagination in the object selection
    /// model if pagination is used.
    /// </summary>
    /// <returns>the number of items per page.</returns>
    int GetItemsPerPage();
    
    /// <summary>
    /// Get the total number of items for pagination in the object selection
    /// model if pagination is used.
    /// This includes all object types currently being displayed.
    /// </summary>
    /// <returns>the total number of items.</returns>
    int GetTotalItems();
  }
}