using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>michaeld</author>
  public class ObjSelFolderViewHelper : IFolderViewHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.ObjSelFolderViewHelper");
    // Query parameter name for the checkbox
    public const String QS_CHECKBOX = "in_cb_checkbox";
    
    /// <summary>
    /// Javascript function: openFolder 
    /// </summary>
    public const String JAVASCRIPT_OPEN_FOLDER = "openFolder";
    
    /// <summary>
    /// HTML Input hidden: Open Folder ID 
    /// </summary>
    public const String HTMLINPUT_OPENFOLDERID = "in_hi_openFolderID";
    private int m_nRepostAction = 0;
    public ObjSelFolderViewHelper()
    {
      m_nRepostAction = ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER;
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayFolder(int,HTMLTableCell,IFolderModelRO,AActivitySpace)"></seealso>
    public virtual int DisplayFolder(int nFolderIndex, HTMLTableCell tableCell,
     IFolderModelRO model, AActivitySpace space)
    {
      try
      {
        // get the folder query
        IASQueryResult qrFolders = model.GetFolderQueryResult();
        int nIndex = nFolderIndex;
        // get name, folder ID, and folder URL from query
        String strName = (String) qrFolders.GetFields(nIndex, PT_PROPIDS.PT_PROPID_NAME);
        int nFolderID = XPConvert.ToInteger(qrFolders.GetFields(nIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
        int nFolderType = XPConvert.ToInteger(qrFolders.GetFields(nIndex,
         PT_PROPIDS.PT_PROPID_FOLDER_FOLDERTYPE));
        String strFolderID = XPConvert.ToString(nFolderID);
        // Open folder URL
        HTMLAnchor myAnchor;
        if (AccessStyles.STANDARD != space.GetAccessStyle())
        {
          ASURL myAsurl = ((AFormDP) space.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
          myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
           nFolderID);
          myAsurl.AddInnerHTMLEncodedString(strName);
          myAnchor = (HTMLAnchor) myAsurl.GetURLAsHTMLElement();
        } else
        {
          myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strName),
           JAVASCRIPT_OPEN_FOLDER + "(\'" + strFolderID + "\')");
        }
        // use list item construct
        UIListItem itemConstruct = new UIListItem(myAnchor, space);
        if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER)
        {
          itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_COMMUNITY,
           space.GetString(1781, "ptmsgs_portalbrowsingmsgs"));
        } else
        {
          itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER, space.GetString(1782,
           "ptmsgs_portalbrowsingmsgs"));
        }
        itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
        // convert the construct to table
        try
        {
          HTMLTable folderTable = itemConstruct.GetItemAsTable();
          tableCell.AddInnerHTMLElement(folderTable);
        }
        catch (Exception e)
        {
          log.Error(e, "Error in ObjSelFolderViewHelper::DisplayFooter: ");
          }
        nFolderIndex++;
      }
      catch (Exception e)
      {
        log.Error("Couldn\'t retrieve folder at " + nFolderIndex);
      }
      return nFolderIndex;
    }
    
    /// <param name="asOwner"></param>
    /// <returns></returns>
    public virtual HTMLScript DisplayJavascript(AActivitySpace asOwner)
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n").Append("function ").Append(JAVASCRIPT_OPEN_FOLDER).Append("(folderID)\n").Append("{\n").Append("\t\tif (document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE).Append(") {\n").Append("\t\t\tdocument.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE).Append(".value = \'false\';\n").Append("\t\t}\n").Append("\t\tdocument.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_OPENFOLDERID).Append(".value = folderID;\n").Append("\t\tpostToSelf(\'").Append(m_nRepostAction).Append("\');\n").Append("}\n");
      try
      {
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript: Failed to add \'openFolder\' javascript function to page. " + he.Message);
        }
      return script;
    }
    
    /// <param name="strControlName"></param>
    public virtual void SetControlName(String strControlName)
    {
    }
    
    /// <param name="nRepostAction"></param>
    public virtual void SetRepostAction(int nRepostAction)
    {
      m_nRepostAction = nRepostAction;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int)
     */
     
    public virtual void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID,
     IFolderModelRO _model, AActivitySpace _space)
    {
      if (AccessStyles.STANDARD != _space.GetAccessStyle())
      {
        ASURL myAsurl = ((AFormDP) _space.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
        myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
         _nFolderID);
        _anchor.SetHRef(myAsurl.GetURLAsString());
      } else
      {
        _anchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
        _anchor.SetOnClick(ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "(\'" + _nFolderID + "\');return false;");
        }
    }
  }
}