using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>michaeld</author>
  public class ObjSelSearch508BodyView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.ObjSelSearch508BodyView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjSelSearch508Body";
    private AActivitySpace m_asOwner;
    private IObjectSelectionModelRO m_asModel;
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
     */
     
    public virtual HTMLElement Display()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      SearchResultModel searchModel = ((SearchResultModel) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME));
      SearchExecutionError error = searchModel.GetError();
      if (error == null)
      {
        log.Debug("Displaying 508 search results.");
        HTMLTable table = new HTMLTable();
        collection.AddInnerHTMLElement(table);
        table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        table.SetCellPadding("5");
        table.SetBorder(CommonHTMLStrings.ZERO);
        table.SetCellSpacing(CommonHTMLStrings.ZERO);
        HTMLTableRow row = new HTMLTableRow();
        table.AddInnerHTMLElement(row);
        row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
        HTMLTableCell cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetVAlign(CommonHTMLStrings.TOP);
        cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        int totalItems = searchModel.GetTotalItems();
        String strSearch = searchModel.GetSearchString();
        int drilldownDepth = searchModel.GetDrilldownDepth();
        IObjectSelectionModelHelper helper = ((ObjectSelectionModel) m_asModel).GetSelectionModelHelper();
        if (null == strSearch || ("*").Equals(strSearch))
        {
          // Total results
          if (drilldownDepth > 1)
          {
            cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(helper.Get508SearchStringMsgIndex(Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_IN_THIS_FOLDER),
             "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(totalItems)));
            } else
          {
            cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(helper.Get508SearchStringMsgIndex(Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_AVAILABLE),
             "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(totalItems)));
            }
        } else
        {
          // Search string
          cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1775,
           "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strSearch)));
          cell.AddInnerHTMLElement(new HTMLBr());
          // Total results from search
          if (drilldownDepth > 1)
          {
            cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1780,
             "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(totalItems),
             XPHttpUtility.HtmlEncode(searchModel.GetBreadcrumbLabel(drilldownDepth))));
            } else
          {
            cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1774,
             "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(totalItems)));
            }
        }
        cell.AddInnerHTMLElement(new HTMLBr());
        // Add a message like "Displaying 1 through 10."
        if (searchModel.GetNumDisplayableItems() < totalItems)
        {
          cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1772,
           "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(searchModel.GetFirstDisplayableItem()),
           XPConvert.ToString((searchModel.GetFirstDisplayableItem() + searchModel.GetNumDisplayableItems()) - 1)));
          }
        collection.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        collection.AddInnerHTMLElement(m_asOwner.GetView(GroupedResultsView.STR_MVC_CLASS_NAME).Display());
        if ((searchModel.GetNumDisplayableItems() < searchModel.GetTotalItems()) && (0 == searchModel.GetNumResultGroups()))
        {
          collection.AddInnerHTMLElement(m_asOwner.GetView(SearchFooterView.STR_MVC_CLASS_NAME).Display());
          }
      } else
      {
        HTMLSpan mySpan = new HTMLSpan();
        collection.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
        mySpan.AddInnerHTMLString(error.GetMessage());
        collection.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        }
      return collection;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
     
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
     */
     
    public virtual void Init(IModelRO arg0, AActivitySpace arg1)
    {
      m_asOwner = arg1;
      m_asModel = (IObjectSelectionModelRO) arg0;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public virtual Object Create()
    {
      return new ObjSelSearch508BodyView();
    }
  }
}