using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>MichaelD</author>
  public class ObjSelSearchHeaderView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.ObjSelSearchHeaderView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjSelSearchHeader";
    private AActivitySpace m_asOwner;
    private IObjectSelectionModelRO m_asModel;
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public virtual Object Create()
    {
      return new ObjSelSearchHeaderView();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
     */
     
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = null;
      HTMLElementCollection collection = new HTMLElementCollection();
      PTConstruct construct;
      try
      {
        if (AccessStyles.STANDARD != m_asOwner.GetAccessStyle())
        {
          construct = UIConstructFactory.GetConstruct(PTBannerType.WIDE_508);
          HTMLTable table = new HTMLTable();
          collection.AddInnerHTMLElement(table);
          table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          HTMLTableRow row = new HTMLTableRow();
          table.AddInnerHTMLElement(row);
          HTMLTableCell cell = new HTMLTableCell();
          row.AddInnerHTMLElement(cell);
          // Simple Drill Down - View by Subfolder
          cell.AddInnerHTMLElement(ReorganizationViewHelper.DisplaySimpleDrilldownView((ISearchResultModelRO) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME),
           m_asOwner));
          // Browse All Folders Link
          cell = new HTMLTableCell();
          row.AddInnerHTMLElement(cell);
          cell.SetAlign(CommonHTMLStrings.RIGHT);
          cell.AddInnerHTMLElement(GetBrowseAllFoldersLink());
          // Spacer Table
          collection.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
          SearchResultModel searchModel = ((SearchResultModel) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME));
          SearchExecutionError error = searchModel.GetError();
          if (error == null)
          {
            int drilldownDepth = searchModel.GetDrilldownDepth();
            if (drilldownDepth > 1)
            {
              construct.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE_508.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
               XPResourceManager.FormatMessage(m_asOwner.GetString(((ObjectSelectionModel) m_asModel).GetSelectionModelHelper().Get508SearchStringMsgIndex(Search508StringIndexConstants.N_OBJECTS_IN_BLANK),
               "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(searchModel.GetBreadcrumbLabel(drilldownDepth))));
              } else
            {
              construct.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE_508.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
               ((ObjectSelectionModel) m_asModel).GetSelectionModelHelper().GetSearchHeaderTitle());
              }
          } else
          {
            construct.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE_508.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
             ((ObjectSelectionModel) m_asModel).GetSelectionModelHelper().GetSearchHeaderTitle());
            }
        } else
        {
          construct = UIConstructFactory.GetConstruct(PTBannerType.WIDE);
          construct.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
           ((ObjectSelectionModel) m_asModel).GetSelectionModelHelper().GetSearchHeaderTitle());
          try
          {
            // MJD: Don't display if this isn't a community page.
            // MJD: or in the community's folder
            if (m_asModel.IsCommunityPage() && m_asModel.GetSelectorCommunityFolderID() != ((ObjectSelectionModel) m_asModel).GetCurrentFolderID())
            {
              // Insert the "This Community's Portlets" button.
              construct.AddElementToNestedElement(PTBannerType.WIDE.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
               GetThisCommunitysPortletsButton());
            }
            // Insert the "Browse All Folders" button.
            construct.AddElementToNestedElement(PTBannerType.WIDE.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
             GetBrowseAllFoldersButton());
          }
          catch (Exception e)
          {
            log.Error(e, "PageDisplay: Browse All Folders button creation failed.");
            }
        }
        collection.AddInnerHTMLElement(construct.GetHTMLElement());
        result = collection;
      }
      catch (Exception e)
      {
        log.Error(e, "PageDisplay: Object Selection Folders banner creation failed.");
        }
      return result;
    }
    
    /// <returns>An HTMLElement which is the "This Community's Portlets" button.</returns>
    private HTMLElement GetThisCommunitysPortletsButton()
    {
      //	Get a button construct
      PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP);
      myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE),
       m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs"));
      ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(733,
       "ptmsgs_portalbrowsingmsgs"));
      ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(733,
       "ptmsgs_portalbrowsingmsgs"));
      HTMLAnchor myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_ANCHOR));
      myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
      myAnchor.SetOnClick(ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "(\'" + m_asModel.GetSelectorCommunityFolderID() + "\');return false;");
      myAnchor.SetTitle(m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs"));
      return myButtonConstruct.GetHTMLElement();
    }
    
    /// <returns>An HTMLElement which is the "Browse All Folders" button.</returns>
    private HTMLElement GetBrowseAllFoldersButton()
    {
      //	Get a button construct
      PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP);
      myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE),
       m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
      ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564,
       "ptmsgs_portalbrowsingmsgs"));
      ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564,
       "ptmsgs_portalbrowsingmsgs"));
      HTMLAnchor myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_ANCHOR));
      myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
      myAnchor.SetOnClick(ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "(\'" + PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER + "\');return false;");
      myAnchor.SetTitle(m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
      return myButtonConstruct.GetHTMLElement();
    }
    
    /// <returns>An HTMLElement which is the "Browse All Folders" link.</returns>
    private HTMLElement GetBrowseAllFoldersLink()
    {
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);
      HTMLAnchor anchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
      span.AddInnerHTMLElement(anchor);
      anchor.SetTitle(m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
      anchor.AddInnerHTMLString(m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
      // Get 508 Browse All Folders URL
      ASURL myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
      myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
       PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
      anchor.SetHRef(myAsurl.GetURLAsString());
      return span;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
     
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
     */
     
    public virtual void Init(IModelRO arg0, AActivitySpace arg1)
    {
      m_asOwner = arg1;
      m_asModel = (IObjectSelectionModelRO) arg0;
    }
  }
}