using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection.portlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <summary>
  /// Handle reposts for the Object Selection Model.
  /// </summary>
  public class ObjectSelectionRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.ObjectSelectionRepostControl");
    public const String STR_MVC_CLASS_NAME = "ObjectSelectRepost";
    // These two should be used together or not at all.
    // The name of the parent form that you would like the data passed back to.
    public const String strPARENT_FORM_NAME = "Form";
    // The name of the input in the parent form that you would like the AActivitySpace
    // ID of the tree space put into.
    public const String strPARENT_FORM_SPACE_ID = "Input";
    // The name of the javascript function in the parent page to call when the tree
    // is submitted.  This should not include the '();'.
    // In Javascript submit mode this method should take an array argument which will
    // be made up of objects with name, ObjectID, and ClassID member variables.
    // see ATreeAS for details.
    public const String strPARENT_SUBMIT_CALL = "Submit";
    public const int POSTTOSELF_ACTION_MISC = 10;
    
    /// <summary>
    /// Post to self after adding portlets from a bundle 
    /// </summary>
    public const int POSTTOSELF_ACTION_ADDPORTLETS_FROMBUNDLE = 40;
    
    /// <summary>
    /// Post to self to select portlet bundle 
    /// </summary>
    public const int POSTTOSELF_ACTION_SELECT_BUNDLE = 41;
    
    /// <summary>
    /// Post to self to open a folder by way of folder view or breadcrumbs 
    /// </summary>
    public const int POSTTOSELF_ACTION_OPENFOLDER = 42;
    
    /// <summary>
    /// Post to self to add a object using the 508 UI 
    /// </summary>
    public const int POSTTOSELF_508_ACTION_ADDOBJECT = 43;
    
    /// <summary>
    /// Post to self to remove a object using the 508 UI 
    /// </summary>
    public const int POSTTOSELF_508_ACTION_REMOVEOBJECT = 44;
    
    /// <summary>
    /// Post to self to add all portlets from a bundle. 
    /// </summary>
    public const int POSTTOSELF_508_ACTION_ADDBUNDLE = 45;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjectSelectionRepostControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call  the associated method for each
    /// action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      switch (_nAction){
      //POSTTOSELF_ACTION_UNDEFINED:
      case -1:
      ((ObjectSelectionModel) m_model).RepostToSearch();
      break;
      case POSTTOSELF_ACTION_ADDPORTLETS_FROMBUNDLE:
      ((ObjectSelectionModel) m_model).RepostAddPortletsFromBundle();
      break;
      case POSTTOSELF_ACTION_SELECT_BUNDLE:
      ((ObjectSelectionModel) m_model).RepostSelectPortletBundle();
      break;
      case POSTTOSELF_ACTION_OPENFOLDER:
      ((ObjectSelectionModel) m_model).RepostOpenFolder();
      break;
      case POSTTOSELF_508_ACTION_ADDOBJECT:
      ((ObjectSelectionModel) m_model).RepostAddObject();
      break;
      case POSTTOSELF_508_ACTION_REMOVEOBJECT:
      ((ObjectSelectionModel) m_model).RepostRemoveObject();
      break;
      }
    }
    
    /// <summary>
    /// This method is called when we finish a sub Editor.
    /// It takes care of closing the sub Editor pop-up winodws
    /// and repost the main Editor window.
    /// </summary>
    protected override void SetRedirectToCloseSubEditor()
    {
      ((EditorModel) m_model).SetDeleteOnCancel(false);
      String strOpenerFunction = ((IObjectSelectionModelRO) m_model).GetParentFormSubmitFunction();
      int nSize = 20;
      if ((strOpenerFunction != null) && (!"".Equals(strOpenerFunction)))
      {
        nSize+=100;
      }
      XPStringBuilder sb = new XPStringBuilder(nSize);
      // Add method to call on opening form, if it exists
      if ((strOpenerFunction != null) && (!"".Equals(strOpenerFunction)))
      {
        // strOpenerFunction should just be the method name, so escaping it will
        // prevent cross-site scripting hacks.
        sb.Append("  parent.opener.").Append(JSHelper.escapeJS(strOpenerFunction)).Append("();\n");
        }
      // We are in a frame, so we need to call parent, not window
      sb.Append("parent.close();\n");
      HTMLScript myScript = new HTMLScript("text/javaScript");
      try
      {
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error generating JS for ClosePopUpDP.");
      }
      ClosePopUpDP myClosePopUp = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      myClosePopUp.SetScript(myScript);
      // Close the Tree pop-up
      Redirect myRedirect = new Redirect();
      myRedirect.SetLinkGetCachedSpace(m_asOwner);
      myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      SetRedirect(myRedirect);
    }
    
    /// <summary>
    /// Helper method to implement the Cancel action.
    /// On cancel, we just redirect to whatever is
    /// returned by GetRedirectAfterFinish.
    /// If this is a sub Editor in Create mode we also
    /// delete the sub Editor from the list. And then we
    /// close the pop-up.
    /// </summary>
    protected override void PerformCancelAction()
    {
      ((EditorModel) m_model).Cancel();
      if (m_asOwner.IsSubSpace())
      {
        if (((EditorModel) m_model).GetDeleteOnCancel())
        {
          m_asOwner.GetParentSpace().DeleteSubSpace(m_asOwner.GetSubSpaceKey());
          }
        Redirect myRedirect = new Redirect();
        myRedirect.SetLinkGetCachedSpace(m_asOwner);
        ClosePopUpDP myClosePopUpDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
        if (m_asOwner.GetName().Equals(PortletSelectionEditorAS.STR_MVC_CLASS_NAME))
        {
          myClosePopUpDP.SetToClose(false);
          HTMLScript script = new HTMLScript("text/javaScript");
          script.AddInnerHTMLString("parent.close();");
          myClosePopUpDP.SetScript(script);
        } else
        {
          myClosePopUpDP.SetToClose(true);
          myClosePopUpDP.SetScript(null);
        }
        myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
        SetRedirect(myRedirect);
      } else
      {
        base.PerformCancelAction();
      }
    }
  }
}