using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>michaeld</author>
  public class ObjectSelectionView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.ObjectSelectionView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjectSelection";
    
    /// <summary>
    /// Form Input: Object radio button 
    /// </summary>
    public const String HTMLINPUT_SELECTION_RA_OBJECT = "in_ra_Object";
    
    /// <summary>
    /// Form Input: Object checkbox 
    /// </summary>
    public const String HTMLINPUT_SELECTION_CB_OBJECT = "in_cb_Object";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private IObjectSelectionModelRO m_asmModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ObjectSelectionView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      HTMLElement myElement = collection;
      try
      {
        HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
         "");
        collection.AddInnerHTMLElement(myInput);
      }
      catch (HTMLException he)
      {
        log.Error(he, "Display(): Failed to add selected objects input to collection.");
        }
      return myElement;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript result = null;
      // Set up parent form space ID
      String strSpaceIDInput = m_asmModel.GetParentFormSpaceID();
      XPStringBuilder sb = new XPStringBuilder(100);
      // Onload method to set the Space ID
      if ((strSpaceIDInput != null) && (!"".Equals(strSpaceIDInput)))
      {
        sb.Append("parent.opener.").Append(JSHelper.escapeJS(m_asmModel.GetParentFormName())).Append(".").Append(JSHelper.escapeJS(strSpaceIDInput)).Append(".value= ").Append(m_asOwner.GetSpaceID()).Append(";\n");
        sb.Append("\n");
      }
      try
      {
        result = new HTMLScript("text/javaScript");
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element.");
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asmModel = (IObjectSelectionModelRO) model;
      m_asOwner = parent;
    }
  }
}