using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>
  /// MichaelD
  /// This control is used to re-open a previously opened object selection and
  /// refresh the contents (which objects are selected, etc...).
  /// </author>
  public class RefreshObjSelControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.RefreshObjSelControl");
    
    /// <summary>
    /// name of the refresh object selection control 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "RefreshObjSel";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Internal data *
    /// </summary>
    protected ObjectSelectionModel m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // MJD- On each repost we check if the user has the rights to be in this Editor.
      if (!((EditorModel) m_asModel).GetUserHasAccessToEditor())
      {
        Redirect myRedirectToLogin = new Redirect();
        myRedirectToLogin.SetIsErrorRedirect(true);
        myRedirectToLogin.SetLinkCreateNewSpace(m_asOwner.GetName(), m_asOwner);
        myRedirectToLogin.SetControl(STR_MVC_CLASS_NAME);
        myRedirectToLogin.AddControlArguments(arguments);
        return myRedirectToLogin;
      }
      // DCA - Perform check to see if we want to update the bottom frame
      if (arguments.ContainsKey(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKOBJECTID))
      {
        String strObjectID = null;
        String strAlignment = null;
        String strName = null;
        strObjectID = ((String[]) arguments.GetElement(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKOBJECTID))[0];
        if (arguments.ContainsKey(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKALIGNMENT))
        {
          strAlignment = ((String[]) arguments.GetElement(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKALIGNMENT))[0];
          }
        if (arguments.ContainsKey(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKNAME))
        {
          strName = ((String[]) arguments.GetElement(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKNAME))[0];
          }
        if (strName != null)
        {
          m_asModel.AddNewlySelected(strObjectID, strAlignment, strName);
          } else
        {
          m_asModel.RemoveObject(strObjectID);
        }
      } else
      {
        m_asModel.RefreshObjectSelection();
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new RefreshObjSelControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      try
      {
        m_asModel = (ObjectSelectionModel) model;
      }
      catch (Exception e)
      {
        log.Error(e, "RefreshObjSelControl::Init Unable to cast the Object " + model + " to ObjectSelectionModel. The following exception occured: " + e.Message);
        // JF- No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + model + " to ObjectSelectionModel.",
         e);
      }
      m_asOwner = space;
    }
  }
}