using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection
{
  /// <author>michaeld</author>
  public class SelectedObjectsView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.SelectedObjectsView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SelectedObjects";
    
    /// <summary>
    /// JS function to refresh the page.
    /// </summary>
    public const String JAVASCRIPT_REFRESH = "refresh";
    
    /// <summary>
    /// Javascript Function: addNewlySelected 
    /// </summary>
    public const String JAVASCRIPT_ADD_SELECTED = "addNewlySelected";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private IObjectSelectionModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SelectedObjectsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      try
      {
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding("5");
        // Row for You have selected:
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetHeight("20");
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_SUBHEAD);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(746, "ptmsgs_portalbrowsingmsgs"));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetHeight("25");
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myCell.AddInnerHTMLEncodedString(m_model.GetSelectedNamesAsString());
        }
      catch (HTMLException he)
      {
        log.Error(he, "Display: Failed to display the selected objects\'s names. " + he.Message);
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      ASURL viewSelectedURL = new ASURL(m_asOwner);
      viewSelectedURL.SetLinkGetCachedSpace(m_asOwner);
      viewSelectedURL.SetDisplayPage(SelectedObjectsDP.STR_MVC_CLASS_NAME);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n");
      sb.Append("function ").Append(JAVASCRIPT_REFRESH).Append("()\n");
      sb.Append("{\n");
      sb.Append("  window.location = \'").Append(viewSelectedURL.GetURLAsString()).Append("\';\n");
      sb.Append("}\n");
      // DCA - javascript to encode non-sjis characters
      sb.Append("function my_hex(n, len) {\n");
      sb.Append("\tvar out, i;\n");
      sb.Append("\tout = \"\";\n");
      sb.Append("\tfor(i = 0; i < len; i++) {\n");
      sb.Append("\t\tout = \"0123456789ABCDEF\".charAt(n & 0xf) + out;\n");
      sb.Append("\t\tn >>= 4;\n");
      sb.Append("\t}\n");
      sb.Append("\treturn out;\n");
      sb.Append("}\n");
      sb.Append("function my_escape(str) {\n");
      sb.Append("\tvar c, i, out;\n");
      sb.Append("\tout = \"\";\n");
      sb.Append("\tfor(i = 0; i < str.length; i++) {\n");
      sb.Append("\t\tc = str.charAt(i);\n");
      sb.Append("\t\tif(c.match(/[^.0-9A-Z_a-z-]/)) {\n");
      sb.Append("\t\t\tc = str.charCodeAt(i);\n");
      sb.Append("\t\t\tif(c < 256)\n");
      sb.Append("\t\t\t\tout += \"%\" + my_hex(c, 2);\n");
      sb.Append("\t\t\telse\n");
      sb.Append("\t\t\t\tout += \"%u\" + my_hex(c, 4);\n");
      sb.Append("\t\t} else\n");
      sb.Append("\t\t\tout += c;\n");
      sb.Append("\t}\n");
      sb.Append("\treturn out;\n");
      sb.Append("}\n");
      sb.Append("function utf16to8(str) {\n");
      sb.Append("\tvar out, i, len, c;\n");
      sb.Append("\tout = \"\";\n");
      sb.Append("\tlen = str.length;\n");
      sb.Append("\tfor(i = 0; i < len; i++) {\n");
      sb.Append("\t\tc = str.charCodeAt(i);\n");
      sb.Append("\t\tif ((c >= 0x0001) && (c <= 0x007F)) {\n");
      sb.Append("\t\t\tout += str.charAt(i);\n");
      sb.Append("\t\t} else if (c > 0x07FF) {\n");
      sb.Append("\t\t\tout += String.fromCharCode(0xE0 | ((c >> 12) & 0x0F));\n");
      sb.Append("\t\t\tout += String.fromCharCode(0x80 | ((c >>  6) & 0x3F));\n");
      sb.Append("\t\t\tout += String.fromCharCode(0x80 | ((c >>  0) & 0x3F));\n");
      sb.Append("\t\t} else {\n");
      sb.Append("\t\t\tout += String.fromCharCode(0xC0 | ((c >>  6) & 0x1F));\n");
      sb.Append("\t\t\tout += String.fromCharCode(0x80 | ((c >>  0) & 0x3F));\n");
      sb.Append("\t\t}\n");
      sb.Append("\t}\n");
      sb.Append("\treturn out;\n");
      sb.Append("}\n");
      // DCA - javascript function to refresh bottom frame w/ newly added or removed object
      viewSelectedURL = new ASURL(m_asOwner);
      viewSelectedURL.SetLinkGetCachedSpace(m_asOwner);
      viewSelectedURL.SetDisplayPage(SelectedObjectsDP.STR_MVC_CLASS_NAME);
      viewSelectedURL.SetControl(RefreshObjSelControl.STR_MVC_CLASS_NAME);
      viewSelectedURL.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKOBJECTID);
      sb.Append("function ").Append(JAVASCRIPT_ADD_SELECTED).Append("(objID, alignment, name, bselect)\n");
      sb.Append("{\n");
      sb.Append("\t name = my_escape(utf16to8(name));\n");
      sb.Append("  var address = \'").Append(viewSelectedURL.GetURLAsString()).Append("\' + objID; \n");
      sb.Append("\t \tif (bselect) {\n");
      sb.Append(" \t\taddress = address + \'&").Append(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKALIGNMENT).Append("=\' + alignment + \'&").Append(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKNAME).Append("=\' + name;\n");
      sb.Append("\t\t}\n");
      sb.Append("  window.location = address;\n");
      sb.Append("}\n");
      HTMLScript result = new HTMLScript("text/javaScript");
      try
      {
        result.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add javascript to the HTMLScript element.");
        return null;
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IObjectSelectionModelRO) model;
      m_asOwner = parent;
    }
  }
}