using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection.communities
{
  /// <author>MichaelD</author>
  public class CommSelGroupedResults508ViewHelper : IGroupedResultsViewHelper
  {
    protected AActivitySpace m_asOwner = null;
    protected ISearchResultModelRO m_model = null;
    protected GroupedResultsView m_view = null;
    protected const String CELL_HEIGHT = "25";
    protected const String LOW_CELL_HEIGHT = "20";
    protected XPDateFormat m_dateFormat = null;
    /* i had to remove final from the declaration above and move it into the
     * constructor in order to get the JUMP to .NET process to work correctly.
     * If this is a big problem for you, please, let me know and we will figure
     * something out.
     * 		-- moose
     */
     
    public CommSelGroupedResults508ViewHelper()
    {
    }
    public virtual void Init(AActivitySpace _owner, ISearchResultModelRO _model,
     GroupedResultsView _view)
    {
      m_asOwner = _owner;
      m_model = _model;
      m_view = _view;
      m_dateFormat = _model.GetDateFormat(m_asOwner);
    }
    
    /// <summary>
    /// Helper method to format path string in a friendly way
    /// </summary>
    public virtual String formatPath(String path)
    {
      const int MAX_LENGTH = 100;
      int len = path.Length;
      if (len < MAX_LENGTH)
      {
        return path;
      }
      return "... " + XPStringUtility.Substring(path, len - MAX_LENGTH);
    }
    
    /// <summary>
    /// Helper method to format size string in a friendly way
    /// </summary>
    public virtual String formatSize(int sizeInBytes)
    {
      if (sizeInBytes < 500)
      {
        return XPConvert.ToString(sizeInBytes);
      }
      double kb = sizeInBytes / 1024;
      if (kb < 500)
      {
        kb = ((int) (kb * 10)) / 10;
        return XPResourceManager.FormatMessage(m_asOwner.GetString(833, "ptmsgs_portalbrowsingmsgs"),
         XPConvert.ToString(kb));
      }
      double mb = kb / 1024;
      mb = ((int) (mb * 10)) / 10;
      return XPResourceManager.FormatMessage(m_asOwner.GetString(834, "ptmsgs_portalbrowsingmsgs"),
       XPConvert.ToString(mb));
    }
    
    /// <summary>
    /// Returns javascript for the view.
    /// </summary>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the element that all other elements will be added to,
    /// such as an HTMLTable.  If null is returned, a generic
    /// HTMLElementCollection will be used.
    /// </summary>
    public virtual HTMLElement DisplayCollection()
    {
      // If no results were returned, don't display anything.
      if (0 == m_model.GetTotalItems())
      {
        return null;
      }
      // Finally, construct the table in which the results will go
      HTMLTable resultTable = new HTMLTable();
      resultTable.SetCellSpacing("2");
      resultTable.SetCellPadding("3");
      resultTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      return resultTable;
    }
    
    /// <summary>
    /// Returns an element that will appear before all results, whether
    /// or not the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayHeader()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns an element that will appear after all results regardless
    /// of whether the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayFooter()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow containing column
    /// headings) that will be used if the results are not grouped.  Not called
    /// if the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayHeaderIfUngrouped()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns an element that will appear after all results if the results
    /// are not grouped.  Not called if the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayFooterIfUngrouped()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow containing column
    /// headings) that will be used if the results are grouped.  Not called
    /// if the results are ungrouped.
    /// </summary>
    public virtual HTMLElement DisplayGroupHeader(int groupNum)
    {
      return m_view.DisplayStandardGroupHeaderRow(groupNum, CELL_HEIGHT, "2",
       true);
    }
    
    /// <summary>
    /// Returns an element that will appear after all results in a single group.
    /// Not called if the results are ungrouped.
    /// </summary>
    public virtual HTMLElement DisplayGroupFooter(int groupNum)
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow) headings) for a single
    /// search result.
    /// </summary>
    public virtual HTMLElement DisplaySingleResult(int _nResultIndex, bool oddRow,
     int groupNum)
    {
      HTMLBr br = new HTMLBr();
      int nObjectID = m_model.GetResultObjectID(_nResultIndex);
      String strObjectName = m_model.GetResultName(_nResultIndex);
      HTMLTableRow row = new HTMLTableRow();
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLSpan span = new HTMLSpan();
      cell.AddInnerHTMLElement(span);
      span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      span.AddInnerHTMLEncodedString(strObjectName);
      cell.AddInnerHTMLElement(br);
      // Add the keyword-in-context (KWIC) information to the same cell
      String kwic = m_model.GetKWIC(_nResultIndex);
      if ((null != kwic) && (0 != kwic.Length))
      {
        cell.AddInnerHTMLString(kwic);
        cell.AddInnerHTMLElement(br);
      }
      // Last modified date
      cell.AddInnerHTMLString(m_asOwner.GetString(826, "ptmsgs_portalbrowsingmsgs") + ": " + m_dateFormat.Format(m_model.GetResultLastModified(_nResultIndex)));
      cell.AddInnerHTMLElement(br);
      ASURL myAsurl;
      if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetIsObjectSelected(nObjectID))
      {
        if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).DoNotShowObjectWithID(nObjectID))
        {
          cell.AddInnerHTMLString(m_asOwner.GetString(1719, "ptmsgs_portalbrowsingmsgs"));
          } else
        {
          myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_508_ACTION_REMOVEOBJECT);
          myAsurl.AddControlArgument(CommunitySelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
           nObjectID);
          myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1271,
           "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strObjectName)));
          cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
        }
      } else
      {
        myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_508_ACTION_ADDOBJECT);
        myAsurl.AddControlArgument(CommunitySelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
         nObjectID);
        myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1270,
         "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strObjectName)));
        cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
      }
      cell.AddInnerHTMLElement(br);
      cell.AddInnerHTMLElement(br);
      return row;
    }
    public virtual void InitDisplayResults()
    {
    }
  }
}