using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection.communities
{
  /// <author>MichaelD</author>
  public class CommSelGroupedResultsViewHelper : IGroupedResultsViewHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.communities.CommSelGroupedResultsViewHelper");
    protected AActivitySpace m_asOwner = null;
    protected ISearchResultModelRO m_model = null;
    protected GroupedResultsView m_view = null;
    protected const String CELL_HEIGHT = "25";
    protected const String LOW_CELL_HEIGHT = "20";
    private int _groupsDisplayed = 0;
    protected XPDateFormat m_dateFormat = null;
    /* i had to remove final from the declaration above and move it into the
     * constructor in order to get the JUMP to .NET process to work correctly.
     * If this is a big problem for you, please, let me know and we will figure
     * something out.
     * 		-- moose
     */
     
    public CommSelGroupedResultsViewHelper()
    {
    }
    public virtual void Init(AActivitySpace _owner, ISearchResultModelRO _model,
     GroupedResultsView _view)
    {
      m_asOwner = _owner;
      m_model = _model;
      m_view = _view;
      m_dateFormat = _model.GetDateFormat(m_asOwner);
    }
    
    /// <summary>
    /// Helper method to format path string in a friendly way
    /// </summary>
    public virtual String formatPath(String path)
    {
      const int MAX_LENGTH = 100;
      int len = path.Length;
      if (len < MAX_LENGTH)
      {
        return path;
      }
      return "... " + XPStringUtility.Substring(path, len - MAX_LENGTH);
    }
    
    /// <summary>
    /// Helper method to format size string in a friendly way
    /// </summary>
    public virtual String formatSize(int sizeInBytes)
    {
      if (sizeInBytes < 500)
      {
        return XPConvert.ToString(sizeInBytes);
      }
      double kb = sizeInBytes / 1024;
      if (kb < 500)
      {
        kb = ((int) (kb * 10)) / 10;
        return XPResourceManager.FormatMessage(m_asOwner.GetString(833, "ptmsgs_portalbrowsingmsgs"),
         XPConvert.ToString(kb));
      }
      double mb = kb / 1024;
      mb = ((int) (mb * 10)) / 10;
      return XPResourceManager.FormatMessage(m_asOwner.GetString(834, "ptmsgs_portalbrowsingmsgs"),
       XPConvert.ToString(mb));
    }
    
    /// <summary>
    /// Returns javascript for the view.
    /// </summary>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append("function ").Append(ReorganizationViewHelper.JAVASCRIPT_RESORT).Append("() {").Append(AFormDP.JAVASCRIPT_SUBMIT_TO_CONTROL).Append("(\"").Append(ReorganizationControl.STR_MVC_CLASS_NAME).Append("\",\"").Append(SearchResultControl.KEY_DATA).Append("=").Append(m_model.GetCurrentKey()).Append("\"); }");
      try
      {
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript: Failed to add \'" + ReorganizationViewHelper.JAVASCRIPT_RESORT + "\' javscript function to the page. " + he.Message);
        }
      return myScript;
    }
    
    /// <summary>
    /// Returns the element that all other elements will be added to,
    /// such as an HTMLTable.  If null is returned, a generic
    /// HTMLElementCollection will be used.
    /// </summary>
    public virtual HTMLElement DisplayCollection()
    {
      // If no results were returned, don't display anything.
      if (0 == m_model.GetTotalItems())
      {
        return null;
      }
      // Initialize some member variables..
      _groupsDisplayed = 0;
      // Finally, construct the table in which the results will go
      HTMLTable resultTable = new HTMLTable();
      resultTable.SetCellSpacing("2");
      resultTable.SetCellPadding("3");
      resultTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      return resultTable;
    }
    
    /// <summary>
    /// Returns an element that will appear before all results, whether
    /// or not the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayHeader()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns an element that will appear after all results regardless
    /// of whether the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayFooter()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow containing column
    /// headings) that will be used if the results are not grouped.  Not called
    /// if the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayHeaderIfUngrouped()
    {
      return GetHeaderRow();
    }
    
    /// <summary>
    /// Returns an element that will appear after all results if the results
    /// are not grouped.  Not called if the results are grouped.
    /// </summary>
    public virtual HTMLElement DisplayFooterIfUngrouped()
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow containing column
    /// headings) that will be used if the results are grouped.  Not called
    /// if the results are ungrouped.
    /// </summary>
    public virtual HTMLElement DisplayGroupHeader(int groupNum)
    {
      HTMLElement he = m_view.DisplayStandardGroupHeaderRow(groupNum, CELL_HEIGHT,
       ("5"), true);
      if (null == he)
      {
        // Nothing in this group
        return null;
      }
      HTMLElementCollection c = new HTMLElementCollection();
      {
        // Add a blank row to separate groups
        HTMLTableRow row = new HTMLTableRow();
        HTMLTableCell cell = new HTMLTableCell();
        cell.SetColSpan("5");
        if (0 == _groupsDisplayed)
        {
          cell.SetHeight("5");
        } else
        {
          cell.SetHeight("15");
        }
        row.AddInnerHTMLElement(cell);
        c.AddInnerHTMLElement(row);
      }
      c.AddInnerHTMLElement(he);
      // Add the column headings for this group too
      c.AddInnerHTMLElement(GetHeaderRow());
      _groupsDisplayed+=1;
      return c;
    }
    
    /// <summary>
    /// Returns an element that will appear after all results in a single group.
    /// Not called if the results are ungrouped.
    /// </summary>
    public virtual HTMLElement DisplayGroupFooter(int groupNum)
    {
      // Not needed
      return null;
    }
    
    /// <summary>
    /// Returns the header element (e.g. an HTMLTableRow) headings) for a single
    /// search result.
    /// </summary>
    public virtual HTMLElement DisplaySingleResult(int _nResultIndex, bool oddRow,
     int groupNum)
    {
      HTMLSpan span;
      // Create a table row
      HTMLTableRow row = new HTMLTableRow();
      if (oddRow)
      {
        row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
      } else
      {
        row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
      }
      int nObjectID = m_model.GetResultObjectID(_nResultIndex);
      String strObjectName = m_model.GetResultName(_nResultIndex);
      // Add cells for the checkbox, type, name, last-modified, size, and action list
      // checkbox
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      cell.SetWidth("20");
      cell.SetHeight(CELL_HEIGHT);
      cell.SetVAlign(CommonHTMLStrings.TOP);
      cell.SetAlign(CommonHTMLStrings.CENTER);
      HTMLInput inputSelector = new HTMLInput(HTMLInputTypes.CHECKBOX, CommunitySelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
       XPResourceManager.FormatMessage(m_asOwner.GetString(700, "ptmsgs_portalbrowsingmsgs"),
       XPHttpUtility.HtmlEncode(strObjectName)));
      cell.AddInnerHTMLElement(inputSelector);
      inputSelector.SetValue(XPConvert.ToString(_nResultIndex));
      // DCA - onclick for updating the bottom frame
      inputSelector.SetOnClick(SelectedObjectsView.JAVASCRIPT_ADD_SELECTED + "(this); return true;");
      if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetIsObjectSelected(nObjectID))
      {
        inputSelector.SetChecked(true);
      }
      if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).DoNotShowObjectWithID(nObjectID))
      {
        inputSelector.SetDisabled(true);
      }
      // type icon
      cell = new HTMLTableCell();
      cell.SetAlign(CommonHTMLStrings.CENTER);
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetWidth("20");
      row.AddInnerHTMLElement(cell);
      HTMLImg icon = (HTMLImg) m_model.GetResultIcon(_nResultIndex);
      if (null != icon)
      {
        icon.SetWidth("20");
        icon.SetHeight("20");
        icon.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        icon.SetBorder(CommonHTMLStrings.ZERO);
        cell.AddInnerHTMLElement(icon);
      } else
      {
        cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      // name
      cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
      cell.SetWidth("100%");
      //    cell.SetNoWrap(true);
      row.AddInnerHTMLElement(cell);
      // Make a clickthru URL.
      HTMLAnchor previewCommAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strObjectName),
       CommunitySelectionViewHelper.JAVASCRIPT_PREVIEW_COMMUNITY + "(\'" + nObjectID + "\',\'" + _nResultIndex + "\')");
      cell.AddInnerHTMLElement(previewCommAnchor);
      previewCommAnchor.SetTitle(m_asOwner.GetString(703, "ptmsgs_portalbrowsingmsgs"));
      // Add the keyword-in-context (KWIC) information to the same cell
      String kwic = m_model.GetKWIC(_nResultIndex);
      if ((null != kwic) && (0 != kwic.Length))
      {
        cell.AddInnerHTMLElement(new HTMLBr());
        span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.LIST_TEXT);
        // Note that the Search server htmlencodes the KWIC for us
        span.AddInnerHTMLString(kwic);
        cell.AddInnerHTMLElement(span);
      }
      // Hidden Inputs with Portlet information
      HTMLInput inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN, ObjectSelectionModel.HTMLINPUT_HIDDEN_ID + _nResultIndex,
       "");
      inputHidden.SetValue(XPConvert.ToString(nObjectID));
      cell.AddInnerHTMLElement(inputHidden);
      inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN, ObjectSelectionModel.HTMLINPUT_HIDDEN_NAME + _nResultIndex,
       "");
      inputHidden.SetValue(XPHttpUtility.HtmlEncode(strObjectName));
      cell.AddInnerHTMLElement(inputHidden);
      // modified date
      cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      cell.SetNoWrap(true);
      cell.SetWidth("125");
      row.AddInnerHTMLElement(cell);
      cell.AddInnerHTMLString(m_dateFormat.Format(m_model.GetResultLastModified(_nResultIndex)));
      // Send to Others Link
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetWidth("20");
      cell.SetVAlign(CommonHTMLStrings.MIDDLE);
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      // just using asurl to build the url - will soon pass it into an HTMLAnchor
      HTMLAnchor sendToOthersAnchor = ConstructStaticHelpers.GetJavascriptAnchor("",
       CommunitySelectionViewHelper.JAVASCRIPT_OPEN_INVITE + "(\'" + _nResultIndex + "\')");
      cell.AddInnerHTMLElement(sendToOthersAnchor);
      sendToOthersAnchor.SetTitle(m_asOwner.GetString(702, "ptmsgs_portalbrowsingmsgs"));
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEND);
      HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();
      myImg.SetAlt(m_asOwner.GetString(702, "ptmsgs_portalbrowsingmsgs"));
      sendToOthersAnchor.AddInnerHTMLElement(myImg);
      return row;
    }
    
    /// <summary>
    /// Helper function, returns the standard column headings
    /// </summary>
    private HTMLTableRow GetHeaderRow()
    {
      // Column headers
      HTMLTableRow row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      // "Rank"
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      cell.SetHeight(LOW_CELL_HEIGHT);
      cell.SetAlign(CommonHTMLStrings.CENTER);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      cell.SetColSpan("2");
      cell.AddInnerHTMLString(m_asOwner.GetString(698, "ptmsgs_portalbrowsingmsgs"));
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      cell.AddInnerHTMLString(m_asOwner.GetString(826, "ptmsgs_portalbrowsingmsgs"));
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
       true, m_asOwner);
      HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt(m_asOwner.GetString(288, "ptmsgs_portalbrowsingmsgs"));
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      cell.AddInnerHTMLElement(myImage);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return row;
    }
    /*
     * Called before a set of results is displayed.
     *  (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.search.IGroupedResultsViewHelper#InitDisplayResults()
     */
     
    public virtual void InitDisplayResults()
    {
    }
  }
}