using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
namespace com.plumtree.portalpages.browsing.objectselection.communities
{
  /// <author>michaeld</author>
  public class CommunitySelectionEditorAS : PTEditorAS,IObjectSelectionAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.communities.CommunitySelectionEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "CommunitySelection";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new CommunitySelectionEditorAS();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String,java.lang.String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bAccess = base.CheckBasicAccess(strPage, strControl, bSameSpace);
      if ((null != strControl) && (strControl.Equals(InvitationPopupControl.STR_MVC_CLASS_NAME)))
      {
        bAccess = true;
      }
      if ((null != strControl) && (strControl.Equals(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME)))
      {
        bAccess = true;
      }
      return bAccess;
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      return GetString(297, "ptmsgs_portalcommonmsgs");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetObjectBannerText()"></seealso>
    public virtual String GetObjectBannerText()
    {
      return GetString(695, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetObjectBannerTitle()"></seealso>
    public virtual String GetObjectBannerTitle()
    {
      return GetString(694, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (ObjectSelectionRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetSearchPrompt()"></seealso>
    public virtual String GetSearchPrompt()
    {
      return GetString(693, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#Init(IPTSession)"></seealso>
    public override void Init()
    {
      log.Info("Initializing Community Selection Activity Space");
      // Community Selection Model
      m_strModelName = ObjectSelectionModel.STR_MVC_CLASS_NAME;
      base.Init();
      // Call IntegratedSearchAS.RegisterSearchClasses to register search stuff.
      IntegratedSearchAS.RegisterSearchClasses(this);
      // Get our instance of SearchResultModel; the views that display
      // results will need it.
      IModel searchModel = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
      ObjectSelectionModel myModel = (ObjectSelectionModel) GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      myModel.SetSelectionModelHelper(new CommunitySelectionModelHelper(this));
      myModel.SetShowFolderBanner(true);
      // Model has to be initialized in Init method because it requires PTSession.
      log.Info("Registered model");
      // Community Selection DisplayPages
      RegisterPage(new CommunitySelectionDP());
      RegisterPage(new CommunitySelectionDP_D());
      RegisterPage(new SelectedObjectsDP());
      RegisterPage(new ObjSelFrameSetDP());
      ((ObjSelFrameSetDP) GetPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME)).SetupFrameSet(GetString(1599,
       "ptmsgs_portalbrowsingmsgs"), CommunitySelectionDP.STR_MVC_CLASS_NAME);
      CommunityInvitationPopupDP CommInvitationPopup = new CommunityInvitationPopupDP();
      CommInvitationPopup.Init(this);
      RegisterPage(CommInvitationPopup);
      log.Info("Registered page");
      // Community Selection Views
      RegisterView(ObjSelBreadCrumbView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjectSelectionView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SelectedObjectsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjectView.STR_MVC_CLASS_NAME, myModel);
      // Register views that present search results, passing in
      // the SearchResultModel
      RegisterView(ObjSelSearchHeaderView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjSelSearch508BodyView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjSelSearchFormView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(GroupedResultsView.STR_MVC_CLASS_NAME, searchModel);
      RegisterView(SearchSummaryView.STR_MVC_CLASS_NAME, searchModel);
      RegisterView(SearchFooterView.STR_MVC_CLASS_NAME, searchModel);
      RegisterView(OrganizationView.STR_MVC_CLASS_NAME, searchModel);
      // Community Preview/Invitation Views
      RegisterView(CommunityInvitationPopupView.STR_MVC_CLASS_NAME, myModel);
      log.Info("Registered views");
      // Set the view helper for the grouped results view
      GroupedResultsView grv = (GroupedResultsView) GetView(GroupedResultsView.STR_MVC_CLASS_NAME);
      if (GetAccessStyle() == AccessStyles.STANDARD)
      {
        grv.SetHelper(new CommSelGroupedResultsViewHelper());
      } else
      {
        grv.SetHelper(new CommSelGroupedResults508ViewHelper());
      }
      // Community Selection Controls
      RegisterControl(OpenSubFolderControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SetStartItemControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SetLastItemControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(ObjectSelectionRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(InvitationPopupControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(RefreshObjSelControl.STR_MVC_CLASS_NAME, myModel);
      log.Info("Registered controls");
      // Set view helper for views
      ((ObjectView) GetView(ObjectView.STR_MVC_CLASS_NAME)).SetObjectViewHelper(new CommunitySelectionViewHelper());
      // Set default page
      if (GetAccessStyle() == AccessStyles.STANDARD)
      {
        SetCurrentPage(GetPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME));
      } else
      {
        SetCurrentPage(GetPage(CommunitySelectionDP_D.STR_MVC_CLASS_NAME));
        }
      this.SetHelpTopic("PT_ChooseCommunities");
    }
  }
}