using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.browsing.login.createaccount;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection.communities
{
  /// <author>michaeld</author>
  public class CommunitySelectionModelHelper : IObjectSelectionModelHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.communities.CommunitySelectionModelHelper");
    
    /// <summary>
    /// Selected Info Array: Number of Columns 
    /// </summary>
    public const int COL_SELECTEDINFO_MAX = 1;
    
    /// <summary>
    /// Header Array: Number of Columns 
    /// </summary>
    public const int COL_HEADER_MAX = 3;
    
    /// <summary>
    /// Header Array: Checkbox Input Name 
    /// </summary>
    public const int COL_HEADER_CB = 0;
    
    /// <summary>
    /// Header Array: Names 
    /// </summary>
    public const int COL_HEADER_NAME = 1;
    
    /// <summary>
    /// Header Array: Invites 
    /// </summary>
    public const int COL_HEADER_INVITE = 2;
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Communities not to show 
    /// </summary>
    private XPSortedDictionary m_xpsdCommunitiesNotToShow;
    
    /// <summary>
    /// Creates a new CommunitySelectionModelHelper object.
    /// </summary>
    /// <param name="asOwner"></param>
    public CommunitySelectionModelHelper(AActivitySpace asOwner)
    {
      m_asOwner = asOwner;
    }
    
    /// <summary>
    /// Creates a new CommunitySelectionModelHelper object.
    /// </summary>
    private CommunitySelectionModelHelper()
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#AddFormInputsForEachObject(XPHashtable,IASQueryResult,int)"></seealso>
    public virtual void AddFormInputsForEachObject(XPHashtable htFormData,
     IASQueryResult asqr, int nObjectViewIndex)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetDoNotShowObjectIDs(ObjectSelectionModel)"></seealso>
    public virtual XPSortedDictionary GetDoNotShowObjectIDs(ObjectSelectionModel model,
     int nObjectViewIndex)
    {
      return m_xpsdCommunitiesNotToShow;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetHeaders()"></seealso>
    public virtual String[] GetHeaders(int nObjectViewIndex)
    {
      String[] astrHeader = new String[COL_HEADER_MAX];
      astrHeader[COL_HEADER_CB] = CommunitySelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
      astrHeader[COL_HEADER_NAME] = m_asOwner.GetString(698, "ptmsgs_portalbrowsingmsgs");
      astrHeader[COL_HEADER_INVITE] = CommonHTMLStrings.SPACE;
      return astrHeader;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetNumObjectViews()"></seealso>
    public virtual int GetNumObjectViews()
    {
      return 1;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjectBannerTitle(String)"></seealso>
    public virtual String GetObjectBannerTitle(String strCurrentFolderName,
     int nObjectViewIndex)
    {
      if (null == strCurrentFolderName)
      {
        return m_asOwner.GetString(697, "ptmsgs_portalbrowsingmsgs");
      }
      return XPResourceManager.FormatMessage(m_asOwner.GetString(696, "ptmsgs_portalbrowsingmsgs"),
       XPHttpUtility.HtmlEncode(strCurrentFolderName));
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjectInputName(ObjectSelectionModel)"></seealso>
    public virtual String GetObjectInputName(int nObjectViewIndex)
    {
      return CommunitySelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjects(IPTSession)"></seealso>
    public virtual IPTObjectManager GetObjectMan(IPTSession ptSession, int nObjectViewIndex)
    {
      return ptSession.GetCommunities();
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjectType()"></seealso>
    public virtual int GetObjectType(int nObjectViewIndex)
    {
      return PT_CLASSIDS.PT_COMMUNITY_ID;
    }
    
    /// <param name="ptSession"></param>
    /// <param name="ptFolder"></param>
    /// <returns></returns>
    public virtual IASQueryResult GetObjects(IPTSession ptSession, IPTAdminFolder ptFolder)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetPropIDsToQuery()"></seealso>
    public virtual int GetPropIDsToQuery(int nObjectViewIndex)
    {
      return PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_DESCRIPTION | PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_LASTMODIFIED;
      }
    
    /// <summary>
    /// Get query filter to use when query for selectable objects. The use of the first column
    /// of thise array, [0][0] - [2][0], is reserved for use by ObjectSelectionModel. Start adding filters to the
    /// array at [0][1] - [2][1].
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetQueryFilter(ObjectSelectionModel)"></seealso>
    public virtual Object[][] GetQueryFilter(ObjectSelectionModel model, int nObjectViewIndex)
    {
      Object[][] ptqf = new Object[3][];
      for (int j2c_index = 0;j2c_index < 3;j2c_index++)
      {
        ptqf[j2c_index] = new Object[2];
      }
      // mj: do not show the user profile community, which always has id 2
      ptqf[0][1] = PT_PROPIDS.PT_PROPID_OBJECTID;
      ptqf[1][1] = PT_FILTEROPS.PT_FILTEROP_NE;
      ptqf[2][1] = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
      return ptqf;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetRedirectAfterFinish()"></seealso>
    public virtual Redirect GetRedirectAfterFinish(ObjectSelectionModel model)
    {
      Redirect redirect = new Redirect();
      ASURL asurl = new ASURL(m_asOwner);
      ASCache myCache = (ASCache) m_asOwner.GetSubSession().GetAttribute(ASConstants.SANDBOXASCACHE);
      AActivitySpace parentSpace = null;
      String strParentSpaceName = m_asOwner.GetParentSpaceName();
      if (strParentSpaceName.Equals(LoginAS.STR_MVC_CLASS_NAME) || strParentSpaceName.Equals(CreateAccountAS.STR_MVC_CLASS_NAME))
      {
        strParentSpaceName = CommunityPageAS.STR_MVC_CLASS_NAME;
      } else
      {
        parentSpace = myCache.GetSpace(strParentSpaceName, m_asOwner.GetParentSpaceID());
        }
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
      {
        if (parentSpace != null)
        {
          redirect.SetLinkGetCachedSpace(parentSpace);
        } else
        {
          redirect.SetLinkCreateNewSpace(strParentSpaceName, m_asOwner);
        }
        return redirect;
      }
      if (parentSpace != null)
      {
        asurl.SetLinkGetCachedSpace(parentSpace);
      } else
      {
        asurl.SetLinkCreateNewSpace(strParentSpaceName, m_asOwner);
      }
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.AddInnerHTMLString("parent.location=\'" + asurl.GetURLAsString() + "\';");
      ClosePopUpDP closeDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      closeDP.SetScript(script);
      closeDP.SetToClose(false);
      redirect.SetLinkGetCachedSpace(m_asOwner);
      redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      redirect.SetControl(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME);
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSelectedInfo(int,IASQueryResult)"></seealso>
    public virtual Object[] GetSelectedInfo(int nIndex, IASQueryResult asqr)
    {
      return new Object[COL_SELECTEDINFO_MAX];
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetSelectedObjects(ObjectSelectionModel)"></seealso>
    public virtual Object[][] GetSelectedObjects(ObjectSelectionModel model)
    {
      IASQueryResult asqrCommunityMembership = null;
      ASQueryResultWrapper qrw = new ASQueryResultWrapper(((IPTCommunityManager) model.GetPTSession().GetCommunities()).QueryMemberships());
      asqrCommunityMembership = qrw;
      Object[][] aoCommunityMembership = new Object[asqrCommunityMembership.GetCount()][];
      for (int j2c_index = 0;j2c_index < asqrCommunityMembership.GetCount();
      j2c_index++)
      {
        aoCommunityMembership[j2c_index] = new Object[ObjectSelectionModel.COL_OBJECT_MAX];
        }
      Object[] aoSelectedInfo;
      m_xpsdCommunitiesNotToShow = new XPSortedDictionary();
      for (int i = 0;i < asqrCommunityMembership.GetCount();i++)
      {
        aoCommunityMembership[i][ObjectSelectionModel.COL_OBJECT_ID] = asqrCommunityMembership.GetFields(i,
         PT_PROPIDS.PT_PROPID_OBJECTID);
        aoSelectedInfo = GetSelectedInfo(i, asqrCommunityMembership);
        aoSelectedInfo[ObjectSelectionModel.COL_SELECTED_NAME] = asqrCommunityMembership.GetFields(i,
         PT_PROPIDS.PT_PROPID_NAME);
        aoCommunityMembership[i][ObjectSelectionModel.COL_OBJECT_INFO] = aoSelectedInfo;
        if (PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE != XPConvert.ToInteger(asqrCommunityMembership.GetFields(i,
         PT_PROPIDS.PT_PROPID_MEMBERSHIP_TYPE)))
        {
          m_xpsdCommunitiesNotToShow.PutElement(aoCommunityMembership[i][ObjectSelectionModel.COL_OBJECT_ID],
           aoCommunityMembership[i][ObjectSelectionModel.COL_OBJECT_ID]);
          }
      }
      return aoCommunityMembership;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetShouldSavePage()"></seealso>
    public virtual bool GetShouldSavePage()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#InitializeFormInputs(XPHashtable)"></seealso>
    public virtual void InitializeFormInputs(XPHashtable htFormData)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#SetSelectedObjects(ObjectSelectionModel,XPSortedDictionary,XPSortedDictionary)"></seealso>
    public virtual void SetSelectedObjects(ObjectSelectionModel model, XPSortedDictionary xpsdOldSelectedObjects,
     XPSortedDictionary xpsdNewSelectedObjects)
    {
      // Setup PEI Variables
      IApplication application = m_asOwner.GetApplication();
      Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
      XPArrayList xpalJoinCommIDs = new XPArrayList();
      int[] anJoinCommIDs;
      int[] anQuitCommIDs;
      // END Setup PEI Variables
      IPTCommunityManager ptCommManager = (IPTCommunityManager) model.GetPTSession().GetCommunities();
      IXPEnumerator xpeKeys = xpsdNewSelectedObjects.GetKeys();
      // bjf -- keep track of whether an error occurs on join.  This can happen if 
      // a community has recently been deleted, or the user was recently taken off the ACL.  Don't
      // just halt everything -- continuing joining and quitting -- and then report the error
      // to the user are the very end.
      bool bFailureOccurred = false;
      while (xpeKeys.MoveNext())
      {
        if (xpsdOldSelectedObjects.ContainsKey(xpeKeys.GetCurrent()))
        {
          xpsdOldSelectedObjects.RemoveElement(xpeKeys.GetCurrent());
        } else
        {
          try
          {
            ptCommManager.JoinCommunity(XPConvert.ToInteger((String) xpeKeys.GetCurrent()),
             PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE);
            if (oa != null && oa.Length > 0)
            {
              xpalJoinCommIDs.Add(xpeKeys.GetCurrent());
            }
          }
          catch (Exception e)
          {
            // make a note of the failure, then let the user know at the very end of
            // this function.
            bFailureOccurred = true;
          }
        }
      }
      try
      {
        //PEI : CommunityActions
        // MJD: All of the following code will load all of the available CommunityAction
        // PEIs and process through them.
        if (oa != null)
        {
          if (oa.Length > 0)
          {
            anJoinCommIDs = new int[xpalJoinCommIDs.GetSize()];
            for (int iJoinCommID = 0;iJoinCommID < xpalJoinCommIDs.GetSize();
            iJoinCommID++)
            {
              anJoinCommIDs[iJoinCommID] = XPConvert.ToInteger(xpalJoinCommIDs.GetElement(iJoinCommID));
              }
          } else
          {
            anJoinCommIDs = new int[0];
          }
          for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
          {
            Object o = oa[iCommAction];
            if (o != null)
            {
              ICommunityActions iActions = (ICommunityActions) o;
              iActions.OnAfterUserJoinsCommunity(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
               anJoinCommIDs);
            }
          }
        }
      }
      //PEI : CommunityActions : END
      catch (Exception ex)
      {
        log.Error(ex, "OnAfterUserJoinsCommunity PEI failed.");
      }
      xpeKeys = xpsdOldSelectedObjects.GetKeys();
      anQuitCommIDs = new int[xpsdOldSelectedObjects.GetSize()];
      int iQuitCommID = 0;
      while (xpeKeys.MoveNext())
      {
        ptCommManager.QuitCommunity(XPConvert.ToInteger((String) xpeKeys.GetCurrent()));
        if (oa != null && oa.Length > 0)
        {
          anQuitCommIDs[iQuitCommID] = XPConvert.ToInteger(xpeKeys.GetCurrent());
          iQuitCommID++;
        }
      }
      try
      {
        //PEI : CommunityActions
        // MJD: All of the following code will load all of the available CommunityAction
        // PEIs and process through them.
        if (oa != null)
        {
          for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
          {
            Object o = oa[iCommAction];
            if (o != null)
            {
              ICommunityActions iActions = (ICommunityActions) o;
              iActions.OnAfterUserQuitsCommunity(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
               anQuitCommIDs);
            }
          }
        }
      }
      //PEI : CommunityActions : END
      catch (Exception ex)
      {
        log.Error(ex, "OnAfterUserQuitsCommunity PEI failed.");
      }
      // bjf -- OK, we did everything we could.  If there was an error, now is the time
      // to report it.
      if (bFailureOccurred)
      {
        String msg = m_asOwner.GetString(1503, "ptmsgs_portalbrowsingmsgs");
        UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetStartInSearch()
     */
     
    public virtual bool GetStartInSearch()
    {
      return true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSearchHeaderTitle()
     */
     
    public virtual String GetSearchHeaderTitle()
    {
      return m_asOwner.GetString(1472, "ptmsgs_portalbrowsingmsgs");
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#Get508SearchStringFromArray(int)
     */
     
    public virtual int Get508SearchStringMsgIndex(int nStringIndex)
    {
      switch (nStringIndex){
      case Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_AVAILABLE:
      return 1777;
      goto case Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_IN_THIS_FOLDER;
      case Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_IN_THIS_FOLDER:
      return 1778;
      goto case Search508StringIndexConstants.N_OBJECTS_IN_BLANK;
      case Search508StringIndexConstants.N_OBJECTS_IN_BLANK:
      return 1779;
      goto default;
      default:
      return 0;
      break;
      }
    }
  }
}