using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.admin.editors.portlet;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection.portlets
{
  /// <author>dustina/michaeld</author>
  public class CreatePortletActionBarView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.portlets.CreatePortletActionBarView");
    public const String STR_MVC_CLASS_NAME = "CreatePortletActionBarView";
    
    /// <summary>
    /// Subspace Key for Creating a portlet 
    /// </summary>
    public const String SUBSPACE_NAME_CREATEPORTLET = "CreatePortlet";
    protected AActivitySpace m_asOwner;
    protected IModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CreatePortletActionBarView();
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        PTConstruct construct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
         true, this.m_asOwner);
        construct.ReplaceNestedElementsWithHTMLString(PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
         m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs"));
        PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
         true, this.m_asOwner);
        myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE),
         m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564,
         "ptmsgs_portalbrowsingmsgs"));
        HTMLAnchor myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_ANCHOR));
        myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
        myAnchor.SetOnClick(ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "(\'" + PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER + "\');return false;");
        myAnchor.SetTitle(m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
        construct.AddElementToNestedElement(PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
         myButtonConstruct.GetHTMLElement());
        result.AddInnerHTMLElement(construct.GetHTMLElement());
        IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
        if (ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS))
        {
          construct = UIConstructFactory.GetConstruct(PTBannerType.OBJECT_ACTION_BAR,
           true, this.m_asOwner);
          //	Get a button construct
          myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.CREATE_PORTLET,
           true, this.m_asOwner);
          myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.CREATE_PORTLET.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE),
           m_asOwner.GetString(711, "ptmsgs_portalbrowsingmsgs") + CommonHTMLStrings.SPACE);
          myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.CREATE_PORTLET.GetElementName(PTButtonType.ELEMENT_NAME_ID_ANCHOR));
          myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
          myAnchor.SetOnClick("CreatePopUp();return false;");
          myAnchor.SetTitle(m_asOwner.GetString(711, "ptmsgs_portalbrowsingmsgs"));
          construct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
           myButtonConstruct.GetHTMLElement());
          result.AddInnerHTMLElement(construct.GetHTMLElement());
        }
        result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
      }
      catch (Exception e)
      {
        log.Error(e, "CreatePortletActionBarView::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(" ", e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      //ASURL myASURL;
      XPStringBuilder sb;
      ASURL myASURL;
      try
      {
        myASURL = new ASURL(m_asOwner);
        myASURL.SetLinkCreateNewSpace(PortMainPortletEditorAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        myASURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        myASURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_CREATE);
        myASURL.SetSubSpaceKey(SUBSPACE_NAME_CREATEPORTLET);
        myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID,
         ((IObjectSelectionModelRO) m_model).GetSelectorCommunityFolderID());
        myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER,
         true);
        myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
         XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
        myASURL.AddControlArgument(PTPortlets.PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY,
         true);
        sb = new XPStringBuilder(400);
        sb.Append("function CreatePopUp()\n");
        sb.Append("{\n");
        sb.Append("    window.open(\'").Append(myASURL.GetURLAsString()).Append("\', \'PopUpCreateMode\', \'location=no,menubar=no,scrollbars,height=600,width=800\');\n");
        sb.Append("}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException e)
      {
      }
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Section with the read-only Model and the Activity Space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = model;
      try
      {
        m_asOwner = parent;
      }
      catch (Exception e)
      {
        log.Error(e, "CreatePortletActionBarView::Init Unable to cast the Object " + parent + " to AActivitySpace. The following exception occured: " + e.Message);
        // JF- No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + parent + " to AActivitySpace.",
         e);
      }
    }
  }
}