using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection.portlets
{
  /// <author>
  /// naveenp
  /// This view doesn't have the create portlet button
  /// because we don't provide that in 508.  It is named
  /// as such because it is a replacement for the standard
  /// access view CreatePortletActionBar.java/cs.
  /// </author>
  public class CreatePortletActionBarView_D : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.portlets.CreatePortletActionBarView_D");
    public const String STR_MVC_CLASS_NAME = "CreatePortletActionBarView_D";
    
    /// <summary>
    /// Subspace Key for Creating a portlet 
    /// </summary>
    public const String SUBSPACE_NAME_CREATEPORTLET = "CreatePortlet";
    protected AActivitySpace m_asOwner;
    protected IModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new CreatePortletActionBarView_D();
    }
    
    /// <summary>
    /// Returns the HTML for the Section.
    /// </summary>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        PTConstruct construct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
         true, this.m_asOwner);
        construct.ReplaceNestedElementsWithHTMLString(PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
         m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs"));
        PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
         true, this.m_asOwner);
        myButtonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE),
         m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564,
         "ptmsgs_portalbrowsingmsgs"));
        HTMLAnchor myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_ANCHOR));
        ASURL myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
        myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
         PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
        myAnchor.SetHRef(myAsurl.GetURLAsString());
        myAnchor.SetTitle(m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
        construct.AddElementToNestedElement(PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
         myButtonConstruct.GetHTMLElement());
        result.AddInnerHTMLElement(construct.GetHTMLElement());
        result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
      }
      catch (Exception e)
      {
        log.Error(e, "CreatePortletActionBarView_D::Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(" ", e);
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Section with the read-only Model and the Activity Space.
    /// </summary>
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = model;
      try
      {
        m_asOwner = parent;
      }
      catch (Exception e)
      {
        log.Error(e, "CreatePortletActionBarView_D::Init Unable to cast the Object " + parent + " to AActivitySpace. The following exception occured: " + e.Message);
        // JF- No need to extract, this is an unexpected error.
        throw new XPException("Unable to cast the Object " + parent + " to AActivitySpace.",
         e);
      }
    }
  }
}