using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.objectselection.portlets
{
  /// <author>michaeld</author>
  public class MyCustomPortletsView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.portlets.MyCustomPortletsView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "MyCustomPortlets";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private IObjectSelectionModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new MyCustomPortletsView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      HTMLElement result = collection;
      try
      {
        HTMLTable myTable = new HTMLTable();
        collection.AddInnerHTMLElement(myTable);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myTable.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);
        HTMLTableRow myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetVAlign(CommonHTMLStrings.TOP);
        HTMLTableCell myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        int folderID = m_asModel.GetSelectorCommunityFolderID();
        // Open folder URL
        HTMLAnchor myAnchor;
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(m_asOwner.GetString(733,
           "ptmsgs_portalbrowsingmsgs"), ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "(\'" + folderID + "\')");
          } else
        {
          ASURL myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
          myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
           folderID);
          myAnchor = new HTMLAnchor(myAsurl.GetURLAsString());
          myAnchor.AddInnerHTMLString(m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs"));
          }
        // use list item construct
        UIListItem itemConstruct = new UIListItem(myAnchor, this.m_asOwner);
        itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_OPEN, "folder");
        itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
        // convert the construct to table
        HTMLTable folderTable = itemConstruct.GetItemAsTable();
        myCell.AddInnerHTMLElement(folderTable);
      }
      catch (HTMLException he)
      {
        log.Error(he, "Couldn\'t display " + m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs") + " folder.");
        }
      catch (Exception e)
      {
        log.Error(e, "Couldn\'t display " + m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs") + " folder.");
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IObjectSelectionModelRO) model;
      m_asOwner = parent;
    }
  }
}