using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
namespace com.plumtree.portalpages.browsing.objectselection.portlets
{
  /// <summary>
  /// This control is used to enable simple mode - no adding or preview of portlets.
  /// </summary>
  /// <author>dhayler</author>
  public class PortletInBundleSelectionEditorStartControl : EditorStartControl
  {
    
    /// <summary>
    /// Object Name for AS 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PortletInBundleEditorStart";
    
    /// <summary>
    /// Whether or not to use simple mode (i.e. true, false).  The default is false.
    /// Simple mode removes the checkboxes and Finish button.
    /// </summary>
    public const String SIMPLE_MODE = "SimpleMode";
    
    /// <summary>
    /// This code is called by the AS Servlet each time there is an Editor is started.
    /// It calls the startEditor method in the Model if a valid Editor Type was in the QS.
    /// If the Redirect object returned is not null,
    /// the Servlet will the page specified by the Redirect.
    /// If the Redirect is null, the Servlet will get the current page
    /// from the AS and display it.
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // This needs to happen before the super call, since that accesses
      // the model as well.
      String[] data = (String[]) arguments.GetElement(SIMPLE_MODE);
      if ((null != data) && (0 != data.Length) && (!"".Equals(data[0])))
      {
        ((PortletInBundleObjectSelectionModel) m_model).SetSimpleMode(XPConvert.ToBoolean(data[0]));
        }
      Redirect result = base.CheckActionSecurityAndExecute(arguments);
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletInBundleSelectionEditorStartControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}