using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.objectselection.portlets
{
  /// <author>michaeld</author>
  public class PortletInBundleSelectionModelHelper : IObjectSelectionModelHelper
  {
    
    /// <summary>
    /// Selected Info Array: Number of Columns 
    /// </summary>
    public const int COL_GADGET_MAX = 2;
    
    /// <summary>
    /// Selected Info Array: Portlet Alignment Column 
    /// </summary>
    public const int COL_GADGET_ALIGNMENT = 1;
    
    /// <summary>
    /// Header Array: Number of Columns for gadget 
    /// </summary>
    public const int COL_HEADER_PORTLET_MAX = 4;
    
    /// <summary>
    /// Header Array: Number of Columns for bundle 
    /// </summary>
    public const int COL_HEADER_BUNDLE_MAX = 2;
    
    /// <summary>
    /// Header Array: Checkbox Input Name 
    /// </summary>
    public const int COL_HEADER_CB = 0;
    
    /// <summary>
    /// Header Array: Names 
    /// </summary>
    public const int COL_HEADER_NAME = 1;
    
    /// <summary>
    /// Header Array: Portlet Size 
    /// </summary>
    public const int COL_HEADER_SIZE = 2;
    
    /// <summary>
    /// Header Array: Invites 
    /// </summary>
    public const int COL_HEADER_INVITE = 3;
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// Creates a new PortletInBundleSelectionModelHelper object.
    /// </summary>
    /// <param name="asOwner"></param>
    public PortletInBundleSelectionModelHelper(AActivitySpace asOwner)
    {
      m_asOwner = asOwner;
    }
    // don't let people instantiate this without an asOwner; it's needed for internationalization.
    private PortletInBundleSelectionModelHelper()
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#AddFormInputsForEachObject(XPHashtable,IASQueryResult,int)"></seealso>
    public virtual void AddFormInputsForEachObject(XPHashtable htFormData,
     IASQueryResult asqr, int nObjectViewIndex)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetDoNotShowObjectIDs(ObjectSelectionModel,int)"></seealso>
    public virtual XPSortedDictionary GetDoNotShowObjectIDs(ObjectSelectionModel model,
     int nObjectViewIndex)
    {
      XPSortedDictionary xpsd = new XPSortedDictionary();
      if (model.IsHomeMyPage())
      {
        IPTQueryResult ptqr = model.GetPTSession().GetMyPages().QueryMandatoryGadgets();
        int nCount = ptqr.RowCount();
        for (int i = 0;i < nCount;i++)
        {
          xpsd.PutElement(ptqr.ItemAsObject(i, PT_PROPIDS.PT_PROPID_OBJECTID),
           "");
        }
      }
      return xpsd;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetHeaders(int)"></seealso>
    public virtual String[] GetHeaders(int nObjectViewIndex)
    {
      if (m_asOwner.GetModelExists(ObjectSelectionModel.STR_MVC_CLASS_NAME))
      {
        IModel baseModel = m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
        // If this is the special portlet in bundle object selection model, ...
        if (XPStringUtility.CompareIgnoreCase(baseModel.GetName(), PortletInBundleObjectSelectionModel.STR_MVC_CLASS_NAME) == 0)
        {
          PortletInBundleObjectSelectionModel model = (PortletInBundleObjectSelectionModel) baseModel;
          if (model.GetSimpleMode())
          {
            // If we're in simple submit mode, don't display the checkbox column.
            String[] astrSimpleHeader = new String[COL_HEADER_PORTLET_MAX - 1];
            astrSimpleHeader[COL_HEADER_NAME - 1] = m_asOwner.GetString(737,
             "ptmsgs_portalbrowsingmsgs");
            astrSimpleHeader[COL_HEADER_SIZE - 1] = m_asOwner.GetString(738,
             "ptmsgs_portalbrowsingmsgs");
            astrSimpleHeader[COL_HEADER_INVITE - 1] = m_asOwner.GetString(739,
             "ptmsgs_portalbrowsingmsgs");
            return astrSimpleHeader;
          }
        }
      }
      String[] astrHeader = new String[COL_HEADER_PORTLET_MAX];
      astrHeader[COL_HEADER_CB] = PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
      astrHeader[COL_HEADER_NAME] = m_asOwner.GetString(737, "ptmsgs_portalbrowsingmsgs");
      astrHeader[COL_HEADER_SIZE] = m_asOwner.GetString(738, "ptmsgs_portalbrowsingmsgs");
      astrHeader[COL_HEADER_INVITE] = m_asOwner.GetString(739, "ptmsgs_portalbrowsingmsgs");
      return astrHeader;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetNumObjectViews()"></seealso>
    public virtual int GetNumObjectViews()
    {
      return 1;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectBannerTitle(String,int)"></seealso>
    public virtual String GetObjectBannerTitle(String strCurrentFolderName,
     int nObjectViewIndex)
    {
      return XPResourceManager.FormatMessage(m_asOwner.GetString(736, "ptmsgs_portalbrowsingmsgs"),
       XPHttpUtility.HtmlEncode(strCurrentFolderName));
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectInputName(int)"></seealso>
    public virtual String GetObjectInputName(int nObjectViewIndex)
    {
      return PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectMan(IPTSession,int)"></seealso>
    public virtual IPTObjectManager GetObjectMan(IPTSession ptSession, int nObjectViewIndex)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectType(int)"></seealso>
    public virtual int GetObjectType(int nObjectViewIndex)
    {
      return -PT_CLASSIDS.PT_GADGET_ID;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjects(IPTSession,IPTAdminFolder)"></seealso>
    public virtual IASQueryResult GetObjects(IPTSession ptSession, IPTAdminFolder ptFolder)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetPropIDsToQuery(int)"></seealso>
    public virtual int GetPropIDsToQuery(int nObjectViewIndex)
    {
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetQueryFilter(ObjectSelectionModel,int)"></seealso>
    public virtual Object[][] GetQueryFilter(ObjectSelectionModel model, int nObjectViewIndex)
    {
      Object[][] ptqf;
      if (model.IsMyPage())
      {
        ptqf = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          ptqf[j2c_index] = new Object[5];
        }
        ptqf[0][4] = PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE;
        ptqf[1][4] = PT_FILTEROPS.PT_FILTEROP_EQ;
        ptqf[2][4] = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;
      } else
      {
        ptqf = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          ptqf[j2c_index] = new Object[4];
        }
      }
      ptqf[0][1] = PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT;
      ptqf[1][1] = PT_FILTEROPS.PT_FILTEROP_NE;
      ptqf[2][1] = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER;
      ptqf[0][2] = PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT;
      ptqf[1][2] = PT_FILTEROPS.PT_FILTEROP_NE;
      ptqf[2][2] = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER;
      ptqf[0][3] = PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT;
      ptqf[1][3] = PT_FILTEROPS.PT_FILTEROP_NE;
      ptqf[2][3] = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM;
      return ptqf;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetRedirectAfterFinish(ObjectSelectionModel)"></seealso>
    public virtual Redirect GetRedirectAfterFinish(ObjectSelectionModel model)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSelectedInfo(int,IASQueryResult)"></seealso>
    public virtual Object[] GetSelectedInfo(int nIndex, IASQueryResult asqr)
    {
      Object[] aoSelectedInfo = new Object[COL_GADGET_MAX];
      aoSelectedInfo[COL_GADGET_ALIGNMENT] = asqr.GetFields(nIndex, PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
      return aoSelectedInfo;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSelectedObjects(ObjectSelectionModel)"></seealso>
    public virtual Object[][] GetSelectedObjects(ObjectSelectionModel model)
    {
      XPSortedDictionary xpsdGadgets;
      Object[][] aoGadgets;
      ASCache myCache = (ASCache) m_asOwner.GetSubSession().GetAttribute(ASConstants.SANDBOXASCACHE);
      AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
       m_asOwner.GetParentSpaceID());
      bool bSimple = false;
      // If this is the special portlet in bundle object selection model
      if (XPStringUtility.CompareIgnoreCase(model.GetName(), PortletInBundleObjectSelectionModel.STR_MVC_CLASS_NAME) == 0)
      {
        bSimple = ((PortletInBundleObjectSelectionModel) model).GetSimpleMode();
        }
      if (bSimple)
      {
        // In simple mode, this model is called from the flyout space, which isn't an
        // object selection space (even though it looks like one), so we can't
        // get the parent object selection model.
        xpsdGadgets = new XPSortedDictionary();
      } else
      {
        ObjectSelectionModel parentModel = (ObjectSelectionModel) parentSpace.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
        xpsdGadgets = parentModel.GetSelectedObjectsForParent();
      }
      aoGadgets = GetGadgetIDsInIntegerArray(xpsdGadgets);
      return aoGadgets;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetShouldSavePage()"></seealso>
    public virtual bool GetShouldSavePage()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#InitializeFormInputs(XPHashtable)"></seealso>
    public virtual void InitializeFormInputs(XPHashtable htFormData)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#SetSelectedObjects(ObjectSelectionModel,XPSortedDictionary,XPSortedDictionary)"></seealso>
    public virtual void SetSelectedObjects(ObjectSelectionModel model, XPSortedDictionary xpsdOldSelectedObjects,
     XPSortedDictionary xpsdNewSelectedObjects)
    {
    }
    
    /// <summary>
    /// Method GetGadgetIDsInIntegerArray.
    /// Puts the object id and info of each item in the query in the Object array
    /// </summary>
    /// <param name="xpsdGadgets"></param>
    /// <returns>Object[][]</returns>
    private Object[][] GetGadgetIDsInIntegerArray(XPSortedDictionary xpsdGadgets)
    {
      Object[][] aoGadgets = new Object[xpsdGadgets.GetSize()][];
      for (int j2c_index = 0;j2c_index < xpsdGadgets.GetSize();j2c_index++)
      {
        aoGadgets[j2c_index] = new Object[ObjectSelectionModel.COL_OBJECT_MAX];
        }
      IXPEnumerator xpeKeys = xpsdGadgets.GetKeys();
      int i = 0;
      while (xpeKeys.MoveNext())
      {
        // Get Portlet ID
        aoGadgets[i][ObjectSelectionModel.COL_OBJECT_ID] = XPConvert.ToInteger((String) xpeKeys.GetCurrent());
        // Get Portlet Info
        aoGadgets[i][ObjectSelectionModel.COL_OBJECT_INFO] = xpsdGadgets.GetElement(xpeKeys.GetCurrent());
        i++;
      }
      return aoGadgets;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetStartInSearch()
     */
     
    public virtual bool GetStartInSearch()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSearchHeaderTitle()
     */
     
    public virtual String GetSearchHeaderTitle()
    {
      return "";
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#Get508SearchStringMsgIndex(int)
     */
     
    public virtual int Get508SearchStringMsgIndex(int nSearch508StringIndex)
    {
      return 0;
    }
  }
}