using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.browsing.portletpreview;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.impl.community;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
namespace com.plumtree.portalpages.browsing.objectselection.portlets
{
  /// <author>michaeld</author>
  public class PortletSelectionEditorAS : PTEditorAS,IObjectSelectionAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionEditorAS");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "GadgetSelection";
    
    /// <summary>
    /// Object Section: Gadgets 
    /// </summary>
    public const String GADGET_VIEW = "GadgetView";
    
    /// <summary>
    /// Object Section: Bundles 
    /// </summary>
    public const String BUNDLE_VIEW = "BundleView";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String,java.lang.String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      bool bAccess = base.CheckBasicAccess(strPage, strControl, bSameSpace);
      // fix for bug 9033606 - caius
      XPHashtable myFormData = this.GetCurrentFormData();
      //-100 is an arbitrary number
      int selectorPageID = -100;
      if (myFormData.ContainsKey(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORPAGEID))
      {
        selectorPageID = XPConvert.ToInteger(((String[]) myFormData.GetElement(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORPAGEID))[0]);
        }
      if (-100 != selectorPageID)
      {
        try
        {
          IPTSession userSession = (IPTSession) this.GetUserSession();
          bool myReturnValue = false;
          PTPageManager myPageManager = (PTPageManager) userSession.GetPages();
          int adminFolderId = myPageManager.GetAdminFolderID(selectorPageID);
          // if the admin folder ID is negative it's a mypage so permissions aren't an issue here
          if (adminFolderId >= 0)
          {
            myReturnValue = userSession.GetPages().IsObjectAccessible(selectorPageID,
             userSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
            if (!myReturnValue)
            {
              return myReturnValue;
            }
          }
        }
        catch (XPException e)
        {
          // this exception isn't a problem but should be logged for debug purposes.
          log.Debug("Exception caught in 9033606 fix code");
          log.Error(e.GetMessage());
        }
      }
      //RT- Bug 9033606 User can get Add Portlets Editor in different way
      // and it uses SelectorObjectID for Portlet selection, So we also need 
      // to check for SelectorObjectID access for the current user.
      if (myFormData.ContainsKey(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID))
      {
        try
        {
          int selectorObjectID = XPConvert.ToInteger(((String[]) myFormData.GetElement(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID))[0]);
          log.Debug("Value of SelectorObjectID is :" + selectorObjectID);
          IPTSession userSession = (IPTSession) this.GetUserSession();
          PTPageManager myPageManager = (PTPageManager) userSession.GetPages();
          int adminFolderId = myPageManager.GetAdminFolderID(selectorObjectID);
          log.Debug("Value of Admin Folder ID is :" + adminFolderId);
          // If AdminFolderID is < 0 then it is a mypage
          if (adminFolderId >= 0)
          {
            bool retVal = userSession.GetPages().IsObjectAccessible(selectorObjectID,
             userSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
            if (!retVal)
            {
              log.Debug("User does not have access to the Page with SelectorObjectID :" + selectorObjectID);
              return retVal;
            }
          }
        }
        catch (XPException e)
        {
          // this exception isn't a problem but should be logged for debug purposes.
          log.Debug(e.GetMessage());
        }
      }
      // MJD- Otherwise make sure this is the refresh control. The access will be checked by those controls.
      if ((null != strControl) && (strControl.Equals(RefreshObjSelControl.STR_MVC_CLASS_NAME)))
      {
        bAccess = true;
      }
      if ((null != strControl) && (strControl.Equals(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME)))
      {
        bAccess = true;
      }
      if ((null != strControl) && (strControl.Equals(InvitationPopupControl.STR_MVC_CLASS_NAME)))
      {
        bAccess = true;
      }
      return bAccess;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PortletSelectionEditorAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      return GetString(714, "ptmsgs_portalbrowsingmsgs") + ": " + ((PortletSelectionModelHelper) ((ObjectSelectionModel) GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetSelectionModelHelper()).GetPageName((ObjectSelectionModel) GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME));
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetObjectBannerText()"></seealso>
    public virtual String GetObjectBannerText()
    {
      return GetString(717, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetObjectBannerTitle()"></seealso>
    public virtual String GetObjectBannerTitle()
    {
      return GetString(716, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (ObjectSelectionRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetSearchPrompt()"></seealso>
    public virtual String GetSearchPrompt()
    {
      return GetString(715, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#Init(IPTSession)"></seealso>
    public override void Init()
    {
      log.Info("Initializing Portlet Selection Activity Space");
      // Portlet Selection Model
      m_strModelName = ObjectSelectionModel.STR_MVC_CLASS_NAME;
      base.Init();
      // Call IntegratedSearchAS.RegisterSearchClasses to register search stuff.
      IntegratedSearchAS.RegisterSearchClasses(this);
      // Get our instance of SearchResultModel; the views that display
      // results will need it.
      IModel searchModel = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
      ObjectSelectionModel myModel = (ObjectSelectionModel) GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      myModel.SetSelectionModelHelper(new PortletSelectionModelHelper(this));
      myModel.SetShowFolderBanner(true);
      // Model has to be initialized in Init method because it requires PTSession.
      log.Info("Registered model");
      // Portlet Selection DisplayPages
      RegisterPage(new PortletSelectionDP());
      RegisterPage(new PortletSelectionDP_D());
      RegisterPage(new SelectedObjectsDP());
      RegisterPage(new ObjSelFrameSetDP());
      ((ObjSelFrameSetDP) GetPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME)).SetupFrameSet(GetString(1276,
       "ptmsgs_portalbrowsingmsgs"), PortletSelectionDP.STR_MVC_CLASS_NAME);
      PortletInvitationPopupDP GadgetInvitationPopup = new PortletInvitationPopupDP();
      GadgetInvitationPopup.Init(this);
      RegisterPage(GadgetInvitationPopup);
      log.Info("Registered page");
      // Portlet Selection Views
      RegisterView(ObjSelBreadCrumbView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(FolderView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjectSelectionView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(SelectedObjectsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjectView.STR_MVC_CLASS_NAME, GADGET_VIEW, myModel);
      RegisterView(ObjectView.STR_MVC_CLASS_NAME, BUNDLE_VIEW, myModel);
      RegisterView(MyCustomPortletsView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(CreatePortletActionBarView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(CreatePortletActionBarView_D.STR_MVC_CLASS_NAME, myModel);
      // Register views that present search results, passing in
      // the SearchResultModel
      RegisterView(ObjSelSearchHeaderView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjSelSearch508BodyView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(ObjSelSearchFormView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(GroupedResultsView.STR_MVC_CLASS_NAME, searchModel);
      RegisterView(SearchSummaryView.STR_MVC_CLASS_NAME, searchModel);
      RegisterView(SearchFooterView.STR_MVC_CLASS_NAME, searchModel);
      RegisterView(OrganizationView.STR_MVC_CLASS_NAME, searchModel);
      // Portlet Preview/Invitation Views
      RegisterView(PortletInvitationPopupView.STR_MVC_CLASS_NAME, myModel);
      // Set the view helper for the grouped results view
      GroupedResultsView grv = (GroupedResultsView) GetView(GroupedResultsView.STR_MVC_CLASS_NAME);
      if (GetAccessStyle() == AccessStyles.STANDARD)
      {
        grv.SetHelper(new PortletSelGroupedResultsViewHelper());
      } else
      {
        grv.SetHelper(new PortletSelGroupedResults508ViewHelper());
      }
      log.Info("Registered views");
      // Portlet Selection Controls
      RegisterControl(OpenSubFolderControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SetStartItemControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SetLastItemControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(ObjectSelectionRepostControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(InvitationPopupControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(RefreshObjSelControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME, myModel);
      log.Info("Registered controls");
      // Set view helpers on views
      ((ObjectView) GetView(PortletSelectionEditorAS.GADGET_VIEW)).SetObjectViewHelper(new PortletSelectionViewHelper());
      ((ObjectView) GetView(PortletSelectionEditorAS.BUNDLE_VIEW)).SetObjectViewHelper(new BundleSelectionViewHelper());
      // Set default page
      if (GetAccessStyle() == AccessStyles.STANDARD)
      {
        SetCurrentPage(GetPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME));
      } else
      {
        SetCurrentPage(GetPage(PortletSelectionDP_D.STR_MVC_CLASS_NAME));
        }
      this.SetHelpTopic("PT_AddPortlets");
    }
  }
}