using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.portalsettings
{
  /// <author>SudhaS</author>
  public class PortalSettingsModel : IPortalSettingsModel,IPortalSettingsModelRO
  {
    public const String STR_MVC_CLASS_NAME = "PortalSettings";
    private AActivitySpace m_asOwner;
    private IPTSession m_ptSession;
    private XPArrayList m_arrList = null;
    private Object[] m_oaSettings;
    public PortalSettingsModel()
    {
      m_arrList = new XPArrayList();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PortalSettingsModel();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetNumSettingItems()
    {
      return m_arrList.GetSize();
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual String GetSettingItemDescription(int _nIndex)
    {
      String strDesc = ((SettingItem) m_arrList.GetElement(_nIndex)).m_strDescription;
      if (strDesc != null)
      {
        return strDesc;
      }
      return (m_asOwner.GetString(1639, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual String GetSettingItemName(int _nIndex)
    {
      return ((SettingItem) m_arrList.GetElement(_nIndex)).m_strName;
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual int GetActivityRightRestriction(int _nIndex)
    {
      return ((SettingItem) m_arrList.GetElement(_nIndex)).m_nActivityRightRestriction;
      }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual String GetSettingItemURL(int _nIndex)
    {
      return ((SettingItem) m_arrList.GetElement(_nIndex)).m_strURL;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace _asOwner)
    {
      m_asOwner = _asOwner;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    //InitSettings(_asOwner);
    public virtual void InitSettings(AActivitySpace _asOwner)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      m_oaSettings = (Object[]) application.GetCachingManager().GetEntry("DisplayPortalSettings");
      m_arrList.Clear();
      String strLang = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,
       _asOwner);
      for (int i = 0;i < m_oaSettings.Length;i++)
      {
        IPortalSettings objPortalSettings = (IPortalSettings) m_oaSettings[i];
        if (objPortalSettings.GetDisplaySetting(m_ptSession))
        {
          m_arrList.Add(new SettingItem(objPortalSettings.GetLinkText(strLang),
           objPortalSettings.GetDescription(strLang), GetLinkFromPortalSetting(objPortalSettings),
           objPortalSettings.GetActivityRightRestriction()));
        }
      }
      //		Pluggable Portal Setting Pages
      IPTSessionInfo ptSessionInfo = m_ptSession.GetSessionInfo();
      IPTQueryResult ptQueryResult = ptSessionInfo.GetCurrentUserCachedPluggablePages();
      bool bEditingGuestUser = PlumtreeHelpers.IsEditingDefaultProfile(m_asOwner);
      for (int i = 0;i < ptQueryResult.RowCount();i++)
      {
        int nPersonalization = ptQueryResult.ItemAsInt(i, PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION);
        //JD - Get the bit for user personalization.
        int nUserPersonalization = nPersonalization & PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PERSONAL;
        //JD- Flag to keep track of whether Return URI was set correctly
        bool bReturnURISet = false;
        //JD- Compare the bitmasked number to the right value
        if (nUserPersonalization == PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PERSONAL)
        {
          //JD- This web service has user personalization.
          String strName = ptQueryResult.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
          int nObjectID = ptQueryResult.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
          String strDesc = ptQueryResult.ItemAsString(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
          //JD- Add the RedirectGuest argument depending on whether or not we're
          //editing the guest user.
          String strURL;
          if (bEditingGuestUser)
          {
            strURL = GatewayHelpers.ConstructPrefPageLink(_asOwner, nObjectID,
             0, 0, GatewayHelpers.USERPLUGPAGE, PT_CLASSIDS.PT_WEBSERVICE_ID);
            } else
          {
            strURL = GatewayHelpers.ConstructPrefPageLink(_asOwner, nObjectID,
             0, 0, GatewayHelpers.USERPLUGPAGE | GatewayHelpers.REDIRECTGUEST,
             PT_CLASSIDS.PT_WEBSERVICE_ID);
          }
          m_arrList.Add(new SettingItem(strName, strDesc, strURL, PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE));
          //JD- Add return URI.
          if (!bReturnURISet)
          {
            ASURL url = new ASURL(m_asOwner);
            bool bSetURL = url.SetLinkGetCachedSpace(m_asOwner);
            if (bSetURL)
            {
              HttpUtils.SetReturnURI(url.GetURLAsString(), m_asOwner.GetSubSession());
              bReturnURISet = true;
            }
          }
        }
      }
    }
    
    /// <param name="_ptSetting"></param>
    /// <returns></returns>
    private String GetLinkFromPortalSetting(IPortalSettings _ptSetting)
    {
      ASURL asURL = new ASURL(m_asOwner);
      String strSettingURL = null;
      // The space
      asURL.SetLinkCreateNewSpace(_ptSetting.GetASName(), m_asOwner);
      // The control
      String strControl = _ptSetting.GetASControlName();
      if (strControl != null)
      {
        asURL.SetControl(strControl);
      }
      // The display page
      String strDP = _ptSetting.GetASDPName();
      if (strDP != null)
      {
        asURL.SetDisplayPage(strDP);
      }
      // The query string
      String strQueryString = _ptSetting.GetASQueryString();
      if (strQueryString != null)
      {
        strSettingURL = asURL.GetURLAsString() + strQueryString;
      } else
      {
        strSettingURL = asURL.GetURLAsString();
      }
      return strSettingURL;
    }
    
    /// <author>$author$</author>
    private class SettingItem
    {
      public String m_strDescription;
      public String m_strName;
      public String m_strURL;
      public int m_nActivityRightRestriction;
      
      /// <summary>
      /// Creates a new SettingItem object.
      /// </summary>
      /// <param name="_strName"></param>
      /// <param name="_strDescription"></param>
      /// <param name="_strURL"></param>
      public SettingItem(String _strName, String _strDescription, String _strURL,
       int _nActivityRightRestriction)
      {
        m_strName = _strName;
        m_strDescription = _strDescription;
        m_strURL = _strURL;
        m_nActivityRightRestriction = _nActivityRightRestriction;
      }
    }
  }
}