using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.portalsettings.displayoptions
{
  /// <author>Sample</author>
  public class DisplayOptModel : EditorModel,IDisplayOptModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portalsettings.displayoptions.DisplayOptModel");
    public const String STR_MVC_CLASS_NAME = "DisplayOpt";
    protected IPTSession m_ptSession;
    private String m_strAccess = "";
    // these are the settings
    private String m_strGreeting = "";
    private String m_strOpenWin = "";
    private String m_strRefreshRate = "10";
    private int m_nTimeout = -1;
    private bool m_bEnableRulesDebugMode = false;
    
    /// <param name="strErrorMsgs"></param>
    /// <param name="strNewMessage"></param>
    /// <returns></returns>
    public virtual String AddToErrorString(String strErrorMsgs, String strNewMessage)
    {
      if (strErrorMsgs.Length > 0)
      {
        return strErrorMsgs + ", " + strNewMessage;
      } else
      {
        return strNewMessage;
      }
    }
    // interface PropertyValidatorOwner 
    // TODO: olegs - need this? class does not implement this interface
    // implementation
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      LoadSettings();
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DisplayOptModel();
    }
    public override void Finish()
    {
      try
      {
        SetStringSetting(PersonalSettingNames.GREETING, m_strGreeting);
        if (-1 != m_nTimeout)
        {
          SetIntSetting(PersonalSettingNames.PORTLET_TIMEOUT, m_nTimeout * 1000);
          } else
        {
          SetIntSetting(PersonalSettingNames.PORTLET_TIMEOUT, m_nTimeout);
          }
        SetStringSetting(PersonalSettingNames.OPEN_DOC_NEW_WINDOW, m_strOpenWin);
        SetStringSetting(PersonalSettingNames.ACCESS_STYLE, m_strAccess);
        SetIntSetting(PersonalSettingNames.MY_PAGE_REFRESH_RATE, XPConvert.ToInteger(m_strRefreshRate));
        if (m_bEnableRulesDebugMode)
        {
          SetIntSetting(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE, 1);
          } else
        {
          SetIntSetting(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE, 0);
          }
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1000, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1000,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <returns></returns>
    public virtual String GetAccessibilityStyle()
    {
      return m_strAccess;
    }
    
    /// <returns></returns>
    public virtual String GetGreeting()
    {
      return m_strGreeting;
    }
    
    /// <returns></returns>
    public virtual bool GetRulesDebugMode()
    {
      return m_bEnableRulesDebugMode;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetTimeout()
    {
      return m_nTimeout;
    }
    public virtual bool IsRefreshRate(String strRate)
    {
      return m_strRefreshRate.Equals(strRate);
    }
    
    /// <param name="strType"></param>
    /// <returns></returns>
    public virtual bool IsViewChecked(String strType)
    {
      return m_strAccess.Equals(strType);
    }
    public virtual void LoadSettings()
    {
      try
      {
        m_ptSession = (IPTSession) m_asOwner.GetUserSession();
        m_strGreeting = GetStringSetting(PersonalSettingNames.GREETING);
        m_nTimeout = GetIntSetting(PersonalSettingNames.PORTLET_TIMEOUT) / 1000;
        m_nTimeout = (m_nTimeout == 0) ? (-1) : m_nTimeout;
        m_strRefreshRate = XPConvert.ToString(GetIntSetting(PersonalSettingNames.MY_PAGE_REFRESH_RATE));
        m_strOpenWin = GetStringSetting(PersonalSettingNames.OPEN_DOC_NEW_WINDOW);
        m_strAccess = GetStringSetting(PersonalSettingNames.ACCESS_STYLE);
        if (m_strOpenWin.Equals(""))
        {
          m_strOpenWin = "0";
        }
        if (m_strAccess.Equals(""))
        {
          m_strAccess = "3";
        }
        if (GetIntSetting(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE) == 1)
        {
          m_bEnableRulesDebugMode = true;
        }
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(1000, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1000,
         "ptmsgs_portalbrowsingmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int result = RepostControl.PAGE_STATUS_VALID;
      if (_sPageName.Equals(MainDP.STR_MVC_CLASS_NAME))
      {
        if (RepostControl.PAGE_STATUS_INVALID == SaveDisplayOptions(_htFormData))
        {
          result = RepostControl.PAGE_STATUS_INVALID;
        }
        if (RepostControl.PAGE_STATUS_INVALID == SaveGreeting(_htFormData))
        {
          result = RepostControl.PAGE_STATUS_INVALID;
        }
        if (RepostControl.PAGE_STATUS_INVALID == SaveTimeout(_htFormData))
        {
          result = RepostControl.PAGE_STATUS_INVALID;
        }
        if (RepostControl.PAGE_STATUS_INVALID == SaveAccessibility(_htFormData))
        {
          result = RepostControl.PAGE_STATUS_INVALID;
        }
      }
      if (_sPageName.Equals(AdvancedSettingsDP.STR_MVC_CLASS_NAME))
      {
        if (RepostControl.PAGE_STATUS_INVALID == SaveEnableRulesDebugMode(_htFormData))
        {
          result = RepostControl.PAGE_STATUS_INVALID;
        }
      }
      return result;
    }
    
    /// <returns></returns>
    public virtual bool ShouldOpenNewWindow()
    {
      return m_strOpenWin.Equals("1");
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveAccessibility(XPHashtable _htFormData)
    {
      String strErrorMsgs = "";
      int result = RepostControl.PAGE_STATUS_VALID;
      String[] data = (String[]) _htFormData.GetElement(AccessibilityView.HTMLRADIO_PORTALSTYLE);
      if ((null != data) && !(0 == data.Length))
      {
        m_strAccess = data[0];
      } else
      {
        log.Warn("DisplayOptModel::SaveMainPage Accessibility view was not in Query String.");
        }
      // Report Errors if any
      if (strErrorMsgs.Length > 0)
      {
        result = RepostControl.PAGE_STATUS_INVALID;
        String msg = m_asOwner.GetString(999, "ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return result;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveDisplayOptions(XPHashtable _htFormData)
    {
      String strErrorMsgs = "";
      int result = RepostControl.PAGE_STATUS_VALID;
      // Folder Description Type
      String[] data = (String[]) _htFormData.GetElement(DisplayOptView.HTMLRADIO_OPENDOC);
      if ((null != data) && !(0 == data.Length))
      {
        m_strOpenWin = data[0];
      }
      // Report Errors if any
      if (strErrorMsgs.Length > 0)
      {
        result = RepostControl.PAGE_STATUS_INVALID;
        String msg = m_asOwner.GetString(999, "ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return result;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveGreeting(XPHashtable _htFormData)
    {
      String strErrorMsgs = "";
      int result = RepostControl.PAGE_STATUS_VALID;
      String[] data = (String[]) _htFormData.GetElement(GreetingView.HTMLINPUT_GREETING);
      if ((null != data) && !(0 == data.Length))
      {
        m_strGreeting = data[0];
      } else
      {
        log.Warn("DisplayOptModel::SaveMainPage Greeting was not in Query String.");
        }
      data = (String[]) _htFormData.GetElement(TimeoutView.HTMLSELECT_REFRESH);
      if ((null != data) && !(0 == data.Length))
      {
        m_strRefreshRate = data[0];
      } else
      {
        log.Warn("DisplayOptModel::SaveMainPage Refresh Rate was not in Query String.");
        }
      // Report Errors if any
      if (strErrorMsgs.Length > 0)
      {
        result = RepostControl.PAGE_STATUS_INVALID;
        String msg = m_asOwner.GetString(999, "ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return result;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveTimeout(XPHashtable _htFormData)
    {
      String strErrorMsgs = "";
      int result = RepostControl.PAGE_STATUS_VALID;
      String[] data = (String[]) _htFormData.GetElement(TimeoutView.HTMLRADIO_ADMIN);
      if ((null != data) && !(0 == data.Length))
      {
        String strChoice = data[0];
        if (strChoice.Equals("admin"))
        {
          m_nTimeout = -1;
        } else
        {
          data = (String[]) _htFormData.GetElement(TimeoutView.HTMLSELECT_TIMEOUT);
          if ((null != data) && !(0 == data.Length))
          {
            try
            {
              m_nTimeout = XPConvert.ToInteger(data[0]);
            }
            catch (Exception e)
            {
              m_nTimeout = -1;
            }
            if (m_nTimeout < 1)
            {
              m_nTimeout = -1;
            }
          } else
          {
            log.Warn("DisplayOptModel::SaveMainPage Timeout number was not in Query String.");
            }
        }
      } else
      {
        log.Warn("DisplayOptModel::SaveMainPage Admin default timeout was not in Query String.");
        }
      // Report Errors if any
      if (strErrorMsgs.Length > 0)
      {
        result = RepostControl.PAGE_STATUS_INVALID;
        String msg = m_asOwner.GetString(999, "ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, msg, msg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return result;
    }
    
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    protected virtual int SaveEnableRulesDebugMode(XPHashtable _htFormData)
    {
      String strErrorMsgs = "";
      int result = RepostControl.PAGE_STATUS_VALID;
      String[] data = (String[]) _htFormData.GetElement(RulesDebugModeView.HTMLINPUT_ENABLE_DEBUG_MODE);
      if (data != null)
      {
        m_bEnableRulesDebugMode = XPConvert.ToBoolean(data[0]);
      } else
      {
        m_bEnableRulesDebugMode = false;
      }
      return result;
    }
    
    /// <param name="strSetting"></param>
    /// <returns></returns>
    private int GetIntSetting(String strSetting)
    {
      Object ret = PTPersonalSettingsHelper.GetPersonalSettingValue(strSetting,
       m_asOwner);
      int iReturnValue = 0;
      if (ret != null)
      {
        iReturnValue = XPConvert.ToInteger(ret);
      }
      return iReturnValue;
    }
    
    /// <param name="strSetting"></param>
    /// <returns></returns>
    private String GetStringSetting(String strSetting)
    {
      String ret = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(strSetting,
       m_asOwner);
      //JD- if it's null, set it to an empty string 														 
      if (ret == null)
      {
        ret = "";
      }
      return ret;
    }
    
    /// <param name="strSettingName"></param>
    /// <param name="intSettingValue"></param>
    private void SetIntSetting(String strSettingName, int intSettingValue)
    {
      Object iSettingValue = intSettingValue;
      PTPersonalSettingsHelper.SetAndCachePersonalSetting(strSettingName,
       iSettingValue, m_asOwner);
    }
    
    /// <param name="strSettingName"></param>
    /// <param name="strSettingValue"></param>
    private void SetStringSetting(String strSettingName, String strSettingValue)
    {
      PTPersonalSettingsHelper.SetAndCachePersonalSetting(strSettingName,
       (Object) strSettingValue, m_asOwner);
    }
  }
}