using System;
// Plumtree Server
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.portalsettings.displayoptions
{
  /// <summary>
  /// This DP displays the Views for the Display Options page.
  /// </summary>
  /// <author>Julie Fournier</author>
  public class MainDP : EditorDP
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DisplayOptionsMainDP";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return (m_asOwner.GetString(1286, "ptmsgs_portalbrowsingmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)"></seealso>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      parent.SetHelpTopic("PT_DisplayOptions_MainSettings");
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    /// <returns>HTMLElement</returns>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Insert super class HTML
      result.AddInnerHTMLElement(base.PageDisplay());
      HTMLElementCollection views = new HTMLElementCollection();
      views.AddInnerHTMLElement((m_asOwner.GetView(AccessibilityView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement((m_asOwner.GetView(GreetingView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement((m_asOwner.GetView(DisplayOptView.STR_MVC_CLASS_NAME)).Display());
      views.AddInnerHTMLElement(EditorView.GetSpacerTable());
      views.AddInnerHTMLElement((m_asOwner.GetView(TimeoutView.STR_MVC_CLASS_NAME)).Display());
      result.AddInnerHTMLElement(CreateLeftNavBar(views));
      return result;
    }
    
    /// <summary>
    /// Implement this method to add HTML below the sub header.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLElement GetHTMLBelowSubHeader()
    {
      return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1449, "ptmsgs_portalbrowsingmsgs"),
       this.m_asOwner);
    }
  }
}