using System;
using com.plumtree.portalpages.common.constants;
using PasswordValidationHelper=com.plumtree.portalpages.common.passwordvalidation.PasswordValidationHelper;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.login;
namespace com.plumtree.portalpages.browsing.portalsettings.password
{
  /// <author>
  /// DonH
  /// This activity space lets you change your password.
  /// </author>
  public class PasswordAS : PTEditorAS
  {
    
    /// <summary>
    /// MVC object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ChangePassword";
    
    /// <summary>
    /// The user session for the change password page - either the normal one stored
    /// on the HTTP session or an expired one stored separately.
    /// </summary>
    protected IPTSession m_ptPasswordUserSession = null;
    
    /// <summary>
    /// Whether or not the current user session is an expired one.
    /// </summary>
    protected bool m_bExpiredSession = false;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()"></seealso>
    public override String GetEditorTitle()
    {
      return GetString(1305, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PasswordAS();
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PasswordModel.STR_MVC_CLASS_NAME;
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      // Register DisplayPages
      PasswordDP passwordDP = new PasswordDP();
      RegisterPage(passwordDP);
      // Default page
      SetCurrentPage(PasswordDP.STR_MVC_CLASS_NAME);
      // Register Views
      RegisterView(PasswordView.STR_MVC_CLASS_NAME, myModel);
      // Register Controls
      RegisterControl(ExpiredPasswordControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(ExpiredPasswordMarkAsGuestControl.STR_MVC_CLASS_NAME,
       myModel);
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1305, "ptmsgs_portalbrowsingmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PasswordDP.STR_MVC_CLASS_NAME);
      this.SetHelpTopic("PT_ChangePassword_MainSettings");
      // register the javascript handler for password validation
      passwordDP.AddToValidationFunction(PasswordValidationHelper.STR_JS_CHECK_PASSWORD);
      }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // This checks for non-guest native users, and handles expired password users as well.
      return CheckValidUser();
    }
    
    /// <returns>
    /// whether or not the user session is an expired session that needs to
    /// change it's password.
    /// </returns>
    public virtual bool GetIsExpiredSession()
    {
      return m_bExpiredSession;
    }
    
    /// <summary>
    /// Return the user's Session.  This is a generic Object that
    /// can be used for different kinds of sessions.  This will
    /// have to be cast to the correct type of session (IPTSession
    /// for the portal).
    /// This special version of this method for PasswordAS will either
    /// return the normal user session, or the cached expired user session
    /// if it is being hidden by a guest user.
    /// </summary>
    /// <returns>Object the user's session</returns>
    public override Object GetUserSession()
    {
      // If we have already looked up the user session
      if (m_ptPasswordUserSession != null)
      {
        return m_ptPasswordUserSession;
      }
      m_ptPasswordUserSession = (IPTSession) base.GetUserSession();
      if (LoginHelper.INSTANCE.GetIsGuestUser(m_ptPasswordUserSession))
      {
        // If this is a guest user, then there should be an expired user in the cache.
        IPTSession expiredSession = (IPTSession) GetPersistentSubSession().GetAttribute(ExpiredPasswordControl.SESSION);
        if (expiredSession != null)
        {
          m_ptPasswordUserSession = expiredSession;
          m_bExpiredSession = true;
        }
      }
      return m_ptPasswordUserSession;
    }
    
    /// <summary>
    /// This helper method checks that we are a valid logged in native user,
    /// or a valid user with an expired password.
    /// </summary>
    /// <param name="_space">the current space</param>
    /// <returns>true means the user is valid, false means they are not.</returns>
    public virtual bool CheckValidUser()
    {
      IPTSession ptUserSession = (IPTSession) GetUserSession();
      // Only allow password change if not guest
      if (LoginHelper.INSTANCE.GetIsGuestUser(ptUserSession))
      {
        // If this is a guest user, and there isn't an expired session to process, fail.
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, GetString(1295, ResourceConstants.PORTALBROWSINGMSGS), "");
        UIErrorHandler.RaiseError(myError, GetSubSession(), GetApplication());
        return false;
      }
      // Only allow password change if user is not synced to an auth source
      if (ptUserSession.GetUser().GetAuthenticationSourceID() != PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, GetString(1294, ResourceConstants.PORTALBROWSINGMSGS), "");
        UIErrorHandler.RaiseError(myError, GetSubSession(), GetApplication());
        return false;
      }
      return true;
    }
  }
}