using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.portalsettings.password
{
  /// <author>
  /// DonH
  /// This saves your password
  /// </author>
  public class PasswordModel : EditorModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portalsettings.password.PasswordModel");
    
    /// <summary>
    /// MVC object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ChangePassword";
    
    /// <summary>
    /// The editor start type to denote an expiration warning. 
    /// </summary>
    public const int EDITOR_START_FLAG_EXPIRATION_WARNING = 11;
    
    /// <summary>
    /// Editor Control Argument - password has expired 
    /// </summary>
    public const String PASSWORD_EXPIRED = "PasswordExpired";
    
    /// <summary>
    /// Editor Control Argument - password will expire in X days 
    /// </summary>
    public const String PASSWORD_EXPIRATION = "PasswordExpiration";
    protected PasswordAS m_passwordAS;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorModel#CheckEditorAccessAndStart(XPHashtable)"></seealso>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      // This checks for non-guest native users, and handles expired password users as well.
      if (!m_passwordAS.CheckValidUser())
      {
        return false;
      }
      // Password Expiration Messages
      String[] aExpired = (String[]) _htFormData.GetElement(PASSWORD_EXPIRED);
      if (aExpired != null)
      {
        try
        {
          bool bExpired = XPConvert.ToBoolean(aExpired[0]);
          if (bExpired)
          {
            // raise error to display to user
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             
            // Password expired
            m_asOwner.GetString(1988, ResourceConstants.PORTALBROWSINGMSGS),
             null);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
            // Remove the cancel button from the editor.
            m_bEnableCancelButton = false;
          }
        }
        catch (Exception e)
        {
          log.Warn(e, "Unable to convert password expired arg to boolean in Change Password space. Ignoring.");
          }
      }
      String[] aExpiration = (String[]) _htFormData.GetElement(PASSWORD_EXPIRATION);
      if (aExpiration != null)
      {
        try
        {
          int nExpiration = XPConvert.ToInteger(aExpiration[0]);
          if (nExpiration > 0)
          {
            // raise error to display to user
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             
            // Password will expire in X days
            XPResourceManager.FormatMessage(m_asOwner.GetString(1989, ResourceConstants.PORTALBROWSINGMSGS),
             nExpiration), null);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
          }
        }
        catch (Exception e)
        {
          log.Warn(e, "Unable to convert password expiration arg to int in Change Password space. Ignoring.");
          }
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public override void Finish()
    {
    }
    
    /// <summary>
    /// Returns the Redirect object
    /// (this is were we need to go at the end of the Editor).
    /// By default this is going to the previous AS
    /// (the one that opened this one). But Editors can override
    /// that method if they need to redirect somewhere else.
    /// </summary>
    /// <returns>Redirect</returns>
    public override Redirect GetRedirectAfterFinish()
    {
      if (m_passwordAS.GetIsExpiredSession())
      {
        // Set the pw changed variable directly on the control so that it
        // can't be hacked via QS arg manipulation by hackers.
        ExpiredPasswordControl control = (ExpiredPasswordControl) m_passwordAS.GetControl(ExpiredPasswordControl.STR_MVC_CLASS_NAME);
        control.m_bPasswordChanged = true;
        Redirect rReturn = new Redirect();
        // Create a new space so the editor is initialized for the new user.
        rReturn.SetLinkGetCachedSpace(m_asOwner);
        rReturn.SetControl(ExpiredPasswordControl.STR_MVC_CLASS_NAME);
        return rReturn;
      }
      // If this was an expiration warning, get the real login redirect.
      if (GetEditorType() == PasswordModel.EDITOR_START_FLAG_EXPIRATION_WARNING)
      {
        // Redirect to the login control and have it redirect to where
        // we are supposed to go.  It will also handle making this a 302
        // redirect so the "new" user will be logged in correctly.
        Redirect myRedirect = new Redirect();
        myRedirect.SetLinkGetSpaceIfCached(LoginAS.STR_MVC_CLASS_NAME, m_asOwner);
        myRedirect.SetControl(LoginControl.STR_MVC_CLASS_NAME);
        myRedirect.AddControlArgument(LoginHelper.PARAM_DONT_LOGIN_JUST_REDIRECT,
         true);
        return myRedirect;
      }
      return base.GetRedirectAfterFinish();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      String[] sValues;
      // PasswordActions PEI
      // BrianH: All of the following code will load all of the available PasswordAction
      // PEIs and process through them. If they return a false string an error will 
      // appear and the saving of the password will stop.
      Object[] oa;
      Object o;
      IPasswordActions iActions;
      IApplication application = m_asOwner.GetApplication();
      oa = (Object[]) application.GetCachingManager().GetEntry("PasswordActions");
      if (oa != null)
      {
        String sErrorMsgs = "";
        for (int x = 0;x < oa.Length;x++)
        {
          o = oa[x];
          log.Debug("PasswordModel.SavePage - About to call OnChangePassword on an: " + o);
          if (o != null)
          {
            iActions = (IPasswordActions) o;
            String sError = iActions.OnBeforeChangePassword(m_asOwner, (IPTSession) m_asOwner.GetUserSession(),
             _htFormData);
            if ((null != sError) && (sError.Length > 0))
            {
              sErrorMsgs+=sError + " ";
            }
          }
        }
        if ((null != sErrorMsgs) && (sErrorMsgs.Length > 0))
        {
          UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER,
           null, sErrorMsgs, sErrorMsgs);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          return RepostControl.PAGE_STATUS_INVALID;
        }
      }
      //PEI : OnChangePassword : END
      // Old password
      sValues = (String[]) _htFormData.GetElement(PasswordView.HTML_INPUT_OLD_PASSWORD);
      if (sValues == null)
      {
        log.Error("Could not find old password in form data.");
        return RepostControl.PAGE_STATUS_INVALID;
      }
      String strOldPassword = sValues[0];
      // New password
      sValues = (String[]) _htFormData.GetElement(PasswordView.HTML_INPUT_NEW_PASSWORD);
      if (sValues == null)
      {
        log.Error("Could not find new password in form data.");
        return RepostControl.PAGE_STATUS_INVALID;
      }
      String strNewPassword = sValues[0];
      // Confirm new password
      sValues = (String[]) _htFormData.GetElement(PasswordView.HTML_INPUT_CONFIRM_NEW_PASSWORD);
      if (sValues == null)
      {
        log.Error("Could not find confirm new password in form data.");
        return RepostControl.PAGE_STATUS_INVALID;
      }
      String strConfirmNewPassword = sValues[0];
      // Check if new passwords are the same
      if (!strNewPassword.Equals(strConfirmNewPassword))
      {
        log.Info("New passwords do not match.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1290, "ptmsgs_portalbrowsingmsgs"), "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      IPTSession myRealIPTSession = (IPTSession) m_asOwner.GetUserSession();
      int nUserID = myRealIPTSession.GetSessionInfo().GetCurrentUserID();
      // Check old password
      try
      {
        IPTSession myTestIPTSession = PortalObjectsFactory.CreateSession();
        // null login token
        myTestIPTSession.Connect(nUserID, strOldPassword, null);
      }
      catch (Exception e)
      {
        log.Info(e, "Could not connect with old password while trying to change the password.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1292, "ptmsgs_portalbrowsingmsgs"), "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      // Check that the old password and new password are not the same
      if (XPStringUtility.Compare(strNewPassword, strOldPassword) == 0)
      {
        log.Info("Old and new passwords cannot be the same.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1744, ResourceConstants.PORTALBROWSINGMSGS),
         "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      // Change password
      // This should really be in Finish(), but Finish() does not allow
      // the same kind of error reporting as SavePage().
      try
      {
        myRealIPTSession.ChangePassword(strOldPassword, strNewPassword);
      }
      catch (Exception e)
      {
        log.Info(e, "Could not change password.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(1293, ResourceConstants.PORTALBROWSINGMSGS),
         "");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
      // Add the old password to the user's password history.
      IPTUserManager users = (IPTUserManager) myRealIPTSession.GetUsers();
      users.UpdatePasswordHistory(nUserID, strOldPassword);
      // Reset the user's changed password time to now.
      long lNow = XPSystem.GetCurrentTimeMilliSec();
      IPTObjectProperties props = myRealIPTSession.GetUser().GetObjectProperties();
      Object[][] propdata = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        propdata[j2c_index] = new Object[1];
      }
      propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_PROPERTYID][0] = PT_INTRINSICS.PT_PASSWORD_LAST_CHANGED;
      propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_VALUE][0] = lNow;
      props.SetPropertyData(propdata);
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PasswordModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Inits the Model with the Activity Space.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace _parent)
    {
      m_passwordAS = (PasswordAS) _parent;
      base.Init(_parent);
    }
  }
}