using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.userprofile;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.common.constants;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.browsing.portalsettings.passwordmanager
{
  /// <author>JenniferSu</author>
  public class PasswordManagerAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerAS");
    private const String sClassName = "com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerAS";
    
    /// <summary>
    /// object name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PasswordManagerAS";
    
    /// <summary>
    /// member variable describing the lockbox object editor *
    /// </summary>
    public const String m_strLockboxObjEdit = "ObjectEditor";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PasswordManagerAS();
    }
    
    /// <summary>
    /// Sets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      return GetString(1835, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (UserProfileRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = PasswordManagerModel.STR_MVC_CLASS_NAME;
      base.Init();
      PasswordManagerModel myModel = (PasswordManagerModel) GetModel(m_strModelName);
      RegisterControl(UserProfileRepostControl.STR_MVC_CLASS_NAME, myModel);
      XPArrayList alPages = myModel.GetProfilePages();
      if (alPages != null && alPages.GetSize() > 0)
      {
        IPTProfilePage page = (IPTProfilePage) alPages.GetElement(0);
        Object[] arSections = page.GetChildSections();
        String subHeaderText = null;
        if (arSections.Length == 0)
        {
          subHeaderText = GetString(1898, ResourceConstants.PORTALBROWSINGMSGS);
          } else
        {
          subHeaderText = GetString(1837, ResourceConstants.PORTALBROWSINGMSGS);
          }
        GeneralProfileDP passwordManagerDP = new GeneralProfileDP(page, 0,
         "MainDP", GetString(1836, ResourceConstants.PORTALBROWSINGMSGS),
         subHeaderText);
        RegisterPage(passwordManagerDP);
        IPTObjectManager profileSectionObjMgr = ((IPTSession) GetUserSession()).GetProfileSections();
        ((PasswordManagerModel) GetModel(m_strModelName)).SetNumProfileSectionsTable(0,
         arSections.Length);
        // mel: Fix for bug# 45118, XPNullPointerException was thrown
        // when Password Manager initialized because no model
        // was registered if no lockboxes were configured.
        if (arSections.Length == 0)
        {
          RegisterModel(UserProfileObjEditModel.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "00");
          } else
        {
          for (int indLockbox = 0;indLockbox < arSections.Length;indLockbox++)
          {
            int nSectionID = XPConvert.ToInteger(arSections[indLockbox]);
            IPTProfileSection profileSection = (IPTProfileSection) profileSectionObjMgr.Open(nSectionID,
             false);
            RegisterModel(UserProfileObjEditModel.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "0" + indLockbox);
            // Get back the Model we just registered because we need it to register the Section
            UserProfileObjEditModel myObjEditorModel = (UserProfileObjEditModel) GetModel(m_strLockboxObjEdit + "0" + indLockbox);
            myObjEditorModel.Init(profileSection);
            RegisterView(GeneralInfoView.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "0" + indLockbox,
             myObjEditorModel);
            RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "0" + indLockbox,
             myObjEditorModel);
          }
        }
      } else
      {
        log.Error(STR_MVC_CLASS_NAME + "::Init Unable to load PTProfilePage for the PasswordManager.");
        String sMessage = "Unable to load PTProfilePage for the PasswordManager";
        String sExceptionMessage = "Unable to load PTProfilePage for the PasswordManager";
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, sMessage, null);
        UIErrorHandler.RaiseError(myError, GetSubSession(), GetApplication());
        throw new XPException(sExceptionMessage);
      }
      SetCurrentPage("MainDP");
      this.SetHelpTopic("PT_PasswordManager");
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      // make sure this is not the guest user
      bool isGuest = PlumtreeHelpers.IsGuestSession(this);
      if (isGuest)
      {
        return false;
      }
      return true;
    }
  }
}