using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.userprofile;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.portalsettings.passwordmanager
{
  /// <author>jennifersu</author>
  public class PasswordManagerModel : UserProfileModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerModel");
    
    /// <summary>
    /// object name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PasswordManagerModel";
    private Object[] m_arLockboxes;
    
    /// <summary>
    /// Code executed when the Editor is starting. Get all of the property
    /// information for the user
    /// </summary>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      bool bAccess;
      bAccess = base.CheckEditorAccessAndStart(_htFormData);
      SetHideLeftNav(true);
      IPTProfilePage ptProfilePage = (IPTProfilePage) m_alProfilePages.GetElement(0);
      m_arLockboxes = ptProfilePage.GetChildSections();
      return bAccess;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PasswordManagerModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="aspace"></param>
    public override void Init(AActivitySpace aspace)
    {
      m_asOwner = aspace;
      // Look up lockboxes.
      m_alProfilePages = new XPArrayList();
      IPTObjectManager profilePageObjMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProfilePages();
      PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(profilePageObjMgr);
      Object[][] queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID,
       PT_FILTEROPS.PT_FILTEROP_EQ, PT_INTRINSICS.PT_PROFILE_PAGE_CREDENTIAL_VAULT);
      omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, queryFilter);
      if (omqw.GetCount() > 0)
      {
        IPTProfilePage page = (IPTProfilePage) profilePageObjMgr.Open(1, false);
        m_alProfilePages.Add(page);
        m_numProfilePages++;
      }
      //Load all property values into a hashtable
      m_htPropTypeTable = new XPHashtable();
      m_htPropValueTable = PutUserPropertiesIntoHashtable();
    }
    
    /// <param name="_sectionIndex"></param>
    /// <returns></returns>
    public virtual Object[] GetLockboxIDs()
    {
      return m_arLockboxes;
    }
    
    /// <summary>
    /// We need to overwrite this method here, simply because parent implements it within
    /// its own context, which fails for this specific class. Basically we are replication
    /// what was implemented in EditorModel here.
    /// </summary>
    /// <returns></returns>
    public override Redirect GetRedirectAfterFinish()
    {
      Redirect result = new Redirect();
      if (null != m_asOwner.GetParentSpace())
      {
        result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
      } else
      {
        result.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
        }
      return (result);
    }
  }
}