using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.portalsettings.passwordmanager
{
  /// <author>jennifersu</author>
  public class PasswordManagerRepostControl : EditorRepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerRepostControl");
    
    /// <summary>
    /// object name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PasswordManagerRepostControl";
    public const int POSTTOSELF_ACTION_508_ADDROW = 30;
    public const int POSTTOSELF_ACTION_508_REMOVEROW = 31;
    public const String HTMLSUBMIT_508_ADDREMOVEROW = "in_su_508AddRemoveRow_";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PasswordManagerRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
    }
    
    /// <summary>
    /// Get the repost action mode from the form data
    /// hashtable and set it in the member variable.
    /// </summary>
    protected override void SetRepostAction()
    {
      if ((AccessStyles.LOW_BANDWIDTH == m_asOwner.GetAccessStyle()) || (AccessStyles.SECTION_508 == m_asOwner.GetAccessStyle()))
      {
        // JF- If we are in 508 mode, we get the repost action from the submit button name.
        // E.g.: if the button that submitted the form was:
        //       <input type="submit" name="in_su_508PostToSelf_2" value="Done">
        //       The repost action will be 2.
        IXPEnumerator enumFormKeys = m_htFormData.GetKeys();
        String sKey;
        while (enumFormKeys.MoveNext())
        {
          sKey = (String) enumFormKeys.GetCurrent();
          if (XPStringUtility.StartsWith(sKey, PasswordManagerRepostControl.HTMLSUBMIT_508_ADDREMOVEROW))
          {
            try
            {
              String sRepostAction = XPStringUtility.Substring(sKey, PasswordManagerRepostControl.HTMLSUBMIT_508_ADDREMOVEROW.Length,
               XPStringUtility.LastIndexOf(sKey, '_'));
              m_nAction = XPConvert.ToInteger(sRepostAction);
              log.Debug(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID value: " + m_nAction);
              break;
            }
            catch (Exception e)
            {
              log.Error(STR_MVC_CLASS_NAME + "::SetRepostAction Unable to retrieve the 508 repost " + "action from the submit button: " + sKey);
              }
          } else
          if (XPStringUtility.StartsWith(sKey, HTMLSUBMIT_508_POSTTOSELF))
          {
            try
            {
              String sRepostAction = XPStringUtility.Substring(sKey, RepostControl.HTMLSUBMIT_508_POSTTOSELF.Length);
              m_nAction = XPConvert.ToInteger(sRepostAction);
              log.Debug(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID value: " + m_nAction);
              break;
            }
            catch (Exception e)
            {
              log.Error(STR_MVC_CLASS_NAME + "::SetRepostAction Unable to retrieve the 508 repost " + "action from the submit button: " + sKey);
              }
          }
        }
      } else
      if (m_htFormData.ContainsKey(HTMLINPUT_POSTTOSELF))
      {
        String[] data = (String[]) m_htFormData.GetElement(HTMLINPUT_POSTTOSELF);
        if ((0 != data.Length) && (null != data[0]))
        {
          m_nAction = XPConvert.ToInteger(data[0]);
          log.Debug(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID value: " + m_nAction);
          } else
        {
          log.Warn(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID was not in Query String.");
          }
      }
    }
  }
}