using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.portalsettings.passwordmanager
{
  /// <author>jennifersu</author>
  public class PasswordManagerSectionModel : EditorHelperModel,IPasswordManagerSectionModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerSectionModel");
    
    /// <summary>
    /// object name *
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PasswordManagerSectionModel";
    protected int m_nUsernamePropID;
    protected int m_nPasswordPropID;
    protected IPTSession m_ptSession;
    protected IPTProperty m_objUsernameProp;
    protected IPTProperty m_objPasswordProp;
    protected String m_strUsernameValue;
    protected String m_strPasswordValue;
    protected IPTProfileSection m_ptLockbox;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PasswordManagerSectionModel();
    }
    
    /// <summary>
    /// Initialize member variables
    /// </summary>
    /// <param name="_ptLockbox">- IPTProfileSection that this lockbox represents.</param>
    public virtual void Init(IPTProfileSection _ptLockbox)
    {
      m_ptLockbox = _ptLockbox;
      Object[] arPropIDs = m_ptLockbox.GetChildProperties();
      if (arPropIDs.Length >= 2)
      {
        m_nUsernamePropID = XPConvert.ToInteger(arPropIDs[0]);
        m_nPasswordPropID = XPConvert.ToInteger(arPropIDs[1]);
      }
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTObjectManager propMgr = m_ptSession.GetProperties();
      IPTProfileManager pm = (IPTProfileManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER,
       false);
      IPTObjectProperties userProps = pm.GetUserProperties(((IPTSessionInfo) m_ptSession.GetSessionInfo()).GetCurrentUserID(),
       true);
      // Load username
      IPTQueryResult ptQR = propMgr.QuerySingleObject(m_nUsernamePropID);
      if (ptQR.RowCount() > 0)
      {
        m_objUsernameProp = (IPTProperty) propMgr.Open(m_nUsernamePropID,
         false);
        ptQR = userProps.GetSinglePropertyData(m_nUsernamePropID, PT_PROPIDS.PT_PROPID_PROP_VALUE);
        if (ptQR.RowCount() > 0)
        {
          m_strUsernameValue = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);
          }
      }
      // Load password
      ptQR = propMgr.QuerySingleObject(m_nPasswordPropID);
      if (ptQR.RowCount() > 0)
      {
        m_objPasswordProp = (IPTProperty) propMgr.Open(m_nPasswordPropID,
         false);
        ptQR = userProps.GetSinglePropertyData(m_nPasswordPropID, PT_PROPIDS.PT_PROPID_PROP_VALUE);
        if (ptQR.RowCount() > 0)
        {
          m_strPasswordValue = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);
          }
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nValid = RepostControl.PAGE_STATUS_VALID;
      m_strUsernameValue = ModelHelper.GetFormElementString(_htFormData, LockboxView.HTMLINPUT_USERNAME + m_nUsernamePropID,
       m_strUsernameValue);
      m_strPasswordValue = ModelHelper.GetFormElementString(_htFormData, LockboxView.HTMLINPUT_PASSWORD + m_nPasswordPropID,
       m_strPasswordValue);
      return nValid;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetUsernameValue()
     */
     
    public virtual String GetUsernameValue()
    {
      return m_strUsernameValue;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetPasswordValue()
     */
     
    public virtual String GetPasswordValue()
    {
      return m_strPasswordValue;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetUsernamePropName()
     */
     
    public virtual String GetUsernamePropName()
    {
      return m_objUsernameProp.GetLocalizedName();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetPasswordPropName()
     */
     
    public virtual String GetPasswordPropName()
    {
      return m_objPasswordProp.GetLocalizedName();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetLockboxName()
     */
     
    public virtual String GetLockboxName()
    {
      return m_ptLockbox.GetLocalizedName();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetUsernamePropID()
     */
     
    public virtual int GetUsernamePropID()
    {
      return m_nUsernamePropID;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetPasswordPropID()
     */
     
    public virtual int GetPasswordPropID()
    {
      return m_nPasswordPropID;
    }
  }
}