using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.portalpages.browsing.portalsettings;
using com.plumtree.portalpages.browsing.portalsettings.password;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.uiinfrastructure.login;
namespace com.plumtree.portalpages.browsing.portalsettings.settings
{
  /// <author>
  /// DonH
  /// This describes a link to the change password space.
  /// </author>
  public class PasswordPortalSetting : IPortalSettings
  {
    
    /// <seealso cref="com.plumtree.portalpages.browsing.portalsettings.IPortalSettings#GetDescription(String)"></seealso>
    public virtual String GetDescription(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(1815, "ptmsgs_portalbrowsingmsgs", _strLangID);
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.portalsettings.IPortalSettings#GetImageLocation()"></seealso>
    public virtual String GetImageLocation()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.portalsettings.IPortalSettings#GetDisplaySetting(Object)"></seealso>
    public virtual bool GetDisplaySetting(Object session)
    {
      IPTSession ptSession = (IPTSession) session;
      // Only display if not guest
      // WilliamA - Change guest user detection for multiple-guest-user support
      /*
       if (ptSession.GetSessionInfo().GetCurrentUserID() == PT_INTRINSICS.PT_USER_GUEST)
       {
       return false;
       }
       */
       
      if (LoginHelper.INSTANCE.GetIsGuestUser(ptSession))
      {
        return false;
      }
      // Need to catch -- bug where user could not see own account... not OK
      try
      {
        // Only display setting if user is not synced to an auth source
        if (ptSession.GetUser().GetAuthenticationSourceID() != PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE)
        {
          return false;
        }
      }
      catch (Exception e)
      {
        //SS - If the server throws an error we assume that the setting should not 
        //be displayed.
        return false;
      }
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#GetASControlName()"></seealso>
    public virtual String GetASControlName()
    {
      return EditorStartControl.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#GetASDPName()"></seealso>
    public virtual String GetASDPName()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#GetASName()"></seealso>
    public virtual String GetASName()
    {
      return PasswordAS.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#GetASQueryString()"></seealso>
    public virtual String GetASQueryString()
    {
      return LinkConstants.AMPERSAND + EditorStartControl.QS_EDITOR_TYPE + LinkConstants.EQUALS + EditorStartControl.EDITOR_START_FLAG_MISC;
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#GetLinkText(String)"></seealso>
    public virtual String GetLinkText(String _strLangID)
    {
      IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
      XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
      return rm.GetString(1305, "ptmsgs_portalbrowsingmsgs", _strLangID);
      }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#IsStandardPortalOption()"></seealso>
    public virtual bool IsStandardPortalOption()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.browsing.settings.ISettings#IsViewable()"></seealso>
    public virtual bool IsViewable()
    {
      return true;
    }
    public virtual int GetActivityRightRestriction()
    {
      return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE;
    }
  }
}