using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.portletpreview
{
  /// <summary>
  /// File: AddPortletControl.java
  /// ---------------------------
  /// Control for adding gadget via gadget invitation
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class AddPortletControl : RepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portletpreview.AddPortletControl");
    public const String STR_MVC_CLASS_NAME = "AddGadget";
    
    /// <summary>
    /// QueryString Parameter for Page ID
    /// </summary>
    public const String strPageParam = "in_se_pageMenu";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private PreviewPortletModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      Redirect objRedirect = new Redirect();
      objRedirect.SetLinkGetCachedSpace(m_asOwner);
      objRedirect.SetDisplayPage(PortletInvitationJoinDP.STR_MVC_CLASS_NAME);
      String[] sValues = (String[]) arguments.GetElement(strPageParam);
      if (sValues == null)
      {
        // DCA - Fix to bug #27785: since this is merely a preview of the portlet,
        // repost functionality will be ignored
        log.Warn("Could not find page ID in query string. Cannot handle portlet reposting in preview mode.");
        return null;
      }
      String[] sHostPageURIs = (String[]) arguments.GetElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL);
      if ((null != sHostPageURIs) && (sHostPageURIs.Length > 0))
      {
        m_asModel.SetHostPageURI(sHostPageURIs[0]);
      }
      String[] sHeaders = (String[]) arguments.GetElement(HttpUtils.HASHTABLE_CONTROL_KEY_HTTP_HEADERS);
      if ((null != sHeaders) && (sHeaders.Length > 0))
      {
        m_asModel.SetRawHeaders(sHeaders[0]);
      }
      m_asModel.SetPageID(XPConvert.ToInteger(sValues[0]));
      if (m_asModel.IsPortletInPage())
      {
        m_asModel.SetErrorPage(true);
      } else
      {
        m_asModel.SetErrorPage(false);
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          m_asModel.AddPortletInPage();
        } else
        {
          if (arguments.GetElement(RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH) != null)
          {
            m_asModel.AddPortletInPage();
          }
        }
      }
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        return objRedirect;
      } else
      {
        if (m_asModel.IsErrorPage() && arguments.GetElement(RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH) != null)
        {
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, XPResourceManager.FormatMessage(m_asOwner.GetString(591,
           "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(m_asModel.GetPortletName())),
           XPResourceManager.FormatMessage(m_asOwner.GetString(591, "ptmsgs_portalbrowsingmsgs"),
           XPHttpUtility.HtmlEncode(m_asModel.GetPortletName())));
          myError.SetDisplayOnSeparatePage(false);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          Redirect obj508Redirect = new Redirect();
          obj508Redirect.SetLinkGetCachedSpace(m_asOwner);
          obj508Redirect.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
          return obj508Redirect;
        } else
        {
          Redirect obj508Redirect = new Redirect();
          obj508Redirect.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME,
           m_asOwner);
          return obj508Redirect;
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new AddPortletControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public override void Init(IModel model, AActivitySpace space)
    {
      base.Init(model, space);
      m_asModel = (PreviewPortletModel) model;
      m_asOwner = space;
    }
  }
}