using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.portletpreview
{
  /// <summary>
  /// File: IPreviewPortletModelRO
  /// ---------------------------
  /// Read Only Interface for the PreviewPortletModel.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  /// <author>DavidP</author>
  public interface IPreviewPortletModelRO : IModelRO
  {
    
    /// <summary>
    /// AddPortletInPage - adds gadget to the specified user's page
    /// </summary>
    /// <param name="int">nPageID</param>
    void AddPortletInPage();
    
    /// <summary>
    /// Get Default MyPage URL
    /// </summary>
    /// <returns>String</returns>
    String GetDefaultMyPageURL();
    
    /// <summary>
    /// Get the gadget alignment
    /// </summary>
    /// <returns>String</returns>
    int GetPortletAlignment();
    
    /// <summary>
    /// Get the gadget HTML Text
    /// </summary>
    /// <returns>String</returns>
    Object[][] GetPortletHTMLText();
    
    /// <summary>
    /// Get the gadget id
    /// </summary>
    /// <returns>int</returns>
    int GetPortletID();
    
    /// <summary>
    /// Get the gadget index for selection page
    /// </summary>
    /// <returns>int</returns>
    int GetPortletIndex();
    
    /// <summary>
    /// Get the gadget name
    /// </summary>
    /// <returns>String</returns>
    String GetPortletName();
    
    /// <summary>
    /// Get the gadget name
    /// </summary>
    /// <returns>String</returns>
    String GetPortletDescription();
    
    /// <summary>
    /// Get Preview Portlet URL
    /// </summary>
    /// <returns>String</returns>
    String GetPortletPreviewURL();
    
    /// <summary>
    /// Returns the gadget type
    /// </summary>
    /// <returns>Portlet type</returns>
    int GetPortletType();
    
    /// <summary>
    /// Returns true if the community preview mode should be used even if the portlet is not community-only
    /// </summary>
    /// <returns>True if the community preview mode should be used even if the portlet is not community-only</returns>
    bool GetAlwaysUseCommunityPreview();
    
    /// <summary>
    /// Get MyPage URL
    /// </summary>
    /// <returns>String</returns>
    String GetMyPageURL();
    
    /// <summary>
    /// Get My Pages
    /// </summary>
    /// <returns>boolean</returns>
    IASQueryResult GetMyPages();
    
    /// <summary>
    /// Get the page id
    /// </summary>
    /// <returns>int</returns>
    int GetPageID();
    
    /// <summary>
    /// Get the page name
    /// </summary>
    /// <returns>String</returns>
    String GetPageName();
    
    /// <summary>
    /// Returns the user session
    /// </summary>
    /// <returns>IPTSession</returns>
    IPTSession GetSession();
    
    /// <summary>
    /// Returns the user ID
    /// </summary>
    /// <returns>User ID</returns>
    int GetUserID();
    
    /// <summary>
    /// IsErrorPage
    /// </summary>
    /// <param name="boolean"></param>
    bool IsErrorPage();
    
    /// <summary>
    /// Is Portlet Checked
    /// </summary>
    /// <returns>boolean</returns>
    bool IsPortletChecked();
    
    /// <summary>
    /// IsPortletInPage - checks to if the gadget is already in
    /// the user's page thatt's specified
    /// </summary>
    /// <param name="int">nPageID</param>
    bool IsPortletInPage();
    
    /// <summary>
    /// Is Portlet Invite Page
    /// </summary>
    /// <returns>boolean</returns>
    bool IsPortletInvitePage();
    
    /// <summary>
    /// Is Search Preview Portlet
    /// </summary>
    /// <returns>boolean</returns>
    bool IsPortletSearchPreviewPage();
    
    /// <summary>
    /// Is Portlet Selection Preview Page
    /// </summary>
    /// <returns>boolean</returns>
    bool IsPortletSelectionPreviewPage();
    
    /// <summary>
    /// Is Portlet Narrow
    /// </summary>
    /// <returns>boolean</returns>
    bool IsNarrow();
    
    /// <summary>
    /// User Has Read Access
    /// </summary>
    /// <returns>boolean</returns>
    bool UserHasReadAccess();
    
    /// <summary>
    /// User Has Select Access
    /// </summary>
    /// <returns>boolean</returns>
    bool UserHasSelectAccess();
    
    /// <summary>
    /// User Has My Page Access
    /// </summary>
    /// <returns>boolean</returns>
    bool UserHasMyPageAccess();
    
    /// <summary>
    /// List of Communities Containing This Portlet 
    /// </summary>
    /// <returns>boolean</returns>
    XPArrayList GetAllCommunitiesUsingPortlet();
    
    /// <summary>
    /// Is Portlet Enabled
    /// </summary>
    /// <returns>boolean</returns>
    bool IsPortletEnabled();
    
    /// <summary>
    /// Get Disabled Message if portlet is disabled
    /// </summary>
    /// <returns>String</returns>
    String GetPortletDisabledMessage();
    
    /// <summary>
    /// Get Add Portlet Javascript override.
    /// This javascript should be the name of the javascript function to be
    /// used in the onclick attribute of the add button.  The function should
    /// take 2 arguments: the portlet ID, and a reference to the popup window.
    /// (i.e. If the name is "addPortlet", then the function will look like
    /// this: "addPortlet(portletID, self)").  This function name can also
    /// include an optional window reference (i.e. "opener.addPortlet").
    /// </summary>
    /// <returns>
    /// String the name of the javascript function to use when adding the portlet.
    /// This string will be null if there is no override.
    /// </returns>
    String GetAddPortletJavaScriptOverride();
  }
}