using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.portletpreview
{
  /// <summary>
  /// File: InvitePortletJSView.java
  /// -----------------------------
  /// Section for Portlet Invitation JavaScript.  This is a blank page
  /// that simply popups up the Portlet Invitation.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class InvitePortletJSView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portletpreview.InvitePortletJSView");
    public const String STR_MVC_CLASS_NAME = "InvitePortletJS";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private IPreviewPortletModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new InvitePortletJSView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLTable table = new HTMLTable();
      HTMLTableRow tRow = new HTMLTableRow();
      HTMLTableCell tCell = new HTMLTableCell();
      try
      {
        tCell.AddInnerHTMLString("<b>" + m_asOwner.GetString(601, "ptmsgs_portalbrowsingmsgs") + "</b>");
        tRow.AddInnerHTMLElement(tCell);
        table.AddInnerHTMLElement(tRow);
      }
      catch (HTMLException he)
      {
        log.Error(he, he.Message);
      }
      return table;
    }
    
    /// <summary>
    /// Display JavaScript - this includes the static source file
    /// return HTMLScript
    /// </summary>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) + "opennewwindow.js");
      return script;
    }
    
    /// <summary>
    /// Display JavaScript - this includes the static source file
    /// return HTMLScript
    /// </summary>
    public virtual HTMLScript DisplayRedirectJavascript()
    {
      NavigationModel navModel = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      ASURL defaultURL = navModel.GetDefaultSubportalURL();
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      try
      {
        if (m_asModel.IsNarrow())
        {
          script.AddInnerHTMLString("OpenNarrowGadgetPreviewWindow(\'" + m_asModel.GetPortletPreviewURL() + "\');\n");
          script.AddInnerHTMLString("window.history.go(-1);");
        } else
        {
          script.AddInnerHTMLString("OpenWideGadgetPreviewWindow(\'" + m_asModel.GetPortletPreviewURL() + "\');\n");
          script.AddInnerHTMLString("window.history.go(-1);");
        }
        if (m_asModel.IsPortletInvitePage())
        {
          script.AddInnerHTMLString("window.location=\'" + defaultURL.GetURLAsString() + "\';");
          }
      }
      catch (HTMLException he)
      {
        log.Error(he, he.Message);
      }
      return script;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IPreviewPortletModelRO) model;
      m_asOwner = parent;
    }
  }
}