using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.portletpreview
{
  /// <summary>
  /// File: PortletInvitationJoinView.java
  /// --------------------------------------
  /// Section for adding a gadget via an invitation.  This
  /// view displays a congratulations message if the gadget is successfully
  /// joined, and an error message if the user is already has that gadget.
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  public class PortletInvitationJoinView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portletpreview.PortletInvitationJoinView");
    public const String STR_MVC_CLASS_NAME = "PortletInvitationJoin";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private IPreviewPortletModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PortletInvitationJoinView();
    }
    
    /// <summary>
    /// Method createConfirmOfJoinPage - displays page that confirms the adding
    /// of a gadget and allows to view the affected page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public virtual HTMLElement CreateConfirmOfAddPage()
    {
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow1 = new HTMLTableRow();
      HTMLTableRow mainRow2 = new HTMLTableRow();
      HTMLTableRow mainRow3 = new HTMLTableRow();
      HTMLTableCell mainRow1Cell = new HTMLTableCell();
      HTMLTableCell mainRow2Cell = new HTMLTableCell();
      HTMLTableCell mainRow3Cell = new HTMLTableCell();
      //congratsTable componenets
      HTMLTable congratsTable = new HTMLTable();
      HTMLTableRow congratsRow = new HTMLTableRow();
      HTMLTableCell congratsCell = new HTMLTableCell();
      //linksTable components
      HTMLTable linksTable = new HTMLTable();
      HTMLTableRow linksRow1 = new HTMLTableRow();
      HTMLTableRow linksRow2 = new HTMLTableRow();
      HTMLTableRow linksRow3 = new HTMLTableRow();
      HTMLTableRow linksRow4 = new HTMLTableRow();
      HTMLTableRow linksRow5 = new HTMLTableRow();
      HTMLTableCell linksRow1Cell = new HTMLTableCell();
      HTMLTableCell linksRow2Cell = new HTMLTableCell();
      HTMLTableCell linksRow3Cell = new HTMLTableCell();
      HTMLTableCell linksRow4Cell = new HTMLTableCell();
      HTMLTableCell linksRow5Cell = new HTMLTableCell();
      // use asurl to create URL, then pass string to anchor
      ASURL asurl = new ASURL(m_asOwner);
      asurl.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      asurl.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
      asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(m_asModel.GetPageID()));
      //Anchors
      String strMyPage = m_asModel.GetMyPageURL();
      HTMLAnchor newMyPageAnchor = new HTMLAnchor(strMyPage);
      newMyPageAnchor.SetOnClick("window.opener.location=\'" + asurl.GetURLAsString() + "\';window.close();");
      newMyPageAnchor.AddInnerHTMLString(m_asOwner.GetString(589, "ptmsgs_portalbrowsingmsgs"));
      asurl = new ASURL(m_asOwner);
      asurl.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      asurl.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
      asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, SetPageControl.N_HOME_PAGE_ID);
      String strDefMyPage = m_asModel.GetDefaultMyPageURL();
      HTMLAnchor defMyPageAnchor = new HTMLAnchor(strDefMyPage);
      defMyPageAnchor.SetOnClick("window.opener.location=\'" + asurl.GetURLAsString() + "\';window.close();");
      defMyPageAnchor.AddInnerHTMLString(m_asOwner.GetString(590, "ptmsgs_portalbrowsingmsgs"));
      HTMLAnchor closeAnchor = new HTMLAnchor("");
      closeAnchor.SetOnClick("window.close();");
      closeAnchor.AddInnerHTMLString(m_asOwner.GetString(1317, "ptmsgs_portalbrowsingmsgs"));
      //Community Name
      String strPortletName = m_asModel.GetPortletName();
      //Specifying mainTable attributes
      mainTable.SetAlign("center");
      mainTable.SetBorder("0");
      mainTable.SetCellPadding("0");
      mainTable.SetWidth("90%");
      mainTable.SetHeight("30%");
      //Specifying congratsTable attributes
      //class="gHeader" border="0" cellpadding="4" width="100%"
      congratsTable.SetBorder("0");
      congratsTable.SetCellPadding("0");
      congratsTable.SetWidth("100%");
      //Specifying linksTable attributes
      //border="0" cellpadding="0" width="100%"
      linksTable.SetBorder("0");
      linksTable.SetCellPadding("0");
      linksTable.SetWidth("100%");
      //Setting up congratulations table
      congratsCell.SetStyleClass(PTStyleClass.ALERT_TITLE);
      congratsCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(588,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strPortletName)));
      PreviewCommunityView.addRowCell(congratsTable, congratsRow, congratsCell);
      //Setting up linksTable
      linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow1Cell.AddInnerHTMLElement(newMyPageAnchor);
      linksRow2Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      linksRow3Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow3Cell.AddInnerHTMLElement(defMyPageAnchor);
      linksRow4Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      linksRow5Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow5Cell.AddInnerHTMLElement(closeAnchor);
      PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow4, linksRow4Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow5, linksRow5Cell);
      //Setting up the Main Table
      mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mainRow2Cell.AddInnerHTMLElement(congratsTable);
      mainRow3Cell.AddInnerHTMLElement(linksTable);
      PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
      //display page
      return mainTable;
    }
    
    /// <summary>
    /// Method createErrorPage - displays the error page if user is already a
    /// member of the community specified
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public virtual HTMLElement CreateErrorPage()
    {
      //mainTable components
      HTMLTable mainTable = new HTMLTable();
      HTMLTableRow mainRow1 = new HTMLTableRow();
      HTMLTableRow mainRow2 = new HTMLTableRow();
      HTMLTableRow mainRow3 = new HTMLTableRow();
      HTMLTableCell mainRow1Cell = new HTMLTableCell();
      HTMLTableCell mainRow2Cell = new HTMLTableCell();
      HTMLTableCell mainRow3Cell = new HTMLTableCell();
      //errorTable componenets
      HTMLTable errorTable = new HTMLTable();
      HTMLTableRow errorRow = new HTMLTableRow();
      HTMLTableCell errorCell = new HTMLTableCell();
      //linksTable components
      HTMLTable linksTable = new HTMLTable();
      HTMLTableRow linksRow1 = new HTMLTableRow();
      HTMLTableRow linksRow2 = new HTMLTableRow();
      HTMLTableRow linksRow3 = new HTMLTableRow();
      HTMLTableRow linksRow4 = new HTMLTableRow();
      HTMLTableRow linksRow5 = new HTMLTableRow();
      HTMLTableCell linksRow1Cell = new HTMLTableCell();
      HTMLTableCell linksRow2Cell = new HTMLTableCell();
      HTMLTableCell linksRow3Cell = new HTMLTableCell();
      HTMLTableCell linksRow4Cell = new HTMLTableCell();
      HTMLTableCell linksRow5Cell = new HTMLTableCell();
      // use asurl to create URL, then pass string to anchor
      ASURL asurl = new ASURL(m_asOwner);
      asurl.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      asurl.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
      asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, XPConvert.ToString(m_asModel.GetPageID()));
      //Anchors
      String strNewMyPage = m_asModel.GetMyPageURL();
      HTMLAnchor newMyPageAnchor = new HTMLAnchor(strNewMyPage);
      newMyPageAnchor.SetOnClick("window.opener.location=\'" + asurl.GetURLAsString() + "\';window.close();");
      newMyPageAnchor.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(592,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(m_asModel.GetPageName())));
      asurl = new ASURL(m_asOwner);
      asurl.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      asurl.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
      asurl.AddControlArgument(SetPageControl.STR_PAGE_ID, SetPageControl.N_HOME_PAGE_ID);
      String strDefMyPage = m_asModel.GetDefaultMyPageURL();
      HTMLAnchor defMyPageAnchor = new HTMLAnchor(strDefMyPage);
      defMyPageAnchor.SetOnClick("window.opener.location=\'" + asurl.GetURLAsString() + "\';window.close();");
      defMyPageAnchor.AddInnerHTMLString(m_asOwner.GetString(590, "ptmsgs_portalbrowsingmsgs"));
      HTMLAnchor closeAnchor = new HTMLAnchor("");
      closeAnchor.SetOnClick("window.close();");
      closeAnchor.AddInnerHTMLString(m_asOwner.GetString(1317, "ptmsgs_portalbrowsingmsgs"));
      //Specifying mainTable attributes
      mainTable.SetAlign("center");
      mainTable.SetBorder("0");
      mainTable.SetCellPadding("0");
      mainTable.SetWidth("90%");
      mainTable.SetHeight("30%");
      //Specifying errorTable attributes
      errorTable.SetBorder("0");
      errorTable.SetCellPadding("0");
      errorTable.SetWidth("100%");
      //Specifying linksTable attributes
      linksTable.SetBorder("0");
      linksTable.SetCellPadding("0");
      linksTable.SetWidth("100%");
      //Setting up errorTable
      errorCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
      String strPortletName = m_asModel.GetPortletName();
      errorCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(591,
       "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strPortletName)));
      PreviewCommunityView.addRowCell(errorTable, errorRow, errorCell);
      //Setting up linksTable
      if (m_asModel.GetPageID() != -1 * m_asModel.GetUserID())
      {
        linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
        linksRow1Cell.AddInnerHTMLElement(newMyPageAnchor);
        linksRow2Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      linksRow3Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow3Cell.AddInnerHTMLElement(defMyPageAnchor);
      linksRow4Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      linksRow5Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
      linksRow5Cell.AddInnerHTMLElement(closeAnchor);
      PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow4, linksRow4Cell);
      PreviewCommunityView.addRowCell(linksTable, linksRow5, linksRow5Cell);
      //Setting up the Main Table
      mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      mainRow2Cell.AddInnerHTMLElement(errorTable);
      mainRow3Cell.AddInnerHTMLElement(linksTable);
      PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
      PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
      //display page
      return mainTable;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement page = null;
      try
      {
        if (m_asModel.IsErrorPage())
        {
          page = CreateErrorPage();
        } else
        {
          page = CreateConfirmOfAddPage();
        }
      }
      catch (HTMLException he)
      {
        log.Error(he, he.Message);
      }
      return page;
    }
    
    /// <summary>
    /// Display JavaScript
    /// </summary>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IPreviewPortletModelRO) model;
      m_asOwner = parent;
    }
  }
}