using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.portletpreview
{
  /// <summary>
  /// File: PreviewPortletAS.java
  /// --------------------------
  /// Activity Space for the Preview Portlet and Portlet Invitations
  /// Includes the following MVC and DP files:
  /// Models:        PreviewPortletModel
  /// ObjectSelectionModel
  /// Views:        PreviewPortletView
  /// PortletInvitationPopupView
  /// InvitePortletJSView
  /// PreviewPortletDescPopupView
  /// DPs:        PreviewPortletDP
  /// PortletInvitationPopupDP
  /// InvitePortletJSDP
  /// InvitationOpenerRedirectDP
  /// PreviewPortletDescPopupDP
  /// Controls:    PreviewPortletControl
  /// AddPortletControl
  /// These files make up the functionality for previewing a gadget
  /// in three ways:
  /// 1. Preview Portlet in Selection Page and adding it
  /// 2. Receiving a Portlet Invitation and adding it
  /// 3. Previewing the Portlet in the Portlet Editor
  /// These files also include the popup for the Portlet Invitation
  /// Text on a Selection Page (the "Send to Others" link).
  /// </summary>
  /// <author>NaveenP/DustinA</author>
  /// <author>DavidP</author>
  public class PreviewPortletAS : PlumtreeAS,IFormAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.portletpreview.PreviewPortletAS");
    public const String STR_MVC_CLASS_NAME = "PreviewGadget";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PreviewPortletAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Get Repost Control Name
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return AddPortletControl.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#Init(IPTSession)"></seealso>
    public override void Init()
    {
      base.Init();
      log.Info("Initializing Portlet Preview Activity Space");
      // Portlet Preview/Invitation DisplayPages
      RegisterPage(new PreviewPortletDP());
      RegisterPage(new PortletInvitationPopupDP());
      //		InvitePortletJSDP invitePortletDP = new InvitePortletJSDP();
      //		if (GetAccessStyle() != AccessStyles.STANDARD)
      //		{
      //			invitePortletDP.SetShowFormFooter(true);
      //		}
      RegisterPage(new InvitePortletJSDP());
      RegisterPage(new InvitationOpenerRedirectDP());
      RegisterPage(new PortletInvitationJoinDP());
      RegisterPage(new NoMyPageAccessDP());
      RegisterPage(new PreviewCommPortletListDP());
      RegisterPage(new PreviewPortletDescPopupDP());
      // Community Selection Model
      RegisterModel(PreviewPortletModel.STR_MVC_CLASS_NAME);
      IModel myModel = GetModel(PreviewPortletModel.STR_MVC_CLASS_NAME);
      RegisterModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      IModel selectionModel = GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
      // Model has to be initialized in Init method because it requires PTSession.
      log.Debug("Registered model");
      // Preview Portlet Previews
      RegisterView(PreviewPortletView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(PortletInvitationPopupView.STR_MVC_CLASS_NAME, selectionModel);
      RegisterView(InvitePortletJSView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(InvitePortletJSView_D.STR_MVC_CLASS_NAME, myModel);
      RegisterView(PortletInvitationJoinView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(NoMyPageAccessView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(PreviewCommPortletListView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(PreviewPortletDescPopupView.STR_MVC_CLASS_NAME, myModel);
      log.Debug("Registered views");
      // Community Selection Controls
      RegisterControl(PreviewPortletControl.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(AddPortletControl.STR_MVC_CLASS_NAME, myModel);
      log.Debug("Registered controls");
    }
  }
}