using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portalpages.common.documentlanguage;
using com.plumtree.portalpages.common.search;
using com.plumtree.portaluiinfrastructure.filter;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.search.advanced
{
  /// <author>CraigS</author>
  public class AdvancedSearchModel : EditorModel,IAdvancedSearchModelRO
  {
    public const String STR_MVC_CLASS_NAME = "AdvancedSearchModel";
    public const String HTML_SELECT_NUMRESULTS = "in_se_numresults";
    private CardLanguagePlugInModel _languageModel;
    // Passthru IFilterIteratorIO methods
    private FilterIterator _filterIterator;
    private FolderSelectorModel _foldersModel;
    private IPTFilter _filter;
    private IPTSession _session;
    private SimpleSelectorModel _numResultsModel;
    private TypeSelectorModel _typeModel;
    private bool _showErrorsOnPage;
    protected String _mode = SearchPageModeHelper.BROWSE_MODE;
    
    /// <returns></returns>
    public virtual IPTFilter GetFilter()
    {
      return _filter;
    }
    
    /// <returns></returns>
    public virtual IPTSession GetSession()
    {
      return _session;
    }
    
    /// <summary>
    /// Returns the current filter iterator.
    /// </summary>
    /// <returns>the current filter iterator</returns>
    public virtual IFilterIteratorRO GetFilterIterator()
    {
      return _filterIterator;
    }
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>boolean Is true if the current user has the rights to access this Editor.</returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      // We may be coming from a page that already has a results mode selected. In that
      // case we need to be sure that the mode gets passed on to our results.
      if (SearchPageModeHelper.UserHasEditModeAccess(m_asOwner))
      {
        _mode = GetModelMode(_htFormData);
      }
      _session = (IPTSession) m_asOwner.GetUserSession();
      // Create a temporary filter
      try
      {
        _filter = FilterForm.BuildFilterFromForm(m_asOwner, _htFormData, "");
        }
      catch (Exception e)
      {
      }
      if (_filter == null)
      {
        _filter = PortalObjectsFactory.CreateSearchFilter();
      }
      _filterIterator = new FilterIterator(_session, _filter, m_asOwner);
      // Initialize the language plugin
      _languageModel = (CardLanguagePlugInModel) m_asOwner.GetModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME);
      String lastLang = _languageModel.GetLangFromFormData(_htFormData);
      if (lastLang == null || lastLang.Equals(""))
      {
        lastLang = CardLanguagePlugInView.s_AllLanguagesOptionCode;
      }
      /* defaultlanguage= */
      _languageModel.InitializePlugIn(lastLang, m_asOwner.GetString(767, "ptmsgs_portalbrowsingmsgs"),
       m_asOwner.GetString(768, "ptmsgs_portalbrowsingmsgs"), /* includeAllLangs= */
      true);
      // Initialize the number-of-results plugin
      _numResultsModel = (SimpleSelectorModel) m_asOwner.GetModel(SimpleSelectorModel.STR_MVC_CLASS_NAME);
      _numResultsModel.InitializePlugIn(new String[]{"10", "20", "50", "100"},
       /* initialSelection= */
      0, m_asOwner.GetString(769, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(770,
       "ptmsgs_portalbrowsingmsgs"), HTML_SELECT_NUMRESULTS);
      _numResultsModel.SetSelectionFromFormData(_htFormData);
      // Initialize the folders plugin
      _foldersModel = (FolderSelectorModel) m_asOwner.GetModel(FolderSelectorModel.STR_MVC_CLASS_NAME);
      /* multiselect= */
      _foldersModel.InitializePlugIn(true);
      _foldersModel.InitFromFormData(_htFormData);
      bool adminMode = (null != _mode) && (_mode.Equals(SearchPageModeHelper.ADMIN_MODE));
      // Initialize the types plugin
      _typeModel = (TypeSelectorModel) m_asOwner.GetModel(TypeSelectorModel.STR_MVC_CLASS_NAME);
      /*noTypesSelected */
      _typeModel.InitializePlugIn(false, adminMode);
      _typeModel.InitFromFormData(_htFormData);
      // Don't show potential errors until the user first attempts to submit
      _showErrorsOnPage = false;
      return true;
    }
    
    /// <returns></returns>
    public override Object Create()
    {
      return new AdvancedSearchModel();
    }
    public override void Finish()
    {
    }
    // nothing needed here
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual bool GetShowPotentialErrors()
    {
      return _showErrorsOnPage;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String pageName, XPHashtable formData)
    {
      _filter = FilterForm.BuildFilterFromForm(m_asOwner, formData);
      // Reinitialize filter iterator
      _filterIterator.InitFromFilter(_filter);
      // Passthru to save plugin models as well
      _languageModel.SaveSection(formData);
      _numResultsModel.SaveSection(formData);
      _foldersModel.SaveSection(formData);
      _typeModel.SaveSection(formData);
      // Page may now be redisplayed from saved model
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual void SetShowPotentialErrors()
    {
      _showErrorsOnPage = true;
    }
    protected virtual String GetModelMode(XPHashtable formdata)
    {
      String[] val = (String[]) formdata.GetElement(SearchResultModel.MODEL_MODE_INPUT);
      if (val == null || val.Length == 0)
      {
        return SearchPageModeHelper.BROWSE_MODE;
      } else
      {
        return val[0];
      }
    }
    public virtual String GetMode()
    {
      return _mode;
    }
  }
}