using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portalpages.common.documentlanguage;
using com.plumtree.portalpages.common.search;
using com.plumtree.portaluiinfrastructure.filter;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.browsing.search.advanced
{
  /// <author>CraigS, based on JulieF template</author>
  public class AdvancedSearchRepostControl : RepostControl
  {
    public const String STR_MVC_CLASS_NAME = "AdvancedSearchRepost";
    public static readonly int SEARCH_ACTION = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
    // Error messages on search submission
    private CardLanguagePlugInRepostControl _languageControl = null;
    private FolderSelectorRepostControl _folderControl = null;
    private TypeSelectorRepostControl _typeControl = null;
    
    /// <returns></returns>
    public override Object Create()
    {
      return new AdvancedSearchRepostControl();
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="action"></param>
    protected override void PerformAction(int action)
    {
      // Check for common form actions first
      base.PerformAction(action);
      // Check whether this action passes thru to plugins
      initPlugins();
      _languageControl.PerformRepostAction(action, m_htFormData);
      _folderControl.PerformRepostAction(action, m_htFormData);
      _typeControl.PerformRepostAction(action, m_htFormData);
      // If it's time to submit the search
      if (SEARCH_ACTION == action)
      {
        AdvancedSearchModel model = (AdvancedSearchModel) m_model;
        // ASModel.SavePage() has saved the filter within the model class.
        // Encode the filter as control arguments and pass it along to the
        // search space.
        XPHashtable args = new XPHashtable();
        bool filterValid = FilterForm.EncodeFilterAsControlArgs(model.GetSession(),
         m_asOwner, model.GetFilter(), args);
        if (!filterValid)
        {
          // If there's something wrong with the filter, don't run the search,
          // just show an error and redisplay the advanced search creation page
          // with errors flagged.
          String errorString = m_asOwner.GetString(771, "ptmsgs_portalbrowsingmsgs");
          // Check whether the user entered any query at all; this is the only
          // case that won't show up as another message
          IPTFilter filter = model.GetFilter();
          if ((null == filter.GetSearchString()) || (0 == filter.GetSearchString().Length))
          {
            IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) filter.GetPropertyFilter();
            if (0 == clause.GetCount())
            {
              errorString = m_asOwner.GetString(772, "ptmsgs_portalbrowsingmsgs");
              }
          }
          UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, errorString, errorString);
          UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          model.SetShowPotentialErrors();
          return;
        }
        // Create a Redirect to the SearchResult space
        Redirect r = new Redirect();
        r.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, m_asOwner);
        r.SetControl(AdvancedStartSearchControl.STR_MVC_CLASS_NAME);
        r.SetIsHTTPRedirect(true);
        // Set the mode (edit, admin) for the redirect if the current user is an administrator.
        if (SearchPageModeHelper.UserHasEditModeAccess(m_asOwner))
        {
          r.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, XPConvert.ToString(model.GetMode()));
          }
        // Add filter arguments
        r.AddControlArguments(args);
        // Get the selected language from the language plugin
        CardLanguagePlugInModel languageModel = (CardLanguagePlugInModel) m_asOwner.GetModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME);
        String language = languageModel.GetCardLanguageCode();
        // .. and pass the language on to the search space
        if (!language.Equals(CardLanguagePlugInView.s_AllLanguagesOptionCode))
        {
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_LANGUAGE_S,
           language);
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_LIMITBYLOCALE_S,
           "1");
        }
        // Get the selected number of results
        SimpleSelectorModel numResultsModel = (SimpleSelectorModel) m_asOwner.GetModel(SimpleSelectorModel.STR_MVC_CLASS_NAME);
        int nrIndex = numResultsModel.GetCurrentSelection();
        String pageSize;
        if (1 == nrIndex)
        {
          pageSize = "20";
        } else
        if (2 == nrIndex)
        {
          pageSize = "50";
        } else
        if (3 == nrIndex)
        {
          pageSize = "100";
        } else
        {
          pageSize = "10";
        }
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_MAXRESULTS_S,
         pageSize);
        FolderSelectorModel folderModel = (FolderSelectorModel) m_asOwner.GetModel(FolderSelectorModel.STR_MVC_CLASS_NAME);
        // Get the set of selected folders
        IXPCollection adminFolders = folderModel.GetSelections(true);
        IXPCollection catalogFolders = folderModel.GetSelections(false);
        if (adminFolders.GetSize() > 0)
        {
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S,
           getFolderIDsFromTreeNodeCollection(adminFolders));
        }
        if (catalogFolders.GetSize() > 0)
        {
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_DDFOLDERS_S,
           getFolderIDsFromTreeNodeCollection(catalogFolders));
        }
        if (!folderModel.GetIncludeSubfolders())
        {
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S,
           "0");
        }
        // Get the selected object types
        TypeSelectorModel typeModel = (TypeSelectorModel) m_asOwner.GetModel(TypeSelectorModel.STR_MVC_CLASS_NAME);
        // Are we using "detailed" options (which allow any object type to be selected),
        // or "broad" options (which allow only abstract types and applications to be
        // selected)?
        if (typeModel.AreDetailedOptionsShown())
        {
          // The "detailed options" version is displayed.
          bool searchPortal;
          bool searchCollab = false;
          bool searchContent = false;
          IXPCollection types = typeModel.GetSelectedTypes();
          if ((null == types) || (0 == types.GetSize()))
          {
            // No types were selected.  Show an error along with the AS form again.
            String errorString = m_asOwner.GetString(1553, "ptmsgs_portalbrowsingmsgs");
            UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             null, errorString, errorString);
            UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
            model.SetShowPotentialErrors();
            return;
          }
          IXPEnumerator eTypes = types.GetEnumerator();
          XPArrayList classes = new XPArrayList();
          while (eTypes.MoveNext())
          {
            String selectedType = (String) eTypes.GetCurrent();
            int classId;
            try
            {
              classId = XPConvert.ToInteger(selectedType);
            }
            catch (Exception e)
            {
              throw XPException.GetInstance(e);
            }
            // if this isn't one of the abstract types selected on the panel
            // that isn't currently shown
            if (classId < SearchObjectTypes.MIN_SPECIAL_CLASSID_VALUE)
            {
              // then add this one to our list
              classes.Add(selectedType);
            } else
            if (classId == SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE)
            {
              searchContent = true;
            } else
            if (classId == SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE)
            {
              searchCollab = true;
            }
          }
          // end loop over selected types
          // now, turn our XPArrayList of Strings corresponding to types into a String[]
          int numTypes = classes.GetSize();
          if (numTypes > 0)
          {
            String[] array = new String[numTypes];
            for (int j = 0;j < numTypes;j++)
            {
              array[j] = (String) classes.GetElement(j);
            }
            // and pass the object type constraint along as a URL argument
            r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S,
             array);
            searchPortal = true;
          } else
          {
            searchPortal = false;
          }
          // Finally, add the application constraint
          int apps = 0;
          if (searchPortal)
          {
            apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL;
          }
          if (searchCollab)
          {
            apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB;
          }
          if (searchContent)
          {
            apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT;
          }
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
           apps);
        } else
        // end of "detailed options" version of objecttype selector plugin
        {
          // The "broad options" version is displayed.
          // First, handle abstract types.
          bool wantDocs = typeModel.IsTypeSelected(SearchObjectTypes.DOCUMENT_ABSTRACTTYPE);
          bool wantFolders = typeModel.IsTypeSelected(SearchObjectTypes.FOLDER_ABSTRACTTYPE);
          bool wantViews = typeModel.IsTypeSelected(SearchObjectTypes.OTHER_ABSTRACTTYPE);
          // We only want to add an abstract type constraint if the user selected some
          // abstract types but not others.
          if ((wantDocs != wantFolders) || (wantDocs != wantViews) || (wantFolders != wantViews))
          {
            int absTypes = 0;
            if (wantDocs)
            {
              absTypes|=PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_DOCUMENTS;
            }
            if (wantFolders)
            {
              absTypes|=PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_CONTAINERS;
              }
            if (wantViews)
            {
              absTypes|=PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_OTHER;
            }
            r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S,
             absTypes);
          }
          // Next, handle applications.
          bool wantPortal = typeModel.IsTypeSelected(SearchObjectTypes.PORTAL_APPLICATION);
          bool wantCollab = typeModel.IsTypeSelected(SearchObjectTypes.COLLAB_APPLICATION);
          bool wantContent = typeModel.IsTypeSelected(SearchObjectTypes.CONTENT_APPLICATION);
          // Similarly, we only want to add an application constraint if the user selected some
          // apps but not others.
          if ((wantPortal != wantCollab) || (wantPortal != wantContent) || (wantCollab != wantContent))
          {
            int apps = 0;
            if (wantPortal)
            {
              apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL;
            }
            if (wantCollab)
            {
              apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB;
            }
            if (wantContent)
            {
              apps|=PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT;
            }
            r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
             apps);
          }
        }
        // And off we go..
        SetRedirect(r);
      } else
      {
      }
    }
    
    /// <param name="c"></param>
    /// <returns></returns>
    private String[] getFolderIDsFromTreeNodeCollection(IXPCollection c)
    {
      String[] r = new String[c.GetSize()];
      int j = 0;
      IXPEnumerator e = c.GetEnumerator();
      while (e.MoveNext())
      {
        TreeLeafNode node = (TreeLeafNode) (e.GetCurrent());
        r[j] = XPConvert.ToString(node.m_nObjectID);
        j++;
      }
      return r;
    }
    // NOTE: The number-of-results plugin has no repost control.
    private void initPlugins()
    {
      if (null == _languageControl)
      {
        _languageControl = (CardLanguagePlugInRepostControl) m_asOwner.GetControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME);
        }
      if (null == _folderControl)
      {
        _folderControl = (FolderSelectorRepostControl) m_asOwner.GetControl(FolderSelectorRepostControl.STR_MVC_CLASS_NAME);
        }
      if (null == _typeControl)
      {
        _typeControl = (TypeSelectorRepostControl) m_asOwner.GetControl(TypeSelectorRepostControl.STR_MVC_CLASS_NAME);
        }
    }
  }
}