using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
namespace com.plumtree.portalpages.browsing.search.advanced
{
  /// <author>CraigS</author>
  public class PowerSearchControl : IControl
  {
    protected AActivitySpace _parent;
    protected PowerSearchModel _model;
    public const String STR_MVC_CLASS_NAME = "PowerSearch";
    
    /// <returns>New instance of this class</returns>
    public virtual Object Create()
    {
      return new PowerSearchControl();
    }
    
    /// <returns>Name of this class</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      _model = (PowerSearchModel) model;
      _parent = space;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable args)
    {
      // First, check for errors.
      // If portal object types to search for are selectable..
      if (_model.GetMakeClassIDsSelectable())
      {
        bool userNeededToSelectAtLeastOneType = false;
        //.. and, either
        //  (1) the user was not given the chance to select applications to search (implying
        //      that the portal would always be searched), OR
        //  (2) the user was given this choice, and included the portal in his or her
        //      selection
        if (!_model.GetShowApplicationSelector())
        {
          // case 1
          userNeededToSelectAtLeastOneType = true;
        } else
        {
          // look at what applications the user picked
          String sValue = ((String[]) (args.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_APPS_S)))[0];
          int iValue = XPConvert.ToInteger(sValue);
          if (0 == iValue || (PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL == iValue))
          {
            // case 2
            userNeededToSelectAtLeastOneType = true;
          }
        }
        if (userNeededToSelectAtLeastOneType)
        {
          // Make sure at least one type was selected
          Object oValue = args.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PFX_CHECKBOXES + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S);
          // If one wasn't selected
          if (null == oValue)
          {
            // raise an error and stay on the same page
            // "Select at least one result type"
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             _parent.GetString(1553, "ptmsgs_portalbrowsingmsgs"), _parent.GetString(1553,
             "ptmsgs_portalbrowsingmsgs"));
            UIErrorHandler.RaiseError(myError, _parent.GetSubSession(), _parent.GetApplication());
            return null;
          }
        }
      }
      // No errors. Redirect 
      Redirect r = new Redirect();
      // Use the same search parameters already constructed by the search form
      r.AddControlArguments(args);
      // .. except we need to go to the search result page this time
      r.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, _parent);
      r.SetDisplayPage(SearchResultDP.STR_MVC_CLASS_NAME);
      r.SetControl(StartSearchControl.STR_MVC_CLASS_NAME);
      // Check for any date-time pickers and extract their comparison values.
      // First, loop over properties once to make sure we've reconstructed all datepickers,
      // even if the cache has been flushed
      int numProperties = _model.GetNumPropertyConstraints();
      int numDateProperties = 0;
      for (int j = 0;j < numProperties;j++)
      {
        int propType = _model.GetPropertyType(j);
        // If date type
        if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == propType)
        {
          // keep a count
          numDateProperties+=1;
          // get the property ID
          int propID = _model.GetPropertyID(j);
          // reconstruct the date-time picker object
          _model.MakeAndCacheDateTimePicker(propID);
        }
      }
      // end if date type
      // end loop over properties
      // If there were any date properties
      if (numDateProperties > 0)
      {
        // Force the (now fully reconstructed) page manager to store any dates encoded in the URL args
        int pageStatus = RepostControl.PAGE_STATUS_VALID;
        try
        {
          pageStatus = _model.StoreAllDateInputs(args);
        }
        catch (Exception e)
        {
          pageStatus = RepostControl.PAGE_STATUS_INVALID;
        }
        if (RepostControl.PAGE_STATUS_VALID == pageStatus)
        {
          // loop over them all again
          for (int j = 0;j < numProperties;j++)
          {
            // is this one a date?
            int propType = _model.GetPropertyType(j);
            // if so..
            if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == propType)
            {
              // extract the datepicker object (now updated with user input)
              int propID = _model.GetPropertyID(j);
              ADatePickerComponent dtPicker = _model.GetDateTimePicker(propID);
              // extract the date
              XPDateTime xpDT = dtPicker.GetDateTimeAsDateTime();
              // if there was any input
              if (null != xpDT)
              {
                // convert to msec since 1970
                long msec1970 = xpDT.GetTimeInMilliSeconds();
                // and add an arg to our redirect specifying the time
                r.AddControlArgument("in_tx_comparedate_1_" + XPConvert.ToString(j + 1),
                 XPConvert.ToString(msec1970));
              }
            }
          }
        }
        // end if this prop has date type
        // end loop over properties
        // end if all datepickers contained something valid
        // If the page manager complained about something invalid..
        // (note: NOT entering a date is not an invalid input - in that case the status will be
        //  VALID, and xpDT above will simply be null.)
        if (RepostControl.PAGE_STATUS_INVALID == pageStatus)
        {
          // See if we can display an error message
          String pageMgrErrors = _model.GetPageManagerErrors();
          if ((null != pageMgrErrors) && (0 < pageMgrErrors.Length))
          {
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             pageMgrErrors, pageMgrErrors);
            UIErrorHandler.RaiseError(myError, _parent.GetSubSession(), _parent.GetApplication());
            }
          // And redisplay the same page again
          return null;
        }
      }
      // end if any date properties
      return r;
    }
  }
}