using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.browsing.search.advanced
{
  /// <author>CraigS</author>
  public class PowerSearchModel : IModelRO,IModel
  {
    public const String STR_MVC_CLASS_NAME = "PowerSearch";
    
    /// <summary>
    /// Owning ActivitySpace
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Our cache of property IDs, names, and types
    /// </summary>
    private IASQueryResult _propertyCache = null;
    
    /// <summary>
    /// Owning session
    /// </summary>
    private IPTSession _session;
    private int[] _propertyConstraints;
    private int[] _supportedClassIDs;
    private bool _makeClassIDsSelectable;
    private bool _showAbstractTypeSelector;
    private bool _showApplicationSelector;
    private bool _supportTextSearch;
    
    /// <summary>
    /// Page manager, needed by date-time picker 
    /// </summary>
    protected PageMgr m_ptPageMgr;
    
    /// <summary>
    /// Our own cache of datepicker objects that we've created.  Needed
    /// because PageMgr is not so good at handling duplicate datepickers
    /// with the same name - if we simply ask for the same one back again,
    /// we sometimes get a new one, and thereafter, calls through PageMgr
    /// will end up altering one or the other but not both.
    /// Map of String -> ADatePickerComponent.
    /// </summary>
    private XPHashtable _datePickerCache = null;
    public virtual void CleanupTempData()
    {
      _propertyCache = null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <returns></returns>
    public virtual Object Create()
    {
      return new PowerSearchModel();
    }
    
    /// <returns></returns>
    public virtual bool GetMakeClassIDsSelectable()
    {
      return _makeClassIDsSelectable;
    }
    
    /// <returns></returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetNumPropertyConstraints()
    {
      return _propertyConstraints.Length;
    }
    
    /// <param name="idx"></param>
    /// <returns></returns>
    public virtual int GetPropertyID(int idx)
    {
      return _propertyConstraints[idx];
    }
    
    /// <param name="idx"></param>
    /// <returns></returns>
    public virtual String GetPropertyName(int idx)
    {
      initPropertyCache();
      int propID = GetPropertyID(idx);
      for (int j = 0;j < _propertyCache.GetCount();j++)
      {
        if (XPConvert.ToInteger(_propertyCache.GetFields(j, PT_PROPIDS.PT_PROPID_OBJECTID)) == propID)
        {
          // found it
          try
          {
            return ((String) _propertyCache.GetFields(j, PT_PROPIDS.PT_PROPID_NAME));
            }
          catch (Exception e)
          {
            throw XPException.GetInstance(e);
          }
        }
      }
      return "";
    }
    
    /// <param name="idx"></param>
    /// <returns></returns>
    public virtual int GetPropertyType(int idx)
    {
      initPropertyCache();
      int propID = GetPropertyID(idx);
      int propType = -1;
      for (int j = 0;j < _propertyCache.GetCount();j++)
      {
        if (XPConvert.ToInteger(_propertyCache.GetFields(j, PT_PROPIDS.PT_PROPID_OBJECTID)) == propID)
        {
          // found it
          try
          {
            propType = XPConvert.ToInteger(_propertyCache.GetFields(j, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
            }
          catch (Exception e)
          {
            throw XPException.GetInstance(e);
          }
          return propType;
        }
      }
      throw new XPException("unknown property ID " + propID);
    }
    
    /// <returns></returns>
    public virtual bool GetShowAbstractTypeSelector()
    {
      return _showAbstractTypeSelector;
    }
    
    /// <returns></returns>
    public virtual bool GetShowApplicationSelector()
    {
      return _showApplicationSelector;
    }
    
    /// <returns></returns>
    public virtual bool GetSupportTextSearch()
    {
      return _supportTextSearch;
    }
    
    /// <returns></returns>
    public virtual int[] GetSupportedClassIDs()
    {
      return _supportedClassIDs;
    }
    
    /// <param name="parent"></param>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      _session = (IPTSession) m_asOwner.GetUserSession();
    }
    public virtual void MakeAndCacheDateTimePicker(int propID)
    {
      // Just call the Get method, which caches it for us.
      GetDateTimePicker(propID);
    }
    public virtual ADatePickerComponent GetDateTimePicker(int propID)
    {
      if (null == m_ptPageMgr)
      {
        String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
        m_ptPageMgr = new PageMgr(m_asOwner.GetAccessStyle(), PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
         PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner),
         strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
        }
      // Initialize our datepicker cache if we haven't already
      if (null == _datePickerCache)
      {
        _datePickerCache = new XPHashtable();
      }
      const String KEY_PREFIX = "powersearch";
      String dtpKey = KEY_PREFIX + XPConvert.ToString(propID);
      Object cacheValue = _datePickerCache.GetElement(dtpKey);
      ADatePickerComponent dtPicker = null;
      if (null != cacheValue)
      {
        dtPicker = (ADatePickerComponent) cacheValue;
      } else
      {
        // Make a new one
        dtPicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
        _datePickerCache.PutElement(dtpKey, dtPicker);
        dtPicker.Init(PowerSearchView.FORMNAME, m_ptPageMgr, dtpKey);
      }
      return dtPicker;
    }
    public virtual int StoreAllDateInputs(XPHashtable args)
    {
      if (null != m_ptPageMgr)
      {
        return m_ptPageMgr.StoreAllUserInput(args);
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual String GetPageManagerErrors()
    {
      if (null != m_ptPageMgr)
      {
        return m_ptPageMgr.GetErrorMessages(m_asOwner);
      }
      return null;
    }
    
    /// <param name="propertyConstraints"></param>
    /// <param name="supportTextSearch"></param>
    /// <param name="supportedClassIDs"></param>
    /// <param name="makeClassIDsSelectable"></param>
    /// <param name="showAbstractTypeSelector"></param>
    /// <param name="showApplicationSelector"></param>
    public virtual void Setup(int[] propertyConstraints, bool supportTextSearch,
     int[] supportedClassIDs, bool makeClassIDsSelectable, bool showAbstractTypeSelector,
     bool showApplicationSelector)
    {
      _propertyConstraints = propertyConstraints;
      _supportTextSearch = supportTextSearch;
      _supportedClassIDs = supportedClassIDs;
      _makeClassIDsSelectable = makeClassIDsSelectable;
      // If the abstract type selector is visible, does it make any
      // sense to also restrict class IDs?
      _showAbstractTypeSelector = showAbstractTypeSelector;
      _showApplicationSelector = showApplicationSelector;
      initPropertyCache();
    }
    private void initPropertyCache()
    {
      if (null == _propertyCache)
      {
        int fields = PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
        PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(_session.GetProperties());
        Object[][] ptqf = new Object[3][];
        for (int j2c_index = 0;j2c_index < 3;j2c_index++)
        {
          ptqf[j2c_index] = new Object[1];
        }
        ptqf[0][0] = PT_PROPIDS.PT_PROPID_PROP_SEARCHABLE;
        ptqf[1][0] = PT_FILTEROPS.PT_FILTEROP_GT;
        ptqf[2][0] = 0;
        omqw.Query(fields, -1, null, ptqf);
        _propertyCache = (IASQueryResult) omqw;
      }
    }
  }
}