using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.filter;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.search.advanced
{
  /// <author>CraigS</author>
  public class PowerSearchView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.search.advanced.PowerSearchView");
    public const String STR_MVC_CLASS_NAME = "PowerSearch";
    // Names of HTML elements.  By using the names defined in FilterForm, we can
    // take advantage of the infrastructure that Advanced Search also uses for reconstructing
    // filters from forms automatically
    public const String FORMNAME = "powersearch";
    public static readonly String SUBMITBUTTON = "in_su_" + FORMNAME;
    public static readonly String FULLTEXT = FilterForm.FULL_TEXT;
    public static readonly String OPERATOR = FilterForm.TOP_OPERATOR;
    public static readonly String OPERATOR_AND = FilterForm.OPERATOR_AND;
    public static readonly String OPERATOR_OR = FilterForm.OPERATOR_OR;
    public static readonly String CLAUSE_DEPTH = FilterForm.DEPTH_PREFIX + "1";
    public static readonly String CLAUSE_COUNT = FilterForm.TOTAL_GROUPS;
    public static readonly String IGNORE_BLANK_STATEMENTS = FilterForm.IGNORE_BLANK_STATEMENTS;
    public static readonly String IGNORE_BLANK_STATEMENTS_VAL = FilterForm.IGNORE_BLANK_STATEMENTS_VAL;
    public static readonly String PROPID_PREFIX = FilterForm.PROPERTY_HIDDEN + "_1_";
    public static readonly String VALUE_PREFIX = FilterForm.COMPARISON_VALUE + "_1_";
    public static readonly String DATE_VALUE_PREFIX = FilterForm.COMPARISON_VALUE_IF_DATE + "_1_";
    public static readonly String STATEMENT_COUNT = FilterForm.REVEALED + "1";
    private AActivitySpace m_asOwner;
    private PowerSearchModel _model;
    private bool _is508;
    
    /// <returns></returns>
    public virtual Object Create()
    {
      return new PowerSearchView();
    }
    
    /// <returns></returns>
    public virtual HTMLElement Display()
    {
      HTMLForm form = null;
      try
      {
        form = new HTMLForm(FORMNAME);
        form.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
        // Add hidden inputs to direct the search to the SearchResult space
        HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACENAME_INPUT,
         "");
        input.SetValue(AdvancedSearchAS.STR_MVC_CLASS_NAME);
        form.AddInnerHTMLElement(input);
        input = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.PAGE_INPUT,
         "");
        input.SetValue(PowerSearchDP.STR_MVC_CLASS_NAME);
        form.AddInnerHTMLElement(input);
        input = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.CONTROL_INPUT,
         "");
        input.SetValue(PowerSearchControl.STR_MVC_CLASS_NAME);
        form.AddInnerHTMLElement(input);
        // Add abstract type selection, if requested
        if (_model.GetShowAbstractTypeSelector())
        {
          form.AddInnerHTMLString("<b>");
          form.AddInnerHTMLString(m_asOwner.GetString(1341, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLString("</b>");
          form.AddInnerHTMLElement(new HTMLBr());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S,
           "");
          input.SetChecked(true);
          input.SetValue("0");
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1346, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S,
           "");
          input.SetValue(XPConvert.ToString(PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_DOCUMENTS));
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1347, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S,
           "");
          input.SetValue(XPConvert.ToString(PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_CONTAINERS));
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1348, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S,
           "");
          input.SetValue(XPConvert.ToString(PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_OTHER));
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1349, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
        }
        // Add inputs for individual object class selection, if requested
        int[] supportedClassIDs = _model.GetSupportedClassIDs();
        if (null != supportedClassIDs)
        {
          if (_model.GetMakeClassIDsSelectable())
          {
            form.AddInnerHTMLString("<b>");
            form.AddInnerHTMLString(m_asOwner.GetString(1341, "ptmsgs_portalbrowsingmsgs"));
            form.AddInnerHTMLString("</b>");
            form.AddInnerHTMLElement(new HTMLBr());
            form.AddInnerHTMLElement(new HTMLBr());
          }
          // Loop over types
          for (int j = 0;j < supportedClassIDs.Length;j++)
          {
            if (_model.GetMakeClassIDsSelectable())
            {
              // Make a checkbox and prompt for this type
              input = new HTMLInput(HTMLInputTypes.CHECKBOX, StartSearchControl.REQUIRED_CONSTRAINT_PFX_CHECKBOXES + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S,
               "");
              input.SetChecked(true);
              input.SetValue(XPConvert.ToString(supportedClassIDs[j]));
              form.AddInnerHTMLElement(input);
              form.AddInnerHTMLString(SearchResultModel.getDisplayableNameForType(m_asOwner,
               supportedClassIDs[j]));
              form.AddInnerHTMLElement(MakeHiddenDotInSpan());
              form.AddInnerHTMLElement(new HTMLBr());
            } else
            {
              // Types not selectable - just make a hidden input restricting the
              // search to this type
              input = new HTMLInput(HTMLInputTypes.HIDDEN, StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S,
               "");
              input.SetValue(XPConvert.ToString(supportedClassIDs[j]));
              form.AddInnerHTMLElement(input);
            }
          }
        }
        if (_model.GetShowApplicationSelector())
        {
          // next, application selection
          form.AddInnerHTMLElement(new HTMLBr());
          form.AddInnerHTMLString("<b>");
          form.AddInnerHTMLString(m_asOwner.GetString(1342, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLString("</b>");
          form.AddInnerHTMLElement(new HTMLBr());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
           "");
          input.SetChecked(true);
          input.SetValue("0");
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1350, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
           "");
          input.SetValue(XPConvert.ToString(PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL));
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1351, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
           "");
          input.SetValue(XPConvert.ToString(PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB));
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1352, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          input = new HTMLInput(HTMLInputTypes.RADIO, StartSearchControl.REQUIRED_CONSTRAINT_PFX_RADIO + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
           "");
          input.SetValue(XPConvert.ToString(PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT));
          form.AddInnerHTMLElement(input);
          form.AddInnerHTMLString(m_asOwner.GetString(1353, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
        }
        // Add inputs for the search query itself
        form.AddInnerHTMLElement(new HTMLBr());
        form.AddInnerHTMLString("<b>");
        form.AddInnerHTMLString(m_asOwner.GetString(1343, "ptmsgs_portalbrowsingmsgs"));
        form.AddInnerHTMLString("</b>");
        form.AddInnerHTMLElement(new HTMLBr());
        HTMLTable table = new HTMLTable();
        table.SetCellPadding("3");
        table.SetCellSpacing("0");
        table.SetSummary(m_asOwner.GetString(1345, "ptmsgs_portalbrowsingmsgs"));
        form.AddInnerHTMLElement(table);
        bool supportTextSearch = _model.GetSupportTextSearch();
        // Show text searchbox, if requested
        if (supportTextSearch)
        {
          table.AddInnerHTMLElement(makeFormElement(m_asOwner.GetString(1335,
           "ptmsgs_portalbrowsingmsgs"), FULLTEXT));
        }
        // Get the number of possible property constraints
        int numProperties = _model.GetNumPropertyConstraints();
        // Encode number of constraints
        input = new HTMLInput(HTMLInputTypes.HIDDEN, STATEMENT_COUNT, "");
        input.SetValue(XPConvert.ToString(numProperties));
        form.AddInnerHTMLElement(input);
        // If there are any property constraints
        if (numProperties > 0)
        {
          // Create a hidden input to cause creation of a single clause,
          // whose operator will default to the same as the top operator
          input = new HTMLInput(HTMLInputTypes.HIDDEN, CLAUSE_COUNT, "");
          input.SetValue("1");
          form.AddInnerHTMLElement(input);
          input = new HTMLInput(HTMLInputTypes.HIDDEN, CLAUSE_DEPTH, "");
          input.SetValue("0");
          form.AddInnerHTMLElement(input);
          // This search should ignore any fields that the user doesn't fill in,
          // instead of throwing an error
          input = new HTMLInput(HTMLInputTypes.HIDDEN, IGNORE_BLANK_STATEMENTS,
           "");
          input.SetValue(IGNORE_BLANK_STATEMENTS_VAL);
          form.AddInnerHTMLElement(input);
        }
        // For each property constraint
        for (int j = 0;j < numProperties;j++)
        {
          // Get the property info
          int propID = _model.GetPropertyID(j);
          String propName = XPHttpUtility.HtmlEncode(_model.GetPropertyName(j));
          int propType = _model.GetPropertyType(j);
          // Show the "Property foo contains: " prompt and textbox or date/time picker
          if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == propType)
          {
            table.AddInnerHTMLElement(makeFormElementForDateProperty(XPResourceManager.FormatMessage(m_asOwner.GetString(1337,
             "ptmsgs_portalbrowsingmsgs"), propName), propID));
          } else
          {
            // Add the prompt and textbox
            table.AddInnerHTMLElement(makeFormElement(XPResourceManager.FormatMessage(m_asOwner.GetString(1336,
             "ptmsgs_portalbrowsingmsgs"), propName), VALUE_PREFIX + XPConvert.ToString(j + 1)));
            }
          // Add property ID hidden input
          input = new HTMLInput(HTMLInputTypes.HIDDEN, PROPID_PREFIX + XPConvert.ToString(j + 1),
           "");
          input.SetValue(XPConvert.ToString(propID) + "|" + XPConvert.ToString(propType));
          form.AddInnerHTMLElement(input);
        }
        // If there is more than one possible property constraint,
        // or at least one property constraint and a text constraint
        if ((numProperties > 1) || ((numProperties > 0) && supportTextSearch))
        {
          form.AddInnerHTMLElement(new HTMLBr());
          form.AddInnerHTMLString("<b>");
          form.AddInnerHTMLString(m_asOwner.GetString(1344, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLString("</b>");
          form.AddInnerHTMLElement(new HTMLBr());
          // show AND vs OR radiobuttons
          HTMLInput operatorInput = new HTMLInput(HTMLInputTypes.RADIO, OPERATOR,
           "");
          operatorInput.SetValue(OPERATOR_AND);
          operatorInput.SetChecked(true);
          form.AddInnerHTMLElement(operatorInput);
          form.AddInnerHTMLString(m_asOwner.GetString(1338, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
          operatorInput = new HTMLInput(HTMLInputTypes.RADIO, OPERATOR, "");
          operatorInput.SetValue(OPERATOR_OR);
          form.AddInnerHTMLElement(operatorInput);
          form.AddInnerHTMLString(m_asOwner.GetString(1339, "ptmsgs_portalbrowsingmsgs"));
          form.AddInnerHTMLElement(MakeHiddenDotInSpan());
          form.AddInnerHTMLElement(new HTMLBr());
        }
        form.AddInnerHTMLElement(new HTMLBr());
        HTMLInput button = new HTMLInput(HTMLInputTypes.SUBMIT, SUBMITBUTTON,
         SUBMITBUTTON);
        button.SetValue(m_asOwner.GetString(1340, "ptmsgs_portalbrowsingmsgs"));
        button.SetTitle(m_asOwner.GetString(1340, "ptmsgs_portalbrowsingmsgs"));
        button.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        button.SetAccessKey(m_asOwner.GetString(4, "ptmsgs_portal508quickkeymsgs"));
        button.SetAlt(m_asOwner.GetString(41, "ptmsgs_portal508quickkeymsgs"));
        form.AddInnerHTMLElement(button);
      }
      catch (HTMLException e)
      {
        log.Error(e, e.Message);
        return new HTMLGenericElement(e.Message);
      }
      return form;
    }
    private HTMLElement MakeHiddenDotInSpan()
    {
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.D_HIDDEN_WHITE_TEXT);
      span.AddInnerHTMLString(".");
      return span;
    }
    
    /// <returns></returns>
    public virtual HTMLScript DisplayJavascript()
    {
      // return nothing; this view should be 508-compliant
      return null;
    }
    
    /// <returns></returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      _model = (PowerSearchModel) model;
      m_asOwner = parent;
      _is508 = (!(m_asOwner.GetAccessStyle() == AccessStyles.STANDARD));
    }
    
    /// <param name="prompt"></param>
    /// <param name="textBoxInputName"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    private HTMLElement makeFormElement(String prompt, String textBoxInputName)
    {
      HTMLElement result = null;
      HTMLInput textbox = new HTMLInput(HTMLInputTypes.TEXT, textBoxInputName,
       "");
      textbox.SetSize("40");
      textbox.SetMaxLength("200");
      textbox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      result = new HTMLTableRow();
      //		result.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG);
      HTMLTableCell cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      result.AddInnerHTMLElement(cell);
      cell.AddInnerHTMLString(prompt);
      cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      result.AddInnerHTMLElement(cell);
      cell.AddInnerHTMLElement(textbox);
      cell.AddInnerHTMLElement(MakeHiddenDotInSpan());
      return result;
    }
    private HTMLElement makeFormElementForDateProperty(String prompt, int propID)
    {
      HTMLElement result = null;
      ADatePickerComponent dtPicker = _model.GetDateTimePicker(propID);
      HTMLElement dtPickerHTML = dtPicker.GetComponentHTML();
      result = new HTMLTableRow();
      HTMLTableCell cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      result.AddInnerHTMLElement(cell);
      cell.AddInnerHTMLString(prompt);
      cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      result.AddInnerHTMLElement(cell);
      cell.AddInnerHTMLElement(dtPickerHTML);
      return result;
    }
  }
}