using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.pei;
using BannerSearchHelperService=com.plumtree.portaluiinfrastructure.helpers.BannerSearchHelperService;
using IBannerSearchHelper=com.plumtree.portaluiinfrastructure.helpers.IBannerSearchHelper;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.portalpagesperf;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public class BannerStartSearchControl : StartSearchControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.search.results.BannerStartSearchControl");
    
    /// <summary>
    /// Name of this control. 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "bannerstart";
    
    /// <summary>
    /// Names of search preferences in the Plumtree database. 
    /// </summary>
    public const String SEARCHPREF_LIMITBYLOCALE = "searchLimitByLocale";
    public const String SEARCHPREF_PAGESIZE = "searchPageSize";
    public const String SEARCHPREF_OBJECTTYPES = "searchObjectTypes";
    public const String SEARCHPREF_GROUPBY = "searchGroupBy";
    public const String SEARCHPREF_OBSOLETE_GROUPBY = "GroupBySearchPrefs";
    
    /// <summary>
    /// Name under which we cache banner search preferences in our subsession. 
    /// </summary>
    public const String CACHED_SEARCHPREFS_KEY = "BannerSearchPreferences";
    
    /// <summary>
    /// Name under which we cache recent banner searches in our subsession. 
    /// </summary>
    public const String CACHED_RECENT_KEY = "RecentSearches";
    
    /// <returns></returns>
    public override Object Create()
    {
      return new BannerStartSearchControl();
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.search.StartSearchControl.CustomizeQuery()"></seealso>
    protected override Redirect CustomizeQuery(QueryArguments query)
    {
      // First, check for a top best bet lookup, indicated by ">" as the first character
      // of the query string
      String queryString = query.userQuery;
      if ((queryString.Length > 1) && XPStringUtility.StartsWith(queryString,
       ">"))
      {
        String possibleKeyword = XPStringUtility.Substring(queryString, 1);
        // DCD: Construct the TBB URL explicitly
        String sTBBURL = _parent.GetCurrentNormalizedBaseURL() + IPTOpenerConstants.QS_KEYWORD + "=" + possibleKeyword;
        // DCD: Simply open the object instead of displaying the search results page
        Redirect rTBB = new Redirect();
        rTBB.SetIsHTTPRedirect(true);
        rTBB.SetLinkToExternalURL(sTBBURL);
        return rTBB;
      }
      // Bump up the banner search counter
      PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_BANNER_SEARCHES);
      // Call a helper method to keep track of recent searches
      // for the Portal Search Portlet.
      cacheRecentSearches(query);
      // Save the user's query for logging in the search server logs
      _logString = query.userQuery;
      // Log this query to the Analytics Server
      if (_parent.GetModelExists(LoggingHelperModel.STR_MVC_CLASS_NAME))
      {
        LoggingHelperModel logHelper = (LoggingHelperModel) _parent.GetModel(LoggingHelperModel.STR_MVC_CLASS_NAME);
        if (null != logHelper)
        {
          logHelper.LogStartSearchEvent(query.userQuery, LoggingHelperModel.SEARCH_TYPE_BANNER);
          }
      }
      // Make sure PEIs are loaded
      LoadBannerSearchPEIs();
      // Call out to each PEI in turn
      if (null != _bannerSearchPEIs)
      {
        IXPEnumerator e = _bannerSearchPEIs.GetEnumerator();
        while (e.MoveNext())
        {
          IBannerSearchActions pei = (IBannerSearchActions) e.GetCurrent();
          pei.CustomizeQueryOnBeforeSearch(_parent, (IPTSession) _parent.GetUserSession(),
           query);
        }
      }
      // Return no Redirect - we want to stay on the search results page
      return null;
    }
    
    /// <summary>
    /// This method is called just before the initial query is
    /// executed for banner search.  It uses a user's preferences to add a few
    /// settings to the search (to specify the object types to be searched, for
    /// example).  It also calls any banner search event interface to allow a
    /// customer or PSO to customize the search query or settings.
    /// </summary>
    protected override SearchSettingCollection GetCustomSearchSettings()
    {
      SearchSettingCollection settings = new SearchSettingCollection();
      // Banner search always uses BestBets, spellchecking, and thesaurus
      settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, true);
      settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, true);
      settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_THESAURUS, true);
      // Banner search does not bring back header, footer, or canvas portlets;
      // restricting GADGET_SEARCH_TYPE to "bannersearch" accomplishes this
      settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE,
       SearchSettingCollection.GADGET_SEARCH_TYPE_BANNERSEARCH);
      // Look up the current user's preferences (or retrieve from cache)
      BannerSearchPreferences prefs = GetPreferences();
      // Set the user's page size.
      settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, prefs.pageSize);
      // If the user only wants to see results in his/her own language
      if (prefs.limitByLocale)
      {
        // then change the LIMITBYLOCALE setting
        settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE, true);
        }
      // If the user has a preferred "sort order" (can actually be either an order-by
      // or group-by setting.. "sort order" is misnamed), use it
      if ((null != prefs.groupBy) && (0 < prefs.groupBy.Length))
      {
        // Check for the special "lastmodified" token, which actually means to order
        // by last-modified date, not group-by
        if (prefs.groupBy.Equals("lastmodified"))
        {
          settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, -1 * PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED);
          } else
        {
          // Otherwise, the setting controls "group-by"
          settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_GROUPBYPROP, prefs.groupBy);
          }
      }
      // By default, PTSearch retrieves objects from the portal, 
      // Collaboration Server, or Content Server.  If the user has
      // changed one of these defaults, we need to change the setting
      // PT_SEARCHSETTING_APPS.
      if ((!prefs.returnCollabObjects) || (!prefs.returnContentObjects) || (null == prefs.portalObjectTypes))
      {
        int appFlag = 0;
        // If we're returning any portal object types
        if (null != prefs.portalObjectTypes)
        {
          appFlag|=PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL;
        }
        if (prefs.returnCollabObjects)
        {
          appFlag|=PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB;
        }
        if (prefs.returnContentObjects)
        {
          appFlag|=PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT;
        }
        settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, appFlag);
      }
      // If the user wants any portal object types,
      // modify PT_SEARCHSETTING_OBJTYPES to indicate which types
      if (null != prefs.portalObjectTypes)
      {
        // Banner search retrieves only certain portal object types.
        // Note collab/content also comes back by default.
        settings.add(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, prefs.portalObjectTypes);
        }
      // Finally, if there are PEIs that might add or override settings,
      // we need to merge those with the set we already have.
      // Make sure any PEIs are loaded
      LoadBannerSearchPEIs();
      if (null != _bannerSearchPEIs)
      {
        IXPEnumerator e = _bannerSearchPEIs.GetEnumerator();
        while (e.MoveNext())
        {
          IBannerSearchActions pei = (IBannerSearchActions) e.GetCurrent();
          SearchSettingCollection customSettings = pei.GetCustomSettingsOnBeforeSearch(_parent,
           (IPTSession) _parent.GetUserSession());
          if (null != customSettings)
          {
            settings.merge(customSettings);
          }
        }
      }
      // All done
      return settings;
    }
    
    /// <summary>
    /// For banner searches, the user's query is logged in the search server logs
    /// </summary>
    protected override String GetLogString()
    {
      return _logString;
    }
    
    /// <summary>
    /// Helper method to look up the current user's banner search preferences.  Checks
    /// a cache first; if not there, looks in the database.
    /// </summary>
    /// <returns>the current user's banner search preferences.</returns>
    private BannerSearchPreferences GetPreferences()
    {
      BannerSearchPreferences prefs = new BannerSearchPreferences();
      IBannerSearchHelper bannerSearchHelper = BannerSearchHelperService.GetInstance();
      const int DEFAULT_PAGE_SIZE = 10;
      try
      {
        IPTSession session = (IPTSession) _parent.GetUserSession();
        int userID = GetUserID();
        IPTSessionInfo sessionInfo = session.GetSessionInfo();
        // Try to look up preferences in the subsession cache
        Object o = _parent.GetSubSession().GetAttribute(CACHED_SEARCHPREFS_KEY);
        int nObjectTypeOverride = bannerSearchHelper.GetIntSessionSetting(sessionInfo,
         BannerSearchHelperService.SEARCHPREF_OBJECTTYPES_OVERRIDE, -1);
        if (nObjectTypeOverride == -1 && (null != o) && (o is BannerSearchPreferences))
        {
          BannerSearchPreferences cachedPrefs = (BannerSearchPreferences) o;
          // If the user has not logged in and out as another user
          if (cachedPrefs.userID == userID)
          {
            // .. just use the cached prefs
            return (BannerSearchPreferences) o;
          }
        }
        // Otherwise, we need to look up preferences in the database..
        prefs.userID = userID;
        prefs.pageSize = bannerSearchHelper.GetIntSetting(sessionInfo, SEARCHPREF_PAGESIZE,
         DEFAULT_PAGE_SIZE);
        prefs.groupBy = bannerSearchHelper.GetStringSetting(sessionInfo, SEARCHPREF_GROUPBY,
         null);
        int limitFlag = bannerSearchHelper.GetIntSetting(sessionInfo, SEARCHPREF_LIMITBYLOCALE,
         0);
        prefs.limitByLocale = (limitFlag != 0);
        int objectTypeBitmask = bannerSearchHelper.GetIntSetting(sessionInfo,
         BannerStartSearchControl.SEARCHPREF_OBJECTTYPES, 0);
        prefs.returnCollabObjects = (0 == (objectTypeBitmask & BannerSearchHelperService.BIT_COLLAB));
        prefs.returnContentObjects = (0 == (objectTypeBitmask & BannerSearchHelperService.BIT_CONTENT));
        XPArrayList classIDs = bannerSearchHelper.GetPortalObjectTypes(sessionInfo,
         objectTypeBitmask);
        // now convert to int[]
        if (0 < classIDs.GetSize())
        {
          prefs.portalObjectTypes = new int[classIDs.GetSize()];
          for (int j = 0;j < classIDs.GetSize();j++)
          {
            prefs.portalObjectTypes[j] = XPConvert.ToInteger(classIDs.GetElement(j));
            }
        } else
        {
          prefs.portalObjectTypes = null;
        }
        if (nObjectTypeOverride == -1)
        {
          // Cache the preferences we've looked up
          _parent.GetSubSession().SetAttribute(CACHED_SEARCHPREFS_KEY, prefs);
          }
      }
      catch (Exception e)
      {
        // On any error, just use defaults
        prefs.pageSize = DEFAULT_PAGE_SIZE;
        prefs.limitByLocale = false;
        prefs.portalObjectTypes = GetBannerSearchObjectTypes();
        prefs.returnCollabObjects = true;
        prefs.returnContentObjects = true;
        log.Error(e, "Caught exception while looking up banner search preferences, using defaults instead.");
        }
      return prefs;
    }
    
    /// <summary>
    /// Helper method to look up the current user's ID.
    /// </summary>
    /// <returns>the current user's ID.</returns>
    private int GetUserID()
    {
      IPTSession session = (IPTSession) _parent.GetUserSession();
      IPTSessionInfo info = session.GetSessionInfo();
      return info.GetCurrentUserID();
    }
    
    /// <summary>
    /// Private helper method to cache recent searches; these are displayed in
    /// the intrinsic search portlet
    /// </summary>
    /// <param name="query"></param>
    private void cacheRecentSearches(QueryArguments query)
    {
      // If it's not an advanced search
      // fixing j2c translation error -mgs
      String userQuery = query.userQuery;
      if ((null != query.userQuery) && (0 < userQuery.Length))
      {
        Object[][] oa = null;
        // Check whether we have cached recent searches
        Object o = _parent.GetSubSession().GetAttribute(CACHED_RECENT_KEY);
        if ((null == o) || (!(o is RecentSearchHistory)))
        {
          // If it's not there or is corrupt, recreate and cache it
          oa = new Object[2][];
          for (int j2c_index = 0;j2c_index < 2;j2c_index++)
          {
            oa[j2c_index] = new Object[3];
          }
          oa[0][0] = null;
          oa[1][0] = null;
          oa[0][1] = null;
          oa[1][1] = null;
          oa[0][2] = null;
          oa[1][2] = null;
          RecentSearchHistory hist = new RecentSearchHistory();
          hist.userId = GetUserID();
          hist.recentSearches = oa;
          _parent.GetSubSession().SetAttribute(CACHED_RECENT_KEY, hist);
        } else
        {
          RecentSearchHistory hist = (RecentSearchHistory) o;
          // Has the user ID changed?
          if (hist.userId != GetUserID())
          {
            // If so, replace the cached object
            oa = new Object[2][];
            for (int j2c_index = 0;j2c_index < 2;j2c_index++)
            {
              oa[j2c_index] = new Object[3];
            }
            oa[0][0] = null;
            oa[1][0] = null;
            oa[0][1] = null;
            oa[1][1] = null;
            oa[0][2] = null;
            oa[1][2] = null;
            hist = new RecentSearchHistory();
            hist.userId = GetUserID();
            hist.recentSearches = oa;
            _parent.GetSubSession().SetAttribute(CACHED_RECENT_KEY, hist);
            }
          oa = hist.recentSearches;
        }
        // If this isn't a repeat of something already in the list
        if (!(((null != oa[0][0]) && query.userQuery.Equals((String) oa[0][0])) || ((null != oa[0][1]) && query.userQuery.Equals((String) oa[0][1]))))
        {
          // Move everybody else back a step
          oa[0][2] = oa[0][1];
          oa[1][2] = oa[1][1];
          oa[0][1] = oa[0][0];
          oa[1][1] = oa[1][0];
          // Add the latest query
          oa[0][0] = query.userQuery;
          oa[1][0] = ASConstants.SPACENAME + "=" + SearchResultAS.STR_MVC_CLASS_NAME + "&" + ASConstants.CONTROL + "=" + BannerStartSearchControl.STR_MVC_CLASS_NAME + "&" + StartSearchControl.USER_QUERY + "=" + XPHttpUtility.UrlEncode(query.userQuery,
           "utf-8");
        }
      }
    }
    
    /// <summary>
    /// Inner class holding all of a single user's banner search preferences,
    /// e.g. preferred number of results per page, object types, and so on.
    /// </summary>
    private class BannerSearchPreferences
    {
      public int[] portalObjectTypes;
      public bool limitByLocale;
      public bool returnCollabObjects;
      public bool returnContentObjects;
      public int pageSize;
      public String groupBy;
      public int userID;
    }
    private IXPCollection _bannerSearchPEIs = null;
    private bool _loadedPEIs = false;
    private String _logString = null;
    
    /// <summary>
    /// BrianH/CraigS : This function will pull in all of the available
    /// IBannerSearchActions PEIs.
    /// </summary>
    private void LoadBannerSearchPEIs()
    {
      // if already loaded
      if (_loadedPEIs)
      {
        // don't do it again
        return;
      }
      _loadedPEIs = true;
      IApplication application = _parent.GetApplication();
      Object[] actions = (Object[]) application.GetCachingManager().GetEntry("BannerSearchActions");
      if (null != actions)
      {
        _bannerSearchPEIs = new XPArrayList();
        for (int x = 0;x < actions.Length;x++)
        {
          Object oAction = actions[x];
          if ((null != oAction) && (oAction is IBannerSearchActions))
          {
            _bannerSearchPEIs.Add(oAction);
          } else
          {
            log.Warn("BannerStartSearchControl.LoadBannerSearchPEIs: element " + XPConvert.ToString(x) + " is not an instance of IBannerSearchActions");
            }
        }
      }
    }
  }
}