using System;
using com.plumtree.server;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.analytics.openusage;
namespace com.plumtree.portalpages.browsing.search.results
{
  public class LoggingHelperModel : IModel
  {
    
    /// <summary>
    /// Name of this class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SearchLogHelper";
    
    /// <summary>
    /// Search type - Banner search 
    /// </summary>
    public const String SEARCH_TYPE_BANNER = "banner";
    
    /// <summary>
    /// Search type - Advanced search 
    /// </summary>
    public const String SEARCH_TYPE_ADVANCED = "advanced";
    
    /// <summary>
    /// Owning session 
    /// </summary>
    private IPTSession _session;
    
    /// <summary>
    /// Owning activityspace 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Query logging id, set to non-null when this is a banner search (in ).
    /// </summary>
    protected String _queryLoggingId = null;
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      _session = (IPTSession) m_asOwner.GetUserSession();
      _queryLoggingId = null;
    }
    public virtual void CleanupTempData()
    {
    }
    public virtual void CleanupAllData()
    {
      _queryLoggingId = null;
    }
    public virtual Object Create()
    {
      return new LoggingHelperModel();
    }
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public virtual String GetLoggingID()
    {
      return _queryLoggingId;
    }
    public virtual void LogStartSearchEvent(String searchString, String searchType)
    {
      _queryLoggingId = _GenerateNewSearchId();
      ISearchEvent searchEvent = ASEventFactory.createSearchEvent();
      searchEvent.setSearchString(searchString);
      int nUserId = _session.GetSessionInfo().GetCurrentUserID();
      searchEvent.setUserId(nUserId);
      searchEvent.setQueryId(_queryLoggingId);
      // No need to set timestamp
      //XPDateTime dateTime = new XPDateTime();
      //long nTimeStamp = dateTime.GetTimeInMilliSeconds();
      //searchEvent.setTimestamp(new Long(nTimeStamp));
      // Set the search type (advanced or banner)
      searchEvent.setSearchType(searchType);
      // Log the event...
      searchEvent.sendEvent();
    }
    public virtual void LogSearchResultsEvent(int nNumTotalMatches, int nResultStartRange,
     int nResultEndRange, String drilldownKey)
    {
      if (null == _queryLoggingId)
      {
        // If initial search wasn't logged, then no need to log results
        return;
      }
      ISearchResultEvent searchResultEvent = ASEventFactory.createSearchResultEvent();
      searchResultEvent.setQueryId(_queryLoggingId);
      searchResultEvent.setTotalMatches(nNumTotalMatches);
      searchResultEvent.setStartRange(nResultStartRange);
      searchResultEvent.setEndRange(nResultEndRange);
      if (drilldownKey != null)
      {
        searchResultEvent.setCategoryFilter(drilldownKey);
      }
      // DCA - no longer needed
      //searchResultEvent.setSpellCorrect(bWasSpellCorrected);
      //searchResultEvent.setBestBets(bHasBestBets);
      int nUserId = _session.GetSessionInfo().GetCurrentUserID();
      searchResultEvent.setUserId(nUserId);
      // No need to set timestamp
      //XPDateTime dateTime = new XPDateTime();
      //long nTimeStamp = dateTime.GetTimeInMilliSeconds();
      //searchResultEvent.setTimestamp(new Long(nTimeStamp));
      // Log the event...
      searchResultEvent.sendEvent();
    }
    private String _GenerateNewSearchId()
    {
      long lTime = XPSystem.GetCurrentTimeMilliSec();
      // Used the cached user ID - don't go to the DB for something as
      // useless as this.
      int nUserId = _session.GetSessionInfo().GetCurrentUserID();
      int nKey = (int) lTime + nUserId;
      String strId = XPConvert.ToString(nKey);
      if (strId.Length > 8)
      {
        strId = XPStringUtility.Substring(strId, strId.Length - 8);
      }
      return strId;
    }
  }
}