using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.search.exceptions;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public class SaveSearch508View : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.search.results.SaveSearch508View");
    public const String STR_MVC_CLASS_NAME = "SaveSearch508";
    public static readonly String FORM_NAME = STR_MVC_CLASS_NAME;
    public const String HI_TEXTBOX = "in_tx_ss_name";
    public const String HI_508_SAVE = "in_su_ss_save";
    public const String HI_508_CANCEL = "in_su_ss_cancel";
    protected AActivitySpace m_asOwner;
    protected ISearchResultModelRO _model;
    
    /// <returns></returns>
    public virtual Object Create()
    {
      return new SaveSearch508View();
    }
    
    /// <returns></returns>
    public virtual HTMLElement Display()
    {
      if (!_model.IsInitialized())
      {
        // The activityspace cache must have been flushed.  Show the
        // "your search is no longer available" message.
        throw new CacheFlushedException(m_asOwner);
      }
      HTMLForm form = null;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      try
      {
        form = new HTMLForm(FORM_NAME);
        form.SetName(FORM_NAME);
        form.SetID(FORM_NAME);
        form.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(),
         m_asOwner.GetName(), m_asOwner.IsSubSpace()));
        myTable = new HTMLTable();
        myTable.SetBorder("0");
        myTable.SetWidth("100%");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        // "Save this Search"
        myTable.SetSummary(m_asOwner.GetString(816, "ptmsgs_portalbrowsingmsgs"));
        form.AddInnerHTMLElement(myTable);
        // Add hidden inputs for the current space, ID, page, and SaveSearchControl
        // Stay in the same space
        HTMLInput targetSpace = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACENAME_INPUT,
         ASConstants.SPACENAME_INPUT, "");
        targetSpace.SetValue(m_asOwner.GetName());
        form.AddInnerHTMLElement(targetSpace);
        // Add our current space ID, so the framework doesn't create
        // another instance of the space
        HTMLInput targetSpID = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.SPACEID_INPUT,
         ASConstants.SPACEID_INPUT, "");
        targetSpID.SetValue(m_asOwner.GetSpaceID());
        form.AddInnerHTMLElement(targetSpID);
        // Set target as SaveSearchControl
        HTMLInput targetControl = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.CONTROL_INPUT,
         ASConstants.CONTROL_INPUT, "");
        targetControl.SetValue(SaveSearchControl.STR_MVC_CLASS_NAME);
        form.AddInnerHTMLElement(targetControl);
        // OUTER TABLE ROW: Header, "Save this Search"
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        myCell.SetStyleClass(PTStyleClass.BAN_TEXT);
        myCell.SetHeight("30");
        myCell.AddInnerHTMLString("&nbsp;");
        myCell.AddInnerHTMLString("&nbsp;");
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.BAN_HEADER);
        // "Save this Search"
        mySpan.AddInnerHTMLString(m_asOwner.GetString(816, "ptmsgs_portalbrowsingmsgs"));
        // OUTER TABLE BLANK ROW
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetHeight("30");
        // OUTER TABLE ROW: containing inner table
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // Add inner table with grey background
        HTMLTable innerTable = new HTMLTable();
        innerTable.SetCellPadding("10");
        innerTable.SetCellSpacing("0");
        innerTable.SetWidth("100%");
        innerTable.SetBorder("00");
        myCell.AddInnerHTMLElement(innerTable);
        bool somethingVeryBadHappened = false;
        // Check if there were any errors the last time the user clicked Save
        int errorCode = _model.GetSavedSearchErrorCode();
        if (0 != errorCode)
        {
          // INNER TABLE ROW: report error
          myRow = new HTMLTableRow();
          innerTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
          mySpan = new HTMLSpan();
          mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.AddInnerHTMLString("<b>&nbsp;");
          if (SaveSearchControl.ERRORCODE_NO_NAME_ENTERED == errorCode)
          {
            mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(841, "ptmsgs_portalbrowsingmsgs"));
            } else
          if (SaveSearchControl.ERRORCODE_ALREADY_EXISTS == errorCode)
          {
            mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(842, "ptmsgs_portalbrowsingmsgs"));
            } else
          {
            somethingVeryBadHappened = true;
            mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(843, "ptmsgs_portalbrowsingmsgs"));
            }
          mySpan.AddInnerHTMLString("</b>");
        }
        // ADDITIONAL INNER TABLE BLANK ROW IN CASE OF ERROR
        /*
         myRow = new HTMLTableRow();
         innerTable.AddInnerHTMLElement(myRow);
         myCell = new HTMLTableCell();
         myRow.AddInnerHTMLElement(myCell);
         myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
         myCell.SetHeight("15");
         */
         
        if (!somethingVeryBadHappened)
        {
          // INNER TABLE ROW: You are saving this search in the Portal Search Portlet.
          myRow = new HTMLTableRow();
          innerTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
          mySpan = new HTMLSpan();
          mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(836, "ptmsgs_portalbrowsingmsgs"));
          // INNER TABLE ROW: To see your Saved Searches, you will need to add the Portal Search Portlet to your My Page.
          myRow = new HTMLTableRow();
          innerTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
          mySpan = new HTMLSpan();
          mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
          myCell.AddInnerHTMLElement(mySpan);
          // In 508 mode, we can't support the "add the search portlet" link,
          // so just show a plain string
          // _ui_ToSee == "To see your saved searches, add the Portal Search Portlet to your My Page."
          mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(837, "ptmsgs_portalbrowsingmsgs"));
          // INNER TABLE BLANK ROW
          /*
           myRow = new HTMLTableRow();
           innerTable.AddInnerHTMLElement(myRow);
           myCell = new HTMLTableCell();
           myRow.AddInnerHTMLElement(myCell);
           myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
           myCell.SetHeight("10");
           */
           
          // INNER TABLE ROW: Enter a name for this saved search, and textbox
          myRow = new HTMLTableRow();
          myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
          innerTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("20");
          myCell.SetNoWrap(true);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
          mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(838, "ptmsgs_portalbrowsingmsgs"));
          myCell.AddInnerHTMLString("   ");
          HTMLInput textBox = new HTMLInput(HTMLInputTypes.TEXT, HI_TEXTBOX,
           "");
          textBox.SetSize(51);
          textBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
          textBox.SetValue(_model.GetSearchString());
          myCell.AddInnerHTMLElement(textBox);
          // INNER TABLE BLANK ROW
          myRow = new HTMLTableRow();
          innerTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
          myCell.SetHeight("15");
          // END INNER TABLE
          // OUTER TABLE BLANK ROW
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("25");
          // OUTER TABLE ROW: submit and cancel buttons
          myRow = new HTMLTableRow();
          myRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetHeight("40");
          myCell.SetAlign("center");
          myRow.AddInnerHTMLElement(myCell);
          // in 508 mode, make an ordinary submit button
          HTMLInput saveButton = new HTMLInput(HTMLInputTypes.SUBMIT, HI_508_SAVE,
           "");
          saveButton.SetValue(m_asOwner.GetString(839, "ptmsgs_portalbrowsingmsgs"));
          saveButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
          saveButton.SetAccessKey(m_asOwner.GetString(26, "ptmsgs_portal508quickkeymsgs"));
          saveButton.SetTitle(m_asOwner.GetString(28, "ptmsgs_portal508quickkeymsgs"));
          myCell.AddInnerHTMLElement(saveButton);
          myCell.AddInnerHTMLElement(DirConstants.CreateSpacerImage(1, 10));
          } else
        {
          // if, because of some serious error, 
          // we're just showing the cancel button, create a row and cell for it
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myCell.SetAlign("center");
          myRow.AddInnerHTMLElement(myCell);
        }
        // always show the cancel button, even if a bad error happened, like
        // the portal going down
        HTMLInput cancelButton = new HTMLInput(HTMLInputTypes.SUBMIT, HI_508_CANCEL,
         "");
        cancelButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        cancelButton.SetAccessKey(m_asOwner.GetString(27, "ptmsgs_portal508quickkeymsgs"));
        cancelButton.SetTitle(m_asOwner.GetString(29, "ptmsgs_portal508quickkeymsgs"));
        cancelButton.SetValue(m_asOwner.GetString(840, "ptmsgs_portalbrowsingmsgs"));
        myCell.AddInnerHTMLElement(cancelButton);
        // OUTER TABLE ROW FOR FINAL BLANK SPACE
        myTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(1, 150));
        }
      catch (XPException e)
      {
        // Just display the exception.
        log.Error(e, e.Message);
        // Let the framework catch this exception and show a generic message,
        // with the underlying stack trace hidden in a comment
        throw e;
      }
      catch (Exception e)
      {
        // Let the framework catch this exception and show a generic message,
        // with the underlying stack trace hidden in a comment
        throw XPException.GetInstance(e);
      }
      return form;
    }
    
    /// <returns></returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <returns></returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="model"></param>
    /// <param name="parent"></param>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      _model = (ISearchResultModelRO) model;
      m_asOwner = parent;
    }
  }
}