using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public class SearchBannerView : SearchResultView
  {
    public const String STR_MVC_CLASS_NAME = "SearchBannerView";
    
    /// <returns></returns>
    public override Object Create()
    {
      return new SearchBannerView();
    }
    protected SearchPageModeHelper _pageMode = null;
    public virtual void SetPageModeHelper(SearchPageModeHelper pageMode)
    {
      _pageMode = pageMode;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultView#DisplaySearchView()"></seealso>
    public override HTMLElement DisplaySearchView()
    {
      // If no results were returned, don't display anything.
      if (0 == _model.GetTotalItems())
      {
        return null;
      }
      String banner;
      if ((null != _pageMode) && (_pageMode.IsAdminMode()))
      {
        // Use a different message to clue the user in that clickthrough behaves
        // differently
        banner = m_asOwner.GetString(1396, "ptmsgs_portalbrowsingmsgs");
      } else
      {
        banner = m_asOwner.GetString(844, "ptmsgs_portalbrowsingmsgs");
      }
      // In 508 mode, limit formatting
      if (is508())
      {
        HTMLDiv c = new HTMLDiv();
        c.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
        // "Search Results"
        HTMLSpan span508 = new HTMLSpan();
        span508.SetStyleClass(PTStyleClass.DIR_HEADER);
        span508.AddInnerHTMLString(banner);
        c.AddInnerHTMLElement(span508);
        c.AddInnerHTMLElement(new HTMLBr());
        return c;
      }
      HTMLTable table = new HTMLTable();
      table.SetCellSpacing("0");
      table.SetCellPadding("5");
      table.SetWidth("100%");
      HTMLTableRow row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
      cell.SetHeight("25");
      cell.SetVAlign("middle");
      cell.SetWidth("100%");
      cell.SetStyleClass(PTStyleClass.DIR_HEADER);
      cell.AddInnerHTMLString(banner);
      // User is an administrator, so they could click the "edit" link; we aren't doing an "admin object search",because
      // in that case the edit link doesn't apply.
      if ((null != _pageMode) && _pageMode.UserHasEditModeAccess() && (!_pageMode.IsAdminMode()))
      {
        cell = new HTMLTableCell();
        cell.SetStyleClass(PTStyleClass.DIR_HEADER);
        cell.SetNoWrap(true);
        //Add edit/browse button
        cell.AddInnerHTMLElement(GetEditBrowseButton());
        row.AddInnerHTMLElement(cell);
      }
      return table;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public virtual HTMLElement GetEditBrowseButton()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      PTConstruct buttonConstruct;
      HTMLAnchor myAnchor;
      bool editing = (null != _pageMode) && (_pageMode.IsEditMode());
      if (editing)
      {
        //Toggle Mode button has Browse image
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.BROWSE_HEADER,
         true, this.m_asOwner);
        buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.BROWSE_HEADER.TITLE_ELEMENT_NAME,
         m_asOwner.GetString(170, "ptmsgs_portalbrowsingmsgs"));
        ASURL urle = new ASURL(m_asOwner);
        urle.SetLinkGetCachedSpace(m_asOwner);
        urle.SetControl(SearchBrowseEditModeControl.STR_MVC_CLASS_NAME);
        urle.SetDisplayPage(SearchResultDP.STR_MVC_CLASS_NAME);
        urle.AddControlArgument(SearchBrowseEditModeControl.EDIT_MODE_INPUT,
         SearchBrowseEditModeControl.BROWSE_VALUE);
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.BROWSE_HEADER.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(urle.GetURLAsString());
        result.AddInnerHTMLElement(buttonConstruct.GetHTMLElement());
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(170,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(170,
         "ptmsgs_portalbrowsingmsgs"));
      } else
      {
        //Toggle Mode button has Edit image
        buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EDIT_HEADER,
         true, this.m_asOwner);
        buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.EDIT_HEADER.TITLE_ELEMENT_NAME,
         m_asOwner.GetString(171, "ptmsgs_portalbrowsingmsgs"));
        ASURL urle = new ASURL(m_asOwner);
        urle.SetLinkGetCachedSpace(m_asOwner);
        urle.SetControl(SearchBrowseEditModeControl.STR_MVC_CLASS_NAME);
        urle.SetDisplayPage(SearchResultDP.STR_MVC_CLASS_NAME);
        urle.AddControlArgument(SearchBrowseEditModeControl.EDIT_MODE_INPUT,
         SearchBrowseEditModeControl.EDIT_VALUE);
        // BROWSE_HEADER?
        myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.EDIT_HEADER.ANCHOR_ELEMENT_NAME);
        myAnchor.SetHRef(urle.GetURLAsString());
        result.AddInnerHTMLElement(buttonConstruct.GetHTMLElement());
        ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(171,
         "ptmsgs_portalbrowsingmsgs"));
        ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(171,
         "ptmsgs_portalbrowsingmsgs"));
      }
      return result;
    }
  }
}