using System;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public class SearchPageModeHelper
  {
    private ISearchResultModelRO _model = null;
    private AActivitySpace _asOwner = null;
    public virtual void Init(SearchResultModel model, AActivitySpace asOwner)
    {
      _model = model;
      _asOwner = asOwner;
      if (null == _model.GetPageMode())
      {
        model.SetPageMode(BROWSE_MODE);
      }
    }
    public const String BROWSE_MODE = "browse";
    public const String EDIT_MODE = "edit";
    public const String ADMIN_MODE = "admin";
    public virtual bool IsBrowseMode()
    {
      return _model.GetPageMode().Equals(BROWSE_MODE);
    }
    public virtual bool IsEditMode()
    {
      return _model.GetPageMode().Equals(EDIT_MODE);
    }
    public virtual bool IsAdminMode()
    {
      return _model.GetPageMode().Equals(ADMIN_MODE);
    }
    public virtual bool ShowToolbar()
    {
      return (!IsBrowseMode());
    }
    public virtual bool GetMakeEditLinks()
    {
      return IsAdminMode();
    }
    public virtual bool UserHasEditModeAccess()
    {
      // DCA - display edit URL if there is no type restriction and user has admin and KD edit access,
      // or search is restricted to KD items and user has KD edit access,
      // or search is restricted to some admin objects and user has admin access
      int selectedFilter = _model.GetSelectedTypeFilter();
      if ((selectedFilter < 0 && UserHasAdminAccess(_asOwner) && UserHasEditDocumentAccess(_asOwner)) || ((selectedFilter == SearchObjectTypes.CLASSID_00 || selectedFilter == SearchObjectTypes.CLASSID_01) && UserHasEditDocumentAccess(_asOwner)) || (selectedFilter > 0 && selectedFilter != SearchObjectTypes.CLASSID_00 && selectedFilter != SearchObjectTypes.CLASSID_01 && UserHasAdminAccess(_asOwner)))
      {
        return true;
      } else
      {
        return false;
      }
    }
    public virtual bool UserHasAdminAccess(AActivitySpace asOwner)
    {
      IPTSession ptSession = (IPTSession) (asOwner.GetUserSession());
      IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
      return ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      }
    public virtual bool UserHasEditDocumentAccess(AActivitySpace asOwner)
    {
      IPTSession ptSession = (IPTSession) (asOwner.GetUserSession());
      IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
      return ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY);
      }
    public static bool UserHasEditModeAccess(AActivitySpace asOwner)
    {
      IPTSession ptSession = (IPTSession) (asOwner.GetUserSession());
      IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
      return (ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION) && ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY));
      }
  }
}