using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public abstract class SearchResultView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.search.results.SearchResultView");
    //
    // The rest of this file is useful helpers for subclasses
    //
    public const String SPACE = "&nbsp;";
    public const String SPACE2 = "&nbsp;&nbsp;";
    public const String SPACE3 = "&nbsp;&nbsp;&nbsp;";
    public const String SPACE4 = "&nbsp;&nbsp;&nbsp;&nbsp;";
    protected AActivitySpace m_asOwner;
    protected ISearchResultModelRO _model;
    
    /// <summary>
    /// This method is used by the ASManager to return new instances of managed
    /// objects.
    /// </summary>
    /// <returns>A new instance of the managed class (i.e. return new Foo();)</returns>
    public abstract Object Create();
    
    /// <summary>
    /// DisplaySearchView() should be implemented by all subclasses and
    /// should perform the same function as the regular Display() method,
    /// but is allowed to throw a SearchModelException or an HTMLException.
    /// SearchModelException indicates a problem with usage of the
    /// portalinfrastructure classes, not a problem with the search itself
    /// (which are SearchExecutionExceptions; call ISearchResultModelRO.GetError()).
    /// </summary>
    public abstract HTMLElement DisplaySearchView();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement he = null;
      // If the last search failed..
      if (null != _model.GetError())
      {
        // Usually this is null. Sometimes it is an un-internationalized error message.
        return _model.GetError().GetComment();
      }
      try
      {
        // display the view
        he = DisplaySearchView();
      }
      catch (SearchModelException e)
      {
        // Just display the exception.
        log.Error(e, "Unable to display search results view due to problem in search model.");
        // Let the framework catch this exception and show a generic message,
        // with the underlying stack trace hidden in a comment
        throw e;
      }
      //he = new HTMLGenericElement(e.getMessage());
      catch (HTMLException e)
      {
        // Same.
        log.Error(e, "Unable to display search results view.");
        throw XPException.GetInstance(e);
      }
      return he;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      // by default, return nothing
      return null;
    }
    
    /// <returns></returns>
    public abstract String GetName();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      _model = (ISearchResultModelRO) model;
      m_asOwner = parent;
    }
    
    /// <returns></returns>
    protected virtual bool is508()
    {
      return (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD);
    }
  }
}