using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.application.varpacks;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public class SearchSummaryView : SearchResultView
  {
    public const String STR_MVC_CLASS_NAME = "SearchSummary";
    protected SearchPageModeHelper _pageMode = null;
    public virtual void SetPageModeHelper(SearchPageModeHelper pageMode)
    {
      _pageMode = pageMode;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SearchSummaryView();
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultView#DisplaySearchView()"></seealso>
    public override HTMLElement DisplaySearchView()
    {
      // Log this set of results to the Analytics Server
      LogSearchResultsEvent();
      bool displayedAnythingInThisView = false;
      HTMLTable table = new HTMLTable();
      table.SetCellSpacing("0");
      table.SetCellPadding("5");
      table.SetWidth("100%");
      table.SetSummary(m_asOwner.GetString(1397, "ptmsgs_portalbrowsingmsgs"));
      HTMLTableRow row = null;
      HTMLTableCell cell = null;
      int height = 25;
      row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      // FIRST ROW:  Breadcrumbs.
      int heightToAdd = DisplayBreadcrumbs(cell);
      if (heightToAdd > 0)
      {
        height+=heightToAdd;
        displayedAnythingInThisView = true;
      }
      // end row for breadcrumb links
      // SECOND ROW:  Restrictions on the search (folders, communities, types, property conditions).
      bool displayedAnythingOnSecondRow = false;
      HTMLElementCollection secondRow = new HTMLElementCollection();
      secondRow.AddInnerHTMLString(m_asOwner.GetString(850, "ptmsgs_portalbrowsingmsgs"));
      secondRow.AddInnerHTMLElement(new HTMLBr());
      HTMLTable srTable = new HTMLTable();
      secondRow.AddInnerHTMLElement(srTable);
      srTable.SetCellSpacing("5");
      srTable.SetCellPadding("0");
      srTable.SetWidth("100%");
      srTable.SetSummary(m_asOwner.GetString(1398, "ptmsgs_portalbrowsingmsgs"));
      if (DisplayTypeRestrictions(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayCommunityRestrictions(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayAdminAndDocFolderRestrictions(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayPortletRestrictions(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayCollabProjectRestrictions(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayLanguageRestriction(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayTextRestriction(srTable, displayedAnythingOnSecondRow))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (DisplayPropertyContraints(srTable))
      {
        displayedAnythingOnSecondRow = true;
      }
      if (displayedAnythingOnSecondRow)
      {
        cell.AddInnerHTMLElement(secondRow);
        cell.AddInnerHTMLElement(new HTMLBr());
        displayedAnythingInThisView = true;
      }
      // THIRD ROW:  Spelling corrections.
      if (DisplaySpellCorrections(cell))
      {
        displayedAnythingInThisView = true;
      }
      // FOURTH ROW:  Number of results and range displayed.
      // In 508 mode, this is displayed by GroupedResults508ViewHelper, so we skip it here.
      if (!is508())
      {
        ShowNumberOfResults(m_asOwner, cell, _model);
        displayedAnythingInThisView = true;
      }
      // FIFTH ROW: Check whether there is a warning message to display
      SearchExecutionWarning warning = _model.GetWarning();
      if (null != warning)
      {
        cell.AddInnerHTMLElement(new HTMLBr());
        cell.AddInnerHTMLElement(new HTMLBr());
        displayedAnythingInThisView = true;
        height+=25;
        cell.AddInnerHTMLString(((XPException) warning).GetMessage());
      }
      cell.SetHeight(XPConvert.ToString(height));
      if (!displayedAnythingInThisView)
      {
        return null;
      }
      return table;
    }
    
    /// <summary>
    /// Diplays search breadcrumbs when user drills down
    /// </summary>
    /// <param name="cell">Cell to which to add breadcrumbs, if any</param>
    /// <returns>true if displayed, false otherwise</returns>
    private int DisplayBreadcrumbs(HTMLTableCell cell)
    {
      // If user has drilled down.. and is not in 508 mode
      if ((1 < _model.GetDrilldownDepth()) && (!is508()))
      {
        // After drilldown, show a row with breadcrumb links, like
        // Search for lunch : Restricted to Portlets 
        // Original search first
        String firstCrumb;
        String firstCrumbMouseOver = null;
        if (null != _model.GetSearchString())
        {
          String searchString = XPHttpUtility.HtmlEncode(_model.GetSearchString());
          firstCrumb = XPResourceManager.FormatMessage(m_asOwner.GetString(871,
           "ptmsgs_portalbrowsingmsgs"), searchString);
          // Use the version without <b> tags for the mouseover message
          firstCrumbMouseOver = XPResourceManager.FormatMessage(m_asOwner.GetString(1750,
           "ptmsgs_portalbrowsingmsgs"), searchString);
        } else
        {
          if (_model.isAdvancedSearch())
          {
            firstCrumb = m_asOwner.GetString(874, "ptmsgs_portalbrowsingmsgs");
            } else
          {
            firstCrumb = m_asOwner.GetString(873, "ptmsgs_portalbrowsingmsgs");
            }
        }
        HTMLElement breadcrumbLink = BreadcrumbControl.makeURL(_model, m_asOwner,
         firstCrumb, _model.GetBreadcrumbKey(1));
        if (null != firstCrumbMouseOver)
        {
          breadcrumbLink.SetTitle(firstCrumbMouseOver);
        }
        cell.AddInnerHTMLElement(breadcrumbLink);
        int depth = _model.GetDrilldownDepth();
        // from the first step after the initial search
        // to the next-to-last drilldown step
        for (int j = 2;j <= (depth - 1);j++)
        {
          cell.AddInnerHTMLString(" : ");
          String categoryLabel = XPHttpUtility.HtmlEncode(_model.GetBreadcrumbLabel(j));
          String linkText = XPResourceManager.FormatMessage(m_asOwner.GetString(872,
           "ptmsgs_portalbrowsingmsgs"), categoryLabel);
          breadcrumbLink = BreadcrumbControl.makeURL(_model, m_asOwner, linkText,
           _model.GetBreadcrumbKey(j));
          // Use a string without <b> tags for the mouseover message
          breadcrumbLink.SetTitle(XPResourceManager.FormatMessage(m_asOwner.GetString(1751,
           "ptmsgs_portalbrowsingmsgs"), categoryLabel));
          cell.AddInnerHTMLElement(breadcrumbLink);
        }
        // Add final drilldown step; this isn't a link
        String strCategoryLabel = XPHttpUtility.HtmlEncode(_model.GetBreadcrumbLabel(depth));
        String lastStep = XPResourceManager.FormatMessage(m_asOwner.GetString(872,
         "ptmsgs_portalbrowsingmsgs"), strCategoryLabel);
        cell.AddInnerHTMLString(" : ");
        cell.AddInnerHTMLString(lastStep);
        cell.AddInnerHTMLElement(new HTMLBr());
        cell.AddInnerHTMLElement(new HTMLBr());
        // Height to add
        return 25;
      }
      return 0;
    }
    
    /// <summary>
    /// Display property constraints.
    /// </summary>
    /// <param name="srTable">Table to which to add the row of constraints</param>
    /// <returns>true if displayed, false otherwise</returns>
    private bool DisplayPropertyContraints(HTMLTable srTable)
    {
      // Next, property constraints.
      if ((_model.isAdvancedSearch()) && (!_model.IsASTooComplexToSummarize()) && (_model.GetASNumPropertyConstraints() > 0))
      {
        int numConstraints = _model.GetASNumPropertyConstraints();
        HTMLTableRow srRow = new HTMLTableRow();
        srRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        srTable.AddInnerHTMLElement(srRow);
        HTMLTableCell srCell = new HTMLTableCell();
        srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
        srCell.AddInnerHTMLString(SPACE4);
        srRow.AddInnerHTMLElement(srCell);
        srCell = new HTMLTableCell();
        srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
        srCell.SetNoWrap(true);
        srRow.AddInnerHTMLElement(srCell);
        srCell.SetVAlign("top");
        srCell.SetNoWrap(true);
        if (1 == numConstraints)
        {
          srCell.AddInnerHTMLString(m_asOwner.GetString(861, "ptmsgs_portalbrowsingmsgs"));
          } else
        {
          srCell.AddInnerHTMLString(m_asOwner.GetString(862, "ptmsgs_portalbrowsingmsgs"));
          }
        if (is508())
        {
          // In 508/lb, add a hidden '.' so screenreaders will pause
          srCell.AddInnerHTMLElement(MakeHiddenTextInSpan(".", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
          } else
        {
          srCell.AddInnerHTMLString("&nbsp;&nbsp;");
        }
        srCell = new HTMLTableCell();
        srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
        srRow.AddInnerHTMLElement(srCell);
        srCell.SetWidth("100%");
        if (1 == numConstraints)
        {
          srCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(_model.GetASConstraintProperty(0)));
          srCell.AddInnerHTMLString(" ");
          srCell.AddInnerHTMLString(_model.GetASConstraintOperator(0));
          String cValue = _model.GetASConstraintValue(0);
          if ((null != cValue) && (cValue.Length > 0))
          {
            srCell.AddInnerHTMLString(" <b>");
            if (is508())
            {
              srCell.AddInnerHTMLElement(MakeHiddenTextInSpan("&quot;", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
              }
            srCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(cValue));
            if (is508())
            {
              srCell.AddInnerHTMLElement(MakeHiddenTextInSpan("&quot;", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
              }
            srCell.AddInnerHTMLString("</b>");
          }
        } else
        {
          for (int j = 0;j < numConstraints;j++)
          {
            srCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(_model.GetASConstraintProperty(j)));
            srCell.AddInnerHTMLString(" ");
            srCell.AddInnerHTMLString(_model.GetASConstraintOperator(j));
            String cValue = _model.GetASConstraintValue(j);
            if ((null != cValue) && (cValue.Length > 0))
            {
              srCell.AddInnerHTMLString(" <b>");
              if (is508())
              {
                srCell.AddInnerHTMLElement(MakeHiddenTextInSpan("&quot;",
                 PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
              }
              srCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(cValue));
              if (is508())
              {
                srCell.AddInnerHTMLElement(MakeHiddenTextInSpan("&quot;",
                 PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
              }
              srCell.AddInnerHTMLString("</b>");
            }
            if (j < (numConstraints - 1))
            {
              if (_model.GetASPropertyClauseOperator())
              {
                srCell.AddInnerHTMLString(m_asOwner.GetString(863, "ptmsgs_portalbrowsingmsgs"));
                } else
              {
                srCell.AddInnerHTMLString(m_asOwner.GetString(864, "ptmsgs_portalbrowsingmsgs"));
                }
              srCell.AddInnerHTMLElement(new HTMLBr());
            }
          }
        }
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Displays the text search restriction
    /// </summary>
    /// <param name="srTable">Table to which to add the row</param>
    /// <param name="displayedAnythingOnSecondRow">Flag that indicated if a previous row of restrictions has been displayed</param>
    /// <returns>true if displayed, false otherwise.</returns>
    private bool DisplayTextRestriction(HTMLTable srTable, bool displayedAnythingOnSecondRow)
    {
      // Next, text condition, if advanced search OR if any other constraints are listed.
      if ((_model.isAdvancedSearch() || displayedAnythingOnSecondRow) && (!(_model.isAdvancedSearch() && _model.IsASTooComplexToSummarize())))
      {
        String searchString = _model.GetSearchString();
        if ((null != searchString) && (searchString.Length > 0))
        {
          HTMLTableRow srRow = new HTMLTableRow();
          srRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          srTable.AddInnerHTMLElement(srRow);
          HTMLTableCell srCell = new HTMLTableCell();
          srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          srCell.AddInnerHTMLString(SPACE4);
          srRow.AddInnerHTMLElement(srCell);
          srCell = new HTMLTableCell();
          srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          srCell.SetNoWrap(true);
          srRow.AddInnerHTMLElement(srCell);
          srCell.AddInnerHTMLString(m_asOwner.GetString(860, "ptmsgs_portalbrowsingmsgs"));
          if (is508())
          {
            srCell.AddInnerHTMLElement(MakeHiddenTextInSpan(".", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
            } else
          {
            srCell.AddInnerHTMLString("&nbsp;&nbsp;");
          }
          srCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
          srCell = new HTMLTableCell();
          srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          srRow.AddInnerHTMLElement(srCell);
          srCell.SetWidth("100%");
          srCell.AddInnerHTMLString("<b>");
          if (is508())
          {
            srCell.AddInnerHTMLElement(MakeHiddenTextInSpan("&quot;", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
            }
          srCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(searchString));
          if (is508())
          {
            srCell.AddInnerHTMLElement(MakeHiddenTextInSpan("&quot;", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
            }
          srCell.AddInnerHTMLString("</b>");
          // If there are property constraints as well, append the
          // top-level operator after the search string
          if (_model.isAdvancedSearch() && (_model.GetASNumPropertyConstraints() > 0))
          {
            bool isAnd = _model.GetASTopLevelOperator();
            if (isAnd)
            {
              srCell.AddInnerHTMLString(m_asOwner.GetString(863, "ptmsgs_portalbrowsingmsgs"));
              } else
            {
              srCell.AddInnerHTMLString(m_asOwner.GetString(864, "ptmsgs_portalbrowsingmsgs"));
              }
          } else
          {
            // Show a hidden '.' in 508 mode to make a screenreader pause
            if (is508())
            {
              srCell.AddInnerHTMLElement(MakeHiddenTextInSpan(".", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
              }
          }
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Display the language restriction
    /// </summary>
    /// <param name="srTable">Table to which to add the row</param>
    /// <returns>true if displayed, false otherwise</returns>
    private bool DisplayLanguageRestriction(HTMLTable srTable)
    {
      String language = _model.GetLanguageRestriction();
      if ((!isBannerSearch()) && ((null != language) && (0 < language.Length)))
      {
        // Map two-character language code to a displayable string
        // get LocaleVarPack
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        PTSearchLocaleVarPack langVP = (PTSearchLocaleVarPack) application.GetVarPackManager().GetVariablePackage(PTSearchLocaleVarPack.VARPACK_ID);
        // Get current user's locale
        String currUserLocale = null;
        currUserLocale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();
        // map code to localized string
        language = langVP.GetLanguageNameForCode(language, XPStringUtility.Substring(currUserLocale,
         0, 2));
        // if this gave us something comprehensible
        if ((null != language) && (0 < language.Length))
        {
          // add a row to the search summary table
          HTMLTableRow srRow = new HTMLTableRow();
          srRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
          srTable.AddInnerHTMLElement(srRow);
          HTMLTableCell srCell = new HTMLTableCell();
          srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          srCell.AddInnerHTMLString(SPACE4);
          srRow.AddInnerHTMLElement(srCell);
          srCell = new HTMLTableCell();
          srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          srCell.SetNoWrap(true);
          srRow.AddInnerHTMLElement(srCell);
          srCell.AddInnerHTMLString(m_asOwner.GetString(859, "ptmsgs_portalbrowsingmsgs"));
          srCell = new HTMLTableCell();
          srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
          srRow.AddInnerHTMLElement(srCell);
          srCell.SetWidth("100%");
          srCell.AddInnerHTMLString(language);
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Display collab project restrictions id there are any
    /// </summary>
    /// <param name="srTable">Table to which to add the row</param>
    /// <returns>true if displayed, false otherwise</returns>
    private bool DisplayCollabProjectRestrictions(HTMLTable srTable)
    {
      int[] projectIDs = _model.GetCollabProjectRestrictions();
      // Display project restrictions
      if ((projectIDs != null) && (projectIDs.Length > 0))
      {
        XPArrayList projects = new XPArrayList();
        for (int j = 0;j < projectIDs.Length;j++)
        {
          //!!! How can we lookup a project name given its ID?
          projects.Add(XPConvert.ToString(projectIDs[j]));
        }
        DisplayRestrictionsLine(srTable, projects, 1829);
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Display portlet restrictions
    /// </summary>
    /// <param name="srTable">Table to which to add the row of restrictions</param>
    /// <returns>true if displayed, false otherwise</returns>
    private bool DisplayPortletRestrictions(HTMLTable srTable)
    {
      int[] portletIDs = _model.GetPortletRestrictions();
      // Display portlet restrictions
      if ((portletIDs != null) && (portletIDs.Length > 0))
      {
        XPArrayList portlets = new XPArrayList();
        for (int j = 0;j < portletIDs.Length;j++)
        {
          portlets.Add(_model.GetPortletNameForID(portletIDs[j]));
        }
        DisplayRestrictionsLine(srTable, portlets, 1667);
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Display admin and KD folder restrictions in a row
    /// </summary>
    /// <param name="srTable">Table to which to add row</param>
    /// <returns>true if admin folders are displayed, false otherwise</returns>
    private bool DisplayAdminAndDocFolderRestrictions(HTMLTable srTable)
    {
      int[] aFolderIDs = _model.GetAdminFolderRestrictions();
      int[] dFolderIDs = _model.GetDocFolderRestrictions();
      // Display folder restrictions
      if (((aFolderIDs != null) && (aFolderIDs.Length > 0)) || ((dFolderIDs != null) && (dFolderIDs.Length > 0)))
      {
        XPArrayList folders = new XPArrayList();
        if ((aFolderIDs != null) && (aFolderIDs.Length > 0))
        {
          for (int j = 0;j < aFolderIDs.Length;j++)
          {
            folders.Add(_model.GetFolderNameForID(aFolderIDs[j], true));
          }
        }
        if ((dFolderIDs != null) && (dFolderIDs.Length > 0))
        {
          for (int j = 0;j < dFolderIDs.Length;j++)
          {
            folders.Add(_model.GetFolderNameForID(dFolderIDs[j], false));
            }
        }
        if (folders.GetSize() > 0)
        {
          int idLineTitle;
          if (folders.GetSize() == 1)
          {
            if (_model.GetIncludeSubfolders())
            {
              idLineTitle = 857;
            } else
            {
              idLineTitle = 855;
            }
          } else
          {
            if (_model.GetIncludeSubfolders())
            {
              idLineTitle = 858;
            } else
            {
              idLineTitle = 856;
            }
          }
          DisplayRestrictionsLine(srTable, folders, idLineTitle);
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Display community restrictions if there are any
    /// </summary>
    /// <param name="srTable">Table to which to add the row</param>
    /// <returns>true if displayed, false otherwise</returns>
    private bool DisplayCommunityRestrictions(HTMLTable srTable)
    {
      // Assemble a list of communities to which this search was restricted
      int[] communityIDs = _model.GetCommunityRestrictions();
      // Display community restrictions
      if ((communityIDs != null) && (communityIDs.Length > 0))
      {
        XPArrayList communities = new XPArrayList();
        for (int j = 0;j < communityIDs.Length;j++)
        {
          communities.Add(_model.GetCommunityNameForID(communityIDs[j]));
          }
        int idLineTitle;
        if (communities.GetSize() == 1)
        {
          idLineTitle = 853;
        } else
        {
          idLineTitle = 854;
        }
        DisplayRestrictionsLine(srTable, communities, idLineTitle);
        return true;
      }
      return false;
    }
    
    /// <summary>
    /// Displays type restrictions (not for basic banner search though)
    /// </summary>
    /// <param name="srTable">Table in which to add row of restrictions</param>
    /// <returns>true if displayed, false otherwise</returns>
    private bool DisplayTypeRestrictions(HTMLTable srTable)
    {
      if (!isBannerSearch())
      {
        XPArrayList types = SearchSummaryView.GetObjectTypeRestrictionsList(_model,
         m_asOwner);
        // now, if we've put anything on the list of types to show
        if (0 < types.GetSize())
        {
          int idLineTitle;
          if (types.GetSize() == 1)
          {
            idLineTitle = 851;
          } else
          {
            idLineTitle = 852;
          }
          DisplayRestrictionsLine(srTable, types, idLineTitle);
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Displays a row of search restrictions.
    /// </summary>
    /// <param name="srTable">Table to add the row</param>
    /// <param name="listToDisplay">The list of restriction strings to display</param>
    /// <param name="idLineTitle">id of the i18n string in ptmsgs_portalbrowsingmsgs to use as the title.</param>
    private void DisplayRestrictionsLine(HTMLTable srTable, XPArrayList listToDisplay,
     int idLineTitle)
    {
      // add a row labeled "Object Types"
      HTMLTableRow srRow = new HTMLTableRow();
      srRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      srTable.AddInnerHTMLElement(srRow);
      HTMLTableCell srCell = new HTMLTableCell();
      srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      srCell.AddInnerHTMLString(SPACE4);
      srRow.AddInnerHTMLElement(srCell);
      srCell = new HTMLTableCell();
      srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      srCell.SetNoWrap(true);
      srRow.AddInnerHTMLElement(srCell);
      srCell.AddInnerHTMLString(m_asOwner.GetString(idLineTitle, "ptmsgs_portalbrowsingmsgs"));
      if (is508())
      {
        srCell.AddInnerHTMLElement(MakeHiddenTextInSpan(".", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
        } else
      {
        srCell.AddInnerHTMLString("&nbsp;&nbsp;");
      }
      srCell = new HTMLTableCell();
      srCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
      srRow.AddInnerHTMLElement(srCell);
      srCell.SetWidth("100%");
      srCell.AddInnerHTMLString(concatStrings(listToDisplay, "<b>", "</b>"));
      if (is508())
      {
        srCell.AddInnerHTMLElement(MakeHiddenTextInSpan(".", PTStyleClass.D_HIDDEN_LTGRAY_TEXT));
        }
    }
    
    /// <summary>
    /// Display spelling corrections.
    /// </summary>
    /// <param name="cell">Cell to which to add corrections</param>
    /// <returns>true if corrections displayed, false otherwise</returns>
    private bool DisplaySpellCorrections(HTMLTableCell cell)
    {
      int totalItems = _model.GetTotalItems();
      // Display spelling correction message if there were corrections,
      // we haven't drilled down (since in that case we don't know which query was corrected), and
      // at least one item was returned.
      // The spell correct string will be shown even when Best Bets are present (fix for Bug 44187)
      if (_model.wasSpellCorrected() && (totalItems > 0) && (1 == _model.GetDrilldownDepth()))
      {
        // No results for "plummtree", but here are results for "plumtree" and "palmtree"
        // Assemble and uniquify the list of misspellings and corrections
        IXPList misspelledTokens = new XPArrayList(10);
        IXPList correctionsPerMisspelling = new XPArrayList(10);
        AssembleUniqueMisspellingsAndCorrections(_model, misspelledTokens,
         correctionsPerMisspelling);
        if (misspelledTokens.GetSize() > 0)
        {
          String searchString = XPHttpUtility.HtmlEncode(_model.GetSearchString());
          if (1 == misspelledTokens.GetSize())
          {
            String listOfCorrections = concatStrings((IXPList) correctionsPerMisspelling.GetElement(0),
             "<b>", "</b>");
            cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1399,
             "ptmsgs_portalbrowsingmsgs"), searchString, (String) misspelledTokens.GetElement(0),
             listOfCorrections));
          } else
          {
            // Multiple replacements: make an indented list
            cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1400,
             "ptmsgs_portalbrowsingmsgs"), searchString));
            for (int j = 0;j < misspelledTokens.GetSize();j++)
            {
              cell.AddInnerHTMLElement(new HTMLBr());
              String listOfCorrections = concatStrings((IXPList) correctionsPerMisspelling.GetElement(j),
               "<b>", "</b>");
              cell.AddInnerHTMLString(SPACE4);
              cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1401,
               "ptmsgs_portalbrowsingmsgs"), (String) misspelledTokens.GetElement(j),
               listOfCorrections));
            }
          }
          cell.AddInnerHTMLElement(new HTMLBr());
          cell.AddInnerHTMLElement(new HTMLBr());
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Assembles the list of spelling corrections given two empty lists.
    /// </summary>
    /// <param name="model">Search results model</param>
    /// <param name="misspelledTokens">List to which misspelled tokens are added</param>
    /// <param name="correctionsPerMisspelling">List to which corrections are added</param>
    public static void AssembleUniqueMisspellingsAndCorrections(ISearchResultModelRO model,
     IXPList misspelledTokens, IXPList correctionsPerMisspelling)
    {
      int numMisspellings = model.GetNumMisspelledTokens();
      for (int j = 0;j < numMisspellings;j++)
      {
        String misspelling = model.GetMisspelledToken(j);
        // Have we seen this misspelling already?
        bool seenM = false;
        for (int m = 0;m < misspelledTokens.GetSize();m++)
        {
          if (misspelling.Equals((String) misspelledTokens.GetElement(m)))
          {
            seenM = true;
            break;
          }
        }
        // If we haven't already seen it
        if (!seenM)
        {
          // How many corrections for this misspelling?
          int numCorrections = model.GetNumCorrections(j);
          IXPList corrections = new XPArrayList(numCorrections);
          for (int k = 0;k < numCorrections;k++)
          {
            // Did this correction actually match any documents?
            // If not, don't display it.
            if (0 < model.GetCorrectionFrequency(j, k))
            {
              String c = model.GetSpellingCorrection(j, k);
              // Have we seen this correction for this mispelling already?
              bool seenC = false;
              for (int m = 0;m < corrections.GetSize();m++)
              {
                if (c.Equals((String) corrections.GetElement(m)))
                {
                  seenC = true;
                  break;
                }
              }
              if (!seenC)
              {
                corrections.Add(c);
              }
            }
          }
          // end if this correction was actually used
          // end loop over corrections for this mispelling
          if (corrections.GetSize() > 0)
          {
            misspelledTokens.Add(misspelling);
            correctionsPerMisspelling.Add(corrections);
          }
        }
      }
    }
    // end if this misspelling is not a duplicate
    // end loop over misspellings
    
    /// <summary>
    /// Returns the list of current object type restrictions.
    /// </summary>
    /// <param name="model">Search Results model</param>
    /// <param name="asOwner">Current activity space</param>
    /// <returns>List of object types to show</returns>
    public static XPArrayList GetObjectTypeRestrictionsList(ISearchResultModelRO model,
     AActivitySpace asOwner)
    {
      XPArrayList types = new XPArrayList();
      int[] objectTypes = model.GetObjectTypeRestrictions();
      int apps = model.GetApplicationRestrictions();
      int absTypes = model.GetAbstractTypeRestrictions();
      // First, do we have detailed type information?
      if ((objectTypes != null) && (objectTypes.Length > 0))
      {
        if ((0 == apps) || (0 != (apps & PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL)))
        {
          for (int j = 0;j < objectTypes.Length;j++)
          {
            types.Add(SearchResultModel.getDisplayableNameForType(asOwner,
             objectTypes[j]));
          }
        }
      } else
      {
        // Or, do we have broad "abstract" type information?
        if (0 != absTypes)
        {
          // show abstract type categories
          if (0 != (absTypes & PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_DOCUMENTS))
          {
            types.Add(asOwner.GetString(865, "ptmsgs_portalbrowsingmsgs"));
            }
          if (0 != (absTypes & PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_CONTAINERS))
          {
            types.Add(asOwner.GetString(866, "ptmsgs_portalbrowsingmsgs"));
            }
          if (0 != (absTypes & PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_OTHER))
          {
            types.Add(asOwner.GetString(867, "ptmsgs_portalbrowsingmsgs"));
            }
        }
      }
      // Only list applications if applications were explicitly specified or if we've
      // already started a list
      if ((0 != apps) || (types.GetSize() > 0))
      {
        // List "portal items" if it was explicitly specified AND
        // if no list of detailed object types appears (i.e. the only
        // thing on the list at this point is a bunch of abstract types)
        if ((0 != (apps & PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL)) && ((objectTypes == null) || (objectTypes.Length == 0)))
        {
          types.Add(asOwner.GetString(868, "ptmsgs_portalbrowsingmsgs"));
          }
        // if collab was explicitly searched
        if ((0 != (apps & PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB)) || ((0 < types.GetSize()) && (0 == apps)))
        // .. or if all apps are included and we've already started a list
        {
          types.Add(asOwner.GetString(869, "ptmsgs_portalbrowsingmsgs"));
          }
        // if content was explicitly searched
        if ((0 != (apps & PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT)) || ((0 < types.GetSize()) && (0 == apps)))
        // .. or if all apps are included and we've already started a list
        {
          types.Add(asOwner.GetString(870, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      return types;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    private bool isBannerSearch()
    {
      return (!(_model.isAdvancedSearch() || (null == _pageMode) || _pageMode.GetMakeEditLinks()));
      }
    
    /// <summary>
    /// Concatenates a list of strings into a comma-seperated list
    /// </summary>
    /// <param name="a">List of strings</param>
    /// <param name="pre">Text to display before the list</param>
    /// <param name="post">Text to display after the list</param>
    /// <returns>The concatenated string</returns>
    private String concatStrings(IXPList a, String pre, String post)
    {
      XPStringBuilder sb = new XPStringBuilder(50);
      if (null != pre)
      {
        sb.Append(pre);
      }
      for (int j = 0;j < a.GetSize();j++)
      {
        if (j > 0)
        {
          sb.Append(", ");
        }
        sb.Append(XPHttpUtility.HtmlEncode((String) a.GetElement(j)));
      }
      if (null != post)
      {
        sb.Append(post);
      }
      return sb.ToString();
    }
    
    /// <summary>
    /// Shows a summary of the number of results and how many are being displayed.
    /// </summary>
    /// <param name="owner">Current activity space</param>
    /// <param name="cell">Cell to which to add the summary text</param>
    /// <param name="model">Search results model.</param>
    public static void ShowNumberOfResults(AActivitySpace owner, HTMLTableCell cell,
     IBaseSearchResultModelRO model)
    {
      int totalItems = model.GetTotalItems();
      if (0 == totalItems)
      {
        // No results at all.
        cell.AddInnerHTMLString(owner.GetString(848, "ptmsgs_portalbrowsingmsgs"));
        } else
      if (1 == totalItems)
      {
        // One result from your search
        cell.AddInnerHTMLString(owner.GetString(847, "ptmsgs_portalbrowsingmsgs"));
        } else
      {
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        span.AddInnerHTMLString(XPConvert.ToString(totalItems));
        cell.AddInnerHTMLString(owner.GetString(846, "ptmsgs_portalbrowsingmsgs"));
        cell.AddInnerHTMLElement(span);
        cell.AddInnerHTMLString(".");
      }
      // Add a message like "Showing 1-10."
      if (model.GetNumDisplayableItems() < totalItems)
      {
        cell.AddInnerHTMLString(SPACE2);
        cell.AddInnerHTMLString(owner.GetString(875, "ptmsgs_portalbrowsingmsgs"));
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        span.AddInnerHTMLString(XPConvert.ToString(model.GetFirstDisplayableItem()));
        span.AddInnerHTMLString("-");
        span.AddInnerHTMLString(XPConvert.ToString((model.GetFirstDisplayableItem() + model.GetNumDisplayableItems()) - 1));
        cell.AddInnerHTMLElement(span);
        cell.AddInnerHTMLString(".");
      }
    }
    
    /// <summary>
    /// Helper method to show a "hidden" span (used to add text that will only display in 508 mode)
    /// </summary>
    /// <param name="text">"Hidden" text to add</param>
    /// <param name="style">Style of the text (mostly D_HIDDEN_LTGRAY_TEXT)</param>
    /// <returns>The span as an HTMLElement</returns>
    private static HTMLElement MakeHiddenTextInSpan(String text, PTStyleClass style)
    {
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(style);
      span.AddInnerHTMLString(text);
      return span;
    }
    
    /// <summary>
    /// Method to log the search result event.
    /// </summary>
    public virtual void LogSearchResultsEvent()
    {
      if (!(m_asOwner.GetModelExists(LoggingHelperModel.STR_MVC_CLASS_NAME)))
      {
        return;
      }
      LoggingHelperModel logHelper = (LoggingHelperModel) m_asOwner.GetModel(LoggingHelperModel.STR_MVC_CLASS_NAME);
      if (null == logHelper)
      {
        return;
      }
      // Note that the logHelper will not log any results unless the original
      // query was also logged earlier (via a call to LogStartSearchEvent).
      // This happens only for banner search.
      int nNumTotalMatches = _model.GetTotalItems();
      // start range
      int nResultStartRange = _model.GetFirstDisplayableItem();
      // end range
      int nResultEndRange = -1;
      if (nResultStartRange > 0)
      {
        nResultEndRange = _model.GetFirstDisplayableItem() + _model.GetNumDisplayableItems() - 1;
        }
      String currentKey = null;
      if (_model.GetDrilldownDepth() > 1)
      {
        currentKey = _model.GetCurrentKey();
      }
      logHelper.LogSearchResultsEvent(nNumTotalMatches, nResultStartRange,
       nResultEndRange, currentKey);
    }
  }
}