using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.search.exceptions;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.search.results
{
  /// <author>CraigS</author>
  public class SearchWithinResultsControl : SearchResultControl
  {
    public const String STR_MVC_CLASS_NAME = "swr";
    public const String ADDITIONAL_QUERY_DATA = "in_tx_addquery";
    public const String WITHIN_RESULTS_DATA_SE = "in_se_withinresults";
    public const String WITHIN_RESULTS_DATA_HI = "in_hi_withinresults";
    public const String WITHIN_RESULTS_VALUE = "2";
    public const String SAME_RESTRICTIONS_VALUE = "1";
    public const String ENTIRE_PORTAL_VALUE = "0";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SearchWithinResultsControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.search.SearchResultControl#ExecuteSearchControl()"></seealso>
    protected override Redirect ExecuteSearchControl(XPHashtable args, String key)
    {
      String additionalQuery = null;
      String[] values = (String[]) args.GetElement(ADDITIONAL_QUERY_DATA);
      if (null != values)
      {
        additionalQuery = values[0];
      }
      // Get "within results" (vs. "entire portal" or "same restriction") value
      values = (String[]) args.GetElement(WITHIN_RESULTS_DATA_SE);
      if (null == values)
      {
        values = (String[]) args.GetElement(WITHIN_RESULTS_DATA_HI);
      }
      String withinResultsValue = null;
      if (null != values)
      {
        withinResultsValue = values[0];
      } else
      {
        // assume "entire portal" if no value
        withinResultsValue = ENTIRE_PORTAL_VALUE;
      }
      // May have entered from "Edit Mode" so we want the followon search to be edit mode as well.
      String[] pageModeVals = (String[]) args.GetElement(SearchResultModel.MODEL_MODE_INPUT);
      String pageMode = null;
      if (pageModeVals != null && pageModeVals.Length == 1)
      {
        pageMode = pageModeVals[0];
      }
      // Special case: If our model is uninitialized, that means the original model was
      // flushed from the ActivitySpace cache, and this new one was auto-generated
      // to replace it (or someone just made up a bogus URL).  If our mode is
      // "Same Restrictions" or "Within Results", then there's no way to know
      // what the original search restrictions were.  In this case we just have
      // to generate an error and ask the user to restart the search from scratch.
      if ((!(((ISearchResultModelRO) _model).IsInitialized())) && (withinResultsValue.Equals(SAME_RESTRICTIONS_VALUE) || withinResultsValue.Equals(WITHIN_RESULTS_VALUE)))
      {
        throw new CacheFlushedException(_parent);
      }
      // If this is an "entire portal" url, then
      // just redirect the user to a brand new search space.
      if (withinResultsValue.Equals(ENTIRE_PORTAL_VALUE))
      {
        Redirect r = new Redirect();
        r.SetIsHTTPRedirect(true);
        r.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, _parent);
        r.AddControlArgument(SearchResultControl.USER_QUERY, additionalQuery);
        // Run a new banner search
        r.SetControl(BannerStartSearchControl.STR_MVC_CLASS_NAME);
        // Keep ourselves in edit or admin mode, if we were
        if (null != pageMode)
        {
          r.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, pageMode);
          }
        return r;
      }
      // End "entire portal" case
      // Next case: "same restrictions" search
      if (withinResultsValue.Equals(SAME_RESTRICTIONS_VALUE))
      {
        ISearchResultModelRO modelRO = (ISearchResultModelRO) _model;
        // Redirect to a *new* space; we want this space to remain cached
        // in case the user backs up into this search again.
        Redirect r = new Redirect();
        r.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, _parent);
        r.SetControl(StartSearchControl.STR_MVC_CLASS_NAME);
        // Make this a genuine 302 redirect so the user can bookmark the new search.
        r.SetIsHTTPRedirect(true);
        /* includeOptionalSettings= */
        XPHashtable newArgs = modelRO.GetSearchAgainArgs(true);
        r.AddControlArguments(newArgs);
        r.AddControlArgument(USER_QUERY, additionalQuery);
        if (null == pageMode)
        {
          // If not in admin search, log the new query in the search server logs
          r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_INITIALSEARCHSTRING_S,
           additionalQuery);
        } else
        {
          // otherwise, just pass the same mode on to the new search
          r.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, pageMode);
          }
        // Do the redirect
        return r;
      }
      // If we get here, must be a true "within results" search
      // Call the model to run the new search and update itself
      _model.SearchWithinResults(key, additionalQuery);
      // Don't need to redirect to a different page or space; just
      // redisplay the page
      return null;
    }
    
    /// <summary>
    /// Overrides superclass method - indicates that we can still
    /// possibly run even if the owning ActivitySpace has been flushed
    /// from the cache.
    /// Since this method returns false,
    /// ExecuteSearchControl has to be able to handle the case where
    /// _model.IsInitialized() returns false.
    /// </summary>
    protected sealed override bool expectModelInitialized()
    {
      return false;
    }
  }
}