using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.browsing.sessionprefs
{
  /// <author>SudhaS</author>
  public class SessionPrefsModel : ISessionPrefsModel,ISessionPrefsModelRO
  {
    public const String STR_MVC_CLASS_NAME = "SessionPrefs";
    private const String strPrefNamePrefix = "_";
    private const int iPrefixLength = 1;
    private const String strTrue = "true";
    private const String strFalse = "false";
    private const String strTextHTML = "text/html;charset=UTF-8";
    private const String strTextXML = "text/xml;charset=UTF-8";
    private AActivitySpace m_asOwner;
    private IPTSession m_ptSession;
    private String m_strDisplayString;
    private String m_strContentType;
    private const String strReturnXML = "<?xml version=\"1.0\"?><preferences>{0}</preferences>";
    private const String strXMLPref = "<field><name><![CDATA[{0}]]></name><value><![CDATA[{1}]]></value></field>";
    private const String strLeftBracket = "{";
    private const String strRightBracket = "}";
    private const int iBracketLength = 4;
    private const String strEmptyString = "";
    public SessionPrefsModel()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SessionPrefsModel();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IModel#Init(AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace _asOwner)
    {
      m_asOwner = _asOwner;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      m_strDisplayString = strFalse;
      m_strContentType = strTextHTML;
    }
    public virtual void SetSessionPrefs(XPHashtable preferences)
    {
      IXPDictionaryEnumerator prefs = preferences.GetEnumerator();
      bool bSetPref = false;
      //need to move all the preferences into a 2D array
      String[][] arrPrefs = new String[preferences.GetSize()][];
      for (int j2c_index = 0;j2c_index < preferences.GetSize();j2c_index++)
      {
        arrPrefs[j2c_index] = new String[2];
      }
      int i = 0;
      while (prefs.MoveNext())
      {
        IXPDictionaryEntry preference = prefs.GetCurrentDictionaryEntry();
        String strPrefName = (String) preference.GetKey();
        //All real session prefs will begin with a special token (underscore)
        //this is so that they won't be confused with regular parameters (space, control, etc.).
        if (null != strPrefName && XPStringUtility.StartsWith(strPrefName,
         strPrefNamePrefix))
        {
          // get the value
          String[] strPrefValue = (String[]) preference.GetValue();
          // take off the underscore
          strPrefName = XPStringUtility.Substring(strPrefName, iPrefixLength);
          //store the name and the value in the array
          arrPrefs[i][0] = strPrefName;
          arrPrefs[i][1] = strPrefValue[0];
          bSetPref = true;
          i++;
        }
      }
      if (bSetPref)
      {
        bool bSetPrefs = m_ptSession.GetSessionInfo().AddSessionPreferences(arrPrefs,
         true);
        // set the result
        if (bSetPrefs)
        {
          m_strDisplayString = strTrue;
        }
      }
    }
    public virtual String GetDisplayString()
    {
      return m_strDisplayString;
    }
    public virtual String GetContentType()
    {
      return m_strContentType;
    }
    public virtual void GetSessionPrefs(XPHashtable preferences)
    {
      IXPDictionaryEnumerator prefs = preferences.GetEnumerator();
      //Guesstimate the length of session pref names array to be the size of hashtable.
      String[] arrSessionPrefNames = new String[preferences.GetSize()];
      int i = 0;
      //Get all session pref names into an array.
      while (prefs.MoveNext())
      {
        IXPDictionaryEntry preference = prefs.GetCurrentDictionaryEntry();
        String strPrefName = (String) preference.GetKey();
        //All real session prefs will begin with a special token (underscore)
        //this is so that they won't be confused with regular parameters (space, control, etc.).
        if (XPStringUtility.StartsWith(strPrefName, strPrefNamePrefix))
        {
          arrSessionPrefNames[i] = XPStringUtility.Substring(strPrefName,
           iPrefixLength);
          i++;
        }
      }
      //Get pref values.
      String[][] arrPrefValues;
      if (i > 0)
      {
        arrPrefValues = m_ptSession.GetSessionInfo().LookupSessionPreferences(arrSessionPrefNames,
         true);
        //Now, let's generate the XML.
        //this array will hold the field name-value pair strings.
        String[] arrPrefElements = new String[i];
        //this string will consist of {0}{1}{2} etc.. for the number of fields there are.
        XPStringBuilder strPrefElementsFormatString = new XPStringBuilder(i * iBracketLength);
        //this array will hold name and value for formatting each field.
        String[] arrPrefNameValue = new String[2];
        for (int j = 0;j < i;j++)
        {
          // Get the pref name and value
          arrPrefNameValue[0] = arrPrefValues[0][j];
          arrPrefNameValue[1] = arrPrefValues[1][j];
          //if the pref value is null, we want to replace it with an empty string.
          if (arrPrefNameValue[1] == null)
          {
            arrPrefNameValue[1] = strEmptyString;
          }
          // generate the <field> ... </field> XML string
          arrPrefElements[j] = XPFormat.Format(strXMLPref, arrPrefNameValue);
          // add to the big format string
          strPrefElementsFormatString.Append(strLeftBracket);
          strPrefElementsFormatString.Append(XPConvert.ToString(j));
          strPrefElementsFormatString.Append(strRightBracket);
        }
        //Now let's chunk together all the field values
        String[] arrAllFields = new String[1];
        arrAllFields[0] = XPFormat.Format(strPrefElementsFormatString.ToString(),
         arrPrefElements);
        //and put it into the final xml string.
        m_strDisplayString = XPFormat.Format(strReturnXML, arrAllFields);
        m_strContentType = strTextXML;
      }
    }
  }
}