using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.sitemap.editweblink
{
  /// <summary>
  /// File: EditWebLinkModel.java
  /// ---------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class EditWebLinkModel : IRepostModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.editweblink.EditWebLinkModel");
    
    /// <summary>
    /// Activity space name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditWebLink";
    
    /// <summary>
    /// Store session and catalog to retrieve data 
    /// </summary>
    protected IPTSession m_ptSession;
    
    /// <summary>
    /// Logger 
    /// </summary>
    private AActivitySpace m_asOwner = null;
    
    /// <summary>
    /// Link ID 
    /// </summary>
    private IPTSiteMapLink m_objSiteMapLink = null;
    
    /// <summary>
    /// Link Description 
    /// </summary>
    private String m_strLinkDesc = "";
    
    /// <summary>
    /// Link Name 
    /// </summary>
    private String m_strLinkName = "";
    
    /// <summary>
    /// Link URL 
    /// </summary>
    private String m_strLinkURL = "";
    
    /// <summary>
    /// Folder ID 
    /// </summary>
    private int m_nFolderID = -1;
    
    /// <summary>
    /// Link ID 
    /// </summary>
    private int m_nLinkID = -1;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new EditWebLinkModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public virtual void Finish()
    {
      if (null != m_objSiteMapLink)
      {
        m_objSiteMapLink.SetName(m_strLinkName);
        m_objSiteMapLink.SetDescription(m_strLinkDesc);
        m_objSiteMapLink.SetLinkURL(m_strLinkURL);
        m_objSiteMapLink.Store();
      }
      m_objSiteMapLink = null;
      m_strLinkName = null;
      m_strLinkDesc = null;
      m_strLinkURL = null;
      m_nFolderID = -1;
      m_nLinkID = -1;
    }
    ////////////////////////
    /// IModel         /////
    ////////////////////////
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns>String</returns>
    public virtual String GetOriginalDescription()
    {
      return m_objSiteMapLink.GetDescription();
    }
    
    /// <returns>String</returns>
    public virtual String GetOriginalName()
    {
      return m_objSiteMapLink.GetName();
    }
    
    /// <returns>String</returns>
    public virtual String GetOriginalURL()
    {
      return m_objSiteMapLink.GetLinkURL();
    }
    
    /// <summary>
    /// Returns the Redirect object
    /// (this is were we need to go at the end of the Editor).
    /// </summary>
    /// <returns>Redirect</returns>
    public virtual Redirect GetRedirectAfterFinish()
    {
      ClosePopUpDP closeDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      try
      {
        script.AddInnerHTMLString(
        //location.reload(true);");
        "window.opener.postToSelf(" + RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");");
        }
      //DCA - changed to get rid of page refresh warning
      catch (HTMLException he)
      {
        log.Error(he, he.Message);
      }
      closeDP.SetScript(script);
      Redirect redirectClose = new Redirect();
      redirectClose.SetLinkGetCachedSpace(m_asOwner);
      redirectClose.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
      return redirectClose;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModel#Init()"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      String[] sValues = (String[]) _htFormData.GetElement(EditWebLinkView.HTMLINPUT_LINKNAME);
      if (sValues == null)
      {
        log.Info("could not find link name in query string.");
        m_strLinkName = "";
        return RepostControl.PAGE_STATUS_INVALID;
      } else
      {
        m_strLinkName = sValues[0];
      }
      sValues = (String[]) _htFormData.GetElement(EditWebLinkView.HTMLINPUT_LINKDESC);
      if (sValues == null)
      {
        log.Info("could not find link desc in query string.");
        m_strLinkDesc = "";
        return RepostControl.PAGE_STATUS_INVALID;
      } else
      {
        m_strLinkDesc = sValues[0];
      }
      sValues = (String[]) _htFormData.GetElement(EditWebLinkView.HTMLINPUT_LINKURL);
      if (sValues == null)
      {
        log.Info("could not find link url in query string.");
        m_strLinkURL = "";
        return RepostControl.PAGE_STATUS_INVALID;
      } else
      {
        m_strLinkURL = sValues[0];
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="nLinkID"></param>
    /// <param name="nFolderID"></param>
    /// <throws>Exception</throws>
    public virtual void SetLinkAndFolderIDs(int nLinkID, int nFolderID)
    {
      m_nLinkID = nLinkID;
      m_nFolderID = nFolderID;
      if ((m_nFolderID != -1) && (m_nLinkID != -1))
      {
        IPTObjectManager objMan = m_ptSession.GetSiteMapFolders();
        if (objMan.IsObjectAccessible(m_nFolderID, m_ptSession.GetSessionInfo().GetCurrentUserID(),
         PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT))
        {
          try
          {
            IPTSiteMapFolder objFolder = (IPTSiteMapFolder) objMan.Open(m_nFolderID,
             false);
            m_objSiteMapLink = objFolder.OpenLink(m_nLinkID);
          }
          catch (Exception e)
          {
            log.Error(e, "Could not open Community Knowledge Directory Folder or Link:" + e.Message);
            throw new XPException("Could not open Community Knowledge Directory Folder or Link:" + e);
            }
        } else
        {
          //pkd extracted: 				throw new Exception(_ui_AccessError);
          throw new XPException(m_asOwner.GetString(877, "ptmsgs_portalbrowsingmsgs"));
          }
      }
    }
  }
}