using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.browsing.sitemap.editweblink
{
  /// <summary>
  /// File: SetLinkControl.java
  /// -------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SetLinkControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.editweblink.SetLinkControl");
    public const String STR_MVC_CLASS_NAME = "SetLink";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_LinkID = "LinkID";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_FolderID = "FolderID";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private EditWebLinkModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String[] sValues = (String[]) arguments.GetElement(m_LinkID);
      int nLinkID = -1;
      if (sValues == null)
      {
        log.Info("could not find link ID in query string.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, "Invalid Link ID", "Invalid Link ID");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        } else
      {
        nLinkID = XPConvert.ToInteger(sValues[0]);
      }
      sValues = (String[]) arguments.GetElement(m_FolderID);
      int nFolderID = -1;
      if (sValues == null)
      {
        log.Info("could not find folder ID in query string.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, "Invalid Folder ID", "Invalid Folder ID");
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        } else
      {
        nFolderID = XPConvert.ToInteger(sValues[0]);
      }
      try
      {
        m_asModel.SetLinkAndFolderIDs(nLinkID, nFolderID);
      }
      catch (Exception e)
      {
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SetLinkControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (EditWebLinkModel) model;
      m_asOwner = space;
    }
  }
}