using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.browsing.sitemap.linkselector
{
  /// <summary>
  /// File: SiteMapLinkContainer.java
  /// -------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SiteMapLinkContainer
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.linkselector.SiteMapLinkContainer");
    
    /// <summary>
    /// Activity space name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapLinkContainer";
    public const int KEEP = 0;
    public const int DELETE = 1;
    public const int ADD = 2;
    public const int UPDATE = 3;
    public const int SORT_COLUMN = 0;
    public const int LINK_COLUMN = 1;
    private XPHashtable m_tableWebLinks;
    private XPHashtable m_tableCommPages;
    private XPHashtable m_tableDocs;
    private XPHashtable m_tableFolders;
    private XPHashtable m_tableUsers;
    private XPArrayList m_arrNewlyAddedLinks;
    private XPArrayList m_arrUpdatedWebLinks;
    private XPArrayList m_arrDeletedLinks;
    
    /// <param name="qrLinks"></param>
    public SiteMapLinkContainer(IPTQueryResult qrLinks)
    {
      m_tableUsers = new XPHashtable();
      m_tableDocs = new XPHashtable();
      m_tableFolders = new XPHashtable();
      m_tableCommPages = new XPHashtable();
      m_tableWebLinks = new XPHashtable();
      m_arrNewlyAddedLinks = new XPArrayList();
      m_arrUpdatedWebLinks = new XPArrayList();
      m_arrDeletedLinks = new XPArrayList();
      if (null != qrLinks)
      {
        PTLink link;
        for (int i = 0;i < qrLinks.RowCount();i++)
        {
          link = new PTLink();
          link.nType = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID);
          link.nState = KEEP;
          link.nObjectID = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
          link.strName = qrLinks.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
          link.strDesc = qrLinks.ItemAsString(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
          switch (link.nType){
          case PT_CLASSIDS.PT_PAGE_ID:
          link.nPageID = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);
          link.nLinkObjectID = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKPAGEID);
          link.nType = PT_CLASSIDS.PT_COMMUNITY_ID;
          m_tableCommPages.PutElement(link.nPageID, link);
          break;
          case PT_CLASSIDS.PT_USER_ID:
          link.nLinkObjectID = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);
          m_tableUsers.PutElement(link.nLinkObjectID, link);
          break;
          case PT_CLASSIDS.PT_CATALOGCARD_ID:
          link.nLinkObjectID = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);
          m_tableDocs.PutElement(link.nLinkObjectID, link);
          break;
          case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
          link.nLinkObjectID = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);
          m_tableFolders.PutElement(link.nLinkObjectID, link);
          break;
          case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
          link.strWebURL = qrLinks.ItemAsString(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKURL);
          m_tableWebLinks.PutElement(link.nObjectID, link);
          break;
          default:
          log.Error("Invalid Link Type");
          break;
          }
        }
      }
    }
    public virtual void DebugPrintSizes()
    {
      log.Info("CommPage Size: " + m_tableCommPages.GetSize());
      log.Info("User Size: " + m_tableUsers.GetSize());
      log.Info("Doc Size: " + m_tableDocs.GetSize());
      log.Info("Folder Size: " + m_tableFolders.GetSize());
      log.Info("WebLink Size: " + m_tableWebLinks.GetSize());
    }
    
    /// <returns>String[]</returns>
    public virtual String[] GetCommPageNames()
    {
      return GetNamesFromTable(m_tableCommPages);
    }
    
    /// <returns>String[]</returns>
    public virtual String[] GetDocNames()
    {
      return GetNamesFromTable(m_tableDocs);
    }
    
    /// <returns>String[]</returns>
    public virtual String[] GetFolderNames()
    {
      return GetNamesFromTable(m_tableFolders);
    }
    
    /// <summary>
    /// The comm page tree is a server tree, so we need to delimit
    /// each location with semi-colons (';')
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSelectedCommPagesAsStringForTree()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableCommPages.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
          sb.Append(link.nPageID);
          sb.Append(",");
          if (null != link.strName)
          {
            // DCA - distinguish from delimiters
            sb.Append(GeneralHelpers.Replace(link.strName, ";", ";;"));
          }
          sb.Append(";");
        }
      }
      if (sb.GetLength() == 0)
      {
        return "";
      } else
      {
        return sb.Substring(0, sb.GetLength() - 1);
      }
    }
    
    /// <returns>String</returns>
    public virtual String GetSelectedCommPagesAsString()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableCommPages.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(link.nPageID);
          sb.Append(",");
        }
      }
      sb.Append("0");
      // append 0 because the JS function new Array() with one arg  will be interpreted as size as size
      return sb.ToString();
    }
    
    /// <returns>String</returns>
    public virtual String GetSelectedDirItemsAsStringForTree()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableDocs.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(PT_CLASSIDS.PT_CATALOGCARD_ID);
          sb.Append(",");
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
        }
      }
      elements = m_tableFolders.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(PT_CLASSIDS.PT_CATALOGFOLDER_ID);
          sb.Append(",");
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
        }
      }
      if (sb.GetLength() == 0)
      {
        return "";
      } else
      {
        return sb.Substring(0, sb.GetLength() - 1);
      }
    }
    
    /// <returns>String</returns>
    public virtual String GetSelectedDocsAsString()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableDocs.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
        }
      }
      sb.Append("0");
      // append 0 because the JS function new Array() with one arg  will be interpreted as size as size
      return sb.ToString();
    }
    
    /// <returns>String</returns>
    public virtual String GetSelectedFoldersAsString()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableFolders.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
        }
      }
      sb.Append("0");
      // append 0 because the JS function new Array() with one arg  will be interpreted as size as size
      return sb.ToString();
    }
    
    /// <returns>String</returns>
    public virtual String GetSelectedUsersAsStringForTree()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableUsers.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(PT_CLASSIDS.PT_USER_ID);
          sb.Append(",");
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
        }
      }
      if (sb.GetLength() == 0)
      {
        return "";
      } else
      {
        return sb.Substring(0, sb.GetLength() - 1);
      }
    }
    
    /// <returns>String</returns>
    public virtual String GetSelectedUsersAsString()
    {
      XPStringBuilder sb = new XPStringBuilder();
      PTLink link;
      IXPEnumerator elements = m_tableUsers.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          sb.Append(link.nLinkObjectID);
          sb.Append(",");
        }
      }
      sb.Append("0");
      // append 0 because the JS function new Array() with one arg  will be interpreted as size as size
      return sb.ToString();
    }
    
    /// <returns>String[]</returns>
    public virtual String[] GetUserNames()
    {
      return GetNamesFromTable(m_tableUsers);
    }
    
    /// <returns>String[][]</returns>
    public virtual String[][] GetWebLinks()
    {
      PTLink link;
      String[][] retArr = new String[m_tableWebLinks.GetSize()][];
      for (int j2c_index = 0;j2c_index < m_tableWebLinks.GetSize();j2c_index++)
      {
        retArr[j2c_index] = new String[4];
      }
      IXPEnumerator elements = m_tableWebLinks.GetElements();
      int nIndex = 0;
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          retArr[nIndex][0] = XPConvert.ToString(link.nObjectID);
          retArr[nIndex][1] = link.strName;
          retArr[nIndex][2] = link.strDesc;
          retArr[nIndex][3] = link.strWebURL;
          nIndex++;
        }
      }
      return retArr;
    }
    public virtual XPArrayList GetNewlyAddedLinks()
    {
      return m_arrNewlyAddedLinks;
    }
    public virtual void ClearNewlyAddedLinks()
    {
      m_arrNewlyAddedLinks = null;
      m_arrNewlyAddedLinks = new XPArrayList();
    }
    public virtual XPArrayList GetUpdateWebLinks()
    {
      return m_arrUpdatedWebLinks;
    }
    public virtual void ClearUpdateWebLinks()
    {
      m_arrUpdatedWebLinks = null;
      m_arrUpdatedWebLinks = new XPArrayList();
    }
    public virtual XPArrayList GetDeletedLinks()
    {
      return m_arrDeletedLinks;
    }
    public virtual void ClearDeletedLinks()
    {
      m_arrDeletedLinks = null;
      m_arrDeletedLinks = new XPArrayList();
    }
    public virtual void ProcessCommPageData(XPArrayList arrCommItemList, AActivitySpace asOwner)
    {
      PTLink link;
      int intPageID;
      int nCommunityID;
      for (int i = 0;i < arrCommItemList.GetSize();i++)
      {
        TreeLeafNode item = (TreeLeafNode) arrCommItemList.GetElement(i);
        if (item == null)
        {
        }
        //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));
        XPStringTokenizer myTokenizer = new XPStringTokenizer(item.m_strLocation,
         ",");
        //Now get the first two tokens, which we are going to use
        nCommunityID = XPConvert.ToInteger(myTokenizer.GetNextToken());
        intPageID = XPConvert.ToInteger(myTokenizer.GetNextToken());
        //Last token maybe community name, but we will not be using it at all since location 
        //consists CommunityID and PageID only, so commenting parsing next token.
        //String strCommName = myTokenizer.GetNextToken();
        IPTSession ptSession = (IPTSession) asOwner.GetUserSession();
        // We don't have this, try to add
        if (!m_tableCommPages.ContainsKey(intPageID))
        {
          // Check if we have SELECT access to this community first
          IPTCommunityInfo ptCommInfo = ((IPTCommunityManager) ptSession.GetCommunities().GetInterfaces("IPTCommunityManager")).CachedOpenCommunityInfo(nCommunityID,
           false);
          if (!(ptCommInfo.GetAccessLevel() >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
          {
            String errorMsg = XPResourceManager.FormatMessage(asOwner.GetString(1723,
             "ptmsgs_portalbrowsingmsgs"), nCommunityID);
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             null, errorMsg, errorMsg);
            UIErrorHandler.RaiseError(myError, asOwner.GetSubSession(), asOwner.GetApplication());
            } else
          {
            link = new PTLink();
            link.nState = ADD;
            link.nType = PT_CLASSIDS.PT_COMMUNITY_ID;
            link.nLinkObjectID = nCommunityID;
            link.nPageID = intPageID;
            if (null != ptCommInfo.GetName())
            {
              link.strName = ptCommInfo.GetName();
            }
            link.strPageName = item.GetName();
            m_tableCommPages.PutElement(intPageID, link);
            m_arrNewlyAddedLinks.Add(link);
          }
        } else
        {
          link = (PTLink) m_tableCommPages.GetElement(intPageID);
          if (link.nState == DELETE)
          {
            link.nState = KEEP;
            m_arrNewlyAddedLinks.Add(link);
          }
        }
      }
      XPArrayList keysToDelete = new XPArrayList();
      IXPEnumerator elements = m_tableCommPages.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        intPageID = link.nPageID;
        nCommunityID = link.nLinkObjectID;
        bool bIsSelected = false;
        for (int i = 0;i < arrCommItemList.GetSize();i++)
        {
          TreeLeafNode item = (TreeLeafNode) arrCommItemList.GetElement(i);
          if (item == null)
          {
          }
          //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));				
          XPStringTokenizer myTokenizer = new XPStringTokenizer(item.m_strLocation,
           ",");
          //Now get the first two tokens, which we are going to use
          int nTreeCommunityID = XPConvert.ToInteger(myTokenizer.GetNextToken());
          int intTreePageID = XPConvert.ToInteger(myTokenizer.GetNextToken());
          if (nCommunityID == nTreeCommunityID && intPageID == intTreePageID)
          {
            bIsSelected = true;
            break;
          }
        }
        if (!bIsSelected)
        {
          if (link.nState == ADD)
          {
            keysToDelete.Add(intPageID);
          } else
          if (link.nState == KEEP)
          {
            link.nState = DELETE;
          }
          m_arrDeletedLinks.Add(link);
        }
      }
      for (int i = 0;i < keysToDelete.GetSize();i++)
      {
        Object intKey = keysToDelete.GetElement(i);
        m_tableCommPages.RemoveElement(intKey);
      }
    }
    
    /// <param name="arrDocs"></param>
    public virtual void ProcessDirectoryData(XPArrayList arrDirItemList, AActivitySpace asOwner)
    {
      PTLink link;
      int intObjectID;
      int nClassID;
      for (int i = 0;i < arrDirItemList.GetSize();i++)
      {
        TreeLeafNode item = (TreeLeafNode) arrDirItemList.GetElement(i);
        if (item == null)
        {
        }
        //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));				
        nClassID = item.m_nClassID;
        intObjectID = item.m_nObjectID;
        XPHashtable tableObjects = null;
        if (nClassID == PT_CLASSIDS.PT_CATALOGCARD_ID)
        {
          tableObjects = m_tableDocs;
        } else
        if (nClassID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
        {
          tableObjects = m_tableFolders;
        }
        IPTSession ptSession = (IPTSession) asOwner.GetUserSession();
        if (!tableObjects.ContainsKey(intObjectID))
        {
          // Check for at least SELECT access to the document
          //if (!ptSession.GetCatalog().IsCatalogObjectAccessible(nClassID, intObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
          // SE: Bug 40725 - for Amgen and Enbridge Amgen SR#1-250508001 and Enbridge SR # 1-251946292
          // Allow users with READ access to a document or folder to be able to add a link to the community links portlet
          if (!ptSession.GetCatalog().IsCatalogObjectAccessible(nClassID,
           intObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
          {
            String errorMsg = XPResourceManager.FormatMessage(asOwner.GetString(1724,
             "ptmsgs_portalbrowsingmsgs"), item.GetName());
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             null, errorMsg, errorMsg);
            UIErrorHandler.RaiseError(myError, asOwner.GetSubSession(), asOwner.GetApplication());
            } else
          {
            link = new PTLink();
            link.nState = ADD;
            link.nType = nClassID;
            link.nLinkObjectID = intObjectID;
            link.strName = item.GetName();
            tableObjects.PutElement(intObjectID, link);
            m_arrNewlyAddedLinks.Add(link);
          }
        } else
        {
          link = (PTLink) tableObjects.GetElement(intObjectID);
          if (link.nState == DELETE)
          {
            link.nState = KEEP;
            m_arrNewlyAddedLinks.Add(link);
          }
        }
      }
      XPArrayList keysToDelete = new XPArrayList();
      IXPEnumerator elements = m_tableDocs.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        intObjectID = link.nLinkObjectID;
        nClassID = link.nType;
        bool bIsSelected = false;
        for (int i = 0;i < arrDirItemList.GetSize();i++)
        {
          TreeLeafNode item = (TreeLeafNode) arrDirItemList.GetElement(i);
          if (item == null)
          {
          }
          //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));				
          int nTreeClassID = item.m_nClassID;
          int intTreeObjectID = item.m_nObjectID;
          if (nTreeClassID == PT_CLASSIDS.PT_CATALOGCARD_ID && nClassID == nTreeClassID && intObjectID == intTreeObjectID)
          {
            bIsSelected = true;
            break;
          }
        }
        if (!bIsSelected)
        {
          if (link.nState == ADD)
          {
            keysToDelete.Add(intObjectID);
          } else
          if (link.nState == KEEP)
          {
            link.nState = DELETE;
          }
          m_arrDeletedLinks.Add(link);
        }
      }
      for (int i = 0;i < keysToDelete.GetSize();i++)
      {
        Object intKey = keysToDelete.GetElement(i);
        m_tableDocs.RemoveElement(intKey);
      }
      keysToDelete = new XPArrayList();
      elements = m_tableFolders.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        intObjectID = link.nLinkObjectID;
        nClassID = link.nType;
        bool bIsSelected = false;
        for (int i = 0;i < arrDirItemList.GetSize();i++)
        {
          TreeLeafNode item = (TreeLeafNode) arrDirItemList.GetElement(i);
          if (item == null)
          {
          }
          //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));				
          int nTreeClassID = item.m_nClassID;
          int intTreeObjectID = item.m_nObjectID;
          if (nTreeClassID == PT_CLASSIDS.PT_CATALOGFOLDER_ID && nClassID == nTreeClassID && intObjectID == intTreeObjectID)
          {
            bIsSelected = true;
            break;
          }
        }
        if (!bIsSelected)
        {
          if (link.nState == ADD)
          {
            keysToDelete.Add(intObjectID);
          } else
          if (link.nState == KEEP)
          {
            link.nState = DELETE;
          }
          m_arrDeletedLinks.Add(link);
        }
      }
      for (int i = 0;i < keysToDelete.GetSize();i++)
      {
        Object intKey = keysToDelete.GetElement(i);
        m_tableFolders.RemoveElement(intKey);
      }
    }
    public virtual void ProcessUserData(XPArrayList arrUserItems, AActivitySpace asOwner)
    {
      PTLink link;
      int intUserID;
      for (int i = 0;i < arrUserItems.GetSize();i++)
      {
        TreeLeafNode item = (TreeLeafNode) arrUserItems.GetElement(i);
        if (item == null)
        {
        }
        //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));				
        intUserID = item.m_nObjectID;
        if (!m_tableUsers.ContainsKey(intUserID))
        {
          // No security on users
          link = new PTLink();
          link.nState = ADD;
          link.nType = PT_CLASSIDS.PT_USER_ID;
          link.nLinkObjectID = intUserID;
          link.strName = item.GetName();
          m_tableUsers.PutElement(intUserID, link);
          m_arrNewlyAddedLinks.Add(link);
        } else
        {
          link = (PTLink) m_tableUsers.GetElement(intUserID);
          if (link.nState == DELETE)
          {
            link.nState = KEEP;
            m_arrNewlyAddedLinks.Add(link);
          }
        }
      }
      XPArrayList keysToDelete = new XPArrayList();
      IXPEnumerator elements = m_tableUsers.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        intUserID = link.nLinkObjectID;
        bool bIsSelected = false;
        for (int i = 0;i < arrUserItems.GetSize();i++)
        {
          TreeLeafNode item = (TreeLeafNode) arrUserItems.GetElement(i);
          if (item == null)
          {
          }
          //log.Error(m_asOwner.GetString(1494, "ptmsgs_portalbrowsingmsgs"));				
          int intTreeUserID = item.m_nObjectID;
          if (intUserID == intTreeUserID)
          {
            bIsSelected = true;
            break;
          }
        }
        if (!bIsSelected)
        {
          if (link.nState == ADD)
          {
            keysToDelete.Add(intUserID);
          } else
          if (link.nState == KEEP)
          {
            link.nState = DELETE;
          }
          m_arrDeletedLinks.Add(link);
        }
      }
      for (int i = 0;i < keysToDelete.GetSize();i++)
      {
        Object intKey = keysToDelete.GetElement(i);
        m_tableUsers.RemoveElement(intKey);
      }
    }
    
    /// <param name="strName"></param>
    /// <param name="strDesc"></param>
    /// <param name="strURL"></param>
    public virtual void ProcessWebLinkData(String strName, String strDesc,
     String strURL)
    {
      PTLink newLink = new PTLink();
      newLink.nType = PT_CLASSIDS.PT_SITEMAPWEBLINK_ID;
      newLink.nState = ADD;
      newLink.strName = strName;
      newLink.strDesc = strDesc;
      newLink.strWebURL = strURL;
      newLink.nObjectID = m_tableWebLinks.GetSize();
      m_tableWebLinks.PutElement(newLink.nObjectID, newLink);
      m_arrNewlyAddedLinks.Add(newLink);
    }
    public virtual void EditWebLink(int nUniqueID, String strName, String strDesc,
     String strURL)
    {
      PTLink link = (PTLink) m_tableWebLinks.GetElement(nUniqueID);
      link.strName = strName;
      link.strDesc = strDesc;
      link.strWebURL = strURL;
      if (link.nState == KEEP)
      {
        link.nState = UPDATE;
        m_arrUpdatedWebLinks.Add(link);
      }
    }
    public virtual void DeleteLink(int nType, int nUniqueID)
    {
      XPHashtable table = null;
      switch (nType){
      case PT_CLASSIDS.PT_COMMUNITY_ID:
      table = m_tableCommPages;
      break;
      case PT_CLASSIDS.PT_CATALOGCARD_ID:
      table = m_tableDocs;
      break;
      case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
      table = m_tableFolders;
      break;
      case PT_CLASSIDS.PT_USER_ID:
      table = m_tableUsers;
      break;
      case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
      table = m_tableWebLinks;
      break;
      default:
      break;
      }
      // shouldn't get here	
      if (table == null)
      {
        return;
      }
      PTLink link = (PTLink) table.GetElement(nUniqueID);
      if (link != null)
      {
        if (link.nState == ADD)
        {
          table.RemoveElement(nUniqueID);
        } else
        if (link.nState == KEEP || link.nState == UPDATE)
        {
          link.nState = DELETE;
        }
        m_arrDeletedLinks.Add(link);
      }
    }
    public virtual void DeleteWebLink(int nUniqueID)
    {
      PTLink link = (PTLink) m_tableWebLinks.GetElement(nUniqueID);
      if (link.nState == KEEP || link.nState == UPDATE)
      {
        link.nState = DELETE;
      } else
      if (link.nState == ADD)
      {
        m_tableWebLinks.RemoveElement(nUniqueID);
      }
      m_arrDeletedLinks.Add(link);
    }
    public virtual XPArrayList GetAllLinks()
    {
      PTLink link;
      XPArrayList retArr = new XPArrayList();
      IXPEnumerator elements = m_tableCommPages.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          retArr.Add(link);
        }
      }
      elements = m_tableUsers.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          retArr.Add(link);
        }
      }
      elements = m_tableDocs.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          retArr.Add(link);
        }
      }
      elements = m_tableFolders.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          retArr.Add(link);
        }
      }
      elements = m_tableWebLinks.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          retArr.Add(link);
        }
      }
      return retArr;
    }
    public virtual PTSortedArrayWrapper GetAllLinksAlphaSorted()
    {
      PTLink link;
      int[] arrColIDs = new int[]{SORT_COLUMN, LINK_COLUMN};
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = SORT_COLUMN;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      XPArrayList arLinks = GetAllLinks();
      Object[][] arrLinks = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrLinks[j2c_index] = new Object[arLinks.GetSize()];
      }
      for (int j = 0;j < arLinks.GetSize();j++)
      {
        arrLinks[SORT_COLUMN][j] = ((PTLink) arLinks.GetElement(j)).strName;
        arrLinks[LINK_COLUMN][j] = arLinks.GetElement(j);
      }
      PTSortedArrayWrapper arrSortedLinks = new PTSortedArrayWrapper();
      arrSortedLinks.Initialize(arrColIDs, arrLinks, arrSort, true);
      return arrSortedLinks;
    }
    
    /// <param name="objFolder"></param>
    public virtual void StoreAll(IPTSiteMapFolder objFolder)
    {
      StoreUsers(objFolder);
      StoreDocs(objFolder);
      StoreFolders(objFolder);
      StoreCommPages(objFolder);
      StoreWebLinks(objFolder);
    }
    public virtual void StoreUsers(IPTSiteMapFolder objFolder)
    {
      PTLink link;
      IPTSiteMapLink ptNewLink;
      IXPEnumerator elements = m_tableUsers.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState == ADD)
        {
          ptNewLink = objFolder.CreateLink();
          ptNewLink.SetLinkClassID(PT_CLASSIDS.PT_USER_ID);
          ptNewLink.SetLinkObjectID(link.nLinkObjectID);
          try
          {
            ptNewLink.Store();
            link.nObjectID = ptNewLink.GetObjectID();
          }
          catch (Exception e)
          {
            throw new XPException("Unable to Store Use link: " + e);
          }
        } else
        if (link.nState == DELETE)
        {
          objFolder.DeleteLink(link.nObjectID);
        } else
        {
        }
      }
    }
    // Do nothing
    public virtual void StoreDocs(IPTSiteMapFolder objFolder)
    {
      PTLink link;
      IPTSiteMapLink ptNewLink;
      IXPEnumerator elements = m_tableDocs.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState == ADD)
        {
          ptNewLink = objFolder.CreateLink();
          ptNewLink.SetLinkClassID(PT_CLASSIDS.PT_CATALOGCARD_ID);
          ptNewLink.SetLinkObjectID(link.nLinkObjectID);
          try
          {
            ptNewLink.Store();
            link.nObjectID = ptNewLink.GetObjectID();
          }
          catch (Exception e)
          {
            throw new XPException("Unable to Store Document link: " + e);
            }
        } else
        if (link.nState == DELETE)
        {
          objFolder.DeleteLink(link.nObjectID);
        } else
        {
        }
      }
    }
    // Do nothing
    public virtual void StoreFolders(IPTSiteMapFolder objFolder)
    {
      PTLink link;
      IPTSiteMapLink ptNewLink;
      IXPEnumerator elements = m_tableFolders.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState == ADD)
        {
          ptNewLink = objFolder.CreateLink();
          ptNewLink.SetLinkClassID(PT_CLASSIDS.PT_CATALOGFOLDER_ID);
          ptNewLink.SetLinkObjectID(link.nLinkObjectID);
          try
          {
            ptNewLink.Store();
            link.nObjectID = ptNewLink.GetObjectID();
          }
          catch (Exception e)
          {
            throw new XPException("Unable to Store Directory Folder link: " + e);
            }
        } else
        if (link.nState == DELETE)
        {
          objFolder.DeleteLink(link.nObjectID);
        } else
        {
        }
      }
    }
    // Do nothing
    public virtual void StoreCommPages(IPTSiteMapFolder objFolder)
    {
      PTLink link;
      IPTSiteMapLink ptNewLink;
      IXPEnumerator elements = m_tableCommPages.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState == ADD)
        {
          ptNewLink = objFolder.CreateLink();
          ptNewLink.SetLinkClassID(PT_CLASSIDS.PT_COMMUNITY_ID);
          ptNewLink.SetLinkObjectID(link.nLinkObjectID);
          ptNewLink.SetLinkPageID(link.nPageID);
          try
          {
            ptNewLink.Store();
            link.nObjectID = ptNewLink.GetObjectID();
          }
          catch (Exception e)
          {
            throw new XPException("Unable to Store Community Page link: " + e);
            }
        } else
        if (link.nState == DELETE)
        {
          objFolder.DeleteLink(link.nObjectID);
        } else
        {
        }
      }
    }
    // Do nothing
    public virtual void StoreWebLinks(IPTSiteMapFolder objFolder)
    {
      PTLink link;
      IPTSiteMapLink ptNewLink;
      IXPEnumerator elements = m_tableWebLinks.GetElements();
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState == ADD)
        {
          ptNewLink = objFolder.CreateLink();
          ptNewLink.SetLinkClassID(PT_CLASSIDS.PT_SITEMAPWEBLINK_ID);
          ptNewLink.SetName(link.strName);
          ptNewLink.SetDescription(link.strDesc);
          ptNewLink.SetLinkURL(link.strWebURL);
          try
          {
            ptNewLink.Store();
            link.nLinkObjectID = link.nObjectID;
            link.nObjectID = ptNewLink.GetObjectID();
          }
          catch (Exception e)
          {
            throw new XPException("Unable to Store Web link: " + e);
          }
        } else
        if (link.nState == UPDATE)
        {
          IPTSiteMapLink ptWebLink = objFolder.OpenLink(link.nObjectID);
          ptWebLink.SetName(link.strName);
          ptWebLink.SetDescription(link.strDesc);
          ptWebLink.SetLinkURL(link.strWebURL);
          try
          {
            ptWebLink.Store();
          }
          catch (Exception e)
          {
            throw new XPException("Unable to Store Edited Web link: " + e);
            }
        } else
        if (link.nState == DELETE)
        {
          objFolder.DeleteLink(link.nObjectID);
        }
      }
    }
    
    /// <param name="tableInfo"></param>
    /// <returns>String[]</returns>
    private static String[] GetNamesFromTable(XPHashtable tableInfo)
    {
      PTLink link;
      IXPEnumerator elements = tableInfo.GetElements();
      int numSelected = 0;
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          numSelected++;
        }
      }
      String[] retArr = new String[numSelected];
      elements = tableInfo.GetElements();
      int count = 0;
      while (elements.MoveNext())
      {
        link = (PTLink) elements.GetCurrent();
        if (link.nState != DELETE)
        {
          if ((link.nType == PT_CLASSIDS.PT_COMMUNITY_ID) && (link.nState == KEEP))
          {
            retArr[count++] = link.strName;
          } else
          {
            retArr[count++] = link.strName;
          }
        }
      }
      return retArr;
    }
  }
}