/*
 * Created on Mar 25, 2003
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.browsing.sitemap.sitemappage
{
  /// <summary>
  /// Handles fallback case where there's no control available.  This can occur
  /// on various fallthrough conditions such as ClearErrorsAndReturn().
  /// </summary>
  /// <author>Naveenp</author>
  public class DefaultSiteMapPageControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.sitemappage.DefaultSiteMapPageControl");
    public const String STR_MVC_CLASS_NAME = "DefaultSiteMapPage";
    
    /// <summary>
    /// Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private SiteMapModel m_asModel;
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      return RedirectToSiteMapPage(arguments);
    }
    
    /// <summary>
    /// Redirects to a community page.
    /// </summary>
    /// <param name="arguments"></param>
    /// <returns>Redirect</returns>
    public virtual Redirect RedirectToSiteMapPage(XPHashtable arguments)
    {
      Redirect redirect = null;
      int nCommunityID = NavigationModel.NO_CURRENT_COMMID;
      int nFolderID = 0;
      int nGroupID = 0;
      nCommunityID = m_asModel.GetCommunityID();
      nFolderID = m_asModel.GetCurrentFolderID();
      nGroupID = m_asModel.GetCurrentGroupID();
      try
      {
        m_asModel.SetCommunityID(nCommunityID);
        if (m_asOwner.GetCurrentPage().GetName().Equals(MembersDP.STR_MVC_CLASS_NAME))
        {
          if (nGroupID != 0)
          {
            m_asModel.SetGroupID(nGroupID);
          }
        } else
        {
          m_asModel.OpenSubFolder(nFolderID);
          if (m_asModel.IsEditMode())
          {
            m_asModel.SetEditMode();
          } else
          {
            m_asModel.SetBrowseMode();
          }
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Server Error trying to redirect to site map page.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return redirect;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
     */
     
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (SiteMapModel) model;
      m_asOwner = space;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public virtual Object Create()
    {
      return new DefaultSiteMapPageControl();
    }
  }
}