using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.error;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.browsing.sitemap.sitemappage
{
  /// <summary>
  /// File: SetGroupControl.java
  /// --------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SetGroupControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.sitemappage.SetGroupControl");
    public const String STR_MVC_CLASS_NAME = "SetGroup";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const int BROWSE = 0;
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const int EDIT = 1;
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_GroupID = "GroupID";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private SiteMapModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String[] sValues = (String[]) arguments.GetElement(SetSiteMapControl.m_CommunityID);
      int nCommunityID = -1;
      if (sValues != null)
      {
        try
        {
          nCommunityID = XPConvert.ToInteger(sValues[0]);
          m_asModel.SetCommunityID(nCommunityID);
        }
        catch (Exception e)
        {
          log.Error(e, "Server Error");
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, e.Message, e.Message);
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
      }
      sValues = (String[]) arguments.GetElement(SetSiteMapControl.PREVIEW);
      if (sValues != null)
      {
        m_asModel.SetToPreviewPage();
      }
      sValues = (String[]) arguments.GetElement(m_GroupID);
      int nGroupID;
      if (sValues == null)
      {
        log.Info("could not find group ID in query string.");
        nGroupID = 0;
        m_asModel.ClearGroups();
      } else
      {
        nGroupID = XPConvert.ToInteger(sValues[0]);
        if (!m_asModel.SetGroupID(nGroupID))
        {
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           null, m_asOwner.GetString(602, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(602,
           "ptmsgs_portalbrowsingmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
      }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SetGroupControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (SiteMapModel) model;
      m_asOwner = space;
    }
  }
}