using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.browsing.sitemap.sitemappage
{
  /// <summary>
  /// File: SetSiteMapControl.java
  /// ----------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SetSiteMapControl : RepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.sitemappage.SetSiteMapControl");
    public const String STR_MVC_CLASS_NAME = "SetSiteMap";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const int BROWSE = 0;
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const int EDIT = 1;
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_CommunityID = "CommunityID";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_FolderID = "FolderID";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_Mode = "Mode";
    
    /// <summary>
    /// Is Preview? 
    /// </summary>
    public const String PREVIEW = "Preview";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private SiteMapModel m_asModel;
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()"></seealso>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      try
      {
        String[] sValues = (String[]) arguments.GetElement(m_CommunityID);
        int nCommunityID = -1;
        if (sValues == null)
        {
          log.Error("could not find community ID in query string.");
          throw new Exception(m_asOwner.GetString(955, "ptmsgs_portalbrowsingmsgs"));
          } else
        {
          nCommunityID = XPConvert.ToInteger(sValues[0]);
        }
        sValues = (String[]) arguments.GetElement(m_FolderID);
        int nFolderID = -1;
        if (sValues == null)
        {
          log.Info("could not find folder ID in query string.");
        } else
        {
          nFolderID = XPConvert.ToInteger(sValues[0]);
        }
        sValues = (String[]) arguments.GetElement(m_Mode);
        int nMode = -1;
        if (sValues == null)
        {
          log.Error("could not find mode in query string.");
          throw new Exception(m_asOwner.GetString(954, "ptmsgs_portalbrowsingmsgs"));
          } else
        {
          nMode = XPConvert.ToInteger(sValues[0]);
        }
        m_asModel.SetCommunityID(nCommunityID);
        m_asModel.OpenSubFolder(nFolderID);
        if (nMode == BROWSE)
        {
          m_asModel.SetBrowseMode();
        } else
        if (nMode == EDIT)
        {
          m_asModel.SetEditMode();
        }
        sValues = (String[]) arguments.GetElement(PREVIEW);
        if (sValues != null)
        {
          m_asModel.SetToPreviewPage();
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Server Error");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         null, e.Message, e.Message);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SetSiteMapControl();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public override void Init(IModel model, AActivitySpace space)
    {
      m_asModel = (SiteMapModel) model;
      m_asOwner = space;
    }
  }
}