using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.sitemap.sitemappage
{
  /// <summary>
  /// File: SiteMapBreadcrumbView.java
  /// --------------------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SiteMapBreadcrumbView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapBreadcrumbView");
    public const String STR_MVC_CLASS_NAME = "SiteMapBreadcrumb";
    private AActivitySpace m_asOwner;
    private IFolderModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new SiteMapBreadcrumbView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      //Display the Breadcrumb path, flush left to the margin
      HTMLElementCollection myGroup = new HTMLElementCollection();
      HTMLElement result = myGroup;
      try
      {
        // Bread crumb path
        myGroup.AddInnerHTMLElement(GetBreadcrumbPath().GetPathAsHTMLElement());
        myGroup.AddInnerHTMLElement(new HTMLBr());
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating " + STR_MVC_CLASS_NAME + " Section: " + e.Message + "<BR>");
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#getName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IFolderModelRO) model;
      m_asOwner = parent;
    }
    
    /// <returns>PTBreadcrumbPath</returns>
    /// <throws>HTMLException</throws>
    private PTBreadcrumbPath GetBreadcrumbPath()
    {
      PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();
      XPStringTokenizer stPath = new XPStringTokenizer(m_asModel.GetPath(),
       "\\");
      Object[] oIDs = m_asModel.GetParentFolderIDs();
      // In the case of the root folder, there will be two oIDs even though there
      // is only one folder in stPath.  Otherwise there will be an equal number of
      // IDs and folder names.		
      if (oIDs.Length < stPath.GetTokenCount())
      {
        log.Error("There are more parent names (" + stPath.GetTokenCount() + "than ids (" + oIDs.Length + ").");
        return myCrumbs;
      }
      SiteMapModel model = (SiteMapModel) m_asModel;
      ASURL myURL;
      int i = 0;
      int end = stPath.GetTokenCount();
      while (stPath.HasMoreTokens())
      {
        if (i < (end - 1))
        {
          myURL = new ASURL(m_asOwner);
          myURL.SetLinkGetCachedSpace(m_asOwner);
          myURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
          myURL.AddControlArgument(SetSiteMapControl.m_CommunityID, model.GetCommunityID());
          myURL.AddControlArgument(SetSiteMapControl.m_FolderID, XPConvert.ToInteger(oIDs[i++]));
          myURL.AddControlArgument(SetSiteMapControl.m_Mode, model.GetMode());
          myURL.AddInnerHTMLEncodedString(stPath.GetNextToken());
          myCrumbs.appendAnchorItem((HTMLAnchor) myURL.GetURLAsHTMLElement());
          } else
        {
          myCrumbs.appendTextItem(XPHttpUtility.HtmlEncode(stPath.GetNextToken()));
          // Probably not necessary -- should break out of loop after this.
          i++;
        }
      }
      return myCrumbs;
    }
  }
}