using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.objects;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.browsing.sitemap.sitemappage
{
  /// <summary>
  /// File: SiteMapDP.java
  /// --------------------
  /// </summary>
  /// <author>NaveenP</author>
  public class SiteMapDP : PlumtreeDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapDP");
    public const String STR_MVC_CLASS_NAME = "SiteMap";
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()"></seealso>
    public override String GetSubtitleForBanner()
    {
      return m_asOwner.GetString(971, "ptmsgs_portalbrowsingmsgs");
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()"></seealso>
    public override String GetTitleForBanner()
    {
      NavigationModel modelNavigation = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      return modelNavigation.GetCurCommunityName();
    }
    
    /// <summary>
    /// helper display method for PlumtreeDP
    /// Fill in the body argument with HTML to display in the page.
    /// </summary>
    public override HTMLElement PageDisplay()
    {
      // rob: we need to get the model here, can't set it in the init method since it hasn't been created at that time
      // (don't know why)
      SiteMapModel m_asModel = (SiteMapModel) m_asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
      if (m_asModel == null)
      {
        throw new XPIllegalStateException("Unable to display the SiteMap page, the SiteMap Model has not been initialized.");
        }
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetBorder(CommonHTMLStrings.ZERO);
      //table.SetCellSpacing("10");
      table.SetCellSpacing(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.ZERO);
      HTMLTableRow row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      try
      {
        //Breadcrumbs
        if (!m_asModel.InRootFolder())
        {
          result.AddInnerHTMLElement(m_asOwner.GetView(SiteMapBreadcrumbView.STR_MVC_CLASS_NAME).Display());
          }
        // browse or edit bar	
        result.AddInnerHTMLElement(m_asOwner.GetView(SiteMapBannerView.STR_MVC_CLASS_NAME).Display());
        // members and subcommunities	
        result.AddInnerHTMLElement(m_asOwner.GetView(MemberAndSubCommunitiesView.STR_MVC_CLASS_NAME).Display());
        //Folders
        FolderView folderView = (FolderView) m_asOwner.GetView(FolderView.STR_MVC_CLASS_NAME);
        if (m_asModel.InRootFolder())
        {
          // Don't show "No Subfolders in this folder" message in root because we have members and subcomms
          folderView.SetShowNoFolderMessage(false);
        } else
        {
          folderView.SetShowNoFolderMessage(true);
        }
        result.AddInnerHTMLElement(m_asOwner.GetView(FolderView.STR_MVC_CLASS_NAME).Display());
        result.AddInnerHTMLElement(DirConstants.CreateSpacerTable(15, 1));
        // links - display if not in root folder
        if (!m_asModel.InRootFolder())
        {
          result.AddInnerHTMLElement(m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME).Display());
          }
        cell.AddInnerHTMLElement(result);
      }
      catch (HTMLException he)
      {
        log.Error(he, "Error in SiteMapDP::Display.");
      }
      return table;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      // rob: we need to get the model here, can't set it in the init method since it hasn't been created at that time
      // (don't know why)
      SiteMapModel m_asModel = (SiteMapModel) m_asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
      if (m_asModel == null)
      {
        throw new XPIllegalStateException("Unable to display the SiteMap page, the SiteMap Model has not been initialized.");
        }
      HTMLScriptCollection scripts = new HTMLScriptCollection();
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) + "opennewwindow.js");
      scripts.AddInnerHTMLElement(script);
      scripts.AddInnerHTMLElement(m_asOwner.GetView(SiteMapBannerView.STR_MVC_CLASS_NAME).DisplayJavascript());
      if (!m_asModel.InRootFolder())
      {
        scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME).DisplayJavascript());
        }
      SiteMapFolderPlugInView plugInView = (SiteMapFolderPlugInView) m_asOwner.GetView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME);
      if (m_asModel.IsEditMode())
      {
        scripts.AddInnerHTMLElement(plugInView.DisplayJavascript());
      }
      return scripts;
    }
  }
}