using System;
namespace com.plumtree.portalpages.common.areyousure
{
  /// <author>
  /// adolfoc
  /// This simple class encapsulates a single message to be rendered in the AYSMessageView.
  /// </author>
  public class AYSMessage
  {
    
    /// <summary>
    /// Top level messages are printed with now title or descriptive text.
    /// Actions are marked as actions that will occur when the OK button is clicked.
    /// Warnings are warnings displayed to the user.
    /// Recommendations are marked as suggested actions for the user to take after clicking OK.
    /// Errors are errors displayed to the user.
    /// </summary>
    public const int AYSTYPE_TOPLEVEL = 0;
    public const int AYSTYPE_ACTION = 1;
    public const int AYSTYPE_WARNING = 2;
    public const int AYSTYPE_RECOMMENDATION = 3;
    public const int AYSTYPE_ERROR = 4;
    
    /// <summary>
    /// The actual message text you would like to print. This should be localized for display.
    /// </summary>
    public String m_strMessage = "";
    
    /// <summary>
    /// Whether or not this message should be HTMLEncoded when displayed.
    /// </summary>
    public bool m_bHTMLEncode = true;
    
    /// <summary>
    /// The message type for this message.
    /// </summary>
    public int m_nMessageType = 0;
    
    /// <summary>
    /// Creates a new AYSMessage object.
    /// </summary>
    /// <param name="strMessage"></param>
    /// <param name="nMessageType"></param>
    public AYSMessage(String strMessage, int nMessageType)
    {
      m_strMessage = strMessage;
      m_nMessageType = nMessageType;
    }
    
    /// <summary>
    /// Creates a new AYSMessage object.
    /// </summary>
    /// <param name="strMessage"></param>
    /// <param name="nMessageType"></param>
    /// <param name="bHTMLEncode"></param>
    public AYSMessage(String strMessage, int nMessageType, bool bHTMLEncode)
    {
      m_strMessage = strMessage;
      m_nMessageType = nMessageType;
    }
  }
}