using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.helpers;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.areyousure
{
  /// <author>adolfoc</author>
  public class AYSMessageView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.areyousure.AYSMessageView");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AYSMessageView";
    
    /// <summary>
    /// HTML Object name: close button 
    /// </summary>
    public const String HTMLBUTTON_CANCEL = "in_bu_Cancel";
    
    /// <summary>
    /// HTML Object name: ok button 
    /// </summary>
    public const String HTMLBUTTON_OK = "in_bu_Ok";
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    private AreYouSureAS m_asOwner;
    
    /// <summary>
    /// Associated read-only Model.
    /// </summary>
    private IAYSModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new AYSMessageView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLInput myInput;
      HTMLB myB;
      try
      {
        // Content table
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        // to let some left margin
        myTable.SetWidth("90%");
        // to let some left margin
        myTable.SetAlign(CommonHTMLStrings.CENTER);
        myTable.SetBorder("0");
        myTable.SetCellPadding("0");
        myTable.SetCellSpacing("0");
        myTable.SetSummary(m_asOwner.GetString(494, "ptmsgs_portalcommonmsgs"));
        // Row 2 - begin
        myRow = ViewHelper.AddRow(myTable);
        myCell = ViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myCell.SetNoWrap(false);
        mySpan = ViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_HEADER);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(25, "ptmsgs_portalcommonmsgs"));
        AddLineBreaks(myCell, 2);
        XPArrayList xpalMessages = ((IAYSModelRO) m_model).GetMessages();
        myCell.AddInnerHTMLElement(DisplayMessages(m_asOwner.GetString(718,
         "ptmsgs_portalcommonmsgs"), null, xpalMessages, AYSMessage.AYSTYPE_ERROR));
        myCell.AddInnerHTMLElement(DisplayMessages(null, null, xpalMessages,
         AYSMessage.AYSTYPE_TOPLEVEL));
        myCell.AddInnerHTMLElement(DisplayMessages(m_asOwner.GetString(4,
         "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(5, "ptmsgs_portalcommonmsgs"),
         xpalMessages, AYSMessage.AYSTYPE_ACTION));
        myCell.AddInnerHTMLElement(DisplayMessages(m_asOwner.GetString(6,
         "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(7, "ptmsgs_portalcommonmsgs"),
         xpalMessages, AYSMessage.AYSTYPE_WARNING));
        myCell.AddInnerHTMLElement(DisplayMessages(m_asOwner.GetString(8,
         "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(9, "ptmsgs_portalcommonmsgs"),
         xpalMessages, AYSMessage.AYSTYPE_RECOMMENDATION));
        // Row  - begin (Margin)
        myRow = ViewHelper.AddRow(myTable);
        myCell = ViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myCell.SetNoWrap(false);
        mySpan = ViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myB = new HTMLB();
        mySpan.AddInnerHTMLElement(myB);
        myB.AddInnerHTMLString(m_asOwner.GetString(0, "ptmsgs_portalcommonmsgs"));
        AddLineBreaks(result, 2);
        // Row - begin
        myRow = ViewHelper.AddRow(myTable);
        myCell = ViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        myCell.SetNoWrap(false);
        mySpan = ViewHelper.AddSpanToCell(myCell);
        mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
        // OK Button
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_OK, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(694, "ptmsgs_portalcommonmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        myInput.SetOnClick("onOK();");
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE + CommonHTMLStrings.SPACE);
        // Button to close the window
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(693, "ptmsgs_portalcommonmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("top.close();");
        // Bottom Margin
        AddLineBreaks(myCell, 2);
      }
      catch (Exception e)
      {
        log.Error(e, "Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(10, "ptmsgs_portalcommonmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      XPStringBuilder sb;
      try
      {
        sb = new XPStringBuilder(200);
        // AGC- redirect the parent window when we popup.
        sb.Append("function onOK()\n{\n  top.opener.postToSelf(\'" + AreYouSureControl.POSTTOSELF_ACTION_REDIRECT_AFTER_OK + "\');\n top.close();\n}\n");
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript The following error occured when trying to display the JavaScript: " + he.Message);
        }
      return myScript;
    }
    
    /// <summary>
    /// Displays all of the AYSMessages in xpalMessages or nothing if there are no messages.
    /// </summary>
    /// <param name="strTitle"></param>
    /// <param name="strSubTitle"></param>
    /// <param name="xpalMessages"></param>
    /// <returns></returns>
    public virtual HTMLElement DisplayMessages(String strTitle, String strSubTitle,
     XPArrayList xpalMessages, int nAYSMessageTypeToDisplay)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      IXPEnumerator xpeMessages = xpalMessages.GetEnumerator();
      HTMLSpan mySpan = new HTMLSpan();
      result.AddInnerHTMLElement(mySpan);
      switch (nAYSMessageTypeToDisplay){
      case AYSMessage.AYSTYPE_ERROR:
      mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
      break;
      case AYSMessage.AYSTYPE_WARNING:
      mySpan.SetStyleClass(PTStyleClass.ALERT_WARNING_TEXT);
      break;
      default:
      mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
      break;
      }
      // The label for messages
      if (!ModelHelper.IsBlankString(strTitle))
      {
        HTMLB myB = new HTMLB();
        mySpan.AddInnerHTMLElement(myB);
        myB.AddInnerHTMLString(strTitle);
        AddLineBreaks(mySpan, 1);
      }
      if (!ModelHelper.IsBlankString(strSubTitle))
      {
        mySpan.AddInnerHTMLString(strSubTitle);
        AddLineBreaks(mySpan, 2);
      }
      bool bFoundAMessage = false;
      while (xpeMessages.MoveNext())
      {
        AYSMessage aysmCurrent = (AYSMessage) xpeMessages.GetCurrent();
        if (nAYSMessageTypeToDisplay == aysmCurrent.m_nMessageType)
        {
          result.AddInnerHTMLElement(DisplayMessage(aysmCurrent));
          bFoundAMessage = true;
        }
      }
      AddLineBreaks(result, 1);
      if (bFoundAMessage)
      {
        return result;
      } else
      {
        return new HTMLElementCollection();
      }
    }
    
    /// <summary>
    /// Default implementation which simply displays and Are You Sure message
    /// </summary>
    public virtual HTMLElement DisplayMessage(AYSMessage aysmIn)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLSpan mySpan = new HTMLSpan();
      result.AddInnerHTMLElement(mySpan);
      switch (aysmIn.m_nMessageType){
      case AYSMessage.AYSTYPE_WARNING:
      mySpan.SetStyleClass(PTStyleClass.ALERT_WARNING_TEXT);
      mySpan.AddInnerHTMLElement(GetHTMLForIcon(PTImageType.ICON_WARNING));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      break;
      case AYSMessage.AYSTYPE_ERROR:
      mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
      mySpan.AddInnerHTMLElement(GetHTMLForIcon(PTImageType.ICON_ERROR));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      break;
      case AYSMessage.AYSTYPE_RECOMMENDATION:
      mySpan.AddInnerHTMLElement(GetHTMLForIcon(PTImageType.ICON_INFORMATION));
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      break;
      }
      if (aysmIn.m_bHTMLEncode)
      {
        mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(aysmIn.m_strMessage));
        } else
      {
        mySpan.AddInnerHTMLString(aysmIn.m_strMessage);
      }
      AddLineBreaks(result, 1);
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IAYSModelRO) model;
      m_asOwner = (AreYouSureAS) parent;
    }
    
    /// <summary>
    /// Helper method to add a BR tag to another element.
    /// </summary>
    protected virtual void AddLineBreaks(HTMLElement myElement, int nNumBreaks)
    {
      for (int nIndex = 0;nIndex < nNumBreaks;nIndex++)
      {
        HTMLBr myBr = new HTMLBr();
        myElement.AddInnerHTMLElement(myBr);
      }
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetHTMLForIcon(PTImageType _imgRowIcon)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign("absmiddle");
      return (myImage);
    }
  }
}