using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.areyousure
{
  /// <author>adolfoc</author>
  public class AYSTopView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.areyousure.AYSTopView");
    
    /// <summary>
    /// Class name for the activity space
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "AYSTopView";
    
    /// <summary>
    /// Parent AS.
    /// </summary>
    private AreYouSureAS m_asOwner;
    
    /// <summary>
    /// Associated read-only Model.
    /// </summary>
    private IAYSModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new AYSTopView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myMainTable;
      HTMLTableRow myMainTableRow;
      HTMLTableCell myMainTableCell;
      HTMLSpan mySpan;
      try
      {
        // Main table
        myMainTable = new HTMLTable();
        result.AddInnerHTMLElement(myMainTable);
        myMainTable.SetWidth("100%");
        myMainTable.SetHeight("100%");
        myMainTable.SetBorder("0");
        myMainTable.SetCellPadding("0");
        myMainTable.SetCellSpacing("0");
        // Main table = row 1
        myMainTableRow = new HTMLTableRow();
        myMainTable.AddInnerHTMLElement(myMainTableRow);
        myMainTableCell = new HTMLTableCell();
        myMainTableRow.AddInnerHTMLElement(myMainTableCell);
        myMainTableCell.SetHeight("60");
        myMainTableCell.SetWidth("100%");
        myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        mySpan = new HTMLSpan();
        myMainTableCell.AddInnerHTMLElement(mySpan);
        mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      catch (Exception e)
      {
        log.Error(e, "Display The following error occured when trying to display the HTML: " + e.Message);
        throw new XPException(m_asOwner.GetString(24, "ptmsgs_portalcommonmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IAYSModelRO) model;
      m_asOwner = (AreYouSureAS) parent;
    }
  }
}