using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.common.browsingpropchooser
{
  /// <summary>
  /// This is the implementation of the Expandable List for editing card properties.
  /// </summary>
  /// <author>stephenc</author>
  public class PropChooserModel : ExpListModel,IPropChooserModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.browsingpropchooser.PropChooserModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropChooser";
    
    /// <summary>
    /// Number total of columns 
    /// </summary>
    public const int EXPLIST_COL_MAX = 4;
    public const int EXPLIST_COL_PROPID = 1;
    public const int EXPLIST_COL_NAME = 2;
    public const int EXPLIST_COL_STATUS = 3;
    public const int COL_STATUS_COMMITTED = 0;
    public const int COL_STATUS_ADDED_NEW = 1;
    public const int NEW_PROP_DEFAULTVALUE = -1;
    public const int NEW_PROP_PROPID_UNSELECTED = -1;
    
    /// <summary>
    /// XPSortedDictionary 
    /// </summary>
    public XPSortedDictionary m_xpUnusedProperties = null;
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    protected IPTSession m_ptSession;
    
    /// <summary>
    /// This is used on add to populate the input  text of the newly added row.
    /// </summary>
    protected Object m_oDefaultValue;
    
    /// <summary>
    /// Icon to display on each row, just before the input text. 
    /// </summary>
    protected PTImageType m_imgRowIcon;
    private IPTServerConfigSettings m_ptSCS;
    private String m_strSelectedProperties = "";
    private int m_nNewAddSelectedPropID = -1;
    public PropChooserModel() : base()
    {
      m_nNewAddSelectedPropID = NEW_PROP_PROPID_UNSELECTED;
    }
    // *** END: Logging Setup   ***
    // ****************************
    
    /// <param name="_htFormData"></param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      // Commit the current New Row (if any) to the Added List
      CommitNewAddRow();
      // Create a New Row
      if (m_xpUnusedProperties.GetSize() > 0)
      {
        Object[] oNewRow = new Object[EXPLIST_COL_MAX];
        oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex++;
        oNewRow[EXPLIST_COL_PROPID] = NEW_PROP_DEFAULTVALUE;
        oNewRow[EXPLIST_COL_NAME] = "";
        oNewRow[EXPLIST_COL_STATUS] = COL_STATUS_ADDED_NEW;
        base.GetItems().AddRow(oNewRow);
        m_nNewAddSelectedPropID = NEW_PROP_PROPID_UNSELECTED;
      } else
      {
      }
    }
    // TODO: report a message somehow	
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PropChooserModel();
    }
    
    /// <param name="_htFormData"></param>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
      // JF- We get back the list of index of rows to delete.
      if (_htFormData.ContainsKey(sDataKey))
      {
        String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
        int[] aRowsToDelete = GetRowsToDelete(aDataValue);
        // Remove rows
        m_saData.RemoveRows(aRowsToDelete);
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual int GetNewlySelectedPropertyID()
    {
      return m_nNewAddSelectedPropID;
    }
    
    /// <summary>
    /// Returns the icon to display on each row before the  input text. If the
    /// value is null, no icon is displayed.
    /// </summary>
    /// <returns>PTImageType</returns>
    public virtual PTImageType GetRowIcon()
    {
      return m_imgRowIcon;
    }
    
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    public virtual String GetRowName(int _nRowIndex)
    {
      return (String) m_saData.GetItem(_nRowIndex, EXPLIST_COL_NAME);
    }
    
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    public virtual int GetRowPropertyID(int _nRowIndex)
    {
      return XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, EXPLIST_COL_PROPID));
      }
    
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    public virtual int GetRowStatus(int _nRowIndex)
    {
      return XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, EXPLIST_COL_STATUS));
      }
    
    /// <returns></returns>
    public virtual String GetSelectedProperties()
    {
      try
      {
        // Commit Any Newly Added Properties
        CommitNewAddRow();
        bool bFirstProp = true;
        for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
        {
          int nStatus = GetRowStatus(nRowIndex);
          if (COL_STATUS_COMMITTED == nStatus)
          {
            int nPropID = GetRowPropertyID(nRowIndex);
            if (bFirstProp)
            {
              m_strSelectedProperties = XPConvert.ToString(nPropID);
              bFirstProp = false;
            } else
            {
              m_strSelectedProperties = m_strSelectedProperties + " " + nPropID;
              }
          }
        }
      }
      catch (Exception e)
      {
        log.Error("PropChooserModel::GetSelectedProperties " + m_asOwner.GetString(495,
         "ptmsgs_portalcommonmsgs") + ". The following exception occured: " + e);
        throw new XPException(m_asOwner.GetString(495, "ptmsgs_portalcommonmsgs"),
         e);
      }
      return m_strSelectedProperties;
    }
    
    /// <returns></returns>
    public override XPSortedDictionary GetUnusedProperties()
    {
      return m_xpUnusedProperties;
    }
    
    /// <param name="_ptSession"></param>
    /// <param name="_ptObject"></param>
    /// <param name="_sSectionTitle"></param>
    /// <param name="_imgAddIcon"></param>
    /// <param name="_sAddLabel"></param>
    /// <param name="_nListKey"></param>
    /// <returns></returns>
    public virtual bool InitializeSelectedProperties(IPTSession _ptSession)
    {
      m_ptSession = _ptSession;
      // If object does not support object properties, then return immediately with false value.
      // If object supports GetObjectProperties, then continue with initialization of expandable list.
      InitExpandableList(m_asOwner.GetString(497, "ptmsgs_portalcommonmsgs"),
       PTImageType.ICON_PROPERTY, m_asOwner.GetString(496, "ptmsgs_portalcommonmsgs"),
       1);
      SetEnableMoveRowActions(true);
      // Create a list of properties that have not been assigned.
      LoadUnusedProperties();
      // Load the properties only after expandable list is initialized.
      // Important: this must come AFTER LoadUnusedProperties()		 as it will remove properties that already selected
      LoadSelectedProperties();
      return true;
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
    /// mapping and an array of sort. The growable array will always be sorted
    /// by the 1st  column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_PROPID,
       EXPLIST_COL_NAME, EXPLIST_COL_STATUS};
      // JF- Sort array
      // The growable array will always be sorted by the 1st column.
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null bellow)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true);
    }
    
    /// <summary>
    /// Because this select ptobject list needs to support both move
    /// row actions enable and disable, we need to change the
    /// colspan of the header row when this happens.
    /// </summary>
    /// <param name="_bEnableMoveRowActions"></param>
    public override void SetEnableMoveRowActions(bool _bEnableMoveRowActions)
    {
      base.SetEnableMoveRowActions(_bEnableMoveRowActions);
      if (m_bEnableMoveRowActions)
      {
        // JF- If the move row actions are enabled, this will
        // create one more cell at the end of each row and
        // we need to reflect that change on the header row.
        m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      } else
      {
        m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      }
    }
    
    /// <param name="_aDataValue"></param>
    /// <returns></returns>
    protected virtual int[] GetRowsToDelete(String[] _aDataValue)
    {
      XPArrayList alistRowsToDelete = new XPArrayList();
      // Determine which rows we actually want to actually remove from the expandable list.
      for (int i = 0;i < _aDataValue.Length;i++)
      {
        int nRowIndex = XPConvert.ToInteger(_aDataValue[i]);
        int nStatus = GetRowStatus(nRowIndex);
        int nPropID = GetRowPropertyID(nRowIndex);
        // Restore this item back to the list of unused properties
        if (nStatus != COL_STATUS_ADDED_NEW)
        {
          String strPropName = ((IPTProperty) m_ptSession.GetProperties().Open(nPropID,
           false)).GetLocalizedName();
          m_xpUnusedProperties.PutElement(strPropName, nPropID);
        }
        // The row is always deleted from the list, regardless of whether it is an original or newly added row
        alistRowsToDelete.Add(nRowIndex);
      }
      // Convert array list to int array
      int[] aRowsToDelete = new int[alistRowsToDelete.GetSize()];
      for (int i = 0;i < alistRowsToDelete.GetSize();i++)
      {
        aRowsToDelete[i] = XPConvert.ToInteger(alistRowsToDelete.GetElement(i));
        }
      return aRowsToDelete;
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      String sDataNewRowNameKey = PropChooserView.HTMLINPUT_SELECT_NEW_PROP;
      // Check if this is a newly added row
      // Dont save newly added rows here.  Just record the propID.  They are saved when an addition row is added and during StoreObjectProperties()
      int nStatus = GetRowStatus(_nRowIndex);
      if (COL_STATUS_ADDED_NEW == nStatus)
      {
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataNewRowNameKey);
        //int nPropID;
        if ((null != aDataValues) && !(0 == aDataValues.Length))
        {
          m_nNewAddSelectedPropID = XPConvert.ToInteger(aDataValues[0]);
        } else
        {
          m_nNewAddSelectedPropID = NEW_PROP_DEFAULTVALUE;
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="_nRowIndex"></param>
    /// <param name="_nStatus"></param>
    protected virtual void SetRowStatus(int _nRowIndex, int _nStatus)
    {
      m_saData.SetItem(_nRowIndex, EXPLIST_COL_STATUS, _nStatus);
    }
    
    /// <summary>
    /// Commit Newly Added Row (should only be one)
    /// </summary>
    private void CommitNewAddRow()
    {
      for (int nRowIndex = 0;nRowIndex < m_saData.GetCount();nRowIndex++)
      {
        int nStatus = GetRowStatus(nRowIndex);
        if (COL_STATUS_ADDED_NEW == nStatus)
        {
          // PropID should already be set
          if (NEW_PROP_PROPID_UNSELECTED == m_nNewAddSelectedPropID)
          {
            log.Error("EditCardPropModel::CommitNewAddRow Unable to determine selected PropID");
            return;
          }
          // Determine Name
          String strName = ((IPTProperty) m_ptSession.GetProperties().Open(m_nNewAddSelectedPropID,
           false)).GetLocalizedName();
          // Update columns
          m_saData.SetItem(nRowIndex, EXPLIST_COL_PROPID, m_nNewAddSelectedPropID);
          m_saData.SetItem(nRowIndex, EXPLIST_COL_STATUS, COL_STATUS_COMMITTED);
          m_saData.SetItem(nRowIndex, EXPLIST_COL_NAME, strName);
          // Remove this item from to the list of unused properties 
          String strPropName = ((IPTProperty) m_ptSession.GetProperties().Open(m_nNewAddSelectedPropID,
           false)).GetLocalizedName();
          m_xpUnusedProperties.RemoveElement(strPropName);
        }
      }
    }
    
    /// <param name="_sSectionTitle"></param>
    /// <param name="_imgAddIcon"></param>
    /// <param name="_sAddLabel"></param>
    /// <param name="_nListKey"></param>
    private void InitExpandableList(String _sSectionTitle, PTImageType _imgAddIcon,
     String _sAddLabel, int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      // The first column will be the property name and will be not sortable
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(498,
       "ptmsgs_portalcommonmsgs");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "20%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    private void LoadSelectedProperties()
    {
      // Retrieve from PTServerConfig db table
      m_ptSCS = (IPTServerConfigSettings) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      Object oValue = m_ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PROP_COLUMNS);
      if (null != oValue)
      {
        String strAllProps = (String) oValue;
        if (0 == strAllProps.Length)
        {
          return;
        }
        XPStringTokenizer st = new XPStringTokenizer(strAllProps, " ");
        Object[] aRowToAdd = new Object[EXPLIST_COL_MAX];
        int nStatus = COL_STATUS_COMMITTED;
        IPTProperty ptProp;
        try
        {
          for (int i = 0;st.HasMoreTokens();i++)
          {
            int nPropID = XPConvert.ToInteger(st.GetNextToken());
            try
            {
              ptProp = (IPTProperty) m_ptSession.GetProperties().Open(nPropID,
               false);
            }
            catch (Exception e)
            {
              log.Warn("Init::Unable to open selected property " + nPropID + ".");
              continue;
            }
            String strPropName = ptProp.GetLocalizedName();
            aRowToAdd[EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex++;
            aRowToAdd[EXPLIST_COL_PROPID] = nPropID;
            aRowToAdd[EXPLIST_COL_NAME] = strPropName;
            aRowToAdd[EXPLIST_COL_STATUS] = nStatus;
            m_xpUnusedProperties.RemoveElement(strPropName);
            m_saData.AddRow(aRowToAdd);
          }
        }
        catch (Exception e)
        {
        }
      }
    }
    private void LoadUnusedProperties()
    {
      m_xpUnusedProperties = new XPSortedDictionary();
      IASQueryResult asqr = null;
      try
      {
        IPTQueryResult qr = m_ptSession.GetCatalog().GetOrderByProperties();
        asqr = new ASQueryResultWrapper(qr);
        // Show all card properties
        for (int i = 0;i < asqr.GetCount();i++)
        {
          int nPropID = XPConvert.ToInteger(asqr.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
          // ignore card name (already shown by default)
          if (PT_INTRINSICS.PT_PROPERTY_OBJECTNAME == nPropID)
          {
            continue;
          }
          String strPropName = (String) asqr.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
          m_xpUnusedProperties.PutElement(strPropName, nPropID);
        }
      }
      catch (XPException xpe)
      {
        log.Error(xpe, STR_MVC_CLASS_NAME + "::LoadUnusedProperties(): Unable to retrieve browsing order by properties: " + xpe.GetMessage());
        }
    }
  }
}