using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.browsingpropchooser
{
  /// <summary>
  /// This is the implementation of the Expandable List for editing properties displayed when browsing
  /// </summary>
  /// <author>stephenc</author>
  public class PropChooserView : ExpListView
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PropChooser";
    public const String HTMLINPUT_SELECT_NEW_PROP = "in_se_NewProperty";
    public const String HTMLINPUT_SELECT_NEW_PROP_TAGID = "NewPropTagID";
    
    /// <summary>
    /// Used to set the style of the row 
    /// </summary>
    private PTStyleClass rowStyleClass;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PropChooserView();
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex. Each row contains just an icon
    /// and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForName(_saData, _nRowIndex));
      if (((IExpListModelRO) m_model).GetEnableMoveRowActions())
      {
        result.AddInnerHTMLElement(base.GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected override HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
    {
      IPropChooserModelRO iECPModel = (IPropChooserModelRO) m_model;
      HTMLTableCell myCell;
      HTMLInput myInput;
      myCell = new HTMLTableCell();
      myCell.SetWidth("20");
      myCell.SetHeight("30");
      myCell.SetAlign("center");
      myCell.SetVAlign("middle");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      // checkbox
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, iECPModel.GetUniqueString(HTMLCHECKBOX_DELROW),
       iECPModel.GetDeleteIconAlt());
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetValue(XPConvert.ToString(_nRowIndex));
      myCell.AddInnerHTMLElement(myInput);
      return myCell;
    }
    
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected virtual HTMLTableCell GetHTMLForName(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      IPropChooserModelRO iECPModel = (IPropChooserModelRO) m_model;
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      String strName = iECPModel.GetRowName(_nRowIndex);
      int nStatus = iECPModel.GetRowStatus(_nRowIndex);
      // Display name
      if (PropChooserModel.COL_STATUS_ADDED_NEW == nStatus)
      {
        myCell.AddInnerHTMLElement(GetUnusedPropertiesHTMLSelect());
      } else
      {
        myCell.AddInnerHTMLString("<B>" + XPHttpUtility.HtmlEncode(strName) + "</B>");
        }
      return myCell;
    }
    
    /// <summary>
    /// Generates a list of properties to be added.  Only card props that have not been chosen are offered
    /// </summary>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected virtual HTMLSelect GetUnusedPropertiesHTMLSelect()
    {
      IPropChooserModelRO iECPModel = (IPropChooserModelRO) m_model;
      HTMLSelect mySelect = new HTMLSelect(HTMLINPUT_SELECT_NEW_PROP, HTMLINPUT_SELECT_NEW_PROP_TAGID);
      XPSortedDictionary xpUnusedProperties = iECPModel.GetUnusedProperties();
      IXPEnumerator xpEnum;
      IXPEnumerator xpKeys;
      xpEnum = xpUnusedProperties.GetElements();
      xpKeys = xpUnusedProperties.GetKeys();
      int nNewlySelectedPropertyID = iECPModel.GetNewlySelectedPropertyID();
      while (xpEnum.MoveNext() && xpKeys.MoveNext())
      {
        String strPropName = (String) xpKeys.GetCurrent();
        int nPropID = XPConvert.ToInteger(xpEnum.GetCurrent());
        HTMLOption optionVal = new HTMLOption(XPConvert.ToString(nPropID));
        if (nNewlySelectedPropertyID == nPropID)
        {
          optionVal.SetSelected(true);
        }
        mySelect.AddInnerHTMLElement(optionVal);
        optionVal.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strPropName));
        }
      return mySelect;
    }
    
    /// <summary>
    /// Helper method to set the style of a row.  This method is used by
    /// Display(). Overrides the ExpListView::SetExpListRowStyle().
    /// </summary>
    /// <param name="_myRow"></param>
    /// <param name="_nRowIndex"></param>
    /// <param name="_nLastVisibleRow"></param>
    /// <throws>HTMLException</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#SetExpListRowStyle(HTMLTableRow,int,int)"></seealso>
    protected virtual void SetRowStyle(HTMLTableRow _myRow, int _nRowIndex,
     int _nLastVisibleRow)
    {
      IPropChooserModelRO iOPModel = (IPropChooserModelRO) m_model;
      // Get current property ID
      int nPropertyID = iOPModel.GetRowPropertyID(_nRowIndex);
      // Get last visible property ID
      int nLastVisiblePropertyID = PT_INTRINSICS.PT_NULL_OBJECTID;
      if (-1 != _nLastVisibleRow)
      {
        nLastVisiblePropertyID = iOPModel.GetRowPropertyID(_nLastVisibleRow);
        }
      // Check if we have moved on to a new property
      if (nPropertyID != nLastVisiblePropertyID)
      {
        // Toggle style index if we have a new property
        if (PTStyleClass.LIST_ITEM_ONE_BG == rowStyleClass)
        {
          rowStyleClass = PTStyleClass.LIST_ITEM_TWO_BG;
        } else
        {
          rowStyleClass = PTStyleClass.LIST_ITEM_ONE_BG;
        }
      }
      _myRow.SetStyleClass(rowStyleClass);
    }
  }
}