using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.browsingpropchooser;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.tips;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.dirprefs
{
  /// <author>StephenC</author>
  public class DirPrefsAS : PTEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.dirprefs.DirPrefsAS");
    private const String sClassName = "com.plumtree.portalpages.common.dirprefs.DirPrefsAS";
    public const String STR_MVC_CLASS_NAME = "DirPrefs";
    public const String strBrowsingPropertiesPlugInKey = "BrowsingPropertiesPlugIn";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new DirPrefsAS();
    }
    
    /// <returns></returns>
    public override String GetEditorTitle()
    {
      return (GetString(499, "ptmsgs_portalcommonmsgs"));
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (DirPrefsRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
      {
        return false;
      }
      return base.CheckBasicAccess(strPage, strControl, bSameSpace);
    }
    public override void Init()
    {
      m_strModelName = DirPrefsModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(m_strModelName);
      RegisterPage(new DirPrefsDP());
      RegisterView(DirPrefsView.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(DirPrefsRepostControl.STR_MVC_CLASS_NAME, myModel);
      // Register Plug-In: Browsing Properties
      RegisterModel(PropChooserModel.STR_MVC_CLASS_NAME, strBrowsingPropertiesPlugInKey);
      // Get back the Model we just registered because we need it to register the Section and the Control
      IModel myPropChooserPlugInModel = GetModel(strBrowsingPropertiesPlugInKey);
      RegisterView(PropChooserView.STR_MVC_CLASS_NAME, strBrowsingPropertiesPlugInKey,
       myPropChooserPlugInModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strBrowsingPropertiesPlugInKey,
       myPropChooserPlugInModel);
      SetCurrentPage(DirPrefsDP.STR_MVC_CLASS_NAME);
      // This editor only has one page so we can set the help here
      this.SetHelpTopic("PT_KnowledgeDirectoryPreferences_MainSettings");
      // Set left nav menu
      // BEGIN Sub menu "General Settings"
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(500, "ptmsgs_portalcommonmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, DirPrefsDP.STR_MVC_CLASS_NAME);
      // END Sub menu "General Settings"
      //	TIPS
      TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
      if (tm != null)
      {
        try
        {
          tm.SetGeneratingClass(sClassName);
          int iTitleId = 117;
          int iTipId = 118;
          int iSecondaryTipId = 119;
          tm.SetTipTitle(this.GetString(iTitleId, ResourceConstants.TIPS));
          HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId,
           ResourceConstants.TIPS));
          tm.SetTip(e);
          String sSecondary = this.GetString(iSecondaryTipId, ResourceConstants.TIPS);
          if (!("none_do_not_translate".Equals(sSecondary)))
          {
            e = new HTMLGenericElement(sSecondary);
            tm.SetSecondarTip(e);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, "Couldn\'t generate tip.");
        }
      }
    }
  }
}
//	Got the tips model
