using System;
namespace com.plumtree.portalpages.common.editpage
{
  /// <summary>
  /// Interface IPageLayoutModelRO.
  /// This is the interface used by PageLayoutView.
  /// </summary>
  /// <author>michaeld</author>
  public interface IPageLayoutModelRO
  {
    
    /// <summary>
    /// Method GetCanChangeLayout.
    /// If this editor can choose the page layout type for this page,
    /// then this will return true.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetCanChangeLayout();
    
    /// <summary>
    /// Method GetCanChooseFreeForm.
    /// If this editor can choose a free form gadget for this page,
    /// then this will return true.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetCanChooseFreeForm();
    
    /// <summary>
    /// Method GetCanCreatePortlet.
    /// If this editor can create a gadget from a gadget template,
    /// then this will return true.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetCanCreatePortlet();
    
    /// <summary>
    /// Method GetPortletAlignment.
    /// Gets the gadget alignment for the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>int</returns>
    int GetPortletAlignment(int nPortletIndex);
    
    /// <summary>
    /// Method GetPortletColumn.
    /// Gets the gadget column for the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>int</returns>
    int GetPortletColumn(int nPortletIndex);
    
    /// <summary>
    /// Method GetPortletCount.
    /// Gets the count of the gadgets on the page.
    /// </summary>
    /// <returns>int</returns>
    int GetPortletCount();
    
    /// <summary>
    /// Method GetPortletDescription.
    /// Gets the gadget description for the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>String</returns>
    String GetPortletDescription(int nPortletIndex);
    
    /// <summary>
    /// Method GetPortletID.
    /// Gets the gadget ID for the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>int</returns>
    int GetPortletID(int nPortletIndex);
    
    /// <summary>
    /// Method GetPortletIsCommunityType.
    /// Gets whether the gadget at the given index is of type community or not.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>boolean</returns>
    bool GetPortletIsCommunityType(int nPortletIndex);
    
    /// <summary>
    /// Method GetPortletIsFromPT.
    /// Returns true if the gadget is from the page template.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>boolean</returns>
    bool GetPortletIsFromPT(int nPortletIndex);
    
    /// <summary>
    /// Method GetPortletName.
    /// Gets the gadget name for the gadget at the given index.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <returns>String</returns>
    String GetPortletName(int nPortletIndex);
    
    /// <summary>
    /// Method GetHasFreeFormPortlet.
    /// Return true if the page has a free form portlet selected.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetHasFreeFormPortlet();
    
    /// <summary>
    /// Method GetInputValue.
    /// Get the value for the given input.
    /// </summary>
    /// <param name="strName"></param>
    /// <returns>String</returns>
    String GetInputValue(String strName);
    
    /// <summary>
    /// Method IsFreeFormLayoutAllowed.
    /// Returns whether free form layouts can be selected.
    /// </summary>
    /// <returns>boolean</returns>
    bool IsFreeFormLayoutAllowed();
    
    /// <summary>
    /// Method GetClassID.
    /// Gets the class ID of the object that opened this layout page.
    /// </summary>
    /// <returns>int</returns>
    int GetClassID();
    
    /// <summary>
    /// Method GetFolderID.
    /// Gets the Folder ID of the page that opened this layout page.
    /// </summary>
    /// <returns>int</returns>
    int GetFolderID();
    
    /// <summary>
    /// Method GetObjectID.
    /// Gets the Object ID of the object that opened this layout page.
    /// </summary>
    /// <returns>int</returns>
    int GetObjectID();
    
    /// <summary>
    /// Method GetPageType.
    /// Gets the page type of the page we are editing.
    /// </summary>
    /// <returns>int</returns>
    int GetPageType();
    
    /// <summary>
    /// Method GetTableHeight.
    /// Gets the height of the drag and drop table.
    /// </summary>
    /// <returns>int</returns>
    int GetTableHeight();
    
    /// <summary>
    /// Method GetUseDragDropLayout.
    /// Gets wether to use the drag drop layout or the alternate layout based upon which browser is being used.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetUseDragDropLayout();
  }
}