using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.portletpreview;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
namespace com.plumtree.portalpages.common.editpage
{
  /// <author>MichaelD</author>
  public class PageLayoutView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.editpage.PageLayoutView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EditPageLayout";
    
    /// <summary>
    /// Form Button: Add Portlets Button Name 
    /// </summary>
    public const String HTMLBUTTON_ADDGADGETS = "in_bu_addgadgets";
    
    /// <summary>
    /// Form Button: Select Layout Button Name 
    /// </summary>
    public const String HTMLBUTTON_SELECTLAYOUT = "in_bu_selectlayout";
    
    /// <summary>
    /// Form Input: Portlet Order Prefix 
    /// </summary>
    public const String HTMLINPUT_EDITPAGE_GADGETORDER_PREFIX = "in_hi_gadgetorder";
    
    /// <summary>
    /// Form Input: Portlet Order in Column 0 
    /// </summary>
    public const String HTMLINPUT_EDITPAGE_GADGETORDER0 = "in_hi_gadgetorder0";
    
    /// <summary>
    /// Form Input: Portlet Order in Column 1 
    /// </summary>
    public const String HTMLINPUT_EDITPAGE_GADGETORDER1 = "in_hi_gadgetorder1";
    
    /// <summary>
    /// Form Input: Portlet Order in Column 2 
    /// </summary>
    public const String HTMLINPUT_EDITPAGE_GADGETORDER2 = "in_hi_gadgetorder2";
    
    /// <summary>
    /// Layout table width 
    /// </summary>
    public const int LAYOUTTABLE_WIDTH = 600;
    
    /// <summary>
    /// Layout table height 
    /// </summary>
    private const int LAYOUTTABLE_HEIGHT = 400;
    
    /// <summary>
    /// Two Column: Narrow Column Width 
    /// </summary>
    private static readonly int TWOCOLUMN_NARROWCOLUMN_WIDTH = (int) (LAYOUTTABLE_WIDTH * 0.35);
    
    /// <summary>
    /// Two Column: Wid Column Width 
    /// </summary>
    private static readonly int TWOCOLUMN_WIDECOLUMN_WIDTH = (int) (LAYOUTTABLE_WIDTH * 0.65);
    
    /// <summary>
    /// Three Column: Narrow Column Width 
    /// </summary>
    private static readonly int THREECOLUMN_NARROWCOLUMN_WIDTH = (int) (LAYOUTTABLE_WIDTH * 0.25);
    
    /// <summary>
    /// Three Column: Wide Column Width 
    /// </summary>
    private static readonly int THREECOLUMN_WIDECOLUMN_WIDTH = (int) (LAYOUTTABLE_WIDTH * 0.5);
    
    /// <summary>
    /// Narrow Portlet Width 
    /// </summary>
    private static readonly int NARROWGADGET_WIDTH = THREECOLUMN_NARROWCOLUMN_WIDTH - 8;
    
    /// <summary>
    /// Wide Portlet Width 
    /// </summary>
    private static readonly int WIDEGADGET_WIDTH = THREECOLUMN_WIDECOLUMN_WIDTH - 16;
    
    /// <summary>
    /// Portlet Height 
    /// </summary>
    private const int GADGET_HEIGHT = 72;
    
    /// <summary>
    /// Portlet Spacer 
    /// </summary>
    private const int GADGET_SPACER = 2;
    
    /// <summary>
    /// Portlet Offset 
    /// </summary>
    private static readonly int GADGET_OFFSET = GADGET_HEIGHT + GADGET_SPACER;
    
    /// <summary>
    /// Free Form Category Height 
    /// </summary>
    private const int FREEFORM_HEIGHT = 78;
    
    /// <summary>
    /// Javascript Function: previewPortlet 
    /// </summary>
    public const String JAVASCRIPT_PREVIEW_GADGET = "previewGadget";
    
    /// <summary>
    /// Layout table left 
    /// </summary>
    private int m_nLayoutTableLeft;
    
    /// <summary>
    /// Layout table top 
    /// </summary>
    private int m_nLayoutTableTop;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageLayoutView();
    }
    
    /// <summary>
    /// Adds the HTML for that section to the table passed  in argument.
    /// </summary>
    /// <returns></returns>
    public override HTMLElement Display()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      HTMLElement result = collection;
      HTMLDiv myDiv;
      HTMLLayer myLayer;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      //HTMLInput myInput;
      HTMLSpan mySpan;
      HTMLImg myImg;
      PTConstruct myConstruct;
      PTStyleClass ptstyleContentBackground;
      PTStyleClass ptstyleHeaderBackground;
      if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID == ((IPageLayoutModelRO) m_model).GetObjectID() && PT_CLASSIDS.PT_PAGETEMPLATE_ID == ((IPageLayoutModelRO) m_model).GetClassID())
      {
        return null;
      }
      try
      {
        collection.AddInnerHTMLElement(DisplayLayouts());
        // No drop image and drop target line
        myDiv = new HTMLDiv();
        myDiv.SetID("nodrop");
        myDiv.SetStyle("position:absolute; left:10; top:20; z-index:97; visibility:hidden;");
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ERROR,
         true, this.m_asOwner);
        myImg = (HTMLImg) myConstruct.GetHTMLElement();
        myImg.SetAlt(m_asOwner.GetString(36, "ptmsgs_portalcommonmsgs"));
        myImg.SetWidth("18");
        myImg.SetHeight("18");
        myDiv.AddInnerHTMLElement(myImg);
        collection.AddInnerHTMLElement(myDiv);
        HTMLScript scriptColumns = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        String sCol1Align;
        String sCol2Align;
        int nPageType = ((IPageLayoutModelRO) m_model).GetPageType();
        if ((PageTypeConstants.TWO_COLUMN_WFFC_WIDE_NARROW == nPageType) || (PageTypeConstants.TWO_COLUMN_WIDE_NARROW == nPageType) || (PageTypeConstants.TWO_COLUMN_WIDE_WFFC_NARROW == nPageType))
        {
          sCol1Align = "iGadgetWide";
          sCol2Align = "iGadgetNarrow";
        } else
        {
          sCol1Align = "iGadgetNarrow";
          sCol2Align = "iGadgetWide";
        }
        //amcd-initialize the column array.
        //insert the gadgets into columns
        //amcd-the MyPageLayout	Object.
        scriptColumns.AddInnerHTMLString("cols = new MyPageLayout(iTableLeft,iTableTop,iTableWidth,iTableHeight);\n\n" + 
        //Add columns.
        "cols.addColumn(\"left\", iCol1Left, iCol1Top, " + sCol1Align + ");\n" + "cols.addColumn(\"center\", iCol2Left, iCol2Top, " + sCol2Align + ");\n" + "cols.addColumn(\"right\",\tiCol3Left, iCol3Top, iGadgetNarrow);\n" + 
        // Add a column to use for moving gadgets from narrow-wide to wide-narrow
        "cols.addColumn(\"none\", iCol4Left, iCol4Top, iGadgetWide);\n");
        XPArrayList xparMovedPortlets = new XPArrayList(((IPageLayoutModelRO) m_model).GetPortletCount());
        bool bCheckAlignmentChange = true;
        for (int nPortletIndex = 0;nPortletIndex < ((IPageLayoutModelRO) m_model).GetPortletCount();
        nPortletIndex++)
        {
          GetPortletSettingsAndAddToLayout(collection, scriptColumns, xparMovedPortlets,
           bCheckAlignmentChange, nPortletIndex);
        }
        bCheckAlignmentChange = false;
        for (int iIndex = 0;iIndex < xparMovedPortlets.GetSize();iIndex++)
        {
          GetPortletSettingsAndAddToLayout(collection, scriptColumns, xparMovedPortlets,
           bCheckAlignmentChange, XPConvert.ToInteger(xparMovedPortlets.GetElement(iIndex)));
          }
        if (0 < xparMovedPortlets.GetSize())
        {
          scriptColumns.AddInnerHTMLString("alert(\"" + m_asOwner.GetString(700,
           "ptmsgs_portalcommonmsgs") + "\");\n");
        }
        collection.AddInnerHTMLElement(scriptColumns);
        if (((IPageLayoutModelRO) m_model).GetHasFreeFormPortlet())
        {
          int nFreeFormID = ((IPageLayoutModelRO) m_model).GetPortletID(-1);
          if (((IPageLayoutModelRO) m_model).GetPortletIsFromPT(-1))
          {
            ptstyleHeaderBackground = PTStyleClass.PLATPORTLET_MANDATORY_HEADER_BG;
            ptstyleContentBackground = PTStyleClass.PLATPORTLET_MANDATORY_BG;
            } else
          {
            ptstyleHeaderBackground = PTStyleClass.PLATPORTLET_HEADER_BG;
            ptstyleContentBackground = PTStyleClass.LIST_ITEM_TWO_BG;
          }
          myTable = new HTMLTable();
          // write free form div or layer
          BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
          if (browser.IsNetscape4())
          {
            myLayer = new HTMLLayer();
            collection.AddInnerHTMLElement(myLayer);
            myLayer.SetZIndex("96");
            myLayer.SetID("FreeForm");
            myLayer.AddInnerHTMLElement(myTable);
          } else
          {
            myDiv = new HTMLDiv();
            collection.AddInnerHTMLElement(myDiv);
            myDiv.SetStyle("position:absolute; z-index:96;");
            myDiv.SetID("FreeForm");
            myDiv.AddInnerHTMLElement(myTable);
          }
          //     myTable.SetName("ff");
          //     myTable.SetID("ff");
          myTable.SetCellPadding("1");
          myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
          myTable.SetBorder(CommonHTMLStrings.ZERO);
          myTable.SetHeight(XPConvert.ToString(GADGET_HEIGHT));
          myTable.SetWidth(XPConvert.ToString(WIDEGADGET_WIDTH));
          myTable.SetStyleClass(ptstyleContentBackground);
          // Portlet header
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("12");
          //     myCell.SetName("ff");
          //     myCell.SetID("ff");
          myCell.SetStyleClass(ptstyleHeaderBackground);
          myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myCell.SetAlign(CommonHTMLStrings.LEFT);
          myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.PLATPORTLET_WIDE_HEADER);
          mySpan.AddInnerHTMLEncodedString(GeneralHelpers.TruncateLongString(GeneralHelpers.TruncateLongString(((IPageLayoutModelRO) m_model).GetPortletName(-1),
           20, true), 40, false));
          String strFreeFormDesc = ((IPageLayoutModelRO) m_model).GetPortletDescription(-1);
          // Portlet content
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("35");
          //     myCell.SetName("ff");
          //     myCell.SetID("ff");
          myCell.SetAlign(CommonHTMLStrings.LEFT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
          if (null == strFreeFormDesc)
          {
            mySpan.AddInnerHTMLString(m_asOwner.GetString(32, "ptmsgs_portalcommonmsgs"));
            } else
          {
            mySpan.AddInnerHTMLEncodedString(GeneralHelpers.TruncateLongString(GeneralHelpers.TruncateLongString(strFreeFormDesc,
             20, true), 40, false));
          }
          // Portlet content
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("15");
          //   myCell.SetName("td");
          //   myCell.SetID("td");
          myCell.SetAlign(CommonHTMLStrings.RIGHT);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          mySpan = new HTMLSpan();
          myCell.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
          bool bShowDivider = false;
          if (!((IPageLayoutModelRO) m_model).GetPortletIsCommunityType(-1))
          {
            HTMLAnchor previewPortletAnchor = ConstructStaticHelpers.GetJavascriptAnchor(m_asOwner.GetString(47,
             "ptmsgs_portalcommonmsgs"), JAVASCRIPT_PREVIEW_GADGET + "(\'" + nFreeFormID + "\', \'" + XPConvert.ToString(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE) + "\')");
            mySpan.AddInnerHTMLElement(previewPortletAnchor);
            bShowDivider = true;
          }
          if (!((IPageLayoutModelRO) m_model).GetPortletIsFromPT(-1))
          {
            if (bShowDivider)
            {
              mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE + "|" + CommonHTMLStrings.SPACE);
              }
            HTMLAnchor deletePortletAnchor = ConstructStaticHelpers.GetJavascriptAnchor(m_asOwner.GetString(48,
             "ptmsgs_portalcommonmsgs"), PageLayoutHeaderView.JAVASCRIPT_DELETE_GADGET + "(\'" + nFreeFormID + "\')");
            mySpan.AddInnerHTMLElement(deletePortletAnchor);
          }
        }
        log.Info("PageLayoutView::Display: Succesful");
      }
      catch (Exception e)
      {
        log.Error(e, "PageLayoutView::Display: The following error occured when trying to display the HTML: " + e.Message);
        }
      return result;
    }
    private void GetPortletSettingsAndAddToLayout(HTMLElementCollection collection,
     HTMLScript scriptColumns, XPArrayList xparMovedPortlets, bool bCheckAlignmentChange,
     int nPortletIndex)
    {
      PTStyleClass ptstyleHeaderText;
      PTStyleClass ptstyleContentBackground;
      PTStyleClass ptstyleHeaderBackground;
      int nPortletWidth;
      String strPortletAlignment;
      String strIDPrefix;
      if (((IPageLayoutModelRO) m_model).GetPortletIsFromPT(nPortletIndex))
      {
        ptstyleHeaderBackground = PTStyleClass.PLATPORTLET_MANDATORY_HEADER_BG;
        ptstyleContentBackground = PTStyleClass.PLATPORTLET_MANDATORY_BG;
        } else
      if (((IPageLayoutModelRO) m_model).GetPortletAlignment(nPortletIndex) == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW)
      {
        ptstyleHeaderBackground = PTStyleClass.PLATPORTLET_HEADER_BG;
        ptstyleContentBackground = PTStyleClass.PLATPORTLET_LIGHT_BG;
      } else
      {
        ptstyleHeaderBackground = PTStyleClass.PLATPORTLET_HEADER_BG;
        ptstyleContentBackground = PTStyleClass.LIST_ITEM_TWO_BG;
      }
      if (((IPageLayoutModelRO) m_model).GetPortletAlignment(nPortletIndex) == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW)
      {
        ptstyleHeaderText = PTStyleClass.PLATPORTLET_NARROW_HEADER;
        nPortletWidth = NARROWGADGET_WIDTH;
        strPortletAlignment = "Narrow";
      } else
      {
        ptstyleHeaderText = PTStyleClass.PLATPORTLET_WIDE_HEADER;
        nPortletWidth = WIDEGADGET_WIDTH;
        strPortletAlignment = "Wide";
      }
      if (((IPageLayoutModelRO) m_model).GetPortletIsFromPT(nPortletIndex))
      {
        strIDPrefix = "PTMand_";
      } else
      {
        strIDPrefix = "Gadget_";
      }
      int nColumn = ((IPageLayoutModelRO) m_model).GetPortletColumn(nPortletIndex);
      if (bCheckAlignmentChange && PortletColumnConstants.NARROW_ONE.ToInt() == nColumn && ("Wide").Equals(strPortletAlignment) && !("PTMand_").Equals(strIDPrefix))
      {
        xparMovedPortlets.Add(nPortletIndex);
      } else
      {
        if (!bCheckAlignmentChange && PortletColumnConstants.NARROW_ONE.ToInt() == nColumn && ("Wide").Equals(strPortletAlignment))
        {
          nColumn = PortletColumnConstants.WIDE_ONE.ToInt();
        }
        AddPortletToLayout(collection, ptstyleHeaderText, ptstyleContentBackground,
         ptstyleHeaderBackground, nPortletWidth, strPortletAlignment, strIDPrefix,
         scriptColumns, nPortletIndex, nColumn);
      }
    }
    private void AddPortletToLayout(HTMLElementCollection collection, StyleClass ptstyleHeaderText,
     StyleClass ptstyleContentBackground, StyleClass ptstyleHeaderBackground,
     int nPortletWidth, String strPortletAlignment, String strIDPrefix, HTMLScript scriptColumns,
     int nPortletIndex, int nColumn)
    {
      HTMLDiv myDiv;
      HTMLLayer myLayer;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      // if the page is wide then narrow, for the change layout javascript we need to add the
      // gadget to the opposite column.
      if ((PageTypeConstants.TWO_COLUMN_WFFC_WIDE_NARROW == ((IPageLayoutModelRO) m_model).GetPageType()) || (PageTypeConstants.TWO_COLUMN_WIDE_NARROW == ((IPageLayoutModelRO) m_model).GetPageType()) || (PageTypeConstants.TWO_COLUMN_WIDE_WFFC_NARROW == ((IPageLayoutModelRO) m_model).GetPageType()))
      {
        if (PortletColumnConstants.NARROW_ONE.ToInt() == nColumn)
        {
          nColumn = PortletColumnConstants.WIDE_ONE.ToInt();
        } else
        {
          nColumn = PortletColumnConstants.NARROW_ONE.ToInt();
        }
      }
      // Add gadget to column in javascript
      scriptColumns.AddInnerHTMLString("cols.arrCols[" + nColumn + "].addGadget(\"" + XPHttpUtility.HtmlEncode(((IPageLayoutModelRO) m_model).GetPortletName(nPortletIndex)) + "\", iGadget" + strPortletAlignment + ", " + ((IPageLayoutModelRO) m_model).GetPortletID(nPortletIndex) + ");\n");
      if (((IPageLayoutModelRO) m_model).GetPortletIsFromPT(nPortletIndex))
      {
        scriptColumns.AddInnerHTMLString("cols.arrCols[" + nColumn + "].incrementMandatoryIndex();\n");
        }
      myTable = new HTMLTable();
      // write gadget div or layer
      BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      if (browser.IsNetscape4())
      {
        myLayer = new HTMLLayer();
        collection.AddInnerHTMLElement(myLayer);
        myLayer.SetZIndex("96");
        myLayer.SetID(strIDPrefix + ((IPageLayoutModelRO) m_model).GetPortletID(nPortletIndex));
        myLayer.AddInnerHTMLElement(myTable);
      } else
      {
        myDiv = new HTMLDiv();
        collection.AddInnerHTMLElement(myDiv);
        myDiv.SetStyle("position:absolute; z-index:96;");
        myDiv.SetOnMouseOver("selecthighlight()");
        myDiv.SetOnMouseOut("losehighlight()");
        myDiv.SetID(strIDPrefix + ((IPageLayoutModelRO) m_model).GetPortletID(nPortletIndex));
        myDiv.AddInnerHTMLElement(myTable);
      }
      myTable.SetName("td");
      myTable.SetID("td");
      myTable.SetCellPadding("1");
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetHeight(XPConvert.ToString(GADGET_HEIGHT));
      myTable.SetWidth(XPConvert.ToString(nPortletWidth));
      myTable.SetStyleClass(ptstyleContentBackground);
      // Portlet header
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("12");
      myCell.SetName("td");
      myCell.SetID("td");
      myCell.SetStyleClass(ptstyleHeaderBackground);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetAlign(CommonHTMLStrings.LEFT);
      myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(ptstyleHeaderText);
      mySpan.AddInnerHTMLEncodedString(GeneralHelpers.TruncateLongString(GeneralHelpers.TruncateLongString(((IPageLayoutModelRO) m_model).GetPortletName(nPortletIndex),
       20, true), 40, false));
      // Portlet content
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("35");
      myCell.SetName("td");
      myCell.SetID("td");
      myCell.SetAlign(CommonHTMLStrings.LEFT);
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
      if (null == ((IPageLayoutModelRO) m_model).GetPortletDescription(nPortletIndex) || "".Equals(((IPageLayoutModelRO) m_model).GetPortletDescription(nPortletIndex)))
      {
        mySpan.AddInnerHTMLString(m_asOwner.GetString(32, "ptmsgs_portalcommonmsgs"));
        } else
      {
        mySpan.AddInnerHTMLEncodedString(GeneralHelpers.TruncateLongString(GeneralHelpers.TruncateLongString(((IPageLayoutModelRO) m_model).GetPortletDescription(nPortletIndex),
         20, true), 40, false));
      }
      // Portlet content
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("15");
      myCell.SetName("td");
      myCell.SetID("td");
      myCell.SetAlign(CommonHTMLStrings.RIGHT);
      myCell.SetVAlign(CommonHTMLStrings.TOP);
      mySpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
      bool bShowDivider = false;
      if (!((IPageLayoutModelRO) m_model).GetPortletIsCommunityType(nPortletIndex))
      {
        HTMLAnchor previewPortletAnchor = ConstructStaticHelpers.GetJavascriptAnchor(m_asOwner.GetString(47,
         "ptmsgs_portalcommonmsgs"), JAVASCRIPT_PREVIEW_GADGET + "(\'" + ((IPageLayoutModelRO) m_model).GetPortletID(nPortletIndex) + "\', \'" + XPConvert.ToString(((IPageLayoutModelRO) m_model).GetPortletAlignment(nPortletIndex)) + "\')");
        mySpan.AddInnerHTMLElement(previewPortletAnchor);
        bShowDivider = true;
      }
      if (!((IPageLayoutModelRO) m_model).GetPortletIsFromPT(nPortletIndex))
      {
        if (bShowDivider)
        {
          mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE + "|" + CommonHTMLStrings.SPACE);
          }
        HTMLAnchor deletePortletAnchor = ConstructStaticHelpers.GetJavascriptAnchor(m_asOwner.GetString(48,
         "ptmsgs_portalcommonmsgs"), PageLayoutHeaderView.JAVASCRIPT_DELETE_GADGET + "(\'" + ((IPageLayoutModelRO) m_model).GetPortletID(nPortletIndex) + "\')");
        mySpan.AddInnerHTMLElement(deletePortletAnchor);
      }
    }
    
    /// <summary>
    /// Display the javascript functions that are needed in this view.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    public virtual HTMLScriptCollection DisplayJavascriptCollection()
    {
      HTMLScriptCollection result = new HTMLScriptCollection();
      XPStringBuilder sb;
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sbScript;
      try
      {
        result.AddInnerHTMLElement(script);
        sbScript = new XPStringBuilder(400);
        sbScript.Append("\n// Form Elements\n").Append("var strFormName = \"").Append(AFormDP.HTMLFORM_NAME).Append("\";\n").Append("var strPageLayoutTypeElementName =  \"").Append(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE).Append("\";\n").Append("var strGadgetOrderColumnZeroName = \"").Append(HTMLINPUT_EDITPAGE_GADGETORDER0).Append("\";\n").Append("var strGadgetOrderColumnOneName = \"").Append(HTMLINPUT_EDITPAGE_GADGETORDER1).Append("\";\n").Append("var strGadgetOrderColumnTwoName = \"").Append(HTMLINPUT_EDITPAGE_GADGETORDER2).Append("\";\n\n").Append("// *** Client side global vars\n");
        // ROB: If we use adaptive layout, then make the javascript treat it as a regular 3 column layout since we 
        // just want to display 3 columns for the 3 regions
        int pageType = ((IPageLayoutModelRO) m_model).GetPageType();
        //if ( pageType < 0) { pageType = PageTypeConstants.THREE_COLUMN; }
        sbScript.Append("var intPageType\t\t= ").Append(pageType).Append(";\n").Append("var iTableWidth\t\t= ").Append(LAYOUTTABLE_WIDTH).Append(";\n").Append("var iTableHeight\t= ").Append(LAYOUTTABLE_HEIGHT).Append(";\n").Append("var iTableTop\t\t= ").Append(m_nLayoutTableTop).Append(";\n").Append("var iWideGadgetWidth\t= ").Append(WIDEGADGET_WIDTH).Append(";\n").Append("var iNarrowGadgetWidth\t= ").Append(NARROWGADGET_WIDTH).Append(";\n").Append("var iGadgetOffset \t= ").Append(XPConvert.ToBoolean(m_asOwner.GetSubSession().GetAttribute("ISIE")) ? GADGET_OFFSET : (GADGET_OFFSET + 1)).Append(";\n");
        sbScript.Append("function getLayoutTableLeft()\n").Append("{\n").Append("\treturn ").Append(m_nLayoutTableLeft).Append(";\n").Append("}\n\n");
        sbScript.Append("function getFreeFormHeight()\n").Append("{\n").Append("\treturn ").Append(FREEFORM_HEIGHT).Append(";\n").Append("}\n\n");
        sbScript.Append("function getNarrowColumnWidth()\n").Append("{\n").Append("\tif (COLUMNCOUNT_ONE == intColumnCount)\n").Append("\t{\n").Append("\t\treturn 0;\n").Append("\t}\n").Append("\telse if (COLUMNCOUNT_TWO_NW == intColumnCount || ").Append("COLUMNCOUNT_TWO_WN == intColumnCount)\n").Append("\t{\n").Append("\t\treturn ").Append(TWOCOLUMN_NARROWCOLUMN_WIDTH).Append(";\n").Append("\t}\n").Append("\telse if (COLUMNCOUNT_THREE == intColumnCount)\n").Append("\t{\n").Append("\t\treturn ").Append(THREECOLUMN_NARROWCOLUMN_WIDTH).Append(";\n").Append("\t}\n").Append("\telse\n").Append("\t\treturn 0;\n").Append("}\n\n");
        sbScript.Append("function getWideColumnWidth()\n").Append("{\n").Append("\tif (COLUMNCOUNT_ONE == intColumnCount)\n").Append("\t{\n").Append("\t\treturn ").Append(LAYOUTTABLE_WIDTH).Append(";\n").Append("\t}\n").Append("\telse if (COLUMNCOUNT_TWO_NW == intColumnCount || ").Append("COLUMNCOUNT_TWO_WN == intColumnCount)\n").Append("\t{\n").Append("\t\treturn ").Append(TWOCOLUMN_WIDECOLUMN_WIDTH).Append(";\n").Append("\t}\n").Append("\telse if (COLUMNCOUNT_THREE == intColumnCount)\n").Append("\t{\n").Append("\t\treturn ").Append(THREECOLUMN_WIDECOLUMN_WIDTH).Append(";\n").Append("\t}\n").Append("\telse\n").Append("\t\treturn ").Append(LAYOUTTABLE_WIDTH).Append(";\n").Append("}\n\n");
        sbScript.Append("function hasFreeFormPortlet()\n").Append("{\n");
        if (((IPageLayoutModelRO) m_model).GetHasFreeFormPortlet())
        {
          sbScript.Append("\treturn true;\n");
        } else
        {
          sbScript.Append("\treturn false;\n");
        }
        sbScript.Append("}\n");
        script.AddInnerHTMLString(sbScript.ToString());
        ASURL asurl = new ASURL(m_asOwner);
        asurl.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME, m_asOwner);
        asurl.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
        asurl.SetDisplayPage(PreviewPortletDP.STR_MVC_CLASS_NAME);
        asurl.AddControlArgument(PreviewPortletControl.m_PreviewType, PreviewPortletModel.PREVIEWHEADER);
        try
        {
          sb = new XPStringBuilder(200);
          sb.Append("\n").Append("function ").Append(JAVASCRIPT_PREVIEW_GADGET).Append("(gadgetID, gadgetAlign)\n").Append("{\n").Append("\t\tvar url = \'").Append(asurl.GetURLAsString()).Append("&").Append(PreviewPortletControl.m_strPortletParam).Append("=\' + gadgetID;\n").Append("\t\tif ( ").Append(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW).Append(" == gadgetAlign )\n").Append("\t\t{\n").Append("\t\t\tOpenNarrowGadgetPreviewWindow(url);\n").Append("\t\t}\n").Append("\t\telse\n").Append("\t\t{\n").Append("\t\t\tOpenWideGadgetPreviewWindow(url);\n").Append("\t\t}\n").Append("}\n");
          script.AddInnerHTMLString(sb.ToString());
        }
        catch (HTMLException he)
        {
          log.Error("DisplayJavascriptCollection: Failed to add javascript function " + JAVASCRIPT_PREVIEW_GADGET + " to javscript collection. " + he.Message);
          }
        String strPathToJSFiles = ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner);
        script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        result.AddInnerHTMLElement(script);
        script.SetSrc(strPathToJSFiles + "dragdropchangelayout.js");
        script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        result.AddInnerHTMLElement(script);
        script.SetSrc(strPathToJSFiles + "opennewwindow.js");
      }
      catch (HTMLException e)
      {
      }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Method SetLayoutTablePosition.
    /// Set the position of the layout table's top pixel and left pixel.
    /// </summary>
    /// <param name="nTop"></param>
    /// <param name="nLeft"></param>
    public virtual void SetLayoutTablePosition(int nTop, int nLeft)
    {
      m_nLayoutTableTop = nTop;
      m_nLayoutTableLeft = nLeft;
    }
    
    /// <summary>
    /// Display a layout div with the given id.
    /// </summary>
    private HTMLDiv DisplayLayoutDiv(int nDivID)
    {
      HTMLDiv myDiv = new HTMLDiv();
      try
      {
        myDiv.SetID("layouttable" + XPConvert.ToString(nDivID));
        myDiv.SetStyle("position:absolute; z-index:1; visibility:hidden;");
        }
      catch (HTMLException he)
      {
        log.Error("DisplayLayoutDiv: Failed to display layout div with id lt" + nDivID + ": " + he.Message);
        }
      return myDiv;
    }
    
    /// <summary>
    /// Display a layout table with the given id.
    /// </summary>
    private HTMLTable DisplayLayoutTable(int nTableID)
    {
      HTMLTable myTable = new HTMLTable();
      try
      {
        myTable.SetID("lt" + XPConvert.ToString(nTableID));
        myTable.SetCellPadding(CommonHTMLStrings.ZERO);
        myTable.SetCellSpacing("2");
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(XPConvert.ToString(LAYOUTTABLE_WIDTH));
        myTable.SetHeight(XPConvert.ToString(((IPageLayoutModelRO) m_model).GetTableHeight()));
        }
      catch (HTMLException he)
      {
        log.Error("DisplayLayoutTable: Failed to display layout table with id lt" + nTableID + ": " + he.Message);
        }
      return myTable;
    }
    
    /// <summary>
    /// Display all layout divs.
    /// </summary>
    private HTMLElement DisplayLayouts()
    {
      HTMLElementCollection collection = new HTMLElementCollection();
      HTMLElement result = collection;
      HTMLDiv myDiv;
      HTMLTable myTable;
      HTMLTableRow myRow;
      try
      {
        // Change Layout Drag and Drop section
        // Table background 1 Column
        myDiv = DisplayLayoutDiv(0);
        myTable = DisplayLayoutTable(0);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(LAYOUTTABLE_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 2 Column
        myDiv = DisplayLayoutDiv(1);
        myTable = DisplayLayoutTable(1);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_WIDECOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 3 Column
        myDiv = DisplayLayoutDiv(2);
        myTable = DisplayLayoutTable(2);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_WIDECOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 2 Column Narrow on right
        myDiv = DisplayLayoutDiv(3);
        myTable = DisplayLayoutTable(3);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_WIDECOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 1 Column with free form section
        myDiv = DisplayLayoutDiv(4);
        myTable = DisplayLayoutTable(4);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(LAYOUTTABLE_WIDTH,
         XPConvert.ToString(FREEFORM_HEIGHT), 1, true));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(LAYOUTTABLE_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 2 Column with free form section
        myDiv = DisplayLayoutDiv(5);
        myTable = DisplayLayoutTable(5);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(LAYOUTTABLE_WIDTH,
         XPConvert.ToString(FREEFORM_HEIGHT), 2, true));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_WIDECOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 3 Column with free form section
        myDiv = DisplayLayoutDiv(6);
        myTable = DisplayLayoutTable(6);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(LAYOUTTABLE_WIDTH,
         XPConvert.ToString(FREEFORM_HEIGHT), 3, true));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_WIDECOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 2 Column Narrow on right with free form section
        myDiv = DisplayLayoutDiv(7);
        myTable = DisplayLayoutTable(7);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(LAYOUTTABLE_WIDTH,
         XPConvert.ToString(FREEFORM_HEIGHT), 2, true));
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_WIDECOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 2 Column with free form section in wide col only
        myDiv = DisplayLayoutDiv(8);
        myTable = DisplayLayoutTable(8);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayWideColumnWithFreeForm(TWOCOLUMN_WIDECOLUMN_WIDTH));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 3 Column with free form section wide narrow has it
        myDiv = DisplayLayoutDiv(9);
        myTable = DisplayLayoutTable(9);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayTwoColsWithFreeForm(9));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 3 Column with free form section narrow wide has it
        myDiv = DisplayLayoutDiv(10);
        myTable = DisplayLayoutTable(10);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayTwoColsWithFreeForm(10));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 2 Column Narrow on right with free form section only in wide
        myDiv = DisplayLayoutDiv(11);
        myTable = DisplayLayoutTable(11);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayWideColumnWithFreeForm(TWOCOLUMN_WIDECOLUMN_WIDTH));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(TWOCOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
        // Table background 3 Column with free form section
        myDiv = DisplayLayoutDiv(12);
        myTable = DisplayLayoutTable(12);
        myDiv.AddInnerHTMLElement(myTable);
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        myRow.AddInnerHTMLElement(DisplayWideColumnWithFreeForm(THREECOLUMN_WIDECOLUMN_WIDTH));
        myRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
        collection.AddInnerHTMLElement(myDiv);
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayLayouts: Failed to display the layouts. " + he.Message);
        log.Error(he.ToString());
      }
      return result;
    }
    
    /// <summary>
    /// Display a column of the given width.
    /// </summary>
    private HTMLTableCell DisplayPortletColumn(int nWidth, String strHeight,
     int nColSpan, bool bIsContentCanvas)
    {
      HTMLTableCell myCell = new HTMLTableCell();
      try
      {
        myCell.SetHeight(strHeight);
        if (bIsContentCanvas)
        {
          myCell.SetStyleClass(PTStyleClass.PAGELAYOUT_CONTENT_BG);
        } else
        {
          myCell.SetStyleClass(PTStyleClass.PAGELAYOUT_COLUMN_BG);
        }
        myCell.SetWidth(XPConvert.ToString(nWidth));
        myCell.SetAlign(CommonHTMLStrings.LEFT);
        myCell.SetVAlign(CommonHTMLStrings.TOP);
        myCell.SetNoWrap(true);
        myCell.SetColSpan(XPConvert.ToString(nColSpan));
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      catch (HTMLException he)
      {
        log.Error("DisplayPortletColumn: Failed to display gadget column with width " + nWidth + ": " + he.Message);
        }
      return myCell;
    }
    
    /// <param name="nColType"></param>
    /// <returns></returns>
    private HTMLTableCell DisplayTwoColsWithFreeForm(int nColType)
    {
      int nWidthCol1;
      int nWidthCol2;
      if (9 == nColType)
      {
        nWidthCol1 = THREECOLUMN_WIDECOLUMN_WIDTH;
        nWidthCol2 = THREECOLUMN_NARROWCOLUMN_WIDTH;
      } else
      {
        nWidthCol1 = THREECOLUMN_NARROWCOLUMN_WIDTH;
        nWidthCol2 = THREECOLUMN_WIDECOLUMN_WIDTH;
      }
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetHeight(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLTable myInnerTable = new HTMLTable();
      myInnerTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myInnerTable.SetCellSpacing("2");
      myInnerTable.SetBorder(CommonHTMLStrings.ZERO);
      myInnerTable.SetWidth(XPConvert.ToString(THREECOLUMN_NARROWCOLUMN_WIDTH + THREECOLUMN_WIDECOLUMN_WIDTH));
      myInnerTable.SetHeight(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      try
      {
        myCell.AddInnerHTMLElement(myInnerTable);
        HTMLTableRow myInnerRow = new HTMLTableRow();
        myInnerTable.AddInnerHTMLElement(myInnerRow);
        myInnerRow.AddInnerHTMLElement(DisplayPortletColumn(THREECOLUMN_NARROWCOLUMN_WIDTH + THREECOLUMN_WIDECOLUMN_WIDTH,
         XPConvert.ToString(FREEFORM_HEIGHT), 2, true));
        myInnerRow = new HTMLTableRow();
        myInnerTable.AddInnerHTMLElement(myInnerRow);
        myInnerRow.AddInnerHTMLElement(DisplayPortletColumn(nWidthCol1, CommonHTMLStrings.ONE_HUNDRED_PERCENT,
         1, false));
        myInnerRow.AddInnerHTMLElement(DisplayPortletColumn(nWidthCol2, CommonHTMLStrings.ONE_HUNDRED_PERCENT,
         1, false));
      }
      catch (HTMLException he)
      {
        log.Error("DisplayTwoColsWithFreeForm: Failed to display two gadget columns with free form section of page type " + nColType + ": " + he.Message);
        }
      return myCell;
    }
    
    /// <param name="nWideColWidth"></param>
    /// <returns></returns>
    private HTMLTableCell DisplayWideColumnWithFreeForm(int nWideColWidth)
    {
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetHeight(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLTable myInnerTable = new HTMLTable();
      myInnerTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myInnerTable.SetCellSpacing("2");
      myInnerTable.SetBorder(CommonHTMLStrings.ZERO);
      myInnerTable.SetWidth(XPConvert.ToString(nWideColWidth));
      myInnerTable.SetHeight(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      try
      {
        myCell.AddInnerHTMLElement(myInnerTable);
        HTMLTableRow myInnerRow = new HTMLTableRow();
        myInnerTable.AddInnerHTMLElement(myInnerRow);
        myInnerRow.AddInnerHTMLElement(DisplayPortletColumn(nWideColWidth,
         XPConvert.ToString(FREEFORM_HEIGHT), 1, true));
        myInnerRow = new HTMLTableRow();
        myInnerTable.AddInnerHTMLElement(myInnerRow);
        myInnerRow.AddInnerHTMLElement(DisplayPortletColumn(nWideColWidth,
         CommonHTMLStrings.ONE_HUNDRED_PERCENT, 1, false));
      }
      catch (HTMLException he)
      {
        log.Error("DisplayWideColumnWithFreeForm: Failed to display wide gadget column with free form section with width " + nWideColWidth + ": " + he.Message);
        }
      return myCell;
    }
  }
}