using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.common.editpage
{
  /// <summary>
  /// This Model contains the state of the page name plug-in section.
  /// </summary>
  /// <author>MichaelD</author>
  public class PageNamePlugInModel : EditorHelperModel,IPageNameModelRO
  {
    // ***CHANGE_HERE*** Change the name of the class.
    // ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
    // when you are done.
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.editpage.PageNamePlugInModel");
    public const String STR_MVC_CLASS_NAME = "PageNamePlugIn";
    
    /// <summary>
    /// Name Label 
    /// </summary>
    private String m_strNameLabel = "";
    
    /// <summary>
    /// Page Name 
    /// </summary>
    private String m_strPageName = "";
    
    /// <summary>
    /// Opener Object ID : Only used by page template editor. 
    /// </summary>
    private int m_nOpenerObjectID;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageNamePlugInModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageNameModelRO#GetNameLabel()"></seealso>
    public virtual String GetNameLabel()
    {
      return m_strNameLabel;
    }
    // BEGIN ***************** helper methods ***************** 
    
    /// <seealso cref="com.plumtree.portalpages.common.editpage.IPageNameModelRO#GetOpenerObjectID()"></seealso>
    public virtual int GetOpenerObjectID()
    {
      return m_nOpenerObjectID;
    }
    
    /// <summary>
    /// Returns the value of the page name.
    /// </summary>
    /// <returns>String strPageName</returns>
    public virtual String GetPageName()
    {
      return (m_strPageName);
    }
    // END ***************** helper methods ***************** 
    
    /// <summary>
    /// To initialize this plug-in you need to set the DP name
    /// and the default value of the plug-in setting.
    /// </summary>
    /// <param name="_dpName">This is the name of the DP that will display SamplePlugInView.</param>
    /// <param name="String">_strPageName</param>
    public virtual void InitializePlugIn(String _strPageName, String _strNameLabel,
     int _nOpenerObjectID)
    {
      m_strPageName = _strPageName;
      m_strNameLabel = _strNameLabel;
      m_nOpenerObjectID = _nOpenerObjectID;
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      String[] data;
      data = (String[]) _htFormData.GetElement(PageNameView.HTMLINPUT_EDITPAGE_PAGENAME);
      // Set page name
      if ((null != data) && !(0 == data.Length))
      {
        if (IsValidPageName(data[0]))
        {
          SetPageName(data[0]);
        } else
        {
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           m_asOwner.GetString(527, "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(528,
           "ptmsgs_portalcommonmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          return RepostControl.PAGE_STATUS_INVALID;
        }
      } else
      {
        log.Warn("PageNamePlugInModel::SaveSection page name parameter was not in Query String.");
        }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Method IsValidPageName.
    /// Checks to see if the page name is valid.
    /// </summary>
    /// <param name="_strPageName"></param>
    /// <returns>boolean</returns>
    public virtual bool IsValidPageName(String _strPageName)
    {
      if (("").Equals(_strPageName))
      {
        return false;
      }
      for (int i = 0;i < _strPageName.Length;++i)
      {
        // && (_strPageName.charCodeAt(i) == 9))
        if (!(XPConvert.ToString(XPStringUtility.CharAt(_strPageName, i))).Equals(" "))
        {
          return true;
        }
      }
      return false;
    }
    
    /// <summary>
    /// Sets the value of the page name.
    /// </summary>
    /// <param name="String">_strPageName</param>
    public virtual void SetPageName(String _strPageName)
    {
      m_strPageName = _strPageName;
      log.Debug("PageNamePlugInModel::SetPageName New page name value: " + _strPageName);
      }
  }
}