using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.editpage
{
  /// <author>michaeld</author>
  public class PageNameView : EditorView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.editpage.PageNameView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "PageName";
    
    /// <summary>
    /// Form Input: Page Name 
    /// </summary>
    public const String HTMLINPUT_EDITPAGE_PAGENAME = "in_tx_PageName";
    
    /// <summary>
    /// Javascript Function: Validate Page Name 
    /// </summary>
    public const String JS_VALIDATE_PAGENAME_FUNC = "validatePageName";
    
    /// <summary>
    /// Size of Page Name field 
    /// </summary>
    public const int N_PAGE_NAME_INPUT_SIZE = 50;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new PageNameView();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorView#Display()"></seealso>
    public override HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(50,
         "ptmsgs_portalcommonmsgs")));
        //result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        myTable = new HTMLTable();
        result.AddInnerHTMLElement(myTable);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetCellPadding("5");
        myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        // 2nd row begins
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_EDITPAGE_PAGENAME,
         ((IPageNameModelRO) m_model).GetNameLabel());
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(((IPageNameModelRO) m_model).GetPageName());
        myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
        myInput.SetMaxLength(PT_SERVERCONSTANTS.PT_MAX_NAMELENGTH);
        myInput.SetSize(N_PAGE_NAME_INPUT_SIZE);
        if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
        {
          myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
          }
        // 2nd row ends
        log.Info("PageNameView::Display: Succesful");
      }
      catch (Exception e)
      {
        log.Error(e, "PageNameView::Display: The following error occured when trying to display the HTML: " + e.Message);
        }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScriptCollection DisplayJavascriptCollection()
    {
      HTMLScriptCollection myScriptCollection = new HTMLScriptCollection();
      try
      {
        HTMLScript myScript = base.DisplayJavascript();
        if (null != myScript)
        {
          myScriptCollection.AddInnerHTMLElement(myScript);
        }
        myScript = PlumtreeHelpers.GetExecuteViaEnterJScript(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
        myScriptCollection.AddInnerHTMLElement(myScript);
      }
      catch (HTMLException he)
      {
        log.Error(he, "PageNameView::DisplayJavascript: The following error occured when trying to display the javascript: " + he.Message);
        }
      String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n").Append("function ").Append(JS_VALIDATE_PAGENAME_FUNC).Append("()\n").Append("{\n").Append("\tif (document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_EDITPAGE_PAGENAME + ")\n").Append("\t\tif (" + strJSUtilVersionPrefix + "PTStringUtil.isAllWhitespace(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_EDITPAGE_PAGENAME).Append(".value))\n").Append("\t\t{\n").Append("\t\t\talert(\"").Append(m_asOwner.GetString(529,
       "ptmsgs_portalcommonmsgs")).Append("\");\n").Append("\t\t\treturn false;\n").Append("\t\t}\n").Append("\treturn true;\n").Append("}\n");
      try
      {
        HTMLScript myScript = base.DisplayJavascript();
        if (null != myScript)
        {
          myScriptCollection.AddInnerHTMLElement(myScript);
        }
        myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        myScript.AddInnerHTMLString(sb.ToString());
        myScriptCollection.AddInnerHTMLElement(myScript);
      }
      catch (HTMLException he)
      {
        log.Error(he, "PageNameView::DisplayJavascript: The following error occured when trying to display the javascript: " + he.Message);
        }
      return myScriptCollection;
    }
  }
}