using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server.portalpagesperf;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.error
{
  /// <summary>
  /// Core error display page
  /// </summary>
  /// <author>BenG</author>
  public class ErrorDP : PlumtreeDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.error.ErrorDP");
    public const String STR_MVC_CLASS_NAME = "ErrorDP";
    
    /// <summary>
    /// for performance 
    /// </summary>
    private const String EMPTY_STRING = "";
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()"></seealso>
    public override String GetSubtitleForBanner()
    {
      return EMPTY_STRING;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()"></seealso>
    public override String GetTitleForBanner()
    {
      return m_asOwner.GetString(51, "ptmsgs_portalcommonmsgs");
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection myCollection = new HTMLElementCollection();
      // Increment the performance counters for errors	
      PerfCounters.INSTANCE.IncrementCounter(PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_ERRORS);
      try
      {
        HTMLElement element = DisplayLayout(Layouts.ERROR_PAGE);
        if (null != element)
        {
          return element;
        }
        myCollection.AddInnerHTMLElement(m_asOwner.GetView(SinglePageErrorView.STR_MVC_CLASS_NAME).Display());
        }
      catch (HTMLException he)
      {
        log.Error(he, "Unable to display error view.");
      }
      return myCollection;
    }
    protected override HTMLElement DisplayLayout(Layouts layout)
    {
      // Override the base version of this method so that we can add
      // additional error handling.
      try
      {
        return base.DisplayLayout(layout);
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to display error page using layout.  Trying standard error page.");
        return null;
      }
    }
  }
}