using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.folder
{
  /// <author>Don Hayler</author>
  public class BreadcrumbView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.folder.BreadcrumbView");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "Breadcrumb";
    
    /// <summary>
    /// Javascript function: openFolder 
    /// </summary>
    public const String JAVASCRIPT_OPEN_FOLDER = "openFolder";
    protected AActivitySpace m_asOwner;
    
    /// <summary>
    /// MVC objects 
    /// </summary>
    protected IFolderModelRO m_asModel;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new BreadcrumbView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      //Display the Breadcrumb path, flush left to the margin
      HTMLElementCollection myGroup = new HTMLElementCollection();
      HTMLElement result = myGroup;
      try
      {
        // add spacer gif
        // This image is used to center the bread crumb view top to bottom.
        PTConstruct myConstruct = ConstructFactory.GetConstruct(PTImageType.SPACER);
        HTMLImg mySpacer = (HTMLImg) myConstruct.GetHTMLElement();
        mySpacer.SetHeight("25");
        mySpacer.SetWidth("1");
        mySpacer.SetAlign(CommonHTMLStrings.MIDDLE);
        myGroup.AddInnerHTMLElement(mySpacer);
        // Bread crumb path
        myGroup.AddInnerHTMLElement(GetBreadcrumbPath().GetPathAsHTMLElement());
        }
      catch (Exception e)
      {
        log.Error(e, "Error creating " + STR_MVC_CLASS_NAME + " Section.");
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      ASURL asOpenSubFolderURL = new ASURL(m_asOwner);
      asOpenSubFolderURL.SetLinkGetCachedSpace(m_asOwner);
      asOpenSubFolderURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n").Append("function ").Append(JAVASCRIPT_OPEN_FOLDER).Append("(folderID)\n").Append("{\n").Append("\t\twindow.location(\'").Append(asOpenSubFolderURL.GetURLAsString()).Append("&").Append(OpenSubFolderControl.m_SubFolderID).Append("=\' + folderID);\n").Append("}\n");
      try
      {
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error("DisplayJavascript: Failed to add \'openFolder\' javascript function to page. " + he);
        }
      return script;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#getName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IFolderModelRO) model;
      m_asOwner = parent;
    }
    
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected virtual PTBreadcrumbPath GetBreadcrumbPath()
    {
      PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();
      XPStringTokenizer stPath = new XPStringTokenizer(m_asModel.GetPath(),
       "\\");
      Object[] oIDs = m_asModel.GetParentFolderIDs();
      // In the case of the root folder, there will be two oIDs even though there
      // is only one folder in stPath.  Otherwise there will be an equal number of
      // IDs and folder names.		
      if (oIDs.Length < stPath.GetTokenCount())
      {
        log.Error("There are more parent names (" + stPath.GetTokenCount() + "than ids (" + oIDs.Length + ").");
        return myCrumbs;
      }
      HTMLAnchor myAnchor;
      int i = 0;
      int end = stPath.GetTokenCount();
      while (stPath.HasMoreTokens())
      {
        if (i < (end - 1))
        {
          myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
          myAnchor.SetOnClick(JAVASCRIPT_OPEN_FOLDER + "(\'" + XPConvert.ToString(oIDs[i++]) + "\'); return false;");
          myAnchor.AddInnerHTMLString(stPath.GetNextToken());
          myCrumbs.appendAnchorItem(myAnchor);
        } else
        {
          myCrumbs.appendTextItem(stPath.GetNextToken());
          // Probably not necessary -- should break out of loop after this.
          i++;
        }
      }
      return myCrumbs;
    }
  }
}