using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.folder
{
  /// <author>
  /// RupaP
  /// DisplayFolder writes out one folder to the given table cell and
  /// returns a reference to the next folder in the query result to
  /// display.
  /// In this implementation, folders of all levels will be displayed.
  /// The reference is incremented by 1 until the last folder in the
  /// query result has been displayed.
  /// </author>
  public class FolderViewHelper : IFolderViewHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.folder.FolderViewHelper");
    // Query parameter name for the checkbox
    public const String QS_CHECKBOX = "in_cb_checkbox";
    private String m_strControlName = null;
    
    /// <seealso cref="com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayObject(int,HTMLTableCell,IFolderModelRO)"></seealso>
    public virtual int DisplayFolder(int nFolderQueryIndex, HTMLTableCell tableCell,
     IFolderModelRO model, AActivitySpace space)
    {
      try
      {
        // get the folder query
        IASQueryResult qrFolders = model.GetFolderQueryResult();
        int nIndex = nFolderQueryIndex;
        // get name, folder ID, and folder URL from query
        String strName = (String) qrFolders.GetFields(nIndex, PT_PROPIDS.PT_PROPID_NAME);
        int nFolderID = XPConvert.ToInteger(qrFolders.GetFields(nIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
        String strFolderID = XPConvert.ToString(nFolderID);
        // Open folder URL
        ASURL url = new ASURL(space);
        url.SetLinkGetCachedSpace(space);
        if (null == m_strControlName)
        {
          url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
        } else
        {
          url.SetControl(m_strControlName);
        }
        url.AddControlArgument(OpenSubFolderControl.m_SubFolderID, strFolderID);
        String strURL = url.GetURLAsString();
        // use list item construct
        UIListItem itemConstruct = new UIListItem(strName, strURL, space);
        itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_OPEN, "folder");
        itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
        // check if there's a checkbox item
        if (model.GetShowCheckbox())
        {
          itemConstruct.EnableCheckbox(QS_CHECKBOX + strFolderID, strURL,
           
          //to do: specify value
          strFolderID, model.GetIsFolderSelected(nFolderID));
        }
        // convert the construct to table
        try
        {
          HTMLTable folderTable = itemConstruct.GetItemAsTable();
          tableCell.AddInnerHTMLElement(folderTable);
        }
        catch (Exception e)
        {
          log.Error(e, "Error in FolderViewHelper::Display: ");
        }
        nFolderQueryIndex++;
      }
      catch (Exception e)
      {
        log.Error("Couldn\'t retrieve folder at " + nFolderQueryIndex);
      }
      return nFolderQueryIndex;
    }
    
    /// <param name="strControlName"></param>
    public virtual void SetControlName(String strControlName)
    {
      m_strControlName = strControlName;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int)
     */
     
    public virtual void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID,
     IFolderModelRO _model, AActivitySpace _space)
    {
      ASURL url = new ASURL(_space);
      url.SetLinkGetCachedSpace(_space);
      if (null == m_strControlName)
      {
        url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
      } else
      {
        url.SetControl(m_strControlName);
      }
      url.AddControlArgument(OpenSubFolderControl.m_SubFolderID, _nFolderID);
      _anchor.SetHRef(url.GetURLAsString());
    }
  }
}