using System;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.common.folder
{
  /// <author>Don Hayler, RupaP</author>
  public interface IFolderModelRO : IModelRO
  {
    
    /// <summary>
    /// Get the id of the current folder.
    /// </summary>
    int GetCurrentFolderID();
    
    /// <summary>
    /// Get the level of the current folder
    /// </summary>
    int GetCurrentFolderLevel();
    
    /// <summary>
    /// Get the name of the current folder.
    /// </summary>
    String GetCurrentFolderName();
    
    /// <summary>
    /// Get the index of the first folder to display.
    /// </summary>
    int GetFirstFolderIndex();
    
    /// <summary>
    /// Get the number of columns to display.
    /// </summary>
    int GetFolderColumnCount();
    
    /// <summary>
    /// Get a list of object names and the number of those objects in the current
    /// folder.  The list will have PT_PROPID_CLASSID ("filter 32") and
    /// PT_PROPID_OBJECTCOUNT (12).
    /// </summary>
    IASQueryResult GetFolderObjectCount();
    
    /// <summary>
    /// Get an IPTQueryResult containing all of the subfolders of the current folder.
    /// </summary>
    IASQueryResult GetFolderQueryResult();
    
    /// <summary>
    /// Retrieves the folder view helper. This contains a method to implement
    /// display for one folder.
    /// FolderViewHelper is the implementation for general use, but you may need
    /// to implement your own helper.
    /// </summary>
    IFolderViewHelper GetFolderViewHelper();
    
    /// <summary>
    /// This method returns whether or not the requested folder is
    /// currently selected.
    /// </summary>
    /// <returns>boolean true implies selected, false implies not selected</returns>
    bool GetIsFolderSelected(int nFolderID);
    
    /// <summary>
    /// Get the index of the first folder to display.
    /// </summary>
    int GetLastFolderIndex();
    
    /// <summary>
    /// Set the number of sub-subfolders to display after the next page..
    /// </summary>
    int GetNumSubSubFoldersToDisplay();
    
    /// <summary>
    /// Get the ID of the parent folder of the current folder.
    /// </summary>
    int GetParentFolderID();
    
    /// <summary>
    /// Get an Object array containing the Integer IDs of all the parent folders
    /// (the path) of the current folder.
    /// Each element in the array must be cast to an Integer.
    /// This will return one ID per folder in the path, except for the root folder,
    /// where two IDs will be returned even though there is only one folder in the
    /// path.
    /// </summary>
    Object[] GetParentFolderIDs();
    
    /// <summary>
    /// Get the path to the current folder concatenated with '\'.
    /// </summary>
    String GetPath();
    
    /// <summary>
    /// Returns whether the folders should have checkboxes next to them.
    /// </summary>
    bool GetShowCheckbox();
    
    /// <summary>
    /// Returns whether the subfolder banner should be shown.
    /// </summary>
    bool GetShowFolderBanner();
    
    /// <summary>
    /// Get the number of sub folders in the current folder at the
    /// specified level.
    /// </summary>
    int GetSubFolderCount(int nFolderLevel);
    
    /// <summary>
    /// Get the number of folders at all levels in the hierachy
    /// </summary>
    int GetSubFolderCount();
    
    /// <summary>
    /// Returns true if the current folder is the root folder.
    /// </summary>
    bool InRootFolder();
  }
}