using System;
namespace com.plumtree.portalpages.common.helpers
{
  /// <author>OlegS</author>
  public class OptionalProperty : PropertyValidator
  {
    protected PropertyValue m_parent;
    
    /// <summary>
    /// Creates a new OptionalProperty object.
    /// </summary>
    /// <param name="owner"></param>
    public OptionalProperty(PropertyValidatorOwner owner) : base(owner)
    {
      m_parent = null;
    }
    
    /// <summary>
    /// Creates a new OptionalProperty object.
    /// </summary>
    /// <param name="owner"></param>
    /// <param name="parentProperty"></param>
    public OptionalProperty(PropertyValidatorOwner owner, PropertyValue parentProperty) : this(owner)
    {
      m_parent = parentProperty;
    }
    
    /// <param name="val"></param>
    /// <returns></returns>
    public override int validate(PropertyValue val)
    {
      int result = base.validate(val);
      if (result == VALIDSOFAR)
      {
        if (val.empty())
        {
          if (m_parent == null)
          {
            // no parent - valid if empty
            result = VALID;
          } else
          // has parent - 
          {
            if (m_parent.empty())
            {
              // valid if empty and parent is empty
              result = VALID;
            } else
            {
              SetInvalid(val, m_asOwner.GetString(56, "ptmsgs_portalcommonmsgs"));
              // invalid if empty but parent is not empty
              result = INVALID;
            }
          }
        }
      }
      return result;
    }
  }
}