using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.common.helpers
{
  /// <author>OlegS</author>
  public class PropertyValue
  {
    public const int SRC_SERVER = 0;
    public const int SRC_FORM = 1;
    public const int UNKNOWN = 0;
    public const int STRING = 1;
    public const int INTEGER = 2;
    public const int DATETIME = 3;
    public Object m_value = null;
    protected String m_help;
    protected String m_name;
    protected Object[] m_id = null;
    protected PropertyValidator[] m_validator;
    protected int m_srcServerIndex;
    
    /// <summary>
    /// Creates a new PropertyValue object.
    /// </summary>
    /// <param name="list"></param>
    /// <param name="name"></param>
    /// <param name="help"></param>
    /// <param name="id"></param>
    /// <param name="qryname"></param>
    /// <param name="vld"></param>
    public PropertyValue(XPArrayList list, String name, String help, int id,
     String qryname, PropertyValidator[] vld) : this(list, name, help, 0,
     id, qryname, vld)
    {
    }
    
    /// <summary>
    /// Creates a new PropertyValue object.
    /// </summary>
    /// <param name="list"></param>
    /// <param name="name"></param>
    /// <param name="help"></param>
    /// <param name="id"></param>
    /// <param name="qryname"></param>
    /// <param name="vld"></param>
    public PropertyValue(XPArrayList list, String name, String help, Object id,
     String qryname, PropertyValidator[] vld) : this(list, name, help, 0,
     id, qryname, vld)
    {
    }
    
    /// <summary>
    /// Creates a new PropertyValue object.
    /// </summary>
    /// <param name="list"></param>
    /// <param name="name"></param>
    /// <param name="help"></param>
    /// <param name="srcServerIndex"></param>
    /// <param name="id"></param>
    /// <param name="qryname"></param>
    /// <param name="vld"></param>
    public PropertyValue(XPArrayList list, String name, String help, int srcServerIndex,
     int id, String qryname, PropertyValidator[] vld)
    {
      // NOTE: We can't just call
      //  this(.., new Integer(id), ..)
      // because in C# there is no distinction between int and Integer,
      // and the jump tool will simply comment out the call.
      // Instead we must duplicate the constructor here.
      list.Add(this);
      m_name = name;
      m_help = help;
      m_srcServerIndex = srcServerIndex;
      m_id = new Object[2];
      m_id[SRC_SERVER] = id;
      m_id[SRC_FORM] = qryname;
      m_validator = vld;
    }
    
    /// <summary>
    /// Creates a new PropertyValue object.
    /// </summary>
    /// <param name="list"></param>
    /// <param name="name"></param>
    /// <param name="help"></param>
    /// <param name="srcServerIndex"></param>
    /// <param name="id"></param>
    /// <param name="qryname"></param>
    /// <param name="vld"></param>
    public PropertyValue(XPArrayList list, String name, String help, int srcServerIndex,
     Object id, String qryname, PropertyValidator[] vld)
    {
      list.Add(this);
      m_name = name;
      m_help = help;
      m_srcServerIndex = srcServerIndex;
      m_id = new Object[2];
      m_id[SRC_SERVER] = id;
      m_id[SRC_FORM] = qryname;
      m_validator = vld;
    }
    
    /// <summary>
    /// Creates a new PropertyValue object skipping the id array. Called from DateTimePropertyValue constructor
    /// </summary>
    /// <param name="list"></param>
    /// <param name="name"></param>
    /// <param name="help"></param>
    /// <param name="srcServerIndex"></param>
    /// <param name="vld"></param>
    protected PropertyValue(XPArrayList list, String name, String help, int srcServerIndex,
     PropertyValidator[] vld)
    {
      list.Add(this);
      m_name = name;
      m_help = help;
      m_srcServerIndex = srcServerIndex;
      m_validator = vld;
    }
    
    /// <returns></returns>
    public virtual bool isMandatory()
    {
      for (int i = 0;(m_validator != null) && (i < m_validator.Length);i++)
      {
        if (m_validator[i] is MandatoryProperty)
        {
          return true;
        }
      }
      return false;
    }
    
    /// <param name="val"></param>
    public virtual void SetValue(Object val)
    {
      m_value = val;
    }
    
    /// <returns></returns>
    public virtual bool changeTypeToDate()
    {
      bool ok = false;
      if (m_value != null)
      {
        if (m_value is String)
        {
          if (!ok)
          {
            try
            {
              XPDateTime xpdt = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT,
               XPDateFormat.SHORT).Parse((String) m_value);
              m_value = xpdt;
              ok = true;
            }
            catch (Exception e)
            {
            }
          }
          if (!ok)
          {
            try
            {
              XPDateTime xpdt = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM,
               XPDateFormat.SHORT).Parse((String) m_value);
              m_value = xpdt;
              ok = true;
            }
            catch (Exception e)
            {
            }
          }
          if (!ok)
          {
            try
            {
              XPDateTime xpdt = XPDateFormat.GetDateTimeInstance(XPDateFormat.LONG,
               XPDateFormat.SHORT).Parse((String) m_value);
              m_value = xpdt;
              ok = true;
            }
            catch (Exception e)
            {
            }
          }
        }
      }
      return ok;
    }
    public virtual void changeTypeToInteger()
    {
      if (m_value != null)
      {
        if (m_value is String)
        {
          try
          {
            String val = (String) m_value;
            m_value = XPConvert.ToInteger(XPStringUtility.Trim(val));
          }
          catch (Exception e)
          {
          }
        }
      }
    }
    
    /// <returns></returns>
    public virtual String controlName()
    {
      return (String) m_id[SRC_FORM];
    }
    
    /// <returns></returns>
    public virtual XPDateTime date()
    {
      XPDateTime result = null;
      if (m_value is XPDateTime)
      {
        result = (XPDateTime) m_value;
      }
      return result;
    }
    
    /// <returns></returns>
    public virtual bool empty()
    {
      return ((m_value == null) || (m_value.ToString().Length == 0));
    }
    
    /// <param name="src"></param>
    /// <param name="srctype"></param>
    /// <returns></returns>
    public virtual bool Get(PropertySource src, int srctype)
    {
      bool modified = false;
      if ((srctype == SRC_FORM) && (XPStringUtility.IndexOf(((String) m_id[srctype]),
       ',') >= 0))
      {
        // special case - multiple controls for single property (e.g. date and time)
        Object m_oldvalue = m_value;
        m_value = null;
        String ids = (String) m_id[srctype];
        for (XPStringTokenizer i = new XPStringTokenizer(ids, ", ");i.HasMoreTokens();
        )
        {
          String id = i.GetNextToken();
          if (id != null)
          {
            Object o = src.Get(id);
            if ((o != null) && (o.ToString().Length > 0))
            {
              if (m_value == null)
              {
                m_value = o.ToString();
              } else
              {
                m_value = m_value + " " + o.ToString();
              }
            }
          }
        }
        modified|=((m_oldvalue == null) || !m_oldvalue.Equals(m_value));
      } else
      {
        if (m_id[srctype] != null)
        {
          Object val = src.Get(m_id[srctype]);
          if ((val != null) || (srctype != SRC_FORM))
          {
            modified|=((m_value == null) || !m_value.Equals(val));
            m_value = val;
          }
        }
      }
      // else the value was not in query string - leave unchanged
      return modified;
    }
    
    /// <param name="srcArray"></param>
    /// <param name="srctype"></param>
    /// <returns></returns>
    public virtual bool Get(PropertySource[] srcArray, int srctype)
    {
      return Get(srcArray[m_srcServerIndex], srctype);
    }
    
    /// <returns></returns>
    public virtual String help()
    {
      return m_help;
    }
    
    /// <returns></returns>
    public virtual Object idForm()
    {
      return m_id[SRC_FORM];
    }
    
    /// <returns></returns>
    public virtual Object idServer()
    {
      return m_id[SRC_SERVER];
    }
    
    /// <param name="c"></param>
    /// <returns></returns>
    public virtual bool isClass(Type c)
    {
      return (m_value != null) && m_value.GetType().Equals(c);
    }
    
    /// <returns></returns>
    public virtual String name()
    {
      return m_name;
    }
    
    /// <returns></returns>
    public virtual int number()
    {
      int result = 0;
      if (m_value is int)
      {
        result = XPConvert.ToInteger(m_value);
      }
      return result;
    }
    
    /// <param name="src"></param>
    /// <param name="srctype"></param>
    public virtual void Set(PropertySource src, int srctype)
    {
      if (m_id[srctype] != null)
      {
        src.Set(m_id[srctype], m_value);
      }
    }
    
    /// <param name="srcArray"></param>
    /// <param name="srctype"></param>
    public virtual void Set(PropertySource[] srcArray, int srctype)
    {
      Set(srcArray[m_srcServerIndex], srctype);
    }
    
    /// <returns></returns>
    public virtual String text()
    {
      String result = null;
      if (m_value is XPDateTime)
      {
        result = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT, XPDateFormat.SHORT).Format(date());
        } else
      {
        result = XPConvert.ToString(m_value);
      }
      return result;
    }
    
    /// <returns></returns>
    public virtual String textDate()
    {
      String result = null;
      if (m_value is XPDateTime)
      {
        result = XPDateFormat.GetDateInstance(XPDateFormat.SHORT).Format(date());
        } else
      if (m_value is String)
      {
        result = text();
      }
      return result;
    }
    
    /// <returns></returns>
    public virtual String textTime()
    {
      String result = null;
      if (m_value is XPDateTime)
      {
        result = XPDateFormat.GetTimeInstance(XPDateFormat.SHORT).Format(date());
        }
      return result;
    }
    
    /// <returns></returns>
    public virtual bool validate()
    {
      int result = PropertyValidator.VALIDSOFAR;
      for (int i = 0;(m_validator != null) && (i < m_validator.Length) && (result == PropertyValidator.VALIDSOFAR);
      i++)
      {
        result = m_validator[i].validate(this);
      }
      return (result != PropertyValidator.INVALID);
    }
  }
}