using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.resultwrapper;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.helpers
{
  /// <author>
  /// adolfoc
  /// This class was built for use in generating small collections of HTML for editors
  /// that were not appropriate for HTMLConstructs (mostly because they are used in 
  /// table generation).
  /// </author>
  public class ViewHelper
  {
    public const String SPACE = "&nbsp;";
    public const int INPUTSIZE_PREFIXED = 40;
    public const int INPUTSIZE_NONPREFIXED = 63;
    public const int TEXTAREA_COLUMNS = 50;
    public const int TEXTAREA_ROWS = 4;
    public const int INPUTMAXLENGTH_SHORT = 255;
    public const int INPUTMAXLENGTH_LONG = 511;
    
    /// <summary>
    /// Adds a cell with default view styling to myRow.
    /// The cell will span colspan columns.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddCell(HTMLTableRow myRow, String colspan)
    {
      HTMLTableCell resultCell;
      resultCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(resultCell);
      resultCell.SetNoWrap(true);
      resultCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      resultCell.SetVAlign(CommonHTMLStrings.TOP);
      if (null == colspan)
      {
        resultCell.SetAutoFit(true);
      } else
      {
        resultCell.SetColSpan(colspan);
      }
      resultCell.SetHeight(CommonHTMLStrings.THREE);
      return resultCell;
    }
    
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="sDefaultValue"></param>
    /// <param name="sHTMLID"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    public static HTMLTableCell AddEditBoxCell(HTMLTableRow myRow, String colspan,
     String sDefaultValue, String sHTMLID)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLElement(MakeSmallInput(INPUTSIZE_PREFIXED, sDefaultValue,
       sHTMLID, HTMLInputTypes.TEXT));
      return myCell;
    }
    public static HTMLTableCell AddEditBoxCell(HTMLTableRow myRow, String colspan,
     String sDefaultValue, String sHTMLID, int width)
    {
      return AddEditBoxCell(myRow, colspan, sDefaultValue, sHTMLID, width,
       false, null);
    }
    public static HTMLTableCell AddEditBoxCell(HTMLTableRow myRow, String colspan,
     String sDefaultValue, String sHTMLID, int width, bool bIsInputDisabled,
     String sFormID)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLElement(MakeSmallInput(width, sDefaultValue, sHTMLID,
       HTMLInputTypes.TEXT, bIsInputDisabled, sFormID, INPUTMAXLENGTH_SHORT));
      return myCell;
    }
    
    /// <summary>
    /// Adds an empty cell with default view styling to myRow. The cell will span
    /// colspan columns.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddEmptyCell(HTMLTableRow myRow, String colspan)
    {
      HTMLTableCell resultCell;
      resultCell = AddCell(myRow, colspan);
      resultCell.AddInnerHTMLString(SPACE + SPACE);
      return resultCell;
    }
    
    /// <summary>
    /// Adds an empty row with default view styling to myTable.
    /// The empty row will span colspan columns.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="colspan"></param>
    /// <returns>HTMLTableRow</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableRow AddEmptyRow(HTMLTable myTable, String colspan)
    {
      HTMLTableRow resultRow;
      resultRow = AddRow(myTable);
      resultRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      AddEmptyCell(resultRow, colspan);
      return resultRow;
    }
    
    /// <summary>
    /// Adds a Cell with a single object icon in it.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="nCLASSID"></param>
    /// <param name="strProviderCLSID"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddIconCell(HTMLTableRow myRow, String colspan,
     int nCLASSID, String strProviderCLSID, String _strLangID)
    {
      HTMLTableCell resultCell = AddCell(myRow, colspan);
      resultCell.SetVAlign(CommonHTMLStrings.CENTER);
      resultCell.SetWidth("20");
      HTMLSpan mySpan = AddSpanToCell(resultCell);
      if (0 < nCLASSID)
      {
        // Add Class description
        ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
        // AGC- The english name is used here only as a reference to get icons with. It should not be printed.
        String strProvEnglishName = ptClassTypeDescManager.GetProviderEnglishNameGivenCLSID(strProviderCLSID);
        HTMLImg myImage = ptClassTypeDescManager.GetDefaultIconForClassType(nCLASSID,
         _strLangID, strProvEnglishName);
        // Icon
        mySpan.AddInnerHTMLElement(myImage);
      } else
      {
        mySpan.AddInnerHTMLString(SPACE);
      }
      return resultCell;
    }
    
    /// <summary>
    /// Adds a Cell with a single Type string (Web Service, etc.) in it.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="nCLASSID"></param>
    /// <param name="strProviderCLSID"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddTypeCell(HTMLTableRow myRow, String colspan,
     int nCLASSID, String strProviderCLSID, String _strLangID)
    {
      HTMLTableCell resultCell = AddCell(myRow, colspan);
      HTMLSpan mySpan = AddSpanToCell(resultCell);
      // Add Class description
      ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
      // AGC- The english name is used here only as a reference to get icons with. It should not be printed.
      String strProvEnglishName = "";
      String strType = "";
      try
      {
        strProvEnglishName = ptClassTypeDescManager.GetProviderEnglishNameGivenCLSID(strProviderCLSID);
        strType = ptClassTypeDescManager.GetClassTypeLocalizedName(nCLASSID,
         _strLangID, strProvEnglishName);
      }
      catch (Exception e)
      {
        // AGC- it is very possible that this item either doesn't have a provEnglishName or doesn't have a
        // provider-specific name (like portlets).
        strType = ptClassTypeDescManager.GetClassTypeLocalizedName(nCLASSID,
         _strLangID);
      }
      // Icon
      mySpan.AddInnerHTMLEncodedString(strType);
      return resultCell;
    }
    
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    public static HTMLTableCell AddIndentCell(HTMLTableRow myRow, String colspan)
    {
      HTMLTableCell resultCell = AddEmptyCell(myRow, colspan);
      resultCell.SetWidth("30");
      return resultCell;
    }
    
    /// <summary>
    /// Returns a Cell suitable for long text descriptions. (no wrapping,
    /// bolded, etc)
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strText"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddLabelCell(HTMLTableRow myRow, String colspan,
     String strText)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      myCell.SetVAlign("middle");
      HTMLSpan mySpan = AddSpanToCell(myCell);
      myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strText) + SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Returns a Cell suitable for long text descriptions. (no wrapping,
    /// bolded, etc)
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strText"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddReferencableLabelCell(HTMLTableRow myRow,
     String colspan, String strText, String txtContainerId)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.SetID(txtContainerId);
      mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strText) + SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Adds a cell to a row containing a bolded label followed on a separate
    /// line by text. The cell will wrap.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strLabel"></param>
    /// <param name="strText"></param>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddLabelAndTextCell(HTMLTableRow myRow, String colspan,
     String strLabel, String strText)
    {
      HTMLTableCell myCell = AddLabelCell(myRow, colspan, strLabel);
      myCell.SetNoWrap(false);
      if ((null != strText) && (strText.Length > 0))
      {
        HTMLSpan mySpan = AddSpanToCell(myCell);
        mySpan.AddInnerHTMLElement(new HTMLBr());
        mySpan.AddInnerHTMLEncodedString(strText);
      }
      return myCell;
    }
    
    /// <summary>
    /// Returns a Cell suitable for long text descriptions. (no wrapping,
    /// etc).  The only difference from AddLabelCell is that the label is not
    /// bolded.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strText"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddSubLabelCell(HTMLTableRow myRow, String colspan,
     String strText)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strText) + SPACE);
      return myCell;
    }
    
    /// <summary>
    /// Adds a simple cell containing an image - centered with no border.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="asOwner"></param>
    /// <param name="imgType"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddImageCell(HTMLTableRow myRow, String colspan,
     AActivitySpace asOwner, PTImageType imgType)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetAlign(CommonHTMLStrings.MIDDLE);
      HTMLImg htmlImg = null;
      htmlImg = (HTMLImg) UIConstructFactory.GetConstruct(imgType, true, asOwner).GetHTMLElement();
      htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      htmlImg.SetBorder(CommonHTMLStrings.ZERO);
      myCell.AddInnerHTMLElement(htmlImg);
      return myCell;
    }
    
    /// <summary>
    /// Uses nColCount to determine if there is enough space for margins and a
    /// spacer cell. If so, adds a left margin and returns the count of middle
    /// columns (non-margin cells) left for adding inputs.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="nColCount"></param>
    /// <returns>int</returns>
    /// <throws>HTMLException</throws>
    public static int AddLeftMargin(HTMLTableRow myRow, int nColCount)
    {
      int nMiddleColumns = nColCount;
      if (nColCount >= 3)
      {
        // Add A Margin
        AddEmptyCell(myRow, CommonHTMLStrings.ONE);
        // Return Column count minus the margins.
        nMiddleColumns = nColCount - 2;
      }
      if (nColCount >= 5)
      {
        // Return Column count minus space for a spacer cell.
        nMiddleColumns = nMiddleColumns - 1;
      }
      return nMiddleColumns;
    }
    
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="sDefaultValue"></param>
    /// <param name="sHTMLID"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    public static HTMLTableCell AddPasswordBoxCell(HTMLTableRow myRow, String colspan,
     String sDefaultValue, String sHTMLID)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLElement(MakeSmallInput(INPUTSIZE_PREFIXED, sDefaultValue,
       sHTMLID, HTMLInputTypes.PASSWORD));
      return myCell;
    }
    public static HTMLTableCell AddPasswordBoxCell(HTMLTableRow myRow, String colspan,
     String sDefaultValue, String sHTMLID, int width)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLElement(MakeSmallInput(width, sDefaultValue, sHTMLID,
       HTMLInputTypes.PASSWORD));
      return myCell;
    }
    
    /// <summary>
    /// Uses nColCount to determine if there is enough space for margins and a
    /// spacer cell. If so, adds a right margin and possibly, right spacer.
    /// Assumes that the results of AddLeftMargin were respected with regards to
    /// remaining column count.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="nColCount"></param>
    /// <throws>HTMLException</throws>
    public static void AddRightMargin(HTMLTableRow myRow, int nColCount)
    {
      if (nColCount >= 5)
      {
        // Add A Spacer Cell
        AddSpacerCell(myRow, CommonHTMLStrings.ONE);
      }
      if (nColCount >= 3)
      {
        // Add A Margin
        AddEmptyCell(myRow, CommonHTMLStrings.ONE);
      }
    }
    
    /// <summary>
    /// Adds a row with default view styling to myTable.
    /// </summary>
    /// <param name="myTable"></param>
    /// <returns>HTMLTableRow</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableRow AddRow(HTMLTable myTable)
    {
      HTMLTableRow resultRow;
      resultRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(resultRow);
      return resultRow;
    }
    
    /// <summary>
    /// Adds a label + PTDurationCombo combination to myTable (spanning a single
    /// row).
    /// nColCount is the column count of the table, and ptdDefault contains the
    /// default information used to render the PTDurationCombo.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLTimeoutInput"></param>
    /// <param name="strHTMLTimeoutUnitsSelect"></param>
    /// <param name="ptdIn"></param>
    /// <throws>Exception</throws>
    public static void AddSimpleDurationCombo(HTMLTable myTable, int nColCount,
     String strLabel, String strHTMLTimeoutInput, String strHTMLTimeoutUnitsSelect,
     PTDuration ptdIn, AActivitySpace asOwner)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myRow = ViewHelper.AddRow(myTable);
      int nMiddleColumns = AddLeftMargin(myRow, nColCount);
      // Label		
      myCell = AddLabelCell(myRow, CommonHTMLStrings.ONE, strLabel);
      // Duration Combo
      if (nMiddleColumns > 1)
      {
        // Put the label and duration combo in different cells.
        myCell = ViewHelper.AddCell(myRow, XPConvert.ToString(nMiddleColumns - 1));
        myCell.SetAlign(CommonHTMLStrings.LEFT);
      }
      ////////// Timeout duration construct.		
      myCell.AddInnerHTMLElement(PTDurationCombo.GetDurationCombo(strHTMLTimeoutInput,
       strHTMLTimeoutUnitsSelect, ptdIn.GetSupportedUnitsMask(), XPConvert.ToString(ptdIn.GetDurationInBestUnits()),
       ptdIn.GetBestDurationUnit(), asOwner));
      AddRightMargin(myRow, nColCount);
    }
    public static HTMLTableCell AddSelectBoxWithJSHandlerInColumn(HTMLTableRow row,
     String label, String selectId, int displaySize, String style, String onChangeHandler,
     HTMLOption[] options, String defaultValue, AActivitySpace asOwner)
    {
      HTMLTableCell cell = AddLabelCell(row, CommonHTMLStrings.ONE, label);
      HTMLSelect htmlSelect = new HTMLSelect(selectId, selectId);
      cell.AddInnerHTMLElement(htmlSelect);
      //htmlSelect.SetSize();
      //htmlSelect.SetTitle(label);
      htmlSelect.SetStyle(style);
      htmlSelect.SetSize(displaySize);
      htmlSelect.SetOnChange(onChangeHandler);
      //htmlSelect.SetStyleClass(GetHTMLComponentStyleClass());
      for (int i = 0;i < options.Length;i++)
      {
        htmlSelect.AddInnerHTMLElement(options[i]);
      }
      // if the current value is one of the options then set it
      if (defaultValue != null && !"".Equals(defaultValue))
      {
        htmlSelect.SetValue(defaultValue);
      }
      return cell;
    }
    
    /// <summary>
    /// Adds a label + edit box combination spanning two rows to myTable.
    /// nColCount is the number of columns in the table (margins will be added if
    /// nColCount >= 3). strPrefix is any text that can be prepended to the input
    /// box (like the base URL for an gateway input box). sDefaultValue is the
    /// value in the input box. sHTMLID is the name of the input box form
    /// element.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strPrefix"></param>
    /// <param name="sDefaultValue"></param>
    /// <param name="sHTMLID"></param>
    /// <throws>HTMLException</throws>
    public static void AddSimpleEditBox(HTMLTable myTable, int nColCount,
     String strLabel, String strPrefix, String sDefaultValue, String sHTMLID)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell = null;
      // Label Row
      if ((null != strLabel) && (XPStringUtility.Trim(strLabel).Length > 0))
      {
        AddSimpleLabel(myTable, nColCount, strLabel);
      }
      myRow = AddRow(myTable);
      int nMiddleColumns = AddLeftMargin(myRow, nColCount);
      int nInputSize = INPUTSIZE_PREFIXED;
      if ((null != strPrefix) && (XPStringUtility.Trim(strPrefix).Length > 0))
      {
        myCell = AddSubLabelCell(myRow, XPConvert.ToString(nMiddleColumns),
         strPrefix);
      } else
      {
        nInputSize = INPUTSIZE_NONPREFIXED;
        myCell = AddCell(myRow, XPConvert.ToString(nMiddleColumns));
      }
      myCell.AddInnerHTMLElement(MakeSmallInput(nInputSize, sDefaultValue,
       sHTMLID, HTMLInputTypes.TEXT, false, null, INPUTMAXLENGTH_LONG));
      AddRightMargin(myRow, nColCount);
    }
    
    /// <summary>
    /// Adds a simple Label - full width of the table (adding margins)
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <throws>HTMLException</throws>
    public static void AddSimpleLabel(HTMLTable myTable, int nColCount, String strLabel)
    {
      HTMLTableRow myRow = AddRow(myTable);
      int nMiddleColumns = AddLeftMargin(myRow, nColCount);
      AddLabelCell(myRow, XPConvert.ToString(nMiddleColumns), strLabel);
      AddRightMargin(myRow, nColCount);
    }
    
    /// <summary>
    /// Adds a row with a simple label: value listing. Respects the number of columns required as passed in nColCount.
    /// nColCount must be 2 or greater.
    /// </summary>
    public static void AddSimpleNameValue(HTMLTable myTable, int nColCount,
     String strLabel, String sDefaultValue, String strLang)
    {
      HTMLTableRow myRow = AddRow(myTable);
      int nMiddleColumns = AddLeftMargin(myRow, nColCount);
      AddLabelCell(myRow, CommonHTMLStrings.ONE, strLabel);
      int nRemainingColumns = nMiddleColumns - 1;
      if (nRemainingColumns <= 0)
      {
        nRemainingColumns = 1;
      }
      AddTextCell(myRow, XPConvert.ToString(nRemainingColumns), sDefaultValue);
      AddRightMargin(myRow, nColCount);
    }
    
    /// <summary>
    /// Adds a row to myTable containing a simple radio selection.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <throws>HTMLException </throws>
    public static HTMLTableRow AddSimpleRadio(HTMLTable myTable, int nColCount,
     String strLabel, String strHTMLID, String strValue, bool bChecked, String strOnChange)
    {
      return AddSimpleRadioCheckbox(myTable, nColCount, strLabel, strHTMLID,
       strValue, bChecked, strOnChange, true, false);
    }
    
    /// <summary>
    /// Adds a row to myTable containing a simple checkbox selection.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <throws>HTMLException </throws>
    public static HTMLTableRow AddSimpleCheckbox(HTMLTable myTable, int nColCount,
     String strLabel, String strHTMLID, String strValue, bool bChecked, String strOnChange)
    {
      return AddSimpleRadioCheckbox(myTable, nColCount, strLabel, strHTMLID,
       strValue, bChecked, strOnChange, false, false);
    }
    
    /// <summary>
    /// Adds a row to myTable containing a simple checkbox selection.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <throws>HTMLException </throws>
    public static HTMLTableRow AddSimpleCheckbox(HTMLTable myTable, int nColCount,
     String strLabel, String strHTMLID, String strValue, bool bChecked, String strOnChange,
     bool bDisabled)
    {
      return AddSimpleRadioCheckbox(myTable, nColCount, strLabel, strHTMLID,
       strValue, bChecked, strOnChange, false, bDisabled);
    }
    
    /// <summary>
    /// Adds a row to myTable containing a simple radio (or checkbox) selection.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <throws>HTMLException </throws>
    private static HTMLTableRow AddSimpleRadioCheckbox(HTMLTable myTable,
     int nColCount, String strLabel, String strHTMLID, String strValue, bool bChecked,
     String strOnChange, bool bRadioCheckbox, bool bDisabled)
    {
      bool disableIndentCell = false;
      // olegs - hack to allow proper positioning
      if (nColCount < 0)
      {
        nColCount = -nColCount;
        disableIndentCell = true;
      }
      HTMLTableRow myRow = AddRow(myTable);
      int nMiddleColumns = AddLeftMargin(myRow, nColCount);
      if (nMiddleColumns > 2 && !disableIndentCell)
      {
        // Add an indent.
        AddIndentCell(myRow, CommonHTMLStrings.ONE);
        nMiddleColumns-=1;
      }
      HTMLTableCell myCell = AddCell(myRow, XPConvert.ToString(nMiddleColumns));
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLElement(MakeSimpleRadioCheck(strLabel, strHTMLID,
       strValue, bChecked, strOnChange, bRadioCheckbox, bDisabled));
      AddRightMargin(myRow, nColCount);
      return myRow;
    }
    public static HTMLElement MakeHiddenInput(String strHTMLID, String strvalue)
    {
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, strHTMLID,
       "");
      myInput.SetValue(strvalue);
      return myInput;
    }
    
    /// <summary>
    /// Creates a simple radio selection and returns it.
    /// </summary>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeSimpleRadio(String strLabel, String strHTMLID,
     String strValue, bool bChecked, String strOnChange)
    {
      return MakeSimpleRadioCheck(strLabel, strHTMLID, strValue, bChecked,
       strOnChange, true, false);
    }
    
    /// <summary>
    /// Creates a simple checkbox and returns it.
    /// </summary>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeSimpleCheckbox(String strLabel, String strHTMLID,
     String strValue, bool bChecked, String strOnChange)
    {
      return MakeSimpleRadioCheck(strLabel, strHTMLID, strValue, bChecked,
       strOnChange, false, false);
    }
    
    /// <summary>
    /// Creates a simple radio (or checkbox) selection and returns it.
    /// </summary>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <param name="strOnChange"></param>
    /// <param name="bRadioCheckbox"></param>
    /// <param name="bDisabled"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    private static HTMLElement MakeSimpleRadioCheck(String strLabel, String strHTMLID,
     String strValue, bool bChecked, String strOnChange, bool bRadioCheckbox,
     bool bDisabled)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLInput myInput;
      if (bRadioCheckbox)
      {
        myInput = new HTMLInput(HTMLInputTypes.RADIO, strHTMLID, "");
      } else
      {
        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, strHTMLID, "");
      }
      result.AddInnerHTMLElement(myInput);
      myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
      myInput.SetValue(strValue);
      myInput.SetChecked(bChecked);
      myInput.SetDisabled(bDisabled);
      if ((null != strOnChange) && (strOnChange.Length > 0))
      {
        myInput.SetOnClick(strOnChange);
      }
      result.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strLabel));
      return result;
    }
    
    /// <summary>
    /// Adds a row to myTable containing a simple radio selection.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="nColCount"></param>
    /// <param name="strLabel"></param>
    /// <param name="strHTMLID"></param>
    /// <param name="strValue"></param>
    /// <param name="bChecked"></param>
    /// <throws>HTMLException </throws>
    public static HTMLTableRow AddSimpleRadio(HTMLTable myTable, int nColCount,
     String strLabel, String strHTMLID, String strValue, bool bChecked)
    {
      return AddSimpleRadio(myTable, nColCount, strLabel, strHTMLID, strValue,
       bChecked, "");
    }
    
    /// <summary>
    /// Adds a simple header (no sorting or whatnot) to an existing table.
    /// </summary>
    /// <param name="myTable"></param>
    /// <param name="arsHeaders"></param>
    /// <throws>Exception</throws>
    public static void AddSimpleTableHeader(HTMLTable myTable, String[] arsHeaders)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLSpan mySpan;
      HTMLB myB;
      myRow = ViewHelper.AddRow(myTable);
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      for (int nHeaderIndex = 0;nHeaderIndex < arsHeaders.Length;nHeaderIndex++)
      {
        myCell = ViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
        myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        mySpan = ViewHelper.AddSpanToCell(myCell);
        myB = new HTMLB();
        mySpan.AddInnerHTMLElement(myB);
        myB.AddInnerHTMLString(XPHttpUtility.HtmlEncode(arsHeaders[nHeaderIndex]) + SPACE);
        // AGC- Make the last cell width some large percentage so the table cells
        // are left justified.
        if (nHeaderIndex == (arsHeaders.Length - 1))
        {
          myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        }
      }
    }
    
    /// <summary>
    /// Adds a cell with default view styling to myRow. The cell will span
    /// colspan columns. The cell has a width of 100% (can be used to force other
    /// cells in the row towards the left margin).
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddSpacerCell(HTMLTableRow myRow, String colspan)
    {
      HTMLTableCell resultCell = AddEmptyCell(myRow, colspan);
      resultCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      return resultCell;
    }
    
    /// <summary>
    /// Adds a span with default view styling to myCell.
    /// </summary>
    /// <param name="myCell"></param>
    /// <returns>HTMLSpan</returns>
    /// <throws>HTMLException</throws>
    public static HTMLSpan AddSpanToCell(HTMLTableCell myCell)
    {
      HTMLSpan resultSpan;
      resultSpan = new HTMLSpan();
      myCell.AddInnerHTMLElement(resultSpan);
      resultSpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      return resultSpan;
    }
    
    /// <summary>
    /// Adds a table with default view styling to HTMLCollection result.
    /// </summary>
    /// <param name="result"></param>
    /// <returns>HTMLTable</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTable AddTable(HTMLElementCollection result)
    {
      HTMLTable myTable = MakeTable();
      result.AddInnerHTMLElement(myTable);
      return myTable;
    }
    
    /// <summary>
    /// Adds a table with default list view styling to HTMLCollection result.
    /// </summary>
    /// <param name="result"></param>
    /// <returns>HTMLTable</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTable AddListTable(HTMLElementCollection result)
    {
      HTMLTable myTable = MakeListTable();
      result.AddInnerHTMLElement(myTable);
      return myTable;
    }
    
    /// <summary>
    /// Returns a table with the default view styling.
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTable MakeTable()
    {
      HTMLTable myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ONE);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
      return myTable;
    }
    
    /// <summary>
    /// Returns a table with the default view styling.
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTable MakeListTable()
    {
      HTMLTable myTable = new HTMLTable();
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.THREE);
      myTable.SetCellSpacing(CommonHTMLStrings.THREE);
      myTable.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
      return myTable;
    }
    
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="sDefaultValue"></param>
    /// <param name="sHTMLID"></param>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    public static HTMLTableCell AddTextAreaCell(HTMLTableRow myRow, String colspan,
     String sDefaultValue, String sHTMLID)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(true);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLElement(MakeTextArea(TEXTAREA_COLUMNS, TEXTAREA_ROWS,
       sDefaultValue, sHTMLID));
      return myCell;
    }
    
    /// <summary>
    /// Returns a Cell suitable for long text descriptions. (wrapping, 100%, etc)
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strText"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddTextCell(HTMLTableRow myRow, String colspan,
     String strText)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(false);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strText));
      return myCell;
    }
    
    /// <summary>
    /// Returns a Cell suitable for long text descriptions. (wrapping, 100%, etc)
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strText"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>HTMLException</throws>
    public static HTMLTableCell AddTextCellReferencable(HTMLTableRow myRow,
     String colspan, String strText, String spanId)
    {
      HTMLTableCell myCell = AddCell(myRow, colspan);
      myCell.SetNoWrap(false);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      HTMLSpan mySpan = AddSpanToCell(myCell);
      mySpan.SetID(spanId);
      mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strText));
      return myCell;
    }
    
    /// <summary>
    /// Returns the String path to the folder with ID nAdminFolderID
    /// </summary>
    public static String GetAdminFolderPath(IPTSession ptSession, int nAdminFolderID)
    {
      IPTAdminCatalog ptAFCatalog = ptSession.GetAdminCatalog();
      IPTAdminFolder ptAFParent = ptAFCatalog.OpenAdminFolder(nAdminFolderID,
       false);
      String strPath = ptAFParent.GetPath();
      return strPath;
    }
    
    /// <summary>
    /// Retrieves an int value from a Query Result.
    /// </summary>
    /// <param name="ptQR"></param>
    /// <param name="nRowIndex"></param>
    /// <param name="nPropID"></param>
    /// <returns>int</returns>
    public static int GetQRValueAsInt(IASQueryResult ptQR, int nRowIndex,
     int nPropID)
    {
      return XPConvert.ToInteger(ptQR.GetFields(nRowIndex, nPropID));
    }
    
    /// <summary>
    /// Retrieves a String value from a QueryResult.
    /// </summary>
    /// <param name="ptQR"></param>
    /// <param name="nRowIndex"></param>
    /// <param name="nPropID"></param>
    /// <returns>String</returns>
    public static String GetQRValueAsString(IASQueryResult ptQR, int nRowIndex,
     int nPropID)
    {
      return XPConvert.ToString(ptQR.GetFields(nRowIndex, nPropID));
    }
    
    /// <summary>
    /// Makes a simple link that creates an object in the parent window - passing
    /// in the added arguments.
    /// </summary>
    /// <param name="nCLASSID"></param>
    /// <param name="strProviderCLSID"></param>
    /// <param name="nFolderID"></param>
    /// <param name="strLink"></param>
    /// <param name="asOwner"></param>
    /// <param name="strArgs"></param>
    /// <param name="bCloseWindowOnExit"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeCreateObjectLink(int nCLASSID, String strProviderCLSID,
     int nFolderID, String strLink, AActivitySpace asOwner, String strArgs,
     bool bCloseWindowOnExit)
    {
      HTMLAnchor myAnchor = new HTMLAnchor("#");
      String strURL = "";
      if ((null != strProviderCLSID) && (0 < strProviderCLSID.Length))
      {
        ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
        String strProvEnglishName = ptClassTypeDescManager.GetProviderEnglishNameGivenCLSID(strProviderCLSID);
        // explicitly return to the space before this space.
        strURL = PTOpenerLinks.GetOpenerURLCreateExt(nCLASSID, nFolderID,
         strProvEnglishName, -1, -1, asOwner, asOwner.GetParentSpaceName(),
         asOwner.GetParentSpaceID(), null);
      } else
      {
        // explicitly return to the space before this space.
        strURL = PTOpenerLinks.GetOpenerURLCreate(nCLASSID, nFolderID, asOwner,
         asOwner.GetParentSpaceName(), asOwner.GetParentSpaceID(), null);
        }
      //AGC- Add the args.
      if (null != strArgs)
      {
        strURL = XPStringUtility.ForceEndsWith(strURL, "&");
        if (XPStringUtility.StartsWith(strArgs, "&"))
        {
          strArgs = XPStringUtility.Substring(strArgs, 1);
        }
        strURL+=strArgs;
      }
      XPStringBuilder sb = new XPStringBuilder(200);
      // TODO CR - MJD : document.location was deprecated in Javascript 1.1, use window.opener.location instead		
      sb.Append("window.opener.document.location = \'");
      sb.Append(strURL + "\';");
      if (bCloseWindowOnExit)
      {
        sb.Append("window.close();");
      }
      sb.Append(" return false;");
      myAnchor.SetHRef("");
      myAnchor.SetOnClick(sb.ToString());
      myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strLink));
      return myAnchor;
    }
    
    /// <summary>
    /// Makes a simple button with text strText and onClick handler strOnClick.
    /// Uses the default style for an editor button.
    /// </summary>
    /// <param name="strText"></param>
    /// <param name="strOnClick"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeSimpleButton(String strText, String strOnClick)
    {
      return ViewHelper.MakeComplexValueButton(strText, PTStyleClass.OBJECT_TEXT,
       PTStyleClass.FORM_BTN_TEXT, strOnClick, "in_bu_NULL");
    }
    
    /// <summary>
    /// Makes a simple button with text strText and onClick handler strOnClick.
    /// strHTML will be the button name.
    /// Uses the default style for an editor button.
    /// </summary>
    /// <param name="strText"></param>
    /// <param name="strOnClick"></param>
    /// <param name="strHTML"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    public static HTMLElement MakeSimpleButton(String strText, String strOnClick,
     String strHTML)
    {
      return ViewHelper.MakeComplexValueButton(strText, PTStyleClass.OBJECT_TEXT,
       PTStyleClass.FORM_BTN_TEXT, strOnClick, strHTML);
    }
    
    /// <summary>
    /// Sets the cell color based on bRowColor. Useful for alternating
    /// row colors in table lists.
    /// </summary>
    /// <param name="myCell"></param>
    /// <param name="bRowColor"></param>
    public static void SetRowColor(HTMLTableCell myCell, bool bRowColor)
    {
      if (bRowColor)
      {
        myCell.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
      } else
      {
        myCell.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
      }
    }
    
    /// <summary>
    /// Returns JS for validating that a numeric input is, indeed numeric (and
    /// positive)
    /// </summary>
    /// <param name="strFormName"></param>
    /// <param name="strInputName"></param>
    /// <param name="strError"></param>
    /// <returns>String</returns>
    public static String ValidateNumericInputJS(String strFormName, String strInputName,
     String strError)
    {
      XPStringBuilder sb = new XPStringBuilder(300);
      String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
      sb.Append(" \tif ( !" + strJSUtilVersionPrefix + "PTNumberUtil.isPositiveInteger(document.").Append(strFormName).Append("." + strInputName + ".value) )\n");
      sb.Append("\t\t{\n");
      sb.Append(" \t\talert(\'").Append(strError).Append("\');\n");
      sb.Append(" \t\treturn false;\n");
      sb.Append("\t\t}\n");
      return sb.ToString();
    }
    
    /// <summary>
    /// Makes a simple button with text strText and onClick handler strOnClick.
    /// strHTML will be the button name.
    /// stroutterSpanStyle and titleSpanStyle modify the button styles.
    /// </summary>
    /// <param name="sValue"></param>
    /// <param name="outterSpanStyle"></param>
    /// <param name="titleSpanStyle"></param>
    /// <param name="strOnClick"></param>
    /// <param name="strHTML"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    private static HTMLElement MakeComplexValueButton(String sValue, PTStyleClass outterSpanStyle,
     PTStyleClass titleSpanStyle, String strOnClick, String strHTML)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLSpan mySpan;
      HTMLInput myInput;
      mySpan = new HTMLSpan();
      result.AddInnerHTMLElement(mySpan);
      mySpan.SetPreComment("begin " + sValue + " button");
      mySpan.SetPostComment("end " + sValue + " button");
      mySpan.SetStyleClass(outterSpanStyle);
      myInput = new HTMLInput(HTMLInputTypes.BUTTON, strHTML, "");
      myInput.SetName(strHTML);
      mySpan.AddInnerHTMLElement(myInput);
      if (null != strOnClick)
      {
        myInput.SetOnClick(strOnClick);
      }
      if (sValue != null)
      {
        myInput.SetValue(sValue);
        if (titleSpanStyle != null)
        {
          myInput.SetStyleClass(titleSpanStyle);
        }
      }
      return result;
    }
    
    /// <summary>
    /// Creates a simple Input element.
    /// </summary>
    /// <param name="myRow"></param>
    /// <param name="colspan"></param>
    /// <param name="strPrefix"></param>
    /// <param name="sDefaultValue"></param>
    /// <param name="sHTMLID"></param>
    /// <throws>HTMLException</throws>
    private static HTMLElement MakeSmallInput(int nInputSize, String sDefaultValue,
     String sHTMLID, int nInputType)
    {
      return MakeSmallInput(nInputSize, sDefaultValue, sHTMLID, nInputType,
       false, null, INPUTMAXLENGTH_SHORT);
    }
    private static HTMLElement MakeSmallInput(int nInputSize, String sDefaultValue,
     String sHTMLID, int nInputType, bool bInputIsDisabled, String sFormID,
     int nInputMaxLength)
    {
      // Input Prefix/Label
      HTMLSpan mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      //// Input itself
      HTMLInput myInput = new HTMLInput(nInputType, sHTMLID, "");
      mySpan.AddInnerHTMLElement(myInput);
      myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      myInput.SetMaxLength(nInputMaxLength);
      myInput.SetSize(nInputSize);
      // aj: if the form id is specified, use it - not sure why we don't just use the
      //     HTML Id, but thats a potentially very large change this late in the game...
      if (sFormID != null)
      {
        myInput.SetID(sFormID);
      }
      // aj: set the disabled status...
      myInput.SetDisabled(bInputIsDisabled);
      myInput.SetValue(sDefaultValue);
      return mySpan;
    }
    
    /// <summary>
    /// Creates a simple TextArea element
    /// </summary>
    /// <param name="nColumns"></param>
    /// <param name="nRows"></param>
    /// <param name="sDefaultValue"></param>
    /// <param name="sHTMLID"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException</throws>
    private static HTMLElement MakeTextArea(int nColumns, int nRows, String sDefaultValue,
     String sHTMLID)
    {
      // Input Prefix/Label
      HTMLSpan mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      //// Input itself
      HTMLTextArea myTextArea = new HTMLTextArea(XPConvert.ToString(nColumns),
       XPConvert.ToString(nRows));
      myTextArea.SetName(sHTMLID);
      myTextArea.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      mySpan.AddInnerHTMLElement(myTextArea);
      myTextArea.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sDefaultValue));
      return mySpan;
    }
  }
}