using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.joblogs
{
  /// <summary>
  /// This class displays the HTML for the Job History action bar
  /// </summary>
  /// <author>JohnH</author>
  public class HistoryView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.joblogs.HistoryView");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobHistoryView";
    
    /// <summary>
    /// Helper class that contains all of the implementations for getting the HTML 
    /// </summary>
    private HistoryViewHelper myViewHelper;
    
    /// <summary>
    /// JH- The read-only model associated with this view 
    /// </summary>
    private IJobLogModelRO m_model;
    
    /// <summary>
    /// Member variable for the parent activity space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_model = (IJobLogModelRO) model;
      m_asOwner = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new HistoryView();
    }
    
    /// <summary>
    /// Displays the HTML for the view
    /// </summary>
    /// <returns>HTMLElement</returns>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display HistoryView");
        result.AddInnerHTMLElement(myComment);
        result.AddInnerHTMLElement(myViewHelper.GetHeaderView(m_asOwner.GetString(85,
         "ptmsgs_portalcommonmsgs")));
        //Add the action bar
        result.AddInnerHTMLElement(myViewHelper.AddActionBar());
        //Add the job log detail
        result.AddInnerHTMLElement(myViewHelper.GetJobLogDetail());
        myComment = new HTMLComment("End: Display HistoryView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Portlets"),
         "JobHistoryPortletView::DisplayPortlet", e, true, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(92, "ptmsgs_portalcommonmsgs"));
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = new HTMLScript("text/javaScript");
      myViewHelper = new HistoryViewHelper((IModelRO) m_model, m_asOwner,
       false, AFormDP.JAVASCRIPT_SUBMIT_FORM);
      String newScript = myViewHelper.GetJavascript(AFormDP.HTMLFORM_NAME);
      myScript.AddInnerHTMLString(newScript);
      return myScript;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}