using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
namespace com.plumtree.portalpages.common.joblogs
{
  /// <summary>
  /// This read-only interface provides access to the member variables in the
  /// JobLogModel class.  It is called by the views used to display the job
  /// history and the job logs.
  /// </summary>
  /// <author>JohnH</author>
  public interface IJobLogModelRO
  {
    
    /// <summary>
    /// Returns the log page currently being displayed.
    /// </summary>
    /// <returns>int</returns>
    int GetCurrentLogPage();
    
    /// <summary>
    /// Returns CurrentPage setting.
    /// </summary>
    /// <returns>int</returns>
    int GetCurrentPage();
    
    /// <summary>
    /// Returns the jobID.
    /// </summary>
    /// <returns>int</returns>
    int GetJobID();
    
    /// <summary>
    /// Returns the jobName.
    /// </summary>
    /// <returns>String</returns>
    String GetJobName();
    
    /// <summary>
    /// Returns the Plumtree Session object.
    /// </summary>
    /// <returns>IPTSession</returns>
    IPTSession GetPTSession();
    
    /// <summary>
    /// Returns the job history row to display in the job log detail viewer.
    /// </summary>
    /// <returns>int</returns>
    int GetRowToDisplay();
    
    /// <summary>
    /// Returns the runTime.
    /// </summary>
    /// <returns>String</returns>
    String GetRunTime();
    
    /// <summary>
    /// Returns boolean indicating whether the last request was a log search.
    /// </summary>
    /// <returns>boolean</returns>
    bool IsSearchRequest();
    
    /// <summary>
    /// Returns the target string to be used for a log search.
    /// </summary>
    /// <returns>String</returns>
    String GetSearchString();
    
    /// <summary>
    /// Returns the log file in byte array format
    /// </summary>
    /// <returns>byte[]</returns>
    byte[] GetLogFile();
    
    /// <summary>
    /// Get the Date picker control manager
    /// </summary>
    /// <returns>JSDatePickerMgr</returns>
    JSDatePickerMgr GetDatePickerControlManager();
  }
}