using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.common.joblogs
{
  /// <author>
  /// John Hogan
  /// This activity space is a simple container for the job log display functionality.
  /// It is only referenced in the portlet version of the job history view.
  /// </author>
  public class JobLogAS : AFormAS
  {
    
    /// <summary>
    /// The unique identifier for the space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobLogAS";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobLogAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the name of the repost control class.
    /// E.g.: PropRepostControl.GetName()
    /// </summary>
    /// <seealso cref="com.plumtree.xpshared.form.IRepostAS#GetRepostControlName()"></seealso>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return JobLogRepostControl.STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// This method is called by the Interpreter at the beginning of every HTTP
    /// request to determine whether or not the current user has the security
    /// privileges necessary to view the requested page.
    /// This method is designed for checking whether or not a particular user has
    /// any access to the space, page, and control.  More detailed checking (of
    /// query string parameters, for instance), should be done in the
    /// IControl.CheckActionSecurityAndExecute() method.
    /// For Plumtree portal applications (IPTActivitySpaces), since the IPTSession
    /// is guaranteed to be set before Init() & CheckBasicAccess() are called, you
    /// can check access as follows:
    /// return (GetIPTSession().GetSessionInfo().CheckForActivityRight
    /// (new Integer(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION))
    /// == 1);
    /// </summary>
    /// <param name="String">the requested IDisplayPage name (may be null for default)</param>
    /// <param name="String">the requested IControl name (may be null if not used)</param>
    /// <param name="boolean">
    /// true implies this is from an internal redirect from the same space
    /// false implies this is an URL from the user, or a redirect from
    /// another space.
    /// </param>
    /// <returns>boolean true implies access is allowed, false implies access is denied</returns>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      return ((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      // Job Log Model
      RegisterModel(JobLogModel.STR_MVC_CLASS_NAME);
      IModel myModel = GetModel(JobLogModel.STR_MVC_CLASS_NAME);
      // Job Log Display Page
      RegisterPage(new JobLogDisplayDP());
      // Job Log Download Page -- this needs to be registered after
      // the Job Log Model.
      RegisterPage(new JobLogDownloadDP());
      // Tree Form Views
      RegisterView(JobLogDisplayView.STR_MVC_CLASS_NAME, myModel);
      RegisterView(HistoryView.STR_MVC_CLASS_NAME, myModel);
      // Tree Form Controls
      RegisterControl(JobLogRepostControl.STR_MVC_CLASS_NAME, myModel);
    }
  }
}