using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
namespace com.plumtree.portalpages.common.joblogs
{
  /// <summary>
  /// This is a helper model class implemented to support the display and browsing
  /// of Job histories and job logs.
  /// </summary>
  /// <author>JohnH</author>
  public class JobLogModel : IRepostModel,IJobLogModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.joblogs.JobLogModel");
    
    /// <summary>
    /// Unique identifier for the model 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobLogModel";
    
    /// <summary>
    /// Unique identifier for filter from date picker 
    /// </summary>
    public const String FILTER_FROM = "DP_FilterFrom";
    
    /// <summary>
    /// Unique identifier for filter to date picker 
    /// </summary>
    public const String FILTER_TO = "DP_FilterTo";
    
    /// <summary>
    /// Unique identifier for delete through date picker 
    /// </summary>
    public const String DELETE_THROUGH = "DP_DeleteThrough";
    // Member variables
    
    /// <summary>
    /// JobLogHistory helper model 
    /// </summary>
    private JobLogModelHelper myModelHelper;
    //the user locale
    
    /// <summary>
    /// Member variable for the user's locale 
    /// </summary>
    private XPLocale m_Locale;
    //the user time zone
    
    /// <summary>
    /// Member variable for the user's time zone 
    /// </summary>
    private XPTimeZone m_Timezone;
    
    /// <summary>
    /// Member variable for the parent activity space 
    /// </summary>
    private AActivitySpace m_asOwner;
    // **********End member variables **************
    
    /// <summary>
    /// Inits the Model with the IPTSession.
    /// </summary>
    /// <param name="parent"></param>
    public virtual void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      myModelHelper = new JobLogModelHelper(parent, (IPTSession) parent.GetUserSession());
      //Get the locale
      String strLocaleID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE,
       parent);
      m_Locale = new XPLocale(strLocaleID);
      if (null == m_Locale)
      {
        m_Locale = XPLocale.GetDefault();
      }
      String strTimeZone = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE,
       parent);
      if (null != strTimeZone)
      {
        m_Timezone = XPTimeZone.GetTimeZone(strTimeZone);
      } else
      {
        m_Timezone = XPTimeZone.GetCurrentTimeZone();
      }
      myModelHelper.InitializeDatePickerMgrs(m_Locale, m_Timezone);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new JobLogModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#Finish()"></seealso>
    public virtual void Finish()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()"></seealso>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    // BEGIN ***************** repost action methods *****************
    
    /// <summary>
    /// Delete the job history from the passed in date and earlier
    /// </summary>
    /// <param name="xpdtDeleteFrom"></param>
    public virtual void DeleteJobHistory(XPDateTime xpdtDeleteFrom)
    {
      myModelHelper.DeleteJobHistory(xpdtDeleteFrom);
    }
    
    /// <summary>
    /// Returns the job viewer to non-search mode.
    /// </summary>
    /// <returns>void</returns>
    public virtual void ExitSearchMode()
    {
      myModelHelper.ExitSearchMode();
    }
    
    /// <summary>
    /// This function returns an int array of JobID's to be killed
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int[]</returns>
    public virtual int[] GetArrayOfJobsToKill(XPHashtable _htFormData)
    {
      return myModelHelper.GetArrayOfJobsToKill(_htFormData);
    }
    
    /// <summary>
    /// This function will send a kill message to each job that has been checked
    /// by the user.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void KillJobs(XPHashtable _htFormData)
    {
      myModelHelper.KillJobs(_htFormData);
    }
    
    /// <summary>
    /// Prepare the log file for download by setting it on a byte array member variable
    /// </summary>
    /// <param name="intInstanceID">- The instance ID of the job log</param>
    public virtual void RetrieveFileForDownload(int intInstanceID)
    {
      myModelHelper.RetrieveFileForDownload(intInstanceID);
    }
    // END ***************** repost action methods *****************
    //	BEGIN ***************** Get and Set methods *****************
    
    /// <summary>
    /// Returns whether the very last request is a search of the job log.
    /// </summary>
    /// <returns>int</returns>
    public virtual bool IsSearchRequest()
    {
      return myModelHelper.IsSearchRequest();
    }
    
    /// <summary>
    /// Returns a string used for searching the job log.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSearchString()
    {
      return myModelHelper.GetSearchString();
    }
    
    /// <summary>
    /// Returns the log page currently being displayed.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCurrentLogPage()
    {
      return myModelHelper.GetCurrentLogPage();
    }
    
    /// <summary>
    /// Returns CurrentPage setting.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCurrentPage()
    {
      return myModelHelper.GetCurrentPage();
    }
    
    /// <summary>
    /// Returns the jobID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetJobID()
    {
      return myModelHelper.GetJobID();
    }
    
    /// <summary>
    /// Returns the jobName.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetJobName()
    {
      return myModelHelper.GetJobName();
    }
    
    /// <summary>
    /// Returns the Plumtree Session object.
    /// </summary>
    /// <returns>IPTSession</returns>
    public virtual IPTSession GetPTSession()
    {
      return myModelHelper.GetPTSession();
    }
    
    /// <summary>
    /// Returns the job history row to display in the job log detail viewer.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetRowToDisplay()
    {
      return myModelHelper.GetRowToDisplay();
    }
    
    /// <summary>
    /// Returns the runTime.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetRunTime()
    {
      return myModelHelper.GetRunTime();
    }
    
    /// <summary>
    /// Sets the the search term and indicates a result page
    /// </summary>
    /// <param name="SearchTerm">to be applied against the log text</param>
    public virtual void SetLogSearchPage(String strSearchText)
    {
      myModelHelper.SetLogSearchPage(strSearchText);
    }
    
    /// <summary>
    /// Sets the the log page currently being displayed.
    /// </summary>
    /// <param name="currentLogPage">The currentLogPage to set</param>
    public virtual void SetCurrentLogPage(int currentLogPage)
    {
      myModelHelper.SetCurrentLogPage(currentLogPage);
    }
    
    /// <summary>
    /// Sets CurrentRecord setting.
    /// </summary>
    public virtual void SetCurrentPage(int _intCurrentPage)
    {
      myModelHelper.SetCurrentPage(_intCurrentPage);
    }
    
    /// <summary>
    /// Sets the jobID.
    /// </summary>
    /// <param name="jobID">The jobID to set</param>
    public virtual void SetJobID(int jobID)
    {
      myModelHelper.SetJobID(jobID);
    }
    
    /// <summary>
    /// Sets the jobName.
    /// </summary>
    /// <param name="jobName">The jobName to set</param>
    public virtual void SetJobName(String jobName)
    {
      myModelHelper.SetJobName(jobName);
    }
    
    /// <summary>
    /// Sets the job history row to display in the job log detail viewer.
    /// </summary>
    /// <param name="rowToDisplay">The rowToDisplay to set</param>
    public virtual void SetRowToDisplay(int rowToDisplay)
    {
      myModelHelper.SetRowToDisplay(rowToDisplay);
    }
    
    /// <summary>
    /// Sets the runTime.
    /// </summary>
    /// <param name="runTime">The runTime to set</param>
    public virtual void SetRunTime(String runTime)
    {
      myModelHelper.SetRunTime(runTime);
    }
    
    /// <summary>
    /// Returns the log file in byte array format
    /// </summary>
    /// <returns>byte[]</returns>
    public virtual byte[] GetLogFile()
    {
      return myModelHelper.GetLogFile();
    }
    
    /// <summary>
    /// Get the Date picker control manager
    /// </summary>
    /// <returns>JSDatePickerMgr</returns>
    public virtual JSDatePickerMgr GetDatePickerControlManager()
    {
      return myModelHelper.GetDatePickerControlManager();
    }
    // END ***************** Get and Set methods *****************
    // BEGIN ***************** save DP methods ***************** 
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String,XPHashtable)"></seealso>
    /// <returns>int Page status for server side validation</returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nSaveStatus = RepostControl.PAGE_STATUS_VALID;
      nSaveStatus = SaveHistoryPage(_htFormData);
      return nSaveStatus;
    }
    
    /// <summary>
    /// Saves the data on the History page.
    /// </summary>
    /// <param name="_htFormData"></param>
    private int SaveHistoryPage(XPHashtable _htFormData)
    {
      int intReturnValue = RepostControl.PAGE_STATUS_VALID;
      try
      {
        myModelHelper.GetPageMgr().StoreAllUserInput(_htFormData);
      }
      catch (Exception e)
      {
        intReturnValue = RepostControl.PAGE_STATUS_INVALID;
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"),
         "JobLogModel::SaveHistoryPage", e, false, UIErrorLevel.SERIOUS, m_asOwner.GetString(687,
         "ptmsgs_portalcommonmsgs"));
      }
      return intReturnValue;
    }
  }
}
// END ***************** save DP methods ***************** 
