/*
 * Created on Apr 12, 2003
 *
 * To change this generated comment go to
 * Window>Preferences>Java>Code Generation>Code Template
 */
 
using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.jsutil;
namespace com.plumtree.portalpages.common.joblogs
{
  /// <summary>
  /// This helper class contains the implementation of the functions that the Job Log Model
  /// needs.  Those functions have been moved to the helper class so they can be shared
  /// among multiple models (e.g. the intrinsic portlet model)
  /// </summary>
  /// <author>JohnH</author>
  public class JobLogModelHelper : IJobLogModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.joblogs.JobLogModelHelper");
    //	********** Begin member variables **************
    
    /// <summary>
    /// Server object: Plumtree Session 
    /// </summary>
    private IPTSession m_Session;
    
    /// <summary>
    /// Member variable for the parent activity space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// The name of the job whose log is being displayed 
    /// </summary>
    private String m_strJobName = "";
    
    /// <summary>
    /// The run time of the job whose log is being displayed 
    /// </summary>
    private String m_strRunTime = "";
    
    /// <summary>
    /// mbs- these are used for generating a search result page 
    /// </summary>
    private bool m_bNewSearch = false;
    
    /// <summary>
    /// mbs- Member variable for the search string 
    /// </summary>
    private String m_strSearchString;
    
    /// <summary>
    /// The page of the job log currently being displayed 
    /// </summary>
    private int m_intCurrentLogPage = 1;
    
    /// <summary>
    /// Member variable for the current job run page for history detail view (one based)  
    /// </summary>
    private int m_intCurrentPage = 1;
    
    /// <summary>
    /// The Job ID of the job whose log is being displayed. 
    /// </summary>
    private int m_intJobID = 0;
    
    /// <summary>
    /// The job history row to display when displaying the job log 
    /// </summary>
    private int m_intRowToDisplay = 0;
    
    /// <summary>
    /// Byte array containing the job log file being downloaded 
    /// </summary>
    private byte[] m_btarrLogFile;
    
    /// <summary>
    /// DateTime date picker manager 
    /// </summary>
    private JSDatePickerMgr m_ptJSDatePickerMgr;
    
    /// <summary>
    /// Page Manager object 
    /// </summary>
    private PageMgr m_ptPageMgr;
    // **********End member variables **************
    
    /// <summary>
    /// The constructor for the JobLogModelHelper class.
    /// </summary>
    /// <param name="parent">- The activity space this is being called from</param>
    /// <param name="session">- The user's plumtree session</param>
    public JobLogModelHelper(AActivitySpace parent, IPTSession session)
    {
      m_asOwner = parent;
      m_Session = session;
    }
    
    /// <summary>
    /// This function initializes the manager objects (Page and date) for the date pickers
    /// </summary>
    public virtual void InitializeDatePickerMgrs(XPLocale xpLocale, XPTimeZone xpTimeZone)
    {
      // Deal with the page manager
      String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
      m_ptPageMgr = new PageMgr(m_asOwner.GetAccessStyle(), xpLocale, xpTimeZone,
       strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      // Deal with the date/time-picker
      JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL,
       ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      m_ptJSDatePickerMgr = new JSDatePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(),
       m_ptPageMgr);
      m_ptPageMgr.RegisterComponentMgr(m_ptJSDatePickerMgr);
      ADatePickerComponent ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
      ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, JobLogModel.FILTER_FROM);
      m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);
      ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
      ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, JobLogModel.FILTER_TO);
      m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);
      ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
      ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, JobLogModel.DELETE_THROUGH);
      m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);
    }
    // BEGIN ***************** repost action methods *****************	
    
    /// <summary>
    /// Delete the job history from the passed in date and earlier
    /// </summary>
    /// <param name="xpdtDeleteFrom"></param>
    public virtual void DeleteJobHistory(XPDateTime xpdtDeleteFrom)
    {
      try
      {
        IPTScheduler ptScheduler = m_Session.GetScheduler();
        ptScheduler.DeleteJobHistory(xpdtDeleteFrom);
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"),
         "JobLogModel::DeleteJobHistory", e, false, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(104, "ptmsgs_portalcommonmsgs"));
      }
    }
    
    /// <summary>
    /// This function returns the viewer to simple read mode
    /// </summary>
    /// <param name="none"></param>
    /// <returns>void</returns>
    public virtual void ExitSearchMode()
    {
      m_bNewSearch = false;
    }
    
    /// <summary>
    /// This function returns an int array of JobID's to be killed
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int[]</returns>
    public virtual int[] GetArrayOfJobsToKill(XPHashtable _htFormData)
    {
      String sDataKey = HistoryViewHelper.HTMLCHECKBOX_JOBID;
      String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
      int[] aRowsToDelete = new int[aDataValue.Length];
      for (int i = 0;i < aDataValue.Length;i++)
      {
        try
        {
          aRowsToDelete[i] = XPConvert.ToInteger(aDataValue[i]);
        }
        catch (Exception e)
        {
          PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"),
           "JobLogModel::GetArrayOfJobsToKill", e, false, UIErrorLevel.SERIOUS,
           m_asOwner.GetString(688, "ptmsgs_portalcommonmsgs"));
        }
      }
      return aRowsToDelete;
    }
    
    /// <summary>
    /// This function will send a kill message to each job that has been checked
    /// by the user.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void KillJobs(XPHashtable _htFormData)
    {
      String sDataKey = HistoryViewHelper.HTMLCHECKBOX_JOBID;
      try
      {
        // JF- We get back the list of index of rows to delete.
        if (_htFormData.ContainsKey(sDataKey))
        {
          int[] aRowsToDelete = GetArrayOfJobsToKill(_htFormData);
          IPTScheduler ptScheduler = m_Session.GetScheduler();
          for (int i = 0;i < aRowsToDelete.Length;i++)
          {
            try
            {
              if (-1 != aRowsToDelete[i])
              {
                ptScheduler.KillRunningJob(aRowsToDelete[i], 0);
              }
            }
            // olegs: this is correct kill call, implementation has changed from DCOM to notification via DB
            // note that 0 soft kill timeout is ignored and hardcoded 3 min is used instead
            catch (XPException e)
            {
            }
          }
        }
      }
      // Avoid exception throwing, as exceptions thrown on job kill requests
      // likely owe to simply hitting the refresh button on jobs already in 
      // the process of being killed.
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"),
         "JobLogModel::KillJobs", e, false, UIErrorLevel.SERIOUS, m_asOwner.GetString(689,
         "ptmsgs_portalcommonmsgs"));
      }
    }
    
    /// <summary>
    /// Prepare the log file for download by setting it on a byte array member variable
    /// </summary>
    /// <param name="intInstanceID">- The instance ID of the job log</param>
    public virtual void RetrieveFileForDownload(int intInstanceID)
    {
      byte[] bytes = null;
      try
      {
        IPTScheduler ptScheduler = GetPTSession().GetScheduler();
        int intPageCount = ptScheduler.OpenLogForRead(intInstanceID, HistoryViewHelper.DETAILPAGESIZE);
        //Assuming a max of 250 characters per line, allocate the string size based on 
        //that, number of lines per page, and number of pages
        XPStringBuilder sb = new XPStringBuilder(250 * HistoryViewHelper.DETAILPAGESIZE * intPageCount);
        for (int i = 1;i <= intPageCount;i++)
        {
          Object[][] myResult = ptScheduler.GetPage(i);
          int intNumLines = myResult.Length;
          for (int j = 0;j < intNumLines;j++)
          {
            sb.Append(myResult[j][2]).Append("\r").Append("\n");
          }
        }
        //Return the byte array as UTF-8 (the default for XPStringUtility.GetBytes)
        bytes = XPStringUtility.GetBytes(sb.ToString());
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"),
         "JobLogModel::RetrieveFileForDownload", e, false, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(684, "ptmsgs_portalcommonmsgs"));
      }
      m_btarrLogFile = bytes;
    }
    // END ***************** repost action methods *****************
    // BEGIN ***************** Get and Set methods *****************
    
    /// <summary>
    /// Returns whether the very last request is a search of the job log.
    /// </summary>
    /// <returns>int</returns>
    public virtual bool IsSearchRequest()
    {
      bool bThisRequest = m_bNewSearch;
      return bThisRequest;
    }
    
    /// <summary>
    /// Returns a string used for searching the job log.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSearchString()
    {
      return m_strSearchString;
    }
    
    /// <summary>
    /// Returns the log page currently being displayed.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCurrentLogPage()
    {
      return m_intCurrentLogPage;
    }
    
    /// <summary>
    /// Returns CurrentPage setting.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCurrentPage()
    {
      return m_intCurrentPage;
    }
    
    /// <summary>
    /// Returns the jobID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetJobID()
    {
      return m_intJobID;
    }
    
    /// <summary>
    /// Returns the jobName.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetJobName()
    {
      return m_strJobName;
    }
    
    /// <summary>
    /// Returns the Plumtree Session object.
    /// </summary>
    /// <returns>IPTSession</returns>
    public virtual IPTSession GetPTSession()
    {
      return m_Session;
    }
    
    /// <summary>
    /// Returns the job history row to display in the job log detail viewer.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetRowToDisplay()
    {
      return m_intRowToDisplay;
    }
    
    /// <summary>
    /// Returns the runTime.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetRunTime()
    {
      return m_strRunTime;
    }
    
    /// <summary>
    /// Returns the log file in byte array format
    /// </summary>
    /// <returns>byte[]</returns>
    public virtual byte[] GetLogFile()
    {
      // Force the cleanup of m_btarrLogFile.  Don't want to keep it around in memory
      byte[] logfile = m_btarrLogFile;
      m_btarrLogFile = null;
      return logfile;
    }
    
    /// <summary>
    /// Sets the the search term and indicates a result page
    /// </summary>
    /// <param name="SearchTerm">to be applied against the log text</param>
    public virtual void SetLogSearchPage(String strSearchText)
    {
      m_bNewSearch = true;
      m_strSearchString = strSearchText;
    }
    
    /// <summary>
    /// Sets the the log page currently being displayed.
    /// </summary>
    /// <param name="currentLogPage">The currentLogPage to set</param>
    public virtual void SetCurrentLogPage(int currentLogPage)
    {
      m_intCurrentLogPage = currentLogPage;
    }
    
    /// <summary>
    /// Sets CurrentRecord setting.
    /// </summary>
    public virtual void SetCurrentPage(int _intCurrentPage)
    {
      m_intCurrentPage = _intCurrentPage;
    }
    
    /// <summary>
    /// Sets the jobID.
    /// </summary>
    /// <param name="jobID">The jobID to set</param>
    public virtual void SetJobID(int jobID)
    {
      m_intJobID = jobID;
    }
    
    /// <summary>
    /// Sets the jobName.
    /// </summary>
    /// <param name="jobName">The jobName to set</param>
    public virtual void SetJobName(String jobName)
    {
      m_strJobName = jobName;
    }
    
    /// <summary>
    /// Sets the job history row to display in the job log detail viewer.
    /// </summary>
    /// <param name="rowToDisplay">The rowToDisplay to set</param>
    public virtual void SetRowToDisplay(int rowToDisplay)
    {
      m_intRowToDisplay = rowToDisplay;
    }
    
    /// <summary>
    /// Sets the runTime.
    /// </summary>
    /// <param name="runTime">The runTime to set</param>
    public virtual void SetRunTime(String runTime)
    {
      m_strRunTime = runTime;
    }
    
    /// <summary>
    /// Get the Date picker control manager
    /// </summary>
    /// <returns>JSDatePickerMgr</returns>
    public virtual JSDatePickerMgr GetDatePickerControlManager()
    {
      return m_ptJSDatePickerMgr;
    }
    
    /// <returns>PageMgr</returns>
    public virtual PageMgr GetPageMgr()
    {
      return m_ptPageMgr;
    }
  }
}
// END ***************** Get and Set methods *****************
