using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
namespace com.plumtree.portalpages.common.joblogs
{
  /// <summary>
  /// Performs repost actions for the Job history and job log helper package
  /// </summary>
  /// <author>JohnH</author>
  public class JobLogRepostControl : RepostControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.joblogs.JobLogRepostControl");
    
    /// <summary>
    /// The unique identifier for the class 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobLogRepost";
    //Repost actions
    
    /// <summary>
    /// Delete history repost action 
    /// </summary>
    public const int POSTTOSELF_ACTION_DELETEHISTORY = 21;
    
    /// <summary>
    /// Move to the first history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_FIRSTHISTORYPAGE = 22;
    
    /// <summary>
    /// Move to the previous history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE = 23;
    
    /// <summary>
    /// Move to the next history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_NEXTHISTORYPAGE = 24;
    
    /// <summary>
    /// Move to the last history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_LASTHISTORYPAGE = 25;
    
    /// <summary>
    /// Pop up the job detail window 
    /// </summary>
    public const int POSTTOSELF_ACTION_JOBDETAIL_POPUP = 30;
    
    /// <summary>
    /// Move to the first log page 
    /// </summary>
    public const int POSTTOSELF_ACTION_FIRSTLOGPAGE = 31;
    
    /// <summary>
    /// Move to the previous log page 
    /// </summary>
    public const int POSTTOSELF_ACTION_PREVIOUSLOGPAGE = 32;
    
    /// <summary>
    /// Move to the next log page 
    /// </summary>
    public const int POSTTOSELF_ACTION_NEXTLOGPAGE = 33;
    
    /// <summary>
    /// Move to the last log page 
    /// </summary>
    public const int POSTTOSELF_ACTION_LASTLOGPAGE = 34;
    
    /// <summary>
    /// Search the job log 
    /// </summary>
    public const int POSTTOSELF_ACTION_LOGSEARCH = 35;
    
    /// <summary>
    /// Jump to a page in the job log 
    /// </summary>
    public const int POSTTOSELF_ACTION_JUMPTOPAGE = 36;
    
    /// <summary>
    /// Abort job action 
    /// </summary>
    public const int POSTTOSELF_ACTION_ABORT = 40;
    
    /// <summary>
    /// Download file action 
    /// </summary>
    public const int POSTTOSELF_ACTION_DOWNLOAD = 37;
    
    /// <summary>
    /// Exit the search view 
    /// </summary>
    public const int POSTTOSELF_ACTION_EXITSEARCH = 39;
    //Constant for delete vs. filter mode
    
    /// <summary>
    /// Filter mode 
    /// </summary>
    public const int FILTERMODE = 1;
    protected AActivitySpace m_asOwner = null;
    protected IModel m_model = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public override void Init(IModel model, AActivitySpace space)
    {
      base.Init(model, space);
      // Store these for use later.
      m_asOwner = space;
      m_model = model;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobLogRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.form.RepostControl#SetRepostAction()
     */
     
    protected override void SetRepostAction()
    {
      // JHQ for issue 36772: super.CheckActionSecurityAndExecute() will treate LOW_BANDWIDTH 
      // the same as 508 and therefore look for in_su508PostToSelf_ instead of PostToSelf.
      // But in LB we can execute javascript and we use PostToSelf.
      if (AccessStyles.LOW_BANDWIDTH == m_asOwner.GetAccessStyle())
      {
        if (m_htFormData.ContainsKey(HTMLINPUT_POSTTOSELF))
        {
          String[] data = (String[]) m_htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
          if ((0 != data.Length) && (null != data[0]))
          {
            m_nAction = XPConvert.ToInteger(data[0]);
            log.Debug("JobLogRepostControl::SetRepostAction Repost action ID value: " + m_nAction);
            } else
          {
            log.Warn("JobLogRepostControl::SetRepostAction Repost action ID was not in Query String.");
            }
        }
      } else
      {
        base.SetRepostAction();
      }
    }
    // AGC- Added this in order to make this jumpable - note,
    // you can't change PerformAction to be public because the
    // super method is not public.
    public virtual void PublicPerformAction(int _nAction)
    {
      PerformAction(_nAction);
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      base.PerformAction(_nAction);
      switch (_nAction){
      case POSTTOSELF_ACTION_DELETEHISTORY:
      //Delete the job history
      JSDatePickerMgr myMgr = ((IJobLogModelRO) m_model).GetDatePickerControlManager();
      JSDatePicker myDatePicker = (JSDatePicker) myMgr.GetComponent(JobLogModel.DELETE_THROUGH);
      String strDeleteFrom = myDatePicker.GetSelectedDateAsString();
      if (!(strDeleteFrom.Equals("")))
      {
        XPDateFormat myDateFormat = XPDateFormat.GetDateInstance(XPDateFormat.MEDIUM);
        ((JobLogModel) m_model).DeleteJobHistory(myDateFormat.Parse(strDeleteFrom));
        }
      break;
      case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
      SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_FIRSTHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
      SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
      SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_NEXTHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_LASTHISTORYPAGE:
      SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_LASTHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_JOBDETAIL_POPUP:
      PerformJobDetailPopupAction(m_htFormData);
      break;
      case POSTTOSELF_ACTION_FIRSTLOGPAGE:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_FIRSTLOGPAGE);
      break;
      case POSTTOSELF_ACTION_PREVIOUSLOGPAGE:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_PREVIOUSLOGPAGE);
      break;
      case POSTTOSELF_ACTION_NEXTLOGPAGE:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_NEXTLOGPAGE);
      break;
      case POSTTOSELF_ACTION_LASTLOGPAGE:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_LASTLOGPAGE);
      break;
      case POSTTOSELF_ACTION_LOGSEARCH:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_LOGSEARCH);
      break;
      case POSTTOSELF_ACTION_JUMPTOPAGE:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_JUMPTOPAGE);
      break;
      case POSTTOSELF_ACTION_EXITSEARCH:
      SetNewPage(m_htFormData, POSTTOSELF_ACTION_EXITSEARCH);
      break;
      case POSTTOSELF_ACTION_ABORT:
      AbortJob(m_htFormData);
      break;
      case POSTTOSELF_ACTION_DOWNLOAD:
      //First, place the appropriate log file on the model
      int intInstanceID = 0;
      String strInstanceID = ((String[]) m_htFormData.GetElement(HistoryViewHelper.HTMLHIDDEN_ACTIVEINSTANCE))[0];
      if (null != strInstanceID)
      {
        intInstanceID = XPConvert.ToInteger(strInstanceID);
      }
      if (intInstanceID > 0)
      {
        ((JobLogModel) m_model).RetrieveFileForDownload(intInstanceID);
        //Then, redirect to the download display page
        Redirect repostURL = new Redirect();
        repostURL.SetLinkGetCachedSpace(m_asOwner);
        //repostURL.SetLinkGetCachedSpace(m_asOwner);
        repostURL.SetControl(STR_MVC_CLASS_NAME);
        repostURL.SetDisplayPage(JobLogDownloadDP.STR_MVC_CLASS_NAME);
        SetRedirect(repostURL);
      }
      break;
      }
    }
    public virtual void MyPerformReadOnlyAction(int _nAction, XPHashtable m_htFormData_Copy)
    {
      switch (_nAction){
      case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
      case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
      case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
      case POSTTOSELF_ACTION_LASTHISTORYPAGE:
      m_htFormData = m_htFormData_Copy;
      PerformAction(_nAction);
      m_htFormData_Copy = null;
      break;
      case POSTTOSELF_ACTION_ABORT:
      // refresh
      case POSTTOSELF_ACTION_SIMPLEREPOST:
      case POSTTOSELF_ACTION_DOWNLOAD:
      if (m_htFormData == null)
      {
        m_htFormData = m_htFormData_Copy;
      }
      PerformAction(_nAction);
      m_htFormData_Copy = null;
      break;
      default:
      // TODO: alert
      break;
      }
    }
    
    /// <summary>
    /// JH- PerformJobDetailPopupAction handles the case where a popup is being
    /// displayed
    /// </summary>
    /// <param name="_htFormData">is a hashtable that stores the form post data and querystring</param>
    private void PerformJobDetailPopupAction(XPHashtable _htFormData)
    {
      // MBS- Always make certain we open in read mode
      ((JobLogModel) m_model).ExitSearchMode();
      //JH- Get the row number of the item we're displaying and store it in the Model, where
      //	the Form can get to it.
      ((JobLogModel) m_model).SetRowToDisplay(XPConvert.ToInteger(((String[]) _htFormData.GetElement(HistoryViewHelper.POPUP_CONTROL_ARG_ROWTOVIEW))[0]));
      ((JobLogModel) m_model).SetJobName(((String[]) _htFormData.GetElement(HistoryViewHelper.POPUP_CONTROL_ARG_JOBNAME))[0]);
      ((JobLogModel) m_model).SetRunTime(((String[]) _htFormData.GetElement(HistoryViewHelper.POPUP_CONTROL_ARG_RUNTIME))[0]);
      //Reset the current page of the job log to display back to 1
      ((JobLogModel) m_model).SetCurrentLogPage(1);
    }
    
    /// <summary>
    /// JH- SetNewHistoryPageID sets the History Page ID on the model so the
    /// HistoryDetailView can know which page of the job history to display
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <param name="intAction">- The action to take: First, Previous, Next, Last</param>
    private void SetNewHistoryPageID(XPHashtable _htFormData, int intAction)
    {
      int intCurrentPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(HistoryViewHelper.HTMLHIDDEN_CURRENTPAGE))[0]);
      int intLastPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(HistoryViewHelper.HTMLHIDDEN_LASTPAGE))[0]);
      //set the appropriate BlockID based on the action
      switch (intAction){
      case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
      ((JobLogModel) m_model).SetCurrentPage(1);
      break;
      case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
      ((JobLogModel) m_model).SetCurrentPage(intCurrentPage - 1);
      break;
      case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
      ((JobLogModel) m_model).SetCurrentPage(intCurrentPage + 1);
      break;
      case POSTTOSELF_ACTION_LASTHISTORYPAGE:
      ((JobLogModel) m_model).SetCurrentPage(intLastPage);
      break;
      }
    }
    private void AbortJob(XPHashtable _htFormData)
    {
      //Send a kill message to the job or jobs
      try
      {
        ((JobLogModel) m_model).KillJobs(_htFormData);
      }
      catch (Exception e)
      {
        log.Error("JobLogRepostModel::AbortJob " + m_asOwner.GetString(632,
         "ptmsgs_portalcommonmsgs") + e);
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(632, "ptmsgs_portalcommonmsgs") + e, "");
        myError.SetActivitySpace(m_asOwner.GetName());
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
    
    /// <summary>
    /// JH- SetNewPage sets the page on the model so the JobLogDisplayView can
    /// know which page of the job log to display
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <param name="intAction">- The action to take: First, Previous, Next, Last</param>
    private void SetNewPage(XPHashtable _htFormData, int intAction)
    {
      int intCurrentPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(JobLogDisplayView.HTMLHIDDEN_CURRENTPAGE))[0]);
      int intLastPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(JobLogDisplayView.HTMLHIDDEN_LASTPAGE))[0]);
      //set the appropriate BlockID based on the action
      switch (intAction){
      case POSTTOSELF_ACTION_FIRSTLOGPAGE:
      ((JobLogModel) m_model).SetCurrentLogPage(1);
      break;
      case POSTTOSELF_ACTION_PREVIOUSLOGPAGE:
      ((JobLogModel) m_model).SetCurrentLogPage(intCurrentPage - 1);
      break;
      case POSTTOSELF_ACTION_NEXTLOGPAGE:
      ((JobLogModel) m_model).SetCurrentLogPage(intCurrentPage + 1);
      break;
      case POSTTOSELF_ACTION_LASTLOGPAGE:
      ((JobLogModel) m_model).SetCurrentLogPage(intLastPage);
      break;
      case POSTTOSELF_ACTION_LOGSEARCH:
      ((JobLogModel) m_model).SetCurrentLogPage(1);
      String strTargetText = ((String[]) _htFormData.GetElement(JobLogDisplayView.HTMLINPUT_SEARCHBOX))[0];
      ((JobLogModel) m_model).SetLogSearchPage(strTargetText);
      break;
      case POSTTOSELF_ACTION_JUMPTOPAGE:
      ((JobLogModel) m_model).ExitSearchMode();
      int intJumpToPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(JobLogDisplayView.HTMLHIDDEN_JUMPTOPAGE))[0]);
      ((JobLogModel) m_model).SetCurrentLogPage(intJumpToPage);
      break;
      case POSTTOSELF_ACTION_EXITSEARCH:
      ((JobLogModel) m_model).SetCurrentLogPage(1);
      ((JobLogModel) m_model).ExitSearchMode();
      break;
      }
    }
  }
}