using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.datepicker;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.jsutil;
namespace com.plumtree.portalpages.common.linksettings
{
  /// <summary>
  /// This Model contains the state of the LinkSettings plug-in section.
  /// </summary>
  /// <author>StephenC</author>
  public class LinkSettingsPlugInModel : EditorHelperModel,ILinkSettingsPlugInModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.linksettings.LinkSettingsPlugInModel");
    public const String STR_MVC_CLASS_NAME = "LinkSettingsPlugIn";
    public IPTCardRefreshInfo m_ptCardRefreshInfo = null;
    public XPDateTime m_xpExpirationDate = null;
    public XPDateTime m_xpLastRefreshDate = null;
    public XPDateTime m_xpNextRefreshDate = null;
    public bool m_bIsCrawlerLinkSettings = false;
    public bool m_bMultipleCards = false;
    public int m_nBrokenLinksDeleteUnits;
    public int m_nBrokenLinksDeleteValue;
    public bool m_bCheckLinkOnly;
    public int m_nExpireAfterUnits;
    public int m_nExpireAfterValue;
    // Link Settings
    public int m_nRefreshUnits;
    public int m_nRefreshValue;
    //the user locale
    
    /// <summary>
    /// Member variable containing the editing user's locale 
    /// </summary>
    private XPLocale m_Locale;
    //the user time zone
    
    /// <summary>
    /// Member variable containing the editing user's time zone 
    /// </summary>
    private XPTimeZone m_Timezone;
    
    /// <summary>
    /// DateTime date picker manager 
    /// </summary>
    private JSDateTimePickerMgr m_ptJSDateTimePickerMgr;
    
    /// <summary>
    /// Page Manager object 
    /// </summary>
    private PageMgr m_ptPageMgr;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new LinkSettingsPlugInModel();
    }
    
    /// <returns></returns>
    public virtual int GetBrokenLinksDeleteUnits()
    {
      return m_nBrokenLinksDeleteUnits;
    }
    
    /// <returns></returns>
    public virtual int GetBrokenLinksDeleteValue()
    {
      return m_nBrokenLinksDeleteValue;
    }
    
    /// <returns></returns>
    public virtual IPTCardRefreshInfo GetCardRefreshInfo()
    {
      m_ptCardRefreshInfo.SetCardRefreshRate(GetRefreshUnits(), GetRefreshValue());
      m_ptCardRefreshInfo.SetCardMissingDocumentDeletionDelay(GetBrokenLinksDeleteUnits(),
       GetBrokenLinksDeleteValue());
      m_ptCardRefreshInfo.SetCheckLinkOnly(GetCheckLinkOnly());
      XPDateTime ptDate;
      ptDate = GetNextRefreshDate();
      if (DateTimeConstant.dtNull.GetTimeInMilliSeconds() == ptDate.GetTimeInMilliSeconds())
      {
        m_ptCardRefreshInfo.SetCardNextRefreshDate(null);
      } else
      {
        m_ptCardRefreshInfo.SetCardNextRefreshDate(ptDate);
      }
      ptDate = GetExpirationDate();
      if (DateTimeConstant.dtNull.GetTimeInMilliSeconds() == ptDate.GetTimeInMilliSeconds())
      {
        m_ptCardRefreshInfo.SetCardExpirationDate(null);
      } else
      {
        m_ptCardRefreshInfo.SetCardExpirationDate(ptDate);
      }
      return m_ptCardRefreshInfo;
    }
    
    /// <returns></returns>
    public virtual bool GetCheckLinkOnly()
    {
      return m_bCheckLinkOnly;
    }
    
    /// <returns></returns>
    public virtual XPDateTime GetDisplayExpirationDate()
    {
      XPDateTime ptExpireOn = GetExpirationDate();
      if (DateTimeConstant.dtNull.Equals(ptExpireOn))
      {
        // Add a year
        XPCalendar gcNewExpireDate = XPCalendar.GetInstance();
        gcNewExpireDate.Add(ConvertCalendarUnit(PT_SCHEDULETYPES.PT_SCHEDULETYPE_ANNUALY),
         1);
        return gcNewExpireDate.GetTime();
      } else
      {
        return ptExpireOn;
      }
    }
    
    /// <returns></returns>
    public virtual XPDateTime GetExpirationDate()
    {
      if (null == m_xpExpirationDate)
      {
        return DateTimeConstant.dtNull;
      } else
      {
        return m_xpExpirationDate;
      }
    }
    
    /// <returns></returns>
    public virtual int GetExpireAfterUnits()
    {
      return m_nExpireAfterUnits;
    }
    
    /// <returns></returns>
    public virtual int GetExpireAfterValue()
    {
      return m_nExpireAfterValue;
    }
    
    /// <returns></returns>
    public virtual XPDateTime GetLastRefreshedDate()
    {
      if (null == m_xpLastRefreshDate)
      {
        return DateTimeConstant.dtNull;
      } else
      {
        return m_xpLastRefreshDate;
      }
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual XPDateTime GetNextRefreshDate()
    {
      if (null == m_xpNextRefreshDate)
      {
        return DateTimeConstant.dtNull;
      } else
      {
        return m_xpNextRefreshDate;
      }
    }
    
    /// <returns></returns>
    public virtual int GetRefreshUnits()
    {
      return m_nRefreshUnits;
    }
    
    /// <returns></returns>
    public virtual int GetRefreshValue()
    {
      return m_nRefreshValue;
    }
    // END ***************** helper methods ***************** 
    
    /// <summary>
    /// To initialize this plug-in you need to set the DP name
    /// and the default value of the plug-in setting.
    /// </summary>
    /// <param name="_sPlugInSetting"></param>
    public virtual void InitializePlugIn(bool bMultipleCards, IPTCardRefreshInfo ptRefreshSettings)
    {
      Object oDate;
      m_ptCardRefreshInfo = ptRefreshSettings;
      m_bMultipleCards = bMultipleCards;
      m_bIsCrawlerLinkSettings = false;
      SetRefreshUnits(m_ptCardRefreshInfo.GetCardRefreshRateUnits());
      SetRefreshValue(m_ptCardRefreshInfo.GetCardRefreshRateValue());
      SetCheckLinkOnly(m_ptCardRefreshInfo.GetCheckLinkOnly());
      SetBrokenLinksDeleteUnits(m_ptCardRefreshInfo.GetCardMissingDocumentDeletionDelayUnits());
      SetBrokenLinksDeleteValue(m_ptCardRefreshInfo.GetCardMissingDocumentDeletionDelayValue());
      oDate = m_ptCardRefreshInfo.GetCardNextRefreshDateAsObject();
      SetNextRefreshDate((null == oDate) ? DateTimeConstant.dtNull : (XPDateTime) oDate);
      oDate = m_ptCardRefreshInfo.GetCardLastRefreshedDate();
      SetLastRefreshedDate((null == oDate) ? DateTimeConstant.dtNull : (XPDateTime) oDate);
      oDate = m_ptCardRefreshInfo.GetCardExpirationDateAsObject();
      SetExpirationDate((null == oDate) ? DateTimeConstant.dtNull : (XPDateTime) oDate);
      InitializeCommon();
    }
    
    /// <summary>
    /// To initialize this plug-in you need to set the DP name
    /// and the default value of the plug-in setting.
    /// </summary>
    /// <param name="_sPlugInSetting"></param>
    public virtual void InitializePlugInForCrawlers(int nRefreshRateUnits,
     int nRefreshRateValue, bool bCheckLinkOnly, int nDeleteUnits, int nDeleteValue,
     int nExpireAfterUnits, int nExpireAfterValue)
    {
      m_ptCardRefreshInfo = null;
      m_bMultipleCards = true;
      m_bIsCrawlerLinkSettings = true;
      SetRefreshUnits(nRefreshRateUnits);
      SetRefreshValue(nRefreshRateValue);
      SetCheckLinkOnly(bCheckLinkOnly);
      SetBrokenLinksDeleteUnits(nDeleteUnits);
      SetBrokenLinksDeleteValue(nDeleteValue);
      SetExpireAfterUnits(nExpireAfterUnits);
      SetExpireAfterValue(nExpireAfterValue);
      InitializeCommon();
    }
    
    /// <summary>
    /// This function initializes the manager objects (Page and datetime) for the date pickers
    /// </summary>
    public virtual void InitializeCommon()
    {
      //Get the locale
      m_Locale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner);
      if (null == m_Locale)
      {
        m_Locale = XPLocale.GetDefault();
      }
      //Get the timezone
      m_Timezone = PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner);
      if (null == m_Timezone)
      {
        m_Timezone = XPTimeZone.GetCurrentTimeZone();
      }
      // Deal with the page manager
      String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
      m_ptPageMgr = new PageMgr(m_asOwner.GetAccessStyle(), m_Locale, m_Timezone,
       strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      // Deal with the date/time-picker
      JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL,
       ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      m_ptJSDateTimePickerMgr = new JSDateTimePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(),
       m_ptPageMgr);
      m_ptPageMgr.RegisterComponentMgr(m_ptJSDateTimePickerMgr);
      XPDateTime dtExpireOnDate = GetDisplayExpirationDate();
      ADatePickerComponent ptDatePicker1 = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
      ptDatePicker1.Init(AFormDP.HTMLFORM_NAME, dtExpireOnDate, m_ptPageMgr,
       LinkSettingsPlugInView.EXPIRE_ON_DATEPICKER);
      //m_ptJSDateTimePickerMgr.RegisterComponent(ptDatePicker1);
      m_ptJSDateTimePickerMgr = (JSDateTimePickerMgr) m_ptPageMgr.GetComponentMgr("DateTimePicker");
      }
    
    /// <summary>
    /// Get the Date Time picker control manager
    /// </summary>
    /// <returns>JSDateTimePickerMgr</returns>
    public virtual JSDateTimePickerMgr GetDateTimePickerControlManager()
    {
      return m_ptJSDateTimePickerMgr;
    }
    
    /// <returns></returns>
    public virtual bool IsCrawler()
    {
      return m_bIsCrawlerLinkSettings;
    }
    
    /// <returns></returns>
    public virtual bool IsExpirationDateNull()
    {
      return (DateTimeConstant.dtNull.Equals(GetExpirationDate()));
    }
    
    /// <returns></returns>
    public virtual bool IsMultiple()
    {
      return m_bMultipleCards;
    }
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int Status for server side validation</returns>
    public override int SaveSection(XPHashtable _htFormData)
    {
      int nRetVal = RepostControl.PAGE_STATUS_VALID;
      // save the changes to the date/time picker 
      m_ptJSDateTimePickerMgr.StoreAllUserInput(_htFormData);
      String[] data;
      // Expiration Settings
      data = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLRADIO_EXPIRATION);
      if ((null != data) && !(0 == data.Length))
      {
        int nExpirationSettingOption = XPConvert.ToInteger(data[0]);
        if (0 == nExpirationSettingOption)
        {
          if (m_bIsCrawlerLinkSettings)
          {
            SetExpireAfterUnits(PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER);
            SetExpireAfterValue(1);
          } else
          {
            SetExpirationDate(DateTimeConstant.dtNull);
          }
        } else
        // deleted on / after
        {
          if (m_bIsCrawlerLinkSettings)
          {
            String[] strExpireAfter = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLINPUT_EXPIREAFTERVALUE);
            int nExpireAfterNum = 1;
            int nExpireAfterUnit = PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER;
            if ((null != strExpireAfter) && !(0 == strExpireAfter.Length))
            {
              nExpireAfterNum = XPConvert.ToInteger(strExpireAfter[0]);
            } else
            {
              log.Warn("CardEditorModel::SaveLinkSettingsPage Expire After Setting was not in Query String.");
              }
            strExpireAfter = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLSELECT_EXPIREAFTERUNIT);
            if ((null != strExpireAfter) && !(0 == strExpireAfter.Length))
            {
              nExpireAfterUnit = XPConvert.ToInteger(strExpireAfter[0]);
            } else
            {
              log.Warn("CardEditorModel::SaveLinkSettingsPage Expire After Setting was not in Query String.");
              }
            SetExpireAfterUnits(nExpireAfterUnit);
            SetExpireAfterValue(nExpireAfterNum);
          } else
          {
            JSDateTimePicker ptJSDateTimePicker = (JSDateTimePicker) m_ptJSDateTimePickerMgr.GetComponent(LinkSettingsPlugInView.EXPIRE_ON_DATEPICKER);
            XPDateTime xpdtDeleteOn = ptJSDateTimePicker.GetDateTimeAsDateTime();
            try
            {
              SetExpirationDate(xpdtDeleteOn);
            }
            catch (Exception e)
            {
              log.Error(e, "LinkSettingsPlugInModel::SaveSection The following error occured when trying to parse a date string: " + e.Message);
              }
          }
        }
      } else
      {
        log.Warn("CardEditorModel::SaveLinkSettingsPage Expiration Settings were not in Query String.");
        }
      // Refresh Settings
      data = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLRADIO_REFRESH);
      if ((null != data) && !(0 == data.Length))
      {
        String[] strRefreshEvery = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLINPUT_REFRESHEVERYVALUE);
        int nRefreshEveryNum = 0;
        int nRefreshEveryUnit = PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER;
        if ((null != strRefreshEvery) && !(0 == strRefreshEvery.Length))
        {
          nRefreshEveryNum = XPConvert.ToInteger(strRefreshEvery[0]);
        } else
        {
          log.Warn("CardEditorModel::SaveLinkSettingsPage Refresh Every Setting was not in Query String.");
          }
        strRefreshEvery = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLSELECT_REFRESHEVERYUNIT);
        if ((null != strRefreshEvery) && !(0 == strRefreshEvery.Length))
        {
          nRefreshEveryUnit = XPConvert.ToInteger(strRefreshEvery[0]);
        } else
        {
          log.Warn("CardEditorModel::SaveLinkSettingsPage Refresh Every Setting was not in Query String.");
          }
        int nRefreshSettingOption = XPConvert.ToInteger(data[0]);
        if (0 == nRefreshSettingOption)
        // never refresh
        {
          SetRefreshUnits(PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER);
          SetRefreshValue(nRefreshEveryNum);
          SetNextRefreshDate(DateTimeConstant.dtNull);
        } else
        // refresh every
        {
          SetRefreshUnits(nRefreshEveryUnit);
          SetRefreshValue(nRefreshEveryNum);
          if (false == m_bIsCrawlerLinkSettings)
          {
            // Calculate Next refresh date from Last Refresh Date
            XPDateTime dtLastRefreshDate = GetLastRefreshedDate();
            if (DateTimeConstant.dtNull.Equals(dtLastRefreshDate))
            {
              //set to current time
              dtLastRefreshDate = new XPDateTime();
            }
            XPCalendar xpcDateNextRefresh = XPCalendar.GetInstance();
            xpcDateNextRefresh.SetTime(dtLastRefreshDate);
            xpcDateNextRefresh.Add(ConvertCalendarUnit(nRefreshEveryUnit),
             nRefreshEveryNum);
            XPDateTime dtNextRefreshDate = xpcDateNextRefresh.GetTime();
            SetNextRefreshDate(dtNextRefreshDate);
          }
        }
      } else
      {
        log.Warn("CardEditorModel::SaveLinkSettingsPage Refresh Settings were not in Query String.");
        }
      // Check Validity Setting
      data = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLCHECKBOX_LINKVALIDITY);
      if ((null != data) && !(0 == data.Length))
      {
        // This box is checked
        SetCheckLinkOnly(true);
      } else
      {
        SetCheckLinkOnly(false);
      }
      // Broken Link Settings
      data = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLRADIO_BROKENLINKS);
      if ((null != data) && !(0 == data.Length))
      {
        int nBrokenLinkOption = XPConvert.ToInteger(data[0]);
        // Get Broken Links Value
        String[] strBrokenLinks = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLINPUT_BROKENDELETEVALUE);
        int nBrokenLinksNum = 0;
        if ((null != strBrokenLinks) && !(0 == strBrokenLinks.Length))
        {
          nBrokenLinksNum = XPConvert.ToInteger(strBrokenLinks[0]);
        } else
        {
          log.Warn("CardEditorModel::SaveLinkSettingsPage Broken Link Delete After was not in Query String.");
          }
        // Get Broken Links Unit
        strBrokenLinks = (String[]) _htFormData.GetElement(LinkSettingsPlugInView.HTMLSELECT_BROKENDELETEUNIT);
        int nBrokenLinksUnits = PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER;
        if ((null != strBrokenLinks) && !(0 == strBrokenLinks.Length))
        {
          nBrokenLinksUnits = XPConvert.ToInteger(strBrokenLinks[0]);
        } else
        {
          log.Warn("CardEditorModel::SaveLinkSettingsPage Broken Link Delete After was not in Query String.");
          }
        SetBrokenLinksDeleteValue(nBrokenLinksNum);
        if (0 == nBrokenLinkOption)
        // left alone
        {
          SetBrokenLinksDeleteUnits(PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER);
          } else
        if (1 == nBrokenLinkOption)
        // deleted immediately
        {
          SetBrokenLinksDeleteUnits(PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE);
          } else
        // deleted after
        {
          SetBrokenLinksDeleteUnits(nBrokenLinksUnits);
        }
      } else
      {
        log.Warn("CardEditorModel::SaveLinkSettingsPage Broken Link Settings were not in Query String.");
        }
      return nRetVal;
    }
    
    /// <param name="nUnits"></param>
    public virtual void SetBrokenLinksDeleteUnits(int nUnits)
    {
      m_nBrokenLinksDeleteUnits = nUnits;
    }
    
    /// <param name="nValue"></param>
    public virtual void SetBrokenLinksDeleteValue(int nValue)
    {
      m_nBrokenLinksDeleteValue = nValue;
    }
    
    /// <param name="nValue"></param>
    public virtual void SetCheckLinkOnly(bool bCheckLinkOnly)
    {
      m_bCheckLinkOnly = bCheckLinkOnly;
    }
    
    /// <param name="ptDate"></param>
    public virtual void SetExpirationDate(XPDateTime ptDate)
    {
      if (DateTimeConstant.dtNull.GetTimeInMilliSeconds() == ptDate.GetTimeInMilliSeconds())
      {
        m_xpExpirationDate = null;
      } else
      {
        m_xpExpirationDate = ptDate;
      }
    }
    
    /// <param name="nUnits"></param>
    public virtual void SetExpireAfterUnits(int nUnits)
    {
      m_nExpireAfterUnits = nUnits;
    }
    
    /// <param name="nValue"></param>
    public virtual void SetExpireAfterValue(int nValue)
    {
      m_nExpireAfterValue = nValue;
    }
    
    /// <param name="ptDate"></param>
    public virtual void SetLastRefreshedDate(XPDateTime ptDate)
    {
      if (DateTimeConstant.dtNull.GetTimeInMilliSeconds() == ptDate.GetTimeInMilliSeconds())
      {
        m_xpLastRefreshDate = null;
      } else
      {
        m_xpLastRefreshDate = ptDate;
      }
    }
    
    /// <param name="ptDate"></param>
    public virtual void SetNextRefreshDate(XPDateTime ptDate)
    {
      if (DateTimeConstant.dtNull.GetTimeInMilliSeconds() == ptDate.GetTimeInMilliSeconds())
      {
        m_xpNextRefreshDate = null;
      } else
      {
        m_xpNextRefreshDate = ptDate;
      }
    }
    // set
    public virtual void SetRefreshUnits(int nUnits)
    {
      m_nRefreshUnits = nUnits;
    }
    
    /// <param name="nValue"></param>
    public virtual void SetRefreshValue(int nValue)
    {
      m_nRefreshValue = nValue;
    }
    // ***CHANGE_HERE*** Put your set/get methods and other helper methods
    // BEGIN ***************** helper methods ***************** 
    private int ConvertCalendarUnit(int unit)
    {
      switch (unit){
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_ANNUALY:
      return XPCalendar.YEAR;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY:
      return XPCalendar.MONTH;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY:
      return XPCalendar.WEEK_OF_YEAR;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY:
      return XPCalendar.DATE;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY:
      return XPCalendar.HOUR;
      goto case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY;
      case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY:
      return XPCalendar.MINUTE;
      break;
      }
      return XPCalendar.MINUTE;
    }
  }
}
// END ***************** repost action methods ***************** 
