using System;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.mediator
{
  /// <summary>
  /// Generates HTMLAnchors with target URLs in href, display string
  /// and image(s) if assigned. 
  /// This class is similar to CListURLTemplateMediator, except that the HREF 
  /// is used to go to the URL instead of onlick evens. Hence, it is 508 compatible
  /// since no browser Javascript capability is required.
  /// Example use:
  /// ICPListIterator mediator = new CListURLFullMediator(m_asOwner, cpList1);
  /// mediator.SetLabelMaxLength(50);    //set the maximum label length to 50 characters
  /// while (mediator.Next())
  /// {
  /// HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
  /// ...
  /// }
  /// Extension of ASURL mediator that wraps links in HTMLAnchors.  
  /// 508 compatible
  /// </summary>
  /// <author>DavidP</author>
  public class CListURLFullLinkMediator : CListURLFullMediator,ICPListIterator
  {
    
    /// <summary>
    /// Constructor for CListURLFullLinkMediator.
    /// </summary>
    /// <param name="aspace"></param>
    /// <param name="list"></param>
    public CListURLFullLinkMediator(AActivitySpace aspace, ICPListEntryIterator list) : base(aspace,
     list)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.mediator.ICPListIterator#GetEntry()"></seealso>
    /// <returns>
    /// 						An HTMLAnchor with the target url in the href. 
    /// Returns null if the HTMLAnchor has an href with null value.
    /// </returns>
    public override Object GetEntry()
    {
      HTMLAnchor arrTemplate = null;
      // Return null entry for label-only; must be a URL
      if (base.GetEntryType() != ASCompoundList.ENTRYTYPE_STRINGLABEL)
      {
        arrTemplate = (HTMLAnchor) base.GetEntry();
      }
      return arrTemplate;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.mediator.ICPListIterator#GetEntry()"></seealso>
    /// <returns>
    /// 						An HTMLAnchor with the target url in the href. 
    /// Returns null if the HTMLAnchor has an href with null value.
    /// </returns>
    public override Object GetEntryAtIndex(int nIndex)
    {
      HTMLAnchor arrTemplate = null;
      // Return null entry for label-only; must be a URL
      if (base.GetEntryTypeAtIndex(nIndex) != ASCompoundList.ENTRYTYPE_STRINGLABEL)
      {
        arrTemplate = (HTMLAnchor) base.GetEntryAtIndex(nIndex);
      }
      return arrTemplate;
    }
    
    /// <summary>
    /// Not implemented
    /// </summary>
    /// <param name="nHeight">Image heigh override value</param>
    /// <param name="nWidth">Image width override value</param>
    public virtual void SetImageSize(int nHeight, int nWidth)
    {
    }
  }
}
// no appropriate implementation
