using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.approval;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.opener;
namespace com.plumtree.portalpages.common.objectapproval
{
  /// <author>Ben Geislinger</author>
  public class ObjectApprovalModel : AApprovalModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.objectapproval.ObjectApprovalModel");
    
    /// <summary>
    /// Logging 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ObjectApprovalModel";
    private bool boAdminRights;
    //	private String _ui_menuItemTextStatusPage = "View Approval Status of {0}";
    private IPTMigrationManager m_ptMM = null;
    private IPTQueryResult m_qrItemCount = null;
    private IPTSession m_ptSession = null;
    private bool bDisplayStatusForRequestor = false;
    private bool bDisplaySelectAllButton = false;
    
    /// <summary>
    /// Modifies the object name on repost.
    /// </summary>
    public virtual void ActionOnRepost()
    {
    }
    
    /// <returns></returns>
    public override bool AddColumnsHeaderForEachItem()
    {
      return true;
    }
    //////////////////////////////////////////////////
    //					EditorModel methods
    /////////////////////////////////////////////////    
    
    /// <summary>
    /// Implements some actions to perform on start.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>
    /// boolean Is true if the current user has the rights to access
    /// this Editor.
    /// </returns>
    public override bool CheckEditorAccessAndStart(XPHashtable _htFormData)
    {
      // ***CHANGE_HERE*** Put the code to execute when the editor starts.
      return true;
    }
    public override void ClearCache()
    {
      //	we must do some clearing of our own.
      m_qrItemCount = null;
      base.ClearCache();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new ObjectApprovalModel();
    }
    
    /// <returns></returns>
    public override bool DisplayDescriptionImmediatelyUnderTitle()
    {
      return true;
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public override void Finish()
    {
    }
    
    /// <returns></returns>
    public override bool GetAllowClearingOfApprovalRequests()
    {
      return this.bDisplayStatusForRequestor;
    }
    
    /// <param name="item"></param>
    /// <returns></returns>
    public override bool GetAllowClearingOfItem(AItemDescriptor item)
    {
      // minimize server calls.
      boAdminRights = this.m_ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      if (boAdminRights)
      {
        return true;
      }
      bool b = true;
      if (item.GetApprove())
      {
        //	if the item has been approved, then we don't
        //	allow the user user to clear the approval request.
        b = false;
      }
      return b;
    }
    
    /// <returns></returns>
    public override ApprovalItemType GetDefaultItemType()
    {
      return ApprovalPortalItemType.ADMIN_FOLDER;
    }
    
    /// <returns></returns>
    public static ApprovalItemType GetDefaultItemTypeStatic()
    {
      return ApprovalPortalItemType.ADMIN_FOLDER;
    }
    
    /// <returns></returns>
    public override bool GetDisableRadioSelection()
    {
      return this.bDisplayStatusForRequestor;
    }
    
    /// <returns></returns>
    public override bool GetDisplayHeadersForItemTypesWithNoItems()
    {
      return false;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override bool GetDisplayInstances(ApprovalItemType type)
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool GetDisplayStatusColumn()
    {
      return this.bDisplayStatusForRequestor;
    }
    public override bool GetDisplaySelectAllButton()
    {
      return this.bDisplaySelectAllButton;
    }
    public virtual void SetDisplaySelectAllButton(bool b)
    {
      this.bDisplaySelectAllButton = b;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override bool GetDisplayTypeHeader(ApprovalItemType type)
    {
      return false;
    }
    public override bool DisplayItemTypeHeaderAboveActionbar()
    {
      return true;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override String GetEmptyTypeSectionSubTitle(ApprovalItemType type)
    {
      int iId = type.GetLocalizedNameIDPlural();
      String sLocalizedName = this.m_asOwner.GetString(iId, "ptmsgs_portaladminmsgs");
      String sOut = XPResourceManager.FormatMessage(m_asOwner.GetString(539,
       "ptmsgs_portalcommonmsgs"), sLocalizedName);
      return sOut;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public virtual String GetMenuOptionText(ApprovalItemType type)
    {
      if (type == null)
      {
        String s;
        if (this.bDisplayStatusForRequestor)
        {
          s = this.m_asOwner.GetString(702, "ptmsgs_portalcommonmsgs");
        } else
        {
          s = this.m_asOwner.GetString(701, "ptmsgs_portalcommonmsgs");
        }
        return s;
      }
      int iTypeNameIDPlural = type.GetLocalizedNameIDPlural();
      int iCount = this.GetTypeCount(type);
      String sLocalizedName = null;
      if (iTypeNameIDPlural != -1)
      {
        sLocalizedName = this.m_asOwner.GetString(iTypeNameIDPlural, "ptmsgs_portaladminmsgs");
        } else
      {
        //	just get the type name as a last resort
        sLocalizedName = type.GetName();
      }
      String sOut;
      if (iCount == 0)
      {
        sOut = sLocalizedName;
      } else
      {
        sOut = XPResourceManager.FormatMessage(this.m_asOwner.GetString(3132,
         "ptmsgs_portaladminmsgs"), sLocalizedName, iCount);
      }
      return sOut;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public virtual String GetStatusPageMenuOptionText(ApprovalItemType type)
    {
      if (type == null)
      {
        String s;
        if (this.bDisplayStatusForRequestor)
        {
          s = this.m_asOwner.GetString(702, "ptmsgs_portalcommonmsgs");
        } else
        {
          s = this.m_asOwner.GetString(701, "ptmsgs_portalcommonmsgs");
        }
        return s;
      }
      int iCount = this.GetTypeCount(type);
      int iTypeNameIDPlural = type.GetLocalizedNameIDPlural();
      String sLocalizedName = this.m_asOwner.GetString(iTypeNameIDPlural,
       "ptmsgs_portaladminmsgs");
      String sOut;
      if (iCount == 0)
      {
        sOut = sLocalizedName;
      } else
      {
        sOut = XPResourceManager.FormatMessage(this.m_asOwner.GetString(3132,
         "ptmsgs_portaladminmsgs"), sLocalizedName, iCount);
      }
      return sOut;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public override String GetSubTitle()
    {
      return "";
    }
    
    /// <returns></returns>
    public override XPArrayList GetSupportedItemTypes()
    {
      XPArrayList alTemp = new XPArrayList();
      alTemp.Add(ApprovalPortalItemType.ADMIN_FOLDER);
      alTemp.Add(ApprovalPortalItemType.AUTHSOURCE);
      alTemp.Add(ApprovalPortalItemType.COMMUNITY);
      alTemp.Add(ApprovalPortalItemType.COMMUNITY_TEMPLATE);
      alTemp.Add(ApprovalPortalItemType.CRAWLER);
      alTemp.Add(ApprovalPortalItemType.DATASOURCE);
      alTemp.Add(ApprovalPortalItemType.DOCUMENT);
      alTemp.Add(ApprovalPortalItemType.DOCUMENT_FOLDER);
      alTemp.Add(ApprovalPortalItemType.DOCUMENT_TYPE);
      alTemp.Add(ApprovalPortalItemType.EXTERNAL_OPERATION);
      alTemp.Add(ApprovalPortalItemType.FEDERATED_PORTAL);
      alTemp.Add(ApprovalPortalItemType.FILTER);
      alTemp.Add(ApprovalPortalItemType.GROUP);
      alTemp.Add(ApprovalPortalItemType.INVITATION);
      alTemp.Add(ApprovalPortalItemType.JOB);
      alTemp.Add(ApprovalPortalItemType.PAGE);
      alTemp.Add(ApprovalPortalItemType.PAGE_TEMPLATE);
      alTemp.Add(ApprovalPortalItemType.PORTLET);
      alTemp.Add(ApprovalPortalItemType.PORTLET_BUNDLE);
      alTemp.Add(ApprovalPortalItemType.PORTLET_TEMPLATE);
      alTemp.Add(ApprovalPortalItemType.PROFILE_SOURCE);
      alTemp.Add(ApprovalPortalItemType.PROPERTY);
      alTemp.Add(ApprovalPortalItemType.PROPERTYMAP);
      alTemp.Add(ApprovalPortalItemType.REMOTE_SERVER);
      alTemp.Add(ApprovalPortalItemType.SAVED_SEARCH);
      alTemp.Add(ApprovalPortalItemType.SCHEDULE);
      alTemp.Add(ApprovalPortalItemType.SITE_MAP_FOLDER);
      alTemp.Add(ApprovalPortalItemType.SUBPORTAL);
      alTemp.Add(ApprovalPortalItemType.USER);
      alTemp.Add(ApprovalPortalItemType.WEB_SERVICE);
      return alTemp;
    }
    
    /// <returns></returns>
    public override String GetTitle()
    {
      return m_asOwner.GetString(1208, "ptmsgs_portaladminmsgs");
    }
    
    /// <param name="type"></param>
    /// <param name="iLow"></param>
    /// <param name="iHigh"></param>
    /// <returns></returns>
    public override XPArrayList InternalGetItemDescriptors(ApprovalItemType type,
     int iLow, int iHigh)
    {
      int iSkip = iLow;
      int iMax = (iHigh - iLow) + 1;
      ApprovalPortalItemType pType = (ApprovalPortalItemType) type;
      log.Debug("InternalGetItemDescriptors() - type: " + type.GetName());
      log.Debug("Entering InternalGetItemDescriptors() - iLow: " + iLow);
      log.Debug("Entering InternalGetItemDescriptors() - iHigh: " + iHigh);
      log.Debug("Entering InternalGetItemDescriptors() - iSkip: " + iSkip);
      log.Debug("Entering InternalGetItemDescriptors() - iMax: " + iMax);
      XPArrayList alItems = new XPArrayList();
      log.Debug("InternalGetItemDescriptors - about to perform query.");
      IPTQueryResult qr = null;
      IPTMigrationManager mm = GetMigrationManager();
      IPTSession ptSession = this.GetSession();
      String sMe = ptSession.GetSessionInfo().GetCurrentUserName();
      try
      {
        if (bDisplayStatusForRequestor)
        {
          qr = mm.QueryStatusForMigrationRequestor(pType.GetClassID(), iSkip,
           iMax);
        } else
        {
          qr = mm.QueryObjectsByStatus(pType.GetClassID(), PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED,
           iSkip, iMax, null);
        }
      }
      catch (Exception ex)
      {
        log.Error(ex, "Couldn\'t make query for classid: " + pType.GetClassID());
        }
      if (qr != null)
      {
        String sItemName;
        int itemClassID;
        int itemObjectID;
        String sDescription;
        String sComment;
        String sSubmittedBy;
        XPDateTime submittedDate;
        ObjectItemDescriptor item;
        int iCount;
        try
        {
          iCount = qr.RowCount();
          log.Debug("InternalGetItemDescriptors - iCount: " + iCount);
          for (int x = 0;x < iCount;x++)
          {
            log.Debug("InternalGetItemDescriptors - x: " + x);
            sItemName = qr.ItemAsString(x, PT_PROPIDS.PT_PROPID_NAME);
            sDescription = qr.ItemAsString(x, PT_PROPIDS.PT_PROPID_DESCRIPTION);
            itemClassID = qr.ItemAsInt(x, PT_PROPIDS.PT_PROPID_CLASSID);
            itemObjectID = qr.ItemAsInt(x, PT_PROPIDS.PT_PROPID_OBJECTID);
            if (!bDisplayStatusForRequestor)
            {
              //	only get submitted by if we're approving objects, not
              //	if we're getting status
              log.Debug("InternalGetItemDescriptors - About to get submitted by.");
              sSubmittedBy = qr.ItemAsString(x, PT_PROPIDS.PT_PROPID_MIGRATION_REQUESTOR);
              } else
            {
              //	if we're getting status, submitted by is current user.
              sSubmittedBy = sMe;
            }
            sComment = (String) qr.ItemAsString(x, PT_PROPIDS.PT_PROPID_MIGRATION_COMMENT);
            submittedDate = qr.ItemAsXPDateTime(x, PT_PROPIDS.PT_PROPID_MIGRATION_DATE);
            item = new ObjectItemDescriptor(sItemName, sDescription, sSubmittedBy,
             submittedDate, this.m_asOwner, type);
            if (this.bDisplayStatusForRequestor)
            {
              int iStatus = qr.ItemAsInt(x, PT_PROPIDS.PT_PROPID_MIGRATION_STATUS);
              String sStatus = "";
              switch (iStatus){
              case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED:
              {
                sStatus = m_asOwner.GetString(540, "ptmsgs_portalcommonmsgs");
                break;
              }
              case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED:
              {
                item.Approve();
                sStatus = m_asOwner.GetString(541, "ptmsgs_portalcommonmsgs");
                break;
              }
              case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_DENIED:
              {
                item.Reject();
                sStatus = m_asOwner.GetString(543, "ptmsgs_portalcommonmsgs");
                break;
              }
              case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_MIGRATED:
              {
                sStatus = m_asOwner.GetString(542, "ptmsgs_portalcommonmsgs");
                break;
              }
              }
              item.SetStatus(sStatus);
            } else
            {
              item.SetStatus(m_asOwner.GetString(540, "ptmsgs_portalcommonmsgs"));
              }
            item.SetMigrationManager(mm);
            item.SetSession(ptSession);
            item.SetClassID(itemClassID);
            item.SetObjectID(itemObjectID);
            item.SetComment(sComment);
            String strEditURL = PTOpenerLinks.GetOpenerURLOpenObjID(itemClassID,
             itemObjectID, IOpenerConstants.OPENER_MODE_EDIT, m_asOwner);
            item.SetEditHRef(strEditURL);
            Redirect r = new Redirect();
            r.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME, this.m_asOwner);
            r.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
            r.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID, itemClassID);
            r.AddControlArgument(IPTOpenerConstants.STR_QS_OBJECTID, itemObjectID);
            item.SetEditRedirect(r);
            alItems.Add(item);
          }
        }
        catch (Exception ex)
        {
          log.Error(ex, ex.Message);
        }
      }
      return alItems;
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public override int InternalGetTypeCount(ApprovalItemType type)
    {
      ApprovalPortalItemType pType = (ApprovalPortalItemType) type;
      if (m_qrItemCount == null)
      {
        try
        {
          IPTMigrationManager mm = GetMigrationManager();
          if (this.bDisplayStatusForRequestor)
          {
            m_qrItemCount = mm.QueryStatusForMigrationRequestorCount();
          } else
          {
            m_qrItemCount = mm.QueryObjectsByStatusCount(PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED,
             null);
          }
        }
        catch (Exception ex)
        {
          return 0;
        }
      }
      int iResultCount = m_qrItemCount.RowCount();
      int iClassID = pType.GetClassID();
      int iCount = 0;
      for (int x = 0;x < iResultCount;x++)
      {
        int i = m_qrItemCount.ItemAsInt(x, PT_PROPIDS.PT_PROPID_CLASSID);
        if (i == iClassID)
        {
          //	found the correct row.
          log.Debug("Found count for type: " + type.GetName());
          iCount = m_qrItemCount.ItemAsInt(x, PT_PROPIDS.PT_PROPID_OBJECTCOUNT);
          }
      }
      return iCount;
    }
    
    /// <returns></returns>
    public override bool IsDateSortable()
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool IsDescriptionEditable()
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool IsNameSortable()
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool IsSubmittedBySortable()
    {
      return false;
    }
    
    /// <returns></returns>
    public override bool IsTitleEditable()
    {
      return false;
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns>int Page status for server side validation</returns>
    public override int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="b"></param>
    public virtual void SetDisplayStatusForRequestor(bool b)
    {
      if (bDisplayStatusForRequestor != b)
      {
        //	if it's changing, make sure we clear all cached data.
        this.ClearCache();
      }
      bDisplayStatusForRequestor = b;
    }
    // ***CHANGE_HERE*** Implement one method per DP to save it
    // BEGIN ***************** save DP methods ***************** 
    
    /// <summary>
    /// Saves the data on the Main page.
    /// </summary>
    /// <param name="_htFormData"></param>
    protected virtual void SaveMainPage(XPHashtable _htFormData)
    {
    }
    
    /// <returns></returns>
    private IPTMigrationManager GetMigrationManager()
    {
      if (m_ptMM == null)
      {
        m_ptMM = (IPTMigrationManager) GetSession().OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
         false);
      }
      return m_ptMM;
    }
    
    /// <returns></returns>
    private IPTSession GetSession()
    {
      if (m_ptSession == null)
      {
        m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      }
      return m_ptSession;
    }
  }
}