using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.approval;
using com.plumtree.uiinfrastructure.errordisplay;
namespace com.plumtree.portalpages.common.objectapproval
{
  /// <author>Ben Geislinger</author>
  public class ObjectItemDescriptor : AItemDescriptor
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.objectapproval.ObjectItemDescriptor");
    private IPTMigrationManager migrationManager = null;
    private IPTSession session = null;
    private String sStatus = "";
    private int iClassID = -1;
    private int iNewStatus = 0;
    private int iObjectID = -1;
    
    /// <summary>
    /// Creates a new ObjectItemDescriptor object.
    /// </summary>
    /// <param name="name"></param>
    /// <param name="description"></param>
    /// <param name="submittedBy"></param>
    /// <param name="submittedDate"></param>
    /// <param name="space"></param>
    /// <param name="type"></param>
    public ObjectItemDescriptor(String name, String description, String submittedBy,
     XPDateTime submittedDate, AActivitySpace space, ApprovalItemType type) : base(name,
     description, submittedBy, submittedDate, space, type)
    {
      iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED;
      }
    public override void Execute()
    {
      log.Debug("Execute() - " + this.GetName());
      log.Debug("Execute() - iNewStatus: " + iNewStatus);
      log.Debug("Execute() - classid: " + this.GetClassID());
      log.Debug("Execute() - objectid: " + this.GetObjectID());
      if (GetApprove())
      {
        iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED;
        }
      if (GetReject())
      {
        iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_DENIED;
        }
      if (GetClear())
      {
        iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE;
      }
      if (migrationManager == null)
      {
        log.Error("MigrationManager is null.");
        return;
      }
      try
      {
        int[] iaTemp = new int[1];
        iaTemp[0] = this.GetObjectID();
        String sComment = this.GetComment();
        log.Debug("Execute() - About to set the status on: " + this.GetName());
        log.Debug("Execute() - with comment: " + sComment);
        migrationManager.BulkSetMigrationStatus(this.GetClassID(), iaTemp,
         iNewStatus, GetComment());
      }
      catch (Exception ex)
      {
        log.Error(ex, "Couldn\'t approve object.");
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         "Couldn\'t execute object.", ex.Message);
        myError.SetActivitySpace(mySpace.GetName());
        myError.SetClearWithActivitySpaceChange(true);
        UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(), mySpace.GetApplication());
        }
    }
    
    /// <returns></returns>
    public virtual int GetClassID()
    {
      return iClassID;
    }
    
    /// <returns></returns>
    public virtual int GetObjectID()
    {
      return iObjectID;
    }
    
    /// <returns></returns>
    public override String GetStatus()
    {
      return sStatus;
    }
    
    /// <param name="i"></param>
    public virtual void SetClassID(int i)
    {
      iClassID = i;
    }
    
    /// <param name="mm"></param>
    public virtual void SetMigrationManager(IPTMigrationManager mm)
    {
      migrationManager = mm;
    }
    public virtual void SetSession(IPTSession s)
    {
      session = s;
    }
    
    /// <param name="i"></param>
    public virtual void SetObjectID(int i)
    {
      iObjectID = i;
    }
    
    /// <param name="s"></param>
    public virtual void SetStatus(String s)
    {
      sStatus = s;
    }
  }
}