using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.objects
{
  /// <author>michaeld</author>
  public interface IObjectModelRO : IModelRO
  {
    
    /// <summary>
    /// Get whether to show this object or not.
    /// </summary>
    /// <param name="int">nIndex</param>
    /// <returns>boolean true implies object is hidden, false implies show object</returns>
    bool DoNotShowObject(int nIndex);
    
    /// <summary>
    /// Get whether or not to display the hidden inputs needed by the PaginationControl.
    /// This is only useful if GetShowPagination() returns true.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.pagination.PaginationControl."></seealso>
    /// <returns>boolean true implies display hidden inputs</returns>
    bool GetDisplayPaginationHiddenInputs();
    
    /// <summary>
    /// Get whether or not to display the hidden inputs needed by the SortControl.
    /// This is only useful if GetSortable() returns true.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.sort.SortControl."></seealso>
    /// <returns>boolean true implies display hidden inputs</returns>
    bool GetDisplaySortHiddenInputs();
    
    /// <summary>
    /// Gets the count of the object headers. Returns 0 if the array is null.
    /// </summary>
    /// <returns>int nHeaderCount</returns>
    int GetHeaderCount();
    
    /// <summary>
    /// Returns whether the header has a checkbox or not.
    /// </summary>
    /// <returns>boolean</returns>
    bool GetHeaderHasCheckbox();
    
    /// <summary>
    /// Returns the header row
    /// </summary>
    /// <returns>int nHeaderCount</returns>
    HTMLTableRow GetHeaderRow();
    
    /// <summary>
    /// Gets the text of the header at the given index.
    /// </summary>
    /// <param name="nHeaderIndex">nHeaderIndex</param>
    /// <returns>String strHeaderText</returns>
    String GetHeaderText(int nHeaderIndex);
    
    /// <summary>
    /// Gets whether or not the object banner should be collapsable.
    /// </summary>
    /// <returns>boolean true implies collapsible.</returns>
    bool GetIsCollapsable();
    
    /// <summary>
    /// This method returns whether or not the requested object ID is
    /// currently selected.
    /// </summary>
    /// <returns>boolean true implies selected, false implies not selected</returns>
    bool GetIsObjectSelected(int nObjectID);
    
    /// <summary>
    /// Gets the name of the current folder.
    /// </summary>
    /// <returns>String strCurrentFolderName</returns>
    String GetObjectBannerTitle();
    
    /// <summary>
    /// Gets the number of columns of objects
    /// </summary>
    /// <returns>int nColumnCount</returns>
    int GetObjectColumnCount();
    
    /// <summary>
    /// Gets the count of the objects in the query result.
    /// </summary>
    /// <returns>int nObjectCount</returns>
    int GetObjectCount();
    
    /// <summary>
    /// Gets the fields from the query result.
    /// </summary>
    /// <param name="nIndex">nIndex</param>
    /// <param name="nPropID">nPropID</param>
    /// <returns>Object oFields</returns>
    Object GetObjectFields(int nIndex, int nPropID);
    
    /// <summary>
    /// Get the Object Class ID of the type of objects we are currently viewing.
    /// </summary>
    /// <returns>int the class ID of the object</returns>
    int GetObjectType();
    
    /// <summary>
    /// Get the subtype of the object at the given index.
    /// </summary>
    /// <param name="nIndex">index of the object in the list.</param>
    /// <returns>the subtype of the object, or -1 if the object has no subtype.</returns>
    int GetObjectSubType(int nIndex);
    
    /// <summary>
    /// Get whether the object view is collapsed.
    /// This is only relevant if GetIsCollapsable() returns true.
    /// </summary>
    /// <returns>bObjectViewIsCollapsed</returns>
    bool GetObjectViewIsCollapsed();
    
    /// <summary>
    /// Get whether these objects should use pagination or not.  If this is true, the
    /// header will have a pagination bar.
    /// If this is true, the AActivitySpace will need to include the pagination
    /// framework (pass-thru repost control & implement pagination model interface).
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.pagination.IPaginationModel"></seealso>
    /// <seealso cref="com.plumtree.portalpages.common.objects.ObjectView"></seealso>
    /// <returns>boolean true implies show pagination bar</returns>
    bool GetShowPagination();
    
    /// <summary>
    /// Get whether these objects are sortable or not.  If this is true, the
    /// headers will be sortable.
    /// If this is true, the AActivitySpace will need to include the sortable
    /// framework (pass-thru repost control & implement sortable model interface).
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.sort.ISortModel"></seealso>
    /// <seealso cref="com.plumtree.portalpages.common.objects.ObjectView"></seealso>
    /// <returns>boolean true implies sortable</returns>
    bool GetSortable();
    
    /// <summary>
    /// Get the Space ID of this models AS
    /// </summary>
    /// <returns>String m_asOwner.GetSpaceID()</returns>
    String GetSpaceID();
    
    /// <summary>
    /// Get whether to show the banner or not.
    /// </summary>
    /// <returns>boolean true implies show banner</returns>
    bool ShowObjectBanner();
  }
}