using System;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.objects
{
  /// <author>michaeld</author>
  public interface IObjectViewHelper
  {
    
    /// <summary>
    /// Returns additional HTML as an html element for the object view to display.
    /// </summary>
    /// <param name="model"></param>
    /// <returns>HTMLElement</returns>
    HTMLElement AddObjectViewHTML(IObjectModelRO model);
    
    /// <summary>
    /// Displays the object in 508 mode at the given index in the query result. This must be
    /// overridden by all subclasses.
    /// </summary>
    /// <param name="nObjectIndex">nObjectIndex</param>
    /// <param name="tableObjects">tableObjects</param>
    /// <param name="model"></param>
    void Display508Object(int nObjectIndex, HTMLTable tableObjects, IObjectModelRO model,
     AActivitySpace parent);
    
    /// <summary>
    /// Returns the javascript for this view helper.
    /// </summary>
    /// <param name="asOwner"></param>
    /// <param name="model"></param>
    /// <returns>HTMLScriptCollection</returns>
    HTMLScriptCollection DisplayJavascriptCollection(AActivitySpace asOwner,
     IObjectModelRO model);
    
    /// <summary>
    /// Displays the object at the given index in the query result. This must be
    /// overridden by all subclasses. nRowIndex is used to determine which StyleClass to use.
    /// </summary>
    /// <param name="nObjectIndex">nObjectIndex</param>
    /// <param name="nObjectIndex">nRowIndex</param>
    /// <param name="tableObjects">tableObjects</param>
    /// <param name="model"></param>
    void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
     IObjectModelRO model, AActivitySpace parent);
    
    /// <summary>
    /// This method is called by the ObjectView to fill out the anchor for the
    /// expand / collapse links on the object view header.
    /// </summary>
    /// <param name="HTMLAnchor">the anchor to be filled out.</param>
    /// <param name="IObjectModelRO">the model</param>
    void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model);
    
    /// <summary>
    /// Return the message to display if there are no items.  Return an empty
    /// string if you want to use the default.
    /// </summary>
    /// <returns>String</returns>
    String GetThereAreNoItemsString(AActivitySpace asOwner);
  }
}