using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.objectselection;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.form.pagination;
using com.plumtree.uiinfrastructure.form.sort;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.objects
{
  /// <author>michaeld</author>
  public class ObjectView : IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.objects.ObjectView");
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "Object";
    
    /// <summary>
    /// Javascript Function: checkAll -- matches on substring, not entire name 
    /// </summary>
    public const String JAVASCRIPT_CHECK_ALL = "checkAll";
    
    /// <summary>
    /// Javascript Function: sort 
    /// </summary>
    public const String JAVASCRIPT_SORT = "sort";
    
    /// <summary>
    /// HTML Input checkbox: Check All 
    /// </summary>
    public const String HTMLINPUT_CHECK_ALL = "in_cb_checkAll";
    
    /// <summary>
    /// Activity Space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Model 
    /// </summary>
    private IObjectModelRO m_asModel;
    
    /// <summary>
    /// Object Section Helper 
    /// </summary>
    private IObjectViewHelper m_objectViewHelper;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ObjectView();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElementCollection myViewCollection = new HTMLElementCollection();
      HTMLElement result = myViewCollection;
      PTConstruct myConstruct;
      bool bPaginate = m_asModel.GetShowPagination();
      int nObjectCount = m_asModel.GetObjectCount();
      int nFirstObjectCount = 1;
      int nLastObjectCount = nObjectCount;
      if ((bPaginate) && (nObjectCount > 0))
      {
        try
        {
          IPaginationModelRO asPaginationModel = (IPaginationModelRO) m_asModel;
          nFirstObjectCount = asPaginationModel.GetCurrentLowerObjectCount();
          nLastObjectCount = asPaginationModel.GetCurrentUpperObjectCount();
          }
        catch (Exception e)
        {
          log.Error(e, "Unable to get pagination model.");
        }
      }
      int nFirstObjectIndex = nFirstObjectCount - 1;
      int nLastObjectIndex = nLastObjectCount - 1;
      bool bCollapsed = m_asModel.GetObjectViewIsCollapsed();
      // Objects Subheader
      if (m_asModel.ShowObjectBanner())
      {
        try
        {
          myConstruct = UIConstructFactory.GetConstruct(PTBannerType.OBJECT,
           true, this.m_asOwner);
          if (!m_asModel.GetIsCollapsable())
          {
            // text only title
            myConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
             m_asModel.GetObjectBannerTitle());
          } else
          {
            // collapsable title
            HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
            myAnchor.AddInnerHTMLEncodedString(m_asModel.GetObjectBannerTitle());
            m_objectViewHelper.SetExpandAnchor(myAnchor, m_asModel);
            myConstruct.ReplaceNestedElementsWithElement(PTBannerType.OBJECT.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
             myAnchor);
            PTConstruct myButtonConstruct;
            if (bCollapsed)
            {
              myAnchor.SetTitle(m_asOwner.GetString(676, "ptmsgs_portalcommonmsgs"));
              myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.EXPAND_AREA,
               true, this.m_asOwner);
              // Set the URL on the button
              HTMLAnchor buttonAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.EXPAND_AREA.ANCHOR_ELEMENT_NAME);
              m_objectViewHelper.SetExpandAnchor(buttonAnchor, m_asModel);
              buttonAnchor.SetTitle(m_asOwner.GetString(676, "ptmsgs_portalcommonmsgs"));
              HTMLImg buttonImage = (HTMLImg) myButtonConstruct.GetNestedElement(PTButtonType.EXPAND_AREA.IMG_ELEMENT_NAME);
              buttonImage.SetAlt(m_asOwner.GetString(676, "ptmsgs_portalcommonmsgs"));
              } else
            {
              myAnchor.SetTitle(m_asOwner.GetString(677, "ptmsgs_portalcommonmsgs"));
              myButtonConstruct = UIConstructFactory.GetConstruct(PTButtonType.COLLAPSE_AREA,
               true, this.m_asOwner);
              // Set the URL on the button
              HTMLAnchor buttonAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.COLLAPSE_AREA.ANCHOR_ELEMENT_NAME);
              m_objectViewHelper.SetExpandAnchor((HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.COLLAPSE_AREA.ANCHOR_ELEMENT_NAME),
               m_asModel);
              buttonAnchor.SetTitle(m_asOwner.GetString(677, "ptmsgs_portalcommonmsgs"));
              HTMLImg buttonImage = (HTMLImg) myButtonConstruct.GetNestedElement(PTButtonType.COLLAPSE_AREA.IMG_ELEMENT_NAME);
              buttonImage.SetAlt(m_asOwner.GetString(677, "ptmsgs_portalcommonmsgs"));
              }
            myConstruct.AddElementToNestedElement(PTBannerType.OBJECT.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXPAND_COLLAPSE_CONTAINER),
             myButtonConstruct.GetHTMLElement());
          }
          // add subheader text here
          if (nObjectCount >= 0)
          {
            if (bCollapsed)
            {
              myConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.GetElementName(PTBannerType.ELEMENT_NAME_ID_SUBTITLE),
               "(" + nObjectCount + ")");
            } else
            if (nObjectCount == 0)
            {
              myConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.GetElementName(PTBannerType.ELEMENT_NAME_ID_SUBTITLE),
               CommonHTMLStrings.SPACE);
            } else
            {
              myConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.GetElementName(PTBannerType.ELEMENT_NAME_ID_SUBTITLE),
               CommonHTMLStrings.SPACE + XPResourceManager.FormatMessage(m_asOwner.GetString(692,
               "ptmsgs_portalcommonmsgs"), nFirstObjectCount, nLastObjectCount,
               nObjectCount));
            }
          }
          myViewCollection.AddInnerHTMLElement(myConstruct.GetHTMLElement());
          }
        // bjf -- took out the space table because it makes the first row look
        // taller than all the others.  TODO -- someone who knows this code better
        // than I do please verify that this is OK.  I was working in the site map.
        //myViewCollection.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        catch (HTMLException he)
        {
          log.Error(he, "Display: Object banner failed to display.");
        }
        catch (Exception e)
        {
          log.Error(e, "Display: Object banner creation failed.");
        }
      }
      // If there are no objects in the directory, don't display the header.
      if (nObjectCount == 0)
      {
        try
        {
          HTMLSpan mySpan = new HTMLSpan();
          myViewCollection.AddInnerHTMLElement(mySpan);
          mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          String strThereAreNoItems = m_objectViewHelper.GetThereAreNoItemsString(m_asOwner);
          if (("").Equals(strThereAreNoItems) || null == strThereAreNoItems)
          {
            strThereAreNoItems = m_asOwner.GetString(133, "ptmsgs_portalcommonmsgs");
            }
          mySpan.AddInnerHTMLString(strThereAreNoItems);
          myViewCollection.AddInnerHTMLElement(new HTMLBr());
        }
        catch (HTMLException he)
        {
          log.Error(he, "Display: Failed to display the \"There are no documents in this folder\" message.");
          }
      } else
      if (!m_asModel.GetObjectViewIsCollapsed())
      {
        int nClassID = m_asModel.GetObjectType();
        // Display pagination filtering if necessary
        if (bPaginate && m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          // TODO: should this only display the pagination bar if there are
          // enough items to paginate?
          myConstruct = PaginationControl.CreatePaginationFilterBar(m_asOwner,
           nClassID, nObjectCount);
          try
          {
            myViewCollection.AddInnerHTMLElement(myConstruct.GetHTMLElement());
            }
          catch (HTMLException he)
          {
            log.Error(he, "Unable to create pagination filtering bar.");
          }
        }
        // add a spacer table between the pagination filter bar and the grid per KenJ -mgs
        myViewCollection.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
        bool bNoJavascript = (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD);
        // NOTE: Depending on the number of columns, the tableObjects (outer) table
        // may not be used.
        // Display objects
        HTMLTable tableObjects;
        HTMLTableRow rowObjects;
        HTMLTableCell cellObjects;
        HTMLTable tableObjectsInner;
        HTMLTableRow rowObjectsInner;
        HTMLTableCell cellObjectsInner;
        HTMLInput myInput;
        String strHeaderText;
        bool bFirstTextHeader;
        try
        {
          int nNumCols = m_asModel.GetObjectColumnCount();
          int nObjectsToDisplayCount = nLastObjectIndex - nFirstObjectIndex + 1;
          //Use this array to keep track of the objects we've decided
          //to display (in order to avoid calling DoNotShowObject twice
          //for each object which could introduce performance and consistency
          //problems).
          bool[] abDisplayObject = new bool[nObjectCount];
          //Remove those objects that we deem not showable!
          for (int j = nFirstObjectIndex;j <= nLastObjectIndex;j++)
          {
            if (m_asModel.DoNotShowObject(j) && ((nClassID != PT_CLASSIDS.PT_GADGET_ID) && (nClassID != PT_CLASSIDS.PT_COMMUNITY_ID)))
            {
              nObjectsToDisplayCount--;
              abDisplayObject[j] = false;
            } else
            {
              abDisplayObject[j] = true;
            }
          }
          //Make sure we didn't accidentally fall below zero (shouldn't happen).
          nObjectsToDisplayCount = (0 >= nObjectsToDisplayCount) ? 0 : nObjectsToDisplayCount;
          //Figure out how many objects to show in each column
          int nMaxRowCount = nObjectsToDisplayCount / nNumCols;
          if ((nObjectsToDisplayCount % nNumCols) != 0)
          {
            nMaxRowCount++;
          }
          tableObjects = new HTMLTable();
          if (1 < nNumCols)
          {
            myViewCollection.AddInnerHTMLElement(tableObjects);
          }
          tableObjects.SetBorder(CommonHTMLStrings.ZERO);
          rowObjects = new HTMLTableRow();
          tableObjects.AddInnerHTMLElement(rowObjects);
          tableObjectsInner = new HTMLTable();
          // Add hidden inputs for sorting.
          bool bSortable = m_asModel.GetSortable();
          int nSortedHeader = -1;
          bool bSortUp = false;
          if (bSortable)
          {
            try
            {
              ISortModelRO asSortModel = (ISortModelRO) m_asModel;
              nSortedHeader = asSortModel.GetSortedHeader();
              bSortUp = (asSortModel.GetSortDirection() == PTSortedArrayWrapper.PTSAW_SORT_ASCENDING);
              }
            catch (Exception e)
            {
              log.Error(e, "Unable to get sorting information.");
              bSortable = false;
            }
          }
          // No reason to display hidden inputs if we can't set their values with javascript
          if (!bNoJavascript)
          {
            if (m_asModel.GetDisplaySortHiddenInputs())
            {
              // Hidden input for sort ID (class ID)
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, SortControl.HTMLINPUT_SORT_ID,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
              // Hidden input for sort header
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, SortControl.HTMLINPUT_SORT_HEADER,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
              // Hidden input for sort direction
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, SortControl.HTMLINPUT_SORT_DIRECTION,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
            }
            if (m_asModel.GetDisplayPaginationHiddenInputs())
            {
              // Hidden input for pagination ID (class ID)
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, PaginationControl.HTMLINPUT_PAGINATION_ID,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
              // Hidden input for paginate from
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, PaginationControl.HTMLINPUT_PAGINATE_FROM,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
              // Hidden input for paginate to
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, PaginationControl.HTMLINPUT_PAGINATE_TO,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
              // Hidden input for model storage name
              myInput = new HTMLInput(HTMLInputTypes.HIDDEN, PaginationControl.HTMLINPUT_MODEL_STORAGE_NAME,
               "");
              myViewCollection.AddInnerHTMLElement(myInput);
            }
          }
          int nCurrentCountInRow = 0;
          // Output objects in this folder
          for (int nCurrentObjectCount = nFirstObjectIndex;nCurrentObjectCount <= nLastObjectIndex;
          nCurrentObjectCount++)
          {
            // First, check to see if we must start a new column.  (we must check against the first
            // displayed object, not 0)
            if ((nFirstObjectIndex == nCurrentObjectCount) || (nCurrentCountInRow >= nMaxRowCount))
            {
              nCurrentCountInRow = 0;
              tableObjectsInner = new HTMLTable();
              if (1 < nNumCols)
              {
                //Time to start a new column
                cellObjects = new HTMLTableCell();
                rowObjects.AddInnerHTMLElement(cellObjects);
                cellObjects.SetVAlign(CommonHTMLStrings.TOP);
                cellObjects.AddInnerHTMLElement(tableObjectsInner);
              } else
              {
                myViewCollection.AddInnerHTMLElement(tableObjectsInner);
              }
              tableObjectsInner.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
              tableObjectsInner.SetBorder(CommonHTMLStrings.ZERO);
              tableObjectsInner.SetCellPadding("2");
              tableObjectsInner.SetCellSpacing("2");
              //If we've started a new column, we should add the headers.
              HTMLTableRow myHeaderRow = m_asModel.GetHeaderRow();
              //
              if (null != myHeaderRow)
              {
                // A header row is supplied
                tableObjectsInner.AddInnerHTMLElement(myHeaderRow);
              } else
              {
                if ((0 < m_asModel.GetHeaderCount()) && (AccessStyles.STANDARD == m_asOwner.GetAccessStyle()))
                {
                  // for each object header column write the column header
                  rowObjectsInner = new HTMLTableRow();
                  tableObjectsInner.AddInnerHTMLElement(rowObjectsInner);
                  rowObjectsInner.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
                  HTMLAnchor myAnchor;
                  HTMLImg myImg;
                  PTButtonType myButtonType;
                  bFirstTextHeader = true;
                  for (int nHeaderCount = 0;nHeaderCount < m_asModel.GetHeaderCount();
                  nHeaderCount++)
                  {
                    // display object headers
                    cellObjectsInner = new HTMLTableCell();
                    rowObjectsInner.AddInnerHTMLElement(cellObjectsInner);
                    strHeaderText = m_asModel.GetHeaderText(nHeaderCount);
                    if ((0 == nHeaderCount) && XPStringUtility.StartsWith(strHeaderText,
                     "in_cb"))
                    {
                      cellObjectsInner.SetWidth("25");
                      cellObjectsInner.SetAlign(CommonHTMLStrings.CENTER);
                      cellObjectsInner.SetVAlign(CommonHTMLStrings.MIDDLE);
                      cellObjectsInner.SetStyleClass(PTStyleClass.LIST_TEXT);
                      if (bNoJavascript)
                      {
                        cellObjectsInner.AddInnerHTMLString(CommonHTMLStrings.SPACE);
                        } else
                      {
                        myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLINPUT_CHECK_ALL,
                         m_asOwner.GetString(134, "ptmsgs_portalcommonmsgs"));
                        cellObjectsInner.AddInnerHTMLElement(myInput);
                        // DCA - added a simple repost to the checkall box if user is on an 
                        // objectselection page so that the bottom frame gets updated
                        XPStringBuilder sb = new XPStringBuilder(100);
                        sb.Append(JAVASCRIPT_CHECK_ALL).Append("(this, \'").Append(strHeaderText).Append("\');");
                        if (m_asModel.GetName() == ObjectSelectionModel.STR_MVC_CLASS_NAME)
                        {
                          sb.Append(" postToSelf(").Append(RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST).Append(");");
                          }
                        myInput.SetOnClick(sb.ToString());
                      }
                    } else
                    if (strHeaderText.Equals(CommonHTMLStrings.SPACE))
                    {
                      cellObjectsInner.SetWidth("25");
                      cellObjectsInner.SetStyleClass(PTStyleClass.LIST_TEXT);
                      cellObjectsInner.AddInnerHTMLString(strHeaderText);
                      } else
                    {
                      if (bFirstTextHeader)
                      {
                        bFirstTextHeader = false;
                        // Can't set width to 100% because it breaks the image column (makes it too wide)
                        //	                            		cellObjectsInner.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
                        cellObjectsInner.SetAutoFit(true);
                      }
                      cellObjectsInner.SetHeight("16");
                      cellObjectsInner.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
                      cellObjectsInner.SetNoWrap(true);
                      if (bSortable)
                      {
                        try
                        {
                          if (nHeaderCount == nSortedHeader)
                          {
                            // Add sort anchor plus arrow
                            myButtonType = bSortUp ? PTButtonType.SORT_UP : PTButtonType.SORT_DOWN;
                            PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct(myButtonType,
                             false, this.m_asOwner);
                            myButtonConstruct.ReplaceNestedElementsWithHTMLEncodedString(myButtonType.TITLE_ELEMENT_NAME,
                             strHeaderText);
                            myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(myButtonType.ANCHOR_ELEMENT_NAME);
                            if (bNoJavascript)
                            {
                              ASURL myURL = new ASURL(m_asOwner);
                              myURL.SetLinkGetCachedSpace(m_asOwner);
                              myURL.SetControl(SortControl.STR_MVC_CLASS_NAME);
                              myURL.AddControlArgument(SortControl.HTMLINPUT_SORT_DIRECTION,
                               ((!bSortUp) ? PTSortedArrayWrapper.PTSAW_SORT_ASCENDING : PTSortedArrayWrapper.PTSAW_SORT_DESCENDING));
                              myURL.AddControlArgument(SortControl.HTMLINPUT_SORT_HEADER,
                               nHeaderCount);
                              myURL.AddControlArgument(SortControl.HTMLINPUT_SORT_ID,
                               nClassID);
                              myAnchor.SetHRef(myURL.GetURLAsString());
                            } else
                            {
                              myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
                              myAnchor.SetOnClick(JAVASCRIPT_SORT + "(" + nClassID + ", " + nHeaderCount + ", " + ((!bSortUp) ? PTSortedArrayWrapper.PTSAW_SORT_ASCENDING : PTSortedArrayWrapper.PTSAW_SORT_DESCENDING) + "); return false;");
                              }
                            myImg = (HTMLImg) myButtonConstruct.GetNestedElement(myButtonType.IMG_ELEMENT_NAME);
                            myImg.SetAlt(bSortUp ? m_asOwner.GetString(136,
                             "ptmsgs_portalcommonmsgs") : m_asOwner.GetString(135,
                             "ptmsgs_portalcommonmsgs"));
                            cellObjectsInner.AddInnerHTMLElement(myButtonConstruct.GetHTMLElement());
                            } else
                          {
                            // Just add default sort anchor
                            if (bNoJavascript)
                            {
                              ASURL myURL = new ASURL(m_asOwner);
                              myURL.SetLinkGetCachedSpace(m_asOwner);
                              myURL.SetControl(SortControl.STR_MVC_CLASS_NAME);
                              myURL.AddControlArgument(SortControl.HTMLINPUT_SORT_DIRECTION,
                               ((!bSortUp) ? PTSortedArrayWrapper.PTSAW_SORT_ASCENDING : PTSortedArrayWrapper.PTSAW_SORT_DESCENDING));
                              myURL.AddControlArgument(SortControl.HTMLINPUT_SORT_HEADER,
                               nHeaderCount);
                              myURL.AddControlArgument(SortControl.HTMLINPUT_SORT_ID,
                               nClassID);
                              myAnchor = new HTMLAnchor(myURL.GetURLAsString());
                              myAnchor.AddInnerHTMLEncodedString(strHeaderText);
                              } else
                            {
                              myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
                              myAnchor.SetOnClick(JAVASCRIPT_SORT + "(" + nClassID + ", " + nHeaderCount + ", " + PTSortedArrayWrapper.PTSAW_SORT_DESCENDING + "); return false;");
                              myAnchor.AddInnerHTMLEncodedString(strHeaderText);
                              }
                            cellObjectsInner.AddInnerHTMLElement(myAnchor);
                            }
                        }
                        catch (Exception e)
                        {
                          log.Error(e, "Unable to create sortable header button for column " + nHeaderCount);
                          cellObjectsInner.AddInnerHTMLEncodedString(strHeaderText);
                          }
                      } else
                      {
                        cellObjectsInner.AddInnerHTMLEncodedString(strHeaderText);
                        }
                    }
                  }
                }
              }
            }
            //Now display the actual object (if we're supposed to).
            if (abDisplayObject[nCurrentObjectCount])
            {
              if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
              {
                // display object
                m_objectViewHelper.DisplayObject(nCurrentObjectCount, nCurrentCountInRow,
                 tableObjectsInner, m_asModel, m_asOwner);
              } else
              {
                // display object in 508
                m_objectViewHelper.Display508Object(nCurrentObjectCount, tableObjectsInner,
                 m_asModel, m_asOwner);
              }
              // Only up the row count if we actually display something.
              nCurrentCountInRow++;
            }
          }
          HTMLElement addHTML = m_objectViewHelper.AddObjectViewHTML(m_asModel);
          if (null != addHTML)
          {
            myViewCollection.AddInnerHTMLElement(addHTML);
          }
          // Display pagination links if necessary
          if (bPaginate)
          {
            try
            {
              HTMLTable paginationTable = new HTMLTable();
              myViewCollection.AddInnerHTMLElement(paginationTable);
              paginationTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
              paginationTable.SetBorder(CommonHTMLStrings.ZERO);
              HTMLTableRow paginationRow = new HTMLTableRow();
              paginationTable.AddInnerHTMLElement(paginationRow);
              HTMLTableCell paginationCell = new HTMLTableCell();
              paginationRow.AddInnerHTMLElement(paginationCell);
              paginationCell.SetAlign(CommonHTMLStrings.RIGHT);
              paginationCell.AddInnerHTMLElement(PaginationControl.CreatePaginationLinks(m_asOwner,
               nClassID, nObjectCount, nFirstObjectCount, nLastObjectCount,
               ((IPaginationModelRO) m_asModel).GetPaginationSize()));
            }
            catch (HTMLException he)
            {
              log.Error(he, "Unable to create pagination links.");
            }
          }
        }
        catch (HTMLException e)
        {
          log.Error(e, "Error creating object view.");
          result = new HTMLGenericElement("Error creating object view.");
          }
      }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on
    /// the page.
    /// Warning: this may return null, and HTMLScriptCollections may not handle
    /// having null added to them.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public virtual HTMLScript DisplayJavascript()
    {
      int nScriptLength = 0;
      if (m_asModel.GetHeaderHasCheckbox())
      {
        nScriptLength+=200;
      }
      if (m_asModel.GetSortable())
      {
        nScriptLength+=100;
      }
      if (m_asModel.GetShowPagination())
      {
        nScriptLength+=100;
      }
      if (nScriptLength <= 0)
      {
        return null;
      }
      HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      XPStringBuilder sb = new XPStringBuilder(nScriptLength);
      if (m_asModel.GetHeaderHasCheckbox())
      {
        // JavaScript to check all the rows
        // This matches on substring, not on the entire name
        sb.Append("function ").Append(JAVASCRIPT_CHECK_ALL).Append("(inputCBAll, cbName)\n").Append("{\n").Append("\t\tvar frm = document.").Append(AFormDP.HTMLFORM_NAME).Append(";\n").Append("\t\tvar len = frm.elements.length;\n").Append("\t\tvar nValue = inputCBAll.checked;\n").Append("\t\tvar i = 0;\n").Append("\t\tfor(i=0 ; i<len ; i++)\n").Append("\t\t{\n").Append("\t\t\tif (frm.elements[i].name.substr(0, cbName.length) == cbName)\n").Append("\t\t\t{\n").Append("\t\t\t\tfrm.elements[i].checked = nValue;\n").Append("\t\t\t}\n").Append("\t\t}\n").Append("}\n");
        }
      if (m_asModel.GetSortable())
      {
        // JavaScript to sort by headers
        sb.Append("function ").Append(JAVASCRIPT_SORT).Append("(nID, nHeaderCol, nDirection)\n").Append("{\n").Append("\t\tvar frm = document.").Append(AFormDP.HTMLFORM_NAME).Append(";\n").Append("\t\tfrm.").Append(SortControl.HTMLINPUT_SORT_ID).Append(".value = nID;\n").Append("\t\tfrm.").Append(SortControl.HTMLINPUT_SORT_HEADER).Append(".value = nHeaderCol;\n").Append("\t\tfrm.").Append(SortControl.HTMLINPUT_SORT_DIRECTION).Append(".value = nDirection;\n").Append("\t\t").Append(AFormDP.JAVASCRIPT_SUBMIT_TO_CONTROL).Append("(\'").Append(SortControl.STR_MVC_CLASS_NAME).Append("\');\n").Append("}\n");
        }
      try
      {
        myScript.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript: Failed to add javascript functions to page.");
        }
      if (m_asModel.GetShowPagination())
      {
        try
        {
          myScript.AddInnerHTMLString(PaginationControl.CreatePaginationJavascript(m_asOwner));
          }
        catch (HTMLException he)
        {
          log.Error(he, "DisplayJavascript: Failed to add pagination javascript functions to page.");
          }
      }
      return myScript;
    }
    
    /// <summary>
    /// This method returns a HTMLScriptCollection that encompasses the Javascript
    /// from the object view helper.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    public virtual HTMLScriptCollection DisplayJavascriptCollection()
    {
      return m_objectViewHelper.DisplayJavascriptCollection(m_asOwner, m_asModel);
      }
    ////////////////////////////////
    // Methods from IView
    ////////////////////////////////
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asModel = (IObjectModelRO) model;
      m_asOwner = parent;
    }
    
    /// <summary>
    /// Sets the Object Section Helper for the Object Section to use. The display page
    /// must call this method from within the PageDisplay method, before
    /// calling display on this view.
    /// </summary>
    /// <param name="objectViewHelper"></param>
    public virtual void SetObjectViewHelper(IObjectViewHelper objectViewHelper)
    {
      m_objectViewHelper = objectViewHelper;
    }
    
    /// <summary>
    /// Gets the Object Section Helper for the Object Section.
    /// </summary>
    /// <returns>IObjectViewHelper</returns>
    public virtual IObjectViewHelper GetObjectViewHelper()
    {
      return m_objectViewHelper;
    }
    
    /// <summary>
    /// Gets the javascript that will check the check all box if all the 
    /// checkboxes have been checked.
    /// </summary>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript GetCheckAllScript()
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      sb.Append("\n").Append("\tvar frm = document.").Append(AFormDP.HTMLFORM_NAME).Append(";\n").Append("\tvar len = frm.elements.length;\n").Append("\tvar nValue = true;\n").Append("\tvar checkallbox = null;\n").Append("\tvar i = 0;\n").Append("\tfor(i=0 ; i<len ; i++)\n").Append("\t{\n").Append("\t\tif (frm.elements[i].name == \'in_cb_Object\')\n").Append("\t\t{\n").Append("\t\t\tif (frm.elements[i].checked == false) {\n").Append("\t\t\t\tnValue = false;\n").Append("\t\t\t\tbreak;\n").Append("\t\t\t}\n").Append("\t\t}\n").Append("\t\tif (frm.elements[i].name == \'").Append(HTMLINPUT_CHECK_ALL).Append("\')\n").Append("\t\t{\n").Append("\t\t\tcheckallbox = frm.elements[i];\n").Append("\t\t}\n").Append("\t}\n").Append("\tif (checkallbox) {\n").Append("\t\tcheckallbox.checked = nValue; \n").Append("\t}\n");
      HTMLScript script = new HTMLScript("text/javaScript");
      try
      {
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (HTMLException he)
      {
        log.Error(he, "DisplayJavascript couldn\'t add check checkall box javascript to the HTMLScript element.");
        }
      return script;
    }
  }
}