/*
 * Created on Mar 7, 2003
 */
 
using System;
using com.plumtree.portaluiinfrastructure.compoundlist;
namespace com.plumtree.portalpages.common.plugnav
{
  /// <summary>
  /// Community preview page specific functions
  /// </summary>
  /// <author>DavidP</author>
  public interface ICommunityPreviewNavPageRO : INavigationPageRO
  {
    
    /// <summary>
    /// Unique String Name of category of object.  Critical for link blocking by pluggable nav.
    /// </summary>
    String GetName();
    
    /// <summary>
    /// Checks for at least read access to the specified Community,
    /// If current user lacks access, get the user's default Community and
    /// user has no default communities, return -1.
    /// </summary>
    /// <param name="nCommID">ID of the Community to check access to</param>
    /// <returns>int			Returns an accessible Community for the current user or -1 if none can be found</returns>
    int GetAccessibleCommunityID(int nSubPortalCommID);
    
    /// <summary>
    /// Gets the ID of the current Community (if in one)
    /// </summary>
    /// <returns>Object ID of the current Community</returns>
    int GetCurCommunityID();
    
    /// <summary>
    /// Gets the name of the current Community 
    /// </summary>
    /// <returns>Name of the current Community</returns>
    String GetCurCommunityName();
    
    /// <summary>
    /// Gets the Communities on the same level as the current community.
    /// </summary>
    /// <returns>Links to the the current community's related communities</returns>
    ICPListEntryIterator GetCurRelCommunities();
    
    /// <summary>
    /// Gets the subcommunities of the current community.
    /// </summary>
    /// <returns>Links to the subcommunities of the current community</returns>
    ICPListEntryIterator GetCurSubCommunities();
    
    /// <summary>
    /// Gets the default Community ID of the current user, i.e.
    /// first Community in the membership list.
    /// </summary>
    /// <returns>Object ID of the default Community</returns>
    int GetDefaultCommunity();
    
    /// <summary>
    /// Helper function, returns the join community link, community actions if on
    /// a community page and the list of communities.
    /// </summary>
    /// <param name="bListActions"></param>
    /// <returns>ICPListEntryIterator</returns>
    ICPListEntryIterator GetMyCommunities(bool bListActions);
    
    /// <summary>
    /// Gets the parent community of the current Community
    /// </summary>
    /// <returns>The link to the parent community of the current Community</returns>
    ICPListEntryIterator GetParentComm();
    
    /// <summary>
    /// Checks if the current user is the owner of the current Community
    /// </summary>
    /// <returns>True if the current user is the owner of the current Community</returns>
    bool IsCurCommOwner();
  }
}