using System;
using com.plumtree.portalpages.common.uiparts.navpagetype;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.plugnav
{
  /// <summary>
  /// This interface offers the pluggable navigation developer all the 
  /// functionality they need to build pluggable navigation views.
  /// </summary>
  /// <author>DavidP</author>
  public interface IPluggableNavModelRO : IModelRO
  {
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    Object Create();
    
    /// <summary>
    /// Gets the link to the My Account settings page
    /// </summary>
    /// <returns>Link to My Account settings page in an ICPListEntryIterator</returns>
    ICPListEntryIterator GetPortalSettings();
    
    /// <summary>
    /// Gets visibility of the specified vertical navigation section
    /// </summary>
    /// <param name="nSectionIDConst">NavVisibility ID of the section to check visibility on</param>
    /// <returns>					True if the specified section is visibile</returns>
    /// <seealso cref="NavVisibility"></seealso>
    bool GetSectionVisibility(int nSectionIDConst);
    
    /// <summary>
    /// Gets the internationalized string for the title on the category.
    /// </summary>
    /// <param name="linkType">NavCategoryType</param>
    /// <returns>			Title String for the specified NavCategoryType </returns>
    /// <seealso cref="NavCategoryType"></seealso>
    String GetCategoryTitle(NavCategoryType linkType);
    
    /// <summary>
    /// Get the name of the subsection title; basically, actions for mypage and communities only.
    /// </summary>
    /// <param name="linkType">NavCategoryType</param>
    /// <param name="">boolean actions true or false</param>
    /// <returns>String category name for link title</returns>
    /// <seealso cref="NavCategoryType"></seealso>
    String GetSubsectionTitle(NavCategoryType linkType, bool bAction);
    
    /// <summary>
    /// Gets the header for this page from the Subportal.  Returns 
    /// default header if no header portlet assigned.
    /// </summary>
    /// <returns>HTMLElement with the footer set in the Subportal</returns>
    HTMLElement GetSubportalBanner();
    
    /// <summary>
    /// Gets the footer for this page from the Subportal.  Returns 
    /// default footer if no footer portlet assigned.
    /// </summary>
    /// <returns>HTMLElement with the footer set in the Subportal </returns>
    HTMLElement GetSubportalFooter();
    
    /// <summary>
    /// Checks if the user has admin access rights or not.
    /// </summary>
    /// <returns>True if the current user has Administrator access to the current Community</returns>
    bool HasAdministratorAccess();
    
    /// <summary>
    /// Checks if the current user has at least select access to the current Community
    /// </summary>
    /// <returns>boolean</returns>
    /// <seealso cref="com.plumtree.server.PT_ACCESS_LEVELS"></seealso>
    bool HasSelectAccess();
    
    /// <summary>
    /// Checks if logged in as guest or not.
    /// </summary>
    /// <returns>true if guest</returns>
    bool IsGuestSession();
    
    /// <summary>
    /// Sets visibility on vertical navigation sections
    /// </summary>
    /// <param name="nSectionIDConst">NavVisibility ID of the section to set visibility on</param>
    /// <param name="bShow">True of the section is visible</param>
    /// <seealso cref="NavVisibility"></seealso>
    void SetSectionVisibility(int nSectionIDConst, bool bShow);
    
    /// <summary>
    /// Checks if the specified feature is enabled in the current subportal.
    /// </summary>
    /// <param name="nType">NavVisibility Section ID</param>
    /// <returns>boolean		True if the specified section is visible</returns>
    /// <seealso cref="NavVisibility"></seealso>
    bool GetSubPortalEnabled(int nType);
    
    /// <summary>
    /// Used by pluggable navigation to access the model specific 
    /// to the page we're on (see GetCurNavPage())
    /// </summary>
    /// <returns>The current NavigationPage interface</returns>
    /// <seealso cref="NavigationPage"></seealso>
    /// <seealso cref="NavPageType"></seealso>
    NavigationPage GetPageSpecificMethods();
    
    /// <summary>
    /// Gets the current page type.
    /// </summary>
    /// <returns>NavPageType</returns>
    /// <seealso cref="NavPageType"></seealso>
    NavPageType GetCurNavPageType();
    
    /// <summary>
    /// Gets a user's defeault community id, (right now the first community
    /// in mycommunities)
    /// </summary>
    /// <returns>The default Community ID</returns>
    int GetDefaultCommunity();
    
    /// <summary>
    /// Checks for at least read access to the specified Community,
    /// If current user lacks access, get the user's default Community and
    /// user has no default communities, return -1.
    /// </summary>
    /// <param name="nCommID">ID of the Community to check access to</param>
    /// <returns>int			Returns an accessible Community for the current user or -1 if none can be found</returns>
    int GetAccessibleCommunityID(int nCommID);
    //public String GetMandatoryLinksFolderName();	
    
    /// <summary>
    /// Get the links lists by category, with or without actions
    /// </summary>
    /// <param name="linkType">NavCategoryType</param>
    /// <param name="getActions">True to include actions</param>
    /// <returns>						ICPListEntryIterator with the links of the requested NavCategoryType	</returns>
    /// <seealso cref="NavCategoryType"></seealso>
    ICPListEntryIterator GetCategoryLinks(NavCategoryType linkType, bool getActions);
    
    /// <summary>
    /// Checks if the current page is a Edit Default Profile Editor page
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsEditProfile();
  }
}