using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.common.search
{
  /// <author>CraigS, based on MikeS code</author>
  public class FolderSelectorModel : EditorHelperModel,IFolderSelectorModelRO,
  IFolderSelectorModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.search.FolderSelectorModel");
    public const String STR_MVC_CLASS_NAME = "FolderSelector";
    private String _lastAdmTreeSpaceId;
    private String _lastCatTreeSpaceId;
    private XPArrayList _admSelections;
    private XPArrayList _catSelections;
    private bool _includeSubfolders = true;
    private bool _multiSelectMode;
    
    /// <param name="isAdmin"></param>
    /// <param name="tree"></param>
    public virtual void AddFoldersFromTreeSelections(bool isAdmin, ITreeModel tree)
    {
      XPArrayList treeSelections = tree.GetSelectedItems();
      XPArrayList tempList = new XPArrayList();
      IXPEnumerator e = treeSelections.GetEnumerator();
      while (e.MoveNext())
      {
        TreeLeafNode newNode = (TreeLeafNode) e.GetCurrent();
        tempList.Add(newNode);
      }
      if (isAdmin)
      {
        _admSelections = tempList;
      } else
      {
        _catSelections = tempList;
      }
    }
    
    /// <returns></returns>
    public override Object Create()
    {
      return new FolderSelectorModel();
    }
    
    /// <param name="isAdmin"></param>
    /// <param name="folderIDs"></param>
    public virtual void DeleteFolders(bool isAdmin, int[] folderIDs)
    {
      XPArrayList folderList = (isAdmin ? _admSelections : _catSelections);
      for (int j = 0;j < folderIDs.Length;j++)
      {
        for (int k = 0;k < folderList.GetSize();k++)
        {
          TreeLeafNode node = (TreeLeafNode) folderList.GetElement(k);
          if (node.m_nObjectID == folderIDs[j])
          {
            folderList.RemoveAt(k);
            break;
          }
        }
      }
    }
    
    /// <returns></returns>
    public virtual bool GetIncludeSubfolders()
    {
      return _includeSubfolders;
    }
    
    /// <param name="isAdmin"></param>
    /// <returns></returns>
    public virtual String GetLastTreeSpaceId(bool isAdmin)
    {
      if (_multiSelectMode)
      {
        // In multiselect mode, reuse the same tree
        if (isAdmin)
        {
          return _lastAdmTreeSpaceId;
        } else
        {
          return _lastCatTreeSpaceId;
        }
      } else
      {
        // For single-select mode, make a new tree every time.  On
        // the second and later tree calls, this avoids a confusing "You
        // have selected:" bar appearing with the previous selection.
        return null;
      }
    }
    
    /// <returns></returns>
    public virtual bool GetMultiSelectMode()
    {
      return _multiSelectMode;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="isAdmin"></param>
    /// <returns></returns>
    public virtual IXPCollection GetSelections(bool isAdmin)
    {
      if (isAdmin)
      {
        return _admSelections;
      } else
      {
        return _catSelections;
      }
    }
    
    /// <param name="multiSelectMode"></param>
    public virtual void InitializePlugIn(bool multiSelectMode)
    {
      _catSelections = new XPArrayList();
      _admSelections = new XPArrayList();
      _lastCatTreeSpaceId = null;
      _lastAdmTreeSpaceId = null;
      _multiSelectMode = multiSelectMode;
    }
    
    /// <param name="formData"></param>
    /// <returns></returns>
    public override int SaveSection(XPHashtable formData)
    {
      _includeSubfolders = formData.ContainsKey(FolderSelectorView.HTMLCHECKBOX_RECURSIVE);
      //this value represents if the folder filter is displayed on the advanced search layout.
      bool isFilterDisplayed = formData.ContainsKey(FolderSelectorView.DISPLAY_FOLDER_FILTER);
      //we are checking to see if the folder filter was ever displayed on the advanced search page by looking for
      //the hidden html element, DISPLAY_FOLDER_FILTER, added to the page to represent that the filter was actually
      //there on the page.  If it returns false, this means that it was not included at all, so we're setting the
      //includeSubfolders to true (instead of default false).
      //There is no way to determine if a user chose to NOT include subfolders in their search or if the filter was
      //added, so there is no way to determine if it is a valid Pathways advanced search or not.  Adding this check
      //will determine if the filter was added at all and SearchResultsModel.isValidPathwaysSearch() can properly
      //validate if the filter was set or not.
      if (isFilterDisplayed == false)
      {
        _includeSubfolders = true;
      }
      String[] data = (String[]) formData.GetElement(FolderSelectorView.HTMLHIDDEN_CATSPACEID);
      if ((null != data) && (data.Length > 0) && (data[0].Length > 0))
      {
        _lastCatTreeSpaceId = data[0];
      }
      data = (String[]) formData.GetElement(FolderSelectorView.HTMLHIDDEN_ADMSPACEID);
      if ((null != data) && (data.Length > 0) && (data[0].Length > 0))
      {
        _lastAdmTreeSpaceId = data[0];
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    public virtual void InitFromFormData(XPHashtable formData)
    {
      if (formData == null)
      {
        return;
      }
      IPTSession _session = (IPTSession) m_asOwner.GetUserSession();
      String[] subfolders = (String[]) formData.GetElement(StartSearchControl.NON_INPUT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S);
      if ((null != subfolders) && subfolders.Length > 0)
      {
        try
        {
          _includeSubfolders = (XPConvert.ToInteger(subfolders[0]) != 0);
          }
        catch (Exception e)
        {
          log.Error(e, "FolderSelectorModel.InitFromFormData got exception.");
          }
      }
      String[] folders = (String[]) formData.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S);
      IPTObject ptObj = null;
      if ((null != folders) && (folders.Length > 0))
      {
        int id = 0;
        for (int j = 0;j < folders.Length;j++)
        {
          try
          {
            id = XPConvert.ToInteger(folders[j]);
            TreeLeafNode newNode = new TreeLeafNode(1);
            newNode.m_nObjectID = id;
            try
            {
              ptObj = _session.GetAdminCatalog().OpenAdminFolder(id, false);
              if (null != ptObj)
              {
                String name = ptObj.GetLocalizedName();
                if (null != name)
                {
                  newNode.SetName(name);
                } else
                {
                  newNode.SetName("NULL");
                }
              }
            }
            catch (Exception e)
            {
              newNode.SetName("NULL");
            }
            _admSelections.Add(newNode);
          }
          catch (Exception e)
          {
            throw XPException.GetInstance(e);
          }
        }
      }
      folders = (String[]) formData.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_DDFOLDERS_S);
      if ((null != folders) && (folders.Length > 0))
      {
        int id = 0;
        for (int j = 0;j < folders.Length;j++)
        {
          try
          {
            id = XPConvert.ToInteger(folders[j]);
            TreeLeafNode newNode = new TreeLeafNode(1);
            newNode.m_nObjectID = id;
            try
            {
              ptObj = _session.GetCatalog().OpenFolder(id, false);
              if (null != ptObj)
              {
                String name = ptObj.GetLocalizedName();
                if (null != name)
                {
                  newNode.SetName(name);
                } else
                {
                  newNode.SetName("NULL");
                }
              }
            }
            catch (Exception e)
            {
              newNode.SetName("NULL");
            }
            _catSelections.Add(newNode);
          }
          catch (Exception e)
          {
            throw XPException.GetInstance(e);
          }
        }
      }
    }
    /*
     * getFolderSelections returns a comma-separated list of classid,objectid pairs. It is
     * used to initialize the tree view.
     * @see com.plumtree.portalpages.common.search.IFolderSelectorModelRO#getFolderSelections(boolean)
     */
     
    public virtual String GetFolderSelections(bool isAdmin)
    {
      XPArrayList folderList = (isAdmin ? _admSelections : _catSelections);
      String retval = "";
      for (int j = 0;j < folderList.GetSize();j++)
      {
        for (int k = 0;k < folderList.GetSize();k++)
        {
          TreeLeafNode node = (TreeLeafNode) folderList.GetElement(k);
          // Add classid,
          retval = commaAdd(retval, (isAdmin) ? "20" : "17");
          // Add objectid,
          retval = commaAdd(retval, XPConvert.ToString(node.m_nObjectID));
          }
      }
      return retval;
    }
    private String commaAdd(String initial, String addend)
    {
      if (initial != null && !initial.Equals(""))
      {
        return initial + "," + addend;
      } else
      {
        return addend;
      }
    }
  }
}