using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.tree;
namespace com.plumtree.portalpages.common.search
{
  /// <author>CraigS, based on MikeS/OlegS code</author>
  public class FolderSelectorRepostControl : EditorHelperRepostControl
  {
    public const String STR_MVC_CLASS_NAME = "FolderSelectorRepostControl";
    // Repost actions
    public const int ACTION_DEL = 5411;
    public const int ACTION_ADD_ADMIN = 5412;
    public const int ACTION_ADD_CATALOG = 5413;
    
    /// <returns></returns>
    public override Object Create()
    {
      return new FolderSelectorRepostControl();
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="action"></param>
    /// <param name="formData"></param>
    public override void PerformRepostAction(int action, XPHashtable formData)
    {
      IFolderSelectorModel model = (IFolderSelectorModel) m_model;
      IFolderSelectorModelRO modelRO = (IFolderSelectorModelRO) m_model;
      // If we're deleting
      if (ACTION_DEL == action)
      {
        // The folder(s) to delete are marked by HTMLCHECKBOX_FOLDER.
        String[] folders = (String[]) formData.GetElement(FolderSelectorView.HTMLCHECKBOX_FOLDER);
        if ((null != folders) && (folders.Length > 0))
        {
          int admCount = 0;
          int catCount = 0;
          for (int j = 0;j < folders.Length;j++)
          {
            if (XPStringUtility.StartsWith(folders[j], FolderSelectorView.FOLDER_PFX_ADM))
            {
              admCount+=1;
            } else
            {
              catCount+=1;
            }
          }
          // Delete admin folders, if any
          if (admCount > 0)
          {
            int[] folderIDs = new int[admCount];
            int k = 0;
            for (int j = 0;j < folders.Length;j++)
            {
              if (XPStringUtility.StartsWith(folders[j], FolderSelectorView.FOLDER_PFX_ADM))
              {
                try
                {
                  folderIDs[k] = XPConvert.ToInteger(XPStringUtility.Substring(folders[j],
                   2));
                }
                catch (Exception e)
                {
                  throw XPException.GetInstance(e);
                }
                k++;
              }
            }
            /* isAdmin= */
            model.DeleteFolders(true, folderIDs);
          }
          // Delete catalog folders, if any
          if (catCount > 0)
          {
            int[] folderIDs = new int[catCount];
            int k = 0;
            for (int j = 0;j < folders.Length;j++)
            {
              if (XPStringUtility.StartsWith(folders[j], FolderSelectorView.FOLDER_PFX_CAT))
              {
                try
                {
                  folderIDs[k] = XPConvert.ToInteger(XPStringUtility.Substring(folders[j],
                   2));
                }
                catch (Exception e)
                {
                  throw XPException.GetInstance(e);
                }
                k++;
              }
            }
            /* isAdmin= */
            model.DeleteFolders(false, folderIDs);
          }
        }
        return;
      } else
      // If we're adding
      if ((ACTION_ADD_ADMIN == action) || (ACTION_ADD_CATALOG == action))
      {
        bool isAdminChecked = (ACTION_ADD_ADMIN == action);
        // We need to get the selected items out of the tree popup.
        String treeName = (isAdminChecked ? "AdminFolderTree" : "CatFolderTree");
        ATreeAS treeSpace = (ATreeAS) (m_asOwner.GetSubSpace(treeName));
        ITreeModel tree = (ITreeModel) treeSpace.GetModel(ATreeAS.TREEMODEL);
        model.AddFoldersFromTreeSelections(isAdminChecked, tree);
        if (!modelRO.GetMultiSelectMode())
        {
          // In single select mode, we don't reuse the same selection tree, 
          // so we should remove its subspace to avoid confusing it with the
          // next tree we create
          m_asOwner.DeleteSubSpace(treeName);
        }
      }
    }
  }
}