using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.search
{
  /// <author>CraigS, based on MikeS/OlegS code</author>
  public abstract class FolderSelectorView : EditorLikeView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.search.FolderSelectorView");
    // mbs- believe these are needed for folder tree control
    public const String HTMLHIDDEN_FOLDERSELECTED = "in_hi_CatalogFolderSelected";
    public const String HTMLHIDDEN_CATSPACEID = "in_hi_CatalogFolderSpaceID";
    public const String HTMLHIDDEN_ADMSPACEID = "in_hi_AdminFolderSpaceID";
    public const String HTMLHIDDEN_TREEREPOST = "in_hi_CatalogFolderRepostAction";
    public const String JAVASCRIPT_CATALOGFOLDERTREE = "openRemoteCatalogFolderTree";
    public const String HTMLCHECKBOX_FOLDER = "in_cb_folder";
    public const String IN_CB_MASTER = "in_cb_master";
    public const String HTMLCHECKBOX_RECURSIVE = "in_cb_subfoldersearch";
    public const String FOLDER_PFX_ADM = "od";
    //id of hidden input for folder filter
    public const String DISPLAY_FOLDER_FILTER = "displayFolderFilter";
    public const String FOLDER_PFX_CAT = "dd";
    public const String PORTAL_COMMON_MSGS = "ptmsgs_portalcommonmsgs";
    private IFolderSelectorModelRO _model = null;
    
    /// <summary>
    /// Creates the restrict to folders filter HTML in the advanced search settings page
    /// </summary>
    /// <returns></returns>
    public override HTMLElement Display()
    {
      _model = (IFolderSelectorModelRO) m_model;
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(m_asOwner.GetString(727,
         PORTAL_COMMON_MSGS), false));
        HTMLTable actionbar = GetActionBar();
        result.AddInnerHTMLElement(actionbar);
        HTMLElement spacer = SearchUIUtility.makeSpacer(m_asOwner, CommonHTMLStrings.FOUR);
        result.AddInnerHTMLElement(spacer);
        // Add "include subfolders" checkbox
        HTMLTable include = new HTMLTable();
        include.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        include.SetCellPadding(CommonHTMLStrings.FIVE);
        HTMLTableRow row = new HTMLTableRow();
        row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        include.AddInnerHTMLElement(row);
        HTMLTableCell cell = new HTMLTableCell();
        cell.SetHeight("20");
        cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        //cell.SetStyleClass(PTStyleClass.L) No listcheckbox class
        row.AddInnerHTMLElement(cell);
        HTMLInput recInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_RECURSIVE,
         "");
        recInput.SetChecked(_model.GetIncludeSubfolders());
        recInput.SetValue(XPConvert.ToString(true));
        recInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        cell.AddInnerHTMLElement(recInput);
        //217 == "Include subfolders"
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        span.AddInnerHTMLString(m_asOwner.GetString(217, PORTAL_COMMON_MSGS));
        cell.AddInnerHTMLElement(span);
        //Adding this hidden input to determine if the folder filter is added to the adaptive page layout.
        HTMLInput displayInput = new HTMLInput(HTMLInputTypes.HIDDEN, DISPLAY_FOLDER_FILTER,
         "");
        cell.AddInnerHTMLElement(displayInput);
        result.AddInnerHTMLElement(include);
        DisplayFolderList(result);
        DisplayHiddenInputs(result);
      }
      catch (Exception e)
      {
        log.Error(e, e.Message);
        // 203 == "Unable to display the HTML for FolderSelectorView (Display).
        throw new XPException(m_asOwner.GetString(203, PORTAL_COMMON_MSGS),
         e);
      }
      return result;
    }
    
    /// <summary>
    /// Action bar creates the subheader HTML that contains the "add document folder" and "add administrative folder" buttons
    /// </summary>
    /// <returns></returns>
    protected virtual HTMLTable GetActionBar()
    {
      //Style sheet references has been modified with ADVSEARCH_XXX to provide new color schemes for the advanced search layout
      HTMLTable table = new HTMLTable();
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetCellSpacing(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.ZERO);
      table.SetBorder(CommonHTMLStrings.ZERO);
      HTMLTableRow row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      table.AddInnerHTMLElement(row);
      HTMLImg addImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ACTION_ADD,
       "", "6", "25");
      addImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg add2Img = SearchUIUtility.GetImage(m_asOwner, PTImageType.ACTION_ADD,
       "", "6", "25");
      add2Img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg folderImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ICON_FOLDER,
       "", "18", "20");
      folderImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg adminFolderImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ICON_ADMINISTRATION,
       "", "20", "20");
      adminFolderImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      HTMLImg delImg = SearchUIUtility.GetImage(m_asOwner, PTImageType.ACTION_REMOVE,
       "", "25", "25");
      delImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      //HTMLImg sp1Img = SearchUIUtility.GetImage(m_asOwner,PTImageType.SPACER,"","1","1");
      //HTMLImg sp2Img = SearchUIUtility.GetImage(m_asOwner,PTImageType.SPACER,"","1","1");
      //HTMLImg sp3Img = SearchUIUtility.GetImage(m_asOwner,PTImageType.SPACER,"","1","1");
      HTMLTableCell cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      // Add document folders link
      HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      anchor.SetOnClick(JAVASCRIPT_CATALOGFOLDERTREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_CATSPACEID + ", document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_ADMSPACEID + "," + XPConvert.ToString(FolderSelectorRepostControl.ACTION_ADD_CATALOG) + ",1); return false;");
      cell.AddInnerHTMLElement(anchor);
      anchor.AddInnerHTMLString(SPACE);
      anchor.AddInnerHTMLElement(addImg);
      anchor.AddInnerHTMLElement(folderImg);
      anchor.AddInnerHTMLString(SPACE);
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      span.AddInnerHTMLString(m_asOwner.GetString(725, PORTAL_COMMON_MSGS));
      anchor.AddInnerHTMLElement(span);
      span.AddInnerHTMLString(SPACE);
      /*
       cell = new HTMLTableCell();
       row.AddInnerHTMLElement(cell);
       cell.SetHeight("25");
       cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
       cell.AddInnerHTMLElement(sp1Img);
       */
       
      // Add admin folder button
      anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      anchor.SetOnClick(JAVASCRIPT_CATALOGFOLDERTREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_CATSPACEID + ", document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_ADMSPACEID + "," + XPConvert.ToString(FolderSelectorRepostControl.ACTION_ADD_ADMIN) + ",0); return false;");
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      cell.AddInnerHTMLElement(anchor);
      anchor.AddInnerHTMLString(SPACE);
      anchor.AddInnerHTMLElement(add2Img);
      anchor.AddInnerHTMLElement(adminFolderImg);
      anchor.AddInnerHTMLString(SPACE);
      span = new HTMLSpan();
      span.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      span.AddInnerHTMLString(m_asOwner.GetString(726, PORTAL_COMMON_MSGS));
      anchor.AddInnerHTMLElement(span);
      span.AddInnerHTMLString(SPACE);
      /*
       cell = new HTMLTableCell();
       row.AddInnerHTMLElement(cell);
       cell.SetHeight("25");
       cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
       cell.AddInnerHTMLElement(sp2Img);
       */
       
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      cell.SetNoWrap(true);
      anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      anchor.SetOnClick("postToSelf(" + FolderSelectorRepostControl.ACTION_DEL + "); return false;");
      cell.AddInnerHTMLElement(anchor);
      anchor.AddInnerHTMLElement(delImg);
      /*
       cell = new HTMLTableCell();
       row.AddInnerHTMLElement(cell);
       cell.SetHeight("25");
       cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
       cell.AddInnerHTMLElement(sp3Img);
       */
       
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return table;
    }
    
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      _model = (IFolderSelectorModelRO) m_model;
      HTMLScript script = new HTMLScript("text/javaScript");
      try
      {
        String strFormName = AFormDP.HTMLFORM_NAME;
        // The URL to open a new remote catalog folder tree
        ASURL newCatalogFolderTree = new ASURL(m_asOwner);
        newCatalogFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        newCatalogFolderTree.SetSubSpaceKey("CatFolderTree");
        newCatalogFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        // 212 = Select folder for Search.
        newCatalogFolderTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(212,
         PORTAL_COMMON_MSGS));
        // Users can search in any folder to which they have READ rights (default for tree is SELECT)
        newCatalogFolderTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL,
         PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
        newCatalogFolderTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         _model.GetFolderSelections(false));
        newCatalogFolderTree.AddControlArgument(StartTreeControl.ALLOW_EMPTY_SUBMISSION,
         XPConvert.ToString(true));
        // 214 = Folder
        newCatalogFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
         m_asOwner.GetString(214, PORTAL_COMMON_MSGS));
        newCatalogFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
         XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
        newCatalogFolderTree.AddControlArgument(StartTreeControl.ROOT_ID,
         XPConvert.ToString(PT_INTRINSICS.PT_FOLDER_ROOTFOLDER));
        newCatalogFolderTree.AddControlArgument(StartTreeControl.SHOW_ROOT,
         XPConvert.ToString(true));
        if (_model.GetMultiSelectMode())
        {
          newCatalogFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(true));
        } else
        {
          newCatalogFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(false));
        }
        newCatalogFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE,
         XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
        newCatalogFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
         XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
        newCatalogFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
         strFormName);
        newCatalogFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
         HTMLHIDDEN_CATSPACEID);
        newCatalogFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
         "treeSubmit");
        ASURL newAdminFolderTree = new ASURL(m_asOwner);
        newAdminFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        newAdminFolderTree.SetSubSpaceKey("AdminFolderTree");
        newAdminFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
        newAdminFolderTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
         _model.GetFolderSelections(true));
        // 212 = Select folder for Search.
        newAdminFolderTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(212,
         PORTAL_COMMON_MSGS));
        // 214 = Folder
        newAdminFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
         m_asOwner.GetString(214, PORTAL_COMMON_MSGS));
        // newAdminFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY, XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));
        // Users can search in any folder to which they have READ rights (default for tree is SELECT)
        newAdminFolderTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL,
         PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
        newAdminFolderTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_FOLDER_ROOTFOLDER));
        newAdminFolderTree.AddControlArgument(StartTreeControl.SHOW_ROOT,
         XPConvert.ToString(true));
        if (_model.GetMultiSelectMode())
        {
          newAdminFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(true));
        } else
        {
          newAdminFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
           XPConvert.ToString(false));
        }
        newAdminFolderTree.AddControlArgument(StartTreeControl.ALLOW_EMPTY_SUBMISSION,
         XPConvert.ToString(true));
        newAdminFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE,
         XPConvert.ToString(TreeConstants.N_COMPOSITESELECT));
        newAdminFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
         XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
        newAdminFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
         strFormName);
        newAdminFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
         HTMLHIDDEN_ADMSPACEID);
        newAdminFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
         "treeSubmit");
        // The url to open a previously opened remote catalog folder tree
        // This needs to have the SpaceID added to it.
        ASURL oldCatalogFolderTree = new ASURL(m_asOwner);
        oldCatalogFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        oldCatalogFolderTree.IsSubSpace();
        // The url to open a previously opened remote admin folder tree
        // This needs to have the SpaceID added to it.
        ASURL oldAdminFolderTree = new ASURL(m_asOwner);
        oldAdminFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        oldAdminFolderTree.IsSubSpace();
        String cat = newCatalogFolderTree.GetURLAsString();
        String oldcat = oldCatalogFolderTree.GetURLAsString();
        String adm = newAdminFolderTree.GetURLAsString();
        String oldadm = oldAdminFolderTree.GetURLAsString();
        // Open remote catalog folder tree function
        XPStringBuilder sb = new XPStringBuilder(200);
        sb.Append("function " + JAVASCRIPT_CATALOGFOLDERTREE + "(catspaceid, admspaceid, repostaction, docfldr)\n");
        sb.Append("{\n");
        sb.Append("  if (docfldr != 0)\n");
        sb.Append("  {\n");
        sb.Append("  \tdocument." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_TREEREPOST + ".value = repostaction;\n");
        //catspaceid.value == '')\n");
        sb.Append("  \tif (true)\n");
        sb.Append("    \t\twindow.open(\'" + cat + "\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  \telse\n");
        sb.Append("    \t\twindow.open(\'" + oldcat + "&" + ASConstants.SPACEID + "=\' + catspaceid.value, \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("   }\n");
        sb.Append("   else\n");
        sb.Append("   {\n");
        sb.Append("  \tdocument." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_TREEREPOST + ".value = repostaction;\n");
        //admspaceid.value == '')\n");
        sb.Append("  \tif (true)\n");
        sb.Append("    \t\twindow.open(\'" + adm + "\', \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("  \telse\n");
        sb.Append("    \t\twindow.open(\'" + oldadm + "&" + ASConstants.SPACEID + "=\' + admspaceid.value, \'_blank1\', \'").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("\');\n");
        sb.Append("   }\n");
        sb.Append("}\n");
        script.AddInnerHTMLString(sb.ToString());
        // Submit function
        sb.SetLength(0);
        sb.Append("function treeSubmit()\n");
        sb.Append("{\n");
        sb.Append("  postToSelf(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_TREEREPOST + ".value);\n");
        sb.Append("}\n");
        sb.Append("function DoToggleAll()\n");
        sb.Append("{\n");
        sb.Append("    var fElem = document." + AFormDP.HTMLFORM_NAME + ";\n");
        sb.Append("    var feLen = fElem.elements.length;\n");
        sb.Append("    var checkVal = false;\n");
        sb.Append("    for (var i = 0; i < feLen; i++) {\n");
        sb.Append("        if (fElem.elements[i].name == \'" + IN_CB_MASTER + "\') {\n");
        sb.Append("            checkVal = fElem.elements[i].checked;\n");
        sb.Append("        }\n");
        sb.Append("    }\n");
        sb.Append("    for (var i = 0; i < feLen; i++) {\n");
        sb.Append("    \t   if (fElem.elements[i].name == \'" + HTMLCHECKBOX_FOLDER + "\') {\n");
        sb.Append("            fElem.elements[i].checked = checkVal;\n");
        sb.Append("        }\n");
        sb.Append("    }\n");
        sb.Append("    return true;\n");
        sb.Append("}\n");
        script.AddInnerHTMLString(sb.ToString());
      }
      catch (Exception e)
      {
        log.Error(e, "SettingsView::Display An error occured when trying to display the HTML.");
        // 203 = Unable to display the HTML for FolderSelectorView (Display).
        throw new XPException(m_asOwner.GetString(203, PORTAL_COMMON_MSGS),
         e);
      }
      return script;
    }
    protected virtual String GetTitle()
    {
      // 727 = Restrict to Folders
      return m_asOwner.GetString(727, PORTAL_COMMON_MSGS);
    }
    
    /// <param name="result"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayDeleteButton(HTMLElement result)
    {
      HTMLTable table;
      HTMLTableRow row;
      HTMLTableCell cell;
      HTMLAnchor anchor;
      HTMLImg img;
      HTMLComment myComment = new HTMLComment("Begin: DisplayDeleteButton FolderSelectorView");
      result.AddInnerHTMLElement(myComment);
      table = new HTMLTable();
      result.AddInnerHTMLElement(table);
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetBorder(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.ZERO);
      table.SetCellSpacing(CommonHTMLStrings.ZERO);
      row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      // delete folder	
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetHeight("25");
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      cell.SetNoWrap(true);
      anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      anchor.SetOnClick("postToSelf(" + FolderSelectorRepostControl.ACTION_DEL + ");");
      cell.AddInnerHTMLString(SPACE);
      cell.AddInnerHTMLString(SPACE);
      cell.AddInnerHTMLElement(anchor);
      img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_DELETE).GetHTMLElement();
      img.SetWidth("20");
      img.SetHeight("20");
      //213 = Remove checked folders from list.
      img.SetAlt(m_asOwner.GetString(213, PORTAL_COMMON_MSGS));
      img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      anchor.AddInnerHTMLElement(img);
      // 213 = Remove checked folders from list.
      anchor.AddInnerHTMLString(m_asOwner.GetString(213, PORTAL_COMMON_MSGS));
      cell.AddInnerHTMLString(SPACE);
      myComment = new HTMLComment("End: DisplayDeleteButton FolderSelectorView");
      result.AddInnerHTMLElement(myComment);
    }
    
    /// <summary>
    /// Displays the HTML for the list of folders to restrict 
    /// </summary>
    /// <returns></returns>
    /// <throws>HTMLException </throws>
    protected virtual bool DisplayFolderList(HTMLElementCollection result)
    {
      HTMLTable table;
      //Style sheet references has been modified with ADVSEARCH_XXX to provide new color schemes for the advanced search layout
      // header 
      table = new HTMLTable();
      result.AddInnerHTMLElement(table);
      table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      table.SetBorder(CommonHTMLStrings.ZERO);
      table.SetCellPadding(CommonHTMLStrings.TWO);
      table.SetCellSpacing(CommonHTMLStrings.TWO);
      if (!_model.GetSelections(true).IsEmpty() || !_model.GetSelections(false).IsEmpty())
      {
        HTMLTableRow headerRow = new HTMLTableRow();
        headerRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
        table.AddInnerHTMLElement(headerRow);
        HTMLTableCell cell1 = new HTMLTableCell();
        cell1.SetWidth("20");
        cell1.SetHeight("20");
        cell1.SetAlign(CommonHTMLStrings.CENTER);
        cell1.SetVAlign(CommonHTMLStrings.TOP);
        //cell1.SetStyleClass(PTStyleClass.LISTCHECBOX????)
        headerRow.AddInnerHTMLElement(cell1);
        HTMLInput masterCheck = new HTMLInput(HTMLInputTypes.CHECKBOX, IN_CB_MASTER,
         "", "");
        masterCheck.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        masterCheck.SetOnClick("DoToggleAll()");
        cell1.AddInnerHTMLElement(masterCheck);
        cell1 = new HTMLTableCell();
        cell1.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        cell1.SetHeight("20");
        cell1.SetColSpan(CommonHTMLStrings.TWO);
        cell1.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        cell1.AddInnerHTMLString(m_asOwner.GetString(728, PORTAL_COMMON_MSGS));
        headerRow.AddInnerHTMLElement(cell1);
      }
      int count = 1;
      IXPCollection selections = _model.GetSelections(true);
      IXPEnumerator eSelections = selections.GetEnumerator();
      // Display admin folders
      while (eSelections.MoveNext())
      {
        TreeLeafNode node = (TreeLeafNode) eSelections.GetCurrent();
        DisplayFolderListItem(table, node.m_nObjectID, node.GetName(), (count++ % 2 == 0),
         true);
      }
      selections = _model.GetSelections(false);
      eSelections = selections.GetEnumerator();
      // Display document folders
      while (eSelections.MoveNext())
      {
        TreeLeafNode node = (TreeLeafNode) eSelections.GetCurrent();
        DisplayFolderListItem(table, node.m_nObjectID, node.GetName(), (count++ % 2 == 0),
         false);
      }
      return true;
    }
    
    /// <summary>
    /// displays the folder list headers in the restrict to folders filter ("add document folder")
    /// </summary>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayFolderListHeader(HTMLTable table, bool isAdmin)
    {
      HTMLTableRow row;
      HTMLTableCell cell;
      HTMLAnchor anchor;
      HTMLImg img;
      //Style sheet references has been modified with ADVSEARCH_XXX to provide new color schemes for the advanced search layout
      row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
      table.AddInnerHTMLElement(row);
      cell = new HTMLTableCell();
      cell.SetHeight("15");
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      row.AddInnerHTMLElement(cell);
      HTMLB bold = new HTMLB();
      cell.AddInnerHTMLElement(bold);
      bold.AddInnerHTMLString(SPACE);
      if (isAdmin)
      {
        // 209 = Administrative Folders
        bold.AddInnerHTMLString(m_asOwner.GetString(209, PORTAL_COMMON_MSGS));
        } else
      {
        // 208 = Document Folders
        bold.AddInnerHTMLString(m_asOwner.GetString(208, PORTAL_COMMON_MSGS));
        }
      // Add the "add folder" cell
      cell = new HTMLTableCell();
      cell.SetHeight("15");
      cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      row.AddInnerHTMLElement(cell);
      anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
      anchor.SetOnClick(JAVASCRIPT_CATALOGFOLDERTREE + "(document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_CATSPACEID + ", document." + AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_ADMSPACEID + "," + XPConvert.ToString(isAdmin ? FolderSelectorRepostControl.ACTION_ADD_ADMIN : FolderSelectorRepostControl.ACTION_ADD_CATALOG) + "," + (isAdmin ? "0" : "1") + "); return false;");
      cell.AddInnerHTMLString(SPACE);
      cell.AddInnerHTMLElement(anchor);
      cell.SetAlign(CommonHTMLStrings.RIGHT);
      if (_model.GetMultiSelectMode() && (_model.GetSelections(isAdmin).GetSize() > 0))
      {
        img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT_SMALL).GetHTMLElement();
        } else
      {
        img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD).GetHTMLElement();
        }
      // 210 = Add
      img.SetAlt(m_asOwner.GetString(210, PORTAL_COMMON_MSGS));
      img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      anchor.AddInnerHTMLElement(img);
      HTMLSpan span = new HTMLSpan();
      anchor.AddInnerHTMLElement(span);
      span.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
      span.AddInnerHTMLString(SPACE);
      if (_model.GetMultiSelectMode() && (_model.GetSelections(isAdmin).GetSize() > 0))
      {
        // 211 = Change
        span.AddInnerHTMLString(m_asOwner.GetString(211, PORTAL_COMMON_MSGS));
        } else
      {
        //			210 = Add
        span.AddInnerHTMLString(m_asOwner.GetString(210, PORTAL_COMMON_MSGS));
        }
    }
    
    /// <summary>
    /// Displays the list of folders that have been added in the restrict to folders filter
    /// </summary>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayFolderListItem(HTMLTable table, int id,
     String name, bool shaded, bool isAdmin)
    {
      HTMLTableRow row;
      HTMLTableCell cell;
      HTMLInput input;
      HTMLImg img;
      //Style sheet references has been modified with ADVSEARCH_XXX to provide new color schemes for the advanced search layout
      row = new HTMLTableRow();
      row.SetStyleClass(shaded ? PTStyleClass.LIST_ITEM_ONE_BG : PTStyleClass.LIST_ITEM_TWO_BG);
      table.AddInnerHTMLElement(row);
      // Only display deletion checkbox if we're in single-select mode
      cell = new HTMLTableCell();
      cell.SetVAlign(CommonHTMLStrings.TOP);
      cell.SetAlign(CommonHTMLStrings.CENTER);
      cell.SetHeight("20");
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      row.AddInnerHTMLElement(cell);
      String encodedName = XPHttpUtility.HtmlEncode(name);
      // 216 = Checkbox for folder
      input = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_FOLDER,
       m_asOwner.GetString(216, PORTAL_COMMON_MSGS) + " \"" + encodedName + "\"");
      input.SetChecked(false);
      input.SetValue((isAdmin ? FOLDER_PFX_ADM : FOLDER_PFX_CAT) + XPConvert.ToString(id));
      input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      cell.AddInnerHTMLElement(input);
      cell = new HTMLTableCell();
      cell.SetVAlign(CommonHTMLStrings.TOP);
      cell.SetAlign(CommonHTMLStrings.CENTER);
      cell.SetHeight("20");
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      row.AddInnerHTMLElement(cell);
      img = (HTMLImg) UIConstructFactory.GetConstruct(isAdmin ? PTImageType.ICON_ADMINISTRATION : PTImageType.ICON_FOLDER).GetHTMLElement();
      img.SetWidth("20");
      img.SetHeight("20");
      img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      if (isAdmin)
      {
        // 209 = Administrative Folders
        img.SetAlt(m_asOwner.GetString(209, PORTAL_COMMON_MSGS));
      } else
      {
        // 208 = Document Folders
        img.SetAlt(m_asOwner.GetString(208, PORTAL_COMMON_MSGS));
      }
      cell.AddInnerHTMLElement(img);
      /*
       * 	<tr class="listItemTwoBg">
       <td width="20" height="20" align="center" valign="top" class="listcheckbox"><input type="checkbox" value="checkbox" name="checkbox001" class="formCheckboxText" alt="checkbox"></td>
       <td height="20" align="center" valign="top" class="listText" nowrap><img src="../../common/images/icon_administration.gif" width="20" height="20" align="absmiddle" border="0" alt="Folder"></td>
       <td width="100%" height="20" valign="middle" class="listText" nowrap>Admin Object Director</td>
       </tr>
       
       */
       
      cell = new HTMLTableCell();
      cell.SetAlign(CommonHTMLStrings.LEFT);
      cell.SetHeight("20");
      cell.SetNoWrap(true);
      cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      row.AddInnerHTMLElement(cell);
      cell.AddInnerHTMLString(encodedName);
    }
    
    /// <param name="result"></param>
    /// <throws>HTMLException </throws>
    protected virtual void DisplayHiddenInputs(HTMLElement result)
    {
      HTMLInput input;
      // Hidden input for the Space ID for the tree.  That way if you hit the folder
      // tree link twice, it will open the same tree both times.
      // olegs: cool but dangerous; if you restart server you get a blank tree window
      // due to null root pointer in TreeCompositeIterator.<init>
      // one for the document directory
      input = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_CATSPACEID,
       "");
      result.AddInnerHTMLElement(input);
      String treeId = _model.GetLastTreeSpaceId(false);
      input.SetValue((null == treeId) ? "" : treeId);
      // and one for the admin directory
      input = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_ADMSPACEID,
       "");
      result.AddInnerHTMLElement(input);
      treeId = _model.GetLastTreeSpaceId(true);
      input.SetValue((null == treeId) ? "" : treeId);
      /* for old javascript submit only ??? javascript submitToParent() fails without it*/
      // hidden input to hold folders selected in tree
      input = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_FOLDERSELECTED,
       "");
      result.AddInnerHTMLElement(input);
      input.SetValue("");
      // hidden input to hold repost action on tree submit
      input = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_TREEREPOST,
       "");
      result.AddInnerHTMLElement(input);
      input.SetValue("");
    }
  }
}