using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.search
{
  /// <author>CraigS</author>
  public class SimpleSelectorView : EditorLikeView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.search.SimpleSelectorView");
    public const String STR_MVC_CLASS_NAME = "SimpleSelector";
    private ISimpleSelectorModelRO _model = null;
    
    /// <returns></returns>
    public override Object Create()
    {
      return new SimpleSelectorView();
    }
    
    /// <summary>
    /// displays the HTML for the result count options in result count filter
    /// </summary>
    /// <returns></returns>
    public override HTMLElement Display()
    {
      _model = (ISimpleSelectorModelRO) m_model;
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        result.AddInnerHTMLElement(base.GetHeaderView(_model.GetTitle(), true));
        HTMLTable table = new HTMLTable();
        table.SetCellSpacing("0");
        table.SetCellPadding("5");
        table.SetWidth("100%");
        result.AddInnerHTMLElement(table);
        HTMLTableRow row = new HTMLTableRow();
        table.AddInnerHTMLElement(row);
        row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
        HTMLTableCell cell = new HTMLTableCell();
        cell.SetWidth("100%");
        cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
        row.AddInnerHTMLElement(cell);
        HTMLSpan span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
        span.AddInnerHTMLString(_model.GetPromptText());
        cell.AddInnerHTMLElement(span);
        HTMLSelect select = new HTMLSelect(_model.GetElementName(), "");
        select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
        cell.AddInnerHTMLString("&nbsp;&nbsp;");
        cell.AddInnerHTMLElement(select);
        String[] options = _model.GetPossibleSelections();
        for (int j = 0;j < options.Length;j++)
        {
          HTMLOption option = new HTMLOption(XPConvert.ToString(j));
          option.AddInnerHTMLString(XPHttpUtility.HtmlEncode(options[j]));
          option.SetSelected(j == _model.GetCurrentSelection());
          select.AddInnerHTMLElement(option);
        }
        cell.AddInnerHTMLElement(new HTMLBr());
      }
      catch (Exception e)
      {
        log.Error(e, "SimpleSelectorView.Display error.");
        throw new XPException(m_asOwner.GetString(227, "ptmsgs_portalcommonmsgs"),
         e);
      }
      return result;
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}