using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.search.advanced;
using com.plumtree.portaluiinfrastructure.restconsumerframework.pathways;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.common.search
{
  /// <author>CraigS, based on MikeS code</author>
  public class TypeSelectorModel : EditorHelperModel,ITypeSelectorModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.search.TypeSelectorModel");
    public const String STR_MVC_CLASS_NAME = "TypeSelector";
    private XPArrayList _selectedTypes = null;
    private bool _showingDetailedOptions;
    private bool _showAbstractTypeView;
    protected bool isPathwaysEnabled = false;
    
    /// <returns></returns>
    public virtual bool AreDetailedOptionsShown()
    {
      return _showingDetailedOptions;
    }
    public virtual bool ShowAbstractTypeView()
    {
      return _showAbstractTypeView;
    }
    
    /// <returns></returns>
    public override Object Create()
    {
      return new TypeSelectorModel();
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public virtual IXPCollection GetSelectedTypes()
    {
      return _selectedTypes;
    }
    public virtual void InitializePlugIn(bool showAbstractTypeView, bool noTypesSelected)
    {
      _showAbstractTypeView = showAbstractTypeView;
      _showingDetailedOptions = !_showAbstractTypeView;
      // Preselect the end-user types
      _selectedTypes = new XPArrayList();
      if (noTypesSelected)
      {
        return;
      }
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CLASSID_00));
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CLASSID_01));
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CLASSID_02));
      // community pages
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CLASSID_25));
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CLASSID_03));
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CLASSID_04));
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE));
      _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE));
      if (_showAbstractTypeView)
      {
        _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.DOCUMENT_ABSTRACTTYPE));
        _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.FOLDER_ABSTRACTTYPE));
        _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.OTHER_ABSTRACTTYPE));
        _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.PORTAL_APPLICATION));
        _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.CONTENT_APPLICATION));
        _selectedTypes.Add(XPConvert.ToString(SearchObjectTypes.COLLAB_APPLICATION));
        }
    }
    
    /// <param name="type"></param>
    /// <returns></returns>
    public virtual bool IsTypeSelected(int type)
    {
      return _selectedTypes.Contains(XPConvert.ToString(type));
    }
    
    /// <param name="formData"></param>
    /// <returns></returns>
    public override int SaveSection(XPHashtable formData)
    {
      String[] data = (String[]) formData.GetElement(TypeSelectorView.HTMLHIDDEN_STATUSCLASSIDS);
      if (null != data)
      {
        _showingDetailedOptions = (data[0].Equals("REVEALED"));
      }
      _selectedTypes.Clear();
      data = (String[]) formData.GetElement(TypeSelectorView.HTMLCHECKBOX_CLASSID_BROAD);
      if (null != data)
      {
        for (int j = 0;j < data.Length;j++)
        {
          _selectedTypes.Add(data[j]);
        }
      }
      //this checks for the form data that would exist if the result types filter is enabled
      data = (String[]) formData.GetElement(TypeSelectorView.HTMLCHECKBOX_CLASSID_DETAIL);
      //Checking for Pathways
      IPathwaysRestAPIService pathwaysHelper = PathwaysRestAPIService.GetInstance(m_asOwner);
      bool isPathwaysEnabled = pathwaysHelper.IsPathwaysEnabled();
      bool isAdvancedSearchPage = m_asOwner.GetCurrentPage().GetName().Equals(AdvancedSearchDP.STR_MVC_CLASS_NAME);
      bool isAdaptiveLayout = pathwaysHelper.IsAdaptiveLayoutMode();
      /* bug fix 10242762 - advanced search not returning previously set object type filters when result filters disabled
       * adding code to set default values if the object types filter is not in the layout.
       *
       * There are 3 options to have the result types filter set if Pathways and/or adaptive layout mode is enabled:
       * 1)  it is added to the layout
       * 2)  it is added by the administrator via hidden inputs in the layout that only the administrator can tweak.
       * 3)  both options above are not available and we use banner search preferences instead.
       */
       
      // first we will check if adaptive layout mode is enabled, we're in the advanced search page, and the form data
      // from the result types filter is null, this means the filter is omitted from the advanced search page.
      if (isAdaptiveLayout && isAdvancedSearchPage && (null == data))
      {
        //we are checking for hidden form elements for the result types filter.
        data = (String[]) formData.GetElement(TypeSelectorView.HTMLHIDDEN_ADVSEARCH_CLASSIDS);
        }
      if (null != data)
      {
        for (int j = 0;j < data.Length;j++)
        {
          _selectedTypes.Add(data[j]);
        }
      }
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <summary>
    /// Returns true if admin objects (CLASSID_ENDUSERCOUNT .. DETAILEDCOUNT-1) should be selectable
    /// </summary>
    public virtual bool ShouldDisplayAdminObjects()
    {
      return ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
      }
    public virtual void InitFromFormData(XPHashtable formData)
    {
      if (formData == null)
      {
        return;
      }
      String[] types = (String[]) formData.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S);
      if (null == types)
      {
        types = (String[]) formData.GetElement(SearchResultControl.RECONSTRUCTION_ARGS_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S);
        }
      if ((null != types) && (types.Length > 0))
      {
        _selectedTypes = new XPArrayList();
        for (int i = 0;i < types.Length;i++)
        {
          //log.Error(//"Type was " + types[i]);
          _selectedTypes.Add(types[i]);
        }
      }
    }
    public virtual bool ContentInstalled()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTServerConfigSettings ptSC = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      int setting2 = ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_CONTENT_SERVER_INSTALLED);
      //log.Error("String content val is " + setting2);
      return (setting2 == 1);
    }
    public virtual bool CollabInstalled()
    {
      IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
      IPTServerConfigSettings ptSC = (IPTServerConfigSettings) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      //String setting2 = ptSC.GetSettingAsString(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_COLLAB_SERVER_INSTALLED);
      //log.Error("String collab val is " + setting2);
      int set = ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_COLLAB_SERVER_INSTALLED);
      //log.Error("int collab val is " + set);
      return (set == 1);
    }
    public virtual int[] GetOrderedClassIds()
    {
      return SearchObjectTypes.GetOrderedSearchObjectTypes();
    }
  }
}