using System;
using com.plumtree.uiinfrastructure.activityspace;
using XPHttpUtility=com.plumtree.openfoundation.web.XPHttpUtility;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// The View for the default Footer if none is assigned or found.
  /// </summary>
  /// <author>RobertZ</author>
  /// <author>DavidP</author>
  public class DefaultFooterView : IView
  {
    
    /// <summary>
    /// MVC Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DefaultFooterView";
    private AActivitySpace m_asOwner;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new DefaultFooterView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement result = null;
      try
      {
        HTMLElementCollection resultGroup = new HTMLElementCollection();
        resultGroup.AddInnerHTMLElement(GetTable());
        result = resultGroup;
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating footer: " + e.Message);
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
    }
    
    /// <summary>
    /// Form default Footer HTML
    /// </summary>
    /// <returns>HTMLElement					The HTML for the Footer</returns>
    private HTMLElement GetTable()
    {
      HTMLElement result = null;
      try
      {
        // Create footer table
        HTMLTable footerTable = new HTMLTable();
        footerTable.SetID(PTStyleID.PT_FOOTER);
        footerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        footerTable.SetCellPadding(CommonHTMLStrings.FIVE);
        footerTable.SetBorder(CommonHTMLStrings.ZERO);
        footerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        // Create footer row
        HTMLTableRow onlyRow = (HTMLTableRow) footerTable.InsertInnerHTMLElement(new HTMLTableRow());
        // Set up table cell
        HTMLTableCell onlyCell = (HTMLTableCell) onlyRow.InsertInnerHTMLElement(new HTMLTableCell());
        onlyCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        onlyCell.SetAlign(CommonHTMLStrings.CENTER);
        onlyCell.SetStyleClass(PTStyleClass.FOOT_HEADER_BG + " " + PTStyleClass.FOOT_TEXT);
        // Put subtitle in its own span
        HTMLSpan subtitleSpan = (HTMLSpan) onlyCell.InsertInnerHTMLElement(new HTMLSpan());
        subtitleSpan.SetStyleClass(PTStyleClass.FOOT_SUBTITLE);
        subtitleSpan.AddInnerHTMLString(m_asOwner.GetString(243, "ptmsgs_portalcommonmsgs"));
        // Continue adding content to the table cell
        /* onlyCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
         onlyCell.AddInnerHTMLString(m_asOwner.GetString(244, "ptmsgs_portalcommonmsgs")); */
         
        // Deliver the finished footer table
        result = footerTable;
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating footer table: " + e.Message);
        }
      return result;
    }
  }
}