using System;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// The View for the default Header if none is assigned or found.
  /// </summary>
  /// <author>RobZ</author>
  public class DefaultHeaderView : IView
  {
    
    /// <summary>
    /// MVC Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "DefaultHeaderView";
    private AActivitySpace m_asOwner;
    private NavigationModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new DefaultHeaderView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public virtual HTMLElement Display()
    {
      HTMLElement result = null;
      try
      {
        HTMLElementCollection resultGroup = new HTMLElementCollection();
        resultGroup.AddInnerHTMLElement(GetTable());
        result = resultGroup;
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating banner: " + e.Message);
        }
      return result;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      m_model = (NavigationModel) model;
    }
    
    /// <summary>
    /// Method GetTable.  Form default header banner.
    /// </summary>
    /// <returns>HTMLElement				The HTML for the banner</returns>
    private HTMLElement GetTable()
    {
      HTMLElement result = null;
      try
      {
        /* Build common things we'll need for both standard and 508 display modes */
        // Create outermost table for header
        HTMLTable headerTable = new HTMLTable();
        headerTable.SetID(PTStyleID.PT_HEADER);
        headerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        headerTable.SetCellPadding(CommonHTMLStrings.ZERO);
        headerTable.SetBorder(CommonHTMLStrings.ZERO);
        headerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        // Add only row to table
        HTMLTableRow headerTableRow = (HTMLTableRow) headerTable.InsertInnerHTMLElement(new HTMLTableRow());
        headerTableRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
        headerTableRow.SetVAlign(CommonHTMLStrings.TOP);
        // Add left cell to table row
        HTMLTableCell leftCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
        leftCell.SetID(PTStyleID.PT_HEADER_LEFT);
        // Add right cell to table row
        HTMLTableCell rightCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
        rightCell.SetID(PTStyleID.PT_HEADER_RIGHT);
        rightCell.SetNoWrap(true);
        // Build title H1 and add to right cell
        HTMLH1 titleH1 = new HTMLH1();
        titleH1.AddInnerHTMLEncodedString(m_model.GetTitleForBanner());
        titleH1.SetStyleClass(PTStyleClass.BAN_HEADER);
        rightCell.AddInnerHTMLElement(titleH1);
        // Build subtitle H2 and add to right cell
        HTMLH2 subTitleH2 = new HTMLH2();
        subTitleH2.AddInnerHTMLEncodedString(m_model.GetSubtitleForBanner());
        subTitleH2.SetStyleClass(PTStyleClass.BAN_SUBHEADER);
        rightCell.AddInnerHTMLElement(subTitleH2);
        /* Prepare table cells tailored specifically for either standard or 508 modes */
        if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
        {
          // Configure left cell
          leftCell.SetAlign(CommonHTMLStrings.LEFT);
          // Configure right cell
          rightCell.SetAlign(CommonHTMLStrings.RIGHT);
        } else
        /* 508 mode */
        {
          // Configure left cell
          leftCell.SetAlign(CommonHTMLStrings.LEFT);
          leftCell.SetWidth(CommonHTMLStrings.TWO);
          leftCell.SetHeight("60");
          // Configure right cell
          rightCell.SetAlign(CommonHTMLStrings.LEFT);
          rightCell.SetWidth("200");
        }
        result = headerTable;
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating banner table: " + e.Message);
        }
      return result;
    }
  }
}