using System;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// Navigation model interface for MVC and pluggable navigation.
  /// </summary>
  /// <author>RobZ</author>
  /// <author>DavidP</author>
  public interface INavigationModelRO : IPluggableNavModelRO
  {
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    Object Create();
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetAccessibleCommunityID(int)"></seealso>
    int GetAccessibleCommunityID(int nSubPortalCommID);
    
    /// <summary>
    /// Gets the link to Administration 
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    ICPListEntryIterator GetAdminLink();
    
    /// <summary>
    /// Never check IsCommunityPage before calling this function. Has internal
    /// security check and need to display the edit community membership entry
    /// even when not on community pages.
    /// </summary>
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetMyPortalActions(int,int)"></seealso>
    ICPListEntryIterator GetCommunityActions();
    
    /// <summary>
    /// Gets the Community Pages from the current Community
    /// </summary>
    /// <returns>ICPListEntryIterator containing current Community Pages</returns>
    ICPListEntryIterator GetCurCommPages();
    
    /// <summary>
    /// Gets the ID of the current Community (if in one)
    /// </summary>
    /// <returns>Object ID of the current Community</returns>
    int GetCurCommunityID();
    
    /// <summary>
    /// Gets the name of the current Community (if in one) 
    /// </summary>
    /// <returns>Name of the current Community</returns>
    String GetCurCommunityName();
    
    /// <summary>
    /// Gets the id of the current document directory folder, or 0 if we are
    /// not currently in a single doc directory folder.
    /// </summary>
    /// <returns>Current Document Directory Folder ID, 0 if not in the Document Directory </returns>
    int GetCurDocDirFolderID();
    
    /// <summary>
    /// Get the Mandatory Tabs for the current user
    /// </summary>
    /// <param name="bAddAdminLink">Include Admin link in the list</param>
    /// <returns>ICPListEntryIterator containing Mandatory Community tabs</returns>
    ICPListEntryIterator GetCurMandatoryTabs(bool bAddAdminLink);
    
    /// <summary>
    /// Gets the Mypages for the current user
    /// </summary>
    /// <param name="bShowActions">Include Mypage actions</param>
    /// <returns>ICPListEntryIterator with Mypages</returns>
    ICPListEntryIterator GetCurMyPages(bool bShowActions);
    
    /// <summary>
    /// Gets the current page ID, either Mypage or Community
    /// </summary>
    /// <returns>Current Mypage or Community page ID</returns>
    int GetCurPageID();
    
    /// <summary>
    /// Gets the current page name
    /// </summary>
    /// <returns>Page Name</returns>
    String GetCurPageName();
    
    /// <summary>
    /// Get the related communities of the current community
    /// </summary>
    /// <returns>ICPListEntryIterator </returns>
    ICPListEntryIterator GetCurRelCommunities();
    
    /// <summary>
    /// Gets the subcommunities of the current community
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    ICPListEntryIterator GetCurSubCommunities();
    //
    // Subportal functions END
    //
    //
    // Misc functions
    //
    
    /// <summary>
    /// Gets the default community ID of the current user
    /// </summary>
    /// <returns></returns>
    int GetDefaultCommunity();
    
    /// <summary>
    /// Gets the URL to the default subportal of the current user
    /// </summary>
    /// <returns></returns>
    ASURL GetDefaultSubportalURL();
    
    /// <summary>
    /// Get the directory links 
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    ICPListEntryIterator GetDirectoryLinks();
    
    /// <summary>
    /// Get footer element
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    HTMLElementCollection GetFooterElement();
    
    /// <summary>
    /// Checks if a footer has been set for the current page
    /// </summary>
    /// <returns>True if a footer has been set</returns>
    bool GetFooterHasBeenSet();
    
    /// <summary>
    /// Checks if a header has been set for the current page
    /// </summary>
    /// <returns>True if a header has been set</returns>
    bool GetHeaderHasBeenSet();
    
    /// <summary>
    /// Get header element
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    HTMLElementCollection GetHeaderElement();
    
    /// <summary>
    /// Gets the greeting for the current user
    /// </summary>
    /// <returns>					String greeting</returns>
    String GetGreeting();
    
    /// <summary>
    /// Gets the mandatory links for the current user
    /// </summary>
    /// <returns>					Mandatory links ICPListEntryIterator</returns>
    ICPListEntryIterator GetMandatoryLinks();
    //
    // Subportal functions BEGIN
    //
    
    /// <summary>
    /// Gets the name for the mandatory links folder for the current user
    /// </summary>
    /// <returns>					Mandatory folder String name</returns>
    String GetMandatoryLinksFolderName();
    
    /// <summary>
    /// Helper function, returns the join community link, community actions if on
    /// a community page and the list of communities.
    /// </summary>
    /// <param name="bListActions">True to return the community actions in the list, false otherwise</param>
    /// <returns> 				Communities the current user is a member of in a ICPListEntryIterator</returns>
    ICPListEntryIterator GetMyCommunities(bool bListActions);
    
    /// <summary>
    /// Get the mypage actions for the current page and user
    /// </summary>
    /// <returns>An XPArrayList with ASURLContainer objects.</returns>
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetMyPagesActions()"></seealso>
    ICPListEntryIterator GetMyPageActions();
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModelRO#GetName()"></seealso>
    String GetName();
    
    /// <summary>
    /// Gets the parent community for the current community. The list
    /// will only contain one item.
    /// </summary>
    /// <returns>					Parent community </returns>
    ICPListEntryIterator GetParentComm();
    
    /// <summary>
    /// Gets the link to the user's My Account page (user portal preferences)
    /// </summary>
    /// <returns>					Personal preference link in an ICPListEntryIterator</returns>
    ICPListEntryIterator GetPortalSettings();
    
    /// <summary>
    /// Gets the current visibility status of the specified section. Use constants
    /// defined in com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility.
    /// </summary>
    /// <param name="nSectionIDConst">Navigation section ID (defined in NavVisibility</param>
    /// <returns>boolean			Section visible or not</returns>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility"></seealso>
    bool GetSectionVisibility(int nSectionIDConst);
    
    /// <summary>
    /// Checks if the specified feature is enabled for current user's subportal 
    /// </summary>
    /// <param name="nType">Feature type defined in PT_SUBPORTAL_ACCESS_TYPES</param>
    /// <returns>					Feature enabled or not</returns>
    bool GetSubPortalEnabled(int nType);
    
    /// <summary>
    /// Gets the page type of the current user's default my home page-type.
    /// </summary>
    /// <returns>	int				Page type, -1 one if none can be found.			</returns>
    int GetSubPortalFirstPageType();
    
    /// <summary>
    /// Gets the navigation scheme set for the current user 
    /// </summary>
    /// <returns>					Navigation scheme ID</returns>
    int GetSubPortalNavScheme();
    
    /// <summary>
    /// Gets the Page ID of the first page a user should see after logging in.
    /// Set on a user's Subportal
    /// </summary>
    /// <returns>					Page ID of the first page a user is redirected to after logging in </returns>
    int GetSubPortalPageID();
    
    /// <summary>
    /// Gets the Banner set in the subportal
    /// </summary>
    /// <returns>					Banner HTMLElement</returns>
    HTMLElement GetSubportalBanner();
    
    /// <summary>
    /// Gets the footer set in the subportal
    /// </summary>
    /// <returns>					Footer HTMLElement</returns>
    HTMLElement GetSubportalFooter();
    
    /// <summary>
    /// Gets the subtitle of the current page
    /// </summary>
    /// <returns>					Page Subtitle String</returns>
    String GetSubtitleForBanner();
    
    /// <summary>
    /// Gets the title of the current page
    /// </summary>
    /// <returns>					Page title String</returns>
    String GetTitleForBanner();
    
    /// <summary>
    /// Checks if the current user has Administrator access
    /// </summary>
    /// <returns>					boolean			</returns>
    bool HasAdministratorAccess();
    
    /// <summary>
    /// Checks if the current user has select access to the current community
    /// </summary>
    /// <returns>					boolean</returns>
    bool HasSelectAccess();
    
    /// <summary>
    /// Checks if the current page is a Community Page
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsCommunityPage();
    
    /// <summary>
    /// Checks if the current user is the owner of the current Community
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsCurCommOwner();
    
    /// <summary>
    /// Checks if the current page is a directory page
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsDirPage();
    
    /// <summary>
    /// Checks if the current user is the Guest user
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsGuestSession();
    
    /// <summary>
    /// Checks if the current user is a member of the current Community 
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsMemberInCurCommunity();
    
    /// <summary>
    /// Checks if the current page is the login page
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsLoginPage();
    
    /// <summary>
    /// Checks if the current page is a mypage
    /// </summary>
    /// <returns>					boolean</returns>
    bool IsMyPage();
    
    /// <summary>
    /// Sets a new footer element
    /// </summary>
    /// <param name="bClearPrevContent">True to clear any previously set footer</param>
    /// <param name="element">The new footer element</param>
    void SetFooterElement(bool bClearPrevContent, HTMLElement element);
    
    /// <summary>
    /// Sets a new header element.
    /// </summary>
    /// <param name="bClearPrevContent">True to clear any previously set header</param>
    /// <param name="element">The new header element</param>
    /// <throws>HTMLException</throws>
    void SetHeaderElement(bool bClearPrevContent, HTMLElement element);
    
    /// <summary>
    /// Set the visibility of the specified Navigation section.
    /// </summary>
    /// <param name="nSectionIDConst">Section ID defined in NavVisibility</param>
    /// <param name="bShow">true if the section is displayed, false otherwise</param>
    void SetSectionVisibility(int nSectionIDConst, bool bShow);
    
    /// <summary>
    /// This function checks the MyPortalModel
    /// to see if the current page is a community preview page
    /// (certain actions are disabled in this case).
    /// </summary>
    /// <returns>							boolean</returns>
    bool IsPreviewPage();
    
    /// <summary>
    /// Used by pluggable navigation to access the MyPages model
    /// </summary>
    /// <returns>							The MyPortal IModel interface</returns>
    IModel GetMyPortalModel();
    
    /// <summary>
    /// Returns true if this page should show the "Inside this Community" header and
    /// sub- and related communitites.
    /// </summary>
    /// <returns>							true if the page should show community nav links</returns>
    bool ShowCommunityNavigation();
    
    /// <summary>
    /// Checks if the current user can join the current Community
    /// </summary>
    /// <returns>					boolean</returns>
    bool CanJoinCurCommunity();
    
    /// <summary>
    /// Sets the currently registered view nav scheme to be newNavScheme
    /// </summary>
    /// <returns>Currently registered Navigation Scheme.</returns>
    int GetRegisteredViewNavScheme();
    
    /// <summary>
    /// Sets the currently registered view nav scheme to be newNavScheme
    /// </summary>
    /// <param name="the">new registered view's Nav Scheme</param>
    void SetRegisteredViewNavScheme(int newNavScheme);
  }
}