using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.friendlyurl;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// Common static navigation helper functions.
  /// </summary>
  /// <author>robertz</author>
  public class NavigationCommonHelpers
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.uiparts.NavigationCommonHelpers");
    
    /// <summary>
    /// Default truncation width *
    /// </summary>
    public const int DEFAULT_MENU_TEXT_MAX_LENGTH = 29;
    
    /// <summary>
    /// Url template redirect function. Make the name as short as possible to 
    /// send down less data
    /// </summary>
    public const String URLTEMPLATE_REDIRECT_JSFUNCNAME = "templateURLRedirect";
    
    /// <summary>
    /// Javascript variable name constant 
    /// </summary>
    public const String JSCRIPT_VAR_MANDTAB_ARRAY = "mandTabsArray";
    
    /// <summary>
    /// Javascript variable name constant 
    /// </summary>
    public const String JSCRIPT_VAR_DDTABS_ARRAY = "ddTabsArray";
    
    /// <summary>
    /// Javascript function name constant 
    /// </summary>
    public const String JSCRIPT_FUNC_BUILD_URL_FROM_TEMPL = "buildURLFromTemplate";
    
    /// <summary>
    /// Helper function for getting values of settings in NavigationSettings.xml as integers. 
    /// </summary>
    /// <param name="strKey">Name of the navigation setting.</param>
    /// <param name="owner">Current Activityspace</param>
    /// <returns>int		The requested Navigation setting value as integer. -1 if the key doesn't exist or not an integer. </returns>
    public static int GetNavSettingsValueAsInt(String strKey, AActivitySpace owner)
    {
      try
      {
        String strValue = (String) owner.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(strKey);
        if (null == strValue)
        {
          // Since these settings are usually not present in the config file,
          // check for this and return a default value.
          return -1;
        }
        return XPConvert.ToInteger(strValue);
      }
      catch (Exception e)
      {
      }
      //log.Error(e, "Unable to return int.");
      return -1;
    }
    
    /// <summary>
    /// Helper function for getting values of settings in NavigationSettings.xml as Strings. 
    /// </summary>
    /// <param name="strKey">Name of the navigation setting</param>
    /// <param name="owner">Current Activityspace</param>
    /// <returns>String	The requested Navigation setting value as a String. null if the value doesn't exist. </returns>
    public static String GetNavSettingsValueAsString(String strKey, AActivitySpace owner)
    {
      return (String) owner.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(strKey);
      }
    
    /// <summary>
    /// Adds the end of banner markers for ISC dropdown menus. Should be added to below banner view
    /// when using ISC menus in the above banner view.  
    /// </summary>
    /// <returns>HTMLElementCollection		HTMLElementCollection to add the dropdown markers to</returns>
    public static HTMLElementCollection CreateDropDownEndMarkers()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      HTMLSpan span = new HTMLSpan();
      span.SetID("bannerend");
      HTMLGenericElement layer = new HTMLGenericElement("<layer id=\"nsbannerend\"></layer>");
      //result.AddInnerHTMLElement(new HTMLBr());
      result.AddInnerHTMLElement(span);
      result.AddInnerHTMLElement(layer);
      return result;
    }
    
    /// <summary>
    /// Adds a spacer cell with a cell width of 4to the specified HTMLTableRow
    /// </summary>
    /// <param name="myTableRow">HTMLTableRow to add the spacer cell to</param>
    public static void CreateHorizontalSpacerCell(HTMLTableRow myTableRow)
    {
      HTMLTableCell myCell = new HTMLTableCell();
      myTableRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.NAV_MIDTABSPACER_BG);
      HTMLImg spacer = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();
      spacer.SetWidth("4");
      spacer.SetHeight("1");
      spacer.SetBorder("0");
      spacer.SetAlt("");
      //spacer.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(false));
      myCell.AddInnerHTMLElement(spacer);
    }
    
    /// <summary>
    /// Creates a HTMLScript block with an array of the mandatory tabs to display
    /// The javascript array is a two dimensional array - 
    /// element[i][0]: Name of the mandatory community
    /// element[i][1]: Original name of the mandatory community (before truncation), use for tooltip
    /// element[i][2]: URL to the mandatory community
    /// </summary>
    /// <param name="cpList">List of mandatory tabs</param>
    /// <param name="parent">Current activityspace</param>
    /// <returns>HTMLScript					The HTMLScript with the javascript variable</returns>
    public static HTMLScript CreateMandatoryTabsArray(ICPListEntryIterator cpList,
     AActivitySpace parent)
    {
      // Get the maximum length of mandatory tabs names
      String strMaxLength = (String) parent.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_TRUNCATION_WIDTH);
      // Create an url template mediator for the mandatory tabs links
      CListURLTemplateMediator mediator = new CListURLTemplateMediator(parent,
       cpList);
      mediator.SetLabelMaxLength(XPConvert.ToInteger(strMaxLength));
      // - Generate the 2d array in javascript
      // Roughly estimate the size of the buffer we need
      XPStringBuilder buf = new XPStringBuilder((cpList.GetTotalCount() * 50) + 20);
      buf.Append("[\n");
      for (int i = 0;mediator.Next();i++)
      {
        String[] labelAndURL = (String[]) mediator.GetEntry();
        if (i != 0)
        {
          buf.Append(",");
        }
        // Create the array that stores name, tooltip and url
        // Element 0: Name, Element 1: Tooltip, Element 2: URL
        buf.Append("[\"" + JSHelper.JSEncodeString(labelAndURL[CListURLTemplateMediator.TEMPLATEARR_INDEX_LABEL]) + "\",\"" + 
        // DCA - do not encode since accented chars does not display properly 
        JSHelper.JSEncodeString(mediator.GetNonEncodedEntryOrigLabel()) + "\",\"" + labelAndURL[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL] + "\"]\n");
        }
      // Close the outer array
      buf.Append("\t\t" + "]\n");
      return JSHelper.AddSafeJSVariable(JSCRIPT_VAR_MANDTAB_ARRAY, buf.ToString());
      }
    
    /// <summary>
    /// Creates writeStartTable, writeEndOfTable, writeSpacerTable and writeSpacerCell,
    /// dynamic HTML generating Javascript helper functions used in .js files to to position 
    /// dropdown menu tabs and mandatory communities tabs.
    /// </summary>
    /// <param name="parent">Current Activityspace</param>
    /// <returns>HTMLScript			HTMLScript block with the javascript helper functions</returns>
    public static HTMLScript GenerateJSHTMLHelperFunctions(AActivitySpace parent)
    {
      HTMLScript script = new HTMLScript("text/javascript");
      String strPathToImageServer = ConfigHelper.GetImageServerBaseURL(parent);
      XPStringBuilder buf = new XPStringBuilder(300);
      /*
       function writeStartTable()
       {
       document.write('<table cellpadding="0" cellspacing="0" width="100%" border="0"><tr class="navMidtabBg">\n');
       }*/
       
      buf.Append("\t" + "function writeStartTable() { document.write(\'<table cellpadding=\"0\" cellspacing=\"0\" width=\"100%\" border=\"0\"><tr class=\"navMidtabBg\">" + "\'); }\n");
      /*
       function writeEndofTable()
       {
       document.write('<td width="100%" class="banHeaderBg">&nbsp;</td></tr></table>\n');
       }*/
       
      buf.Append("\t" + "function writeEndOfTable() { document.write(\'" + "<td width=\"100%\" class=\"banHeaderBg\">&nbsp;</td></tr></table>" + "\'); }\n");
      HTMLTable spacerTable = new HTMLTable();
      spacerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      spacerTable.SetBorder(CommonHTMLStrings.ZERO);
      spacerTable.SetCellPadding(CommonHTMLStrings.ZERO);
      spacerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      HTMLTableRow row = new HTMLTableRow();
      row.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
      spacerTable.AddInnerHTMLElement(row);
      CreateVerticalSpacerCell(row);
      spacerTable.SetImgBaseUrl(strPathToImageServer);
      //	this turns off line breaks for this subtree of htmlelements.
      spacerTable.SetForceLineBreaksAfterSafeElements(false);
      buf.Append("\t" + "function writeSpacerTable() { document.write(\'" + spacerTable.GetDisplayString() + "\'); }\n");
      buf.Append("\t" + "function writeSpacerCell() { document.write(\'" + "<td colspan=\"1\" class=\"navMidtabSpacerBg\"><img src=\"" + strPathToImageServer + "portal/public/img/sp.gif\" alt=\"\" border=\"0\" height=\"1\" width=\"4\"/></td>" + "\'); }\n");
      script.AddInnerHTMLString(buf.ToString());
      return script;
    }
    
    /// <summary>
    /// Adds a spacer cell to the specified HTMLTableRow 
    /// </summary>
    /// <param name="myTableRow">The HTMLTableRow to add the spacer cell to</param>
    public static void CreateVerticalSpacerCell(HTMLTableRow myTableRow)
    {
      HTMLTableCell myCell = new HTMLTableCell();
      myTableRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.NAV_MIDTABSPACER_BG);
      HTMLImg spacer = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();
      spacer.SetWidth("1");
      spacer.SetHeight("4");
      spacer.SetBorder("0");
      spacer.SetAlt("");
      myCell.AddInnerHTMLElement(spacer);
    }
    
    /// <summary>
    /// Prepares a string for use in Javascript code, escapes single quotes (').
    /// </summary>
    /// <param name="strIn">The stirng to escape</param>
    /// <returns>								String with escaped single quotes </returns>
    public static String EscapeSingleQuotes(String strIn)
    {
      return GeneralHelpers.Replace(strIn, "\'", "\\\'");
    }
    
    /// <summary>
    /// Helper function that creates a spacer Image with specified width and height
    /// </summary>
    /// <param name="sWidth">Spacer image width</param>
    /// <param name="sHeight">Spacer image height</param>
    /// <returns>HTMLImg		HTMLImg construct</returns>
    public static HTMLImg GetSpacerImage(String sWidth, String sHeight)
    {
      HTMLImg image = null;
      image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();
      image.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(true));
      image.SetWidth(sWidth);
      image.SetHeight(sHeight);
      image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      image.SetBorder(CommonHTMLStrings.ZERO);
      image.SetAlt("");
      return image;
    }
    
    /// <summary>
    /// Helper function that returns a string with the HTML of the formatted image for Communities
    /// </summary>
    /// <param name="aspace">Current Activityspace</param>
    /// <param name="mpName">Alt text for the image</param>
    /// <returns>String					The image as an HTML String</returns>
    public static String GetCommunityImageURLString(AActivitySpace aspace,
     String commName)
    {
      String imageString = "";
      try
      {
        HTMLImg htmlImg = null;
        htmlImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
         true, aspace).GetHTMLElement();
        htmlImg.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(aspace));
        htmlImg.SetAlt(commName);
        htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        htmlImg.SetBorder(CommonHTMLStrings.ZERO);
        // HTMLEncode the string, might contain "s
        //imageString = XPHttpUtility.HtmlEncode( htmlImg.GetDisplayString() );
        imageString = htmlImg.GetDisplayString();
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get CommunityImageURLString.");
      }
      return imageString;
    }
    
    /// <summary>
    /// Helper function that returns a string with the image source of the formatted image for Communities
    /// </summary>
    /// <param name="aspace">Current Activityspace</param>
    /// <returns>String					The image as an image source String</returns>
    public static String GetCommunityImageSource(AActivitySpace aspace)
    {
      String imageString = "";
      try
      {
        imageString = ConfigHelper.GetImageServerBaseURL(aspace) + PTImageType.ICON_COMMUNITIES_MENU.GetFileName() + "\', \'" + PTImageType.ICON_COMMUNITIES_MENU.GetWidth();
        }
      catch (Exception e)
      {
      }
      return imageString;
    }
    
    /// <summary>
    /// Helper function that returns a string with the HTML of the formatted image for Mypages
    /// </summary>
    /// <param name="aspace">Current Activityspace</param>
    /// <param name="mpName">Alt text for the image</param>
    /// <returns>String					The image as an HTML String</returns>
    public static String GetMyPageImageURLString(AActivitySpace aspace, String mpName)
    {
      String imageString = "";
      try
      {
        HTMLImg htmlImg = null;
        htmlImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_MYPAGE,
         true, aspace).GetHTMLElement();
        htmlImg.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(aspace));
        htmlImg.SetAlt(mpName);
        htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        htmlImg.SetBorder(CommonHTMLStrings.ZERO);
        // HTMLEncode the string, might contain "s
        //imageString = XPHttpUtility.HtmlEncode( htmlImg.GetDisplayString() );
        imageString = htmlImg.GetDisplayString();
      }
      catch (Exception e)
      {
      }
      //log.Error(e, "Unable to get MyPageImageURLString.");
      return imageString;
    }
    
    /// <summary>
    /// Helper function that returns a string with the HTML of the formatted image for Mypages
    /// </summary>
    /// <param name="aspace">Current Activityspace</param>
    /// <param name="mpName">Alt text for the image</param>
    /// <returns>String					The image as an HTML String</returns>
    public static String GetMyPageImageSource(AActivitySpace aspace)
    {
      String imageString = "";
      try
      {
        imageString = ConfigHelper.GetImageServerBaseURL(aspace) + PTImageType.ICON_MYPAGE_MENU.GetFileName() + "\', \'" + PTImageType.ICON_MYPAGE_MENU.GetWidth();
        }
      catch (Exception e)
      {
      }
      //log.Error(e, "Unable to get MyPageImageSource");
      return imageString;
    }
    
    /// <summary>
    /// Parses the ID or IDs needed to create the URL for mypages or community pages (or other types)
    /// Needs to be in sync with the IDs put used as data value for each cell. 
    /// M = MyPages C = Communities , E = Editor, F = Freeform URL (no template) etc
    /// </summary>
    /// <returns>	String with the javascript functions</returns>
    public static String writeURLTemplateParseFunction(AActivitySpace space)
    {
      // DCA - figure out if user wants links to open in a new window or in the main window
      String strOpenDocInNewWindow = "0";
      try
      {
        strOpenDocInNewWindow = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.OPEN_DOC_NEW_WINDOW,
         space);
      }
      catch (Exception e)
      {
        // Setting has not been set, log as warning.
        log.Warn(e, "Document preference has not been set for this user, documents will be opened on the main window.");
        }
      int nUserID = ((IPTSession) space.GetUserSession()).GetSessionInfo().GetCurrentUserID();
      // site map root urls
      ASURL siteMapRootURL = new ASURL(space);
      siteMapRootURL.SetLinkCreateNewSpace(SiteMapAS.STR_MVC_CLASS_NAME, space);
      siteMapRootURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
      // editor urls
      // Don't know the space name until it's called
      ASURL editorURL = new ASURL(space);
      editorURL.SetLinkCreateNewSpace("\'+arArgs[1]+\'", space);
      // Generic url, create space
      ASURL genericURL = new ASURL(space);
      genericURL.SetLinkCreateNewSpace("\'+arArgs[1]+\'", space);
      XPStringBuilder sb = new XPStringBuilder();
      sb.Append("\tfunction ").Append(JSCRIPT_FUNC_BUILD_URL_FROM_TEMPL).Append("(strID)\n\t{\n").Append("\t\tvar arArgs = strID.split(\',\');\n\tif(!arArgs){\n").Append("\t  alert(\'Invalid menu ID\');\n\t  return null; }\n");
      // community page
      sb.Append("\tif(arArgs[0] == \'C\'){\n\t var strCommURL = ").Append(
      // expected array: 'C', communityid, pageid, profileid
      PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID),
       "arArgs[1]", "&" + PTCommunities.STR_QS_PAGEID + "=\'+arArgs[2]+\'",
       XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW))).Append("\n\t if ( arArgs.length > 3) { strCommURL += \'&" + SetCommunityControl.PROFILEID + "=\'+arArgs[3]; }\n\t" + "  return strCommURL;\n");
      //		/** Friendly URL Community page 
      //		 * expected array: 'FC', communityid, pageid, communityname, pagename
      //		 ***/
      //		// put in placeholders since friendlyurl will change the object names
      //		try {
      //			// CR: DCA - how are we handling ambiguities when the user clicks on a link after the javascripts have been rendered?
      //			// Maybe we should just treat Firendly URLs as Internal Full URLs (look below)?
      //			FriendlyURL friendly = new FriendlyURL(PT_CLASSIDS.PT_COMMUNITY_ID, "$$objname$$");
      //			// This is to prevent the creation to lookup entries from number of page names, 
      //			// which will fail since we are using a dummy value
      //			friendly.SetUseIdIfAvailable(true);
      //			friendly.SetChildName("$$childname$$");
      //			String massagedURL = friendly.GetFriendlyURL(space);
      //			massagedURL = GeneralHelpers.Replace(massagedURL, "$$objname$$", "'+arArgs[3]+'");
      //			massagedURL = GeneralHelpers.Replace(massagedURL, "$$childname$$", "'+arArgs[4]+'");
      //			String baseURL = PTConfigHelper.GetApplicationBaseURL(space);
      //			sb.Append("\t} else if(arArgs[0] == 'FC'){\n\t var strCommURL = '").Append(baseURL).Append(massagedURL).Append("'\n");
      //			sb.Append("\t\treturn strCommURL;\n");
      //		} catch (Throwable e) {
      //			log.Error(e, "There was an error creating mapping function for friendly URL, skipping.");
      //		}
      // mypage page
      sb.Append("\t} else if (arArgs[0] == \'M\') {\n\t return ").Append(PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID),
       XPConvert.ToString(nUserID), "&" + PTMyPages.STR_PAGE_ID + "=\'+arArgs[1]+\'",
       XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW))).Append("\n");
      // site map root
      sb.Append("\t} else if (arArgs[0] == \'SM\') {\n\t  return \'").Append(siteMapRootURL.GetURLAsString()).Append("&").Append(SetCommunityControl.STR_COMMUNITY_ID).Append("=\'+arArgs[1]+\'&Mode=\'+arArgs[2]+(eval(arArgs[3]) ? \'&Preview=\' : \'\');\n");
      // string label
      sb.Append("\t} else if (arArgs[0] == \'S\') {\n\t  return null;\n");
      // editor url
      sb.Append("\t} else if (arArgs[0] == \'E\') {\n\t    var params = \'\';").Append("\n\t    if ( arArgs.length > 1 ) {\n").Append("\t      for ( var i = 2; i < arArgs.length; i++ ) {\n").Append("\t        params += \'&\' + arArgs[i];" + "\n\t      } }").Append("\n\t  return \'").Append(editorURL.GetURLAsString()).Append("\' + params;").Append("\n");
      // dir page
      sb.Append("\t} else if (arArgs[0] == \'D\') {\n\t return ").Append(PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID),
       "arArgs[2]", "&" + DirConstants.QS_DIRECTORY_MODE + "=\'+arArgs[1]+\'",
       XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW))).Append("\n");
      // Generic with create new space
      sb.Append("\t} else if (arArgs[0] == \'G1\') {\n\t    var params = \'\';").Append("\n\t    if ( arArgs.length > 1 ) {\n").Append("\t      for ( var i = 2; i < arArgs.length; i++ ) {\n").Append("\t        params += \'&\' + arArgs[i];\n\t      } }").Append("\n\t  return \'").Append(genericURL.GetURLAsString()).Append("\' + params;\n");
      // Internal full URL
      sb.Append("\t} else if (arArgs[0] == \'IF\') {\n\t  return arArgs[1];\n");
      // error 
      sb.Append("\t} else {\n\t    alert(\'URL Type is not defined\');\n").Append("\t    return null; }\n\t}\n");
      //int nUserID  = ((IPTSession) space.GetUserSession()).GetSessionInfo().GetCurrentUserID();
      sb.Append("\tfunction ").Append(URLTEMPLATE_REDIRECT_JSFUNCNAME).Append("(templateURL) {\n").Append("\t  if (templateURL == null) { return null; }\n").Append("\t  var arArgs = templateURL.split(\',\');\n");
      // DCA - User Profile URL is different - JO
      sb.Append("\t if (arArgs[0] == \'UP\') {\n\t").Append(PTOpenerLinks.GetJSOpenInSameWindow(PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_USER_ID),
       "arArgs[1]", null, XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)))).Append(";\n");
      // DCA - Doc Open URL is also different
      if (null != strOpenDocInNewWindow && strOpenDocInNewWindow.Equals("1"))
      {
        // DCA - Open in a new window
        sb.Append("\t} else if (arArgs[0] == \'DO\') {\n\t").Append(PTOpenerLinks.GetJSOpenInNewWindow(PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID),
         "arArgs[1]", null, XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)),
         "docLink", "600", "800", true)).Append(";\n");
        // DCA - full url in a new window	
        sb.Append("\t} else if (arArgs[0] == \'F\') {\n\t").Append(PTOpenerLinks.GetJSOpenInNewWindow("arArgs[1]",
         "extLink", "600", "800", true)).Append(";\n");
      } else
      {
        // DCA - Open in the main window
        sb.Append("\t} else if (arArgs[0] == \'DO\') {\n\t").Append(PTOpenerLinks.GetJSOpenInSameWindow(PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID),
         "arArgs[1]", null, XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)))).Append(";\n");
        // DCA - full url in a new window
        sb.Append("\t} else if (arArgs[0] == \'F\') {\n\t  window.location = arArgs[1];\n");
        }
      sb.Append("\t } else {\n").Append("\t   window.location = ").Append(JSCRIPT_FUNC_BUILD_URL_FROM_TEMPL).Append("(templateURL);\n").Append("\t }\n\t \n\t}\n");
      return sb.ToString();
    }
  }
}