using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// Control for collapsing and expanding Navigation sections in left vertical views.
  /// </summary>
  /// <author>robertz</author>
  public class NavigationControl : IControl
  {
    
    /// <summary>
    /// MVC Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "Navigation";
    
    /// <summary>
    /// Parameter name for the Collapse action 
    /// </summary>
    public const String ACTION_COLLAPSE = "NavCol";
    
    /// <summary>
    /// Parameter name for the Expand action 
    /// </summary>
    public const String ACTION_EXPAND = "NavExp";
    
    /// <summary>
    /// Parameter name for the previous page URL 
    /// </summary>
    public const String PREV_PAGE_QSPARAM = "RedirectControl";
    protected AActivitySpace m_asOwner;
    protected NavigationModel m_model;
    
    /// <summary>
    /// Constructor for NavigationControl.
    /// </summary>
    public NavigationControl() : base()
    {
    }
    
    /// <summary>
    /// Updates the vertical navigation section visibility array and then redirects to the 
    /// referring page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Execute(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      if (arguments.ContainsKey(ACTION_COLLAPSE))
      {
        String strSectionID = ((String[]) arguments.GetElement(ACTION_COLLAPSE))[0];
        int nSectionID = XPConvert.ToInteger(strSectionID);
        m_model.SetSectionVisibility(nSectionID, false);
      } else
      if (arguments.ContainsKey(ACTION_EXPAND))
      {
        String strSectionID = ((String[]) arguments.GetElement(ACTION_EXPAND))[0];
        int nSectionID = XPConvert.ToInteger(strSectionID);
        m_model.SetSectionVisibility(nSectionID, true);
      }
      Redirect redirect = new Redirect();
      // Get the argument for the previous url. 
      String prevURL = ((String[]) arguments.GetElement(PREV_PAGE_QSPARAM))[0];
      redirect.SetLinkToExternalURL(prevURL);
      redirect.SetIsHTTPRedirect(true);
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new NavigationControl();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_model = (NavigationModel) model;
      m_asOwner = space;
    }
  }
}