using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portalpages.browsing.objectselection.communities;
using com.plumtree.portalpages.browsing.portalsettings;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portalpages.common.folder;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts.navpagetype;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.web;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// Core model for all navigation. All public function calling into Server API should internally catch all
  /// exceptions.
  /// </summary>
  /// <author>RobZ</author>
  /// <author>DavidP</author>
  public class NavigationModel : AClearModel,INavigationModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.uiparts.NavigationModel");
    
    /// <summary>
    /// Navigation model class identifier for activty space registration 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "NavigationModel";
    
    /// <summary>
    /// Directory constants 
    /// </summary>
    public const int FOLDERID_UNCHANGED = -1;
    
    /// <summary>
    /// How long the login token passed with the admin link should be valid for,
    /// don't want too long since it compromises security but too short could invalidate
    /// it before the user clicks on the link, measured in minutes.
    /// Maybe worth to put as a setting in config.xml?
    /// </summary>
    public const int LOGIN_TOKEN_LIFE_SPAN = 1;
    
    /// <summary>
    /// Uninitialized Mypage ID value. 
    /// Not -1 since that is the home page for administrator
    /// Set to 0 since it is passed and used to open the myportalobject 
    /// in the appdataobject and 0 represents the user's default homepage.
    /// </summary>
    public const int NO_CURRENT_PAGEID = 0;
    
    /// <summary>
    /// Uninitialized Community ID value 
    /// </summary>
    public const int NO_CURRENT_COMMID = 0;
    
    /// <summary>
    /// Session attribute name of the array holding section visibility flag 
    /// </summary>
    protected const String SECTION_VISIBILITY_SESSION_ATTRIBUTE = "SEC_VIC_BOOL_ARRAY";
    
    /// <summary>
    /// Personal preference name of the vertical navigation section visibility setting 
    /// </summary>
    protected const String NAV_SECTIONVISARRAY_PREFSNAME = "VerticalNavVisArray";
    
    /// <summary>
    /// Current Activity space 
    /// </summary>
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// Plumtree user session 
    /// </summary>
    private IPTSession m_ptSession = null;
    
    /// <summary>
    /// View of the NavScheme currently registered; First assumed to be Horizontal Drop Down 
    /// </summary>
    private int m_nRegisteredViewNavScheme;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init()"></seealso>
    public override void Init(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      // Initialize the visbile section array
      if (IsGuestSession())
      {
        return;
      }
      bool[] bCollapsedSections = null;
      //ISessionManager settings = (ISessionManager)m_asOwner.GetSubSession().GetSubSession(PersonalSettingsHelper.PREFS_SUBSESSION_NAME);
      ISessionManager settings = (ISessionManager) m_asOwner.GetSubSession();
      if (null == settings.GetAttribute(SECTION_VISIBILITY_SESSION_ATTRIBUTE))
      //if ( null == PTPersonalSettingsHelper.GetPersonalSettingValue(NAV_SECTIONVISARRAY_PREFSNAME, m_asOwner) )
      {
        String commaDelimitedBitArray = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(NAV_SECTIONVISARRAY_PREFSNAME,
         m_asOwner);
        if (null == commaDelimitedBitArray)
        {
          bCollapsedSections = new bool[NavVisibility.VISIBILITY_SECTION_COUNT];
          for (int i = 0;i < NavVisibility.VISIBILITY_SECTION_COUNT;i++)
          {
            bCollapsedSections[i] = true;
          }
        } else
        {
          XPStringTokenizer items = new XPStringTokenizer(commaDelimitedBitArray,
           ",");
          bCollapsedSections = new bool[NavVisibility.VISIBILITY_SECTION_COUNT];
          int i = 0;
          for (i = 0;items.HasMoreTokens();i++)
          {
            bCollapsedSections[i] = XPConvert.ToBoolean(XPConvert.ToInteger(items.GetNextToken()));
            }
          // In case any new sections were added
          while (i < NavVisibility.VISIBILITY_SECTION_COUNT)
          {
            bCollapsedSections[i++] = true;
          }
        }
        settings.SetAttribute(SECTION_VISIBILITY_SESSION_ATTRIBUTE, bCollapsedSections);
        }
    }
    
    /// <summary>
    /// To be called by AActivitySpace ReInit()
    /// </summary>
    public virtual void ReInit(AActivitySpace parent)
    {
      m_asOwner = parent;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new NavigationModel();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IModelRO#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetAccessibleCommunityID(int)"></seealso>
    public virtual int GetAccessibleCommunityID(int nSubPortalCommID)
    {
      // 1. Go to comm page
      // 2. If no access to comm page -> Go to default comm
      IPTObjectManager objOMCommunites = m_ptSession.GetCommunities();
      if (objOMCommunites.IsObjectAccessible(nSubPortalCommID, m_ptSession.GetSessionInfo().GetCurrentUserID(),
       PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
      {
        return nSubPortalCommID;
      } else
      {
        IPTQueryResult ptCommunityMembership = m_ptSession.GetSessionInfo().GetCurrentCommunityMembership();
        if (ptCommunityMembership.RowCount() != 0)
        {
          int intFirstCommunityID = ptCommunityMembership.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
          return intFirstCommunityID;
        } else
        {
          return -1;
        }
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetCurCommunityID()"></seealso>
    public virtual int GetCurCommunityID()
    {
      NavigationModelTempData tempData = (NavigationModelTempData) GetTempData();
      return tempData.lCurrentCommunityID;
    }
    
    /// <summary>
    /// Find the current Community ID
    /// </summary>
    /// <returns>int						Calculated Community ID</returns>
    public virtual int CalculateCurCommunityID()
    {
      return TaskAPIUICommunity.GetCurrentCommunityID(m_asOwner);
    }
    
    /// <summary>
    /// Gets the name of the current Community (if in one) from the MyPortalModel. 
    /// NOTE: Returned string not HTMLEncoded
    /// </summary>
    /// <returns>Not HTMLEncoded/URLEncoded name of the community</returns>
    /// <throws>XPIllegalStateException If not in a Community or called if NavigationModel hasn't been properly initialized</throws>
    public virtual String GetCurCommunityName()
    {
      IPTCommunityInfo ptCommunityInfo = (IPTCommunityInfo) (((NavigationModelTempData) GetTempData()).ptCommunityInfo);
      if (ptCommunityInfo != null)
      {
        return ptCommunityInfo.GetName();
      } else
      {
        throw new XPIllegalStateException("Attempted to get name of current Community when not on a Community page or " + "when NavigationModel has not been properly initialized yet.");
        }
    }
    
    /// <summary>
    /// Gets the id of the current document directory folder, or 0 if we are
    /// not currently in a single doc directory folder.
    /// </summary>
    public virtual int GetCurDocDirFolderID()
    {
      if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
      {
        if (!IsDirPage())
        {
          return 0;
        }
        // if there is a directory model around
        if (m_asOwner.GetModelExists(DirModel.STR_MVC_CLASS_NAME))
        {
          // fetch it
          DirModel dirModel = (DirModel) m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);
          // and return the folder id
          return dirModel.GetCurrentFolderID();
        }
      }
      return 0;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetDefaultCommunity()"></seealso>
    public virtual int GetDefaultCommunity()
    {
      IPTSubPortalInfo ptSubPortalInfo = ((NavigationModelTempData) GetTempData()).GetSubPortalInfo(m_ptSession);
      return GetDefaultCommunityPassSubportal(ptSubPortalInfo);
    }
    
    /// <summary>
    /// Get the default Community ID - the ID set in PTConfig.xml or if that is zero, then the ID of the first community in a user's membership list. 
    /// </summary>
    /// <param name="ptSubPortalInfo">Current user's Subportal object</param>
    /// <returns>
    /// 						Current user's Default Community ID or 
    /// -1 if Community access is disabled on the subportal or the user
    /// isn't member of any communities. 
    /// </returns>
    public virtual int GetDefaultCommunityPassSubportal(IPTSubPortalInfo ptSubPortalInfo)
    {
      if (GetSubPortalEnabledPassSubportal(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS,
       ptSubPortalInfo))
      {
        int nDefaultCommunityID = PTConfigHelper.GetConfigVariableAsInt("Communities",
         "DefaultCommunityID", "value", m_asOwner);
        if (0 >= nDefaultCommunityID)
        {
          try
          {
            IPTQueryResult qrComms = (IPTQueryResult) GetIPTSession().GetSessionInfo().GetCurrentCommunityMembership();
            if (qrComms.RowCount() > 0)
            {
              return qrComms.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);
              } else
            {
              return -1;
            }
          }
          catch (Exception e)
          {
            log.Warn(e, "Error getting default community: ");
            return -1;
          }
        } else
        {
          return nDefaultCommunityID;
        }
      }
      return NO_CURRENT_COMMID;
    }
    
    /// <summary>
    /// gets the current mypage id
    /// </summary>
    /// <returns>int	Current page id or if none exists, 0</returns>
    public virtual int GetCurPageID()
    {
      // Fix for #24964, Shouldn't check for mypage access since this method is also used for community pages.
      // The check is uneccessary anyways since this won't be called for on a mypage when mypages
      // are disabled.
      //		if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
      //		{		
      if (m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
      {
        return ((MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME)).GetPageID();
        }
      //		}
      return NO_CURRENT_PAGEID;
    }
    
    /// <summary>
    /// NOTE: Returned string not HTML/URLEncoded.
    /// </summary>
    /// <returns>
    /// Not HTMLEncoded/URLEncoded string of the page name or empty
    /// string if no current page.
    /// </returns>
    public virtual String GetCurPageName()
    {
      if (m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
      {
        try
        {
          return ((MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME)).GetPageName();
          }
        catch (Exception e)
        {
          log.Warn(e, "Unable to get the mypage name. This is probably an invalid page. ");
          }
      } else
      if (IsCommunityPage())
      {
        // default to the knowledge directory
        return m_asOwner.GetString(295, "ptmsgs_portalcommonmsgs");
      }
      log.Warn("Unable to get the name of the current page. Probably not on a Community or My Page");
      return "";
    }
    
    /// <summary>
    /// Get "welcome" greeting string
    /// </summary>
    /// <returns>strign set as greeting preference</returns>
    public virtual String GetGreeting()
    {
      String strGreeting;
      try
      {
        ISessionManager mgrSession = m_asOwner.GetSubSession();
        if (mgrSession == null)
        {
          // when a user first hits the login page, no subsession exists.  Use the default greeting
          // in this case.
          strGreeting = m_asOwner.GetString(315, "ptmsgs_portalcommonmsgs");
          } else
        {
          strGreeting = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.GREETING,
           m_asOwner);
          if ((strGreeting == null) || "".Equals(strGreeting))
          {
            // use welcome
            strGreeting = XPResourceManager.FormatMessage(m_asOwner.GetString(546,
             "ptmsgs_portalcommonmsgs"), GetIPTSession().GetSessionInfo().GetCurrentUserName());
            }
        }
      }
      catch (Exception e)
      {
        // Just use the default greeting
        log.Debug(e, "The portal was not able to access the greeting.  Will use a default greeting.");
        strGreeting = m_asOwner.GetString(315, "ptmsgs_portalcommonmsgs");
        }
      return strGreeting;
    }
    
    /// <summary>
    /// NAVIGATION LINK GENERATION *****************************************************
    /// /**
    /// </summary>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetParentComm()"></seealso>
    public virtual ICPListEntryIterator GetParentComm()
    {
      ASCompoundList list = new ASCompoundList();
      IPTURL ptURL = TaskAPIUICommunity.GetCurrentParentCommunityAsURL(m_asOwner);
      if (null == ptURL)
      {
        return list;
      }
      XPArrayList urlList = new XPArrayList();
      urlList.Add(ptURL);
      return ConvertCommunityPagePTURLListToICPIterator(urlList, false);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetPortalSettings()"></seealso>
    public virtual ICPListEntryIterator GetPortalSettings()
    {
      ASCompoundList list = new ASCompoundList();
      try
      {
        list.AddGenericURL(m_asOwner.GetString(296, "ptmsgs_portalcommonmsgs"),
         PortalSettingsAS.STR_MVC_CLASS_NAME, null, null, ASCompoundList.NEWASTYPE_CREATENEW);
        }
      catch (Exception e)
      {
        log.Error(e, "Exception getting the Portal Settings: ");
      }
      return list;
    }
    
    /// <summary>
    /// Never check IsCommunityPage before calling this function. Has internal
    /// security check and need to display the edit community membership entry
    /// even when not on community pages.
    /// NOTE: Any logic changes in this function also needs to be added to TaskAPIUICommunity functions.
    /// </summary>
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetMyPortalActions(int,int)"></seealso>
    public virtual ICPListEntryIterator GetCommunityActions()
    {
      ASCompoundList list = new ASCompoundList();
      XPArrayList urlList = TaskAPIUICommunity.GetCommunityActionsAsURLs(m_asOwner);
      for (int i = 0;i < urlList.GetSize();i++)
      {
        IPTURL ptURL = (IPTURL) urlList.GetElement(i);
        list.AddInternalFullURL(ptURL.GetData(PTURLConstants.KEY_TITLE), ptURL.GetFullURL());
        list.SetImageForLastAddedURL(ptURL.GetData(PTURLConstants.KEY_ICONIMG),
         ptURL.GetData(PTURLConstants.KEY_ICONIMGALT));
      }
      return list;
    }
    
    /// <summary>
    /// Helper to convert an XPArrayList with IPTURLs to Community or Communitypages to an ICPListEntryIterator
    /// </summary>
    /// <param name="urlList"></param>
    /// <param name="bUseCurrentMarker"></param>
    /// <returns></returns>
    public virtual ICPListEntryIterator ConvertCommunityPagePTURLListToICPIterator(XPArrayList urlList,
     bool bDontUseCurrent)
    {
      ASCompoundList list = new ASCompoundList();
      if (null == urlList || urlList.GetSize() == 0)
      {
        return list;
      }
      IXPEnumerator urlEnum = urlList.GetEnumerator();
      while (urlEnum.MoveNext())
      {
        IPTURL ptURL = (IPTURL) urlEnum.GetCurrent();
        // If it is the current community, just add a label instead of an url.
        if (null == ptURL.GetData(PTURLConstants.KEY_CURRENTMARKER) || bDontUseCurrent)
        {
          // DCA - check for profile community
          int nCommId = TaskAPIUICommunity.GetCommunityIDFromPTURL(ptURL);
          if (nCommId == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
          {
            list.AddCommPageURL(ptURL.GetData(PTURLConstants.KEY_TITLE), nCommId,
             TaskAPIUICommunity.GetCommunityPageIDFromPTURL(ptURL), /*DCA - no description*/
            "", /*DCA - this is the user profile Id*/
            XPConvert.ToInteger(ptURL.GetData(PTURLConstants.KEY_OBJECTID)));
            } else
          {
            list.AddCommPageURL(ptURL.GetData(PTURLConstants.KEY_TITLE), nCommId,
             TaskAPIUICommunity.GetCommunityPageIDFromPTURL(ptURL));
          }
        } else
        {
          list.AddLabel(ptURL.GetData(PTURLConstants.KEY_TITLE));
        }
      }
      return list;
    }
    
    /// <summary>
    /// Helper to convert an XPArrayList with IPTURLs to MyPages to an ICPListEntryIterator
    /// </summary>
    /// <param name="urlList"></param>
    /// <returns></returns>
    public virtual ICPListEntryIterator ConvertMyPagePTURLListToICPIterator(XPArrayList urlList)
    {
      ASCompoundList list = new ASCompoundList();
      if (null == urlList)
      {
        return list;
      }
      IXPEnumerator urlEnum = urlList.GetEnumerator();
      while (urlEnum.MoveNext())
      {
        IPTURL ptURL = (IPTURL) urlEnum.GetCurrent();
        // If it is the current mypage, just add a label instead of an url.
        if (null == ptURL.GetData(PTURLConstants.KEY_CURRENTMARKER))
        {
          list.AddMyPageURL(ptURL.GetData(PTURLConstants.KEY_TITLE), TaskAPIUIMyPages.GetMyPageIDFromPTURL(ptURL));
          } else
        {
          list.AddLabel(ptURL.GetData(PTURLConstants.KEY_TITLE));
        }
      }
      return list;
    }
    
    /// <summary>
    /// Gets all the current community pages if on community page
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetCurCommPages()
    {
      ASCompoundList list = new ASCompoundList();
      XPArrayList urlList = TaskAPIUICommunity.GetCurrentCommunityPagesAsURLs(m_asOwner);
      list.AddCompoundList(ConvertCommunityPagePTURLListToICPIterator(urlList,
       false));
      // Add the Community Knowledge Directory link too
      IPTURL url = TaskAPIUICommunity.GetURLForCommunityKnowledgeDirectory(m_asOwner,
       GetCurCommunityID());
      if (url != null)
      {
        list.AddSiteMapRootURL(url.GetData(PTURLConstants.KEY_TITLE), XPConvert.ToInteger(url.GetData(SetSiteMapControl.m_CommunityID)),
         XPConvert.ToInteger(url.GetData(SetSiteMapControl.m_Mode)), false);
        }
      return list;
    }
    
    /// <summary>
    /// Form the admin link for navigation
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetAdminLink()
    {
      ASCompoundList list = new ASCompoundList();
      if (HasAdminLinkAccess())
      {
        IPTURL ptURL = TaskAPIUIAdministration.GetURLForAdministrationPortal(m_asOwner);
        if (null != ptURL)
        {
          list.AddInternalFullURL(ptURL.GetData(PTURLConstants.KEY_TITLE),
           ptURL.GetFullURL());
        }
      }
      return list;
    }
    
    /// <param name="bAddAdminLink"></param>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetCurMandatoryTabs(bool bAddAdminLink)
    {
      XPArrayList urlList = null;
      urlList = TaskAPIUICommunity.GetMyMandatoryCommunitiesWithTabsAsURLs(m_asOwner,
       true);
      ASCompoundList list = (ASCompoundList) ConvertCommunityPagePTURLListToICPIterator(urlList,
       true);
      if (bAddAdminLink)
      {
        list.AddCompoundList(GetAdminLink());
      }
      return list;
    }
    
    /// <summary>
    /// Gets all the current my pages if on the my page
    /// </summary>
    /// <param name="bShowActions">True to show mypage actions</param>
    /// <returns>							Mypages and actions if specified in an ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetCurMyPages(bool bShowActions)
    {
      XPArrayList urlList = TaskAPIUIMyPages.GetMyPagesAsURLs(m_asOwner);
      return ConvertMyPagePTURLListToICPIterator(urlList);
    }
    public virtual IPTQueryResult GetCurMyPagesResult()
    {
      IPTQueryResult qrMyPages = ((NavigationModelTempData) GetTempData()).ptqrMyPages;
      return qrMyPages;
    }
    
    /// <summary>
    /// Helper function, returns the join community link, community actions if on
    /// a community page and the list of communities.
    /// </summary>
    /// <param name="bListActions"></param>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetMyCommunities(bool bListActions)
    {
      ASCompoundList list = new ASCompoundList();
      XPArrayList urlList = TaskAPIUICommunity.GetMyCommunitiesAsURLs(m_asOwner,
       true);
      if (bListActions)
      {
        list.AddCompoundList(GetCommunityActions());
      }
      list.AddCompoundList(ConvertCommunityPagePTURLListToICPIterator(urlList,
       false));
      return list;
    }
    
    /// <summary>
    /// Get actions list for th eMyPages links.
    /// </summary>
    /// <param name="nNumMyPages"></param>
    /// <returns>An XPArrayList with ASURLContainer objects.</returns>
    /// <seealso cref="com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetMyPagesActions()"></seealso>
    public virtual ICPListEntryIterator GetMyPageActions()
    {
      ASCompoundList list = new ASCompoundList();
      XPArrayList urlList = TaskAPIUIMyPages.GetMyPageActionsAsURLs(m_asOwner);
      for (int i = 0;i < urlList.GetSize();i++)
      {
        IPTURL ptURL = (IPTURL) urlList.GetElement(i);
        list.AddInternalFullURL(ptURL.GetData(PTURLConstants.KEY_TITLE), ptURL.GetFullURL());
        //			list.AddFullURL(ptURL.GetData(PTURLConstants.KEY_TITLE), ptURL.GetFullURL());
        list.SetImageForLastAddedURL(ptURL.GetData(PTURLConstants.KEY_ICONIMG),
         ptURL.GetData(PTURLConstants.KEY_ICONIMGALT));
      }
      return list;
    }
    
    /// <summary>
    /// Get the current related communtiies links
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetCurRelCommunities()
    {
      XPArrayList urlList = TaskAPIUICommunity.GetCurrentRelatedCommunitiesAsURLs(m_asOwner);
      return ConvertCommunityPagePTURLListToICPIterator(urlList, false);
    }
    
    /// <summary>
    /// Get current subcommunities links
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    /// <throws>Exception</throws>
    public virtual ICPListEntryIterator GetCurSubCommunities()
    {
      XPArrayList urlList = TaskAPIUICommunity.GetCurrentSubCommunitiesAsURLs(m_asOwner);
      return ConvertCommunityPagePTURLListToICPIterator(urlList, false);
    }
    
    /// <summary>
    /// Get the list fo mandatory links
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetMandatoryLinks()
    {
      ASCompoundList cpList = new ASCompoundList();
      XPArrayList urlList = TaskAPIUISubPortal.GetSubPortalMandatoryLinksAsURLs(m_asOwner);
      for (int i = 0;i < urlList.GetSize();i++)
      {
        IPTURL urlEntry = (IPTURL) urlList.GetElement(i);
        String strTitle = urlEntry.GetData(PTURLConstants.KEY_TITLE);
        String strURL = urlEntry.GetFullURL();
        if (FullURL.URL_TYPE_FULLURL.Equals(urlEntry.GetData(PTURLConstants.KEY_URLTYPE)))
        {
          cpList.AddFullURL(strTitle, strURL);
          cpList.SetImageForLastAddedURL(PTImageType.ICON_URL, strTitle);
          } else
        if (CommonOpenerOpenObjIDURL.URL_TYPE_OBJCOMMONOPENER.Equals(urlEntry.GetData(PTURLConstants.KEY_URLTYPE)))
        {
          int nClassID = XPConvert.ToInteger(urlEntry.GetData(CommonOpenerOpenObjIDURL.KEY_COMMONOPENER_CLASSID));
          int nObjectID = XPConvert.ToInteger(urlEntry.GetData(CommonOpenerOpenObjIDURL.KEY_COMMONOPENER_OBJECTID));
          switch (nClassID){
          case PT_CLASSIDS.PT_COMMUNITY_ID:
          if (null == urlEntry.GetData(SetCommunityControl.PROFILEID))
          {
            int nPageID = XPConvert.ToInteger(urlEntry.GetData(PTCommunities.STR_PAGE_ID));
            cpList.AddCommPageURL(strTitle, nObjectID, nPageID);
            cpList.SetImageForLastAddedURL(PTImageType.ICON_COMMUNITY, strTitle);
            } else
          {
            int nProfileID = XPConvert.ToInteger(urlEntry.GetData(SetCommunityControl.PROFILEID));
            cpList.AddUserProfileURL(strTitle, nProfileID);
            cpList.SetImageForLastAddedURL(PTImageType.ICON_USER, strTitle);
            }
          break;
          case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
          cpList.AddDirectoryURL(strTitle, DirConstants.BROWSE_MODE, nObjectID);
          cpList.SetImageForLastAddedURL(PTImageType.ICON_FOLDER, strTitle);
          break;
          case PT_CLASSIDS.PT_CATALOGCARD_ID:
          cpList.AddDocumentURL(strTitle, nObjectID);
          cpList.SetImageForLastAddedURL(PTImageType.ICON_DOCUMENT, strTitle);
          break;
          }
        }
      }
      return cpList;
    }
    
    /// <summary>
    /// Get list of directory links
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetDirectoryLinks()
    {
      ASCompoundList list = new ASCompoundList();
      IPTURL browseURL = TaskAPIUIDirectory.GetURLForBrowseDirectory(m_asOwner,
       PT_INTRINSICS.PT_FOLDER_ROOTFOLDER);
      IPTURL editURL = TaskAPIUIDirectory.GetURLForEditDirectory(m_asOwner,
       PT_INTRINSICS.PT_FOLDER_ROOTFOLDER);
      if (null != browseURL)
      {
        list.AddDirectoryURL(browseURL.GetData(PTURLConstants.KEY_TITLE),
         DirConstants.BROWSE_MODE, FOLDERID_UNCHANGED);
        list.SetImageForLastAddedURL(PTImageType.ICON_BROWSE_MENU, m_asOwner.GetString(277,
         "ptmsgs_portalcommonmsgs"));
      }
      if (null != editURL)
      {
        list.AddDirectoryURL(editURL.GetData(PTURLConstants.KEY_TITLE), DirConstants.EDIT_MODE,
         FOLDERID_UNCHANGED);
        list.SetImageForLastAddedURL(PTImageType.ICON_EDIT, m_asOwner.GetString(279,
         "ptmsgs_portalcommonmsgs"));
      }
      return list;
    }
    
    /// <summary>
    /// Returns the My Home link for the current user (the page the user first sees after logging in.
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetMyHome()
    {
      IPTURL url = TaskAPIUIUser.GetURLForMyHome(m_asOwner);
      ASCompoundList list = new ASCompoundList();
      if (null == url)
      {
        return list;
      }
      String strURLTitle = url.GetData(PTURLConstants.KEY_TITLE);
      if (CommonOpenerOpenObjIDURL.URL_TYPE_OBJCOMMONOPENER.Equals(url.GetData(PTURLConstants.KEY_URLTYPE)))
      {
        int nClassID = XPConvert.ToInteger(url.GetData(CommonOpenerOpenObjIDURL.KEY_COMMONOPENER_CLASSID));
        int nObjectID = XPConvert.ToInteger(url.GetData(CommonOpenerOpenObjIDURL.KEY_COMMONOPENER_OBJECTID));
        switch (nClassID){
        case PT_CLASSIDS.PT_COMMUNITY_ID:
        list.AddCommPageURL(strURLTitle, nObjectID, 0);
        break;
        case PT_CLASSIDS.PT_MYPAGESCONTAINER_ID:
        list.AddMyPageURL(strURLTitle, nObjectID);
        break;
        case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
        list.AddDirectoryURL(strURLTitle, DirConstants.BROWSE_MODE, nObjectID);
        break;
        }
      } else
      {
        // If it is not an objid url it is an editor url, or a friendly URL
        list.AddInternalFullURL(strURLTitle, url.GetFullURL());
      }
      list.SetImageForLastAddedURL(PTImageType.ICON_HOME, m_asOwner.GetString(699,
       "ptmsgs_portalcommonmsgs"));
      return list;
    }
    
    /// <summary>
    /// Get footer element
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    public virtual HTMLElementCollection GetFooterElement()
    {
      if (!GetFooterHasBeenSet())
      {
        return null;
      }
      return ((HTMLElementCollection) (((NavigationModelTempData) GetTempData()).m_footerCollection));
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetFooterHasBeenSet()"></seealso>
    public virtual bool GetFooterHasBeenSet()
    {
      NavigationModelTempData objTempData = (NavigationModelTempData) GetTempData();
      return objTempData.m_bFooterSet;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetHeaderElement()"></seealso>
    public virtual HTMLElementCollection GetHeaderElement()
    {
      if (!GetHeaderHasBeenSet())
      {
        return null;
      }
      return ((HTMLElementCollection) (((NavigationModelTempData) GetTempData()).m_headerCollection));
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetHeaderHasBeenSet()"></seealso>
    public virtual bool GetHeaderHasBeenSet()
    {
      NavigationModelTempData objTempData = (NavigationModelTempData) GetTempData();
      return objTempData.m_bHeaderSet;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#SetFooterElement(boolean,HTMLElement)"></seealso>
    public virtual void SetFooterElement(bool bClearPrevContent, HTMLElement element)
    {
      NavigationModelTempData objTempData = (NavigationModelTempData) GetTempData();
      log.Debug("NavigationModel::SetFooterElement: A footer gadget is being set as the footer element.");
      if (bClearPrevContent)
      {
        ((HTMLElementCollection) (objTempData.m_footerCollection)).ClearInnerHTMLElements();
        }
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
      {
        log.Debug("NavigationModel::SetFooterElement: Since we are in 508 mode, we will force the footer to be the default footer.");
        element = m_asOwner.GetView(DefaultFooterView.STR_MVC_CLASS_NAME).Display();
        }
      ((HTMLElementCollection) (objTempData.m_footerCollection)).AddInnerHTMLElement(element);
      objTempData.m_bFooterSet = true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#SetHeaderElement(boolean,HTMLElement)"></seealso>
    public virtual void SetHeaderElement(bool bClearPrevContent, HTMLElement element)
    {
      NavigationModelTempData objTempData = (NavigationModelTempData) GetTempData();
      log.Debug("NavigationModel::SetHeaderElement: A header gadget is being set as the header element.");
      if (bClearPrevContent)
      {
        ((HTMLElementCollection) (objTempData.m_headerCollection)).ClearInnerHTMLElements();
        }
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
      {
        log.Debug("NavigationModel::SetHeaderElement: Since we are in 508 mode, we will force the header to be the default header.");
        }
      ((HTMLElementCollection) (objTempData.m_headerCollection)).AddInnerHTMLElement(element);
      objTempData.m_bHeaderSet = true;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetSubportalBanner()"></seealso>
    public virtual HTMLElement GetSubportalBanner()
    {
      try
      {
        if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
        {
          return m_asOwner.GetView(DefaultHeaderView.STR_MVC_CLASS_NAME).Display();
          } else
        //return null;
        // go to subportal
        {
          HTMLElementCollection header = GetHeaderElement();
          if (header != null && GetHeaderHasBeenSet())
          {
            log.Debug("Successfully got a header gadget, will display this header.");
            return header;
          } else
          {
            log.Debug("Could not get a header gadget, no header will display.");
            return m_asOwner.GetView(DefaultHeaderView.STR_MVC_CLASS_NAME).Display();
            }
        }
      }
      //return null;
      catch (Exception e)
      {
        log.Warn(e, "Failed getting header content, no header will display.");
        // Put in a placeholder element for header, will get set at the end.
        return m_asOwner.GetView(DefaultHeaderView.STR_MVC_CLASS_NAME).Display();
        }
    }
    // New design dictates no header if not assigned
    //return null;
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetSubportalFooter()"></seealso>
    public virtual HTMLElement GetSubportalFooter()
    {
      try
      {
        if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
        {
          return m_asOwner.GetView(DefaultFooterView.STR_MVC_CLASS_NAME).Display();
          } else
        // go to subportal
        {
          HTMLElementCollection footer = GetFooterElement();
          if (footer != null && GetFooterHasBeenSet())
          {
            log.Debug("Successfully got a footer gadget, will display this footer.");
            return footer;
          } else
          {
            log.Debug("Could not get a footer gadget, will display the default footer.");
            return m_asOwner.GetView(DefaultFooterView.STR_MVC_CLASS_NAME).Display();
            }
        }
      }
      catch (Exception e)
      {
        log.Warn(e, "Failed getting footer content, will use default Footer.");
        // Put in a placeholder element for header, will get set at the end.
        //result.AddInnerHTMLElement(m_asOwner.GetView(DefaultHeaderView.STR_MVC_CLASS_NAME).Display());
        return m_asOwner.GetView(DefaultFooterView.STR_MVC_CLASS_NAME).Display();
        }
    }
    
    /// <summary>
    /// Sets up all the portlet content for this page. Whether it is a communiy page, my page, or otherwise.
    /// It should only be called after the Expression Engine has been run to determine what the subportal is.
    /// </summary>
    public virtual void InitializePortletContent()
    {
      // If this is a mypage or a community page, then the query for the header and footer will be
      // included in the query for the gadgets on the page, and the header and footer elements
      // will be set when we processed through the gadget content array.
      if (IsMyPortalPage() && NO_CURRENT_PAGEID != ((MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME)).GetPageID())
      {
        ((MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME)).InitializePortletContent();
        } else
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        // In 508 and lowbandwidth, we always use the default header and footer.
        // TODO-MJD : should this take the container class id and object id instead of the community id? 
        IPTState objAppDataObject = AppDataObject.GetAppDataObject(GetCurCommunityID(),
         GetCurPageID(), m_asOwner.GetCurrentRequestURL(), m_asOwner);
        if (!(GatewayAS.STR_MVC_CLASS_NAME).Equals(m_asOwner.GetName()))
        {
          HttpUtils.SetReturnURI(m_asOwner.GetCurrentRequestURL(), m_asOwner.GetSubSession());
          }
        IPTPageInfo pageInfo;
        if (NO_CURRENT_COMMID != GetCurCommunityID())
        {
          pageInfo = ((IPTCommunityManager) m_ptSession.GetCommunities()).CachedOpenCommunityInfo(GetCurCommunityID(),
           false).GetPage(PT_INTRINSICS.PT_PAGE_GLOBAL);
        } else
        {
          pageInfo = ((IPTPageManager) m_ptSession.GetPages()).CachedOpenPageInfo(PT_INTRINSICS.PT_PAGE_GLOBAL,
           false, false);
        }
        IPTMyPortalGadgetContent portletContent = pageInfo.QueryPortletContent(objAppDataObject,
         "", PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
        SetupChromePortlets((NavigationModelTempData) GetTempData(), objAppDataObject,
         portletContent);
      }
    }
    
    /// <summary>
    /// Sets up the portlet that are not in the content area of a page.
    /// </summary>
    /// <param name="objTempData"></param>
    /// <param name="objAppDataObject"></param>
    /// <param name="objHeaderAndFooter"></param>
    private void SetupChromePortlets(NavigationModelTempData objTempData,
     IPTState objAppDataObject, IPTMyPortalGadgetContent objHeaderAndFooter)
    {
      // bjf -- process through the array and look for a header and footer.  If the footer in the 
      // subportal is set to 0, then there won't be a footer in this array.  We can't simply call
      // GetContent(0) and assume that that will be the footer.  Also, if we took that tactic, then
      // the server may throw exceptions.  This method avoids exception throwing unless there
      // really is an error.			
      for (int i = 0;i < objHeaderAndFooter.GetCount();i++)
      {
        // Translate gadget content for header+footer; handle remote + instrinsic
        if ((!objTempData.m_bHeaderSet && PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER == objHeaderAndFooter.GetGadgetAlignment(i)) || (!objTempData.m_bFooterSet && PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER == objHeaderAndFooter.GetGadgetAlignment(i)))
        {
          NavigationModel modelNavigation = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
          try
          {
            Object[][] objArrMarkup = (Object[][]) objHeaderAndFooter.GetContent(i);
            HTMLElement result = new HTMLElementCollection();
            // DAP TODO: We don't have to test for 508 portlets because header+footer portlets 
            // are not supported in 508 mode (for now anyway); refer to MyPortalContentView for code
            // DAP 2-2-04: added intrinsic portlet support for header + footer
            if (IntrinsicPortletModel.IsIntrinsicPortlet(objArrMarkup))
            {
              // it's an intrinsic portlet, so no markup is supported
              result.AddInnerHTMLElement(GetIntrinsicPortletContentWithErrorHandling(i,
               objHeaderAndFooter.GetGadgetID(i), objArrMarkup, objHeaderAndFooter.GetGadget(i),
               objAppDataObject, objHeaderAndFooter.GetGadgetName(i)));
            } else
            {
              // it's a standard remote portlet, so process the markup transformer tags
              // NOTE: the shared JS needs to be displayed before all portlets
              result.AddInnerHTMLElement(GatewayUtils.AddMarkupToElement(m_asOwner,
               objArrMarkup));
            }
            if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER == objHeaderAndFooter.GetGadgetAlignment(i))
            {
              modelNavigation.SetHeaderElement(true, result);
            } else
            {
              modelNavigation.SetFooterElement(true, result);
            }
          }
          catch (Exception e)
          {
            // do nothing, the subportal Footer will be used.
            log.Warn(e, "Failed getting footer content, will use default Footer.");
            }
        }
      }
    }
    //
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetMandatoryLinksFolderName()"></seealso>
    public virtual String GetMandatoryLinksFolderName()
    {
      IPTSiteMapFolderInfo ptSiteMapFolderInfo = null;
      try
      {
        ptSiteMapFolderInfo = (IPTSiteMapFolderInfo) (((NavigationModelTempData) GetTempData()).GetSiteMapFolderInfo(m_ptSession));
        }
      catch (Exception e)
      {
        log.Warn(e, "No mandatory links set for this user.");
      }
      if (ptSiteMapFolderInfo != null)
      {
        int nMandLinksID = ptSiteMapFolderInfo.GetObjectID();
        if (nMandLinksID > 0)
        {
          return ptSiteMapFolderInfo.GetName();
        } else
        {
          log.Info("Couldn\'t get the Mandatory Links from the Subportal.  Either mandatory links are not set on this user\'s subportal, or the current user does not have read access to those links.  Will not display mandatory links section.");
          }
      }
      return "";
    }
    
    /// <summary>
    /// Checks if the specified access type is enabled on the current user's subportal.
    /// </summary>
    /// <param name="nType">PT_SUBPORTAL_ACCESS_TYPES to check access on</param>
    /// <param name="subPortal">Current user's subportal object</param>
    /// <returns>boolean		True if the access type is enabled for current user</returns>
    /// <seealso cref="PT_SUBPORTAL_ACCESS_TYPES"></seealso>
    public virtual bool GetSubPortalEnabledPassSubportal(int nType, IPTSubPortalInfo subPortal)
    {
      if ((nType != PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS) && (nType != PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS) && (nType != PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
      {
        log.Info("Invalid Subportal Access Type.");
        return false;
      }
      try
      {
        int nAccessType = subPortal.GetAccessType();
        if ((nType & nAccessType) != 0)
        {
          return true;
        } else
        {
          return false;
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the Access Type from Subportal: ");
        return false;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetSubPortalEnabled(int)"></seealso>
    public virtual bool GetSubPortalEnabled(int nType)
    {
      IPTSubPortalInfo subPortal;
      try
      {
        subPortal = (IPTSubPortalInfo) (((NavigationModelTempData) GetTempData()).GetSubPortalInfo(m_ptSession));
        }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the Access Type from Subportal: ");
        return false;
      }
      return GetSubPortalEnabledPassSubportal(nType, subPortal);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetSubPortalFirstPageType()"></seealso>
    public virtual int GetSubPortalFirstPageType()
    {
      try
      {
        IPTSubPortalInfo subPortal = (IPTSubPortalInfo) (((NavigationModelTempData) GetTempData()).GetSubPortalInfo(m_ptSession));
        int nAccessType = subPortal.GetDefaultFirstPageType();
        return nAccessType;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the SubPortalInfo object for First Page type: ");
        return -1;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetSubPortalNavScheme()"></seealso>
    public virtual int GetSubPortalNavScheme()
    {
      try
      {
        IPTSubPortalInfo subPortal = (IPTSubPortalInfo) (((NavigationModelTempData) GetTempData()).GetSubPortalInfo(m_ptSession));
        int nNavScheme = subPortal.GetNavigationScheme();
        return nNavScheme;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the NavigationScheme from Subportal: ");
        return -1;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetSubPortalPageID()"></seealso>
    public virtual int GetSubPortalPageID()
    {
      try
      {
        IPTSubPortalInfo subPortal = (IPTSubPortalInfo) (((NavigationModelTempData) GetTempData()).GetSubPortalInfo(m_ptSession));
        int nFirstPageID = subPortal.GetDefaultFirstPageID();
        return nFirstPageID;
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to get the SubPortalInfo object for First Page ID: ");
        return -1;
      }
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetDefaultSubportalURL()"></seealso>
    public virtual ASURL GetDefaultSubportalURL()
    {
      ASURL defaultPageURL = new ASURL(m_asOwner);
      int nDefaultPageType = GetSubPortalFirstPageType();
      int nDefaultPageID = GetSubPortalPageID();
      switch (nDefaultPageType){
      case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS:
      nDefaultPageID = GetAccessibleCommunityID(nDefaultPageID);
      if (nDefaultPageID != -1)
      {
        defaultPageURL.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        defaultPageURL.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
        defaultPageURL.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
         nDefaultPageID);
        defaultPageURL.AddControlArgument(SetCommunityControl.STR_PAGE_ID,
         0);
      } else
      {
        defaultPageURL.SetLinkCreateNewSpace(CommunitySelectionEditorAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        defaultPageURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
        defaultPageURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
         EditorStartControl.EDITOR_START_FLAG_MISC);
      }
      break;
      case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS:
      defaultPageURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
      defaultPageURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
      defaultPageURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, DirConstants.BROWSE_MODE);
      defaultPageURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
       nDefaultPageID);
      break;
      case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS:
      defaultPageURL.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
      defaultPageURL.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
      defaultPageURL.AddControlArgument(SetPageControl.STR_PAGE_ID, SetPageControl.N_HOME_PAGE_ID);
      break;
      }
      return defaultPageURL;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetSubtitleForBanner()"></seealso>
    public virtual String GetSubtitleForBanner()
    {
      PlumtreeDP dpPlumtree = (PlumtreeDP) m_asOwner.GetCurrentPage();
      // Why Call the myportal that calls back to navmodel??
      return dpPlumtree.GetSubtitleForBanner();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#GetTitleForBanner()"></seealso>
    public virtual String GetTitleForBanner()
    {
      PlumtreeDP dpPlumtree = (PlumtreeDP) m_asOwner.GetCurrentPage();
      // Why Call the myportal that calls back to navmodel??
      return dpPlumtree.GetTitleForBanner();
    }
    
    /// <summary>
    /// Gets the currently registered view's Nav Scheme
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetRegisteredViewNavScheme()
    {
      return m_nRegisteredViewNavScheme;
    }
    
    /// <summary>
    /// Sets the currently registered view nav scheme to be newNavScheme
    /// </summary>
    /// <param name="the">new registered view's Nav Scheme</param>
    public virtual void SetRegisteredViewNavScheme(int newNavScheme)
    {
      m_nRegisteredViewNavScheme = newNavScheme;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#HasAdministratorAccess()"></seealso>
    public virtual bool HasAdministratorAccess()
    {
      return TaskAPIUIUser.IsCurrentUserAdministrator(m_asOwner);
    }
    
    /// <summary>
    /// Checks to see if we should display the admin link or not
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool HasAdminLinkAccess()
    {
      return TaskAPIUIUser.HasAdminLinkAccess(m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#HasSelectAccess()"></seealso>
    public virtual bool HasSelectAccess()
    {
      return CheckAccessLevel(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
    }
    
    /// <summary>
    /// Check the if the current user has at least the accesslevel specified to the current
    /// community 
    /// </summary>
    /// <param name="AccessLevel">to check for</param>
    /// <returns>boolean					True if the current user has at least the specified accesslevel</returns>
    /// <seealso cref="PT_ACCESS_LEVELS"></seealso>
    private bool CheckAccessLevel(int _accessLevel)
    {
      bool bHasAccess = false;
      IPTCommunityInfo ptCommunityInfo = (IPTCommunityInfo) (((NavigationModelTempData) GetTempData()).ptCommunityInfo);
      if (ptCommunityInfo != null)
      {
        try
        {
          // mj: pretend that everyone has only read access to the profile community, 
          // so that the "edit" button will be hidden.
          if (ptCommunityInfo.GetObjectID() == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
          {
            bHasAccess = (_accessLevel <= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
            } else
          {
            bHasAccess = (_accessLevel <= ptCommunityInfo.GetAccessLevel());
            }
        }
        catch (Exception e)
        {
          UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
           e, m_asOwner.GetString(647, "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(648,
           "ptmsgs_portalcommonmsgs"));
          UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
          }
      }
      return bHasAccess;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsCommunityPage()"></seealso>
    public virtual bool IsCommunityPage()
    {
      return TaskAPIUICommunity.IsCurrentPageCommunityPage(m_asOwner);
    }
    
    /// <summary>
    /// Checks if this a MyPortal page, (either Mypage or Community page
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsMyPortalPage()
    {
      return TaskAPIUICommunity.IsCurrentPageMyPortalPage(m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsCurCommOwner()"></seealso>
    public virtual bool IsCurCommOwner()
    {
      return TaskAPIUICommunity.IsCurrentUserCommunityOwner(m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsDirPage()"></seealso>
    public virtual bool IsDirPage()
    {
      return TaskAPIUIDirectory.IsCurrentPageDirectoryPage(m_asOwner);
    }
    
    /// <summary>
    /// Checks if this is the User Profile Community
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsUserProfileCommunity()
    {
      return TaskAPIUICommunity.IsCurrentCommunityUserProfileCommunity(m_asOwner);
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#IsEditProfile()"></seealso>
    public virtual bool IsEditProfile()
    {
      return TaskAPIUICommon.IsCurrentPageInEditDefaultProfileMode(m_asOwner);
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#IsGuestSession()"></seealso>
    public virtual bool IsGuestSession()
    {
      return TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsLoginPage()"></seealso>
    public virtual bool IsLoginPage()
    {
      return (LoginAS.STR_MVC_CLASS_NAME.Equals(m_asOwner.GetName()));
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsMyPage()"></seealso>
    public virtual bool IsMyPage()
    {
      return TaskAPIUIMyPages.IsCurrentPageMyPage(m_asOwner);
    }
    
    /// <summary>
    /// This function checks the MyPortalModel
    /// to see if the current page is a community preview page
    /// (certain actions are disabled in this case).
    /// </summary>
    /// <returns>boolean</returns>
    public virtual bool IsPreviewPage()
    {
      return TaskAPIUICommon.IsCurrentPageInPreviewMode(m_asOwner);
    }
    
    /// <returns>boolean</returns>
    public virtual bool IsDefaultProfile()
    {
      return PlumtreeHelpers.IsEditingDefaultProfile(m_asOwner);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsMemberInCurCommunity()"></seealso>
    public virtual bool IsMemberInCurCommunity()
    {
      return TaskAPIUICommunity.IsUserMemberOfCurrentCommunity(m_asOwner);
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetSectionVisibility(int)"></seealso>
    public virtual bool GetSectionVisibility(int nSectionIDConst)
    {
      if (IsGuestSession())
      {
        return true;
      }
      if ((nSectionIDConst < 0) || (nSectionIDConst > NavVisibility.VISIBILITY_SECTION_COUNT))
      {
        log.Error("Getting visibility on an invalid section: " + nSectionIDConst + " Maximum section id is: " + NavVisibility.VISIBILITY_SECTION_COUNT);
        return false;
      }
      //		String commaDelimitedBitArray = (String) PTPersonalSettingsHelper.GetPersonalSettingValue("VerticalNavVisArray", m_asOwner);
      //		 If we don't have anythign stored then everything must be visible, array not stored until the user modifies a section
      //		if ( null == commaDelimitedBitArray ) {
      //			return true; 	
      //		}
      //		XPStringTokenizer items = new XPStringTokenizer(commaDelimitedBitArray, ",");
      //		boolean[] bAr = new boolean[NavVisibility.VISIBILITY_SECTION_COUNT];
      //		for ( int i = 0; items.HasMoreTokens(); i++ ) {
      //			bAr[i] = XPConvert.ToBoolean(items.GetNextToken());
      //		}
      //ISessionManager settings = (ISessionManager)m_asOwner.GetSubSession().GetSubSession(PersonalSettingsHelper.PREFS_SUBSESSION_NAME);
      ISessionManager settings = (ISessionManager) m_asOwner.GetSubSession();
      bool[] bAr = (bool[]) settings.GetAttribute(SECTION_VISIBILITY_SESSION_ATTRIBUTE);
      // If we don't have anythign stored then everything must be visible.
      if (null == bAr)
      {
        return true;
      }
      return bAr[nSectionIDConst];
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#SetSectionVisibility(int,boolean)"></seealso>
    public virtual void SetSectionVisibility(int nSectionIDConst, bool bShow)
    {
      // Don't store anything for guests
      if (IsGuestSession())
      {
        return;
      }
      if ((nSectionIDConst < 0) || (nSectionIDConst > NavVisibility.VISIBILITY_SECTION_COUNT))
      {
        log.Error("Setting visibility on an invalid section: " + nSectionIDConst + " Maximum section id is: " + NavVisibility.VISIBILITY_SECTION_COUNT);
        return;
      }
      //ISessionManager settings = (ISessionManager)m_asOwner.GetSubSession().GetSubSession(PersonalSettingsHelper.PREFS_SUBSESSION_NAME);
      ISessionManager settings = (ISessionManager) m_asOwner.GetSubSession();
      bool[] bAr = (bool[]) settings.GetAttribute(SECTION_VISIBILITY_SESSION_ATTRIBUTE);
      bAr[nSectionIDConst] = bShow;
      settings.SetAttribute(SECTION_VISIBILITY_SESSION_ATTRIBUTE, bAr);
      XPStringBuilder buf = new XPStringBuilder(NavVisibility.VISIBILITY_SECTION_COUNT * 2);
      for (int i = 0;i < bAr.Length;i++)
      {
        buf.Append(((i == 0) ? "" : ","));
        buf.Append(XPConvert.ToInteger(bAr[i]));
      }
      PTPersonalSettingsHelper.SetAndCachePersonalSetting(NAV_SECTIONVISARRAY_PREFSNAME,
       buf.ToString(), m_asOwner);
    }
    
    /// <summary>
    /// This helper method gets the IPTSession from the parent AActivitySpace.
    /// </summary>
    /// <returns>IPTSession</returns>
    private IPTSession GetIPTSession()
    {
      return (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <summary>
    /// Used by pluggable navigation to access the MyPages model
    /// </summary>
    /// <returns>IModel</returns>
    public virtual IModel GetMyPortalModel()
    {
      IModel portalMod = null;
      if (m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
      {
        portalMod = m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        }
      return portalMod;
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetPageSpecificMethods()"></seealso>
    public virtual NavigationPage GetPageSpecificMethods()
    {
      return NavigationPage.Create(GetCurNavPageType(), (INavigationModelRO) this);
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetCurNavPageType()"></seealso>
    public virtual NavPageType GetCurNavPageType()
    {
      if (IsCommunityPage())
      {
        return NavPageType.COMMUNITY;
      } else
      if (IsDirPage())
      {
        return NavPageType.DIRECTORY;
      } else
      if (IsLoginPage())
      {
        return NavPageType.LOGIN;
      } else
      if (IsMyPage())
      {
        return NavPageType.MYPAGE;
      } else
      if (IsPreviewPage())
      {
        return NavPageType.COMMUNITYPREVIEW;
      } else
      if (IsEditProfile())
      {
        return NavPageType.USERPROFILE;
      }
      // unrecognized page type - error!
      return NavPageType.UNKNOWN;
    }
    
    /// <summary>
    /// Get the links lists by category, with or without actions.  If getActions is true,
    /// returns *only actions*, else returns *only the list*.  Note that subportal access is also tested, 
    /// so if community access is disabled on the subportal the links list will be null.
    /// </summary>
    /// <param name="linkType">Type of links, use constants defined in NavCategoryType</param>
    /// <param name="getActions">Returns actions, if any, associated with this link type</param>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetCategoryLinks(NavCategoryType linkType,
     bool getActions)
    {
      ICPListEntryIterator cpList = null;
      // note: subportal access checking done within each method
      if (linkType.Equals(NavCategoryType.ADMIN))
      {
        cpList = GetAdminLink();
      } else
      if (linkType.Equals(NavCategoryType.COMMUNITY))
      {
        if (getActions)
        {
          cpList = GetCommunityActions();
        } else
        {
          cpList = GetCurCommPages();
        }
      } else
      if (linkType.Equals(NavCategoryType.DIRECTORY))
      {
        cpList = GetDirectoryLinks();
      } else
      if (linkType.Equals(NavCategoryType.MANDATORYLINK))
      {
        cpList = GetMandatoryLinks();
      } else
      if (linkType.Equals(NavCategoryType.MYPAGE))
      {
        if (getActions)
        {
          cpList = GetMyPageActions();
        } else
        {
          // action param to GetCurMyPages just appends action list from above
          cpList = GetCurMyPages(false);
        }
      } else
      if (linkType.Equals(NavCategoryType.MANDATORYTABS))
      {
        // subportal access checking done within this method
        cpList = GetCurMandatoryTabs(getActions);
      } else
      if (linkType.Equals(NavCategoryType.MYCOMMUNITIES))
      {
        // subportal access checking done within this method
        cpList = GetMyCommunities(getActions);
      } else
      if (linkType.Equals(NavCategoryType.MYHOME))
      {
        cpList = GetMyHome();
      }
      return cpList;
    }
    
    /// <summary>
    /// Get the name of the category link type.  Example: "Administrator" for admin.  Top level only.
    /// </summary>
    /// <param name="linkType"></param>
    /// <returns>String category name for link title</returns>
    public virtual String GetCategoryTitle(NavCategoryType linkType)
    {
      String categoryTitle = null;
      // Determine the string title for each links section
      if (linkType.Equals(NavCategoryType.ADMIN))
      {
        if (HasAdminLinkAccess())
        {
          // Administrator
          categoryTitle = m_asOwner.GetString(275, "ptmsgs_portalcommonmsgs");
          }
      } else
      if (linkType.Equals(NavCategoryType.COMMUNITY))
      {
        if (GetCurCommunityID() == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
        {
          // User Profile Pages
          categoryTitle = m_asOwner.GetString(578, "ptmsgs_portalbrowsingmsgs");
          } else
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
        {
          // Community Pages
          categoryTitle = m_asOwner.GetString(272, "ptmsgs_portalcommonmsgs");
          }
      } else
      if (linkType.Equals(NavCategoryType.DIRECTORY))
      {
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS))
        {
          // Directory
          categoryTitle = m_asOwner.GetString(254, "ptmsgs_portalcommonmsgs");
          }
      } else
      if (linkType.Equals(NavCategoryType.MANDATORYLINK))
      {
        // (name of mandatory links folder)
        categoryTitle = GetMandatoryLinksFolderName();
      } else
      if (linkType.Equals(NavCategoryType.MYPAGE))
      {
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
        {
          // my pages links
          categoryTitle = m_asOwner.GetString(260, "ptmsgs_portalcommonmsgs");
          }
      } else
      if (linkType.Equals(NavCategoryType.MANDATORYTABS))
      {
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
        {
          // Mandatory Communities
          categoryTitle = m_asOwner.GetString(253, "ptmsgs_portalcommonmsgs");
          }
      } else
      if (linkType.Equals(NavCategoryType.MYCOMMUNITIES))
      {
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
        {
          // My Communities
          categoryTitle = m_asOwner.GetString(252, "ptmsgs_portalcommonmsgs");
          }
      }
      return categoryTitle;
    }
    
    /// <summary>
    /// Get the name of the subsection title; basically, actions for mypage and communities only.
    /// </summary>
    /// <param name="linkType"></param>
    /// <returns>String category name for link title</returns>
    public virtual String GetSubsectionTitle(NavCategoryType linkType, bool bAction)
    {
      String categoryTitle = null;
      // Determine the string title for each subsection
      if (linkType.Equals(NavCategoryType.COMMUNITY))
      {
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS))
        {
          // Community Actions
          if (bAction)
          {
            categoryTitle = m_asOwner.GetString(274, "ptmsgs_portalcommonmsgs");
            }
        }
      } else
      if (linkType.Equals(NavCategoryType.MYPAGE))
      {
        if (GetSubPortalEnabled(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS))
        {
          // My Page Actions
          if (bAction)
          {
            categoryTitle = m_asOwner.GetString(273, "ptmsgs_portalcommonmsgs");
            }
        }
      }
      return categoryTitle;
    }
    
    /// <summary>
    /// Add more when neccessary *
    /// </summary>
    public const int PROPIDTYPE_INT = 0;
    public const int PROPIDTYPE_STRING = 1;
    
    /// <summary>
    /// Creates a PTSortedArrayWrapper from a queryresult
    /// </summary>
    /// <param name="qResult"></param>
    /// <param name="naPropIDs"></param>
    /// <param name="naPropIDType"></param>
    /// <param name="naSorting"></param>
    /// <returns></returns>
    public static PTSortedArrayWrapper SortQueryResult(IPTQueryResult qResult,
     int[] naPropIDs, int[] naPropIDType, int[][] naSorting)
    {
      Object[][] arEntries = new Object[naPropIDs.Length][];
      for (int j2c_index = 0;j2c_index < naPropIDs.Length;j2c_index++)
      {
        arEntries[j2c_index] = new Object[qResult.RowCount()];
      }
      for (int i = 0;i < qResult.RowCount();i++)
      {
        for (int j = 0;j < naPropIDs.Length;j++)
        {
          switch (naPropIDType[j]){
          case PROPIDTYPE_INT:
          arEntries[j][i] = qResult.ItemAsInt(i, naPropIDs[j]);
          break;
          case PROPIDTYPE_STRING:
          arEntries[j][i] = qResult.ItemAsString(i, naPropIDs[j]);
          break;
          }
        }
      }
      PTSortedArrayWrapper arrSortedLinks = new PTSortedArrayWrapper();
      arrSortedLinks.Initialize(naPropIDs, arEntries, naSorting, true);
      return arrSortedLinks;
    }
    //	/**
    //	 * 
    //	 *
    //	 * @param objArrMarkup 
    //	 *
    //	 * @return 
    //	 *
    //	 * @throws Exception 
    //	 */
    //	private HTMLElement ApplyUITransformer(Object[][] objArrMarkup)
    //		throws Exception
    //	{
    //		// invoke the "UI transformer" function -jas
    //		HTMLElement result  = new HTMLElementCollection();
    //		String strRealmName = GetTitleForBanner();
    //		String strPageName  = GetSubtitleForBanner();
    //
    //		GatewayUtils.AddMarkupToElement(m_asOwner, m_ptSession, objArrMarkup,
    //			result, strRealmName, strPageName);
    //
    //		return result;
    //	}
    
    /// <summary>
    /// temp object 
    /// </summary>
    private class NavigationModelTempData
    {
      
      /// <summary>
      /// HTMLElementCollection holding the Header  
      /// </summary>
      public HTMLElementCollection m_headerCollection;
      
      /// <summary>
      /// HTMLElementCollection holding the Footer 
      /// </summary>
      public HTMLElementCollection m_footerCollection;
      
      /// <summary>
      /// Communityinfo object 
      /// </summary>
      public IPTCommunityInfo ptCommunityInfo;
      
      /// <summary>
      /// Mypages queryresult 
      /// </summary>
      public IPTQueryResult ptqrMyPages;
      
      /// <summary>
      /// Header set flag  
      /// </summary>
      public bool m_bHeaderSet = false;
      
      /// <summary>
      /// Footer set flag 
      /// </summary>
      public bool m_bFooterSet = false;
      public int lCurrentCommunityID = 0;
      
      /// <summary>
      /// Sitemapfolderinfo object 
      /// </summary>
      private IPTSiteMapFolderInfo ptSiteMapFolderInfo;
      
      /// <summary>
      /// Subportalinfo object 
      /// </summary>
      private IPTSubPortalInfo ptSubPortalInfo;
      
      /// <summary>
      /// has the subportal and sitemap folder been initialized 
      /// </summary>
      private bool bSubPortalInitialized = false;
      
      /// <summary>
      /// Get the SiteMapFolderInfo 
      /// </summary>
      public virtual IPTSiteMapFolderInfo GetSiteMapFolderInfo(IPTSession ptSession)
      {
        if (!bSubPortalInitialized)
        {
          InitializeSubPortal(ptSession);
        }
        return ptSiteMapFolderInfo;
      }
      
      /// <summary>
      /// Get the SubPortalInfo 
      /// </summary>
      public virtual IPTSubPortalInfo GetSubPortalInfo(IPTSession ptSession)
      {
        if (!bSubPortalInitialized)
        {
          InitializeSubPortal(ptSession);
        }
        return ptSubPortalInfo;
      }
      
      /// <summary>
      /// Initialize the SubPortalInfo and SiteMapFolderInfo. We don't do this in the GetNewTempData
      /// because at that time, the expression engine has not yet run.
      /// </summary>
      /// <param name="ptSession"></param>
      private void InitializeSubPortal(IPTSession ptSession)
      {
        // first, get info about the user; their subportal, etc.
        try
        {
          ptSubPortalInfo = ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
          // try to get the site map folder info; if we fail, we'll just add fake links for now. TODO
          if (ptSubPortalInfo != null)
          {
            int nNavigationLinksID = ptSubPortalInfo.GetMandatoryLinksID();
            if (nNavigationLinksID > 0)
            {
              IPTSiteMapFolderManager ptOM = (IPTSiteMapFolderManager) ptSession.GetSiteMapFolders();
              ptSiteMapFolderInfo = ptOM.CachedOpenSiteMapFolderInfo(nNavigationLinksID);
              } else
            {
              ptSiteMapFolderInfo = null;
            }
          } else
          {
            log.Error("The portal returned a null subportal.");
            ptSiteMapFolderInfo = null;
          }
        }
        catch (Exception e)
        {
          String strName = null;
          int lUserID = -1;
          try
          {
            strName = ptSession.GetSessionInfo().GetCurrentUserName();
            lUserID = ptSession.GetSessionInfo().GetCurrentUserID();
          }
          catch (Exception userException)
          {
            log.Error(userException, "The portal was also not able to access the user name, or user id.");
            }
          log.Error(e, "The portal was not able to access the subportal for user " + strName + " (UserID=" + lUserID + ").");
          }
        bSubPortalInitialized = true;
      }
    }
    
    /// <summary>
    /// This method returns a new temporary data object.  It is called at the beginning
    /// of a new HTTP Request.  This method can perform initialization on the data
    /// object if necessary.
    /// </summary>
    /// <returns>Object the new temporary data object</returns>
    public override Object GetNewTempData()
    {
      NavigationModelTempData ptTempData = new NavigationModelTempData();
      // then get info about the community.  This requires the subportal, which is why we
      // figured that out first.
      try
      {
        int lCurrentCommunityID = CalculateCurCommunityID();
        // Even if communities are disbled, the user profile community needs to work, special case
        if (lCurrentCommunityID == NO_CURRENT_COMMID)
        {
          if (m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
          {
            MyPortalModel mpModel = (MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
            if (null != mpModel)
            {
              if (PT_INTRINSICS.PT_PROFILE_COMMUNITY == mpModel.GetCommunityID())
              {
                lCurrentCommunityID = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
                }
            }
          }
        }
        if (lCurrentCommunityID != NO_CURRENT_COMMID)
        {
          IPTCommunityManager ptOM = (IPTCommunityManager) GetIPTSession().GetCommunities();
          ptTempData.ptCommunityInfo = ptOM.CachedOpenCommunityInfo(lCurrentCommunityID,
           true);
        } else
        {
          ptTempData.ptCommunityInfo = null;
        }
        ptTempData.lCurrentCommunityID = lCurrentCommunityID;
      }
      catch (Exception e)
      {
        log.Error(e, "The portal was not able to access community info.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(649, "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(650,
         "ptmsgs_portalcommonmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        // DCA - returns null so that next time it calls GetTempData a new one will be made	
        return null;
      }
      try
      {
        ptTempData.ptqrMyPages = (IPTQueryResult) GetIPTSession().GetSessionInfo().GetCurrentMyPages();
        }
      catch (Exception e)
      {
        log.Error(e, "The portal was not able to access the current mypage.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(651, "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(652,
         "ptmsgs_portalcommonmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      try
      {
        ptTempData.m_headerCollection = new HTMLElementCollection();
        ptTempData.m_footerCollection = new HTMLElementCollection();
      }
      catch (Exception e)
      {
        log.Error("GetNewTempData ALLOCATION ERROR: Cannot instantiate banner or footer HTMLElementCollection.");
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         e, m_asOwner.GetString(653, "ptmsgs_portalcommonmsgs"), m_asOwner.GetString(654,
         "ptmsgs_portalcommonmsgs"));
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
      return ptTempData;
    }
    
    /// <summary>
    /// Returns true if this page should show the "Inside this Community" header and
    /// sub- and related communitites.
    /// Should be true for all pages except the user profile community.
    /// </summary>
    /// <returns>true if the page should show community nav links</returns>
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#IsCurCommunityProfile()"></seealso>
    public virtual bool ShowCommunityNavigation()
    {
      return (GetCurCommunityID() != PT_INTRINSICS.PT_PROFILE_COMMUNITY);
      }
    
    /// <seealso cref="com.plumtree.portalpages.common.uiparts.INavigationModelRO#CanJoinCurCommunity()"></seealso>
    public virtual bool CanJoinCurCommunity()
    {
      return CheckAccessLevel(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
    }
    
    /// <summary>
    /// Gets the content for an intrinsic portlet, or generates properly beautified error results
    /// Used only for headers and footers, and *only* used in NavigationModel and MyPortalModel - not for
    /// standard usage, although it will work well enough for those cases.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <param name="nPortletID"></param>
    /// <param name="objArrMarkup"></param>
    /// <param name="ptGadget"></param>
    /// <param name="objAppdataState"></param>
    /// <param name="gadgetName"></param>
    /// <returns>HTMLElement to be displayed</returns>
    public virtual HTMLElement GetIntrinsicPortletContentWithErrorHandling(int nPortletIndex,
     int nPortletID, Object[][] objArrMarkup, IPTGadget ptGadget, IPTState objAppdataState,
     String gadgetName)
    {
      try
      {
        // Get HTML for intrinsic portlet
        return GetIntrinsicPortletContent(nPortletIndex, nPortletID, objArrMarkup,
         ptGadget, objAppdataState);
      }
      catch (Exception ex)
      {
        // Build an error table with gadget's name
        HTMLTable table = new HTMLTable();
        HTMLTableRow row = new HTMLTableRow();
        HTMLTableCell cell = new HTMLTableCell();
        table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        table.AddInnerHTMLElement(row);
        row.SetStyleClass(PTStyleClass.PLATPORTLET_LIGHT_BG);
        row.AddInnerHTMLElement(cell);
        HTMLDiv div = new HTMLDiv();
        cell.AddInnerHTMLElement(div);
        cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
        div.SetStyleClass(PTStyleClass.ALERT_TEXT);
        XPException ex2 = new XPException(ex);
        String strErrorComment = ex2.GetStackTrace();
        String strErrorDescription = XPResourceManager.FormatMessage(m_asOwner.GetString(1527,
         "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(gadgetName));
        Object[] aoRecommenedActions = new Object[2];
        aoRecommenedActions[0] = m_asOwner.GetString(1596, "ptmsgs_portalbrowsingmsgs");
        aoRecommenedActions[1] = m_asOwner.GetString(1595, "ptmsgs_portalbrowsingmsgs");
        DisplayPortletError(div, strErrorDescription, strErrorComment, aoRecommenedActions);
        return table;
      }
    }
    
    /// <summary>
    /// Displays portlet error for intrinsic portlet.
    /// </summary>
    /// <param name="_element"></param>
    /// <param name="_strErrorDescription"></param>
    /// <param name="_strErrorComment"></param>
    /// <param name="_aoRecommendedActions"></param>
    private void DisplayPortletError(HTMLElement _element, String _strErrorDescription,
     String _strErrorComment, Object[] _aoRecommendedActions)
    {
      HTMLBr br = new HTMLBr();
      HTMLP myParagraph = new HTMLP();
      _element.AddInnerHTMLElement(myParagraph);
      HTMLSpan mySpan = new HTMLSpan();
      myParagraph.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
      try
      {
        PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ERROR);
        HTMLImg img = (HTMLImg) myConstruct.GetHTMLElement();
        img.SetAlt(m_asOwner.GetString(1592, "ptmsgs_portalbrowsingmsgs"));
        mySpan.AddInnerHTMLElement(img);
      }
      catch (Exception e)
      {
        log.Error(e, "DisplayPortletError: Failed to create error image. " + e.Message);
        }
      mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE + m_asOwner.GetString(1592,
       "ptmsgs_portalbrowsingmsgs"));
      myParagraph.AddInnerHTMLElement(br);
      mySpan = new HTMLSpan();
      myParagraph.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_DESCRIPTION);
      mySpan.AddInnerHTMLString(_strErrorDescription);
      myParagraph = new HTMLP();
      _element.AddInnerHTMLElement(myParagraph);
      mySpan = new HTMLSpan();
      myParagraph.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_SUBTITLE);
      mySpan.AddInnerHTMLString(m_asOwner.GetString(1593, "ptmsgs_portalbrowsingmsgs"));
      for (int i = 0;i < _aoRecommendedActions.Length;i++)
      {
        myParagraph.AddInnerHTMLElement(br);
        myParagraph.AddInnerHTMLString("&bull;" + CommonHTMLStrings.SPACE);
        if (null != _aoRecommendedActions[i])
        {
          if (_aoRecommendedActions[i] is String)
          {
            myParagraph.AddInnerHTMLString(XPConvert.ToString(_aoRecommendedActions[i]));
            } else
          {
            myParagraph.AddInnerHTMLElement((HTMLElement) _aoRecommendedActions[i]);
            }
        }
      }
      HTMLComment commentError = new HTMLComment(_strErrorComment);
      _element.AddInnerHTMLElement(commentError);
    }
    
    /// <summary>
    /// Register model, view, and control for intrinsic portlet.  Initialize
    /// portlet with the portletID, the IPTMyPortal object, and the
    /// AppDataState object.
    /// </summary>
    /// <param name="_strPortletClass">Class identifier for portlet</param>
    /// <param name="_strStorageName">Storage name for portlet</param>
    /// <param name="_nPortletIndex">Portlet index</param>
    /// <throws>
    /// XPException Exception thrown if model, view, or control is not
    /// registered successfully.
    /// </throws>
    private void SetupIntrinsicPortlet(String _strPortletClass, String _strStorageName,
     int _nPortletIndex, int nPortletID, IPTGadget ptPortlet, IPTState objAppDataObject)
    {
      log.Debug("NavigationModel::SetupIntrinsicPortlet (intrinsic header or footer)");
      // Register Model
      if (!m_asOwner.GetModelExists(_strStorageName))
      {
        bool bModelRegistered = m_asOwner.RegisterModel(_strPortletClass,
         _strStorageName);
        if (!bModelRegistered)
        {
          log.Error("NavigationModel::SetupIntrinsicPortlet (intrinsic header or footer). " + m_asOwner.GetString(676,
           "ptmsgs_portalbrowsingmsgs"));
          throw new XPException(m_asOwner.GetString(676, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      IntrinsicPortletModel iPortletModel = (IntrinsicPortletModel) m_asOwner.GetModel(_strStorageName);
      // Register Section
      if (!m_asOwner.GetViewExists(_strStorageName))
      {
        bool bViewRegistered = m_asOwner.RegisterView(_strPortletClass, _strStorageName,
         iPortletModel);
        if (!bViewRegistered)
        {
          log.Error("NavigationModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(677,
           "ptmsgs_portalbrowsingmsgs"));
          throw new XPException(m_asOwner.GetString(677, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      // Register Control
      if (iPortletModel.ControlExists())
      {
        if (!m_asOwner.GetControlExists(_strStorageName))
        {
          bool bControlRegistered = m_asOwner.RegisterControl(_strPortletClass,
           _strStorageName, iPortletModel);
          if (!bControlRegistered)
          {
            log.Error("NavigationModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(675,
             "ptmsgs_portalbrowsingmsgs"));
            throw new XPException(m_asOwner.GetString(675, "ptmsgs_portalbrowsingmsgs"));
            }
        }
      }
      // TODOCR - DonH: presumably this only needs to get set if we are initializing
      // this for the first time.  In fact, if the model for this portlet does not
      // exist, then we can assume that the view and control don't either, and put
      // this all in a single if statement for initialization.  This may be useful
      // because this method gets called once for every page hit.
      // Initialize portlet model
      // DAP note: No MyPortalModel object necessary as it is not used
      iPortletModel.InitPortlet(null, objAppDataObject, ptPortlet, nPortletID);
      }
    // TODOCR - DonH: It looks like there is currently no way to clean up intrinsic
    // portlets from the myportal space until the entire space is cleaned up.  This
    // means that if an intrinsic portlet is viewed once at the beginning of the
    // session, and then the user browses pages without any intrinsic portlets for
    // the rest of their session, the model, view, and control for that intrinsic
    // portlet will remain on the ActivitySpace for the rest of the session.  This
    // use case may or may not be common, but it's worth looking into since these
    // models contain IPTObjects.  Perhaps those could get garbage collected if
    // the portlet isn't used for a while?
    
    /// <summary>
    /// Retrieves HTML for intrinsic portlet.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <param name="objArrMarkup"></param>
    /// <returns></returns>
    private HTMLElement GetIntrinsicPortletContent(int nPortletIndex, int nPortletID,
     Object[][] objArrMarkup, IPTGadget ptGadget, IPTState objAppdataState)
    {
      String strPortletClass = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0];
      String strStorageName = strPortletClass + nPortletID;
      // We are deliberately breaking the rules for models and views here.  Cast RO interface
      // back to model and call setup method from model. -jic
      SetupIntrinsicPortlet(strPortletClass, strStorageName, nPortletIndex,
       nPortletID, ptGadget, objAppdataState);
      IntrinsicPortletView iPortletView = (IntrinsicPortletView) m_asOwner.GetView(strStorageName);
      return iPortletView.Display();
    }
  }
}