using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// This is the base class for all AS's with a banner.
  /// </summary>
  /// <author>RobZ</author>
  /// <author>DavidP</author>
  public abstract class PlumtreeAS : AFormAS,ITypes
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.uiparts.PlumtreeAS");
    protected const String REGISTERED_VIEW_SESSION_ATTRIBUTE = "REGISTERED_VIEW";
    private String strLayoutStyleClass = null;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#GetName()"></seealso>
    public abstract override String GetName();
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)">AS that extends PlumtreeAS must call this super method if overridden to check for changed navigation scheme</seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IFormAS#DisplayCommonJavaScript()"></seealso>
    public override HTMLScriptCollection DisplayCommonJavaScript()
    {
      HTMLScriptCollection scripts = base.DisplayCommonJavaScript();
      return scripts;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      // Navigation Model
      RegisterModel(NavigationModel.STR_MVC_CLASS_NAME);
      IModel navModel = GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      // Banner Section
      RegisterView(DefaultHeaderView.STR_MVC_CLASS_NAME, navModel);
      RegisterView(DefaultFooterView.STR_MVC_CLASS_NAME, navModel);
      // Navigation Section
      RegisterView(PlumtreeTopBarView.STR_MVC_CLASS_NAME, navModel);
      RegisterControl(NavigationControl.STR_MVC_CLASS_NAME, navModel);
      // Error Model
      RegisterModel(ErrorModel.STR_MVC_CLASS_NAME);
      IModel errorModel = GetModel(ErrorModel.STR_MVC_CLASS_NAME);
      RegisterView(ErrorView.STR_MVC_CLASS_NAME, errorModel);
      RegisterControl(ErrorControl.STR_MVC_CLASS_NAME, errorModel);
      int nCurrentScheme;
      if (GetAccessStyle() == AccessStyles.STANDARD)
      {
        //((IPTSession) GetUserSession()).GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetNavigationScheme();
        nCurrentScheme = NavTypeConstants.NAV_TYPE_ID_DEFAULT;
      } else
      {
        nCurrentScheme = NavTypeConstants.NAVTYPE_ID_508COMPLIANT;
      }
      INavTypes curNavType = GetNavType(nCurrentScheme);
      IXPEnumerator navAreas = NavAreaHelper.INSTANCE.GetCategoryTypes();
      if (navAreas != null)
      {
        // For each page area within this pluggable nav, 
        // register the view with the AS
        while (navAreas.MoveNext())
        {
          String pView;
          // Register current scheme
          pView = NavAreaHelper.INSTANCE.GetNavAreaViewClassName(curNavType,
           (NavAreaEnum) navAreas.GetCurrent());
          if (pView != null)
          {
            if (!this.GetViewExists(pView))
            {
              RegisterView(pView, navModel);
            }
          }
        }
      }
      ((NavigationModel) navModel).SetRegisteredViewNavScheme(nCurrentScheme);
      }
    
    /// <summary>
    /// Re-Initialize the Activity Space in case models are holding on to an old session.
    /// </summary>
    public override void ReInit()
    {
      NavigationModel navModel = (NavigationModel) GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      navModel.ReInit(this);
    }
    
    /// <summary>
    /// This method gets the correct navtype for the nav scheme,
    /// correcting for Macintosh users.
    /// </summary>
    /// <param name="int">nNavScheme the desired navigation scheme.</param>
    /// <returns>INavTypes the appropriate navigation scheme.</returns>
    public virtual INavTypes GetNavType(int nNavScheme)
    {
      INavTypes navType = NavManager.INSTANCE.GetNavType(nNavScheme);
      // Use default schema if stored navschema is invalid.
      if (null == navType)
      {
        if (log.IsWarnEnabled())
        {
          log.Warn("Invalid navigation scheme: " + nNavScheme + " Using default navigation.");
          }
        navType = NavManager.INSTANCE.GetNavType(NavTypeConstants.NAV_TYPE_ID_DEFAULT);
        }
      return navType;
    }
    public virtual String GetStrLayoutStyleClass()
    {
      return strLayoutStyleClass;
    }
    public virtual void SetStrLayoutStyleClass(String strLayoutStyleClass)
    {
      this.strLayoutStyleClass = strLayoutStyleClass;
    }
  }
}