using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portaluiinfrastructure.application.varpacks;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using com.plumtree.portaluiinfrastructure.layout;
using com.plumtree.portaluiinfrastructure.navtype;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.marshalers;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.activityspace.utils;
using com.plumtree.uiinfrastructure.common;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.helpers;
// Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// Main display page for the Portal product.
  /// </summary>
  /// <author>RobZ</author>
  /// <author>DavidP</author>
  /// <author>BridgetF</author>
  /// <author>NaveenP</author>
  /// <author>michaeld</author>
  public abstract class PlumtreeDP : AFormDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.uiparts.PlumtreeDP");
    public const String JAVASCRIPT_INITIALIZE_EVENTS = "InitializeEvents();";
    
    /// <summary>
    /// Whether or not to display the main form 
    /// </summary>
    protected bool m_bAddMainForm = false;
    // default base variables for pluggable nav; overridable by settings 
    // in NavigationSettings.xml	
    protected int m_nTableSpacing = 10;
    protected int m_nLeftWidth = 100;
    protected int m_nRightWidth = 100;
    protected int m_nLeftWidthAlone = 200;
    protected int m_nRightWidthAlone = 200;
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#GetName()"></seealso>
    public abstract override String GetName();
    
    /// <summary>
    /// This string will be added as the subtitle in a banner that has a
    /// subtitle. For example, if you were on a my page named "Green Page", then
    /// return "Green Page" here.
    /// </summary>
    /// <returns>SubHeader</returns>
    public abstract String GetSubtitleForBanner();
    
    /// <summary>
    /// This string will be added as the title in a banner that has a title. For
    /// example, if this is a my page, return "My Pages" here.
    /// If you think you don't need a title, then you need to seriously rethink
    /// why you are inheriting from PlumtreeDP.  Because the WHOLE POINT of
    /// PlumtreeDP is that it has a banner.
    /// </summary>
    /// <returns>Header</returns>
    public abstract String GetTitleForBanner();
    
    /// <summary>
    /// This is a helper method that all classes that inherit from PlumtreeDP
    /// need to implement.  The method should add whatever HTML the child class
    /// wants to display to the body argument.  The parent class will then add
    /// that HTML to the HTMLPage after filling in the banner and navigation.
    /// </summary>
    /// <returns>HTML of the page</returns>
    /// <throws>HTMLException </throws>
    public abstract override HTMLElement PageDisplay();
    
    /// <summary>
    /// This method is also used by the BasePage layout NavArea tag.
    /// </summary>
    /// <returns>Returns NavScheme.</returns>
    public virtual int GetNavScheme()
    {
      int nScheme = ((INavigationModelRO) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME)).GetSubPortalNavScheme();
      if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
      {
        nScheme = NavTypeConstants.NAVTYPE_ID_508COMPLIANT;
      }
      // make sure the navscheme we are going to use is the one that is registered
      RegisterNavScheme(nScheme);
      return nScheme;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IDisplayPage#display()"></seealso>
    public override void Display(IWebData pageData)
    {
      // initialize all portlet content for the page
      ((NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME)).InitializePortletContent();
      if (m_asOwner.GetIsInPlaceRefreshDisplayOn())
      {
        try
        {
          HTMLElement myElement = PartialContentDisplay();
          pageData.SetData(myElement);
        }
        catch (Exception ex)
        {
          log.Error(ex, "Error displaying text: " + ex.Message);
          throw new XPException("Error displaying text: " + ex.Message, ex);
          }
        finally
        {
          // reset the in place refresh flag so that future hits
          // will be displayed normally.  this flag is normally 
          // set to true via an in place refresh repost.
          m_asOwner.SetIsInPlaceRefreshDisplayOn(false);
        }
      } else
      {
        HTMLElement element = null;
        NavigationModel navModel = (NavigationModel) GetOwner().GetModel(NavigationModel.STR_MVC_CLASS_NAME);
        if ((navModel != null) && (navModel.IsCommunityPage()) && (navModel.GetCurCommunityID() == PT_INTRINSICS.PT_PROFILE_COMMUNITY))
        {
          element = DisplayLayout(Layouts.PROFILE_PAGE);
        } else
        {
          element = DisplayLayout(Layouts.BASE_PAGE);
        }
        if (null != element)
        {
          pageData.SetData(element);
          // The page has been successfully displayed using layout mode.
          return;
        }
        // BEGIN: Temp code for deciding navigation
        // Updated: Force to nav schema zero when in low bandwidth or 508 mode
        int nNavScheme = GetNavScheme();
        // END: Temp code for deciding navigation
        // Create an HTMLPage
        HTMLPage myPage = new HTMLPage();
        // Set the HTMLPage as the data to be sent to the browser.
        pageData.SetData(myPage);
        if (GetOwner().GetAccessStyle() == AccessStyles.SECTION_508)
        {
          myPage.SetDo508Checking(true);
        }
        // Important note - We MUST construct the body before constructing the head.
        // This is because intrinsic portlets are dynamically registered with the activity
        // space when the body is constructed.  If the portlet has any Javascript, then
        // it must be added to the head, but you don't know if there's any Javascript to
        // add until the body is generated. Of course the head should still be added to
        // the page before the body as usual. -jic
        // Create body
        HTMLBody myBody = DisplayBody(nNavScheme);
        // Create head
        HTMLHead myHead = DisplayHead(nNavScheme);
        // Add the head to the page
        myPage.SetHead(myHead);
        // Add the body to the page
        myPage.SetBody(myBody);
      }
    }
    
    /// <summary>
    /// This method checks whether or not the page should be displayed using layout
    /// mode and then displays it.
    /// </summary>
    /// <param name="_pageData"></param>
    /// <returns>The HTML output of the layout, or null if the layout was disabled.</returns>
    protected virtual HTMLElement DisplayLayout(Layouts layout)
    {
      HTMLElement element = null;
      // The base page and profile page are the only main pages (for tag processing)
      bool bMainPage = ((layout == Layouts.BASE_PAGE) || (layout == Layouts.PROFILE_PAGE));
      // Layout ID of -1 means layouts are not enabled for this page (or globally).
      int nLayoutID = LayoutService.getChooserInstance().GetLayoutWebService(layout,
       m_asOwner);
      // Only use layouts for standard pages, not 508 or low bandwidth.
      if ((nLayoutID != -1) && (GetOwner().GetAccessStyle() == AccessStyles.STANDARD))
      {
        log.Info("Displaying page layout " + layout.ToString() + " using Page Layout with ID " + nLayoutID);
        // Get processed HTMLElement from layout
        element = DisplayLayout(nLayoutID, bMainPage);
      }
      // Bug fix 8751519 - PORTLET SELECTION FLY OUT EDITOR DOES NOT APPEAR UNDER CERTAIN CONDITIONS. 
      // we have already determined above that layout mode isn't supported in current user's experience definition, but we are checking
      // the special case if a user belongs to an exp def that doesn't support layout mode, but has navigated into a community
      // that supports it, layout mode SHOULD be enabled for that request while in the community.
      // Checking if layouts are globally disabled if we're trying to load the Portlet Selection layout.
      if ((nLayoutID == -1) && (layout == Layouts.PORTLET_SELECTION))
      {
        //getting the web service id for the layout so we can load the layout requested.
        int backupLayoutID = LayoutService.getChooserInstance().GetLayoutWebServiceBackUp(layout,
         m_asOwner);
        log.Info("Displaying page layout " + layout.ToString() + " using Page Layout with ID " + nLayoutID);
        // Get processed HTMLElement from layout
        element = DisplayLayout(backupLayoutID, bMainPage);
      }
      return element;
    }
    
    /// <summary>
    /// This helper method displays a particular layout from a web service.
    /// </summary>
    /// <param name="_nWebServiceID">The webservice to display.</param>
    /// <param name="_bMainPage">
    /// whether or not to process the head element for a main page.
    /// This should only be true for one layout per page.
    /// </param>
    /// <returns>the HTML output of displaying the layout.</returns>
    protected virtual HTMLElement DisplayLayout(int _nWebServiceID, bool _bMainPage)
    {
      try
      {
        ILayoutManager manager = LayoutService.getManagerInstance();
        Object[][] markup = manager.GetLayout(_nWebServiceID, m_asOwner);
        ILayoutDisplay display = LayoutService.getFactoryInstance().CreateDisplay();
        if (_bMainPage)
        {
          return display.ProcessMainPageLayout(markup, m_asOwner);
        } else
        {
          return display.ProcessLayout(markup, m_asOwner);
        }
      }
      catch (Exception e)
      {
        if (_bMainPage)
        {
          // DCA - could not display the main page for some reason, switch to classic mode by returning null
          log.Error(e, "PlumtreeDP:DisplayLayout Could not display main page. Switching to classic mode. Please Check the path on webservice with Id " + _nWebServiceID + " and make sure it is correct.");
          return null;
        } else
        {
          throw PTException.GetInstance(e);
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()"></seealso>
    public override String GetFormTitle()
    {
      return GetTitleForBanner();
    }
    
    /// <summary>
    /// Set the AddMainForm member variable. Set it to true if you want to have
    /// the form tag and have the postToSelf javascript automatically printed out.
    /// </summary>
    /// <param name="_bAddMainForm"></param>
    public virtual void SetAddMainForm(bool _bAddMainForm)
    {
      m_bAddMainForm = _bAddMainForm;
    }
    
    /// <returns>
    /// whether or not to add the form tag and have the postToSelf
    /// javascript automatically printed out.
    /// </returns>
    public virtual bool GetAddMainForm()
    {
      return m_bAddMainForm;
    }
    
    /// <summary>
    /// Constructs the body for the Plumtree display page.  Note that this
    /// function must be called prior to calling DisplayHead(), because of the
    /// special case of intrinsic portlets on the MyPortalDP.  Intrinsic
    /// portlets view registration, which occurs in PageDisplay(), must occur
    /// prior to Javascript generation, which occurs during
    /// DisplayJavaScriptFromChild().
    /// </summary>
    /// <param name="nNavScheme">Navigation scheme ID</param>
    /// <returns>HTMLBody			</returns>
    /// <seealso cref="NavTypeConstants"></seealso>
    protected virtual HTMLBody DisplayBody(int nNavScheme)
    {
      // Calculate whether or not to display javascript.
      bool bNoJavascript = !(GetUseJavascript());
      bool displayTopBar = true;
      bool displayHeader = true;
      bool displayFooter = true;
      NavigationModel navModel = (NavigationModel) GetOwner().GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      int pageID = navModel.GetCurPageID();
      String loginName = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserLoginName();
      HTMLBody myBody = new HTMLBody();
      {
        // Every page's body tag gets a "unique" class attribute, based upon user's login name.
        String bodyStyleString = TaskAPIUIHTML.HTMLEncode(PTStyleClass.GetClassStringForPageUser(loginName));
        // Community pages also get a unique class attribute, based upon community id.
        if (navModel.IsCommunityPage())
        {
          String commID = XPConvert.ToString(navModel.GetCurCommunityID());
          bodyStyleString+=" " + PTStyleClass.GetClassStringForCommunity(commID);
          }
        myBody.SetStyleClass(bodyStyleString);
      }
      myBody.SetMarginWidth("0");
      myBody.SetMarginHeight("0");
      myBody.SetTopMargin("0");
      myBody.SetLeftMargin("0");
      /* portalContentDiv is one of two child nodes contained within the body tag.
       * All portal content is displayed in this div.
       *
       * This div will be assigned a unique id attribute for mypages and community pages
       * which have object IDs.
       */
       
      HTMLDiv portalContentDiv = (HTMLDiv) myBody.InsertInnerHTMLElement(new HTMLDiv());
      portalContentDiv.SetStyleClass(PTStyleClass.PORTAL_CONTENT);
      /* extensionDiv exists as a parallel node to portalContentDiv,
       * providing an empty (and by default hidden) region which can be customized
       * as desired.  The Plumtree portal does not ever make use of this area.
       *
       * This div will be assigned a unique id attribute for mypages and community pages
       * which have object IDs.
       */
       
      HTMLDiv extensionDiv = (HTMLDiv) myBody.InsertInnerHTMLElement(new HTMLDiv());
      extensionDiv.SetStyleClass(PTStyleClass.EXTERNAL_CONTENT);
      if (pageID != NavigationModel.NO_CURRENT_PAGEID)
      {
        portalContentDiv.SetID(PTStyleID.GetIDStringForPortalContent(pageID));
        extensionDiv.SetID(PTStyleID.GetIDStringForExternalContent(pageID));
        // Every page's body tag gets a "unique" id attribute, based on page id.
        myBody.SetID(PTStyleID.GetIDStringForPage(pageID));
      }
      //      Remove dom0 registration, handlers will be registered by new jscomponent version
      //		if (!bNoJavascript)
      //		{
      //			String strPCCfunction = "document.PCC.RaiseWindowEvent(event);";
      //			myBody.SetOnActivate(strPCCfunction);
      //			myBody.SetOnAfterPrint(strPCCfunction);
      //			myBody.SetOnBeforeActivate(strPCCfunction);
      //			myBody.SetOnBeforeUnload(strPCCfunction);
      //			myBody.SetOnBlur(strPCCfunction);
      //			myBody.SetOnControlSet(strPCCfunction);
      //			myBody.SetOnDeactivate(strPCCfunction);
      //			myBody.SetOnError(strPCCfunction);
      //			myBody.SetOnFocus(strPCCfunction);
      //			myBody.SetOnHelp(strPCCfunction);
      //			myBody.SetOnLoad(strPCCfunction);
      //			myBody.SetOnResize(strPCCfunction);
      //			myBody.SetOnResizeEnd(strPCCfunction);
      //			myBody.SetOnResizeStart(strPCCfunction);
      //			myBody.SetOnUnload(strPCCfunction);
      //		}
      HTMLTableCell tCell = null;
      INavTypes navType = ((PlumtreeAS) m_asOwner).GetNavType(nNavScheme);
      // determine if headers, footers, topbar to be set		
      displayTopBar = GetPlugNavFeature(navType, NavFeatureEnum.TOPBAR);
      displayHeader = GetPlugNavFeature(navType, NavFeatureEnum.HEADER);
      displayFooter = GetPlugNavFeature(navType, NavFeatureEnum.FOOTER);
      OverrideNavSettingsFromVarPack(navType);
      // Setting banner for non community pages; this will set 508 or the default header or 
      // footer, as necessary.
      if (displayHeader && !navModel.GetHeaderHasBeenSet())
      {
        HTMLElement banner = navModel.GetSubportalBanner();
        navModel.SetHeaderElement(true, banner);
      } else
      if (!displayHeader)
      {
        navModel.SetHeaderElement(true, null);
      }
      if (displayFooter && !navModel.GetFooterHasBeenSet())
      {
        HTMLElement footer = navModel.GetSubportalFooter();
        navModel.SetFooterElement(true, footer);
      } else
      if (!displayFooter)
      {
        navModel.SetFooterElement(true, null);
      }
      // Pretty bad if we can't even get the default nav
      if (navType == null)
      {
        log.Error("Fatal error, unable to load default navigation: " + NavTypeConstants.NAV_TYPE_ID_DEFAULT + "Pluggable navigation module incorrectly installed or configured.");
        }
      if (!bNoJavascript)
      {
        String strOnLoad = GetOnLoad();
        if (null != strOnLoad)
        {
          myBody.SetOnLoad(strOnLoad);
        }
      }
      // get the pluggable views
      IView abovebodyView = null;
      IView leftView = null;
      IView rightView = null;
      IView belowbodyView = null;
      IView abovebannerView = null;
      IView belowbannerView = null;
      IView abovefooterView = null;
      IView belowfooterView = null;
      IView topbarView = null;
      try
      {
        abovebodyView = GetPlugNav(navType, NavAreaEnum.ABOVEBODY);
        leftView = GetPlugNav(navType, NavAreaEnum.LEFTOFBODY);
        rightView = GetPlugNav(navType, NavAreaEnum.RIGHTOFBODY);
        belowbodyView = GetPlugNav(navType, NavAreaEnum.BELOWBODY);
        abovebannerView = GetPlugNav(navType, NavAreaEnum.ABOVEBANNER);
        belowbannerView = GetPlugNav(navType, NavAreaEnum.BELOWBANNER);
        abovefooterView = GetPlugNav(navType, NavAreaEnum.ABOVEFOOTER);
        belowfooterView = GetPlugNav(navType, NavAreaEnum.BELOWFOOTER);
        topbarView = GetPlugNav(navType, NavAreaEnum.TOPBAR);
      }
      catch (Exception e)
      {
        HandleNavCrash(false, myBody, "topbar view error", e);
      }
      // build the body using the pluggable views
      // always have top bar view
      // unless it's been turned off by the navigation, of course
      if (displayTopBar)
      {
        try
        {
          // retrieve the topbar element
          if (topbarView != null)
          {
            //flush topbar to improve perception of page loading
            //	These lines are commented out until the Interpreter code
            //	is written to deal with flushing. -btg
            //				topBarElement.SetFlushAfterDisplay( true );
            //				topBarElement.SetPauseAfterDisplay( true );
            HTMLElement topBarElement = topbarView.Display();
            portalContentDiv.AddInnerHTMLElement(topBarElement);
          }
        }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "topbar view error", e);
        }
      }
      // above banner
      if (abovebannerView != null)
      {
        try
        {
          portalContentDiv.AddInnerHTMLElement(abovebannerView.Display());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "above banner view error", e);
        }
      }
      // banner
      if (displayHeader)
      {
        try
        {
          portalContentDiv.AddInnerHTMLElement(navModel.GetHeaderElement());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "banner error", e);
        }
      }
      // below banner
      if (belowbannerView != null)
      {
        try
        {
          portalContentDiv.AddInnerHTMLElement(belowbannerView.Display());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "below banner view error", e);
        }
      }
      // MAIN PAGE BODY AREA WITH TOP, LEFT, RIGHT, BOTTOM AND CENTER
      // The body area with above+below is a nested table
      // everything goes into this one tRow
      HTMLTable tOuter = new HTMLTable();
      tOuter.SetID("outerTable");
      HTMLTableRow tRow = new HTMLTableRow();
      portalContentDiv.AddInnerHTMLElement(tOuter);
      tOuter.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      tOuter.SetBorder(CommonHTMLStrings.ZERO);
      tOuter.SetCellSpacing(XPConvert.ToString(m_nTableSpacing));
      tOuter.SetCellPadding(CommonHTMLStrings.ZERO);
      tOuter.AddInnerHTMLElement(tRow);
      if (bNoJavascript)
      {
        tOuter.SetSummary("Portal");
      }
      // left hand navigation
      HTMLTableCell leftNavCell = null;
      if (leftView != null)
      {
        try
        {
          HTMLElement leftHTML = leftView.Display();
          if (leftHTML != null)
          {
            // Left hand cell spans multiple rows depending on other views
            // NOTE: this means all other rows should only specify two cells
            leftNavCell = new HTMLTableCell();
            leftNavCell.SetVAlign(CommonHTMLStrings.TOP);
            leftNavCell.SetAlign(CommonHTMLStrings.LEFT);
            leftNavCell.AddInnerHTMLElement(leftHTML);
            tRow.AddInnerHTMLElement(leftNavCell);
          }
        }
        catch (Exception e)
        {
          HandleNavCrash(true, myBody, "left of body view error", e);
        }
      }
      // main body in nested table ("inner")
      HTMLTable tInner = new HTMLTable();
      tInner.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      tInner.SetBorder(CommonHTMLStrings.ZERO);
      tInner.SetCellSpacing(CommonHTMLStrings.ZERO);
      tInner.SetCellPadding(CommonHTMLStrings.ZERO);
      tCell = new HTMLTableCell();
      tCell.SetVAlign(CommonHTMLStrings.TOP);
      tCell.SetAlign(CommonHTMLStrings.LEFT);
      tCell.AddInnerHTMLElement(tInner);
      tRow.AddInnerHTMLElement(tCell);
      // above body (note use of inner table)
      if (abovebodyView != null)
      {
        try
        {
          HTMLElement abovebodyHTML = abovebodyView.Display();
          if (abovebodyHTML != null)
          {
            HTMLTableRow tInnerRow = new HTMLTableRow();
            tCell = new HTMLTableCell();
            tCell.SetVAlign(CommonHTMLStrings.TOP);
            tCell.SetAlign(CommonHTMLStrings.LEFT);
            tCell.AddInnerHTMLElement(abovebodyHTML);
            tInnerRow.AddInnerHTMLElement(tCell);
            tInner.AddInnerHTMLElement(tInnerRow);
          }
        }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "top of body view error", e);
        }
      }
      // MAIN BODY ROW
      // note use of inner nested table added to outer row
      {
        HTMLTableRow tInnerRow = new HTMLTableRow();
        tCell = new HTMLTableCell();
        tCell.SetVAlign(CommonHTMLStrings.TOP);
        tCell.SetAlign(CommonHTMLStrings.LEFT);
        // Placeholder for the error view
        HTMLElementCollection errorView = new HTMLElementCollection();
        tCell.AddInnerHTMLElement(errorView);
        // main body
        HTMLElementCollection myHTMLBeforeForm = DisplayHTMLBeforeForm();
        if (null != myHTMLBeforeForm)
        {
          tCell.AddInnerHTMLElement(myHTMLBeforeForm);
        }
        if (m_bAddMainForm)
        {
          tCell.AddInnerHTMLElement(DisplayForm());
        } else
        {
          tCell.AddInnerHTMLElement(PageDisplay());
          String strStyleClass = ((PlumtreeAS) m_asOwner).GetStrLayoutStyleClass();
          if (null != strStyleClass)
          {
            tOuter.SetStyleClass(strStyleClass);
          }
        }
        // generate the error view after the main page so we can catch
        // errors from displaying the page.	
        try
        {
          errorView.AddInnerHTMLElement(GetOwner().GetView(ErrorView.STR_MVC_CLASS_NAME).Display());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "error section error", e);
        }
        tInnerRow.AddInnerHTMLElement(tCell);
        tInner.AddInnerHTMLElement(tInnerRow);
      }
      // below body navigation (to inner table)
      if (belowbodyView != null)
      {
        try
        {
          HTMLElement belowbodyHTML = belowbodyView.Display();
          if (belowbodyHTML != null)
          {
            HTMLTableRow tInnerRow = new HTMLTableRow();
            tCell = new HTMLTableCell();
            tCell.SetVAlign(CommonHTMLStrings.TOP);
            tCell.SetAlign(CommonHTMLStrings.LEFT);
            tCell.AddInnerHTMLElement(belowbodyHTML);
            tInnerRow.AddInnerHTMLElement(tCell);
            tInner.AddInnerHTMLElement(tInnerRow);
          }
        }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "bottom of body view error", e);
        }
      }
      // right hand navigation (added to outer row)
      HTMLTableCell rightNavCell = null;
      if (rightView != null)
      {
        try
        {
          HTMLElement rightHTML = rightView.Display();
          if (rightHTML != null)
          {
            rightNavCell = new HTMLTableCell();
            rightNavCell.SetVAlign(CommonHTMLStrings.TOP);
            rightNavCell.SetAlign(CommonHTMLStrings.LEFT);
            rightNavCell.AddInnerHTMLElement(rightHTML);
            tRow.AddInnerHTMLElement(rightNavCell);
          }
        }
        catch (Exception e)
        {
          HandleNavCrash(true, myBody, "right of body view error", e);
        }
      }
      // check to see if cells are null
      if (leftNavCell != null)
      {
        if (rightNavCell != null)
        {
          leftNavCell.SetWidth(XPConvert.ToString(m_nLeftWidth));
        } else
        {
          leftNavCell.SetWidth(XPConvert.ToString(m_nLeftWidthAlone));
        }
      }
      if (rightNavCell != null)
      {
        if (leftNavCell != null)
        {
          rightNavCell.SetWidth(XPConvert.ToString(m_nRightWidth));
        } else
        {
          rightNavCell.SetWidth(XPConvert.ToString(m_nRightWidthAlone));
        }
      }
      // above footer
      if (abovefooterView != null)
      {
        try
        {
          portalContentDiv.AddInnerHTMLElement(abovefooterView.Display());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "above footer view error", e);
        }
      }
      // Footer
      // bjf -- note that the footer has already been queried and set at this point.
      // we package that up with the query to get the header, rather than triggering
      // two separate, wasteful gadget queries.  This way we use the parallelism of
      // web downloader parallel.
      if (displayFooter)
      {
        try
        {
          //tFooterCell.AddInnerHTMLElement(navModel.GetFooterElement());
          portalContentDiv.AddInnerHTMLElement(navModel.GetFooterElement());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "footer view error", e);
        }
      }
      // below footer
      if (belowfooterView != null)
      {
        try
        {
          portalContentDiv.AddInnerHTMLElement(belowfooterView.Display());
          }
        catch (Exception e)
        {
          HandleNavCrash(false, myBody, "below footer view error", e);
        }
      }
      BrowserType browser = (BrowserType) GetOwner().GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
      if (!bNoJavascript && browser.IsJSPortletCompliant())
      {
        portalContentDiv.AddInnerHTMLElement(GetInitializeEventsJavaScript());
        }
      return myBody;
    }
    public virtual HTMLScript GetInitializeEventsJavaScript()
    {
      HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      // InitializeEvents is defined in "jsportlet" code included in the head
      script.AddInnerHTMLString(JAVASCRIPT_INITIALIZE_EVENTS);
      return script;
    }
    
    /// <summary>
    /// Get the pluggable navigation view based on enummerated type.
    /// </summary>
    /// <param name="navType"></param>
    /// <param name="navArea"></param>
    /// <returns>IView</returns>
    private IView GetPlugNav(INavTypes navType, NavAreaEnum navArea)
    {
      IView returnView = null;
      String pViewName = "";
      pViewName = navType.GetNavAreaView(navArea);
      if (null != pViewName && pViewName.Length > 0)
      {
        returnView = base.m_asOwner.GetView(pViewName);
      }
      return returnView;
    }
    
    /// <summary>
    /// Get the pluggable navigation feature boolean
    /// </summary>
    /// <param name="navType"></param>
    /// <param name="navArea"></param>
    /// <returns>IView</returns>
    private bool GetPlugNavFeature(INavTypes navType, NavFeatureEnum navFeature)
    {
      return navType.IsFeatureEnabled(navFeature);
    }
    public virtual HTMLScriptCollection GetBasicJavascript()
    {
      HTMLScriptCollection result = new HTMLScriptCollection();
      // Javascript functions
      if (m_bAddMainForm)
      {
        result.AddInnerHTMLElement(DisplayJavascript());
      }
      HTMLScript headScript = DisplayJavaScriptToHead();
      if (headScript != null)
      {
        result.AddInnerHTMLElement(headScript);
      }
      // The Common JS Includes need to come before any functions are registered with
      // the PCC.  This should come before both the PCCHelper and the page and view
      // Javascript (DisplayJavaScriptFromChild, etc...).	
      // Includes jsportlet javascript components files on the page, the version of the jsportlet to use is defined in /settings/config/JSComponentRegistry.xml
      HTMLScriptCollection jsportletScript = new HTMLScriptCollection();
      jsportletScript.AddInnerHTMLElement(ConfigService.getInstance().GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTLET,
       GetOwner()));
      result.AddInnerHTMLElement(jsportletScript);
      HTMLScriptCollection scripts = DisplayJavaScriptFromChild();
      if (scripts != null)
      {
        result.AddInnerHTMLElement(scripts);
      }
      // This call gets the common window opener and the common opener JS open function
      result.AddInnerHTMLElement(((IFormAS) GetOwner()).DisplayCommonJavaScript());
      // Common Opener JS Functions
      HTMLScriptCollection commonOpenerJSScript = PTOpenerService.getInstance().GetOpenerJavascript(m_asOwner);
      result.AddInnerHTMLElement(commonOpenerJSScript);
      // Add the object that will store all the safe javascript variables.
      result.AddInnerHTMLElement(JSHelper.InitializeSafeJSVarElements());
      HTMLScript scriptPCCHelper = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
      scriptPCCHelper.AddInnerHTMLString("var windowOnloadFunction = (window.onload) ? window.onload : new Function;\n" + "document.PCC.RegisterForWindowEvent(\"onload\", windowOnloadFunction);\n" + "var windowOnBlurFunction = (window.onblur) ? window.onblur : new Function;\n" + "document.PCC.RegisterForWindowEvent(\"onblur\", windowOnBlurFunction);\n" + "var windowOnFocusFunction = (window.onfocus) ? window.onfocus : new Function;\n" + "document.PCC.RegisterForWindowEvent(\"onfocus\", windowOnFocusFunction);\n");
      result.AddInnerHTMLElement(scriptPCCHelper);
      // Add Javascript from DisplayJavascript PEI
      HTMLScriptCollection myPEIScripts = DisplayJavascriptHelper.getInstance().DoDisplayJavascriptPEIs(m_asOwner);
      if (myPEIScripts != null)
      {
        result.AddInnerHTMLElement(myPEIScripts);
      }
      if (m_asOwner.GetIsInPlaceRefreshEnabled())
      {
        // if in place refresh is enabled, add supporting js.
        // Add the callback function for ptinplacerefresh.js to return the jsxml version number prefix
        //String strXMLVersion = ConfigHelper.GetJSIncluderComponentVersion(ConfigHelper.JSCOMPONENT_JSXML);
        String strJSXMLPrefixString = ConfigService.getInstance().GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSXML);
        if (XPStringUtility.EndsWith(strJSXMLPrefixString, "."))
        {
          strJSXMLPrefixString = XPStringUtility.Substring(strJSXMLPrefixString,
           0, strJSXMLPrefixString.Length - 1);
        }
        HTMLScript preScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        preScript.AddInnerHTMLString("function getJSXMLVersionObject() { return \'" + strJSXMLPrefixString + "\';}");
        result.AddInnerHTMLElement(preScript);
      }
      return result;
    }
    
    /// <summary>
    /// Constructs the head for the Plumtree display page.  Note that this
    /// function must be called after calling DisplayBody(), because of the
    /// special case of intrinsic portlets on the MyPortalDP.  Intrinsic
    /// portlets view registration, which occurs in PageDisplay(), must occur
    /// prior to Javascript generation, which occurs during
    /// DisplayJavaScriptFromChild().
    /// </summary>
    /// <param name="nNavScheme">Navigation scheme ID</param>
    /// <returns>HTMLHead</returns>
    /// <seealso cref="NavTypeConstants"></seealso>
    protected virtual HTMLHead DisplayHead(int nNavScheme)
    {
      HTMLHead myHead = new HTMLHead();
      try
      {
        myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
        HTMLTitle myTitle = new HTMLTitle(XPHttpUtility.HtmlEncode(GetFormTitle()));
        myHead.AddInnerHTMLElement(myTitle);
        // Calculate whether or not to display javascript.
        bool bNoJavascript = !(GetUseJavascript());
        if (!bNoJavascript)
        {
          // meta-refresh tag for auto refresh of the page
          HTMLMeta tag = GetMetaRefresh();
          if (tag != null)
          {
            myHead.AddInnerHTMLElement(tag);
          }
          // Javascript functions
          myHead.AddInnerHTMLElement(GetBasicJavascript());
          // Add shared JavaScript collection from tag portlets
          // In layout mode, this is handled by the head includes tag.
          myHead.AddInnerHTMLElement(GatewayUtils.GetSharedJavaScriptFromMarkup(m_asOwner));
          // For prefs dropdown menus - only want to include the jsportalmenu javascript on myportal pages and when the navigation scheme is not
          // using the jsportalmenus already
          if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD && m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME) && nNavScheme != NavTypeConstants.NAVTYPE_ID_HORIZONTAL_DHTML_DROPDOWN_JSPORTALMENU)
          {
            try
            {
              myHead.AddInnerHTMLElement(ConfigService.getInstance().GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTALMENU,
               GetOwner()));
            }
            catch (Exception e)
            {
              log.Error(e, "Unable to retrieve jscomponent includes. Javascript on the page will most likely NOT work!");
              }
          }
          // URLTemplate script
          HTMLScript script = new HTMLScript("text/javaScript");
          script.AddInnerHTMLString(NavigationCommonHelpers.writeURLTemplateParseFunction(m_asOwner));
          myHead.AddInnerHTMLElement(script);
          // Javascript from plugable navs
          INavTypes navType = ((PlumtreeAS) m_asOwner).GetNavType(nNavScheme);
          // Pretty bad if we can't even get the default nav
          if (navType == null)
          {
            log.Error("Fatal error, unable to load default navigation: " + NavTypeConstants.NAV_TYPE_ID_DEFAULT + " Pluggable navigation module incorrectly installed or configured.");
            }
          HTMLScriptCollection scripts = navType.JavaScriptIncludes(m_asOwner);
          if (scripts != null)
          {
            myHead.AddInnerHTMLElement(scripts);
          }
          // get the pluggable views and display any javascript they might have
          try
          {
            AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.ABOVEBODY));
            AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.LEFTOFBODY));
            AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.RIGHTOFBODY));
            AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.BELOWBODY));
            AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.ABOVEBANNER));
            AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.BELOWBANNER));
            }
          catch (Exception e)
          {
            log.Error(e, "Error adding Pluggable NavView javascript to HTMLHead");
            }
        }
        // JF- Helper method so that Activity Spaces can add HTML into the head
        // (like meta and link tags for example).           
        HTMLElementCollection myHTMLinHead = DisplayHTMLinHEAD();
        if (null != myHTMLinHead)
        {
          myHead.AddInnerHTMLElement(myHTMLinHead);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to display head.");
      }
      return myHead;
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from PlumtreeDP
    /// need to implement.  The method should add whatever HTML the child class
    /// wants to use the DisplayJavaScript and add it to the head.
    /// </summary>
    /// <returns>HTMLScript block</returns>
    /// <throws>HTMLException</throws>
    protected virtual HTMLScript DisplayJavaScriptToHead()
    {
      return null;
    }
    
    /// <summary>
    /// Makes navigation more bulletproof, gives user feedback when a navigation element fails
    /// </summary>
    /// <param name="body"></param>
    /// <param name="details"></param>
    private void HandleNavCrash(bool vertical, HTMLBody body, String details,
     Exception e)
    {
      HTMLTable myTable = new HTMLTable();
      myTable.SetSummary(m_asOwner.GetString(550, "ptmsgs_portalcommonmsgs"));
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myTable.SetSummary(m_asOwner.GetString(550, "ptmsgs_portalcommonmsgs"));
      HTMLTableRow myTableRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myTableRow);
      myTableRow.SetVAlign(CommonHTMLStrings.TOP);
      myTableRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
      HTMLTableCell myCell = new HTMLTableCell();
      if (vertical)
      {
        myCell = new HTMLTableCell();
        myTableRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetAlign(CommonHTMLStrings.MIDDLE);
        myCell.SetNoWrap(true);
        HTMLH1 headerH1 = new HTMLH1();
        myCell.AddInnerHTMLElement(headerH1);
        headerH1.AddInnerHTMLString(details);
        headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);
      } else
      {
        // First Cell
        myTableRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetHeight("60");
        // End of First Cell
        // Second Cell
        myCell = new HTMLTableCell();
        myTableRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("200");
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myCell.SetNoWrap(true);
        HTMLH1 headerH1 = new HTMLH1();
        myCell.AddInnerHTMLElement(headerH1);
        headerH1.AddInnerHTMLString(details);
        headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);
        // End of Second Cell
        // third cell -- space
        myCell = new HTMLTableCell();
        myTableRow.AddInnerHTMLElement(myCell);
        myCell.SetWidth("10");
        myCell.SetAlign(CommonHTMLStrings.RIGHT);
        myCell.SetNoWrap(true);
        headerH1 = new HTMLH1();
        myCell.AddInnerHTMLElement(headerH1);
        headerH1.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);
      }
      // add to the page at this point as a table
      body.AddInnerHTMLElement(myTable);
      log.Error(e, "PlumtreeDP: Pluggable Navigation: " + details);
    }
    
    /// <summary>
    /// Forms meta-refresh tag for page auto refreshing.
    /// Override this method to do custom page refreshes.
    /// </summary>
    /// <returns>HTMLMeta to be included, or null</returns>
    public virtual HTMLMeta GetMetaRefresh()
    {
      // NOTE: This is only used by MyPortalDP for the mypage (and possibly the community).
      // Should we remove this somehow?
      return null;
    }
    private void OverrideNavSettingsFromVarPack(INavTypes navType)
    {
      // Override table spacing from NavigationSettings.xml
      int nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPTABLESPACING + navType.GetID(),
       m_asOwner);
      if (-1 != nSetting)
      {
        m_nTableSpacing = nSetting;
      }
      // Override left spacing from NavigationSettings.xml
      nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPLEFTWIDTH + navType.GetID(),
       m_asOwner);
      if (-1 != nSetting)
      {
        m_nLeftWidth = nSetting;
      }
      // Override left spacing without right spacing from NavigationSettings.xml
      nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPLEFTWIDTHALONE + navType.GetID(),
       m_asOwner);
      if (-1 != nSetting)
      {
        m_nLeftWidthAlone = nSetting;
      }
      // Override right spacing from NavigationSettings.xml
      nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPRIGHTWIDTH + navType.GetID(),
       m_asOwner);
      if (-1 != nSetting)
      {
        m_nRightWidth = nSetting;
      }
      // Override right spacing without left spacing from NavigationSettings.xml
      nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPRIGHTWIDTHALONE + navType.GetID(),
       m_asOwner);
      if (-1 != nSetting)
      {
        m_nRightWidthAlone = nSetting;
      }
    }
    private static void AddNavViewJavascript(HTMLHead head, IView navView)
    {
      if (navView != null)
      {
        HTMLScript script = navView.DisplayJavascript();
        if (null != script)
        {
          head.AddInnerHTMLElement(script);
        }
      }
    }
    protected virtual void RegisterNavScheme(int nCurrentScheme)
    {
      INavigationModelRO navModel = ((INavigationModelRO) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME));
      int nRegisteredScheme = navModel.GetRegisteredViewNavScheme();
      if (nCurrentScheme != nRegisteredScheme)
      {
        INavTypes regNavType = ((PlumtreeAS) m_asOwner).GetNavType(nRegisteredScheme);
        INavTypes curNavType = ((PlumtreeAS) m_asOwner).GetNavType(nCurrentScheme);
        IXPEnumerator navAreas = NavAreaHelper.INSTANCE.GetCategoryTypes();
        if (navAreas != null)
        {
          // For each page area within this pluggable nav, 
          // register the view with the AS
          while (navAreas.MoveNext())
          {
            String pView;
            // Unregister old scheme
            //if (nRegisteredScheme != NavTypeConstants.NAVTYPE_ID_INVALID) {
            pView = NavAreaHelper.INSTANCE.GetNavAreaViewClassName(regNavType,
             (NavAreaEnum) navAreas.GetCurrent());
            if (pView != null)
            {
              if (m_asOwner.GetViewExists(pView))
              {
                m_asOwner.UnRegisterView(pView);
              }
            }
            //}
            // Register current scheme
            pView = NavAreaHelper.INSTANCE.GetNavAreaViewClassName(curNavType,
             (NavAreaEnum) navAreas.GetCurrent());
            if (pView != null)
            {
              if (!m_asOwner.GetViewExists(pView))
              {
                m_asOwner.RegisterView(pView, navModel);
              }
            }
          }
        }
        navModel.SetRegisteredViewNavScheme(nCurrentScheme);
      }
    }
  }
}