using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <summary>
  /// This is the AS for Rules Debugging Messages.
  /// </summary>
  /// <author>dustina</author>
  public class RulesDebugMSGAS : AFormAS
  {
    public const String STR_MVC_CLASS_NAME = "RulesDebugMSGAS";
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new RulesDebugMSGAS();
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String,String,boolean)"></seealso>
    public override bool CheckBasicAccess(String strPage, String strControl,
     bool bSameSpace)
    {
      return true;
    }
    public override String GetRepostControlName()
    {
      return RepostControl.STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.AActivitySpace#Init()"></seealso>
    public override void Init()
    {
      base.Init();
      RegisterPage(new RulesDebugMSGDP());
      RegisterModel(RulesDebugMSGModel.STR_MVC_CLASS_NAME);
      IModel model = GetModel(RulesDebugMSGModel.STR_MVC_CLASS_NAME);
      RegisterControl(RepostControl.STR_MVC_CLASS_NAME, model);
    }
    
    /// <summary>
    /// This method calculates whether or not the subportal rules debug button
    /// is enabled for the server and the current user.
    /// </summary>
    /// <param name="_asOwner">The current AActivitySpace</param>
    /// <returns>boolean True implies the rules debug button is enabled.</returns>
    public static bool GetIsRulesDebugEnabled(AActivitySpace _asOwner)
    {
      IPTServerConfigSettings config = (IPTServerConfigSettings) ((IPTSession) _asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      bool bRulesDebugEnabled = false;
      try
      {
        bRulesDebugEnabled = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_SUBPORTAL_RULES_MODE) == 1;
        }
      catch (Exception e)
      {
      }
      // DCA - setting not found in the database; assume debug mode off
      Object ret = PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE,
       _asOwner);
      bRulesDebugEnabled = ((bRulesDebugEnabled) && (null != ret) && (XPConvert.ToInteger(ret) == 1));
      return bRulesDebugEnabled;
    }
  }
}