using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
namespace com.plumtree.portalpages.common.uiparts
{
  /// <author>btse</author>
  public class UnsubscribeCurCommunityControl : IControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
     "com.plumtree.portalpages.common.uiparts.UnsubscribeCurCommunityControl");
    public const String STR_MVC_CLASS_NAME = "UnsubscribeCurCommunity";
    
    /// <summary>
    /// Community ID Query String Param 
    /// </summary>
    public const String m_CommunityID = "CommunityID";
    private AActivitySpace m_asOwner;
    
    /// <summary>
    /// model 
    /// </summary>
    private MyPortalModel m_asModel;
    
    /// <summary>
    /// Looks for the CommunityID parameter and removes the current user as a member of the specified
    /// Community ID.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arg0)
    {
      int nCommID = -1;
      try
      {
        nCommID = XPConvert.ToInteger(((String[]) arg0.GetElement("CommunityID"))[0]);
        }
      catch (Exception e)
      {
        log.Error("Unable to unsubscribe community, the Community ID is missing or invalid.");
        return null;
      }
      // Hack, set the community id in the portalmodel so it knows what the current community is without
      // calling the SetCommunity control. Need this since navigation model gets the current community id and more
      // from the myportalmodel. We are sure the model exists since this is in the myportalAS.
      MyPortalModel portalMod = (MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
      // Don't care about the page, we are just unsubscribing the community.
      portalMod.SetCommunity(nCommID, 0);
      m_asModel.UnsubscribeCommunity();
      // Make the MyPortalDP show the confirmation page instead of the regular.
      m_asModel.SetShowUnsubscribeCommConfirmPage(true);
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        return null;
      } else
      {
        Redirect redirect = new Redirect();
        redirect.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME,
         m_asOwner);
        redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
        redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
         m_asModel.GetCommunityID());
        redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID, 0);
        return redirect;
      }
    }
    /*
     * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
     */
     
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asOwner = space;
      m_asModel = (MyPortalModel) model;
    }
    /*
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
     
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /*
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public virtual Object Create()
    {
      return new UnsubscribeCurCommunityControl();
    }
  }
}