/*
 * Created on Mar 5, 2003
 */
 
using System;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.compoundlist;
namespace com.plumtree.portalpages.common.uiparts.navpagetype
{
  /// <summary>
  /// Delegates model methods only usable by community page.
  /// </summary>
  /// <author>DavidP</author>
  public class CommunityNavPage : NavigationPage,ICommunityNavPageRO
  {
    
    /// <summary>
    /// Unique String Name of category of object.  Critical for link blocking by pluggable nav.
    /// </summary>
    public override String GetName()
    {
      return NavPageType.COMMUNITY.ToString();
    }
    
    /// <summary>
    /// CommunityNavPage constructor.   
    /// </summary>
    /// <param name="model"></param>
    public CommunityNavPage(INavigationModelRO model) : base(model, NavPageType.COMMUNITY)
    {
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetAccessibleCommunityID(int)"></seealso>
    public virtual int GetAccessibleCommunityID(int nSubPortalCommID)
    {
      return m_model.GetAccessibleCommunityID(nSubPortalCommID);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurCommunityID()"></seealso>
    public virtual int GetCurCommunityID()
    {
      return m_model.GetCurCommunityID();
    }
    
    /// <summary>
    /// Gets the ID of the current Community Page 
    /// </summary>
    /// <returns>Community Page ID</returns>
    public virtual int GetCurPageID()
    {
      return m_model.GetCurPageID();
    }
    
    /// <summary>
    /// Checks if the current user is a member of the current Community
    /// </summary>
    /// <returns>True if the user is a member</returns>
    public virtual bool IsMemberInCurCommunity()
    {
      return m_model.IsMemberInCurCommunity();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurCommunityName()"></seealso>
    public virtual String GetCurCommunityName()
    {
      return m_model.GetCurCommunityName();
    }
    
    /// <summary>
    /// Gets the current community pages.
    /// </summary>
    /// <returns>ICPListEntryIterator</returns>
    public virtual ICPListEntryIterator GetCurCommPages()
    {
      return m_model.GetCurCommPages();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurRelCommunities()"></seealso>
    public virtual ICPListEntryIterator GetCurRelCommunities()
    {
      return m_model.GetCurRelCommunities();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurSubCommunities()"></seealso>
    public virtual ICPListEntryIterator GetCurSubCommunities()
    {
      return m_model.GetCurSubCommunities();
    }
    //
    // Subportal functions END
    //
    //
    // Misc functions
    //
    
    /// <summary>
    /// Get the ID of the user's Default Community ID
    /// </summary>
    public virtual int GetDefaultCommunity()
    {
      return m_model.GetDefaultCommunity();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetMyCommunities(boolean)"></seealso>
    public virtual ICPListEntryIterator GetMyCommunities(bool bListActions)
    {
      return m_model.GetMyCommunities(bListActions);
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetParentComm()"></seealso>
    public virtual ICPListEntryIterator GetParentComm()
    {
      return m_model.GetParentComm();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#IsCurCommOwner()"></seealso>
    public virtual bool IsCurCommOwner()
    {
      return m_model.IsCurCommOwner();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCommunityID()"></seealso>
    public virtual int GetCommunityID()
    {
      IMyPortalModelRO portalMod = (IMyPortalModelRO) m_model.GetMyPortalModel();
      if (portalMod == null)
      {
        return 0;
      }
      return portalMod.GetCommunityID();
    }
    
    /// <summary>
    /// Returns true if this page should show the "Inside this Community" header and
    /// sub- and related communitites.
    /// </summary>
    /// <returns>true if the page should show community nav links</returns>
    public virtual bool ShowCommunityNavigation()
    {
      return m_model.ShowCommunityNavigation();
    }
    
    /// <seealso cref="com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#CanJoinCurCommunity()"></seealso>
    public virtual bool CanJoinCurCommunity()
    {
      return m_model.CanJoinCurCommunity();
    }
  }
}