/*
 * Created on Mar 5, 2003
 */
 
using System;
using com.plumtree.portalpages.common.plugnav;
using com.plumtree.portalpages.common.uiparts;
namespace com.plumtree.portalpages.common.uiparts.navpagetype
{
  /// <summary>
  /// Class used as facade to navigation model for methods 
  /// appropriate to which page is current
  /// </summary>
  /// <author>DavidP</author>
  public abstract class NavigationPage : INavigationPageRO
  {
    // shared by derived classes but not outside
    protected INavigationModelRO m_model;
    protected NavPageType m_type;
    
    /// <summary>
    /// Protected ctor() to prevent instantiation except through factory method below
    /// Feel free to place navpage-wide code here
    /// </summary>
    protected NavigationPage(INavigationModelRO model, NavPageType type)
    {
      m_model = model;
      m_type = type;
    }
    
    /// <summary>
    /// Factory to instantiate proper navigation page object by type
    /// </summary>
    /// <param name="type">NavPageType</param>
    /// <param name="model">The Navigation model interface</param>
    /// <returns>			The requested NavigationPage interface</returns>
    /// <seealso cref="NavPageType"></seealso>
    public static NavigationPage Create(NavPageType type, INavigationModelRO model)
    {
      // instantiate a navigation page based on nav page type
      // This list must closely match the nav page types
      if (type.Equals(NavPageType.COMMUNITY))
      {
        return new CommunityNavPage(model);
      }
      if (type.Equals(NavPageType.USERPROFILE))
      {
        return new UserProfileNavPage(model);
      }
      if (type.Equals(NavPageType.LOGIN))
      {
        return new LoginNavPage(model);
      }
      if (type.Equals(NavPageType.MYPAGE))
      {
        return new MyPageNavPage(model);
      }
      if (type.Equals(NavPageType.COMMUNITYPREVIEW))
      {
        return new CommunityPreviewNavPage(model);
      }
      if (type.Equals(NavPageType.DIRECTORY))
      {
        return new DirectoryNavPage(model);
      }
      // unrecognized type request
      return null;
    }
    
    /// <summary>
    /// Returns the type of the page created
    /// </summary>
    /// <returns>NavPageType</returns>
    public virtual NavPageType GetPageType()
    {
      return m_type;
    }
    
    /// <summary>
    /// Core name of object.  Critical for link matchign and naming.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      // complex - will calls truly defer to the correct parent?
      return "MAJOR NAMING ERROR";
    }
  }
}
// TODO: session hash object for session wide storage of nav state
