using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.devices.choosepage.common
{
  /// <author>SudhaS</author>
  public class ChoosePageDevicesModel : IChoosePageDevicesModelRO,IModel
  {
    public const String STR_MVC_CLASS_NAME = "ChoosePageDevices_Devices";
    public const int NUM_LINKS_PER_SCREEN = 5;
    private AActivitySpace m_asOwner;
    private IPTSession m_ptSession;
    private int m_nListID = -1;
    private int m_nCurrentCommunityID = 0;
    private int m_nCurrentPageID = 0;
    private int m_nSavedCommunityID = 0;
    private int m_nSavedPageID = 0;
    private Object[][] m_oPageMemberships;
    private int m_nNumPages = 0;
    public virtual void CleanupTempData()
    {
    }
    //m_oPageMemberships = null;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.xpshared.infrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new ChoosePageDevicesModel();
    }
    
    /// <returns></returns>
    public virtual int GetListID()
    {
      return m_nListID;
    }
    public virtual int GetCurrentCommunity()
    {
      return m_nCurrentCommunityID;
    }
    public virtual int GetCurrentPage()
    {
      return m_nCurrentPageID;
    }
    public virtual int GetSavedCommunity()
    {
      return m_nSavedCommunityID;
    }
    public virtual int GetSavedPage()
    {
      return m_nSavedPageID;
    }
    public virtual Object[][] GetPageMemberships()
    {
      return m_oPageMemberships;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="iCount"></param>
    /// <param name="iMaxNumber"></param>
    /// <returns></returns>
    public virtual int GetNumPages(int iCount, int iMaxNumber)
    {
      //SS - Calculate the number of screens to be displayed
      //based on the total number of pages and the pages
      //per screen
      if (iMaxNumber > 0)
      {
        int iNumPages = iCount / iMaxNumber;
        if ((iCount % iMaxNumber) > 0)
        {
          iNumPages++;
        }
        return iNumPages;
      } else
      {
        return 1;
      }
    }
    
    /// <returns></returns>
    public virtual int GetNumTotalPages()
    {
      return m_nNumPages;
    }
    
    /// <returns></returns>
    public virtual Object[][] SetPageMemberships()
    {
      //SS - Create a new 2d array of communities and their pages
      IPTSessionInfo ptSessionInfo = (IPTSessionInfo) m_ptSession.GetSessionInfo();
      IPTQueryResult qrCommunityMemberships = ptSessionInfo.GetCurrentCommunityMembership();
      int nCommMmbrshps = qrCommunityMemberships.RowCount();
      if (nCommMmbrshps > 0)
      {
        m_oPageMemberships = new Object[nCommMmbrshps + 1][];
        for (int j2c_index = 0;j2c_index < nCommMmbrshps + 1;j2c_index++)
        {
          m_oPageMemberships[j2c_index] = new Object[3];
        }
        for (int i = 0;i < nCommMmbrshps;i++)
        {
          int nCommunityID = qrCommunityMemberships.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
          String strCommName = qrCommunityMemberships.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
          IPTObjectManager omCommunities = m_ptSession.GetCommunities();
          IPTCommunity ptCommunity = (IPTCommunity) omCommunities.Open(nCommunityID,
           false);
          IPTQueryResult qrCommunityPages = ptCommunity.QueryPages(0);
          //SS - Get the array of pages for a community
          Object[] oPages = GetPropertiesArray(qrCommunityPages, PT_PROPIDS.PT_PROPID_OBJECTID,
           PT_PROPIDS.PT_PROPID_NAME);
          m_oPageMemberships[i + 1][0] = strCommName;
          m_oPageMemberships[i + 1][1] = nCommunityID;
          m_oPageMemberships[i + 1][2] = oPages;
          String[] pagenames = (String[]) oPages[1];
          m_nNumPages = m_nNumPages + pagenames.Length;
        }
      } else
      {
        m_oPageMemberships = new Object[1][];
        for (int j2c_index = 0;j2c_index < 1;j2c_index++)
        {
          m_oPageMemberships[j2c_index] = new Object[3];
        }
      }
      //SS - The MyPages go in the first index
      IPTQueryResult qrMyPages = ptSessionInfo.GetCurrentMyPages();
      Object[] arPages = GetPropertiesArray(qrMyPages, PT_PROPIDS.PT_PROPID_OBJECTID,
       PT_PROPIDS.PT_PROPID_NAME);
      m_oPageMemberships[0][0] = "My Page";
      m_oPageMemberships[0][1] = 0;
      m_oPageMemberships[0][2] = arPages;
      String[] arPageNames = (String[]) arPages[1];
      m_nNumPages = m_nNumPages + arPageNames.Length;
      return m_oPageMemberships;
    }
    public virtual int GetCommunityIDIndex()
    {
      return GetIndex(true);
    }
    public virtual int GetPageIDIndex()
    {
      return GetIndex(false);
    }
    private int GetIndex(bool _bGetCommunityIndex)
    {
      //SS - Get the index of a starting display screen for a device.
      //If _bGetCommunityIndex return the community ID value, otherwise
      //return the page page ID value.
      if (m_nListID == 0)
      {
        return 0;
      }
      //SS - The current display screen
      int nIndex = m_nListID * NUM_LINKS_PER_SCREEN;
      int nCount = 1;
      for (int i = 0;i < m_oPageMemberships.Length;i++)
      {
        Object[] aPages = (Object[]) m_oPageMemberships[i][2];
        int[] aPageIDs = (int[]) aPages[0];
        for (int j = 0;j < aPageIDs.Length;j++)
        {
          //SS - If we have reached the current display screen
          if (nCount == nIndex)
          {
            //SS - If we are looking for the community index, and we are the
            //end of a community, return the next community
            if (_bGetCommunityIndex)
            {
              if (j == aPageIDs.Length - 1)
              {
                return i + 1;
              } else
              {
                return i;
              }
            } else
            //SS - If we are at the end of a community index, return 0 so
            //we get the first page in the next community
            {
              if (j == aPageIDs.Length - 1)
              {
                return 0;
              } else
              {
                return j + 1;
              }
            }
          }
          nCount++;
        }
      }
      return 0;
    }
    
    /// <param name="_asOwner"></param>
    public virtual void Init(AActivitySpace _asOwner)
    {
      m_asOwner = _asOwner;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
      SetPageMemberships();
    }
    
    /// <param name="_nListID"></param>
    public virtual void SetListID(int _nListID)
    {
      m_nListID = _nListID;
    }
    
    /// <param name="__nCurrentCommunityID"></param>
    public virtual void SetCurrentCommunityID(int _nCurrentCommunityID)
    {
      m_nCurrentCommunityID = _nCurrentCommunityID;
    }
    
    /// <param name="__nCurrentCommunityID"></param>
    public virtual void SetCurrentPageID(int _nCurrentPageID)
    {
      m_nCurrentPageID = _nCurrentPageID;
    }
    
    /// <param name="__nCurrentCommunityID"></param>
    public virtual void SetSavedCommunityID(int _nCurrentCommunityID)
    {
      m_nSavedCommunityID = _nCurrentCommunityID;
    }
    
    /// <param name="__nCurrentCommunityID"></param>
    public virtual void SetSavedPageID(int _nCurrentPageID)
    {
      m_nSavedPageID = _nCurrentPageID;
    }
    
    /// <param name="qr"></param>
    /// <param name="PropID1"></param>
    /// <param name="PropID2"></param>
    /// <returns></returns>
    private Object[] GetPropertiesArray(IPTQueryResult qr, int PropID1, int PropID2)
    {
      //SS - Calculate the pageIDs and page names arrays for a community
      int[] arrObjectIDs;
      String[] arrNames;
      int intCount = qr.RowCount();
      if (intCount > 0)
      {
        arrObjectIDs = new int[intCount];
        arrNames = new String[intCount];
        for (int i = 0;i < intCount;i++)
        {
          arrObjectIDs[i] = qr.ItemAsInt(i, PropID1);
          arrNames[i] = qr.ItemAsString(i, PropID2);
        }
        return new Object[]{arrObjectIDs, arrNames};
      } else
      {
        return new Object[0];
      }
    }
  }
}