using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.devices.choosepage.common;
using com.plumtree.portalpages.devices.mypage.common;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.login;
namespace com.plumtree.portalpages.devices.login.common
{
  /// <author>SudhaS</author>
  public class LoginDevicesControl : ILoginControl,IHTTPControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_DEVICES),
     "com.plumtree.portalpages.devices.login.common.LoginDevicesControl");
    public const String STR_MVC_CLASS_NAME = "Login_Devices";
    public const String HTML_INPUT_NAME = "in_tx_loginName";
    public const String HTML_INPUT_PASSWORD = "in_pw_loginPassword";
    public const String HTML_INPUT_AUTHSRC = "in_se_loginAuthSrc";
    public const String HTML_INPUT_SUBMIT = "in_su_loginSubmit";
    public const String DO_LOGIN = "login_dologin";
    public const String DO_HTML32 = "login_doHTML32";
    public const String m_strPORTAL_SETTINGS_DATA = "Login_Devices";
    private AActivitySpace m_asOwner;
    private ILoginDevicesModelRO m_asmModel;
    private IPTSession m_ptSession;
    // These need to be nulled out at the end of CheckActionSecurityAndExecute()
    private IXPRequest m_xpRequest;
    private IWebData m_WebData;
    
    /// <seealso cref="com.plumtree.xpshared.portalinfrastructure.activityspace.IControl#Execute()"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      LoginResult loginResult = null;
      String[] sValues = (String[]) arguments.GetElement(DO_LOGIN);
      if (sValues != null)
      {
        if (XPConvert.ToBoolean(sValues[0]))
        {
          log.Info("Attempting devices login.");
          String strLoginName = "";
          String strPassword = "";
          String strHTML32 = "";
          String strAuthSrc = "";
          bool bIsNumericConnect = true;
          sValues = (String[]) arguments.GetElement(DO_HTML32);
          if (sValues != null)
          {
            strHTML32 = sValues[0];
            //SS - At this time if it's not HTML32, then it's WML and a numeric connect
            bIsNumericConnect = XPStringUtility.CompareIgnoreCase("true",
             strHTML32) != 0;
          }
          sValues = (String[]) arguments.GetElement(HTML_INPUT_NAME);
          if (sValues != null)
          {
            strLoginName = sValues[0];
          }
          sValues = (String[]) arguments.GetElement(HTML_INPUT_PASSWORD);
          if (sValues != null)
          {
            strPassword = sValues[0];
          }
          sValues = (String[]) arguments.GetElement(HTML_INPUT_AUTHSRC);
          if (sValues != null)
          {
            strAuthSrc = sValues[0];
          }
          //	if the user selected an auth source, we prepend the
          //	authsource prefix to the username.
          if ((strAuthSrc != null) && (XPStringUtility.CompareIgnoreCase("",
           strAuthSrc) != 0))
          {
            strLoginName = strAuthSrc + "/" + strLoginName;
          }
          //SS - Login attempt
          loginResult = LoginHelper.INSTANCE.AttemptLogin(strLoginName, strPassword,
           null, bIsNumericConnect, m_asOwner, m_xpRequest, m_WebData);
          if (loginResult.m_bSuccess)
          {
            m_ptSession = (IPTSession) loginResult.m_UserSession;
          } else
          {
            //	login failed
            log.Error("Device Login failed for user " + strLoginName + ": " + loginResult.m_strError);
            UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
             null, loginResult.m_strError, loginResult.m_strError);
            myError.SetActivitySpace(m_asOwner.GetName());
            myError.SetClearWithActivitySpaceChange(true);
            UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
             m_asOwner.GetApplication());
          }
        }
      }
      // Null out HTTP items so we don't retain (leak) them.
      m_xpRequest = null;
      m_WebData = null;
      Redirect redirect = null;
      if (loginResult != null)
      {
        redirect = loginResult.m_Redirect;
        if (!loginResult.m_bSuccess)
        {
          //	login failed -- don't use redirects on failure.
          return null;
        }
      }
      if (redirect == null)
      {
        redirect = new Redirect();
        // TODOCR: DONH - this should be a constant.
        redirect.SetLinkCreateNewSpace("ChoosePageDevices", m_asOwner);
        redirect.SetControl(ChoosePageDevicesControl.STR_MVC_CLASS_NAME);
        redirect.AddControlArgument(MyPageDevicesControl.STR_PAGE_ID, 0);
        }
      return redirect;
    }
    public virtual void SetRedirectForUseAfterLogin(Redirect redirect)
    {
      LoginDevicesModel myLoginDevicesModel = (LoginDevicesModel) m_asOwner.GetModel(LoginDevicesModel.STR_MVC_CLASS_NAME);
      myLoginDevicesModel.SetRedirect(redirect);
    }
    public virtual Object GetSession()
    {
      return m_ptSession;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.ILoginControl#DoGetSession()"></seealso>
    public virtual bool DoGetSession()
    {
      // The interpreter should ask us for the session.
      return true;
    }
    
    /// <seealso cref="IHTTPControl"></seealso>
    /// <param name="r"></param>
    /// <param name="pageData"></param>
    public virtual void SetHTTPItems(IXPRequest r, IWebData pageData)
    {
      m_xpRequest = r;
      m_WebData = pageData;
    }
    
    /// <seealso cref="com.plumtree.xpshared.infrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new LoginDevicesControl();
    }
    
    /// <seealso cref="com.plumtree.xpshared.portalinfrastructure.activityspace.IControl#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.portalinfrastructure.activityspace.IControl#Init(IModel,AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_asmModel = (ILoginDevicesModelRO) model;
      m_asOwner = space;
    }
  }
}