using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.devices.mypage.common
{
  /// <author>SudhaS</author>
  public class MyPageDevicesModel : IMyPageDevicesModelRO,IModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_DEVICES),
     "com.plumtree.portalpages.devices.mypage.common.MyPageDevicesModel");
    public const String STR_MVC_CLASS_NAME = "MyPageDevices_Devices";
    public const String WML_INTERFACE = "http://www.plumtree.com/uis/wml";
    private AActivitySpace m_asOwner;
    private IPTMyPortalGadgetContent m_gadgetContent = null;
    private IPTMyPortalGadgetContent m_gadgetContentSummary = null;
    private IPTPageInfo m_ptPageInfo;
    private IPTSession m_ptSession;
    private IPTState m_objAppDataState = null;
    private String m_strHostPageURI = "";
    private String m_strPageName = "";
    private int m_nCommunityID = 0;
    private int m_nListID = 0;
    private int m_nNumPortlets = -1;
    private int m_nPageID = -1;
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.xpshared.infrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new MyPageDevicesModel();
    }
    
    /// <param name="_strSpace"></param>
    /// <returns></returns>
    public virtual ASURL GetASURL(String _strSpace)
    {
      ASURL myURL = new ASURL(m_asOwner);
      myURL.SetXMLEncoding(true);
      myURL.SetLinkCreateNewSpace(_strSpace, m_asOwner);
      myURL.AddControlArgument(MyPageDevicesControl.STR_PAGE_ID, m_nPageID);
      myURL.AddControlArgument(MyPageDevicesControl.STR_COMMUNITY_ID, m_nCommunityID);
      return myURL;
    }
    
    /// <returns></returns>
    public virtual int GetCommunityID()
    {
      return m_nCommunityID;
    }
    
    /// <param name="s"></param>
    /// <param name="iMaxSize"></param>
    /// <param name="sEnd"></param>
    /// <returns></returns>
    public virtual String GetFixStringLength(String s, int iMaxSize, String sEnd)
    {
      if (s.Length > iMaxSize)
      {
        return XPStringUtility.Substring(s, 0, iMaxSize - sEnd.Length) + sEnd;
        } else
      {
        return s;
      }
    }
    
    /// <returns></returns>
    public virtual int GetPortletCount()
    {
      return m_nNumPortlets;
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual int GetPortletID(int _nIndex)
    {
      return (m_gadgetContent.GetGadgetID(_nIndex));
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual String GetPortletName(int _nIndex)
    {
      return (m_gadgetContent.GetGadgetName(_nIndex));
    }
    
    /// <param name="_nIndex"></param>
    /// <returns></returns>
    public virtual String GetPortletSummary(int _nIndex)
    {
      //Object[][] oPortletSummary = (Object[][]) m_gadgetContentSummary.GetContent(_nIndex);
      Object[][] oPortletContentSummary;
      try
      {
        oPortletContentSummary = (Object[][]) m_gadgetContentSummary.GetContent(_nIndex);
        }
      //SS - For portlets that don't support summaries, the standard is to catch the error
      //and do nothing
      catch (Exception e)
      {
        return ("");
      }
      XPStringBuilder sb;
      sb = new XPStringBuilder();
      try
      {
        //SS - If we are looking at an intrinsic portlet
        if (IntrinsicPortletModel.IsIntrinsicPortlet(oPortletContentSummary))
        {
          try
          {
          }
          //SS - No support for intrinsic portlets
          catch (Exception e)
          {
          }
        } else
        // If there was an error generating portlet content, then display generic error message.
        //SS - Remote portlet
        {
          int iFragments = oPortletContentSummary[0].Length;
          try
          {
            // run through all the rows in the array -jas		
            for (int iFragment = 0;iFragment < iFragments;iFragment++)
            {
              int iType = XPConvert.ToInteger(oPortletContentSummary[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][iFragment]);
              switch (iType){
              case PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_FINISHED:
              {
                // finished markup string, send it out to the browser -jas	
                sb.Append((String) oPortletContentSummary[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][iFragment]);
                break;
              }
              }
            }
          }
          catch (Exception e)
          {
            log.Error(e, "Error in MyPageDevicesModel: ");
          }
        }
      }
      catch (HTMLException e)
      {
        log.Error(e, "Error in MyPageDevicesModel::Display: ");
      }
      return sb.ToString();
    }
    
    /// <summary>
    /// The results of this method are not used in the Devices
    /// MyPage, but this method needs to be called before
    /// calling GetPortletName(int).
    /// Unused -- devices only display portlet summaries in bulk.
    /// Otherwise they just display a single portlet at a time.\u0009
    /// </summary>
    public virtual HTMLTableCell GetPortletContent(int _nIndex)
    {
      HTMLTableCell result = new HTMLTableCell();
      try
      {
        Object[][] oPortletContent = (Object[][]) m_gadgetContent.GetContent(_nIndex);
        if (IntrinsicPortletModel.IsIntrinsicPortlet(oPortletContent))
        {
          try
          {
            String strPortletWML = GetIntrinsicPortletContent(_nIndex, oPortletContent);
            result.AddInnerHTMLString(strPortletWML);
          }
          catch (Exception e)
          {
          }
        } else
        // If there was an error generating HTML, then display generic error message.
        {
          // Note: we need to add the shared JS separately
          result.AddInnerHTMLElement(GatewayUtils.AddMarkupToElement(m_asOwner,
           oPortletContent));
        }
      }
      catch (HTMLException e)
      {
        log.Error(e, "Error in MyPageDevicesModel::Display: ");
      }
      catch (Exception e)
      {
        log.Error(e, "Error in MyPageDevicesModel::Display: ");
        throw new XPException("Error in MyPageDevicesModel::Display: ", e);
        }
      return result;
    }
    
    /// <returns></returns>
    public virtual int GetListID()
    {
      return m_nListID;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="iCount"></param>
    /// <param name="iMaxNumber"></param>
    /// <returns></returns>
    public virtual int GetNumPages(int iCount, int iMaxNumber)
    {
      if (iMaxNumber > 0)
      {
        int iNumPages = iCount / iMaxNumber;
        if ((iCount % iMaxNumber) > 0)
        {
          iNumPages++;
        }
        return iNumPages;
      } else
      {
        return 1;
      }
    }
    
    /// <returns></returns>
    public virtual int GetPageID()
    {
      return m_nPageID;
    }
    public virtual String GetPageName()
    {
      return m_strPageName;
    }
    public virtual void SetPageName(String _strPageName)
    {
      m_strPageName = _strPageName;
    }
    
    /// <param name="_asOwner"></param>
    public virtual void Init(AActivitySpace _asOwner)
    {
      m_asOwner = _asOwner;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <param name="_nCommunityID"></param>
    public virtual void SetCommunityID(int _nCommunityID)
    {
      m_nCommunityID = _nCommunityID;
    }
    
    /// <returns></returns>
    public virtual void SetPortletContent(String _strUniqueID)
    {
      try
      {
        m_objAppDataState = AppDataObject.GetAppDataObject(m_nCommunityID,
         m_nPageID, m_strHostPageURI, m_asOwner);
        IPTPageInfo ptPageInfo = null;
        if (m_nCommunityID == 0)
        {
          ptPageInfo = m_ptSession.GetMyPages().GetPage(m_nPageID);
        } else
        {
          IPTCommunityInfo communityInfo = ((IPTCommunityManager) m_ptSession.GetCommunities()).CachedOpenCommunityInfo(m_nCommunityID,
           true);
          ptPageInfo = communityInfo.GetPage(m_nPageID);
        }
        Object[] temp = new Object[0];
        m_objAppDataState.Add(AppDataObject.PT_COLLAPSEDGADGETS, (Object[]) temp,
         0, true);
        m_ptPageInfo = ptPageInfo;
        m_gadgetContent = ptPageInfo.QueryPortletContent(m_objAppDataState,
         _strUniqueID, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
        m_gadgetContentSummary = ptPageInfo.QueryPortletContent(m_objAppDataState,
         _strUniqueID, PT_GADGET_MODES.PT_GADGETMODES_SUMMARY, false);
        m_nNumPortlets = m_gadgetContent.GetCount();
      }
      catch (Exception e)
      {
        log.Error("MyPageDevicesModel::The following error occured when trying to set the gadget content: " + e);
        throw new XPException(m_asOwner.GetString(948, "ptmsgs_portaladminmsgs"),
         e);
      }
    }
    
    /// <summary>
    /// Register model, view, and control for intrinsic portlet.  Initialize
    /// portlet with the portletID, the IPTMyPortal object, and the
    /// AppDataState object.
    /// </summary>
    /// <param name="_strPortletClass">Class identifier for portlet</param>
    /// <param name="_strStorageName">Storage name for portlet</param>
    /// <param name="_nPortletIndex">Portlet index</param>
    /// <throws>
    /// XPException Exception thrown if model, view, or control is not
    /// registered successfully.
    /// </throws>
    private void SetupIntrinsicPortlet(String _strPortletClass, String _strStorageName,
     int _nPortletIndex)
    {
      log.Debug("MyPortalModel::SetupIntrinsicPortlet");
      int nPortletID = m_gadgetContent.GetGadgetID(_nPortletIndex);
      // Register Model
      if (!m_asOwner.GetModelExists(_strStorageName))
      {
        bool bModelRegistered = m_asOwner.RegisterModel(_strPortletClass,
         _strStorageName);
        if (!bModelRegistered)
        {
          log.Error("MyPortalModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(676,
           "ptmsgs_portalbrowsingmsgs"));
          throw new XPException(m_asOwner.GetString(676, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      IntrinsicPortletModel iPortletModel = (IntrinsicPortletModel) m_asOwner.GetModel(_strStorageName);
      // Register Section
      if (!m_asOwner.GetViewExists(_strStorageName))
      {
        bool bViewRegistered = m_asOwner.RegisterView(_strPortletClass, _strStorageName,
         iPortletModel);
        if (!bViewRegistered)
        {
          log.Error("MyPortalModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(677,
           "ptmsgs_portalbrowsingmsgs"));
          throw new XPException(m_asOwner.GetString(677, "ptmsgs_portalbrowsingmsgs"));
          }
      }
      // Register Control
      if (iPortletModel.ControlExists())
      {
        if (!m_asOwner.GetControlExists(_strStorageName))
        {
          bool bControlRegistered = m_asOwner.RegisterControl(_strPortletClass,
           _strStorageName, iPortletModel);
          if (!bControlRegistered)
          {
            log.Error("MyPortalModel::SetupIntrinsicPortlet. " + m_asOwner.GetString(675,
             "ptmsgs_portalbrowsingmsgs"));
            throw new XPException(m_asOwner.GetString(675, "ptmsgs_portalbrowsingmsgs"));
            }
        }
      }
      // Get the portlet object from the IPTMyPortalPortletContent
      IPTGadget ptPortlet = m_gadgetContent.GetGadget(_nPortletIndex);
      // Initialize portlet model
      iPortletModel.InitPortlet(m_ptPageInfo, m_objAppDataState, ptPortlet,
       nPortletID);
    }
    
    /// <summary>
    /// Retrieves WML for intrinsic portlet.
    /// </summary>
    /// <param name="nPortletIndex"></param>
    /// <param name="objArrMarkup"></param>
    /// <returns></returns>
    private String GetIntrinsicPortletContent(int nPortletIndex, Object[][] objArrMarkup)
    {
      String strPortletClass = (String) objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][0];
      int nPortletID = m_gadgetContent.GetGadgetID(nPortletIndex);
      String strStorageName = strPortletClass + nPortletID;
      SetupIntrinsicPortlet(strPortletClass, strStorageName, nPortletIndex);
      // We are deliberately breaking the rules for models and views here.  Model is 
      // retrieving data from a view. -jic
      IntrinsicPortletView iPortletView = (IntrinsicPortletView) m_asOwner.GetView(strStorageName);
      return iPortletView.DisplayWML();
    }
    
    /// <param name="_strHostPage"></param>
    public virtual void SetHostPageURI(String _strHostPage)
    {
      m_strHostPageURI = _strHostPage;
    }
    
    /// <param name="_nListID"></param>
    public virtual void SetListID(int _nListID)
    {
      m_nListID = _nListID;
    }
    
    /// <param name="_nPageID"></param>
    public virtual void SetPageID(int _nPageID)
    {
      m_nPageID = _nPageID;
    }
  }
}