using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.devices.mypage.common;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.devices.portlet.common
{
  /// <author>SudhaS</author>
  public class PortletDevicesModel : IPortletDevicesModelRO,IModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_DEVICES),
     "com.plumtree.portalpages.devices.portlet.common.PortletDevicesModel");
    public const String STR_MVC_CLASS_NAME = "PortletDevices_Devices";
    private AActivitySpace m_asOwner;
    private IPTSession m_ptSession;
    private String m_strHostPageURI = "";
    private int m_nCommunityID = -1;
    private int m_nListID = -1;
    private int m_nNumPortlets = -1;
    private int m_nPageID = -1;
    private int m_nIndex = -1;
    private String m_strPageName;
    private IPTMyPortalGadgetContent m_gadgetContent = null;
    private IPTState m_objAppDataState = null;
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.xpshared.infrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new PortletDevicesModel();
    }
    
    /// <returns></returns>
    public virtual int GetCommunityID()
    {
      return m_nCommunityID;
    }
    
    /// <returns></returns>
    public virtual int GetPortletCount()
    {
      return m_nNumPortlets;
    }
    
    /// <returns></returns>
    public virtual int GetListID()
    {
      return m_nListID;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    public virtual String GetPageName()
    {
      return m_strPageName;
    }
    
    /// <returns></returns>
    public virtual int GetPageID()
    {
      return m_nPageID;
    }
    
    /// <param name="_asOwner"></param>
    public virtual void Init(AActivitySpace _asOwner)
    {
      m_asOwner = _asOwner;
      m_ptSession = (IPTSession) m_asOwner.GetUserSession();
    }
    
    /// <param name="_nCommunityID"></param>
    public virtual void SetCommunityID(int _nCommunityID)
    {
      m_nCommunityID = _nCommunityID;
    }
    
    /// <param name="_strHostPage"></param>
    public virtual void SetHostPageURI(String _strHostPage)
    {
      m_strHostPageURI = _strHostPage;
    }
    
    /// <param name="_nListID"></param>
    public virtual void SetListID(int _nListID)
    {
      m_nListID = _nListID;
    }
    public virtual void SetPageName(String _strPageName)
    {
      m_strPageName = _strPageName;
    }
    public virtual ASURL GetASURL(String _strSpace)
    {
      ASURL myURL = new ASURL(m_asOwner);
      myURL.SetXMLEncoding(true);
      myURL.SetLinkCreateNewSpace(_strSpace, m_asOwner);
      myURL.AddControlArgument(MyPageDevicesControl.STR_PAGE_ID, m_nPageID);
      myURL.AddControlArgument(MyPageDevicesControl.STR_COMMUNITY_ID, m_nCommunityID);
      return myURL;
    }
    
    /// <param name="_nPageID"></param>
    public virtual void SetPageID(int _nPageID)
    {
      m_nPageID = _nPageID;
    }
    public virtual void SetPortletContent(String _strUniqueID)
    {
      m_objAppDataState = AppDataObject.GetAppDataObject(0, m_nPageID, m_strHostPageURI,
       m_asOwner);
      IPTPageInfo ptPageInfo = null;
      //SS - Use the MyPages to open up a MyPage
      if (m_nCommunityID == 0)
      {
        ptPageInfo = m_ptSession.GetMyPages().GetPage(m_nPageID);
      } else
      //SS - Use ITPCommunity to first open up a community and then a MyPage
      {
        IPTCommunityInfo communityInfo = ((IPTCommunityManager) m_ptSession.GetCommunities()).CachedOpenCommunityInfo(m_nCommunityID,
         true);
        ptPageInfo = communityInfo.GetPage(m_nPageID);
      }
      m_gadgetContent = ptPageInfo.QueryPortletContent(m_objAppDataState,
       _strUniqueID, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
      m_nNumPortlets = m_gadgetContent.GetCount();
    }
    public virtual String GetPortletContent()
    {
      try
      {
        Object[][] oPortletContent = (Object[][]) m_gadgetContent.GetContent(m_nIndex);
        HTMLElement tagOutput = GatewayUtils.AddMarkupToSingleElement(m_asOwner,
         oPortletContent);
        return tagOutput.GetDisplayString();
      }
      catch (Exception e)
      {
        log.Error(e, "Error in PortletDevicesModel: ");
      }
      return ("");
    }
    public virtual void SetIndex(int _nIndex)
    {
      m_nIndex = _nIndex;
    }
  }
}