using System;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.pei
{
  /// <summary>
  /// This interface was created to allow developers the ability to create
  /// functions that can be dynamically discovered by the Plumtree application
  /// for the purposes of performing some functionality when a particular
  /// banner search based event occurs. The functions will allow primarily for 
  /// the modification of the Search criteria and the available Search Settings.
  /// <br /><br />
  /// NOTE: Should this interface be implemented more than once within the
  /// Dynamic Discovery process, the implementations will be processed in the
  /// order that they are displayed within the representative XML file. All
  /// implementations will be called.
  /// <br /><br />
  /// NOTE: Developers should be very careful implementing either of these 
  /// functions as these will be called every single time that a Search is 
  /// performed and it could hurt performance.
  /// </summary>
  public interface IBannerSearchActions
  {
    
    /// <summary>
    /// This function allows for the modification of the query portion of a
    /// banner search. Implementers of this interface should modify the
    /// QueryArguments object that is passed in to change the search that will
    /// be run.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_qaQueryInfo">
    /// - On entry, this structure will contain: 
    /// userQuery (String):   String that the user typed into the search box
    /// basicFields (String): null  
    /// advancedFilter (IPTFilter): null
    /// </param>
    void CustomizeQueryOnBeforeSearch(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     QueryArguments _qaQueryInfo);
    
    /// <summary>
    /// This function allows for the modification of the settings used for
    /// banner search. Implementers of this interface should modify the
    /// SearchSettingCollection object that is passed in to change the search
    /// that will be run.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <returns>
    /// SearchSettingCollection that will add or override default
    /// settings
    /// </returns>
    SearchSettingCollection GetCustomSettingsOnBeforeSearch(AActivitySpace _asCurrentSpace,
     IPTSession _ptUserSession);
  }
}