using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.pei
{
  /// <summary>
  /// This interface was created to allow developers the ability to create
  /// functions that can be dynamically discovered by the Plumtree application
  /// for the purposes of performing some functionality when a particular
  /// community based event occurs.
  /// <br /><br />
  /// NOTE: Should this interface be implemented more than once within the
  /// Dynamic Discovery process, the implementations will be processed in the
  /// order that they are displayed within the representative XML file. All
  /// implementations will be called.
  /// </summary>
  public interface ICommunityActions
  {
    
    /// <summary>
    /// This function can be used to notify after a user has directly joined 
    /// a community.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_arrJoinedCommIDs">
    /// - Array of the community IDs being joined as
    /// ints
    /// </param>
    void OnAfterUserJoinsCommunity(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     int[] _arrJoinedCommIDs);
    
    /// <summary>
    /// This function can be used to notify after a user has directly unsubscribed 
    /// from a community.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_arrQuitCommIDs">
    /// - Array of the community IDs being unsubscribed
    /// from as ints
    /// </param>
    void OnAfterUserQuitsCommunity(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     int[] _arrQuitCommIDs);
  }
}