using System;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.pei
{
  /// <summary>
  /// This interface was created to allow developers the ability to create
  /// functions that would be dynamically discovered by the Plumtree application
  /// that would perform some functionality that would occur during the
  /// acceptance of a invitation or manual creation of a user account.
  /// <br /><br />
  /// NOTE: Should this interface be implemented more than once within the
  /// Dynamic Discovery process, the implementations will be processed in the
  /// order that they are displayed within the representative XML file. All
  /// implementations will be called.
  /// <br /><br />
  /// NOTE: In the case where multiple implementations return a String object, all 
  /// the valid Strings (not null and not empty) will be appended together 
  /// (separated by a blank space) and the final String will be the error message 
  /// displayed on the page.
  /// </summary>
  public interface ICreateAccountActions
  {
    
    /// <summary>
    /// This function will perform some functionality after a particular
    /// invitation has been accepted by a anonymous user.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_strInviteCode">- String Code of the Invitation being accepted.</param>
    void OnAfterAcceptInvite(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     String _strInviteCode);
    
    /// <summary>
    /// This function will perform some functionality after the manual creation
    /// of a user account. (Clicking on the Create Account button on the Login 
    /// screen.)
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_strUserName">
    /// - Potential user name for the user trying to be
    /// created.
    /// </param>
    /// <param name="_strPassword">- Potential password for the user trying to be created.</param>
    /// <returns>
    /// String - Error message if the creation should not continue,
    /// empty string or null if it should.
    /// </returns>
    String OnBeforeCreateAccount(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     String _strUserName, String _strPassword);
  }
}