using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.search.network;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.pei
{
  /// <summary>
  /// This interface was created to allow developers the ability to create
  /// functions that can be dynamically discovered by the Plumtree application
  /// for the purposes of performing some functionality when a particular
  /// network search based event occurs.
  /// <br /><br />
  /// NOTE: Should this interface be implemented more than once within the
  /// Dynamic Discovery process, the implementations will be processed in the
  /// order that they are displayed within the representative XML file. All
  /// implementations will be called.
  /// <br /><br />
  /// NOTE: Be careful if implementing this interface more than once, as there 
  /// could be very significant problems if multiple functions are making changes 
  /// to the same list of sources and search string.
  /// </summary>
  public interface INetworkSearchActions
  {
    
    /// <summary>
    /// This function will allow for some validation to occur against the search
    /// string being used and the list of sources being searched against. Once
    /// these items have been reviewed, an Object array will be returned
    /// containing the modified search String and List. or null if no changes
    /// are needed.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_strSearchString">- String containing the search criteria</param>
    /// <param name="_lSourceIDs">
    /// - A IXPList object containing a list of valid Network
    /// Source IDs that were checked by the user.
    /// </param>
    /// <returns>
    /// NetworkSearchArguments - Specific object that will allow the
    /// developer the ability to send both a modified String and
    /// modified List of sources.
    /// </returns>
    NetworkSearchArguments OnBeforeNetworkSearchProcess(AActivitySpace _asCurrentSpace,
     IPTSession _ptUserSession, String _strSearchString, IXPList _lSourceIDs);
    }
}