using System;
using com.plumtree.portalpages.browsing.portalsettings.search;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.pei
{
  /// <summary>
  /// This interface was created to allow developers the ability to create
  /// functions that can be dynamically discovered by the Plumtree application
  /// for the purposes of performing some functionality when a particular
  /// search setting based event occurs.   
  /// <br /><br />
  /// NOTE: Should this interface be implemented more than once within the
  /// Dynamic Discovery process, the implementations will be processed in the
  /// order that they are displayed within the representative XML file. All
  /// implementations will be called.
  /// </summary>
  public interface ISearchSettingActions
  {
    
    /// <summary>
    /// This functions allows for some functionality to occur after the user has
    /// successfully modified or deleted saved searches.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_arrCurrentSavedSearches">
    /// -  Array of current saved search names
    /// (after modifying and/or deleting them)
    /// </param>
    void OnAfterModifyOrRemoveSavedSearch(AActivitySpace _asCurrentSpace,
     IPTSession _ptUserSession, String[] _arrCurrentSavedSearches);
    
    /// <summary>
    /// This function allows for some functionality to occur after the user has
    /// saved a search.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_searchData">
    /// - This is an instance of the SavedSearchData class, which
    /// provides access to the data associated with the saved search.
    /// </param>
    void OnAfterSaveSearch(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     SavedSearchData _searchData);
    
    /// <summary>
    /// This functions allows for some functionality to occur before the user
    /// has successfully deleted a saved search.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_searchData">
    /// - This is an instance of the SavedSearchData class, which
    /// provides access to the data associated with the saved search.
    /// Changes to the data are ignored.
    /// </param>
    void OnBeforeRemoveSavedSearch(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     SavedSearchData _searchData);
    
    /// <summary>
    /// This function allows for some functionality to occur before the user has
    /// saved a search.
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_searchData">
    /// - This is an instance of the SavedSearchData class, which
    /// provides access to the data associated with the saved search.
    /// </param>
    void OnBeforeSaveSearch(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     SavedSearchData _searchData);
  }
}