using System;
using com.plumtree.openfoundation.util;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.pei
{
  /// <summary>
  /// This interface was created to allow developers the ability to create
  /// functions that can be dynamically discovered by the Plumtree application
  /// for the purposes of performing some functionality when a particular
  /// user profile based event occurs.
  /// <br /><br />
  /// NOTE: Should this interface be implemented more than once within the
  /// Dynamic Discovery process, the implementations will be processed in the
  /// order that they are displayed within the representative XML file. All
  /// implementations will be called.
  /// <br /><br />
  /// NOTE: In the case where multiple implementations return a String object, all 
  /// the valid Strings (not null and not empty) will be appended together 
  /// (separated by a blank space) and the final String will be the error message 
  /// displayed on the page.
  /// </summary>
  public interface IUserProfileActions
  {
    
    /// <summary>
    /// This functions was created to allow for some kind of verification of
    /// data to occur when a user tries to change their user profile.  It gets
    /// called every time the editor attempts to save a page.
    /// <br /><br />
    /// Warning: Values in _htFormData are String Arrays (String[]).<br />
    /// e.g.: <br />
    /// String[] arrVals = (String[]) _htFormData.GetElement(sKey);<br />
    /// String sVal = arrVals[0];
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_htFormData">
    /// - This parameter referes to all of the data that the
    /// user is dealing with. It would correspond to each piece of the
    /// User Profile View.
    /// </param>
    /// <param name="_htPropObjs">
    /// - This parameter is a hashtable containing all of the
    /// necessary Property data, using the html input name as the key.
    /// With the Property object, information such as the id, name, and
    /// type can be retrieved.
    /// </param>
    /// <returns>
    /// String - This will be a string containing a error message if the
    /// data was incorrect or if the process should not continue
    /// otherwise it will be null or "".
    /// </returns>
    String OnBeforeChangeUserProfile(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     XPHashtable _htFormData, XPHashtable _htPropObjs);
    
    /// <summary>
    /// This functions was created to allow for some kind of verification of
    /// data to occur before a user tries to store their user profile.  It gets
    /// called every time the editor is finished.
    /// <br /><br />
    /// Warning: Values in _htFormData are String Arrays (String[]).<br />
    /// e.g.: <br />
    /// String[] arrVals = (String[]) _htFormData.GetElement(sKey);<br />
    /// String sVal = arrVals[0];
    /// </summary>
    /// <param name="_asCurrentSpace">
    /// - Provides access to the current MVC classes as
    /// well as the Application and the HTTP Session
    /// </param>
    /// <param name="_ptUserSession">- Plumtree session object for the current user</param>
    /// <param name="_htPropObjs">
    /// - This parameter is a hashtable containing all of the
    /// necessary Property data, using the Property ID as the key.  With
    /// the Property object, information such as the id, name, and type
    /// can be retrieved.
    /// </param>
    /// <returns>
    /// String - This will be a string containing a error message if the
    /// data was incorrect or if the process should not continue
    /// otherwise it will be null or "".
    /// </returns>
    String OnBeforeStoreUserProfile(AActivitySpace _asCurrentSpace, IPTSession _ptUserSession,
     XPHashtable _htPropObjs);
  }
}