using System;
using OpenLogService=com.plumtree.openlog.OpenLogService;
using OpenLogger=com.plumtree.openlog.OpenLogger;
using DefaultFooterView=com.plumtree.portalpages.common.uiparts.DefaultFooterView;
using DefaultHeaderView=com.plumtree.portalpages.common.uiparts.DefaultHeaderView;
using NavigationModel=com.plumtree.portalpages.common.uiparts.NavigationModel;
using com.plumtree.portaluiinfrastructure.htmlconstructs;
using IntrinsicPortletView=com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView;
using PTDebugHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
using com.plumtree.portaluiinfrastructure;
namespace com.plumtree.portalpages.portlets.headerfooter
{
  /// <summary>
  /// Standard Footer intrinsic portlet that wraps DefaultFooterView.
  /// </summary>
  /// <author>DavidP</author>
  public class StandardFooterView : IntrinsicPortletView,IView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.headerfooter.StandardFooterView");
    
    /// <summary>
    /// MVC Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "StandardFooter";
    private AActivitySpace m_asOwner;
    private IModelRO m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new StandardFooterView();
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#display()"></seealso>
    public override HTMLElement Display()
    {
      return DisplayPortlet();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.xpshared.activityspace.IView#Init(IModel,AActivitySpace)"></seealso>
    public override void Init(IModelRO model, AActivitySpace parent)
    {
      m_asOwner = parent;
      // Ignore the passed-in model and extract the nav model instead
      m_model = (NavigationModel) parent.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
      }
    
    /// <summary>
    /// Form default Footer HTML
    /// </summary>
    /// <returns>HTMLElement					The HTML for the Footer</returns>
    private HTMLElement GetTable()
    {
      HTMLElement result = null;
      try
      {
        // Create footer table
        HTMLTable footerTable = new HTMLTable();
        footerTable.SetID(PTStyleID.PT_FOOTER);
        footerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        footerTable.SetCellPadding(CommonHTMLStrings.FIVE);
        footerTable.SetBorder(CommonHTMLStrings.ZERO);
        footerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        // Configure table
        footerTable.SetStyle("border-bottom:1px solid rgb(2,80,162); width:100%; vertical-align:middle;");
        // Create footer row
        HTMLTableRow onlyRow = (HTMLTableRow) footerTable.InsertInnerHTMLElement(new HTMLTableRow());
        // Set up table cell
        HTMLTableCell onlyCell = (HTMLTableCell) onlyRow.InsertInnerHTMLElement(new HTMLTableCell());
        onlyCell.SetVAlign(CommonHTMLStrings.MIDDLE);
        onlyCell.SetAlign(CommonHTMLStrings.CENTER);
        onlyCell.SetStyle("text-align:center; font:normal 10px/10px Verdana, Arial, Helvetica, sans-serif;");
        //onlyCell.SetStyleClass(PTStyleClass.FOOT_HEADER_BG + " " + PTStyleClass.FOOT_TEXT);
        // Put subtitle in its own span
        //onlyCell.AddInnerHTMLString(m_asOwner.GetString(243, "ptmsgs_portalcommonmsgs"));
        // Continue adding content to the table cell
        onlyCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        //onlyCell.AddInnerHTMLString(m_asOwner.GetString(244, "ptmsgs_portalcommonmsgs"));
        // Deliver the finished footer table
        result = footerTable;
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating footer table: " + e.Message);
        }
      return result;
    }
    
    /// <summary>
    /// Displays the HTML for the portlet. The child classes must implement this
    /// function. This function is called by Display().
    /// </summary>
    /// <returns>HTML for portlet</returns>
    public override HTMLElement DisplayPortlet()
    {
      HTMLElement result = null;
      try
      {
        result = GetTable();
      }
      catch (Exception e)
      {
        result = new HTMLGenericElement("Error creating footer: " + e.Message);
        }
      return result;
    }
    
    /// <summary>
    /// Displays the WML for the portlet. The child classes must implement this
    /// function.  This function is called by DisplayWML().
    /// </summary>
    /// <returns>WML for portlet</returns>
    public override String DisplayPortletWML()
    {
      return null;
    }
  }
}