using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
namespace com.plumtree.portalpages.portlets.jobhistory
{
  /// <summary>
  /// This class implements the control for the Job History intrinsic portlet
  /// </summary>
  /// <author>JohnH</author>
  public class JobHistoryPortletControl : IntrinsicPortletControl
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.jobhistory.JobHistoryPortletControl");
    
    /// <summary>
    /// Class name for the control. For intrinsic portlets, the control must
    /// have the same class name as the model.
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = JobHistoryPortletModel.STR_MVC_CLASS_NAME;
    
    /// <summary>
    /// Move to the first history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_FIRSTHISTORYPAGE = 22;
    
    /// <summary>
    /// Move to the previous history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE = 23;
    
    /// <summary>
    /// Move to the next history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_NEXTHISTORYPAGE = 24;
    
    /// <summary>
    /// Move to the last history page 
    /// </summary>
    public const int POSTTOSELF_ACTION_LASTHISTORYPAGE = 25;
    
    /// <summary>
    /// Pop up the job detail window 
    /// </summary>
    public const int POSTTOSELF_ACTION_JOBDETAIL_POPUP = 30;
    
    /// <summary>
    /// Abort job action 
    /// </summary>
    public const int POSTTOSELF_ACTION_ABORT = 40;
    //Constant for delete vs. filter mode
    
    /// <summary>
    /// Filter mode 
    /// </summary>
    public const int FILTERMODE = 1;
    
    /// <param name="arguments"></param>
    /// <returns></returns>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobHistoryPortletControl();
    }
    
    /// <summary>
    /// Returns the name for the control
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_nAction"></param>
    /// <param name="_htFormData"></param>
    public override void PerformRepostAction(int _nAction, XPHashtable _htFormData)
    {
      int nAction = _nAction;
      // JHQ for issue 36772: super.CheckActionSecurityAndExecute() will treate LOW_BANDWIDTH 
      // the same as 508 and therefore look for in_su508PostToSelf_ instead of PostToSelf.
      // But in LB we can execute javascript and we use PostToSelf.
      if (AccessStyles.LOW_BANDWIDTH == m_asOwner.GetAccessStyle())
      {
        if (_htFormData.ContainsKey(RepostControl.HTMLINPUT_POSTTOSELF))
        {
          String[] data = (String[]) _htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
          if ((0 != data.Length) && (null != data[0]))
          {
            nAction = XPConvert.ToInteger(data[0]);
            log.Debug("JobHistoryPortletControl::PerformRepostAction Repost action ID value: " + nAction);
            } else
          {
            log.Warn("JobHistoryPortletControl::PerformRepostAction Repost action ID was not in Query String.");
            }
        }
      }
      switch (nAction){
      case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
      SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_FIRSTHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
      SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
      SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_NEXTHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_LASTHISTORYPAGE:
      SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_LASTHISTORYPAGE);
      break;
      case POSTTOSELF_ACTION_JOBDETAIL_POPUP:
      PerformJobDetailPopupAction(_htFormData);
      break;
      case POSTTOSELF_ACTION_ABORT:
      AbortJob(_htFormData);
      break;
      }
    }
    
    /// <summary>
    /// JH- PerformJobDetailPopupAction handles the case where a popup is being
    /// displayed
    /// </summary>
    /// <param name="_htFormData">is a hashtable that stores the form post data and querystring</param>
    private void PerformJobDetailPopupAction(XPHashtable _htFormData)
    {
      //JH- Get the row number of the item we're displaying and store it in the Model, where
      //	the Form can get to it.
      ((JobHistoryPortletModel) m_model).SetRowToDisplay(XPConvert.ToInteger(((String[]) _htFormData.GetElement(HistoryViewHelper.POPUP_CONTROL_ARG_ROWTOVIEW))[0]));
      ((JobHistoryPortletModel) m_model).SetJobName(((String[]) _htFormData.GetElement(HistoryViewHelper.POPUP_CONTROL_ARG_JOBNAME))[0]);
      ((JobHistoryPortletModel) m_model).SetRunTime(((String[]) _htFormData.GetElement(HistoryViewHelper.POPUP_CONTROL_ARG_RUNTIME))[0]);
      //Reset the current page of the job log to display back to 1
      ((JobHistoryPortletModel) m_model).SetCurrentLogPage(1);
    }
    
    /// <summary>
    /// JH- SetNewHistoryPageID sets the History Page ID on the model so the
    /// HistoryViewHelper can know which page of the job history to display
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <param name="intAction">- The action to take: First, Previous, Next, Last</param>
    private void SetNewHistoryPageID(XPHashtable _htFormData, int intAction)
    {
      int intCurrentPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(HistoryViewHelper.HTMLHIDDEN_CURRENTPAGE))[0]);
      int intLastPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(HistoryViewHelper.HTMLHIDDEN_LASTPAGE))[0]);
      //set the appropriate BlockID based on the action
      switch (intAction){
      case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
      ((JobHistoryPortletModel) m_model).SetCurrentPage(1);
      break;
      case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
      ((JobHistoryPortletModel) m_model).SetCurrentPage(intCurrentPage - 1);
      break;
      case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
      ((JobHistoryPortletModel) m_model).SetCurrentPage(intCurrentPage + 1);
      break;
      case POSTTOSELF_ACTION_LASTHISTORYPAGE:
      ((JobHistoryPortletModel) m_model).SetCurrentPage(intLastPage);
      break;
      }
    }
    private void AbortJob(XPHashtable _htFormData)
    {
      //Send a kill message to the job or jobs
      try
      {
        ((JobHistoryPortletModel) m_model).KillJobs(_htFormData);
      }
      catch (Exception e)
      {
        log.Error("JobLogRepostModel::DoTaskOnStartEditor " + m_asOwner.GetString(632,
         "ptmsgs_portalcommonmsgs") + e);
        UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
         null, m_asOwner.GetString(632, "ptmsgs_portalcommonmsgs") + e, "");
        myError.SetActivitySpace(m_asOwner.GetName());
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        }
    }
  }
}