using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
namespace com.plumtree.portalpages.portlets.jobhistory
{
  /// <summary>
  /// This class implements the model for the Job History intrinsic portlet
  /// </summary>
  /// <author>JohnH</author>
  public class JobHistoryPortletModel : IntrinsicPortletModel,IJobHistoryPortletModelRO,
  IRepostModel,IJobLogModelRO
  {
    
    /// <summary>
    /// Class name for the model 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "JobHistoryPortlet";
    
    /// <summary>
    /// JobLogHistory helper model 
    /// </summary>
    private JobLogModelHelper myModelHelper;
    
    /// <summary>
    /// Returns true if this portlet has a control class
    /// </summary>
    /// <returns>boolean</returns>
    public override bool ControlExists()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobHistoryPortletModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public virtual void Finish()
    {
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public override Object GetNewTempData()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the portlet name
    /// </summary>
    /// <returns>Portlet name</returns>
    public virtual String GetPortletName()
    {
      return m_ptPortlet.GetLocalizedName();
    }
    
    /// <summary>
    /// Returns the Redirect object  (this is were we need to go at the end of
    /// the Editor).
    /// </summary>
    /// <returns>Redirect</returns>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <summary>
    /// Inits the Model with the IPTSession.
    /// </summary>
    /// <param name="parent"></param>
    public override void Init(AActivitySpace parent)
    {
      base.Init(parent);
      myModelHelper = new JobLogModelHelper(parent, (IPTSession) parent.GetUserSession());
      //Get the locale
      String strLocaleID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE,
       parent);
      XPLocale m_Locale = new XPLocale(strLocaleID);
      if (null == m_Locale)
      {
        m_Locale = XPLocale.GetDefault();
      }
      String strTimeZone = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE,
       parent);
      XPTimeZone m_Timezone = XPTimeZone.GetCurrentTimeZone();
      if (null != strTimeZone)
      {
        m_Timezone = XPTimeZone.GetTimeZone(strTimeZone);
      } else
      {
        m_Timezone = XPTimeZone.GetCurrentTimeZone();
      }
      myModelHelper.InitializeDatePickerMgrs(m_Locale, m_Timezone);
    }
    // BEGIN ***************** repost action methods *****************
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      int nSaveStatus = RepostControl.PAGE_STATUS_VALID;
      return nSaveStatus;
    }
    
    /// <summary>
    /// This function returns an int array of JobID's to be killed
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int[]</returns>
    public virtual int[] GetArrayOfJobsToKill(XPHashtable _htFormData)
    {
      return myModelHelper.GetArrayOfJobsToKill(_htFormData);
    }
    
    /// <summary>
    /// This function will send a kill message to each job that has been checked
    /// by the user.
    /// </summary>
    /// <param name="_htFormData"></param>
    public virtual void KillJobs(XPHashtable _htFormData)
    {
      myModelHelper.KillJobs(_htFormData);
    }
    // END ***************** repost action methods *****************
    // BEGIN ***************** Get and Set methods *****************
    
    /// <summary>
    /// Returns whether the very last request is a search of the job log.
    /// </summary>
    /// <returns>int</returns>
    public virtual bool IsSearchRequest()
    {
      return myModelHelper.IsSearchRequest();
    }
    
    /// <summary>
    /// Returns a string used for searching the job log.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetSearchString()
    {
      return myModelHelper.GetSearchString();
    }
    
    /// <summary>
    /// Returns the log page currently being displayed.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCurrentLogPage()
    {
      return myModelHelper.GetCurrentLogPage();
    }
    
    /// <summary>
    /// Returns CurrentPage setting.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetCurrentPage()
    {
      return myModelHelper.GetCurrentPage();
    }
    
    /// <summary>
    /// Returns the jobID.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetJobID()
    {
      return myModelHelper.GetJobID();
    }
    
    /// <summary>
    /// Returns the jobName.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetJobName()
    {
      return myModelHelper.GetJobName();
    }
    
    /// <summary>
    /// Returns the Plumtree Session object.
    /// </summary>
    /// <returns>IPTSession</returns>
    public virtual IPTSession GetPTSession()
    {
      return myModelHelper.GetPTSession();
    }
    
    /// <summary>
    /// Returns the job history row to display in the job log detail viewer.
    /// </summary>
    /// <returns>int</returns>
    public virtual int GetRowToDisplay()
    {
      return myModelHelper.GetRowToDisplay();
    }
    
    /// <summary>
    /// Returns the runTime.
    /// </summary>
    /// <returns>String</returns>
    public virtual String GetRunTime()
    {
      return myModelHelper.GetRunTime();
    }
    
    /// <summary>
    /// Sets the the search term and indicates a result page
    /// </summary>
    /// <param name="SearchTerm">to be applied against the log text</param>
    public virtual void SetLogSearchPage(String strSearchText)
    {
      myModelHelper.SetLogSearchPage(strSearchText);
    }
    
    /// <summary>
    /// Sets the the log page currently being displayed.
    /// </summary>
    /// <param name="currentLogPage">The currentLogPage to set</param>
    public virtual void SetCurrentLogPage(int currentLogPage)
    {
      myModelHelper.SetCurrentLogPage(currentLogPage);
    }
    
    /// <summary>
    /// Sets CurrentRecord setting.
    /// </summary>
    public virtual void SetCurrentPage(int _intCurrentPage)
    {
      myModelHelper.SetCurrentPage(_intCurrentPage);
    }
    
    /// <summary>
    /// Sets the jobID.
    /// </summary>
    /// <param name="jobID">The jobID to set</param>
    public virtual void SetJobID(int jobID)
    {
      myModelHelper.SetJobID(jobID);
    }
    
    /// <summary>
    /// Sets the jobName.
    /// </summary>
    /// <param name="jobName">The jobName to set</param>
    public virtual void SetJobName(String jobName)
    {
      myModelHelper.SetJobName(jobName);
    }
    
    /// <summary>
    /// Sets the job history row to display in the job log detail viewer.
    /// </summary>
    /// <param name="rowToDisplay">The rowToDisplay to set</param>
    public virtual void SetRowToDisplay(int rowToDisplay)
    {
      myModelHelper.SetRowToDisplay(rowToDisplay);
    }
    
    /// <summary>
    /// Sets the runTime.
    /// </summary>
    /// <param name="runTime">The runTime to set</param>
    public virtual void SetRunTime(String runTime)
    {
      myModelHelper.SetRunTime(runTime);
    }
    
    /// <summary>
    /// Returns the log file in byte array format
    /// </summary>
    /// <returns>byte[]</returns>
    public virtual byte[] GetLogFile()
    {
      return null;
    }
    
    /// <summary>
    /// Get the Date picker control manager
    /// </summary>
    /// <returns>JSDatePickerMgr</returns>
    public virtual JSDatePickerMgr GetDatePickerControlManager()
    {
      return myModelHelper.GetDatePickerControlManager();
    }
  }
}
// END ***************** Get and Set methods *****************
