using System;
using com.plumtree.openlog;
using com.plumtree.portalpages.common.joblogs;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.jobhistory
{
  /// <summary>
  /// This class displays the HTML for the Job History intrinsic portlet
  /// </summary>
  /// <author>JohnH</author>
  public class JobHistoryPortletView : IntrinsicPortletView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.jobhistory.JobHistoryPortletView");
    
    /// <summary>
    /// Class name for the view. For intrinsic portlets, the view must have the
    /// same class name as the model.
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = JobHistoryPortletModel.STR_MVC_CLASS_NAME;
    private HistoryViewHelper myViewHelper;
    
    /// <summary>
    /// Creates a new SamplePortletView object.
    /// </summary>
    public JobHistoryPortletView()
    {
      // We need a form because we have a repost button.
      m_bAddFormToPortlet = true;
      m_bMultiPart = false;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new JobHistoryPortletView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on
    /// the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      myViewHelper = new HistoryViewHelper(m_model, m_asOwner, true, IntrinsicPortletView.INTRINSIC_PORTLET_JAVASCRIPT_SUBMIT_FORM + ((IIntrinsicPortletModelRO) m_model).GetPortletID());
      IIntrinsicPortletModelRO iModelRO = (IIntrinsicPortletModelRO) m_model;
      String strPortletFormName = IntrinsicPortletView.INTRINSIC_PORTLET_HTMLFORM_NAME + iModelRO.GetPortletID();
      String newScript = myViewHelper.GetJavascript(strPortletFormName);
      myScript.AddInnerHTMLString(newScript);
      return myScript;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()"></seealso>
    public override HTMLElement DisplayPortlet()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      myViewHelper = new HistoryViewHelper(m_model, m_asOwner, true, IntrinsicPortletView.INTRINSIC_PORTLET_JAVASCRIPT_SUBMIT_FORM + ((IIntrinsicPortletModelRO) m_model).GetPortletID());
      try
      {
        HTMLComment myComment = new HTMLComment("Begin: Display HistoryView");
        result.AddInnerHTMLElement(myComment);
        //Add the action bar
        result.AddInnerHTMLElement(myViewHelper.AddActionBar());
        //Add the job log detail
        result.AddInnerHTMLElement(myViewHelper.GetJobLogDetail());
        myComment = new HTMLComment("End: Display HistoryView");
        result.AddInnerHTMLElement(myComment);
      }
      catch (Exception e)
      {
        PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Portlets"),
         "JobHistoryPortletView::DisplayPortlet", e, true, UIErrorLevel.SERIOUS,
         m_asOwner.GetString(92, "ptmsgs_portalcommonmsgs"));
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()"></seealso>
    public override String DisplayPortletWML()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}