using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.browsing.login.createaccount;
using com.plumtree.portalpages.common.login;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.login
{
  /// <author>
  /// mikej
  /// Created on Mar 28, 2003
  /// </author>
  public class LoginPortletView : IntrinsicPortletView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.login.LoginPortletView");
    public static readonly String STR_MVC_CLASS_NAME = LoginPortletModel.STR_MVC_CLASS_NAME;
    public const String LOGIN_PORTLET_FORM = "LoginPortletForm";
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
     
    public override Object Create()
    {
      return new LoginPortletView();
    }
    
    /// <returns></returns>
    public override HTMLScript DisplayJavascript()
    {
      return LoginHTML.GetLoginJScript(false, LOGIN_PORTLET_FORM, XPConvert.ToString(((IIntrinsicPortletModelRO) m_model).GetPortletID()));
      }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()
     */
     
    public override HTMLElement DisplayPortlet()
    {
      HTMLTable myTable;
      HTMLElement myCreateLink = null;
      // Get 508 mode
      bool b508 = false;
      int nAccessStyle;
      try
      {
        // This should not need to check for the access style cookie because
        // CachePersonalSettings does this for us.
        //	default access style for the current user.
        nAccessStyle = m_asOwner.GetAccessStyle().GetAccessID();
      }
      catch (Exception ex)
      {
        log.Debug(ex, "Unable to get config var as int.");
        nAccessStyle = 3;
      }
      if (nAccessStyle != AccessStyles.STANDARD.GetAccessID())
      {
        b508 = true;
      }
      // Create Login Form
      HTMLForm myForm = new HTMLForm("loginFormID");
      myForm.bForceFormattingOn = true;
      myTable = LoginHTML.GetLoginDirections(m_asOwner, "100%", false);
      myForm.AddInnerHTMLElement(myTable);
      // Only create this link if we are actually going to use it.
      if (PTLoginHelper.GetAllowUserCreation(m_asOwner, m_asOwner.GetApplication()))
      {
        // CREATE ACCOUNT LINK
        //   This button can just be a redirect because the form
        //   needn't be submitted.
        ASURL myHRef = new ASURL(m_asOwner);
        myHRef.SetLinkGetSpaceIfCached(CreateAccountAS.STR_MVC_CLASS_NAME,
         this.m_asOwner);
        myHRef.SetControl(CreateAccountControl.STR_MVC_CLASS_NAME);
        // Create an account
        myHRef.AddInnerHTMLString(m_asOwner.GetString(637, "ptmsgs_portalbrowsingmsgs"));
        // Create an account
        ((HTMLAnchor) myHRef.GetURLAsHTMLElement()).SetTitle(m_asOwner.GetString(1459,
         "ptmsgs_portalbrowsingmsgs"));
        myCreateLink = myHRef.GetURLAsHTMLElement();
      }
      IIntrinsicPortletModelRO imodel = (IIntrinsicPortletModelRO) m_model;
      String sUniquifier = XPConvert.ToString(imodel.GetPortletID());
      LoginPortletModel model = (LoginPortletModel) m_model;
      //show authsource dropdown?
      bool bShowAuthsourceDropdown = PTLoginHelper.ShowAuthDropdown();
      bool bAllowAuthSourceDropdownDisplay = PTLoginHelper.AllowAuthDropdown();
      if (!bAllowAuthSourceDropdownDisplay)
      {
        // Mode 3 means never show auth source dropdown
        bShowAuthsourceDropdown = false;
      }
      LoginHTML.MakeLoginForm(myForm, LOGIN_PORTLET_FORM, LoginAS.STR_MVC_CLASS_NAME,
       XPConvert.ToString(model.GetPortletID()), LoginControl.STR_MVC_CLASS_NAME,
       m_asOwner, b508, sUniquifier, myCreateLink, bShowAuthsourceDropdown,
       bAllowAuthSourceDropdownDisplay);
      // WilliamA - check if there's redirect-after-login URL
      // if there is, set it as a hidden input in the login form
      String redirectAfterLoginURL = (String) m_asOwner.GetSubSession().GetAttribute("PT_" + ASConstants.REDIRECT_AFTER_LOGIN);
      if (null != redirectAfterLoginURL && redirectAfterLoginURL.Length > 0)
      {
        // Sets the space name for the event to be passed to the server
        HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.REDIRECT_AFTER_LOGIN_INPUT,
         ASConstants.REDIRECT_AFTER_LOGIN_INPUT, "This is an input");
        myInput.SetValue(redirectAfterLoginURL);
        myForm.AddInnerHTMLElement(myInput);
      }
      return myForm;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()"></seealso>
    public override String DisplayPortletWML()
    {
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}