using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.portlets.savedsearch
{
  /// <author>mikesample</author>
  public class SavedSearchPortletControl : IntrinsicPortletControl
  {
    
    /// <summary>
    /// Class name for the control. For intrinsic portlets, the control must
    /// have the same class name as the model.
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = SavedSearchPortletModel.STR_MVC_CLASS_NAME;
    public const int POSTTOSELF_ACTION_SUBSCRIBE = 33;
    public const int POSTTOSELF_ACTION_UNSUBSCRIBE = 34;
    public const int POSTTOSELF_ACTION_MORE_LINK = 35;
    public const int POSTTOSELF_ACTION_CHANGE_SUBSCRIPTION = 36;
    public const int POSTTOSELF_ACTION_PARAMETRIC_SEARCH = 37;
    public const int POSTTOSELF_ACTION_CLEAR_PARAMETRIC_SEARCH = 38;
    public const int POSTTOSELF_ACTION_SORT = 39;
    public const int POSTTOSELF_ACTION_PAGINATE = 40;
    //	public static final int POSTTOSELF_ACTION_INPLACE_REFRESH = 41;
    
    /// <param name="arguments"></param>
    /// <returns></returns>
    public override Redirect CheckActionSecurityAndExecute(XPHashtable _htFormData)
    {
      Redirect r = null;
      SavedSearchPortletModel myModel = (SavedSearchPortletModel) m_model;
      String sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_RESULTPAGE + myModel.GetPortletID();
      String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
      if ((null != aDataValues) && !(0 == aDataValues.Length))
      {
        int iVal = XPConvert.ToInteger(aDataValues[0]);
        if (1 == iVal)
        {
          r = ((SavedSearchPortletModel) m_model).ConvertSearchToQueryString();
          }
      }
      return r;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SavedSearchPortletControl();
    }
    
    /// <returns></returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="_nAction"></param>
    /// <param name="_htFormData"></param>
    public override void PerformRepostAction(int _nAction, XPHashtable _htFormData)
    {
      SavedSearchPortletModel myModel = (SavedSearchPortletModel) m_model;
      if (_nAction == GetUniqueAction(POSTTOSELF_ACTION_CHANGE_SUBSCRIPTION))
      {
        String sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_MAILID + myModel.GetPortletID();
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValues) && !(0 == aDataValues.Length))
        {
          int subscribe = XPConvert.ToInteger(aDataValues[0]);
          switch (subscribe){
          case POSTTOSELF_ACTION_SUBSCRIBE:
          case POSTTOSELF_ACTION_UNSUBSCRIBE:
          myModel.SetSubscribe(subscribe);
          break;
          default:
          break;
          }
        }
      } else
      if (_nAction == GetUniqueAction(POSTTOSELF_ACTION_PARAMETRIC_SEARCH))
      {
        myModel.ClearParametericResults();
        myModel.SetParametericFilter(_htFormData);
      } else
      if (_nAction == GetUniqueAction(POSTTOSELF_ACTION_CLEAR_PARAMETRIC_SEARCH))
      {
        myModel.ClearParametericResults();
      } else
      if (_nAction == GetUniqueAction(POSTTOSELF_ACTION_SORT))
      {
        String sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_SORTID + myModel.GetPortletID();
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        if ((null != aDataValues) && !(0 == aDataValues.Length))
        {
          int sortid = XPConvert.ToInteger(aDataValues[0]);
          myModel.SetSortOrder(sortid);
        }
      } else
      if (_nAction == GetUniqueAction(POSTTOSELF_ACTION_PAGINATE))
      {
        /*TODO: error handle here */
        String sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_PAGINATE_NUM + myModel.GetPortletID();
        String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        int num = 0;
        if ((null != aDataValues) && !(0 == aDataValues.Length))
        {
          num = XPConvert.ToInteger(aDataValues[0]);
        }
        sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_PAGINATE_FIRST + myModel.GetPortletID();
        aDataValues = (String[]) _htFormData.GetElement(sDataKey);
        int first = 0;
        if ((null != aDataValues) && !(0 == aDataValues.Length))
        {
          first = XPConvert.ToInteger(aDataValues[0]);
        }
        myModel.GoToPage(null, first, num, null);
      }
    }
    //		else if (_nAction == RepostControl.POSTTOSELF_ACTION_IN_PLACE_REFRESH)
    //		{
    //		    /*TODO: error handle here */
    //			String sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_PAGINATE_NUM + myModel.GetPortletID();
    //			String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);
    //	
    //			int num = 0;
    //			if ((null != aDataValues) && !(0 == aDataValues.length))
    //			{
    //				num = XPConvert.ToInteger(aDataValues[0]);
    //			}
    //			
    //			
    //			sDataKey = SavedSearchPortletView.HTMLHIDDENINPUT_PAGINATE_FIRST + myModel.GetPortletID();
    //			aDataValues = (String[]) _htFormData.GetElement(sDataKey);
    //	
    //			int first = 0;
    //			if ((null != aDataValues) && !(0 == aDataValues.length))
    //			{
    //				first = XPConvert.ToInteger(aDataValues[0]);
    //			}
    //			
    //		    myModel.GoToPage(null, first, num, null);
    //
    //	        /* in place refresh */
    ////	        m_asOwner.SetIsInPlaceRefreshEnabled(true);
    //		}
    
    /// <summary>
    /// Appends the portlet ID to the PostToSelfAction for uniqueness
    /// </summary>
    /// <param name="_nPostToSelfAction"></param>
    /// <returns>int representing the (action).append(portletid)</returns>
    private int GetUniqueAction(int _nPostToSelfAction)
    {
      return XPConvert.ToInteger(XPConvert.ToString(_nPostToSelfAction) + XPConvert.ToString(((SavedSearchPortletModel) m_model).GetPortletID()));
      }
  }
}