using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.filter;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.search;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.uiinfrastructure.pagecontrols.framework;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker;
using com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker;
using com.plumtree.uiinfrastructure.pagination;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.jsutil;
namespace com.plumtree.portalpages.portlets.savedsearch
{
  /// <author>mikesample</author>
  public class SavedSearchPortletModel : IntrinsicPortletModel,ISavedSearchPortletModelRO,
  IRepostModel,IPagination,IPaginationRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.savedsearch.SavedSearchPortletModel");
    
    /// <summary>
    /// Class name for the model 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SavedSearchPortlet";
    public const String strTitleKey = "SRCHTITLE";
    //	public final static String strSimpleKey = "SIMPLE";
    //	public final static String strSrchIDKey = "SAVSRCHID";
    public const String ADMIN_PREF_DISPLAY_FIELDS = "DISPLAYFLDS";
    public const String ADMIN_PREF_PARAMETERIC_PROPS = "PARAMETERICS";
    
    /// <summary>
    /// Index of search title in data array 
    /// </summary>
    public const int DATA_INDEX_SEARCHTITLE = 0;
    
    /// <summary>
    /// Index of simple flag in data array 
    /// </summary>
    public const int DATA_INDEX_SIMPLE = 1;
    
    /// <summary>
    /// Index of search ID in data array 
    /// </summary>
    public const int DATA_INDEX_SEARCHID = 2;
    
    /// <summary>
    /// Index of search ID in data array 
    /// </summary>
    public const int DATA_INDEX_PARAMETERICIDS = 3;
    
    /// <summary>
    /// Index of search ID in data array 
    /// </summary>
    public const int DATA_INDEX_DISPLAY_FIELDS = 4;
    
    /// <summary>
    /// Index of Property ID in property info array 
    /// </summary>
    public const int PROPINFO_INDEX_ID = 0;
    
    /// <summary>
    /// Index of Property Name in property info array 
    /// </summary>
    public const int PROPINFO_INDEX_NAME = 1;
    
    /// <summary>
    /// Index of Property Type in property info array 
    /// </summary>
    public const int PROPINFO_INDEX_TYPE = 2;
    
    /// <summary>
    /// Index of UI Orientation (column or row) in property info array 
    /// </summary>
    public const int PROPINFO_INDEX_ORIENT = 3;
    
    /// <summary>
    /// orientation values - column 
    /// </summary>
    public const String PROPINFO_ORIENT_COL = "c";
    
    /// <summary>
    /// orientation values - row 
    /// </summary>
    public const String PROPINFO_ORIENT_ROW = "r";
    private IPTSavedSearchManager m_SrchMgr;
    private int m_nSavSrchID = 0;
    private int m_nUserID;
    private Object[] m_arSearchSettings;
    /* datepicker objects */
    private PageMgr m_pageMgr;
    private JSDateTimePickerMgr m_dtPickerMgr;
    private IPTFilter m_filter;
    private FilterIterator m_itrFilter;
    private bool m_bIsParameterized;
    private bool m_bHasFollowupResults;
    private int m_nSortID = 0;
    private int m_nPaginateSize = 0;
    private int m_nPaginateTotal = 0;
    private int m_nPaginateFirstIndx = 1;
    private int m_nMaxResultsCnt = 0;
    
    /// <returns></returns>
    public override bool ControlExists()
    {
      return true;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SavedSearchPortletModel();
    }
    
    /// <summary>
    /// Implement some code to execute when the user clicks on "Finish".
    /// </summary>
    public virtual void Finish()
    {
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#InitPortlet(com.plumtree.server.IPTPageInfo, com.plumtree.server.IPTState, com.plumtree.server.IPTGadget, int)
     */
     
    public override void InitPortlet(IPTPageInfo _ptPageInfo, IPTState _ptAppDataState,
     IPTGadget _ptPortlet, int _nPortletID)
    {
      base.InitPortlet(_ptPageInfo, _ptAppDataState, _ptPortlet, _nPortletID);
      GetData();
      InitDatePickerObjects();
      m_bIsParameterized = InitParametericPropObjects();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.portlets.savedsearch.ISavedSearchPortletModelRO#GetAdminPrefs()
     */
     
    public virtual Object[] GetSearchSettings()
    {
      return m_arSearchSettings;
    }
    
    /// <returns></returns>
    /// <throws>XPException </throws>
    private void GetData()
    {
      try
      {
        /* we ge the sq id from the ref property */
        /* we are opening the portlet object here because m_ptPortlet uses a
         * nullservercontext, which will not allow us to get the object properties */
         
        IPTGadget ourPortlet = (IPTGadget) this.m_ptSession.GetGadgets().Open(m_nPortletID,
         false);
        IPTObjectProperties properties = ourPortlet.GetObjectProperties();
        IPTQueryResult result = properties.GetSinglePropertyRefData(PT_INTRINSICS.PT_SNAPSHOT_QUERY_REFERENCE,
         PT_PROPIDS.PT_PROPID_PROP_VALUE);
        m_nSavSrchID = result.ItemAsInt(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);
        IPTAdminSettings ptAdminSettings = (IPTAdminSettings) m_ptPortlet;
        String[] aSettings = new String[3];
        aSettings[0] = strTitleKey;
        //			aSettings[1]     = strSimpleKey;
        //			aSettings[1]     = strSrchIDKey;
        aSettings[1] = ADMIN_PREF_PARAMETERIC_PROPS;
        aSettings[2] = ADMIN_PREF_DISPLAY_FIELDS;
        Object[][] arData = (Object[][]) ptAdminSettings.LookupAdminGadgetSettings(aSettings);
        if (null != arData)
        {
          m_arSearchSettings = new Object[5];
          m_arSearchSettings[DATA_INDEX_SEARCHID] = m_nSavSrchID;
          for (int i = 0;i < arData[0].Length;i++)
          {
            String strSettingName = (String) arData[0][i];
            Object oSettingValue = arData[1][i];
            /* we ge the sq id from the ref property */
            //					if (XPStringUtility.EqualsIgnoreCase(strSettingName,SavedSearchPortletModel.strSrchIDKey))
            //					{
            //						m_nSavSrchID     = XPConvert.ToInteger(oSettingValue);
            //
            //						m_arSearchSettings[DATA_INDEX_SEARCHID] = oSettingValue;
            //					}
            //					else if (XPStringUtility.EqualsIgnoreCase(strSettingName, SavedSearchPortletModel.strSimpleKey))
            //					{
            //						// TODO: remove before GA
            //						// the following lines allows for backwards compatibility
            //						// with the beta version of the admin prefs structure
            //						String strValue = XPConvert.ToString(oSettingValue);
            //						if (strValue.equals("TRUE"))
            //							oSettingValue = new Integer(1);
            //						else if (strValue.equals("FALSE"))
            //							oSettingValue = new Integer(0);
            //						
            //						m_arSearchSettings[DATA_INDEX_SIMPLE] = oSettingValue;
            //					}
            /*else */
            if (XPStringUtility.EqualsIgnoreCase(strSettingName, SavedSearchPortletModel.strTitleKey))
            {
              m_arSearchSettings[DATA_INDEX_SEARCHTITLE] = oSettingValue;
              } else
            if (XPStringUtility.EqualsIgnoreCase(strSettingName, ADMIN_PREF_PARAMETERIC_PROPS))
            {
              m_arSearchSettings[DATA_INDEX_PARAMETERICIDS] = oSettingValue;
              } else
            if (XPStringUtility.EqualsIgnoreCase(strSettingName, ADMIN_PREF_DISPLAY_FIELDS))
            {
              m_arSearchSettings[DATA_INDEX_DISPLAY_FIELDS] = oSettingValue;
              }
          }
        }
        /* get the PT server objects */
        m_SrchMgr = (IPTSavedSearchManager) m_ptSession.GetSavedSearches();
        IPTSessionInfo si = m_ptSession.GetSessionInfo();
        m_nUserID = si.GetCurrentUserID();
        /* set the max results setting */
        m_nMaxResultsCnt = ((IPTSavedSearch) m_ptSession.GetSavedSearches().Open(m_nSavSrchID,
         false)).GetSearchRequest().GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS);
        }
      catch (Exception e)
      {
        log.Error(e, "SavedSearchPortletModel::GetData. " + m_asOwner.GetString(553,
         "ptmsgs_portalcommonmsgs") + ":" + e.Message);
      }
    }
    private String[][] GetDisplayFldsFromAdminPref()
    {
      String[][] arFieldIDs;
      String sPref = (String) m_arSearchSettings[DATA_INDEX_DISPLAY_FIELDS];
      if (null == sPref || 0 == sPref.Length)
      {
        log.Warn("SavedSearchPortletModel::GetDisplayFldsFromAdminPref()- Display Fields Admin Prefs not set");
        arFieldIDs = new String[0][];
        for (int j2c_index = 0;j2c_index < 0;j2c_index++)
        {
          arFieldIDs[j2c_index] = new String[0];
        }
        return arFieldIDs;
      }
      XPStringTokenizer st = new XPStringTokenizer(sPref, ",");
      arFieldIDs = new String[st.GetTokenCount()][];
      for (int j2c_index = 0;j2c_index < st.GetTokenCount();j2c_index++)
      {
        arFieldIDs[j2c_index] = new String[2];
      }
      for (int i = 0;st.HasMoreElements();i++)
      {
        String sIDandOrient = st.GetNextElement();
        arFieldIDs[i][0] = XPStringUtility.Substring(sIDandOrient, 0, sIDandOrient.Length - 1);
        arFieldIDs[i][1] = XPStringUtility.Substring(sIDandOrient, sIDandOrient.Length - 1);
        }
      return arFieldIDs;
    }
    
    /// <summary>
    /// Helper method to setup date picker objects
    /// </summary>
    private void InitDatePickerObjects()
    {
      // Get the user's locale and timezone
      String locale = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE,
       m_asOwner);
      String timezone = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE,
       m_asOwner);
      XPLocale xpLocale = null;
      XPTimeZone xpTimeZone = null;
      if (null != locale)
      {
        xpLocale = new XPLocale(locale);
      } else
      {
        xpLocale = XPLocale.GetDefault();
      }
      if (null != timezone)
      {
        xpTimeZone = XPTimeZone.GetTimeZone(timezone);
      } else
      {
        xpTimeZone = XPTimeZone.GetCurrentTimeZone();
      }
      // Initialize the page controls and date/time picker
      String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
      m_pageMgr = new PageMgr(m_asOwner.GetAccessStyle(), xpLocale, xpTimeZone,
       strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL,
       ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
      m_dtPickerMgr = new JSDateTimePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(),
       m_pageMgr);
      m_pageMgr.RegisterComponentMgr(m_dtPickerMgr);
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <returns></returns>
    public override Object GetNewTempData()
    {
      return m_SrchMgr.GetFollowupResults(m_nSavSrchID, m_nUserID, m_nSortID,
       m_nPaginateFirstIndx - 1, m_filter);
    }
    
    /// <summary>
    /// Returns the portlet name
    /// </summary>
    /// <returns>Portlet name</returns>
    public virtual String GetPortletName()
    {
      return m_ptPortlet.GetLocalizedName();
    }
    
    /// <summary>
    /// Returns the Redirect object  (this is were we need to go at the end of
    /// the Editor).
    /// </summary>
    /// <returns>Redirect</returns>
    public virtual Redirect GetRedirectAfterFinish()
    {
      return null;
    }
    
    /// <returns></returns>
    public virtual IPTSearchResponse GetSearchResponseObject()
    {
      return (IPTSearchResponse) m_SrchMgr.GetCachedResponse(m_nSavSrchID);
      }
    
    /// <returns></returns>
    public virtual bool IsSubscriptionEnabled()
    {
      return m_SrchMgr.IsSubscribed(m_nSavSrchID, 0);
    }
    
    /// <returns></returns>
    public virtual bool IsUserSubscribed()
    {
      return m_SrchMgr.IsSubscribed(m_nSavSrchID, m_nUserID);
    }
    
    /// <summary>
    /// Calls the right save function according to the page name passed in
    /// argument.
    /// </summary>
    /// <param name="_sPageName"></param>
    /// <param name="_htFormData"></param>
    /// <returns></returns>
    public virtual int SavePage(String _sPageName, XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <param name="nValue"></param>
    public virtual void SetSubscribe(int nValue)
    {
      switch (nValue){
      case SavedSearchPortletControl.POSTTOSELF_ACTION_SUBSCRIBE:
      m_SrchMgr.AddSubscription(m_nSavSrchID, m_nUserID);
      break;
      case SavedSearchPortletControl.POSTTOSELF_ACTION_UNSUBSCRIBE:
      m_SrchMgr.RemoveSubscription(m_nSavSrchID, m_nUserID);
      break;
      default:
      break;
      }
    }
    public virtual void SetParametericFilter(XPHashtable _htFormData)
    {
      IPTFilter newFilter = FilterForm.BuildFilterFromForm(m_asOwner, _htFormData,
       GetDatePickerMgr().GetPreFormDivID());
      if (null != newFilter)
      {
        m_filter = newFilter;
      }
      m_itrFilter.InitFromFilter(m_filter);
      m_bHasFollowupResults = true;
    }
    public virtual void SetSortOrder(int _nSortID)
    {
      m_nSortID = _nSortID;
      m_bHasFollowupResults = true;
    }
    public virtual String GetSortOrder()
    {
      return XPConvert.ToString(m_nSortID);
    }
    public virtual IPTSearchResponse GetFollowupResponse()
    {
      IPTSearchResponse sr = (IPTSearchResponse) GetTempData();
      m_nPaginateFirstIndx = sr.GetSkipped() + 1;
      m_nPaginateSize = sr.GetResultsReturned();
      m_nPaginateTotal = sr.GetTotalMatches();
      return sr;
    }
    public virtual int GetTotalMatches()
    {
      IPTSearchResponse sr = (IPTSearchResponse) GetTempData();
      return sr.GetTotalMatches();
    }
    public virtual bool HasParametericResults()
    {
      return m_bHasFollowupResults;
    }
    public virtual void ClearParametericResults()
    {
      m_filter = null;
      m_nSortID = 0;
      m_bHasFollowupResults = false;
      m_nPaginateFirstIndx = 1;
      m_nPaginateSize = 0;
      m_nPaginateTotal = 0;
    }
    private bool isPropertyAccessible(int id)
    {
      bool isIntrinsic = (id < PT_SERVERCONSTANTS.PT_MIN_OBJECTID);
      int aclNeeded = (isIntrinsic) ? PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ : PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT;
      return m_ptSession.GetProperties().IsObjectAccessible(id, m_nUserID,
       aclNeeded);
    }
    public virtual Object[][] GetReturnedPropertyInfo()
    {
      Object[][] arIDsAndOrient = GetDisplayFldsFromAdminPref();
      Object[][] arPropInfo = new Object[arIDsAndOrient.Length][];
      for (int j2c_index = 0;j2c_index < arIDsAndOrient.Length;j2c_index++)
      {
        arPropInfo[j2c_index] = new Object[4];
      }
      IPTObjectManager ptOM = m_ptSession.GetProperties();
      for (int i = 0;i < arIDsAndOrient.Length;i++)
      {
        int id = XPConvert.ToInteger(arIDsAndOrient[i][0]);
        IPTQueryResult ptQR = ptOM.QuerySingleObject(id);
        if (isPropertyAccessible(id) && (null != ptQR) && (ptQR.RowCount() > 0))
        {
          arPropInfo[i][PROPINFO_INDEX_TYPE] = ptQR.ItemAsObject(0, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE);
          arPropInfo[i][PROPINFO_INDEX_NAME] = ptQR.ItemAsObject(0, PT_PROPIDS.PT_PROPID_NAME);
          arPropInfo[i][PROPINFO_INDEX_ID] = arIDsAndOrient[i][0];
          arPropInfo[i][PROPINFO_INDEX_ORIENT] = arIDsAndOrient[i][1];
        } else
        {
          log.Warn("Display Property " + arIDsAndOrient[i][0] + " does not exist or is not accessible.");
          }
      }
      return arPropInfo;
    }
    
    /// <returns></returns>
    public virtual Redirect ConvertSearchToQueryString()
    {
      IPTSavedSearch ss = (IPTSavedSearch) m_ptSession.GetSavedSearches().Open(m_nSavSrchID,
       false);
      IPTSearchQuery sq = ss.GetSearchQuery();
      IPTSearchRequest sr = ss.GetSearchRequest();
      IPTFilter filter = (IPTFilter) sq.GetContentAsIPTFilter();
      XPHashtable args = new XPHashtable();
      bool filterValid = FilterForm.EncodeFilterAsControlArgs(m_ptSession,
       m_asOwner, filter, args);
      // Create a Redirect to the SearchResult space
      Redirect r = new Redirect();
      if (!filterValid)
      {
        return r;
      }
      r.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, m_asOwner);
      r.SetControl(StartSearchControl.STR_MVC_CLASS_NAME);
      r.SetIsHTTPRedirect(true);
      // Add filter arguments
      r.AddControlArguments(args);
      // .. and pass the language on to the search space if need be
      /* bug 24385: we should check the limitByLocale flag to determine if
       * we should add the required_constraints args.  Checking the language
       * won't help because when ALlLanguages is set, the value of the
       * language is the default locale (many times: 'EN').
       */
       
      Object bLimitByLocale = sr.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE);
      if (XPConvert.ToBoolean(bLimitByLocale))
      {
        String language = sr.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE);
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_LANGUAGE_S,
         language);
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_LIMITBYLOCALE_S,
         "1");
      }
      r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_MAXRESULTS_S,
       "10");
      String[] sAdminFolders = null;
      Object[] oAdminFolders = sr.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS);
      if ((null != oAdminFolders) && (oAdminFolders.Length > 0))
      {
        sAdminFolders = new String[oAdminFolders.Length];
        for (int i = 0;i < oAdminFolders.Length;i++)
        {
          sAdminFolders[i] = XPConvert.ToString(oAdminFolders[i]);
        }
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S,
         sAdminFolders);
      }
      String[] sCatalogFolders = null;
      Object[] oCatalogFolders = sr.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS);
      if ((null != oCatalogFolders) && (oCatalogFolders.Length > 0))
      {
        sCatalogFolders = new String[oCatalogFolders.Length];
        for (int i = 0;i < oCatalogFolders.Length;i++)
        {
          sCatalogFolders[i] = XPConvert.ToString(oCatalogFolders[i]);
        }
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_DDFOLDERS_S,
         sCatalogFolders);
      }
      if (0 == sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS))
      {
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S,
         "0");
      }
      Object[] arTypes = (Object[]) sr.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES);
      if ((null != arTypes) && (arTypes.Length > 0))
      {
        String[] strClassIDs = new String[arTypes.Length];
        for (int i = 0;i < arTypes.Length;i++)
        {
          strClassIDs[i] = XPConvert.ToString(arTypes[i]);
        }
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S,
         strClassIDs);
      }
      int iBroadOptions = sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES);
      if (iBroadOptions != 0)
      {
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S,
         iBroadOptions);
      }
      int iApps = sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS);
      if (iApps != 0)
      {
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_APPS_S,
         iApps);
      }
      int iOrderProp = sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY);
      if (iOrderProp != 0)
      {
        r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ORDERBY_S,
         iOrderProp);
      }
      return r;
    }
    private bool InitParametericPropObjects()
    {
      /* check if we have any parameteric properties */
      if (null == m_arSearchSettings[DATA_INDEX_PARAMETERICIDS] || 0 == XPConvert.ToString(m_arSearchSettings[DATA_INDEX_PARAMETERICIDS]).Length)
      {
        return false;
      }
      /* ok, we have some set, get each propid and check if the user has access to them */
      XPStringTokenizer tokenizer = new XPStringTokenizer(XPConvert.ToString(m_arSearchSettings[DATA_INDEX_PARAMETERICIDS]),
       ",");
      IPTObjectManager ptOM = m_ptSession.GetProperties();
      XPArrayList ids = new XPArrayList(tokenizer.GetTokenCount());
      /* used to keep track of ids we expect to be in the system */
      XPStringBuilder sbExpectedIDs = new XPStringBuilder();
      for (int i = 0;tokenizer.HasMoreElements();i++)
      {
        int id = XPConvert.ToInteger(tokenizer.GetNextElement());
        if (ptOM.IsObjectAccessible(id, m_nUserID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
        {
          ids.Add(id);
          /* record id */
          if (sbExpectedIDs.GetLength() != 0)
          {
            sbExpectedIDs.Append(",");
          }
          sbExpectedIDs.Append(id);
        } else
        {
          log.Warn("User does not have access to parameteric property " + id + ".");
          }
      }
      /* did the user have access to any of the props? */
      if (ids.GetSize() == 0)
      {
        return false;
      }
      /* user has access to some props, use our prepopulated filter or create a
       * dummy one as initializer */
       
      m_itrFilter = new FilterIterator(m_ptSession, (null == m_filter) ? PortalObjectsFactory.CreateSearchFilter() : m_filter,
       m_asOwner);
      m_itrFilter.SetAllowablePropertyIDs(ids.ToArray());
      if (m_itrFilter.MakeQueryCondition().GetPropInfo().Length == 0)
      {
        log.Warn("The following parameteric properties were expected, but not found: " + sbExpectedIDs.ToString());
        return false;
      }
      return true;
    }
    public virtual FilterIterator GetParametericFilterIterator()
    {
      return m_itrFilter;
    }
    public virtual PageMgr GetPageMgr()
    {
      return m_pageMgr;
    }
    public virtual JSDateTimePickerMgr GetDatePickerMgr()
    {
      return m_dtPickerMgr;
    }
    public virtual bool IsParameterized()
    {
      return m_bIsParameterized;
    }
    public virtual bool IsPaginationEnabled()
    {
      IPTServerConfigSettings ptSC = (IPTServerConfigSettings) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       false);
      return (1 == ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_CONTENT_SNAPSHOT_PORTLET_MODE));
      }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPagination#GoToPage(java.lang.String, int, int, java.lang.Object)
     */
     
    public virtual void GoToPage(String sortOrder, int firstItemOnPage, int pageSize,
     Object additionalInfo)
    {
      m_nPaginateFirstIndx = firstItemOnPage;
      m_nPaginateSize = pageSize;
      m_bHasFollowupResults = true;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetFirstDisplayableItem()
     */
     
    public virtual int GetFirstDisplayableItem()
    {
      return m_nPaginateFirstIndx;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetItemsPerPage()
     */
     
    public virtual int GetItemsPerPage()
    {
      return m_nMaxResultsCnt;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetNumDisplayableItems()
     */
     
    public virtual int GetNumDisplayableItems()
    {
      return m_nPaginateSize;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetTotalItems()
     */
     
    public virtual int GetTotalItems()
    {
      return m_nPaginateTotal;
    }
  }
}