using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.portaluiinfrastructure.tree;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.tree;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.portlets.savedsearch.prefs
{
  /// <author>
  /// joseq
  /// This explist expends the SelectPTObjectModel to include a 5th element to the 
  /// data array which holds the orientation of the field (column or row).
  /// </author>
  public class SavSrchDisplayFieldsListModel : SelectPTObjectModel,ISavSrchDisplayFieldsListModelRO
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.savedsearch.prefs.SavSrchDisplayFieldsListModel");
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SQDisplayFields";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 5;
    
    /// <summary>
    /// This is the column that holds the display orientation option (column/row)
    /// that we doisplay in the list.
    /// </summary>
    public const int EXPLIST_COL_ORIENTATION = 4;
    public const String ORIENTATION_ROW = "r";
    public const String ORIENTATION_COL = "c";
    public SavSrchDisplayFieldsListModel() : base()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SavSrchDisplayFieldsListModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initializes the read only expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public override void InitializeReadOnlySelectPTObject(String _sSectionTitle,
     String _sSectionSubTitle, int[] _arrObjectClassIDs, int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_ORIENTATION;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = "";
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      m_arrObjectClassIDs = _arrObjectClassIDs;
      base.InitializeReadOnlyExpandableList(_sSectionTitle, arrExpListColInfo,
       _nListKey);
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public override void InitializeSelectPTObject(String _sSectionTitle, String _sSectionSubTitle,
     PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs,
     int _nListKey)
    {
      Object[][] arrExpListColInfo = new Object[2][];
      for (int j2c_index = 0;j2c_index < 2;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = EXPLIST_COL_STRING;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = _sSectionSubTitle;
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = true;
      arrExpListColInfo[1][EXPLIST_COLUMN_ID] = EXPLIST_COL_ORIENTATION;
      arrExpListColInfo[1][EXPLIST_COLUMN_TITLE] = "";
      arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN] = "1";
      arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT] = false;
      m_arrObjectClassIDs = _arrObjectClassIDs;
      base.InitializeExpandableList(_sSectionTitle, arrExpListColInfo, _imgAddIcon,
       _sAddLabel, _nListKey);
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING, EXPLIST_COL_ORIENTATION};
      // JF- Sort array
      // The growable array will always be sorted by the String column (the one displayed).
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_STRING;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    
    /// <summary>
    /// Clear the list and add all the values from the tree.
    /// </summary>
    /// <param name="_htFormData">Form data</param>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      if (!m_bIsReadOnly)
      {
        SaveTreeID(_htFormData);
        TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(SUBSPACE_KEY_SELECTTREE));
        if (null != asTree)
        {
          ITreeModelRO myTree = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
          XPArrayList mySelected = myTree.GetSelectedItems();
          int nClassID;
          int nObjectID;
          int nIndex;
          String sOrientation;
          // JF- Before we clear the items and get the brand new list from the tree, we want to keep a copy of the indexes.
          // If the move row actions are enabled, we need to keep the same indexes for Objects already in the list. 
          // We need to keep the order for existing Objects and add the new ones at the end.
          Object[][] arrIndexMapping = CreateIndexMapping(GetItems());
          Object[][] oNewRows = new Object[mySelected.GetSize()][];
          for (int j2c_index = 0;j2c_index < mySelected.GetSize();j2c_index++)
          {
            oNewRows[j2c_index] = new Object[EXPLIST_COL_MAX];
          }
          for (int i = 0;i < mySelected.GetSize();i++)
          {
            nClassID = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
            nObjectID = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
            nIndex = GetIndex(arrIndexMapping, nClassID, nObjectID);
            if (-1 == nIndex)
            {
              nIndex = m_nNextIndex;
              m_nNextIndex++;
              sOrientation = ORIENTATION_COL;
            } else
            {
              try
              {
                sOrientation = XPConvert.ToString(base.GetItems().GetItem(nIndex,
                 EXPLIST_COL_ORIENTATION));
              }
              catch (Exception e)
              {
                sOrientation = ORIENTATION_COL;
              }
            }
            //					oNewRow										  = new Object[EXPLIST_COL_MAX];
            oNewRows[i][EXPLIST_SORTEDARRAY_PROPID_INDEX] = nIndex;
            oNewRows[i][EXPLIST_COL_CLASSID] = nClassID;
            oNewRows[i][EXPLIST_COL_OBJECTID] = nObjectID;
            oNewRows[i][EXPLIST_COL_ORIENTATION] = sOrientation;
            if (PT_CLASSIDS.PT_CATALOGFOLDER_ID == nClassID)
            {
              oNewRows[i][EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).m_strLocation;
              } else
            {
              oNewRows[i][EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
              }
          }
          //					super.GetItems().AddRow(oNewRow);
          // JF- We clear the array before we start adding the selected items from the tree.
          base.GetItems().ClearArray();
          base.GetItems().AddRows(oNewRows);
        }
      }
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#ModifyRow(com.plumtree.openfoundation.util.XPHashtable)
     */
     
    public override void ModifyRow(XPHashtable _htFormData)
    {
      int nRowIndex = GetRowIndex(_htFormData);
      try
      {
        base.GetItems().SetItem(nRowIndex, EXPLIST_COL_ORIENTATION, GetOrientation(_htFormData,
         nRowIndex));
      }
      catch (Exception e)
      {
        log.Error("SavSrchDisplayFieldsListModel::ModifyRow An exception occured" + " when trying to modify the row: " + nRowIndex + ". " + e);
        }
    }
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.portlets.savedsearch.prefs.ISavSrchDisplayListModelRO#IsOrientationRow(int)
     */
     
    public virtual bool IsOrientationRow(int _iRowIndex)
    {
      String sOrientaton = (String) base.GetItems().GetItem(_iRowIndex, EXPLIST_COL_ORIENTATION);
      return XPStringUtility.EqualsIgnoreCase(sOrientaton, ORIENTATION_ROW);
      }
    
    /// <summary>
    /// Helper method to retrieve the row index from the form data.
    /// </summary>
    /// <param name="_htFormData"></param>
    /// <returns>int</returns>
    private String GetOrientation(XPHashtable _htFormData, int _nRowIndex)
    {
      String sDataKey = GetUniqueString(SavSrchDisplayFieldsListView.HTMLINPUT_ORIENTATION + _nRowIndex);
      String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
      return aDataValue[0];
    }
  }
}