using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.common.constants;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.savedsearch.prefs
{
  /// <author>
  /// joseq
  /// Expandable List that continues properties (used in snapshot qrys).  This extends SelectPTObjectView
  /// in that is adds an Orientation (Column or Row) option on each row. 
  /// </author>
  public class SavSrchDisplayFieldsListView : SelectPTObjectView
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SQDisplayFields";
    
    /// <summary>
    /// HTML Object name: Field Orientation 
    /// </summary>
    public const String HTMLINPUT_ORIENTATION = "in_ra_Orientation";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SavSrchDisplayFieldsListView();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
     
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript myScript = base.DisplayJavascript();
      XPStringBuilder sb;
      // JavaScript to set orientation			
      sb = new XPStringBuilder(300);
      sb.Append("function " + ((IExpListModelRO) m_model).GetUniqueString("SetOrientation") + "(varRowIndex)\n");
      sb.Append("{\n");
      sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." + ((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_ROWINDEX) + ".value= varRowIndex;\n");
      //		sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
      //			((IExpListModelRO) m_model).GetUniqueString(
      //				HTMLHIDDEN_MOVEACTION) + ".value= varMoveAction;\n");
      sb.Append("  postToSelf(\'" + ((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_MODIFYROW) + "\');\n");
      sb.Append("}\n");
      myScript.AddInnerHTMLString(sb.ToString());
      return myScript;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// Each row contains just an icon and input text.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLElement</returns>
    /// <throws>Exception</throws>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      /* field orientation html */
      result.AddInnerHTMLElement(GetHTMLForOrientationRadio(_nRowIndex));
      if (((ISelectPTObjectModelRO) m_model).GetEnableMoveRowActions())
      {
        result.AddInnerHTMLElement(base.GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Helper method for empty cell between actions
    /// in the action bar.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    private HTMLTableCell GetHTMLForOrientationRadio(int _nRowIndex)
    {
      HTMLTableCell myCell = new HTMLTableCell();
      if (1 < ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
      {
        PTConstruct myConstruct;
        HTMLImg myImage;
        HTMLAnchor myAnchor;
        HTMLInput myInput;
        HTMLSpan mySpan;
        // We are building an HTML Cell with the 2 radios: column, row
        myCell.SetAlign("right");
        myCell.SetVAlign("middle");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(SPACE);
        /* orientation == col radio */
        myInput = new HTMLInput(HTMLInputTypes.RADIO_TYPE, ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_ORIENTATION + _nRowIndex),
         "");
        myInput.SetChecked(!((ISavSrchDisplayFieldsListModelRO) m_model).IsOrientationRow(_nRowIndex));
        myInput.SetValue(SavSrchDisplayFieldsListModel.ORIENTATION_COL);
        myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("SetOrientation") + "(\'" + _nRowIndex + "\')");
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(66, ResourceConstants.PORTLETSMSGS));
        /* orientation == row radio */
        myInput = new HTMLInput(HTMLInputTypes.RADIO_TYPE, ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_ORIENTATION + _nRowIndex),
         "");
        myInput.SetChecked(((ISavSrchDisplayFieldsListModelRO) m_model).IsOrientationRow(_nRowIndex));
        myInput.SetValue(SavSrchDisplayFieldsListModel.ORIENTATION_ROW);
        myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("SetOrientation") + "(\'" + _nRowIndex + "\')");
        myCell.AddInnerHTMLElement(myInput);
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(67, ResourceConstants.PORTLETSMSGS));
        myCell.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLString(SPACE);
      }
      myCell.AddInnerHTMLString(SPACE);
      return myCell;
    }
  }
}