using System;
using com.plumtree.portalpages.portlets.savedsearch;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.portlets.savedsearch.prefs
{
  /// <summary>
  /// Activity space for intrinsic portlet. The name of this activity space must
  /// be the name of the portlet model + "Prefs".
  /// </summary>
  /// <author>mikes</author>
  public class SavedSearchPortletPrefsEditorAS : PTEditorAS
  {
    
    /// <summary>
    /// SavedSearchPortletPrefs. For intrinsic portlets, the name of the activity
    /// space is the same as the name of the model plus the suffix "Prefs".
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = SavedSearchPortletModel.STR_MVC_CLASS_NAME + IntrinsicPortletPrefsUtils.PREFS_SUFFIX;
    
    /// <summary>
    /// ExpList model displaying which properties to display in a portlet.
    /// </summary>
    public static readonly String STR_MVC_SELECT_DISPLAY_FIELDS = "SelectDisplayFieldsEditor" + IntrinsicPortletPrefsUtils.PREFS_SUFFIX;
    
    /// <summary>
    /// ExpList model displaying which properties to display in a portlet.
    /// </summary>
    public static readonly String STR_MVC_SELECT_PARAMETRIC_FIELDS = "SelectParametericFieldsEditor" + IntrinsicPortletPrefsUtils.PREFS_SUFFIX;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SavedSearchPortletPrefsEditorAS();
    }
    
    /// <summary>
    /// Returns the Editor title.
    /// </summary>
    /// <returns>String</returns>
    public override String GetEditorTitle()
    {
      return GetString(473, "ptmsgs_portalcommonmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Property Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (SavedSearchPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes of the Property Activity Space.
    /// </summary>
    public override void Init()
    {
      m_strModelName = SavedSearchPortletPrefsModel.STR_MVC_CLASS_NAME;
      // Warning: m_strModelName must be initialized before super.Init() is called.
      base.Init();
      IModel myModel = GetModel(SavedSearchPortletPrefsModel.STR_MVC_CLASS_NAME);
      RegisterPage(new SavedSearchPortletPrefsDP());
      RegisterView(SavedSearchPortletAdminPrefsView.STR_MVC_CLASS_NAME, myModel);
      RegisterControl(SavedSearchPortletPrefsRepostControl.STR_MVC_CLASS_NAME,
       myModel);
      //****** Register classes for display fields selector
      RegisterModel(SavSrchDisplayFieldsListModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_FIELDS);
      IModel myDisplayFieldsSelectModel = GetModel(STR_MVC_SELECT_DISPLAY_FIELDS);
      RegisterView(SavSrchDisplayFieldsListView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_FIELDS,
       myDisplayFieldsSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_FIELDS,
       myDisplayFieldsSelectModel);
      //****** Register classes for display fields selector
      RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PARAMETRIC_FIELDS);
      IModel myParametericFieldsSelectModel = GetModel(STR_MVC_SELECT_PARAMETRIC_FIELDS);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PARAMETRIC_FIELDS,
       myParametericFieldsSelectModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PARAMETRIC_FIELDS,
       myParametericFieldsSelectModel);
      SetCurrentPage(SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME);
      //Sets left nav menu
      int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(472, "ptmsgs_portalcommonmsgs"));
      m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME);
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        this.SetHelpTopic("PT_AdminPrefs_SnapshotPortlet");
      }
    }
  }
}