using System;
using com.plumtree.analytics.openusage;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.communities;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.sitemap
{
  /// <author>josephc</author>
  public class SiteMapPortletView : IntrinsicPortletView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.sitemap.SiteMapPortletView");
    
    /// <summary>
    /// Class name for the view. For intrinsic portlets, the view must have the
    /// same class name as the model.
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = SiteMapPortletModel.STR_MVC_CLASS_NAME;
    public const String HTMLBUTTON_REPOST = "in_bu_repost";
    public const String HTMLINPUT_VALUE = "in_tx_Value";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapPortletView();
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on
    /// the page.
    /// </summary>
    /// <returns>HTMLScript</returns>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script;
      try
      {
        HTMLScriptCollection result = new HTMLScriptCollection();
        script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) + "opennewwindow.js");
        result.AddInnerHTMLElement(script);
        return script;
      }
      catch (Exception e)
      {
        return null;
      }
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()"></seealso>
    public override HTMLElement DisplayPortlet()
    {
      ISiteMapPortletModelRO iModel = (ISiteMapPortletModelRO) m_model;
      HTMLElement result = new HTMLElementCollection();
      try
      {
        HTMLTable myTable;
        HTMLTable myParentTable;
        HTMLTableRow myRow;
        HTMLTableRow myParentRow;
        HTMLTableCell myCell;
        HTMLTableCell myParentCell;
        PTConstruct myConstruct;
        HTMLImg myImage;
        myParentTable = new HTMLTable();
        result.AddInnerHTMLElement(myParentTable);
        myParentTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myParentTable.SetBorder(CommonHTMLStrings.ZERO);
        myParentTable.SetCellSpacing(CommonHTMLStrings.ZERO);
        myParentTable.SetCellPadding(CommonHTMLStrings.ZERO);
        // for a border effect, we make one row and one cell, put it in myTable and then 
        // the other tables get added into this cell.
        myParentRow = new HTMLTableRow();
        myParentTable.AddInnerHTMLElement(myParentRow);
        myParentRow.SetStyleClass(PTStyleClass.PLATPORTLET_LIGHT_BG);
        myParentCell = new HTMLTableCell();
        myParentRow.AddInnerHTMLElement(myParentCell);
        myParentCell.SetColSpan(CommonHTMLStrings.TWO);
        if (!CommunityPageAS.STR_MVC_CLASS_NAME.Equals(m_asOwner.GetName()))
        {
          myParentCell.AddInnerHTMLString(m_asOwner.GetString(758, "ptmsgs_portalcommonmsgs"));
          return result;
        }
        // find out if we need the "add links" button
        if (iModel.GetHasEditAccessToCommunity() && (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD) && (iModel.GetHasEditAccessToFolder() || !iModel.GetHasReadAccessToFolder()))
        {
          myTable = GetHTMLForSubmitTable();
          myParentCell.AddInnerHTMLElement(myTable);
          myTable = GetHTMLForSpacerTable();
          myParentCell.AddInnerHTMLElement(myTable);
        }
        ICPListEntryIterator cpList = iModel.GetLinks();
        CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);
        mediator.SetLabelMaxLength(65);
        mediator.SetShowImages(false);
        myTable = new HTMLTable();
        myTable.SetCellPadding(CommonHTMLStrings.TWO);
        myTable.SetCellSpacing(CommonHTMLStrings.TWO);
        myTable.SetBorder(CommonHTMLStrings.ZERO);
        myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myParentCell.AddInnerHTMLElement(myTable);
        // get the header row
        String strFolderName = iModel.GetFolderName();
        myRow = GetHTMLForHeaderRow(strFolderName);
        myTable.AddInnerHTMLElement(myRow);
        int iCurrentLink = 0;
        int nNumLinksToDisplay = iModel.GetNumLinksToDisplay();
        while (mediator.Next() && (iCurrentLink < nNumLinksToDisplay))
        {
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          if ((0 == iCurrentLink) || (((iCurrentLink + 1) / 2) == (iCurrentLink / 2)))
          {
            // it's even
            myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
          } else
          {
            // it's odd
            myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
          }
          // get the whole entry, so we can get the image and the description from it.
          ListEntry objEntry = cpList.GetEntryAtIndex(iCurrentLink);
          // the little image
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetHeight("20");
          myCell.SetWidth("20");
          myCell.SetAlign(CommonHTMLStrings.CENTER);
          myCell.SetVAlign(CommonHTMLStrings.TOP);
          PTImageType objImageType = objEntry.GetImage();
          String strImageAlt = objEntry.GetImageAltTextEncoded();
          if (objImageType != null)
          {
            myConstruct = UIConstructFactory.GetConstruct(objImageType, true,
             this.m_asOwner);
          } else
          {
            myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT,
             true, this.m_asOwner);
          }
          myImage = (HTMLImg) myConstruct.GetHTMLElement();
          if ("".Equals(strImageAlt) || (strImageAlt == null))
          {
            myImage.SetAlt("");
          } else
          {
            myImage.SetAlt(strImageAlt);
          }
          myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
          myImage.SetBorder(CommonHTMLStrings.ZERO);
          myCell.AddInnerHTMLElement(myImage);
          // the link name
          myCell = new HTMLTableCell();
          myRow.AddInnerHTMLElement(myCell);
          myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
          myCell.SetHeight("20");
          myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
          myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
          HTMLAnchor myAnchor = (HTMLAnchor) mediator.GetEntry();
          myCell.AddInnerHTMLElement(myAnchor);
          if (iModel.ShowDescriptions())
          {
            String strDescription = objEntry.GetDescription();
            if (!("").Equals(strDescription) && (strDescription != null))
            {
              // bjf -- only add the BR if there is a description, otherwise in
              // netscape it causes a bug where the colored background does
              // not extend through the whole row.
              myCell.AddInnerHTMLElement(new HTMLBr());
              myCell.AddInnerHTMLString(objEntry.GetDescription());
            }
          }
          iCurrentLink++;
        }
        myCell = new HTMLTableCell();
        myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
        myCell.SetHeight("20");
        myCell.SetColSpan(CommonHTMLStrings.TWO);
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // if there aren't any links, then display an appropriate error message.
        if (iCurrentLink == 0)
        {
          if ((iModel.GetFolderID() == 0) && (iModel.GetHasEditAccessToCommunity() == true))
          {
            // there's no folder, but we have edit access to the community, so we can make one
            myCell.AddInnerHTMLString(m_asOwner.GetString(793, "ptmsgs_portalcommonmsgs"));
            } else
          if ((iModel.GetFolderID() != 0) && (iModel.GetHasEditAccessToFolder() == true))
          {
            // there is a folder, there aren't any links, but we're allowed to add links
            myCell.AddInnerHTMLString(m_asOwner.GetString(794, "ptmsgs_portalcommonmsgs"));
            } else
          if ((iModel.GetFolderID() != 0) && (iModel.GetHasReadAccessToFolder() == false) && (iModel.GetHasEditAccessToCommunity() == true))
          {
            // you have edit access on the community, but you can't even read the folder.  maybe the folder was deleted?
            myCell.AddInnerHTMLString(m_asOwner.GetString(795, "ptmsgs_portalcommonmsgs"));
            } else
          {
            myCell.AddInnerHTMLString(m_asOwner.GetString(602, "ptmsgs_portalcommonmsgs"));
            }
          // only add row to table if appropriate
          myRow = new HTMLTableRow();
          myTable.AddInnerHTMLElement(myRow);
          myRow.AddInnerHTMLElement(myCell);
        } else
        {
          if (iModel.ShowMoreLink())
          {
            ASURL siteMapPageURL = new ASURL(m_asOwner);
            siteMapPageURL.SetLinkCreateNewSpace(SiteMapAS.STR_MVC_CLASS_NAME,
             m_asOwner);
            siteMapPageURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
            siteMapPageURL.AddControlArgument(SetSiteMapControl.m_CommunityID,
             iModel.GetCommunityID());
            siteMapPageURL.AddControlArgument(SetSiteMapControl.m_FolderID,
             iModel.GetFolderID());
            siteMapPageURL.AddControlArgument(SetSiteMapControl.m_Mode, SetSiteMapControl.BROWSE);
            HTMLAnchor anchor = new HTMLAnchor(siteMapPageURL.GetURLAsString());
            myCell.AddInnerHTMLElement(anchor);
            anchor.SetTitle(m_asOwner.GetString(597, "ptmsgs_portalcommonmsgs"));
            anchor.AddInnerHTMLString(m_asOwner.GetString(597, "ptmsgs_portalcommonmsgs"));
            // only add row to table if appropriate
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myRow.AddInnerHTMLElement(myCell);
          }
        }
        // Bug: 8443373 - Send Portlet View OpenUsage Event on portlet render.
        IPTSession ptUserSession = (IPTSession) m_asOwner.GetUserSession();
        int nPageID = 0;
        if (m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME))
        {
          nPageID = ((MyPortalModel) m_asOwner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME)).GetPageID();
          }
        IASPortalEvent portletevent = ASEventFactory.createPortletViewEvent();
        portletevent.setPortletId(iModel.GetPortletID());
        portletevent.setCommunityId(iModel.GetCommunityID());
        portletevent.setPageId(nPageID);
        portletevent.setUserId(ptUserSession.GetSessionInfo().GetCurrentUserID());
        portletevent.sendEvent();
      }
      catch (Exception e)
      {
        log.Error(e, "SiteMapPortletView::Display. " + m_asOwner.GetString(596,
         "ptmsgs_portalcommonmsgs"));
        throw new XPException(m_asOwner.GetString(596, "ptmsgs_portalcommonmsgs"),
         e);
      }
      return result;
    }
    
    /// <seealso cref="com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()"></seealso>
    public override String DisplayPortletWML()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="strFolderName"></param>
    /// <returns></returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableRow GetHTMLForHeaderRow(String strFolderName)
    {
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      myRow = new HTMLTableRow();
      myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetHeight("20");
      myCell.SetColSpan("2");
      myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strFolderName));
      return myRow;
    }
    
    /// <summary>
    /// Returns the HTML for the spacer table.
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTable GetHTMLForSpacerTable()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      myTable = new HTMLTable();
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER, true,
       m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myImage.SetHeight("5");
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myCell.AddInnerHTMLElement(myImage);
      return myTable;
    }
    
    /// <summary>
    /// Returns the HTML for the add links button.
    /// </summary>
    /// <returns>HTMLTable</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTable GetHTMLForSubmitTable()
    {
      ISiteMapPortletModelRO iModel = (ISiteMapPortletModelRO) m_model;
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      PTConstruct myConstruct;
      HTMLImg myImage;
      HTMLAnchor myAnchor;
      HTMLSpan mySpan;
      myTable = new HTMLTable();
      myTable.SetBorder(CommonHTMLStrings.ZERO);
      myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
      myTable.SetCellPadding(CommonHTMLStrings.ZERO);
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myRow.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_BG);
      // if they have edit access to the folder, then display the submit link
      /*if (iModel.GetHasEditAccessToFolder())
       {
       // BEGIN submit button cell
       myCell = new HTMLTableCell();
       myRow.AddInnerHTMLElement(myCell);
       myCell.SetHeight("25");
       myCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_BTN);
       myCell.SetNoWrap(true);
       myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
       // Add icon
       myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_SUBMIT,
       true, this.m_asOwner);
       myImage            = (HTMLImg) myConstruct.GetHTMLElement();
       myImage.SetAlt(m_asOwner.GetString(601, "ptmsgs_portalcommonmsgs"));
       myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
       int nID = iModel.GetFolderID();
       ASURL asurl = new ASURL(m_asOwner);
       asurl.SetLinkCreateNewSpace(CreateLinkAS.STR_MVC_CLASS_NAME, m_asOwner);
       asurl.SetDisplayPage(LinkSelectorDP.STR_MVC_CLASS_NAME);
       asurl.SetControl(SetFolderControl.STR_MVC_CLASS_NAME);
       asurl.AddControlArgument(SetFolderControl.m_FolderID, nID);
       asurl.AddControlArgument(SetFolderControl.m_Type,
       SetFolderControl.FROMGADGET);
       // mj: replaced the following line with a blank constructur and SetOnClick()
       // myAnchor = new HTMLAnchor("OpenLargePreviewWindow('" +
       myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
       myAnchor.SetOnClick("OpenLargePreviewWindow('" +
       asurl.GetURLAsString() + "')");
       myAnchor.AddInnerHTMLElement(myImage);
       mySpan = new HTMLSpan();
       myAnchor.AddInnerHTMLElement(mySpan);
       mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
       // Add label
       mySpan.AddInnerHTMLString(m_asOwner.GetString(601, "ptmsgs_portalcommonmsgs"));
       mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
       myCell.AddInnerHTMLElement(myAnchor);
       // END submit button cell
       }*/
       
      // if they have edit access to the community, then display the configure link
      if (iModel.GetHasEditAccessToCommunity())
      {
        // BEGIN configure button cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetHeight("20");
        myCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_BTN);
        myCell.SetNoWrap(true);
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // Add icon
        myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT_SMALL,
         true, this.m_asOwner);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt(m_asOwner.GetString(786, "ptmsgs_portalcommonmsgs"));
        myImage.SetHeight("20");
        myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
        String strPrefsURL = iModel.GetPrefsURL();
        myAnchor = new HTMLAnchor("#");
        myAnchor.SetOnClick("OpenNewWindow(\'" + strPrefsURL + "\', \'Configure\', \'status=no,toolbar=yes,menubar=no,resizable=yes,scrollbars=yes,location=no,width=1000,height=575\');return false;");
        myAnchor.AddInnerHTMLElement(myImage);
        mySpan = new HTMLSpan();
        myAnchor.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
        // Add label
        mySpan.AddInnerHTMLString(m_asOwner.GetString(786, "ptmsgs_portalcommonmsgs"));
        mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myCell.AddInnerHTMLElement(myAnchor);
      }
      // END configure button cell
      // divider cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_DIR_DIVIDER);
      myCell.SetHeight("20");
      myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER, true,
       m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      myImage.SetHeight(CommonHTMLStrings.ONE);
      myImage.SetWidth(CommonHTMLStrings.ONE);
      myImage.SetBorder(CommonHTMLStrings.ZERO);
      myCell.AddInnerHTMLElement(myImage);
      // spacer cell
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.SetHeight("20");
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myTable;
    }
  }
}