using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.portalpages.browsing.sitemap.linkselector;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.portlets.sitemap.prefs
{
  /// <author>NaveenP</author>
  public class SiteMapPortletPrefsSortedLinksModel : ExpListModel
  {
    public const String STR_MVC_CLASS_NAME = "SiteMapPortletPrefsSortedLinks";
    public const int LINKS_COL_LINK_NAME = 1;
    public const int LINKS_COL_LINK_OBJECTID = 2;
    public const int LINKS_COL_LINK_DESCRIPTION = 3;
    public const int LINKS_COL_LINK_TYPE = 4;
    public const int LINKS_COL_LINK_INDEX = 5;
    public const int LINKS_COL_LINK_UNIQUE_ID = 6;
    
    /// <summary>
    /// Default initial size for the sorted array.
    /// </summary>
    public const int EXPLIST_DEFAULT_INITIAL_SIZE = 25;
    
    /// <summary>
    /// IPTSession 
    /// </summary>
    private IPTSession m_Session;
    private bool m_bIsAlpha;
    private String m_strLinkOrder;
    private XPHashtable m_tableLinkOrder;
    private int m_nNumSortedLinks;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapPortletPrefsSortedLinksModel();
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#AddRowsOnRepost(XPHashtable)"></seealso>
    public override void AddRowsOnRepost(XPHashtable _htFormData)
    {
      SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      PTLink link;
      Object[] oRow;
      XPArrayList newlyAddedLinks = plugInModel.GetNewlyAddedLinks();
      for (int i = 0;i < newlyAddedLinks.GetSize();i++)
      {
        link = (PTLink) newlyAddedLinks.GetElement(i);
        oRow = new Object[6];
        oRow[0] = m_saData.GetCount();
        if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID)
        {
          oRow[1] = link.strName + " (" + link.strPageName + ")";
        } else
        {
          oRow[1] = link.strName;
        }
        oRow[2] = link.nObjectID;
        oRow[3] = link.strDesc;
        oRow[4] = link.nType;
        if (link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID)
        {
          oRow[5] = link.nObjectID;
        } else
        if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID)
        {
          oRow[5] = link.nPageID;
        } else
        {
          oRow[5] = link.nLinkObjectID;
        }
        m_saData.AddRow(oRow);
      }
      plugInModel.ClearNewlyAddedLinks();
    }
    public virtual void UpdateRowsOnRepost(XPHashtable _htFormData)
    {
      SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      PTLink link;
      XPArrayList updatedWebLinks = plugInModel.GetUpdatedWebLinks();
      PTGrowableSortedArrayWrapper arrLinkItems = GetItems();
      int nNumLinks = arrLinkItems.GetCount();
      for (int i = 0;i < updatedWebLinks.GetSize();i++)
      {
        link = (PTLink) updatedWebLinks.GetElement(i);
        for (int j = 0;j < nNumLinks;j++)
        {
          int nTypeID = XPConvert.ToInteger(arrLinkItems.GetItem(j, LINKS_COL_LINK_TYPE));
          int nUniqueID = XPConvert.ToInteger(arrLinkItems.GetItem(j, LINKS_COL_LINK_UNIQUE_ID));
          if (nTypeID == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID && nUniqueID == link.nObjectID)
          {
            arrLinkItems.SetItem(j, LINKS_COL_LINK_NAME, link.strName);
            arrLinkItems.SetItem(j, LINKS_COL_LINK_DESCRIPTION, link.strDesc);
            break;
          }
        }
      }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)"></seealso>
    public override void DeleteRowsOnRepost(XPHashtable _htFormData)
    {
      SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      XPArrayList xparrLinksToDelete = new XPArrayList();
      PTLink link;
      XPArrayList deletedLinks = plugInModel.GetDeletedLinks();
      for (int i = 0;i < deletedLinks.GetSize();i++)
      {
        link = (PTLink) deletedLinks.GetElement(i);
        for (int j = 0;j < m_saData.GetCount();j++)
        {
          int nListType = XPConvert.ToInteger(m_saData.GetItem(j, LINKS_COL_LINK_TYPE));
          int nListUniqueID = XPConvert.ToInteger(m_saData.GetItem(j, LINKS_COL_LINK_UNIQUE_ID));
          int nUniqueID;
          if (link.nType == nListType)
          {
            if (link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID)
            {
              nUniqueID = link.nObjectID;
            } else
            if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID)
            {
              nUniqueID = link.nPageID;
            } else
            {
              nUniqueID = link.nLinkObjectID;
            }
            if (nUniqueID == nListUniqueID)
            {
              xparrLinksToDelete.Add(j);
              break;
            }
          }
        }
      }
      int[] aRowsToDelete = new int[xparrLinksToDelete.GetSize()];
      for (int i = 0;i < xparrLinksToDelete.GetSize();i++)
      {
        aRowsToDelete[i] = XPConvert.ToInteger(xparrLinksToDelete.GetElement(i));
        }
      m_saData.RemoveRows(aRowsToDelete);
      plugInModel.ClearDeletedLinks();
    }
    
    /// <returns>int</returns>
    public virtual int GetCurrNumLinks()
    {
      if (m_saData == null)
      {
        return 0;
      } else
      {
        return m_saData.GetCount();
      }
    }
    //public XPArrayList GetIDsToDelete()
    //{
    //	return m_xparrLinksToDelete;
    //}
    
    /// <returns>String</returns>
    public virtual String GetItemsAsStringForStore()
    {
      if (m_bIsAlpha)
      {
        return "";
      } else
      {
        return CreateStringOfItemsForStore();
      }
    }
    
    /// <param name="nIndex"></param>
    /// <returns></returns>
    public virtual String GetLinkName(int nIndex)
    {
      return ((String) GetItems().GetItem(nIndex, LINKS_COL_LINK_NAME));
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public virtual void InitializeLinkList(IPTSession _Session, int _nListKey,
     String strLinkOrder)
    {
      m_Session = _Session;
      m_strLinkOrder = strLinkOrder;
      m_bIsAlpha = ("").Equals(m_strLinkOrder);
      XPStringTokenizer strTok = new XPStringTokenizer(strLinkOrder, ",");
      m_tableLinkOrder = new XPHashtable();
      int nCount = 0;
      while (strTok.HasMoreElements())
      {
        m_tableLinkOrder.PutElement(XPConvert.ToInteger(strTok.GetNextToken()),
         nCount);
        nCount++;
      }
      m_nNumSortedLinks = nCount;
      Object[][] arrExpListColInfo = new Object[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrExpListColInfo[j2c_index] = new Object[5];
      }
      arrExpListColInfo[0][EXPLIST_COLUMN_ID] = LINKS_COL_LINK_NAME;
      arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = m_asOwner.GetString(574,
       "ptmsgs_portalcommonmsgs");
      arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "100%";
      arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
      arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = false;
      base.InitializeExpandableList(m_asOwner.GetString(573, "ptmsgs_portalcommonmsgs"),
       arrExpListColInfo, PTImageType.ICON_URL, "", _nListKey);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(PTGrowableSortedArrayWrapper)"></seealso>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      //ASQueryResultWrapper asqrLinks = ((SiteMapPortletPrefsModel) m_asOwner.GetModel(SiteMapPortletPrefsModel.STR_MVC_CLASS_NAME)).GetLinks();
      SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      XPArrayList arrItems = plugInModel.GetLinks();
      int nNumLinks = arrItems.GetSize();
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, LINKS_COL_LINK_NAME,
       LINKS_COL_LINK_OBJECTID, LINKS_COL_LINK_DESCRIPTION, LINKS_COL_LINK_TYPE,
       LINKS_COL_LINK_UNIQUE_ID};
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      if (m_bIsAlpha)
      {
        arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = LINKS_COL_LINK_NAME;
        m_bEnableMoveRowActions = false;
      } else
      {
        arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
        m_bEnableMoveRowActions = true;
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      int nCount = m_nNumSortedLinks;
      Object[][] arrData = new Object[6][];
      for (int j2c_index = 0;j2c_index < 6;j2c_index++)
      {
        arrData[j2c_index] = new Object[nNumLinks];
      }
      for (int i = 0;i < nNumLinks;i++)
      {
        PTLink link = (PTLink) arrItems.GetElement(i);
        //int intClassID = XPConvert.ToInteger(asqrLinks.GetFields(i,
        //		PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID));
        int intClassID = link.nType;
        arrData[1][i] = link.strName;
        arrData[2][i] = link.nObjectID;
        arrData[3][i] = link.strDesc;
        arrData[4][i] = intClassID;
        if (link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID)
        {
          arrData[5][i] = link.nObjectID;
        } else
        if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID)
        {
          arrData[5][i] = link.nPageID;
        } else
        {
          arrData[5][i] = link.nLinkObjectID;
        }
        Object oIndex = m_tableLinkOrder.GetElement(arrData[2][i]);
        if (oIndex != null)
        {
          arrData[0][i] = oIndex;
        } else
        {
          arrData[0][i] = nCount++;
        }
      }
      _saData.Initialize(arrColumns, arrData, arrSort, true, nNumLinks);
    }
    
    /// <param name="bIsAlpha"></param>
    public virtual void SetAlphaOrdering(bool bIsAlpha)
    {
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      if (bIsAlpha)
      {
        arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = LINKS_COL_LINK_NAME;
        m_bEnableMoveRowActions = false;
        m_bIsAlpha = true;
      } else
      {
        arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_SORTEDARRAY_PROPID_INDEX;
        m_bEnableMoveRowActions = true;
        m_bIsAlpha = false;
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      m_saData.Sort(arrSort);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListModel#SaveRow(PTGrowableSortedArrayWrapper,int,XPHashtable)"></seealso>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      return RepostControl.PAGE_STATUS_VALID;
    }
    
    /// <returns>String</returns>
    private String CreateStringOfItemsForStore()
    {
      XPStringBuilder retVal = new XPStringBuilder(10);
      PTGrowableSortedArrayWrapper arrLinkItems = GetItems();
      int nNumLinks = arrLinkItems.GetCount();
      SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
      XPArrayList arrLinksFromContainer = plugInModel.GetLinks();
      PTLink link;
      for (int i = 0;i < nNumLinks;i++)
      {
        int nUniqueID = XPConvert.ToInteger(arrLinkItems.GetItem(i, LINKS_COL_LINK_UNIQUE_ID));
        int nTypeID = XPConvert.ToInteger(arrLinkItems.GetItem(i, LINKS_COL_LINK_TYPE));
        for (int j = 0;j < arrLinksFromContainer.GetSize();j++)
        {
          link = (PTLink) arrLinksFromContainer.GetElement(j);
          if (link.nType == nTypeID)
          {
            int nLinkUniqueID;
            if (link.nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID)
            {
              nLinkUniqueID = link.nObjectID;
              if (nLinkUniqueID != nUniqueID)
              {
                // we need to check this if the web link has been stored.  in this case, the link.nObjectID has been updated
                nLinkUniqueID = link.nLinkObjectID;
              }
            } else
            if (link.nType == PT_CLASSIDS.PT_COMMUNITY_ID)
            {
              nLinkUniqueID = link.nPageID;
            } else
            {
              nLinkUniqueID = link.nLinkObjectID;
            }
            if (nLinkUniqueID == nUniqueID)
            {
              if (retVal.GetLength() != 0)
              {
                retVal.Append(",");
              }
              retVal.Append(link.nObjectID);
              break;
            }
          }
        }
      }
      return retVal.ToString();
    }
    public virtual bool IsAlpha()
    {
      return m_bIsAlpha;
    }
  }
}