using System;
// Framework Imports
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.sitemap.prefs
{
  /// <summary>
  /// Section for a list of links in prefs pages.
  /// </summary>
  /// <author>Naveen</author>
  public class SiteMapPortletPrefsSortedLinksView : ExpListView
  {
    
    /// <summary>
    /// Object Name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "SiteMapPortletPrefsLinkListView";
    public const int MAX_DESC_LENGTH = 70;
    
    /// <summary>
    /// Use this if we need to access the _saData
    /// but don't get it passed into the function that if 
    /// being overriden.
    /// </summary>
    internal IPTGrowableSortedArrayWrapperRO m_saData;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new SiteMapPortletPrefsSortedLinksView();
    }
    
    /// <summary>
    /// Display the javascript functions that are needed in this view.
    /// </summary>
    /// <returns>HTMLScript</returns>
    public override HTMLScript DisplayJavascript()
    {
      HTMLScript script = base.DisplayJavascript();
      return script;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(IPTGrowableSortedArrayWrapperRO,int)"></seealso>
    public override HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLElementCollection result = new HTMLElementCollection();
      result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
      if (!((SiteMapPortletPrefsSortedLinksModel) m_model).IsAlpha())
      {
        result.AddInnerHTMLElement(GetHTMLForMoveRowActions(_nRowIndex));
        }
      return result;
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the row _nRowIndex.
    /// </summary>
    /// <param name="_saData"></param>
    /// <param name="_nRowIndex"></param>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData,
     int _nRowIndex)
    {
      HTMLTableCell myCell;
      // Object Name
      String strLinkName = (String) _saData.GetItem(_nRowIndex, SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_NAME);
      String strLinkDesc = (String) _saData.GetItem(_nRowIndex, SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_DESCRIPTION);
      int nLinkType = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_TYPE));
      if (strLinkDesc == null)
      {
        strLinkDesc = "";
      }
      if (strLinkDesc.Length > MAX_DESC_LENGTH)
      {
        strLinkDesc = XPStringUtility.Substring(strLinkDesc, 0, MAX_DESC_LENGTH - 3) + "...";
        }
      myCell = new HTMLTableCell();
      myCell.SetWidth("100%");
      myCell.SetHeight("30");
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      myCell.SetNoWrap(true);
      myCell.AddInnerHTMLString(SPACE);
      // row icon
      myCell.AddInnerHTMLElement(GetIcon(nLinkType));
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      myCell.AddInnerHTMLString(SPACE);
      myCell.AddInnerHTMLEncodedString(strLinkName);
      myCell.AddInnerHTMLElement(new HTMLBr());
      if (((SiteMapPortletPrefsModel) m_asOwner.GetModel(SiteMapPortletPrefsModel.STR_MVC_CLASS_NAME)).ShowDescriptions())
      {
        myCell.AddInnerHTMLEncodedString(strLinkDesc);
      }
      return myCell;
    }
    
    /// <summary>
    /// Helper method to get the HTML for the icon.
    /// (Each row has an icon before the input text.)
    /// </summary>
    /// <returns>HTMLImg</returns>
    /// <throws>Exception</throws>
    protected virtual HTMLImg GetIcon(int nLinkType)
    {
      HTMLImg myImage;
      PTConstruct myConstruct;
      PTImageType _imgRowIcon;
      switch (nLinkType){
      case PT_CLASSIDS.PT_COMMUNITY_ID:
      _imgRowIcon = PTImageType.ICON_COMMUNITY;
      break;
      case PT_CLASSIDS.PT_CATALOGCARD_ID:
      _imgRowIcon = PTImageType.ICON_DOCUMENT;
      break;
      case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
      _imgRowIcon = PTImageType.ICON_FOLDER;
      break;
      case PT_CLASSIDS.PT_USER_ID:
      _imgRowIcon = PTImageType.ICON_USER;
      break;
      case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
      _imgRowIcon = PTImageType.ICON_URL;
      break;
      default:
      _imgRowIcon = PTImageType.ICON_ERROR;
      break;
      }
      myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
      myImage = (HTMLImg) myConstruct.GetHTMLElement();
      myImage.SetAlt("");
      myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
      return (myImage);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(HTMLTableRow)"></seealso>
    protected override void AddHTMLToActionBar(HTMLTableRow _myRow)
    {
      SiteMapFolderPlugInView plugInView = (SiteMapFolderPlugInView) m_asOwner.GetView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME);
      m_saData = ((SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)).GetReadOnlyItems();
      HTMLTableCell myCell = new HTMLTableCell();
      _myRow.AddInnerHTMLElement(myCell);
      myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
      myCell.AddInnerHTMLElement(plugInView.GetHTMLForActionBar(m_saData.GetCount()));
      }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForCheckBox(int)"></seealso>
    protected override HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
    {
      HTMLTableCell myCell;
      HTMLInput myInput;
      int nType = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_TYPE));
      int nUniqueID = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, SiteMapPortletPrefsSortedLinksModel.LINKS_COL_LINK_UNIQUE_ID));
      myCell = new HTMLTableCell();
      //myCell.SetWidth("20");
      myCell.SetHeight("30");
      myCell.SetAlign(CommonHTMLStrings.CENTER);
      myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      // checkbox
      myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, ((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW),
       m_asOwner.GetString(531, "ptmsgs_portalbrowsingmsgs"));
      myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
      myInput.SetValue(nType + "," + nUniqueID);
      myCell.AddInnerHTMLElement(myInput);
      return (myCell);
    }
    
    /// <summary>
    /// Returns the HTML for the delete cell in the action bar.
    /// The plugin view already handle delete, so we'll just return a 
    /// space here
    /// </summary>
    /// <returns>HTMLTableCell</returns>
    /// <throws>Exception</throws>
    protected override HTMLTableCell GetHTMLForDeleteAction()
    {
      HTMLTableCell myCell = new HTMLTableCell();
      myCell.SetHeight("25");
      myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
      myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      return myCell;
    }
  }
}