using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.portlets.userprofile.infrastructure;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.communities
{
  /// <author>jennifersu</author>
  public class CommunitiesPortletView : IntrinsicPortletView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.userprofile.communities.CommunitiesPortletView");
    private const int NUMBER_OF_COLUMNS = 3;
    
    /// <summary>
    /// class id for the community 
    /// </summary>
    private const int COMMUNITY_CLASSID = 512;
    private const String PROFILE_CELL_HEIGHT = "20";
    private const String IMG_FOLDER = "portal/public/img/";
    
    /// <summary>
    /// Class name for the view. For intrinsic portlets, the view must have the
    /// same class name as the model.
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = CommunitiesPortletModel.STR_MVC_CLASS_NAME;
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#Create()
     */
     
    public override Object Create()
    {
      return new CommunitiesPortletView();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()
     */
     
    public override HTMLElement DisplayPortlet()
    {
      //get the profile user id
      int profileUserID = ((ICommunitiesPortletModelRO) m_model).GetProfileID();
      // if the user preference is missing, then set to the current user
      if (CommunitiesPortletModel.NO_PROFILE_USER == profileUserID)
      {
        profileUserID = ((ICommunitiesPortletModelRO) m_model).GetCurrentUser();
        }
      //collection to hold portlet's HTML
      HTMLElementCollection result = new HTMLElementCollection();
      try
      {
        DrawTitleAndDescription(result);
        //display the profile items in a table
        HTMLTable profileItemsTable = new HTMLTable();
        result.AddInnerHTMLElement(profileItemsTable);
        profileItemsTable.SetSummary(((ICommunitiesPortletModelRO) m_model).GetPortletDescription());
        profileItemsTable.SetWidth("100%");
        profileItemsTable.SetBorder("0");
        profileItemsTable.SetCellPadding("2");
        profileItemsTable.SetCellSpacing("2");
        int numCellsInFirstRow = DrawHeaderRow(profileItemsTable);
        IXPEnumerator profileRowsEnum = GetProfileRows(profileUserID);
        int rowCount = 0;
        while (profileRowsEnum.MoveNext())
        {
          numCellsInFirstRow = DrawProfileRow(profileItemsTable, numCellsInFirstRow,
           profileRowsEnum, rowCount);
          ++rowCount;
        }
      }
      catch (XPException e)
      {
        log.Info(e, "Error displaying profile items.");
        result.AddInnerHTMLString(e.GetMessage());
      }
      return result;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()
     */
     
    public override String DisplayPortletWML()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="result"></param>
    /// <throws>HTMLException</throws>
    private void DrawTitleAndDescription(HTMLElementCollection result)
    {
      //set the title
      HTMLTable table = new HTMLTable();
      result.AddInnerHTMLElement(table);
      table.SetWidth("100%");
      table.SetBorder("0");
      table.SetCellPadding("0");
      table.SetCellSpacing("0");
      HTMLTableRow tableHeaderRow = new HTMLTableRow();
      table.AddInnerHTMLElement(tableHeaderRow);
      tableHeaderRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
      HTMLTableCell tableCell = new HTMLTableCell();
      tableHeaderRow.AddInnerHTMLElement(tableCell);
      tableCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      tableCell.SetHeight(PROFILE_CELL_HEIGHT);
      HTMLSpan span = new HTMLSpan();
      tableCell.AddInnerHTMLElement(span);
      span.SetStyleClass(PTStyleClass.OBJECT_HEADER);
      span.AddInnerHTMLString(XPHttpUtility.HtmlEncode(((ICommunitiesPortletModelRO) m_model).GetTitle()));
      // add a spacer table
      result.AddInnerHTMLElement(HTMLHelper.GetShortSpacerTable());
    }
    
    /// <param name="profileItemsTable"></param>
    /// <returns></returns>
    /// <throws>HTMLException</throws>
    private int DrawHeaderRow(HTMLTable profileItemsTable)
    {
      //create a header row (if necessary)
      IProfileRow headerRow = GetHeaderRow();
      int numCellsInFirstRow = -1;
      if (headerRow != null)
      {
        HTMLTableRow tableHeaderRow = new HTMLTableRow();
        profileItemsTable.AddInnerHTMLElement(tableHeaderRow);
        tableHeaderRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
        numCellsInFirstRow = headerRow.GetNumProfileCells();
        IXPEnumerator headerCellsEnum = headerRow.GetProfileCells();
        int nCol = 0;
        while (headerCellsEnum.MoveNext())
        {
          HTMLTableHeader tableHeaderCell = new HTMLTableHeader();
          tableHeaderCell.AddInnerHTMLString(((IProfileCell) headerCellsEnum.GetCurrent()).GetText());
          tableHeaderRow.AddInnerHTMLElement(tableHeaderCell);
          tableHeaderCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
          tableHeaderCell.SetHeight(PROFILE_CELL_HEIGHT);
          tableHeaderCell.SetAlign(CommonHTMLStrings.LEFT);
          tableHeaderCell.SetID(XPConvert.ToString(nCol));
          nCol++;
        }
      }
      return numCellsInFirstRow;
    }
    
    /// <param name="numCellsInFirstRow"></param>
    /// <param name="tableRow"></param>
    /// <param name="profileCellsEnum"></param>
    /// <param name="cellCount"></param>
    /// <throws>XPIllegalStateException</throws>
    /// <throws>HTMLException</throws>
    private void DrawProfileCell(int numCellsInFirstRow, HTMLTableRow tableRow,
     IXPEnumerator profileCellsEnum, int cellCount)
    {
      if (cellCount > numCellsInFirstRow)
      {
        throw new XPIllegalStateException("The current ProfileRow has more cells than the first ProfileRow. This is not allowed.");
        }
      HTMLTableCell tableCell = CreateHTMLTableCellFromProfileCell((IProfileCell) profileCellsEnum.GetCurrent());
      tableRow.AddInnerHTMLElement(tableCell);
      tableCell.SetHeight(PROFILE_CELL_HEIGHT);
      tableCell.SetStyleClass(PTStyleClass.LIST_TEXT);
      tableCell.SetHeaders(XPConvert.ToString(cellCount));
    }
    
    /// <param name="profileItemsTable"></param>
    /// <param name="numCellsInFirstRow"></param>
    /// <param name="profileRowsEnum"></param>
    /// <param name="rowCount"></param>
    /// <returns></returns>
    /// <throws>HTMLException</throws>
    /// <throws>XPIllegalStateException</throws>
    private int DrawProfileRow(HTMLTable profileItemsTable, int numCellsInFirstRow,
     IXPEnumerator profileRowsEnum, int rowCount)
    {
      IProfileRow profileRow = (IProfileRow) profileRowsEnum.GetCurrent();
      //get the number of cells in the first row -- all rows that 
      //follow must have the same number of cells in them
      if (numCellsInFirstRow == -1)
      {
        numCellsInFirstRow = profileRow.GetNumProfileCells();
      }
      HTMLTableRow tableRow = new HTMLTableRow();
      profileItemsTable.AddInnerHTMLElement(tableRow);
      IXPEnumerator profileCellsEnum = profileRow.GetProfileCells();
      if ((rowCount % 2) == 0)
      {
        tableRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
      } else
      {
        tableRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
      }
      int cellCount = 0;
      while (profileCellsEnum.MoveNext())
      {
        DrawProfileCell(numCellsInFirstRow, tableRow, profileCellsEnum, cellCount);
        ++cellCount;
      }
      if (cellCount < numCellsInFirstRow)
      {
        throw new XPIllegalStateException("The current ProfileRow has fewer cells than the first ProfileRow. This is not allowed.");
        }
      return numCellsInFirstRow;
    }
    
    /// <param name="profileUserID"></param>
    /// <param name="UserLogOnToken"></param>
    /// <param name="viewingUserID"></param>
    /// <returns></returns>
    /// <throws>XPException</throws>
    /// <throws>XPIllegalArgumentException</throws>
    /// <throws>XPIndexOutOfBoundsException</throws>
    /// <seealso cref="com.plumtree.xpportlets.expatriate.ext.introspective.IProfilePortlet#getProfileItems(int,int,String)"></seealso>
    public virtual IXPEnumerator GetProfileRows(int profileUserID)
    {
      XPArrayList aProfileRows = null;
      IPTQueryResult searchResponse;
      ICommunitiesPortletModelRO iModel = (ICommunitiesPortletModelRO) m_model;
      // now try getting the search results for the desired profile user
      try
      {
        searchResponse = iModel.GetSearchResults(profileUserID);
      }
      catch (Exception e)
      {
        throw new XPException(m_asOwner.GetString(3, "ptmsgs_portletsmsgs"),
         e);
      }
      try
      {
        if (searchResponse.RowCount() > 0)
        {
          // initialize the profile rows
          aProfileRows = new XPArrayList(searchResponse.RowCount());
          // create an image that is used at the front of the portlet 
          HTMLImg myImg = new HTMLImg(IMG_FOLDER + "icon_community.gif", m_asOwner.GetString(8,
           "ptmsgs_portletsmsgs"));
          // loop through the results and create the rows and profile cells
          for (int i = 0;i < searchResponse.RowCount();i++)
          {
            XPArrayList webCells = new XPArrayList(NUMBER_OF_COLUMNS);
            // there are three columns in the introspective portlet
            ProfileCell myImage = new ProfileCell(myImg);
            webCells.Add(myImage);
            // get the data using the HTMLHelper object
            ProfileCell myData = HTMLHelper.CreateProfileRowFromPTResults(m_asOwner,
             searchResponse, i, COMMUNITY_CLASSID);
            webCells.Add(myData);
            // create the text cell based on if the user is an expert, cont. mgr., or both
            String sRoles = iModel.GetUserRoles(searchResponse, i, profileUserID);
            ProfileCell myRole = new ProfileCell(sRoles, "", "", null, false);
            webCells.Add(myRole);
            // add the cells to the row
            aProfileRows.Add(new ProfileRow(webCells));
          }
        }
      }
      catch (Exception e)
      {
        throw new XPException(m_asOwner.GetString(7, "ptmsgs_portletsmsgs"),
         e);
      }
      if (null == aProfileRows)
      {
        throw new XPException(m_asOwner.GetString(10, "ptmsgs_portletsmsgs"));
        } else
      {
        return (aProfileRows.GetEnumerator());
      }
    }
    
    /// <returns></returns>
    public virtual IProfileRow GetHeaderRow()
    {
      XPArrayList headerCells = new XPArrayList(NUMBER_OF_COLUMNS);
      headerCells.Add(new ProfileCell("&nbsp;", "", "", null, true));
      headerCells.Add(new ProfileCell(m_asOwner.GetString(9, "ptmsgs_portletsmsgs"),
       "", "", null, true));
      headerCells.Add(new ProfileCell(m_asOwner.GetString(11, "ptmsgs_portletsmsgs"),
       "", "", null, true));
      return (new ProfileRow(headerCells));
    }
    
    /// <param name="profileCell"></param>
    /// <returns></returns>
    /// <throws>HTMLException</throws>
    private HTMLTableCell CreateHTMLTableCellFromProfileCell(IProfileCell profileCell)
    {
      HTMLTableCell tableCell = new HTMLTableCell();
      // if it is an image then indicate the column width as small
      if (profileCell.isImg())
      {
        tableCell.SetWidth("3");
        tableCell.AddInnerHTMLElement(profileCell.GetImage());
      } else
      //if there is an anchor tag then get the anchor for the cell and add the text
      if (null != profileCell.GetHTMLAnchor())
      {
        HTMLAnchor link = profileCell.GetHTMLAnchor();
        if (profileCell.isHTML())
        {
          link.AddInnerHTMLString(profileCell.GetText());
        } else
        {
          link.AddInnerHTMLString(XPHttpUtility.HtmlEncode(profileCell.GetText()));
          }
        link.SetTitle(XPHttpUtility.HtmlEncode(profileCell.GetMouseOver()));
        //link.SetTarget("_blank");
        tableCell.AddInnerHTMLElement(link);
      } else
      {
        if (profileCell.isHTML())
        {
          tableCell.AddInnerHTMLString(profileCell.GetText());
        } else
        {
          tableCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(profileCell.GetText()));
          }
      }
      // check to see if there is a sub text
      if (!("").Equals(profileCell.GetSubText()))
      {
        tableCell.AddInnerHTMLString(new HTMLBr().GetDisplayString());
        // I'm always going to encode the description, b/c I know it will be HTML text
        tableCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(profileCell.GetSubText()));
        }
      return tableCell;
    }
  }
}