using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.portalsettings;
using com.plumtree.portalpages.browsing.portalsettings.settings;
using com.plumtree.portalpages.portlets.userprofile.infrastructure;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay
{
  /// <author>jennifersu</author>
  public class EODPortletView : IntrinsicPortletView
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.userprofile.eoddisplay.EODPortletView");
    
    /// <summary>
    /// Class name for the view. For intrinsic portlets, the view must have the
    /// same class name as the model.
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = EODPortletModel.STR_MVC_CLASS_NAME;
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#Create()
     */
     
    public override Object Create()
    {
      return new EODPortletView();
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()
     */
     
    public override HTMLElement DisplayPortlet()
    {
      // DCA - portlet will be styled differently in layout mode
      bool bIsLayoutEnabled = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetLayoutEnabled();
      HTMLElement result;
      if (bIsLayoutEnabled)
      {
        // DCA - create container div in layout mode
        result = new HTMLDiv();
        result.SetID("ali-user-geninfo-container");
      } else
      {
        // collection to hold portlet's HTML
        result = new HTMLElementCollection();
      }
      result.SetForceLineBreaksAfterSafeElements(true);
      IEODPortletModelRO iModel = (IEODPortletModelRO) m_model;
      if (!iModel.OnCommunityPage())
      {
        if (bIsLayoutEnabled)
        {
          DisplayErrorLayoutMode(result, m_asOwner.GetString(51, "ptmsgs_portletsmsgs"));
          } else
        {
          DisplayErrorClassicMode(result, m_asOwner.GetString(51, "ptmsgs_portletsmsgs"));
          }
        return result;
      } else
      {
        try
        {
          //get the profile user id
          int profileUserID = ((IEODPortletModelRO) m_model).GetProfileID();
          // if the user preference is missing, then set to the current user
          if (EODPortletModel.NO_PROFILE_USER == profileUserID)
          {
            profileUserID = ((IEODPortletModelRO) m_model).GetCurrentUser();
            }
          try
          {
            iModel.GetData();
          }
          catch (XPException e)
          {
            if (bIsLayoutEnabled)
            {
              DisplayErrorLayoutMode(result, m_asOwner.GetString(33, "ptmsgs_portletsmsgs"));
              } else
            {
              DisplayErrorClassicMode(result, m_asOwner.GetString(33, "ptmsgs_portletsmsgs"));
              }
            return result;
          }
          IPTProfilePage profilePage = iModel.GetProfilePage();
          //if there are no categories, display a message
          if (profilePage.GetChildSections().Length == 0)
          {
            if (bIsLayoutEnabled)
            {
              DisplayErrorLayoutMode(result, m_asOwner.GetString(53, "ptmsgs_portletsmsgs"));
              } else
            {
              DisplayErrorClassicMode(result, m_asOwner.GetString(53, "ptmsgs_portletsmsgs"));
              }
            return result;
          }
          // Get the user properties hashtable
          // Key=property ID; Value=XPArrayList of property values
          XPHashtable profileData = iModel.PutUserPropertiesIntoHashtable(profileUserID);
          IPortalSettings editSetting = null;
          if ((profileUserID == ((IEODPortletModelRO) m_model).GetCurrentUser()) && (((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_OWN_PROFILE)))
          {
            // user is viewing his own profile, allow edit
            editSetting = new EditUserProfileSetting();
            if (!bIsLayoutEnabled)
            {
              result.AddInnerHTMLElement(CreateActionBar(editSetting));
            }
          }
          //for each category, make a row for the category title
          //and then a row for each property
          Object[] arProfileSectionIDs = profilePage.GetChildSections();
          IPTObjectManager profileSectionMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();
          for (int indSection = 0;indSection < arProfileSectionIDs.Length;
          indSection++)
          {
            int nProfileSectionID = XPConvert.ToInteger(arProfileSectionIDs[indSection]);
            IPTProfileSection profileSection = (IPTProfileSection) profileSectionMgr.Open(nProfileSectionID,
             false);
            // start the table
            HTMLTable myTable;
            if (bIsLayoutEnabled)
            {
              myTable = DisplayHeaderLayoutMode(result, XPHttpUtility.HtmlEncode(profileSection.GetLocalizedName()),
               indSection, editSetting);
            } else
            {
              myTable = DisplayHeaderClassicMode(result, XPHttpUtility.HtmlEncode(profileSection.GetLocalizedName()));
              }
            IPTQueryResult ptqrPropertyInfo = profileSection.GetProperties();
            bool bPropertyDisplayed = false;
            for (int indProperty = 0;indProperty < ptqrPropertyInfo.RowCount();
            indProperty++)
            {
              if (ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_VISIBLE) == 1)
              {
                bPropertyDisplayed = DrawProperty(profileData, myTable, ptqrPropertyInfo,
                 indProperty, bIsLayoutEnabled) || bPropertyDisplayed;
              }
            }
            // if there were no properties displayed, display a message
            if (!bPropertyDisplayed)
            {
              HTMLTableRow myRow = new HTMLTableRow();
              myTable.AddInnerHTMLElement(myRow);
              HTMLTableCell myCell = new HTMLTableCell();
              myRow.AddInnerHTMLElement(myCell);
              myCell.AddInnerHTMLString(m_asOwner.GetString(31, "ptmsgs_portletsmsgs"));
              if (!bIsLayoutEnabled)
              {
                myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
              }
              myCell.SetColSpan("2");
            }
            if (!bIsLayoutEnabled)
            {
              result.AddInnerHTMLElement(HTMLHelper.GetShortSpacerTable());
              }
          }
        }
        catch (Exception e)
        {
          log.Error(e, STR_MVC_CLASS_NAME + "::Display The following error occured when trying to display the HTML: " + e.Message);
          throw new XPException(m_asOwner.GetString(28, "ptmsgs_portletsmsgs"),
           e);
        }
      }
      return result;
    }
    private HTMLTable DisplayHeaderLayoutMode(HTMLElement result, String sectionName,
     int indSection, IPortalSettings editSetting)
    {
      HTMLDiv myOuterDiv = new HTMLDiv();
      result.AddInnerHTMLElement(myOuterDiv);
      myOuterDiv.SetStyleClass("ali-user-geninfo-divider");
      // DCA - add edit if available on first section
      if (0 == indSection && null != editSetting)
      {
        HTMLDiv myInnerDiv = new HTMLDiv();
        myOuterDiv.AddInnerHTMLElement(myInnerDiv);
        myInnerDiv.SetID("ali-user-geninfo-edit");
        HTMLImg myImg = new HTMLImg("portal/private/img/icon_edit.gif", m_asOwner.GetString(54,
         "ptmsgs_portletsmsgs"));
        myInnerDiv.AddInnerHTMLElement(myImg);
        HTMLAnchor myAnchor = new HTMLAnchor("");
        myInnerDiv.AddInnerHTMLElement(myAnchor);
        myAnchor.AddInnerHTMLString(m_asOwner.GetString(54, "ptmsgs_portletsmsgs"));
        String onclick = "window.location=\'" + GetLinkFromPortalSetting(editSetting) + "\'; return false;";
        myAnchor.SetOnClick(onclick);
      }
      myOuterDiv.AddInnerHTMLString(sectionName);
      myOuterDiv = new HTMLDiv();
      result.AddInnerHTMLElement(myOuterDiv);
      myOuterDiv.SetStyleClass("ali-user-geninfo");
      HTMLTable myTable = new HTMLTable();
      myOuterDiv.AddInnerHTMLElement(myTable);
      return myTable;
    }
    private HTMLTable DisplayHeaderClassicMode(HTMLElement result, String sectionName)
    {
      result.AddInnerHTMLElement(HTMLHelper.GetHeaderView(sectionName));
      result.AddInnerHTMLElement(HTMLHelper.GetShortSpacerTable());
      // DCA - outer table of properties list
      HTMLTable myTable = GetHTMLTable();
      myTable.SetSummary(XPHttpUtility.HtmlEncode(((IEODPortletModelRO) m_model).GetPortletDescription()));
      result.AddInnerHTMLElement(myTable);
      return myTable;
    }
    private void DisplayErrorLayoutMode(HTMLElement result, String errorMsg)
    {
      HTMLDiv myDiv = new HTMLDiv();
      result.AddInnerHTMLElement(myDiv);
      myDiv.SetStyleClass("ali-user-geninfo");
      myDiv.AddInnerHTMLString(errorMsg);
    }
    private void DisplayErrorClassicMode(HTMLElement result, String errorMsg)
    {
      HTMLTable myTable;
      HTMLTableCell myCell;
      HTMLTableRow myRow;
      myTable = GetHTMLTable();
      myTable.SetSummary(errorMsg);
      result.AddInnerHTMLElement(myTable);
      myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.AddInnerHTMLString(errorMsg);
      myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
    }
    
    /// <summary>
    /// Returns a blank HTMLTable
    /// </summary>
    /// <returns>HTMLElement</returns>
    private HTMLTable GetHTMLTable()
    {
      HTMLTable myTable = new HTMLTable();
      myTable.SetWidth("100%");
      myTable.SetBorder("0");
      myTable.SetCellPadding("5");
      myTable.SetCellSpacing("0");
      return myTable;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()
     */
     
    public override String DisplayPortletWML()
    {
      return null;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <param name="profileData"></param>
    /// <param name="sectionsTable"></param>
    /// <param name="propertiesEnum"></param>
    /// <param name="rowNumber"></param>
    /// <throws>HTMLException</throws>
    private bool DrawProperty(XPHashtable profileData, HTMLTable sectionsTable,
     IPTQueryResult _ptqrPropertyInfo, int indProperty, bool bIsLayoutEnabled)
    {
      bool bPropertyDisplayed = false;
      Object objPropertyID = _ptqrPropertyInfo.ItemAsObject(indProperty, PT_PROPIDS.PT_PROPID_OBJECTID);
      int nPropertyID = XPConvert.ToInteger(objPropertyID);
      // Get all user values for this property
      XPArrayList xpalPropValues = (XPArrayList) profileData.GetElement(nPropertyID);
      if ((xpalPropValues != null) && (xpalPropValues.GetSize() > 0))
      {
        Object objFirstValue;
        objFirstValue = xpalPropValues.GetElement(0);
        if (objFirstValue != null)
        {
          bPropertyDisplayed = true;
          HTMLTableRow propertyRow = new HTMLTableRow();
          sectionsTable.AddInnerHTMLElement(propertyRow);
          HTMLTableCell propertyNameCell = new HTMLTableCell();
          propertyRow.AddInnerHTMLElement(propertyNameCell);
          String strPropName = _ptqrPropertyInfo.ItemAsString(indProperty,
           PT_PROPIDS.PT_PROPID_NAME);
          XPStringBuilder propertyNameSB = new XPStringBuilder(strPropName);
          propertyNameSB.Append(m_asOwner.GetString(50, "ptmsgs_portletsmsgs"));
          strPropName = XPHttpUtility.HtmlEncode(propertyNameSB.ToString());
          if (bIsLayoutEnabled)
          {
            DisplayPropertyNameLayoutMode(propertyNameCell, strPropName);
            } else
          {
            DisplayPropertyNameClassicMode(propertyNameCell, strPropName);
            }
          //add the first value for the property for the current user
          HTMLTableCell propertyValueCell = new HTMLTableCell();
          propertyRow.AddInnerHTMLElement(propertyValueCell);
          if (!bIsLayoutEnabled)
          {
            propertyValueCell.SetWidth("100%");
            propertyValueCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
          }
          int nRefClassID = _ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_REFCLASS);
          if (nRefClassID > 0)
          {
            // This is a reference property.  Need to convert
            // the property value from reference object ID into the reference name
            int nRefValue = XPConvert.ToInteger(objFirstValue);
            objFirstValue = ((IEODPortletModelRO) m_model).GetNameFromObjectID(nRefClassID,
             nRefValue);
          }
          if (_ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_HREF) == 1)
          {
            HTMLAnchor propLink = new HTMLAnchor(XPHttpUtility.HtmlEncode(XPConvert.ToString(objFirstValue)));
            propLink.SetTitle(XPHttpUtility.HtmlEncode(XPConvert.ToString(objFirstValue)));
            propLink.AddInnerHTMLEncodedString(XPConvert.ToString(objFirstValue));
            propertyValueCell.AddInnerHTMLElement(propLink);
          } else
          if (_ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE) == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE)
          {
            propertyValueCell.AddInnerHTMLString(GetDateFormat().Format((XPDateTime) objFirstValue));
            } else
          {
            propertyValueCell.AddInnerHTMLEncodedString(XPConvert.ToString(objFirstValue));
            }
        }
        for (int indValue = 1;indValue < xpalPropValues.GetSize();indValue++)
        {
          Object objPropertyValue = xpalPropValues.GetElement(indValue);
          if (null != objPropertyValue)
          {
            bPropertyDisplayed = DrawMultipleValue(sectionsTable, _ptqrPropertyInfo,
             indProperty, objPropertyValue, bIsLayoutEnabled) || bPropertyDisplayed;
            }
        }
      }
      return bPropertyDisplayed;
    }
    private void DisplayPropertyNameLayoutMode(HTMLTableCell propertyNameCell,
     String strPropName)
    {
      propertyNameCell.SetStyleClass("ali-user-geninfo-title");
      propertyNameCell.AddInnerHTMLString(strPropName);
    }
    private void DisplayPropertyNameClassicMode(HTMLTableCell propertyNameCell,
     String strPropName)
    {
      propertyNameCell.SetWidth("125");
      propertyNameCell.SetVAlign("top");
      propertyNameCell.SetNoWrap(true);
      propertyNameCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      HTMLSpan mySpan = new HTMLSpan();
      propertyNameCell.AddInnerHTMLElement(mySpan);
      mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
      mySpan.AddInnerHTMLString(strPropName);
    }
    
    /// <param name="profileData"></param>
    /// <param name="sectionsTable"></param>
    /// <param name="propertiesEnum"></param>
    /// <param name="rowNumber"></param>
    /// <throws>HTMLException</throws>
    private bool DrawMultipleValue(HTMLTable _sectionsTable, IPTQueryResult _ptqrPropertyInfo,
     int indProperty, Object _objPropertyValue, bool bIsLayoutEnabled)
    {
      bool bPropertyDisplayed = false;
      HTMLTableRow propertyRow = new HTMLTableRow();
      _sectionsTable.AddInnerHTMLElement(propertyRow);
      HTMLTableCell propertyNameCell = new HTMLTableCell();
      propertyRow.AddInnerHTMLElement(propertyNameCell);
      if (bIsLayoutEnabled)
      {
        DisplayPropertyNameLayoutMode(propertyNameCell, CommonHTMLStrings.SPACE);
        } else
      {
        DisplayPropertyNameClassicMode(propertyNameCell, CommonHTMLStrings.SPACE);
        }
      //add the value for the property for the current user
      HTMLTableCell propertyValueCell = new HTMLTableCell();
      propertyRow.AddInnerHTMLElement(propertyValueCell);
      if (!bIsLayoutEnabled)
      {
        propertyValueCell.SetWidth("100%");
        propertyValueCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      }
      if (_objPropertyValue != null)
      {
        bPropertyDisplayed = true;
        int nRefClassID = _ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_REFCLASS);
        if (nRefClassID > 0)
        {
          // This is a reference property.  Need to convert
          // the property value from reference object ID into the reference name
          int nRefValue = XPConvert.ToInteger(_objPropertyValue);
          _objPropertyValue = ((IEODPortletModelRO) m_model).GetNameFromObjectID(nRefClassID,
           nRefValue);
        }
        if (_ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_HREF) == 1)
        {
          HTMLAnchor propLink = new HTMLAnchor(XPHttpUtility.HtmlEncode(XPConvert.ToString(_objPropertyValue)));
          propLink.SetTitle(XPHttpUtility.HtmlEncode(XPConvert.ToString(_objPropertyValue)));
          propLink.AddInnerHTMLEncodedString(XPConvert.ToString(_objPropertyValue));
          propertyValueCell.AddInnerHTMLElement(propLink);
        } else
        if (_ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE) == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE)
        {
          propertyValueCell.AddInnerHTMLString(GetDateFormat().Format((XPDateTime) _objPropertyValue));
          } else
        {
          propertyValueCell.AddInnerHTMLEncodedString(XPConvert.ToString(_objPropertyValue));
          }
      } else
      {
        propertyValueCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
      }
      return bPropertyDisplayed;
    }
    
    /// <param name="_ptSetting"></param>
    /// <returns></returns>
    private String GetLinkFromPortalSetting(IPortalSettings _ptSetting)
    {
      ASURL asURL = new ASURL(m_asOwner);
      String strSettingURL = null;
      // The space
      asURL.SetLinkCreateNewSpace(_ptSetting.GetASName(), m_asOwner);
      // The control
      String strControl = _ptSetting.GetASControlName();
      if (strControl != null)
      {
        asURL.SetControl(strControl);
      }
      asURL.SetDisplayPage("portlet_" + ((IEODPortletModelRO) m_model).GetPortletID());
      // The query string
      String strQueryString = _ptSetting.GetASQueryString();
      if (strQueryString != null)
      {
        strSettingURL = asURL.GetURLAsString() + strQueryString;
      } else
      {
        strSettingURL = asURL.GetURLAsString();
      }
      return strSettingURL;
    }
    
    /// <summary>
    /// Helper Method that creates action bar for the subHeader.
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    /// <throws>HTMLException</throws>
    private HTMLElement CreateActionBar(IPortalSettings _ptSetting)
    {
      HTMLElementCollection anchors = new HTMLElementCollection();
      HTMLAnchor myAnchor;
      /* create anchor */
      if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
      {
        myAnchor = CreateAnchor(m_asOwner.GetString(54, "ptmsgs_portletsmsgs"),
         PTImageType.ACTION_EDIT, "window.location=\'" + GetLinkFromPortalSetting(_ptSetting) + "\'; return false;");
        } else
      {
        myAnchor = new HTMLAnchor(GetLinkFromPortalSetting(_ptSetting));
        myAnchor.AddInnerHTMLString(XPFormat.Format(m_asOwner.GetString(52,
         "ptmsgs_portletsmsgs"), new Object[]{XPHttpUtility.HtmlEncode(((IEODPortletModelRO) m_model).GetPortletName())}));
        }
      anchors.AddInnerHTMLElement(myAnchor);
      /* create action bar */
      return HTMLConstructHelpers.GetActionBar(anchors, ((IEODPortletModelRO) m_model).GetPortletName(),
       this.m_asOwner);
    }
    
    /// <summary>
    /// Helper Method that creates anchors for the subHeader.
    /// </summary>
    /// <returns>HTMLElementCollection</returns>
    /// <throws>HTMLException</throws>
    private HTMLAnchor CreateAnchor(String _btnText, PTImageType _imgType,
     String _onClick)
    {
      HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(_imgType).GetHTMLElement();
      HTMLAnchor anchor = HTMLConstructHelpers.GetActionBarAnchor(0, img,
       XPFormat.Format(m_asOwner.GetString(52, "ptmsgs_portletsmsgs"), new Object[]{XPHttpUtility.HtmlEncode(((IEODPortletModelRO) m_model).GetPortletName())}),
       _btnText, _onClick, this.m_asOwner);
      return anchor;
    }
    private XPDateFormat GetDateFormat()
    {
      String strLocale = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE,
       m_asOwner);
      String strTZ = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE,
       m_asOwner);
      XPTimeZone xpTZ;
      if (null == strTZ)
      {
        xpTZ = new XPTimeZone();
      } else
      {
        xpTZ = XPTimeZone.GetTimeZone(strTZ);
      }
      XPDateFormat xpFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.DEFAULT,
       XPDateFormat.DEFAULT, new XPLocale(strLocale), xpTZ);
      return xpFormat;
    }
  }
}