using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.editors.community;
using com.plumtree.portalpages.portlets.userprofile.eoddisplay;
using com.plumtree.portaluiinfrastructure.editor;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.expandablelist;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs
{
  /// <author>JHQ</author>
  /// <author>
  /// jennifersu
  /// The activity space for the portlet admin pref page.  It registers the
  /// classes for user profile layout.
  /// </author>
  public class EODPortletPrefsEditorAS : ObjEditorAS
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsEditorAS");
    
    /// <summary>
    /// object name 
    /// </summary>
    public static readonly String STR_MVC_CLASS_NAME = EODPortletModel.STR_MVC_CLASS_NAME + IntrinsicPortletPrefsUtils.PREFS_SUFFIX;
    
    /// <summary>
    /// pop up constants used for keying pop up display pages 
    /// </summary>
    public const String strStorageProfileSectionList = "storageProfileSectionList";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EODPortletPrefsEditorAS();
    }
    
    /// <summary>
    /// Gets the Editor title.
    /// </summary>
    public override String GetEditorTitle()
    {
      return (GetString(47, "ptmsgs_portletsmsgs"));
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the class name of the Repost Control.
    /// </summary>
    /// <returns>String</returns>
    public override String GetRepostControlName()
    {
      return (EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes used for the profile pages.
    /// </summary>
    public virtual void InitProfilePage(EODPortletPrefsModel _model, IPTProfilePage _ptProfilePage)
    {
      /* register display page */
      RegisterPage(new EODPortletPrefsMainDP(_ptProfilePage.GetName(), _ptProfilePage.GetDescription()));
      /* rename category dp and view */
      RegisterPage(new EODPortletPrefsRenameCtgDP(_ptProfilePage.GetName()));
      RegisterView(EODPortletPrefsRenameCtgView.STR_MVC_CLASS_NAME, _model);
      // Register the select PTObject list as a plug-in for each section
      Object[] arProfileSectionIDs = _ptProfilePage.GetChildSections();
      for (int indSection = 0;indSection < arProfileSectionIDs.Length;indSection++)
      {
        int nSectionID = XPConvert.ToInteger(arProfileSectionIDs[indSection]);
        RegisterProfileSection(nSectionID);
      }
      SetCurrentPage(EODPortletPrefsMainDP.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Registers all the classes for this Activity Space.
    /// </summary>
    public override void Init()
    {
      /* set the main model name and call super class's init */
      m_strModelName = EODPortletPrefsModel.STR_MVC_CLASS_NAME;
      base.Init();
      /* get the main model and repost control and register them */
      EODPortletPrefsModel myModel = (EODPortletPrefsModel) GetModel(m_strModelName);
      RegisterControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME, myModel);
      // display page/view for creating new categories
      RegisterPage(new EODPortletPrefsNewCtgDP(), EODPortletPrefsNewCtgDP.STR_MVC_CLASS_NAME);
      RegisterView(EODPortletPrefsNewCtgView.STR_MVC_CLASS_NAME, myModel);
      // objects for renaming sections and categories.  This "subclasses" the 
      // LocNames* objects for localizing strings
      EODPortletPrefsLocNamesDP myLocNamesDP = new EODPortletPrefsLocNamesDP();
      myLocNamesDP.AddToValidationFunction(LocNamesPrimaryNameView.VALIDATION_FUNC_NAME);
      RegisterPage(myLocNamesDP, EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME);
      /* reorder and delete objects */
      RegisterPage(new EODPortletPrefsMoveCtgDP());
      RegisterModel(EODPortletPrefsProfileSectionListModel.STR_MVC_CLASS_NAME,
       strStorageProfileSectionList);
      IModel sectionsModel = GetModel(strStorageProfileSectionList);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageProfileSectionList,
       sectionsModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageProfileSectionList,
       sectionsModel);
    }
    
    /// <summary>
    /// This is a helper method that all classes that inherit from AFormDP can
    /// override if they like.  The method provides a hook into the head so
    /// that DP's can add javascript. Simply override and return and
    /// HTMLScript.  Also, it is best to return the results of the
    /// DisplayJavaScript functions from the appropriate views.
    /// </summary>
    /// <returns>HTMLScriptCollection the Javascript from the Child IViews</returns>
    /// <throws>
    /// HTMLException If error occurs while creating or populating
    /// HTML Elements.
    /// </throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()">Override this method to Display javascript from child IViews</seealso>
    public override HTMLScriptCollection DisplayCommonJavaScript()
    {
      HTMLScriptCollection scripts = base.DisplayCommonJavaScript();
      HTMLScript script = new HTMLScript("text/javascript");
      script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
      scripts.AddInnerHTMLElement(script);
      script = new HTMLScript("text/javascript");
      scripts.AddInnerHTMLElement(script);
      XPStringBuilder sb = new XPStringBuilder(200);
      sb.Append("\n").Append("function ").Append(CommunityEditorAS.JS_ALERTSAVEFORPREFS_FUNC).Append("()").Append("{\n").Append("\t\tif ( confirm(\'").Append(GetString(1228,
       "ptmsgs_portalbrowsingmsgs")).Append("\') )\n").Append("\t\t{\n").Append("\t\t\treturn true;").Append("\t\t}\n").Append("\t\treturn false;").Append("}\n");
      script.AddInnerHTMLString(sb.ToString());
      return scripts;
    }
    
    /// <summary>
    /// Registers the objects associated with a PTProfileSection
    /// (i.e. Model, View, Control).
    /// </summary>
    /// <param name="__intProfileSectionID"></param>
    public virtual void RegisterProfileSection(int _intProfileSectionID)
    {
      /* section select explist */
      String key = EODPortletPrefsModel.GetProfileSectionKey(_intProfileSectionID);
      RegisterModel(EODPortletPrefsSelectPTObjectModel.STR_MVC_CLASS_NAME,
       key);
      IModel myModel = GetModel(key);
      RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, key, myModel);
      RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, key, myModel);
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()"></seealso>
    /// <param name="IDisplayPage">the current Display Page</param>
    public override void SetCurrentPage(IDisplayPage page)
    {
      base.SetCurrentPage(page);
      String sPageName = page.GetName();
      if (page is EODPortletPrefsMainDP)
      {
        SetHelpTopic("PT_UserProfilePortletConfiguration");
      } else
      if (page is EODPortletPrefsMoveCtgDP)
      {
        SetHelpTopic("PT_DeleteOrderCategories");
      } else
      if (page is EODPortletPrefsRenameCtgDP)
      {
        SetHelpTopic("PT_RenameCategory");
      } else
      if (EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME.Equals(sPageName))
      {
        SetHelpTopic("PT_RenameCategories");
      }
    }
  }
}