using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs
{
  /// <author>JHQ</author>
  /// <author>
  /// jennifersu
  /// This class calls the Localized Names Views to display profile object names
  /// and descriptions in localized formats.
  /// </author>
  public class EODPortletPrefsLocNamesDP : EditorDP
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.EODPortletPrefsLocNamesDP");
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EODDisplayPrefsLocNames";
    
    /// <summary>
    /// html element names 
    /// </summary>
    public const String HTMLBUTTON_DONE = "in_bu_done";
    public const String HTMLBUTTON_CANCEL = "in_bu_cancel";
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,  linking to
    /// that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_asOwner.GetString(978, "ptmsgs_portaladminmsgs");
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Returns the HTML for the General Info page.
    /// </summary>
    /// <returns>HTMLElement</returns>
    /// <throws>HTMLException on error</throws>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      /* done & cancel buttons */
      HTMLTable myTable = GetActionRow();
      result.AddInnerHTMLElement(myTable);
      /* add views to a row of this table */
      HTMLTableRow myRow = new HTMLTableRow();
      myTable.AddInnerHTMLElement(myRow);
      HTMLTableCell myCell = new HTMLTableCell();
      myRow.AddInnerHTMLElement(myCell);
      myCell.SetColSpan("2");
      HTMLElementCollection views = new HTMLElementCollection();
      //MES- Add the primary name/desc
      views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME)).Display());
      //MES- Add the list of languages we're localized into, IF we support localization AND we're localized!
      LocNamesModel model = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);
      if (model.m_bSupportsLocalization && model.GetIsLocalized())
      {
        views.AddInnerHTMLElement(new HTMLBr());
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME)).Display());
        }
      myCell.AddInnerHTMLElement(views);
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection scripts = base.DisplayJavaScriptFromChild();
      scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME).DisplayJavascript());
      //MES- Add the JavaScript for the list of languages we're localized into, IF we support localization!
      LocNamesModel model = (LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);
      if (model.GetIsLocalized())
      {
        scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME).DisplayJavascript());
        }
      return scripts;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()"></seealso>
    private HTMLTable GetActionRow()
    {
      HTMLTable myTable;
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLInput myInput;
      HTMLSpan mySpan;
      try
      {
        // action Row begin
        myTable = new HTMLTable();
        myTable.SetWidth("100%");
        myTable.SetBorder("0");
        myTable.SetCellPadding("10");
        myTable.SetCellSpacing("0");
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
        /* title */
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign("left");
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        mySpan.AddInnerHTMLString(m_asOwner.GetString(985, "ptmsgs_portaladminmsgs"));
        /* buttons */
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myCell.SetAlign("right");
        // ***Done Action*** begins here
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_DONE, "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(979, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("postToSelf(\'" + EODPortletPrefsRepostControl.POSTTOSELF_ACTION_RENAMEOBJ_DONE + "\');");
        // ***Done Action*** ends here
        // spacer
        myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        // ***Cancel Action*** begins here
        myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL,
         "");
        myCell.AddInnerHTMLElement(myInput);
        myInput.SetValue(m_asOwner.GetString(980, "ptmsgs_portaladminmsgs"));
        myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
        // mj: removed 'Javascript:' from function name
        myInput.SetOnClick("postToSelf(\'" + EODPortletPrefsRepostControl.POSTTOSELF_ACTION_RENAMEOBJ_CANCEL + "\');");
        }
      // ***Cancel Action*** ends here
      // action Row end
      catch (Exception e)
      {
        log.Error(e, "EODPortletPrefsMainDP::Display An error occured when trying to display the HTML.");
        throw new XPException(m_asOwner.GetString(981, "ptmsgs_portaladminmsgs"),
         e);
      }
      return myTable;
    }
  }
}