using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs
{
  /// <summary>
  /// SelectPTObjectModel for selecting Profile Sections
  /// </summary>
  /// <author>jennifersu</author>
  public class EODPortletPrefsProfileSectionListModel : SelectPTObjectModel,ISelectPTObjectModelRO
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EODDisplayPrefsProfileSectionList";
    
    /// <summary>
    /// Number total of columns
    /// </summary>
    public const int EXPLIST_COL_MAX = 5;
    
    /// <summary>
    /// This column contains the PTProfileSection objects.
    /// </summary>
    public const int EXPLIST_COL_PROFILESECTION = 4;
    private XPArrayList m_listOfGlobalUserProps;
    private String m_propsDisplayString = "";
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EODPortletPrefsProfileSectionListModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Initalizes the list (PTGrowableSortedArrayWrapper)
    /// with a column mapping and an array of sort.
    /// The growable array will always be sorted by the 1st
    /// column ascending.
    /// </summary>
    /// <param name="_saData"></param>
    public override void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
    {
      // JF- Column mapping
      int[] arrColumns = new int[]{EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
       EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING, EXPLIST_COL_PROFILESECTION};
      // JF- Sort array
      // The growable array will always be sorted by the String column (the one displayed).
      int[][] arrSort = new int[1][];
      for (int j2c_index = 0;j2c_index < 1;j2c_index++)
      {
        arrSort[j2c_index] = new int[2];
      }
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID] = EXPLIST_COL_STRING;
      arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
      // JF- We don't initalize the list itself (null below)
      // At first it's empty and we will be initalized if needed using the 
      // AddRowsToList method.
      _saData.Initialize(arrColumns, null, arrSort, true, EXPLIST_DEFAULT_INITIAL_SIZE);
      }
    public virtual void LoadProfileSections(IPTProfilePage _ptProfilePage)
    {
      /*
       * restrict pop up tree to display on those properties mapped on global
       * object property map for users
       */
       
      IPTObjectPropertyMap propMap = (IPTObjectPropertyMap) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP,
       false);
      IPTQueryResult results = propMap.QueryClassPropertyMappings(PT_CLASSIDS.PT_USER_ID,
       PT_PROPIDS.PT_PROPID_OBJECTID);
      int nCount = results.RowCount();
      m_listOfGlobalUserProps = new XPArrayList(nCount);
      if (nCount > 0)
      {
        XPStringBuilder displayString = new XPStringBuilder(nCount * 8);
        String sClass = "" + PT_CLASSIDS.PT_PROPERTY_ID + ',';
        for (int i = 0;i < nCount;i++)
        {
          if (i > 0)
          {
            displayString.Append(',');
          }
          /* get the prop id */
          int propID = results.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
          /* add it to list so we can check for it later */
          m_listOfGlobalUserProps.Add(propID);
          /* add to display string */
          displayString.Append(sClass).Append(propID);
        }
        m_propsDisplayString = displayString.ToString();
      }
      // add categories
      Object[] arProfileSectionIDs = _ptProfilePage.GetChildSections();
      int cnt = arProfileSectionIDs.Length;
      Object[][] oRows = new Object[cnt][];
      for (int j2c_index = 0;j2c_index < cnt;j2c_index++)
      {
        oRows[j2c_index] = new Object[EXPLIST_COL_MAX];
      }
      IPTObjectManager profileSectionMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();
      /* create the select object for each category */
      for (int i = 0;i < cnt;i++)
      {
        int nSectionID = XPConvert.ToInteger(arProfileSectionIDs[i]);
        IPTProfileSection ptProfileSection = (IPTProfileSection) profileSectionMgr.Open(nSectionID,
         false);
        oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = m_nNextIndex;
        m_nNextIndex++;
        oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_PROFILESECTION_ID;
        oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = ptProfileSection.GetObjectID();
        oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] = ptProfileSection.GetLocalizedName();
        oRows[i][EXPLIST_COL_PROFILESECTION] = ptProfileSection;
        /* initialize this category's model */
        StartCtgSelectPTObject(ptProfileSection, i + 1);
      }
      SetDefaultObjects(oRows);
    }
    
    /// <param name="_ptProfileSection"></param>
    /// <param name="_id"></param>
    public virtual void StartCtgSelectPTObject(IPTProfileSection _ptProfileSection,
     int _id)
    {
      /* key to id this category */
      String strProfileSectionKey = EODPortletPrefsModel.GetProfileSectionKey(_ptProfileSection.GetObjectID());
      /* initialize list for each category */
      EODPortletPrefsSelectPTObjectModel profileSectionModel = (EODPortletPrefsSelectPTObjectModel) m_asOwner.GetModel(strProfileSectionKey);
      profileSectionModel.InitializeSelectPTObject(XPHttpUtility.HtmlEncode(_ptProfileSection.GetLocalizedName()),
       m_asOwner.GetString(990, "ptmsgs_portaladminmsgs"), PTImageType.ICON_PROPERTY,
       m_asOwner.GetString(989, "ptmsgs_portaladminmsgs"), new int[]{PT_CLASSIDS.PT_PROPERTY_ID},
       _id);
      /* set the title and subtitle on the add properties pop-up tree */
      profileSectionModel.SetTreeTitle(m_asOwner.GetString(2446, "ptmsgs_portaladminmsgs"));
      profileSectionModel.SetTreeSubTitle(m_asOwner.GetString(990, "ptmsgs_portaladminmsgs"));
      // remove properties that are no longer in global user props map */
      Object[] arPropertyIDs = _ptProfileSection.GetChildProperties();
      int cntProp = arPropertyIDs.Length;
      XPArrayList xpalPropsToKeep = new XPArrayList();
      for (int iPos = 0;iPos < cntProp;iPos++)
      {
        if (m_listOfGlobalUserProps.Contains(arPropertyIDs[iPos]))
        {
          xpalPropsToKeep.Add(arPropertyIDs[iPos]);
        }
      }
      _ptProfileSection.SetChildProperties(xpalPropsToKeep.ToArray());
      cntProp = xpalPropsToKeep.GetSize();
      // add properties.
      Object[][] oRows = new Object[cntProp][];
      for (int j2c_index = 0;j2c_index < cntProp;j2c_index++)
      {
        oRows[j2c_index] = new Object[EODPortletPrefsSelectPTObjectModel.EXPLIST_COL_MAX];
        }
      IPTObjectManager propertyMgr = ((IPTSession) m_asOwner.GetUserSession()).GetProperties();
      for (int iPos = 0;iPos < cntProp;iPos++)
      {
        /* prepare next index */
        oRows[iPos][EODPortletPrefsSelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = profileSectionModel.m_nNextIndex;
        profileSectionModel.m_nNextIndex++;
        /* get prop info */
        IPTProperty property = (IPTProperty) propertyMgr.Open(XPConvert.ToInteger(xpalPropsToKeep.GetElement(iPos)),
         false);
        String name = property.GetLocalizedName();
        /* add prop to select object default display array */
        oRows[iPos][EODPortletPrefsSelectPTObjectModel.EXPLIST_COL_CLASSID] = PT_CLASSIDS.PT_PROPERTY_ID;
        oRows[iPos][EODPortletPrefsSelectPTObjectModel.EXPLIST_COL_OBJECTID] = property.GetObjectID();
        oRows[iPos][EODPortletPrefsSelectPTObjectModel.EXPLIST_COL_STRING] = name;
        }
      profileSectionModel.SetDefaultObjects(oRows);
      /* limit the properties to display to the ones from the global
       * object properties map
       */
       
      profileSectionModel.SetDisplayObjects(m_propsDisplayString);
      /* set the explanatory text on model */
      if (_ptProfileSection.GetDescription().Equals(""))
      {
        profileSectionModel.SetTableInstructions(m_asOwner.GetString(2153,
         "ptmsgs_portaladminmsgs"));
      } else
      {
        profileSectionModel.SetTableInstructions(XPHttpUtility.HtmlEncode(_ptProfileSection.GetDescription()));
        }
      // set message and instructions to display when the list is empty.
      profileSectionModel.SetEmptyListMessages(m_asOwner.GetString(991, "ptmsgs_portaladminmsgs"),
       m_asOwner.GetString(992, "ptmsgs_portaladminmsgs"));
      // mel: Workaround for 47674: The CheckEmptyList javascript functions called from validatePage were overridden
      // to display an alert popup when a category has no properties or when there are no categories.
      // However, the UI produces an error on Finish, so these checks were a "nice to have" feature.
      // Unfortunately, when you delete a user profile section, the CheckEmptyListN() for that section
      // is no longer in the javascript of the page, even though its called from validatePage.
      // This results in a javascript error.
      // The workaround is to disable the javascript validation of category and property lists.
      //
      // add JavaScript validation to make sure the list has at least one row.
      //		String sMsg = m_asOwner.GetString(1675, "ptmsgs_portaladminmsgs");
      //		String valMsg = XPResourceManager.FormatMessage(sMsg, _ptProfileSection.GetLocalizedName());
      //		String sJSFunctionName = profileSectionModel.SetEnableEmptyListClientValidation(JSHelper.escapeJS(valMsg));
      //		EODPortletPrefsMainDP profileManagerDP = (EODPortletPrefsMainDP) m_asOwner.GetPage(EODPortletPrefsMainDP.STR_MVC_CLASS_NAME);
      //		profileManagerDP.AddToValidationFunction(sJSFunctionName);
      /* move rows up and down */
      profileSectionModel.SetEnableMoveRowActions(true);
    }
  }
}