using System;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs
{
  /// <author>JHQ</author>
  /// <author>
  /// jennifersu
  /// Pop up page lists all sections of a page.  Users can select a section to
  /// rename and the localized names and description dp and model are called.
  /// The DP is initialized by passing in a section object representing a section
  /// in a user profile page.  The MVC name is overwritten via the constructor.
  /// When trying to reference this class, use the name it was registered with.
  /// If attempting to find out if a particular class if of this type, use
  /// instanceof insteand of the MVC string.
  /// </author>
  public class EODPortletPrefsRenameCtgDP : EditorDP
  {
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EODDisplayPrefsRenameCtg";
    
    /// <summary>
    /// html element names 
    /// </summary>
    public const String HTMLINPUT_POPUPSTRING = "in_tx_PopUpString";
    public const String HTMLBUTTON_DONE = "in_bu_done";
    public const String HTMLBUTTON_CANCEL = "in_bu_cancel";
    public const String HIDDEN_CTGNAME = "in_hi_CtgName";
    
    /// <summary>
    /// current page 
    /// </summary>
    private String m_pageTitle;
    
    /// <param name="_strTitle"></param>
    public EODPortletPrefsRenameCtgDP(String _strTitle)
    {
      m_pageTitle = _strTitle;
    }
    
    /// <summary>
    /// This method returns the HTMLScript that encompasses the Javascript on the page.
    /// </summary>
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()"></seealso>
    /// <returns>HTMLScript</returns>
    public virtual HTMLScript GetJavascript()
    {
      return null;
    }
    
    /// <summary>
    /// Returns the String to display on the left navigation menu,
    /// linking to that page.
    /// </summary>
    /// <returns>String</returns>
    public override String GetLeftNavString()
    {
      return m_pageTitle;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()"></seealso>
    public override HTMLElement PageDisplay()
    {
      HTMLElementCollection result = new HTMLElementCollection();
      // Add hidden inputs used for new name
      HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HIDDEN_CTGNAME,
       "");
      result.AddInnerHTMLElement(myInput);
      /* add view's display */
      EODPortletPrefsRenameCtgView view = (EODPortletPrefsRenameCtgView) m_asOwner.GetView(STR_MVC_CLASS_NAME);
      result.AddInnerHTMLElement(view.Display());
      return result;
    }
    
    /// <summary>
    /// Display the Javascripts for the Views.
    /// </summary>
    /// <returns>HTMLScriptCollection</returns>
    /// <throws>HTMLException</throws>
    protected override HTMLScriptCollection DisplayJavaScriptFromChild()
    {
      HTMLScriptCollection myScripts = base.DisplayJavaScriptFromChild();
      EODPortletPrefsRenameCtgView view = (EODPortletPrefsRenameCtgView) m_asOwner.GetView(STR_MVC_CLASS_NAME);
      myScripts.AddInnerHTMLElement(view.DisplayJavascript());
      return myScripts;
    }
  }
}