using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.uiinfrastructure.expandablelist;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs
{
  /// <author>JHQ</author>
  /// <author>
  /// jennifersu
  /// Controls repost actions via the usr profile manager.  It calls the following
  /// repost controls: UsrProfCommRepostControl, UserInfoPropMapAS, and various
  /// ExpListControls for the various sections and categories.
  /// </author>
  public class EODPortletPrefsRepostControl : EditorRepostControl
  {
    
    /// <summary>
    /// object name 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EODDisplayPrefsRepost";
    
    /// <summary>
    /// flags to create new categories 
    /// </summary>
    public const int POSTTOSELF_ACTION_NEWCTG = 72;
    public const int POSTTOSELF_ACTION_NEWCTG_DONE = 73;
    
    /// <summary>
    /// flags to order/delete category 
    /// </summary>
    public const int POSTTOSELF_ACTION_MOVECTG = 74;
    public const int POSTTOSELF_ACTION_MOVECTG_DONE = 75;
    
    /// <summary>
    /// flags to rename profile pages and sections 
    /// </summary>
    public const int POSTTOSELF_ACTION_RENAMECTG = 79;
    public const int POSTTOSELF_ACTION_RENAMECTG_OPEN = 80;
    public const int POSTTOSELF_ACTION_RENAMEOBJ_DONE = 81;
    public const int POSTTOSELF_ACTION_RENAMEOBJ_CANCEL = 82;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EODPortletPrefsRepostControl();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Switch between the action modes and call
    /// the associated method for each action.
    /// </summary>
    /// <param name="_nAction"></param>
    protected override void PerformAction(int _nAction)
    {
      // this will do performaction on the user profile community objects 
      base.PerformAction(_nAction);
      // the rest here does perform action on profile page objects
      IDisplayPage page;
      // do action specific stuff
      switch (_nAction){
      case POSTTOSELF_ACTION_NEWCTG:
      case POSTTOSELF_ACTION_MOVECTG:
      case POSTTOSELF_ACTION_RENAMECTG:
      break;
      case POSTTOSELF_ACTION_NEWCTG_DONE:
      ((EODPortletPrefsModel) m_model).ActionOnRepost_NewCtg(m_htFormData);
      break;
      case POSTTOSELF_ACTION_RENAMECTG_OPEN:
      ((EODPortletPrefsModel) m_model).ActionOnRepost_RenameCtg(m_htFormData);
      break;
      case POSTTOSELF_ACTION_RENAMEOBJ_DONE:
      ((EODPortletPrefsModel) m_model).ActionOnRepost_RenameObjDone(m_htFormData);
      m_rRedirect = new Redirect();
      m_rRedirect.SetLinkGetCachedSpace(m_asOwner);
      m_rRedirect.SetDisplayPage(EODPortletPrefsRenameCtgDP.STR_MVC_CLASS_NAME);
      m_rRedirect.SetControl(EODPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
      break;
      case POSTTOSELF_ACTION_RENAMEOBJ_CANCEL:
      m_rRedirect = new Redirect();
      m_rRedirect.SetLinkGetCachedSpace(m_asOwner);
      m_rRedirect.SetDisplayPage(EODPortletPrefsRenameCtgDP.STR_MVC_CLASS_NAME);
      break;
      // do page specific stuff
      default:
      page = m_asOwner.GetCurrentPage();
      // mel: Partial fix for 45756, added else if instead of just if.
      // When deleting user profile categories, the code below (main page sections)
      // was causing a second delete of the same category and this wiped out the properties
      // in the remaining categories.
      // By using else if, we hit only one of these PerformRepostAction sections.
      if (page.GetName().Equals(EODPortletPrefsMoveCtgDP.STR_MVC_CLASS_NAME))
      {
        /* repost for popups */
        ((ExpListControl) m_asOwner.GetControl(EODPortletPrefsEditorAS.strStorageProfileSectionList)).PerformRepostAction(_nAction,
         m_htFormData);
      } else
      if (page.GetName().Equals(EODPortletPrefsLocNamesDP.STR_MVC_CLASS_NAME) || page.GetName().Equals(LocNamesPopUpDP.STR_MVC_CLASS_NAME))
      {
        /* repost for localization names */
        ((ExpListControl) m_asOwner.GetControl(LocNamesRepostControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
         m_htFormData);
      } else
      //if (page instanceof EODPortletPrefsMainDP)
      {
        /* main page sections repost */
        PTGrowableSortedArrayWrapper arProfileSections;
        arProfileSections = ((EODPortletPrefsProfileSectionListModel) m_asOwner.GetModel(EODPortletPrefsEditorAS.strStorageProfileSectionList)).GetItems();
        for (int indSection = 0;indSection < arProfileSections.GetCount();
        indSection++)
        {
          int nSectionID = XPConvert.ToInteger(arProfileSections.GetItem(indSection,
           EODPortletPrefsProfileSectionListModel.EXPLIST_COL_OBJECTID));
          String strProfileSectionKey = EODPortletPrefsModel.GetProfileSectionKey(nSectionID);
          ((ExpListControl) m_asOwner.GetControl(strProfileSectionKey)).PerformRepostAction(_nAction,
           m_htFormData);
        }
      }
      break;
      }
    }
  }
}