using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.expandablelist.selectptobject;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.arraywrapper;
using com.plumtree.uiinfrastructure.errordisplay;
using com.plumtree.uiinfrastructure.form;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs
{
  /// <summary>
  /// SelectPTObjectModel for selecting Properties to be part of the Category.
  /// </summary>
  /// <author>jennifersu</author>
  public class EODPortletPrefsSelectPTObjectModel : SelectPTObjectModel,ISelectPTObjectModelRO
  {
    
    /// <summary>
    /// Class name for the activity space 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "EODDisplayPrefsSelectPTObject";
    private XPArrayList m_propMapList;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public override Object Create()
    {
      return new EODPortletPrefsSelectPTObjectModel();
    }
    
    /// <summary>
    /// Returns the Class name.
    /// </summary>
    /// <returns>String</returns>
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <summary>
    /// Saves the data on the row _nRowIndex.
    /// </summary>
    /// <param name="_saData">List to update the data on row _nRowIndex</param>
    /// <param name="_nRowIndex">Index of the row to save.</param>
    /// <param name="_htFormData">Data posted by the form.</param>
    /// <returns>int Status for server side validation.</returns>
    protected override int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
     XPHashtable _htFormData)
    {
      Object addedID = _saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
      if (m_propMapList.Contains(addedID))
      {
        return RepostControl.PAGE_STATUS_VALID;
      } else
      {
        // raise error to display to user
        String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(579,
         "ptmsgs_portalbrowsingmsgs"));
        UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,
         strErrorMsg, strErrorMsg);
        UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
        return RepostControl.PAGE_STATUS_INVALID;
      }
    }
    
    /// <summary>
    /// Initializes the expandable list.
    /// </summary>
    /// <param name="_sSectionTitle">Main title.</param>
    /// <param name="_sSectionSubTitle">Sub title</param>
    /// <param name="_imgAddIcon">Icon for the add action.</param>
    /// <param name="_sAddLabel">Text to display next to the add icon.</param>
    /// <param name="_arrObjectClassIDs">Class ID of the Objects displayed on the list.</param>
    /// <param name="_nListKey">
    /// In case you have multiple Expandable Lists on
    /// the same DP, they should have a different key (otherwise, just set it to 1).
    /// </param>
    public override void InitializeSelectPTObject(String _sSectionTitle, String _sSectionSubTitle,
     PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs,
     int _nListKey)
    {
      base.InitializeSelectPTObject(_sSectionTitle, _sSectionSubTitle, _imgAddIcon,
       _sAddLabel, _arrObjectClassIDs, _nListKey);
      // load all properties that are mapped to users into an array so we can easily
      // check against it later.
      IPTObjectPropertyMap propMap = (IPTObjectPropertyMap) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP,
       false);
      IPTQueryResult results = propMap.QueryClassPropertyMappings(PT_CLASSIDS.PT_USER_ID,
       PT_PROPIDS.PT_PROPID_OBJECTID);
      m_propMapList = new XPArrayList();
      int nCount = results.RowCount();
      for (int i = 0;i < nCount;i++)
      {
        int propID = results.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
        m_propMapList.Add(propID);
      }
    }
    
    /// <summary>
    /// Return an error message for row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <param name="strMessage">Message</param>
    /// <returns>Error message for row</returns>
    protected virtual String GetRowErrorMessage(int _nRowIndex, String strMessage)
    {
      XPStringBuilder sb = new XPStringBuilder(100);
      String strPropertyName = GetRowName(_nRowIndex);
      sb.Append(strPropertyName).Append(": ");
      sb.Append(strMessage);
      return sb.ToString();
    }
    
    /// <summary>
    /// Returns the name of the property in the indicated row
    /// </summary>
    /// <param name="_nRowIndex">Row index</param>
    /// <returns>Name of property</returns>
    public virtual String GetRowName(int _nRowIndex)
    {
      return (String) m_saData.GetItem(_nRowIndex, SelectPTObjectModel.EXPLIST_COL_STRING);
      }
  }
}