using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.intrinsicportlets;
using com.plumtree.server;
namespace com.plumtree.portalpages.portlets.userprofile.folders
{
  /// <author>jennifersu</author>
  public class FoldersPortletModel : IntrinsicPortletModel,IFoldersPortletModelRO
  {
    
    /// <summary>
    /// Class name for the model 
    /// </summary>
    public const String STR_MVC_CLASS_NAME = "ExpertFoldersPortlet";
    public const int NO_PROFILE_USER = 0;
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#ControlExists()
     */
     
    public override bool ControlExists()
    {
      return false;
    }
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#GetName()
     */
     
    public override String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#Create()
     */
     
    public override Object Create()
    {
      return new FoldersPortletModel();
    }
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#GetNewTempData()
     */
     
    public override Object GetNewTempData()
    {
      return null;
    }
    
    /// <summary>
    /// This method determines what roles the user is a member of and obtains
    /// the approriate text to be displayed in the introspective portlet.
    /// </summary>
    /// <param name="searchResponse">the search results for the user</param>
    /// <param name="index">the current index in the search results</param>
    /// <param name="iCurrentUser">the current user id</param>
    /// <returns>String the display string for the cell</returns>
    public virtual String GetUserRoles(IPTSearchResponse searchResponse, int index,
     int iCurrentUser)
    {
      String expertrole = searchResponse.GetFieldsAsString(index, PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS);
      String conmanagerrole = searchResponse.GetFieldsAsString(index, PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS);
      bool bisExpert = false;
      bool bisConManager = false;
      // check to see if the user belongs to the expert role
      if (belongsToRole(expertrole, iCurrentUser))
      {
        bisExpert = true;
      }
      // check to see if the user belongs to the content manager role
      if (belongsToRole(conmanagerrole, iCurrentUser))
      {
        bisConManager = true;
      }
      // return the appropriate string
      if (bisExpert && bisConManager)
      {
        return m_asOwner.GetString(19, "ptmsgs_portletsmsgs");
      } else
      if (bisExpert)
      {
        return m_asOwner.GetString(15, "ptmsgs_portletsmsgs");
      } else
      if (bisConManager)
      {
        return m_asOwner.GetString(14, "ptmsgs_portletsmsgs");
      }
      return "";
    }
    
    /// <summary>
    /// This method uses the Plumtree search API and searches all folders that a
    /// user is a expert or content manager of.
    /// </summary>
    /// <param name="ptSession">a valid plumtree session</param>
    /// <param name="profileUserID">
    /// the profile user id that will be used to search
    /// information on.
    /// </param>
    /// <returns>IPTSearchResponse</returns>
    public virtual IPTSearchResponse GetSearchResults(int profileUserID)
    {
      IPTSearchRequest searchRequest;
      IPTFilter ptFilter;
      searchRequest = m_ptSession.GetSearchRequest();
      // Restrict the search to our top level test folders
      searchRequest.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
       new int[]{PT_CLASSIDS.PT_CATALOGFOLDER_ID});
      // make sure the expert and content manager information is returned.
      searchRequest.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS,
       new int[]{PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS, PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS});
      ptFilter = PortalObjectsFactory.CreateSearchFilter();
      IPTPropertyFilterClauses ptClause = (IPTPropertyFilterClauses) ptFilter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
      ptClause.SetOperator(PT_BOOLOPS.PT_BOOLOP_OR);
      // check for expert
      addStatement(ptFilter, ptClause, PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS,
       PT_FILTEROPS.PT_FILTEROP_CONTAINS, profileUserID);
      // check for community manager
      addStatement(ptFilter, ptClause, PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS,
       PT_FILTEROPS.PT_FILTEROP_CONTAINS, profileUserID);
      ptFilter.SetPropertyFilter(ptClause);
      IPTSearchQuery query = searchRequest.CreateAdvancedQuery(ptFilter);
      return searchRequest.Search(query);
    }
    
    /// <summary>
    /// Helper function to add a statement to a filter. The filter API is
    /// somewhat confusing. A filter holds a clause, which can in turn hold a
    /// number of statements. This method creates a statement equivalent to
    /// "propID opID value" and adds it to the clause. We presume that the
    /// caller has created the clause using the filter.
    /// </summary>
    /// <param name="ptFilter"></param>
    /// <param name="ptClause"></param>
    /// <param name="propID">
    /// Integer id of a property, e.g. 101 corresponds to the
    /// "Keywords" property. These numbers are object ids in the
    /// PTPROPERTIES database table.
    /// </param>
    /// <param name="opID">
    /// Integer id of an operator, e.g. PT_FILTEROPS.
    /// PT_FILTEROP_CONTAINS
    /// </param>
    /// <param name="value">String value to use for the search.</param>
    private void addStatement(IPTFilter ptFilter, IPTPropertyFilterClauses ptClause,
     int propID, int opID, int value)
    {
      IPTPropertyFilterStatement ptStatement = (IPTPropertyFilterStatement) ptFilter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
      ptStatement.SetOperand(propID);
      ptStatement.SetOperator(opID);
      ptStatement.SetValue(value);
      int count = ptClause.GetCount();
      ptClause.AddItem(ptStatement, count);
    }
    
    /// <summary>
    /// checks to see if the user is in a particular role (expert or content
    /// manager).  The way the EOD role data is indexed in Plumtree is by a
    /// space delimited string of all the userids. This method loops through to
    /// determine if this user exists in the string.
    /// </summary>
    /// <param name="sData">The data being inspected</param>
    /// <param name="sUserid">the user id to be checked</param>
    /// <returns>boolean</returns>
    private bool belongsToRole(String sData, int sUserid)
    {
      if (null != sData)
      {
        XPStringTokenizer stRole = new XPStringTokenizer(sData, " ");
        String sKey;
        while (stRole.HasMoreElements())
        {
          sKey = (String) stRole.GetNextElement();
          if (XPConvert.ToInteger(sKey) == sUserid)
          {
            return true;
          }
        }
      }
      return false;
    }
    
    /// <returns></returns>
    public virtual int GetProfileID()
    {
      IPTUserInfo userInfo = m_ptSession.GetUserInfo();
      return userInfo.GetProfileUserID();
    }
    
    /// <returns></returns>
    public virtual int GetCurrentUser()
    {
      IPTSessionInfo sessionInfo = m_ptSession.GetSessionInfo();
      return sessionInfo.GetCurrentUserID();
    }
    
    /// <seealso cref="com.plumtree.xpportlets.expatriate.ext.introspective.IProfilePortlet#getTitle()"></seealso>
    public virtual String GetTitle()
    {
      return "";
    }
    public virtual String GetPortletDescription()
    {
      return m_ptPortlet.GetDescription();
    }
  }
}