using System;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.opener;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.infrastructure
{
  /// <author>
  /// dand This is a helper class designed to help draw some common
  /// elements for portlets
  /// </author>
  public class HTMLHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
     "com.plumtree.portalpages.portlets.userprofile.infrastructure.HTMLHelper");
    protected const String PTOPENERLINK_START = "<pt:openerLink xmlns:pt=\'http://www.plumtree.com/xmlschemas/ptui/\'";
    protected const String PTOPENERLINK_END = "</pt:openerLink>";
    protected const String OBJECTID_TAG = " pt:objectID=";
    protected const String CLASSID_TAG = " pt:classID=";
    protected const String MODE_TAG = " pt:mode=\'2\'";
    protected const String SINGLEQUOTE = "\'";
    
    /// <summary>
    /// string for a blank URL 
    /// </summary>
    public const String BLANK_URL = "#";
    
    /// <summary>
    /// This method will return a standard introspective portlet cell based on a
    /// Plumtree ASQueryResultWrapper object.  It should get the name,
    /// description, and create a common opener java script function based on
    /// the object class id and object id.
    /// </summary>
    /// <param name="searchResponse">THe search result object containing all the data</param>
    /// <param name="index">the index row of the search result</param>
    /// <param name="Classid"></param>
    /// <returns>ProfileCell  a introspective ProfileCell that will be displayed</returns>
    /// <throws>HTMLException </throws>
    public static ProfileCell CreateProfileRowFromPTResults(AActivitySpace aspace,
     IPTQueryResult searchResponse, int index, int Classid)
    {
      String sName;
      int Objectid;
      String sDescr;
      // create the text cell based on fodler name and description
      sName = searchResponse.ItemAsString(index, PT_PROPIDS.PT_PROPID_NAME);
      sDescr = searchResponse.ItemAsString(index, PT_PROPIDS.PT_PROPID_DESCRIPTION);
      // create the ptopener link using pt opener tag - previously it was using the common opener
      // function but this seems to be better especially for 508. 
      // get the object and class ids
      Objectid = searchResponse.ItemAsInt(index, PT_PROPIDS.PT_PROPID_OBJECTID);
      HTMLAnchor openerLink = HTMLHelper.GetObjectOpenerTag(aspace, sName,
       Classid, Objectid);
      logData(sName, sDescr, Classid, Objectid);
      return new ProfileCell(sName, sDescr, sName, openerLink, false);
    }
    
    /// <summary>
    /// This method will return a standard introspective portlet cell based on a
    /// Plumtree IPTSearchResponse object.  It should get the name,
    /// description, and create a common opener java script function based on
    /// the object class id and object id.
    /// </summary>
    /// <param name="searchResponse">THe search result object containing all the data</param>
    /// <param name="index">the index row of the search result</param>
    /// <returns>ProfileCell  a introspective ProfileCell that will be displayed</returns>
    /// <throws>HTMLException </throws>
    public static ProfileCell CreateProfileRowFromPTResults(AActivitySpace aspace,
     IPTSearchResponse searchResponse, int index)
    {
      String sName;
      int Classid;
      int Objectid;
      String sDescr;
      // create the text cell based on fodler name and description
      sName = searchResponse.GetFieldsAsString(index, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
      sDescr = searchResponse.GetFieldsAsString(index, PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY);
      // create the ptopener link using pt opener tag - previously it was using the common opener
      // function but this seems to be better especially for 508.
      // get the object and class ids
      Classid = searchResponse.GetFieldsAsInt(index, PT_INTRINSICS.PT_PROPERTY_CLASSID);
      Objectid = searchResponse.GetFieldsAsInt(index, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
      HTMLAnchor openerLink = HTMLHelper.GetObjectOpenerTag(aspace, sName,
       Classid, Objectid);
      logData(sName, sDescr, Classid, Objectid);
      return new ProfileCell(sName, sDescr, sName, openerLink, false);
    }
    
    /// <summary>
    /// Returns the header for the Section.
    /// </summary>
    /// <param name="_sHeaderTitle">Title you want to display in the header.</param>
    /// <returns>HTMLTable</returns>
    public static HTMLElement GetHeaderView(String _sHeaderTitle)
    {
      PTConstruct myViewBanner = null;
      try
      {
        // JF- Get the construct for the Section banner
        myViewBanner = ConstructFactory.GetConstruct(PTBannerType.OBJECT);
        myViewBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.TITLE_ELEMENT_NAME,
         _sHeaderTitle);
        myViewBanner.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.SUBTITLE_ELEMENT_NAME,
         "");
      }
      catch (Exception e)
      {
        log.Error(e, "EditorView::GetHeaderView The following error occured when trying to display the HTML: " + e.Message);
        }
      // DRD - not going to throw an exception
      return myViewBanner.GetHTMLElement();
    }
    
    /// <summary>
    /// Returns a pttag that sould create an appropriate URL to open a plumtree
    /// object
    /// </summary>
    /// <param name="name"></param>
    /// <param name="classid">the classid of the plumtree object</param>
    /// <param name="objectid">the Plumtree object id</param>
    /// <returns>the javascript function that opens a common plumtree object</returns>
    /// <throws>HTMLException </throws>
    public static HTMLAnchor GetObjectOpenerTag(AActivitySpace aspace, String name,
     int classid, int objectid)
    {
      String strURL = PTOpenerLinks.GetOpenerURLOpenObjID(classid, objectid,
       IPTOpenerConstants.OPENER_MODE_VIEW, aspace);
      HTMLAnchor openerLink = new HTMLAnchor(strURL);
      return openerLink;
    }
    
    /// <summary>
    /// Returns a short empty table. This is the one you should use in your
    /// Section, just below the Section header (the one returned by GetHeaderView)
    /// </summary>
    /// <returns>HTMLTable</returns>
    public static HTMLTable GetShortSpacerTable()
    {
      HTMLTable mySpacerTable = new HTMLTable();
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLImg myImage;
      PTConstruct myConstruct;
      try
      {
        mySpacerTable.SetWidth("100%");
        mySpacerTable.SetBorder("0");
        mySpacerTable.SetCellPadding("0");
        mySpacerTable.SetCellSpacing("0");
        // 1st Row begin
        myRow = new HTMLTableRow();
        mySpacerTable.AddInnerHTMLElement(myRow);
        // Empty Cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myConstruct = ConstructFactory.GetConstruct(PTImageType.SPACER);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetWidth("1");
        myImage.SetHeight("5");
        myImage.SetBorder("0");
        myCell.AddInnerHTMLElement(myImage);
      }
      catch (Exception e)
      {
        log.Error(e, "EditorView::GetShortSpacerTable The following error occured when trying to display the HTML: " + e.Message);
        }
      // JF- no need to throw an exception, this is not critical.
      return mySpacerTable;
    }
    
    /// <summary>
    /// Returns an empty table. This is the one used to separate each section in
    /// any Editor page. Note that this is a static method so you can also call
    /// it from any DP.
    /// </summary>
    /// <returns>HTMLTable</returns>
    public static HTMLTable GetSpacerTable()
    {
      HTMLTable mySpacerTable = new HTMLTable();
      HTMLTableRow myRow;
      HTMLTableCell myCell;
      HTMLImg myImage;
      PTConstruct myConstruct;
      try
      {
        mySpacerTable.SetWidth("100%");
        mySpacerTable.SetBorder("0");
        mySpacerTable.SetCellPadding("0");
        mySpacerTable.SetCellSpacing("0");
        // 1st Row begin
        myRow = new HTMLTableRow();
        mySpacerTable.AddInnerHTMLElement(myRow);
        // Empty Cell
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        myConstruct = ConstructFactory.GetConstruct(PTImageType.SPACER);
        myImage = (HTMLImg) myConstruct.GetHTMLElement();
        myImage.SetAlt("");
        myImage.SetWidth("1");
        myImage.SetHeight("15");
        myImage.SetBorder("0");
        myCell.AddInnerHTMLElement(myImage);
      }
      catch (Exception e)
      {
        log.Error(e, "EditorView::GetSpacerTable The following error occured when trying to display the HTML: " + e.Message);
        }
      // JF- no need to throw an exception, this is not critical.
      return mySpacerTable;
    }
    
    /// <summary>
    /// Log the data from the search response
    /// </summary>
    /// <param name="Name"></param>
    /// <param name="Descr"></param>
    /// <param name="Classid"></param>
    /// <param name="Objectid"></param>
    private static void logData(String Name, String Descr, int Classid, int Objectid)
    {
      if (log.IsDebugEnabled())
      {
        log.Debug("Name: " + Name + " Description: " + Descr + " Class Id: " + Classid + " Object Id: " + Objectid);
        }
    }
  }
}