using System;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.portalpages.portlets.userprofile.infrastructure
{
  /// <author>chrisb</author>
  public interface IProfileCell
  {
    
    /// <summary>
    /// Tells the caller whether or not this ProfileCell contains  HTML. If it
    /// has markup, the caller will not encode it so that  the markup gets
    /// interpreted. If it returns false, you're telling the caller that you
    /// want to HTMLEncode the text.
    /// </summary>
    /// <returns>Whether or not this ProfileCell contains HTML.</returns>
    bool isHTML();
    
    /// <summary>
    /// Tells the caller if the cell that is being displayed is an image.  If
    /// the cell is an image it is displayed differently in the TablePage.
    /// </summary>
    /// <returns>boolean</returns>
    bool isImg();
    
    /// <summary>
    /// Returns an HTMLAnchor element if the Profile Cell is using a click
    /// through URI and/or an onclick action.
    /// </summary>
    /// <returns>HTMLAnchor the anchor element that is used for the cell.</returns>
    HTMLAnchor GetHTMLAnchor();
    
    /// <summary>
    /// If there is an image set on the Profile Cell it will return the image
    /// object
    /// </summary>
    /// <returns>HTMLImg</returns>
    HTMLImg GetImage();
    
    /// <summary>
    /// Returns a description of the ProfileCell that will be shown as
    /// mouse-over (pop-up) text. This method is optional. If you  don't want
    /// to have a mouse-over, implement this method to return  an empty string.
    /// </summary>
    /// <returns>A description of the ProfileCell to be shown as a mouse-over.</returns>
    String GetMouseOver();
    
    /// <summary>
    /// Returns the sub text that will be displayed below the text of the cell.
    /// This sub text will not be associated with the click through URI.
    /// </summary>
    /// <returns>boolean</returns>
    String GetSubText();
    
    /// <summary>
    /// Returns the text to go in the ProfileCell. This method must return a
    /// value.
    /// </summary>
    /// <returns>The text to display in the ProfileCell.</returns>
    String GetText();
  }
}