using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.portlets.userprofile.infrastructure
{
  /// <summary>
  /// Represents a row in the ProfileTable. Each ProfileRow object contains an
  /// arbitrary number of ProfileCell objects. To preserve the integrity of the
  /// ProfileTable, all the ProfileRow objects should have the same number of
  /// ProfileCell objects in them.
  /// </summary>
  /// <author>chrisb</author>
  public interface IProfileRow
  {
    
    /// <summary>
    /// Returns the number of ProfileCell objects in the ProfileRow.
    /// </summary>
    /// <returns>The number of ProfileCell objects in the ProfileRow.</returns>
    int GetNumProfileCells();
    
    /// <summary>
    /// Returns an XPEnumerator containing the ProfileCell objects that belong
    /// in this row.
    /// </summary>
    /// <returns>
    /// An XPEnumerator containing the ProfileCell objects in this
    /// ProfileRow.
    /// </returns>
    IXPEnumerator GetProfileCells();
  }
}