using System;
using com.plumtree.openfoundation.util;
namespace com.plumtree.portalpages.portlets.userprofile.infrastructure
{
  /// <summary>
  /// Describes the methods required to be an Introspective User Profile  Portlet.
  /// Examples of these portlets may include "Documents Submitted," "Folders
  /// Created," "Gadgets Created," etc.
  /// </summary>
  /// <author>chrisb</author>
  public interface IProfileTable
  {
    
    /// <summary>
    /// Returns the portlet's description.
    /// </summary>
    /// <returns>The portlet's description.</returns>
    String GetDescription();
    
    /// <summary>
    /// Optionally returns a "header" row. This row will be formatted like a
    /// header for your ProfileTable. If you don't want to have a ProfileRow
    /// that looks like a header, return null.
    /// </summary>
    /// <returns>
    /// A ProfileRow object to represent the header row of the
    /// ProfileTable or null if you don't want a header row.
    /// </returns>
    IProfileRow GetHeaderRow();
    
    /// <summary>
    /// Returns the number of ProfileRow objects in the ProfileTable.
    /// </summary>
    /// <returns>The number of ProfileRow objects in the ProfileTable.</returns>
    int GetNumProfileRows();
    
    /// <summary>
    /// Returns the ProfileItem objects corresponding to the profile  username.
    /// Each ProfileItem represents one row of content  (e.g. the name and
    /// description of a folder or document created  by the profile user).
    /// </summary>
    /// <param name="profileUserID">
    /// The ID of the user who's profile is currently being
    /// viewed.
    /// </param>
    /// <param name="profileLogOnToken">
    /// The log on token of the user that is being
    /// viewed. This is used to search on Plumtree specific information
    /// </param>
    /// <param name="viewingUserID">
    /// The ID of the user who is currently viewing the
    /// profile.
    /// </param>
    /// <returns>An XPEnumerator of ProfileItem objects.</returns>
    IXPEnumerator GetProfileRows(int profileUserID, String profileLogOnToken,
     int viewingUserID);
    
    /// <summary>
    /// Returns the portlet's title.
    /// </summary>
    /// <returns>The Portlet's title.</returns>
    String GetTitle();
    
    /// <summary>
    /// Indicates whether the source content has been updated since the supplied
    /// date. This method enables the UI to cache the content until it changes.
    /// To turn off caching, implement this method always to return true. To
    /// use caching, implement this method as a fast way to tell if the content
    /// you're supplying has changed since the date passed into this method.
    /// </summary>
    /// <param name="lastUpdatedDate">
    /// Indicates the date/time at which the content was
    /// last updated.
    /// </param>
    /// <returns>true if the content has been updated; false otherwise.</returns>
    bool hasBeenUpdatedSince(XPDateTime lastUpdatedDate);
  }
}