using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.rest
{
  /// <summary>
  /// This class manages all the REST errors to provide easy lookup and make sure
  /// that there aren't any conflicts.
  /// </summary>
  public class RESTErrors
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
     "com.plumtree.portalpages.rest.RestErrors");
    
    /// <summary>
    /// This needs to be initialized before any of the specific errors are created.
    /// </summary>
    protected static readonly XPHashtable ERRORS = new XPHashtable();
    
    /// <summary>
    /// Add a REST error to the global map for easy lookup and conflict checking.
    /// </summary>
    /// <param name="_error">the error to add.</param>
    /// <throws>XPIllegalStateException if the code is already in use.</throws>
    public static void AddRestError(IRESTError _error)
    {
      if (ERRORS.GetElement(_error.GetCode()) != null)
      {
        String strError = "Error inserting Rest error " + _error.GetCode() + " into enum. " + "That code already exists for error [" + _error.GetMessage() + "].";
        log.Warn(strError);
        throw new XPIllegalStateException(strError);
      }
      ERRORS.PutElement(_error.GetCode(), _error);
    }
    
    /// <summary>
    /// Lookup a IRestError object from the error code.
    /// </summary>
    /// <param name="_nCode">the error code to lookup</param>
    /// <returns>the matching error object.</returns>
    /// <throws>XPIllegalArgumentException if the error can not be found.</throws>
    public static IRESTError GetError(int _nCode)
    {
      IRESTError error = (IRESTError) ERRORS.GetElement(_nCode);
      if (error == null)
      {
        throw new XPIllegalArgumentException("Error " + _nCode + " does not exist.");
        }
      return error;
    }
  }
}