using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.rest;
using com.plumtree.portalpages.rest.utils;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.rest.dojo
{
  /// <author>rozhang</author>
  public class KDDocumentDataStoreDP : IDisplayPage
  {
    public const String STR_MVC_CLASS_NAME = "KDDocumentDataStore";
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
     "com.plumtree.portalpages.rest.dojo.KDDocumentDataStoreDP");
    protected AActivitySpace m_space;
    protected KDDocumentDataStoreModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display(com.plumtree.uiinfrastructure.activityspace.IWebData)"></seealso>
    public virtual void Display(IWebData webData)
    {
      try
      {
        // This will turn off HTML performance comments, allowing us to output
        // a valid JSON response.  Note that adding comment filtering allows us
        // to add the comments after the comment and Dojo will ignore them.  We
        // should still disable them anyways, in case someone wants to use a
        // library other than Dojo.
        webData.SetIsHTMLText(false);
        // Say that this data is JSON.
        webData.SetHeader(HTTPHeaderConstants.CONTENT_TYPE, "application/json");
        // This currently only supports JSON output
        IRESTError error = m_model.GetError();
        if (error != null)
        {
          // This handles outputting the error to the webdata object.
          new RESTHelper().OutputError(error, webData, false);
        } else
        {
          XPHashtable restObject = m_model.GetQueryStoreResult();
          JSONSerializer json = new JSONSerializer(restObject);
          String jsonResponse = json.GenerateStringRepresentation(true);
          webData.SetStatus(200);
          webData.SetData(jsonResponse);
        }
      }
      catch (Exception e)
      {
        log.Error(e, "Unable to display JSON output in User REST API.");
        // This handles outputting the error to the webdata object.
        new RESTHelper().OutputError(CommonRestErrors.GENERAL, webData, false);
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_space = parent;
      m_model = (KDDocumentDataStoreModel) m_space.GetModel(KDDocumentDataStoreModel.STR_MVC_CLASS_NAME);
      if (m_model == null)
      {
        throw new XPIllegalStateException("Required model:" + KDDocumentDataStoreModel.STR_MVC_CLASS_NAME + " not found in Activityspace: " + parent.GetName());
        }
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()"></seealso>
    public virtual AActivitySpace GetOwner()
    {
      return m_space;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
  }
}