using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.server.impl.search;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.rest.dojo
{
  /// <summary>
  /// Model to retrieve KD documents in a specific KD folder
  /// </summary>
  /// <author>rozhang</author>
  public class KDDocumentDataStoreModel : AQueryStoreModel,IModel
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
     "com.plumtree.portalpages.rest.dojo.KDDocumentDataStoreModel");
    public const String STR_MVC_CLASS_NAME = "KDDocumentDataStore";
    
    /// <summary>
    /// KD document specific property names *
    /// </summary>
    public static readonly String COL_DOCUMENTPATH = COLNAME_PREFIX + PT_INTRINSICS.PT_PROPERTY_FOLDERPATH;
    public static readonly String COL_ICON = COLNAME_PREFIX + PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID;
    public static readonly String COL_DOCUMENTURL = COLNAME_PREFIX + PT_INTRINSICS.PT_PROPERTY_DOCUMENTURL;
    // @TODO what is the constant for this?
    public static readonly String COL_AUTHOR = COLNAME_PREFIX + "103";
    
    /// <summary>
    /// folder id to return empty response (default behavior) *
    /// </summary>
    public const int NOFOLDER_EMPTYRESPONSE = 0;
    
    /// <summary>
    /// folder id to return error  *
    /// </summary>
    public const int INVALIDFOLDER_ERROR = -1;
    protected AActivitySpace m_space = null;
    
    /// <summary>
    /// Document folder to retrieve documents from *
    /// </summary>
    private int m_currFolderId = NOFOLDER_EMPTYRESPONSE;
    private int[] m_queryPropIds = new int[]{};
    // SHORT format as default
    private int m_dateFormat = 3;
    // SHORT format as default
    private int m_timeFormat = 3;
    // default locale
    private XPLocale m_locale = XPLocale.GetDefault();
    private XPTimeZone m_timeZone = null;
    static KDDocumentDataStoreModel()
    {
      AddColNameToSearchPropIdMapping(COL_DOCUMENTPATH, PT_INTRINSICS.PT_PROPERTY_FOLDERPATH);
      AddColNameToSearchPropIdMapping(COL_ICON, PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID);
      AddColNameToSearchPropIdMapping(COL_DOCUMENTURL, PT_INTRINSICS.PT_PROPERTY_DOCUMENTURL);
      // @TODO what is the constant for this?
      AddColNameToSearchPropIdMapping(COL_AUTHOR, 103);
    }
    
    /// <summary>
    /// Return the result from the current request.
    /// This method is is called
    /// </summary>
    /// <returns></returns>
    public override XPHashtable GetQueryStoreResult()
    {
      String strTZ = (String) TaskAPIUIUser.GetPersonalSettingValue(m_space,
       PersonalSettingNames.TIMEZONE);
      try
      {
        m_timeZone = XPTimeZone.GetTimeZone(strTZ);
      }
      catch (XPException e)
      {
        log.Error(e, "Unable to set timezone for string loaded from preference: " + strTZ);
        m_timeZone = XPTimeZone.GetCurrentTimeZone();
      }
      return GetFolderDocumentDataStoreObject(GetCurrFolderId());
    }
    //return GetSESSearchResults(GetCurrFolderId());
    //	XPHashtable GetSESSearchResults(int dgId)
    //	{
    //		XPHashtable jsonData;
    //		try {
    //			OracleSearchService ctx = new OracleSearchService();
    //			ctx.setSoapURL("http://rozhang01.amer.bea.com:7777/search/query/OracleSearch");
    //			
    //			//getAllGroups(ctx);
    //			
    //			//getAllAttribs(ctx);
    //			
    //			jsonData = doSESSearch(ctx, dgId);
    //			
    //		} catch (Exception e) {
    //			e.printStackTrace();
    //			jsonData = new XPHashtable();
    //		}
    //		return jsonData;
    //		
    //	}
    //	
    //	/**
    //	 * @param ctx
    //	 * @throws Exception
    //	 */
    //	private XPHashtable doSESSearch(OracleSearchService ctx, int dgId) throws Exception
    //	{
    //		//OracleSearchResult result = ctx.doOracleSimpleSearch("cnn", new Integer(1), new Integer(20), Boolean.TRUE, Boolean.TRUE, Boolean.TRUE);
    //		Filter filt = new Filter(new Integer(101), "string", "contains", "folder1");
    //		DataGroup[] dg = new DataGroup[] {new DataGroup(new Integer(dgId), null)};
    //		OracleSearchResult result = 
    //			ctx.doOracleSearch("", new Integer(1), new Integer(20), Boolean.FALSE, Boolean.FALSE, dg,null, null, Boolean.FALSE, "or", null, 
    //					new Integer[] {new Integer(101), new Integer(109), new Integer(112), new Integer(111)});
    //		
    //		int estimatedHitCount = result.getEstimatedHitCount().intValue();
    //		
    //		// Process result
    //		ResultElement[] resElements = result.getResultElements();
    //		XPArrayList hits = new XPArrayList();
    //		
    //		for(int i = 0; i < resElements.length; i++)
    //		{
    //			ResultElement curr = resElements[i];
    //		 	
    //			String mimeType = curr.getMimetype();
    //			String imguid = "";
    //			if ( "text/html".equals(mimeType) ) {
    //				imguid = "{52a5a5a0-84c9-11d2-a0c5-0060979c42d8}";
    //			}
    //			
    //		 	
    //		 	XPHashtable docObject = new XPHashtable();
    //		 	// @TODO check mimetype and use appropriate icon 
    //		 	docObject.PutElement(COL_NAME, CreateGridLabelEntry(imguid, curr.getUrl(), curr.getTitle()) );
    //		 	docObject.PutElement(COL_LASTMODIFIED, FormatPropertyDateString(new XPDateTime(curr.getLastModified())) );
    //		 	docObject.PutElement(COL_OBJECTID, curr.getDocID());
    //		 	docObject.PutElement(COL_DESCRIPTION, curr.getDescription());
    //		 	
    //		 	hits.Add(docObject);
    //		 	// dont need cust attribs since we are already searching on them
    //		 	//CustomAttribute[] cusAtr = curr.getCustomAttributes();
    //		}
    //		
    //		// dojo datstore response object
    //		XPHashtable jsonObj = new XPHashtable();
    //		// set the results and other meta data on the datastore response object
    //		AddDataStoreMetaData(jsonObj, hits, estimatedHitCount);
    //		
    //		return jsonObj;
    //	}
    
    /// <summary>
    /// Performs search request to retrieve documents
    /// </summary>
    /// <param name="folderId"></param>
    /// <returns>
    /// Empty DataStore response object if folderId is NOFOLDER_EMPTYRESPONSE or null if folder id
    /// is INVALIDFOLDER_ERROR
    /// </returns>
    public virtual XPHashtable GetFolderDocumentDataStoreObject(int folderId)
    {
      if (folderId == NOFOLDER_EMPTYRESPONSE)
      {
        XPHashtable emptyData = new XPHashtable();
        AddDataStoreMetaData(emptyData, new XPArrayList(), 0);
        return emptyData;
      }
      if (folderId == INVALIDFOLDER_ERROR)
      {
        return null;
      }
      IPTSession session = (IPTSession) m_space.GetUserSession();
      IPTSearchRequest ptSR = session.GetSearchRequest();
      // gets parameters from parent AQueryStoreModel
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, GetResultSize());
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, GetStartIndex());
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS, new int[]{folderId});
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, GetOrderById());
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS, m_queryPropIds);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
       false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, new int[]{PT_CLASSIDS.PT_CATALOGCARD_ID});
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE, "dirbrowse");
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_USUAL_FIELDS,
       true);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC, true);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, true);
      // perform search query
      IPTSearchQuery ptQuery = ptSR.CreateBasicQuery(GetQuery(), "");
      IPTSearchResponse results = ptSR.Search(ptQuery);
      int totalResultCount = results.GetTotalMatches();
      // list containing dojo datastore entry object representations
      XPArrayList docs = new XPArrayList();
      // iterate over the search result and build a dojo datastore object representation
      // The caller (usually displaypage) will convert it to JSON/other format. 
      // We just return an object representation for datastore response 
      for (int resultIndex = 0;resultIndex < results.GetResultsReturned();
      resultIndex++)
      {
        // object representation of a single datastore object entry
        XPHashtable docObject = new XPHashtable();
        // retrieve the needed data from search result
        int docObjectId = results.GetFieldsAsInt(resultIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
        String docName = results.GetFieldsAsString(resultIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
        String docPath = results.GetFieldsAsString(resultIndex, PT_INTRINSICS.PT_PROPERTY_FOLDERPATH);
        String docIcon = results.GetFieldsAsString(resultIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID);
        // some app servers are case sensitive
        docIcon = XPStringUtility.ToLowerCase(docIcon);
        String docUrl = results.GetFieldsAsString(resultIndex, PT_INTRINSICS.PT_PROPERTY_DOCUMENTURL);
        double searchDocCreated = results.GetFieldsAsDouble(resultIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED);
        double searchDocModified = results.GetFieldsAsDouble(resultIndex,
         PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED);
        String docCreated = FormatPropertyDateString(searchDocCreated);
        String docModified = FormatPropertyDateString(searchDocModified);
        // iterate over the requested property ids in the querystring 
        for (int propIndex = 0;propIndex < m_queryPropIds.Length;propIndex++)
        {
          int propId = m_queryPropIds[propIndex];
          switch (propId){
          case PT_INTRINSICS.PT_PROPERTY_OBJECTID:
          case PT_INTRINSICS.PT_PROPERTY_OBJECTNAME:
          case PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID:
          case PT_INTRINSICS.PT_PROPERTY_DOCUMENTURL:
          case PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED:
          case PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED:
          // don't do anything, these default properties are always 
          // included in the response 
          break;
          default:
          int type = GetPropType(propId, m_space);
          if (type == NO_PROPTYPE)
          {
            type = GetCustomPropType(propId, m_space);
          }
          String propValue;
          // @TODO might want add support for other property types
          if (type == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE)
          {
            XPDateTime dDateProp = results.GetFieldsAsXPDateTime(resultIndex,
             propId);
            propValue = FormatPropertyDateString(dDateProp);
          } else
          // treat all other types like strings
          {
            propValue = results.GetFieldsAsString(resultIndex, propId);
          }
          docObject.PutElement(COLNAME_PREFIX + propId, propValue);
          break;
          }
        }
        // set the default properties
        // json serializer takes care of javascript encoding the strings
        docObject.PutElement(COL_OBJECTID, docObjectId);
        docObject.PutElement(COL_NAME, CreateGridLabelEntry(docIcon, docUrl,
         docName));
        docObject.PutElement(COL_CREATED, docCreated);
        docObject.PutElement(COL_LASTMODIFIED, docModified);
        docObject.PutElement(COL_ICON, docIcon);
        docObject.PutElement(COL_DOCUMENTURL, docUrl);
        //docObject.PutElement("desc", docDesc);
        //            docObject.PutElement(COL_DOCUMENTPATH, docPath);
        docs.Add(docObject);
      }
      // dojo datstore response object
      XPHashtable jsonObj = new XPHashtable();
      // set the results and other meta data on the datastore response object
      AddDataStoreMetaData(jsonObj, docs, totalResultCount);
      return jsonObj;
    }
    
    /// <summary>
    /// Create special entry for first column in the dojo datagrid widget. The label columns
    /// displays the name of the document with an icon and url to the document. Need to pass
    /// in values for all 3 of the properties.
    /// The comma separated string list is parsed by the kdLabelFormatter javascript function
    /// </summary>
    /// <param name="iconUrl"></param>
    /// <param name="docUrl"></param>
    /// <param name="docName"></param>
    /// <returns></returns>
    protected virtual String CreateGridLabelEntry(String iconUrl, String docUrl,
     String docName)
    {
      return iconUrl + "," + docUrl + "," + docName;
    }
    public virtual String FormatPropertyDateString(double dateFromSearch)
    {
      XPDateTime date = PTSearchHelper.ConvertSearchDateTimeToXPDateTime(dateFromSearch);
      return FormatPropertyDateString(date);
    }
    
    /// <TODO>do we need to use the user's locale and not the default locale here?</TODO>
    /// <param name="date"></param>
    /// <returns></returns>
    public virtual String FormatPropertyDateString(XPDateTime date)
    {
      int dateFormat = GetDateFormat();
      int timeFormat = GetTimeFormat();
      if (!(dateFormat == -1 && timeFormat == -1))
      {
        XPDateFormat dateFormatter;
        if (dateFormat == -1)
        {
          dateFormatter = XPDateFormat.GetTimeInstance(timeFormat, GetLocale(),
           m_timeZone);
        } else
        if (timeFormat == -1)
        {
          dateFormatter = XPDateFormat.GetDateInstance(dateFormat, GetLocale(),
           m_timeZone);
        } else
        {
          dateFormatter = XPDateFormat.GetDateTimeInstance(dateFormat, timeFormat,
           GetLocale(), m_timeZone);
        }
        return dateFormatter.Format(date);
      } else
      {
        // neither date nor time wanted, return empty string
        return "";
      }
    }
    public virtual void SetCurrFolderId(int folderId)
    {
      m_currFolderId = folderId;
    }
    public virtual int GetCurrFolderId()
    {
      return m_currFolderId;
    }
    public virtual void SetDateFormat(int dateFormat)
    {
      // The form in prefs.jsp sets the full value as 10 since the value for XPDateFormat.FULL - 0 is interpreted
      // by setprefs.jsp as no change in value. Set it back to 0 here.
      if (dateFormat == 10)
      {
        // 
        dateFormat = XPDateFormat.FULL;
      }
      m_dateFormat = dateFormat;
    }
    public virtual int GetDateFormat()
    {
      return m_dateFormat;
    }
    public virtual void SetTimeFormat(int timeFormat)
    {
      m_timeFormat = timeFormat;
    }
    public virtual int GetTimeFormat()
    {
      return m_timeFormat;
    }
    public virtual void SetLocale(String localeStr)
    {
      try
      {
        XPLocale locale;
        String language = XPStringUtility.Substring(localeStr, 0, 2);
        if (localeStr.Length > 2)
        {
          String country = XPStringUtility.Substring(localeStr, 3, 5);
          locale = new XPLocale(language, country);
        } else
        {
          locale = new XPLocale(language);
        }
        m_locale = locale;
      }
      catch (XPException e)
      {
        log.Warn(e, "Unable to set Locale from the following string on the request: " + localeStr + ". Using default Locale.");
        }
    }
    public virtual XPLocale GetLocale()
    {
      return m_locale;
    }
    public virtual void SetQueryPropIds(int[] queryPropIds)
    {
      m_queryPropIds = queryPropIds;
    }
    public virtual int[] GetQueryPropIds()
    {
      return m_queryPropIds;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
      m_space = null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
      m_space = null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_space = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new KDDocumentDataStoreModel();
    }
  }
}