using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.rest;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.rest.dojo
{
  /// <summary>
  /// Handles REST requests for retrieving subfolders in a KD Folders
  /// </summary>
  /// <author>rozhang</author>
  public class KDFolderDataStoreControl : IControl
  {
    public const String STR_MVC_CLASS_NAME = "folders";
    
    /// <summary>
    /// query string parameter with folder id *
    /// </summary>
    public const String QS_FOLDERID = "folderid";
    protected AActivitySpace m_space;
    protected KDFolderDataStoreModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // lookup the folderid to retrieve subfolders from and set it on the model
      int folderId = HTTPHelpers.GetArgumentAsInt(arguments, QS_FOLDERID,
       1);
      m_model.SetParentFolderId(folderId);
      return GetDPRedirect();
    }
    
    /// <summary>
    /// This helper method sets the error on the model and redirects to the
    /// REST API display page.
    /// </summary>
    /// <param name="_nErrorID">the current error code.</param>
    /// <returns>The redirect to the User REST API display page.</returns>
    public virtual Redirect ProcessError(IRESTError _error)
    {
      Redirect redirect = GetDPRedirect();
      m_model.SetError(_error);
      return redirect;
    }
    public virtual Redirect GetDPRedirect()
    {
      Redirect redirect = new Redirect();
      redirect.SetLinkGetCachedSpace(m_space);
      redirect.SetDisplayPage(KDFolderDataStoreDP.STR_MVC_CLASS_NAME);
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_space = space;
      m_model = (KDFolderDataStoreModel) model;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new KDFolderDataStoreControl();
    }
  }
}