using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.rest;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.rest.dojo
{
  /// <summary>
  /// Model to retrieve subfolders in a specific KD folder 
  /// </summary>
  /// <author>rozhang</author>
  public class KDFolderDataStoreModel : ARESTModel,IModel
  {
    public const String STR_MVC_CLASS_NAME = "KDFolderDataStore";
    
    /// <summary>
    /// property name for kd folder level (from root level 1) *
    /// </summary>
    public const String COL_FOLDERLEVEL = "folderlevel";
    
    /// <summary>
    /// property to flag that an entry has children *
    /// </summary>
    public const String COL_CHILDREN = "children";
    // unique identifier for each entry
    public const String COL_ID = "id";
    private const int FOLDER_MAXSEARCHLIMIT = 100;
    protected AActivitySpace m_space;
    
    /// <summary>
    /// parent folder id to retrieve sub folders from, set from a Control *
    /// </summary>
    private int m_parentFolderId = 0;
    
    /// <summary>
    /// Wrapper for returning sub folders from set parent folder id
    /// </summary>
    /// <returns>null if invalid/no parent folder id was set</returns>
    public virtual IXPList GetKDSubFoldersForCurrentParentFolder()
    {
      if (m_parentFolderId > 0)
      {
        return GetKDSubFolders(m_parentFolderId);
      } else
      {
        return null;
      }
    }
    
    /// <summary>
    /// Returns a list of dojo datastore object representations as a hashtable with properties
    /// The property names are synchronized with clientside javascript
    /// </summary>
    /// <param name="folderId"></param>
    /// <returns></returns>
    public virtual IXPList GetKDSubFolders(int folderId)
    {
      IPTSession session = (IPTSession) m_space.GetUserSession();
      IPTSearchRequest ptSR = session.GetSearchRequest();
      int[] folderid = {folderId};
      // setup search parameters
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS, folderid);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS,
       false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, new int[]{PT_CLASSIDS.PT_CATALOGFOLDER_ID});
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, PT_INTRINSICS.PT_PROPERTY_NAMEINDEX);
      // properties to return 
      int[] arPropIDs = {PT_INTRINSICS.PT_PROPERTY_OBJECTID, 
      // 1
      PT_INTRINSICS.PT_PROPERTY_OBJECTNAME, 
      // 2
      PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY, 
      //			PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED, // 3
      // 11 folderlevel
      PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL};
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_USUAL_FIELDS,
       false);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS, arPropIDs);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SKIPRESULTS, 0);
      ptSR.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, FOLDER_MAXSEARCHLIMIT);
      IPTSearchQuery ptQuery;
      if (folderId == PT_INTRINSICS.PT_FOLDER_ROOTFOLDER)
      {
        ptQuery = ptSR.CreateAdvancedQuery(CreateSubFolderSearchFilter(1));
        } else
      {
        ptQuery = ptSR.CreateBasicQuery("*", "");
      }
      // perform search
      IPTSearchResponse searchResponse = ptSR.Search(ptQuery);
      // put search results in hashtables, converted to json/other format by caller
      XPArrayList results = new XPArrayList();
      for (int i = 0;i < searchResponse.GetResultsReturned();i++)
      {
        XPHashtable resultEntry = new XPHashtable();
        resultEntry.PutElement(AQueryStoreModel.COL_OBJECTID, searchResponse.GetFieldsAsInt(i,
         PT_INTRINSICS.PT_PROPERTY_OBJECTID));
        resultEntry.PutElement(AQueryStoreModel.COL_NAME, searchResponse.GetFieldsAsString(i,
         PT_INTRINSICS.PT_PROPERTY_OBJECTNAME));
        resultEntry.PutElement(AQueryStoreModel.COL_DESCRIPTION, searchResponse.GetFieldsAsString(i,
         PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY));
        resultEntry.PutElement(COL_FOLDERLEVEL, searchResponse.GetFieldsAsInt(i,
         PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL));
        // create an empty child node to flag that this is an expandable node
        resultEntry.PutElement(COL_CHILDREN, new XPArrayList());
        resultEntry.PutElement(COL_ID, i + "");
        results.Add(resultEntry);
      }
      return results;
    }
    
    /// <summary>
    /// Search specific code, not sure why it is needed
    /// </summary>
    /// <param name="nCurrentLevel"></param>
    /// <returns></returns>
    public virtual IPTFilter CreateSubFolderSearchFilter(int nCurrentLevel)
    {
      IPTFilter filter = PortalObjectsFactory.CreateSearchFilter();
      IPTPropertyFilterStatement statementThisLevel = (IPTPropertyFilterStatement) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_STATEMENT);
      statementThisLevel.SetOperand(PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
      statementThisLevel.SetOperator(PT_FILTEROPS.PT_FILTEROP_EQ);
      statementThisLevel.SetValue(XPConvert.ToString(nCurrentLevel + 1));
      IPTPropertyFilterClauses clause = (IPTPropertyFilterClauses) filter.GetNewFilterItem(PT_FILTER_ITEM_TYPES.PT_FILTER_ITEM_CLAUSES);
      clause.AddItem(statementThisLevel, 0);
      if (FOLDER_MAXSEARCHLIMIT > 0)
      {
        filter.SetPropertyFilter(clause);
      } else
      {
        filter.SetPropertyFilter(statementThisLevel);
      }
      return filter;
    }
    public virtual void SetParentFolderId(int folderId)
    {
      m_parentFolderId = folderId;
    }
    public virtual int GetParentFolderId()
    {
      return m_parentFolderId;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()"></seealso>
    public virtual void CleanupAllData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()"></seealso>
    public virtual void CleanupTempData()
    {
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(AActivitySpace parent)
    {
      m_space = parent;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new KDFolderDataStoreModel();
    }
  }
}