using System;
using com.plumtree.openfoundation.util;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.rest.dojo
{
  /// <summary>
  /// Common control to parse request from dojo QueryStoreControl store
  /// The QueryStoreControl handles server-side loading, paging, and sorting by requesting bits
  /// of data, specified with query string arguments 
  /// </summary>
  /// <author>rozhang</author>
  public class QueryStoreControl : IControl
  {
    public const String STR_MVC_CLASS_NAME = "QueryStoreControl";
    
    /// <summary>
    /// Query string parameters sent by QueryStoreControl *
    /// </summary>
    public const String QS_QUERY = "query";
    public const String QS_ORDERBY = "sort";
    public const String QS_RESULTSIZE = "count";
    public const String QS_STARTINDEX = "start";
    protected AActivitySpace m_space;
    protected AQueryStoreModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      // parse request parameters
      int resultSize = HTTPHelpers.GetArgumentAsInt(arguments, QS_RESULTSIZE,
       0);
      int startIndex = HTTPHelpers.GetArgumentAsInt(arguments, QS_STARTINDEX,
       0);
      String orderByColName = HTTPHelpers.GetArgumentAsString(arguments, QS_ORDERBY,
       null);
      String query = HTTPHelpers.GetArgumentAsString(arguments, QS_QUERY,
       null);
      // use default set in model if none is passed
      if (orderByColName != null)
      {
        int orderBy = m_model.GetSearchPropIdFromColumnName(orderByColName);
        m_model.SetOrderById(orderBy);
      }
      // use default set in model if none is passed
      if (resultSize != 0)
      {
        m_model.SetResultSize(resultSize);
      }
      // use default set in model if none is passed
      if (query != null)
      {
        m_model.SetQuery(query);
      }
      m_model.SetStartIndex(startIndex);
      return null;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_space = space;
      m_model = (AQueryStoreModel) model;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new QueryStoreControl();
    }
  }
}