using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.rest;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
namespace com.plumtree.portalpages.rest.ldap
{
  /// <summary>
  /// Sets the name reqest parameter on the model 
  /// </summary>
  /// <author>rozhang</author>
  public class UserIdLookupControl : IControl
  {
    public const String STR_MVC_CLASS_NAME = "getid";
    public const String QS_AUTHNAME = "name";
    protected AActivitySpace m_space;
    protected UserIdLookupModel m_model;
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)"></seealso>
    public virtual Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
    {
      String authName = HTTPHelpers.GetArgumentAsString(arguments, QS_AUTHNAME,
       null);
      if (authName != null)
      {
        m_model.SetAuthName(authName);
      } else
      {
        m_model.SetError(CommonRestErrors.PARAM_MISSING_REQUESTARGUMENT.ParameterizeRESTError(QS_AUTHNAME));
        }
      return GetDPRedirect();
    }
    public virtual Redirect GetDPRedirect()
    {
      Redirect redirect = new Redirect();
      redirect.SetLinkGetCachedSpace(m_space);
      redirect.SetDisplayPage(UserIdLookupDP.STR_MVC_CLASS_NAME);
      return redirect;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel,com.plumtree.uiinfrastructure.activityspace.AActivitySpace)"></seealso>
    public virtual void Init(IModel model, AActivitySpace space)
    {
      m_space = space;
      m_model = (UserIdLookupModel) model;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()"></seealso>
    public virtual String GetName()
    {
      return STR_MVC_CLASS_NAME;
    }
    
    /// <seealso cref="com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()"></seealso>
    public virtual Object Create()
    {
      return new UserIdLookupControl();
    }
  }
}