using System;
using com.plumtree.openfoundation.io;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.openlog;
using com.plumtree.portalpages.rest;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.portalpages.rest.utils
{
  /// <summary>
  /// This class contains helper methods for the REST APIs.
  /// </summary>
  public class RESTHelper
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_REST),
     "com.plumtree.portalpages.rest.user.UserRESTControl");
    
    /// <summary>
    /// This helper method returns the POST body from the request
    /// input stream.
    /// </summary>
    /// <param name="_request">The current request.</param>
    /// <returns>the POST data.</returns>
    public virtual String GetPOSTBody(IXPRequest _request)
    {
      /* Get the input stream */
      XPInputStream xpInputStream = _request.GetInputStream();
      /* Find out the length of the body */
      int iStreamContentLength = _request.GetContentLength();
      /* allocate memory for the POST body */
      byte[] bodyStream = new byte[iStreamContentLength];
      /* read the POST body from the input stream */
      int iBytesRead = 0;
      while (iBytesRead < iStreamContentLength)
      {
        int iBytesReadLastTime = xpInputStream.Read(bodyStream, iBytesRead,
         iStreamContentLength - iBytesRead);
        if (iBytesReadLastTime < 0)
        {
          break;
        }
        iBytesRead+=iBytesReadLastTime;
      }
      if ((bodyStream != null) && (bodyStream.Length > 0))
      {
        // Technically this should be the encoding of the request, but we'll
        // just default to UTF-8 for now.
        return XPEncoding.GetString(bodyStream, XPStringUtility.DEFAULT_ENCODING);
        }
      return null;
    }
    
    /// <summary>
    /// This method outputs the JSON error results.
    /// </summary>
    /// <param name="_error">The error to output.</param>
    /// <param name="_webData">The current request web data.</param>
    public virtual void OutputError(IRESTError _error, IWebData _webData,
     bool commentFiltered)
    {
      // HTML encode the error string.
      // @TODO rob: do we really need to html encode json strings? shouldn't we escape encode it instead?
      // we don't know if the error string will be used in html or in javascript so it is better to leave that
      // up to the client
      String strError = XPHttpUtility.HtmlEncode(_error.GetMessage());
      // Really rough estimate of smallest output
      XPStringBuilder sbJSON = new XPStringBuilder(65);
      // Display error results
      sbJSON.Append((commentFiltered) ? "/*" : "{} && ").Append("{\n").Append("  \"").Append(RESTErrorConstants.ERROR_FORMAT_NAME).Append("\": {\n").Append("    \"").Append(RESTErrorConstants.ERROR_TEXT).Append("\": \"").Append(strError).Append("\",\n").Append("    \"").Append(RESTErrorConstants.ERROR_CODE).Append("\": \"").Append(_error.GetCode()).Append("\"\n").Append("  }\n").Append("}").Append((commentFiltered) ? "*/" : "");
      // NOTE: We should set this to 400, but that means we can't access the error data
      // since the dojo error handlers don't have access to the response data.
      _webData.SetStatus(200);
      _webData.SetData(sbJSON.ToString());
    }
    public virtual void OutputXMLError(IRESTError _error, IWebData _webData)
    {
      // HTML encode the error string.
      String strError = XPHttpUtility.HtmlEncode(_error.GetMessage());
      // Really rough estimate of smallest output
      XPStringBuilder xmlOut = new XPStringBuilder(65);
      // Display error results
      xmlOut.Append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>").Append("<" + RESTErrorConstants.ERROR_FORMAT_NAME + ">\n").
      // @TODO encode the message?
      Append("\t<" + RESTErrorConstants.ERROR_TEXT + ">").Append(strError).Append("</" + RESTErrorConstants.ERROR_TEXT + ">").Append("\t<" + RESTErrorConstants.ERROR_CODE + ">").Append(_error.GetCode()).Append("</" + RESTErrorConstants.ERROR_CODE + ">").Append("</" + RESTErrorConstants.ERROR_FORMAT_NAME + ">");
      // NOTE: We should set this to 400, but that means we can't access the error data
      // since the dojo error handlers don't have access to the response data.
      _webData.SetStatus(200);
      _webData.SetData(xmlOut.ToString());
    }
  }
}