using System;
using com.plumtree.portalpages.admin.objmgr;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// TaskAPI function related to the Administration Portal.
  /// </summary>
  public class TaskAPIUIAdministration
  {
    
    /// <summary>
    /// Gets the URL to the Administration Portal. 
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>IPTURL</c> with the URL to the Administrative portal, or <c>null</c> if user does not have access to it.</returns>
    public static IPTURL GetURLForAdministrationPortal(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      if (HasAdminLinkAccess(owner))
      {
        String strTitle = owner.GetString(275, "ptmsgs_portalcommonmsgs");
        String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
        CommonOpenerOpenASURL ptURL = new CommonOpenerOpenASURL(strTitle,
         ObjMgrAS.STR_MVC_CLASS_NAME, owner);
        ptURL.AddControlParameter(ASConstants.CONTROL, AdminRedirectControl.STR_MVC_CLASS_NAME);
        ptURL.SetURLImageType(PTImageType.ICON_ADMINISTRATION, strImageServerURL);
        return ptURL;
      }
      return null;
    }
    
    /// <seealso cref="TaskAPIUIUser.HasAdminLinkAccess"></seealso>
    public static bool HasAdminLinkAccess(AActivitySpace owner)
    {
      return TaskAPIUIUser.HasAdminLinkAccess(owner);
    }
  }
}