/*
 */
 
using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.gateway;
using com.plumtree.portalpages.browsing.myportal;
using CommunityPageAS=com.plumtree.portalpages.browsing.myportal.communities.CommunityPageAS;
using MyPageAS=com.plumtree.portalpages.browsing.myportal.mypages.MyPageAS;
using com.plumtree.portalpages.browsing.objectselection.flyout;
using com.plumtree.portalpages.browsing.sitemap.sitemappage;
using com.plumtree.portalpages.common.mediator;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.compoundlist;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.uitasks;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// Common functions used by other TaskAPI packages.
  /// </summary>
  public class TaskAPIUICommon
  {
    public const int INVALID_OBJECTID = 0;
    
    /// <param name="env">IEnvironment type</param>
    /// <returns>					An AActivityspace object</returns>
    /// <throws>
    /// XPIllegalArgumentException
    /// 		If the provided IEnvironment is null
    /// </throws>
    /// <throws>
    /// XPClassCastException
    /// 						If the provided IEnvironment is not of the required AActivityspace type
    /// </throws>
    public static AActivitySpace GetEnvTypeObject(IEnvironment env)
    {
      // TODOCR DONH: This method name doesn't make sense.  It takes an IEnvironment
      // as an argument, it doesn't return it.  It should be called something more like
      // GetAActivitySpace.
      ValidateEnvironmentArgumenmt(env);
      AActivitySpace owner = null;
      try
      {
        owner = (AActivitySpace) env;
      }
      catch (Exception cce)
      {
        throw new XPClassCastException("The provided IEnvironment object it not of the required type, need an AActivityspace.");
        }
      return owner;
    }
    
    /// <summary>
    /// Method to determine and obtain if object is a valid MyPage or CommunityPage AActivitySpace.
    /// </summary>
    /// <param name="env">IEnvironment type</param>
    /// <returns>		A MyPage or CommunityPage AActivityspace object or null if it is not available</returns>
    /// <throws>
    /// XPIllegalArgumentException
    /// 		If the provided IEnvironment is null
    /// </throws>
    public static AActivitySpace GetMyPageOrCommunityAActivitySpace(IEnvironment env)
    {
      ValidateEnvironmentArgumenmt(env);
      AActivitySpace owner = null;
      try
      {
        owner = (AActivitySpace) env;
        String spaceName = owner.GetName();
        // Check current space name, if not MyPage or CommunityPage, check the parent space
        if (0 != XPStringUtility.CompareIgnoreCase(spaceName, CommunityPageAS.STR_MVC_CLASS_NAME) && 0 != XPStringUtility.CompareIgnoreCase(spaceName,
         MyPageAS.STR_MVC_CLASS_NAME) && 0 != XPStringUtility.CompareIgnoreCase(spaceName,
         SiteMapAS.STR_MVC_CLASS_NAME))
        {
          if (0 == XPStringUtility.CompareIgnoreCase(spaceName, FlyoutPortletSelectionAS.STR_MVC_CLASS_NAME) || 0 == XPStringUtility.CompareIgnoreCase(spaceName,
           FlyoutCommunitySelectionAS.STR_MVC_CLASS_NAME))
          {
            if (owner.GetParentSpace() != null)
            {
              spaceName = owner.GetParentSpace().GetName();
              if (0 == XPStringUtility.CompareIgnoreCase(spaceName, CommunityPageAS.STR_MVC_CLASS_NAME) || 0 == XPStringUtility.CompareIgnoreCase(spaceName,
               MyPageAS.STR_MVC_CLASS_NAME))
              {
                // Ok, parent space is the one we should use
                owner = owner.GetParentSpace();
              } else
              {
                // Not a MyPage or CommunityPage ActivitySpace, return null. 
                owner = null;
              }
            }
          } else
          {
            // DCA - not the flyout editor, don't check the parent space.
            owner = null;
          }
        }
      }
      catch (Exception cce)
      {
        owner = null;
      }
      return owner;
    }
    
    /// <summary>
    /// INTERNAL
    /// </summary>
    /// <param name="env">IEnvironemnt object.</param>
    /// <throws>
    /// XPIllegalArgumentException
    /// 	If IEnvironment object is <c>null</c>.
    /// </throws>
    internal static void ValidateEnvironmentArgumenmt(IEnvironment env)
    {
      if (null == env)
      {
        throw new XPIllegalArgumentException("Invalid IEnvironment object provided - its value is null.");
        } else
      {
        return;
      }
    }
    
    /// <summary>
    /// INTERNAL
    /// </summary>
    /// <param name="owner">Activityspace object.</param>
    /// <throws>
    /// XPIllegalArgumentException
    /// 	If Activityspace object is <c>null</c>. 
    /// </throws>
    internal static void ValidateActivitySpaceArgument(AActivitySpace owner)
    {
      if (null == owner)
      {
        throw new XPIllegalArgumentException("Invalid actvityspace object provided - its value  is null.");
        } else
      {
        return;
      }
    }
    
    /// <summary>
    /// INTERNAL
    /// </summary>
    /// <param name="nObjectID"></param>
    /// <throws>XPIllegalArgumentException If nObjectID has the value of <c>0</c> or a negative number.</throws>
    internal static void ValidateObjectIDArgument(int nObjectID)
    {
      if (nObjectID <= INVALID_OBJECTID)
      {
        throw new XPIllegalArgumentException("Invalid object id provided: " + nObjectID + " - must be positive.");
        } else
      {
        return;
      }
    }
    
    /// <param name="nObjectID"></param>
    /// <returns>true if the provided nObjectID is valid (value greater than 0) </returns>
    internal static bool IsValidObjectIDArgument(int nObjectID)
    {
      return (nObjectID > INVALID_OBJECTID);
    }
    
    /// <summary>
    /// Helper function to convert an <c>ICPListEntryIterator</c> object to an array with <c>FullURL</c>s.
    /// Used for backwards compatibility.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="cpList">ICPListEntryIterator with URL data.</param>
    /// <returns>
    /// 					An array of <c>FullURL</c> objects with the URL, URL Title from the <c>ICPListEntryIterator</c>. 
    /// Icons and other components are not included.
    /// </returns>
    public static FullURL[] GetFullURLFromListEntryIterator(AActivitySpace owner,
     ICPListEntryIterator cpList)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      int nListCount = cpList.GetTotalCount();
      FullURL[] arURLs = new FullURL[nListCount];
      for (int i = 0;null != cpList && i < nListCount;i++)
      {
        CListURLFullLinkMediator mediator = new CListURLFullLinkMediator(owner,
         cpList);
        HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntryAtIndex(i);
        String strFullURL = anchor.GetHRef();
        String strText = anchor.GetInnerHTML();
        FullURL url = new FullURL(strText, strFullURL);
        arURLs[i] = url;
      }
      return arURLs;
    }
    
    /// <summary>
    /// Gets the Plumtree Session from the Activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>					Plumtree session.</returns>
    /// <throws>
    /// XPIllegalArgumentException
    /// 		If the provided AActivityspace is <c>null</c>.
    /// </throws>
    /// <throws>
    /// XPClassCastException
    /// 						If the provided AActivityspace has not been initialized correctly.
    /// </throws>
    public static IPTSession GetPTSession(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      IPTSession session = null;
      try
      {
        session = (IPTSession) owner.GetUserSession();
      }
      catch (Exception cce)
      {
        throw new XPClassCastException("Invalid AActivityspace provided - unable to get the IPTSession.");
        }
      return session;
    }
    
    /// <summary>
    /// Helper method that checks whether or not the NavigationModel
    /// object is present on the activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace object.</param>
    /// <returns>	<c>true</c> implies the NavigationModel is present, <c>false</c> otherwise.</returns>
    /// <throws>
    /// XPIllegalArgumentException
    /// 		If the provided AActivityspace is null
    /// </throws>
    public static bool GetNavigationModelExists(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      return owner.GetModelExists(NavigationModel.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Helper method that gets the NavigationModel object from an activityspace or throws
    /// an exception if the AActivityspace is invalid.
    /// </summary>
    /// <param name="owner">AActivityspace object</param>
    /// <returns>	NavigationModel object</returns>
    /// <throws>
    /// XPIllegalArgumentException If the provided AActivityspace is <c>null</c>
    /// or the <c>NavigationModel</c> is not available on the current Activity Space.
    /// </throws>
    /// <deprecated>	All functionality is available from TaskAPI functions, no need for <c>NavigationModel</c>.</deprecated>
    public static NavigationModel GetNavigationModel(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      if (GetNavigationModelExists(owner))
      {
        return (NavigationModel) owner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
        }
      throw new XPIllegalArgumentException("Invalid activityspace object, Unable to  get NavigationModel from activityspace");
      }
    
    /// <summary>
    /// Helper method to check if the specified Model object exists in the current Activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="strModelName">
    /// Name of the Model object, defined as a static constant on every model object
    /// named <c>STR_MVC_CLASS_NAME</c>
    /// </param>
    /// <returns>	<c>true</c> if the specified model exists on the activutyspace, <c>false</c> otherwise.</returns>
    public static bool GetASModelExist(AActivitySpace owner, String strModelName)
    {
      ValidateActivitySpaceArgument(owner);
      return owner.GetModelExists(strModelName);
    }
    
    /// <summary>
    /// Gets the specified Activityspace Model object. 
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="strModelName">
    /// Name of the Model object, defined as a static constant on every model object
    /// named <c>STR_MVC_CLASS_NAME</c>
    /// </param>
    /// <returns>	The requested Activityspace Model object or <c>null</c> if it does not exist.</returns>
    public static Object GetASModel(AActivitySpace owner, String strModelName)
    {
      ValidateActivitySpaceArgument(owner);
      return owner.GetModel(strModelName);
    }
    
    /// <summary>
    /// Gets the <c>MyPortalModel</c> object.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns><c>MyPortalModel</c> object, or <c>null</c> if MyPortalModel was not found</returns>
    public static MyPortalModel GetMyPortalPageModel(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      MyPortalModel model = null;
      try
      {
        model = (MyPortalModel) owner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        }
      catch (Exception e)
      {
        // Do not do anything, just return null;
        }
      return model;
    }
    
    /// <summary>
    /// Checks if the <c>MyPortalModel</c> exists in the current Activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the MyPortalModel exists, <c>false</c> otherwise.</returns>
    public static bool GetMyPortalPageModelExists(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      return owner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Gets the <c>SiteMapModel</c> object.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns><c>SiteMapModel</c> object, or <c>null</c> if MyPortalModel was not found</returns>
    public static SiteMapModel GetSiteMapPageModel(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      SiteMapModel model = null;
      try
      {
        model = (SiteMapModel) owner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
        }
      catch (Exception e)
      {
        // Do not do anything, just return null;
        }
      return model;
    }
    
    /// <summary>
    /// Checks if the <c>SiteMapModel</c> exists in the current Activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the SiteMapModel exists, <c>false</c> otherwise.</returns>
    public static bool GetSiteMapPageModelExists(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      return owner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Gets the <c>GatewayModel</c> object.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns><c>SiteMapModel</c> object, or <c>null</c> if GatewayModel was not found</returns>
    public static GatewayModel GetGatewayPageModel(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      GatewayModel model = null;
      try
      {
        model = (GatewayModel) owner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
        }
      catch (Exception e)
      {
        // Do not do anything, just return null;
        }
      return model;
    }
    
    /// <summary>
    /// Checks if the <c>GatewayModel</c> exists in the current Activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the GatewayModel exists, <c>false</c> otherwise.</returns>
    public static bool GetGatewayPageModelExists(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      return owner.GetModelExists(GatewayModel.STR_MVC_CLASS_NAME);
    }
    
    /// <summary>
    /// Gets the name of the provided Activityspace.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>		Name of the Activityspace.</returns>
    public static String GetActivitySpaceName(AActivitySpace owner)
    {
      ValidateActivitySpaceArgument(owner);
      String strASName = owner.GetName();
      return strASName;
    }
    
    /// <summary>
    /// Checks if the current Page is a Preview Page.
    /// For example, Preview Portlet or Preview Community page.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the current <c>page</c> is a preview page, false otherwise.</returns>
    public static bool IsCurrentPageInPreviewMode(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      bool bIsPreviewPage = false;
      if (GetASModelExist(owner, MyPortalModel.STR_MVC_CLASS_NAME))
      {
        MyPortalModel myPortalModel = (MyPortalModel) owner.GetModel(MyPortalModel.STR_MVC_CLASS_NAME);
        bIsPreviewPage = myPortalModel.IsPreviewPage();
      }
      if (owner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME))
      {
        SiteMapModel siteMapModel = (SiteMapModel) owner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
        bIsPreviewPage = siteMapModel.IsPreviewPage();
      }
      return bIsPreviewPage;
    }
    
    /// <summary>
    /// Checks if the current page is an Edit Default Profile page.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the current page is a Edit Default Profile page, <c>false</c> otherwise.</returns>
    public static bool IsCurrentPageInEditDefaultProfileMode(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      return PlumtreeHelpers.IsEditingDefaultProfile(owner);
    }
    
    /// <summary>
    /// Checks if the current Activityspace is the specified Activityspace type, E.g. MyPageAS.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="strASName">Name of Activityspace type to check for.</param>
    /// <returns><c>true</c> if the current Activityspace is of the specified type, <c>false</c> if not or Activityspace name is <c>null</c>.</returns>
    public static bool IsCurrentActivitySpace(AActivitySpace owner, String strASName)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      if (null == strASName)
      {
        return false;
      }
      return strASName.Equals(GetActivitySpaceName(owner));
    }
    
    /// <summary>
    /// Checks if the current DisplayPage is the specified DisplayPage type, E.g. PlumtreeDP or MyPortalDP.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="strPageName">
    /// Name of the DisplayPage, defined on each DisplayPage as a static constant named
    /// <c>STR_MVC_CLASS_NAME</c>.
    /// </param>
    /// <returns><c>true</c> if the current DisplayPage is of the specified type, <c>false</c> if not or DisplayPage name is <c>null</c>.</returns>
    public static bool IsCurrentDisplayPage(AActivitySpace owner, String strPageName)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      if (null == strPageName)
      {
        return false;
      }
      return strPageName.Equals(owner.GetCurrentPage().GetName());
    }
    
    /// <summary>
    /// Checks whether the classId supports friendly URLs
    /// This method is primarily used to check if specific opener links should generate friendly URLs
    /// or regular opener URLs.
    /// </summary>
    /// <param name="classId">Class Id of the object type to create URL for</param>
    /// <returns>Result whether friendly URLs should be used for the class type</returns>
    public static bool UseFriendlyURLS(int classId)
    {
      // Friendly URL defined for a particular classId if there are friendly url token defined 
      return UseFriendlyURLS(classId, null);
    }
    
    /// <summary>
    /// Checks whether the classId supports friendly URLs also considering any additional
    /// query string parameters.
    /// This method is primarily used to check if specific opener links should generate friendly URLs
    /// or regular opener URLs.  
    /// </summary>
    /// <param name="classId">Class Id of the object type to create URL for</param>
    /// <param name="queryStringArgs">Any query string parameters on the URL</param>
    /// <returns>Result whether friendly URLs should be used for the class type</returns>
    public static bool UseFriendlyURLS(int classId, String queryStringArgs)
    {
      return PTConfigService.getPTInstance().UseFriendlyURLS(classId, queryStringArgs);
      }
  }
}