using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.pei;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// This class manages instances of the ITaskAPIUICommunity interface
  /// for both production and testing purposes.
  /// It is a replacement for the TaskAPIUICommunity class, since that
  /// class uses static methods and cannot be mocked for testing.
  /// </summary>
  public class TaskAPIUICommunityService : ITaskAPIUICommunity
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.taskapi.portalui.TaskAPIUICommunityService");
    private static ITaskAPIUICommunity m_DEBUG_INSTANCE = null;
    
    /// <returns>An instance of the ITaskAPIUIDirectory interface.</returns>
    public static ITaskAPIUICommunity GetInstance()
    {
      if (m_DEBUG_INSTANCE != null)
      {
        return m_DEBUG_INSTANCE;
      }
      return new TaskAPIUICommunityService();
    }
    
    /// <summary>
    /// This method sets the debug instance of the ITaskAPIUIDirectory interface
    /// for use as a mock object.  This should never be used in a production
    /// environment.
    /// This should be reset to null at the end of testing to ensure other code
    /// does not get an old mock instance.
    /// </summary>
    /// <param name="_instance">
    /// The mock instance of the ITaskAPIUIDirectory interface.
    /// When the mock instance is done being used it should be reset to null by
    /// calling this method again with a null argument.
    /// </param>
    public static void SetMockInstanceForDebug(ITaskAPIUICommunity _instance)
    {
      m_DEBUG_INSTANCE = _instance;
    }
    
    /// <summary>
    /// Private constructor to force people to use the GetInstance() method..
    /// </summary>
    private TaskAPIUICommunityService()
    {
    }
    public virtual bool CheckUserAccessLevelToCommunity(AActivitySpace owner,
     int nAccessLevel, int nCommunityID)
    {
      return TaskAPIUICommunity.CheckUserAccessLevelToCommunity(owner, nAccessLevel,
       nCommunityID);
    }
    public virtual bool CheckUserAccessLevelToCurrentCommunity(AActivitySpace owner,
     int nAccessLevel)
    {
      return TaskAPIUICommunity.CheckUserAccessLevelToCurrentCommunity(owner,
       nAccessLevel);
    }
    public virtual bool CheckUserAccessLevelToCurrentCommunityPage(AActivitySpace owner,
     int nAccessLevel)
    {
      return TaskAPIUICommunity.CheckUserAccessLevelToCurrentCommunityPage(owner,
       nAccessLevel);
    }
    public virtual IPTURL CreateCommunityCommonOpenerURL(AActivitySpace owner,
     int nCommunityID, String strCommunityName)
    {
      return TaskAPIUICommunity.CreateCommunityCommonOpenerURL(owner, nCommunityID,
       strCommunityName);
    }
    public virtual IPTURL CreateCommunityPageCommonOpenerURL(AActivitySpace owner,
     int nCommunityID, int nCommunityPageID, String strCommunityPageName)
    {
      return TaskAPIUICommunity.CreateCommunityPageCommonOpenerURL(owner,
       nCommunityID, nCommunityPageID, strCommunityPageName);
    }
    public virtual IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
     int nProfileUserID, String sProfileUserName)
    {
      return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner,
       nProfileUserID, sProfileUserName);
    }
    public virtual IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
     int nProfileUserID, String sProfileUserName, String strURLTitle)
    {
      return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner,
       nProfileUserID, sProfileUserName, strURLTitle);
    }
    public virtual IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
     int nProfileUserID, String sProfileUserName, String strURLTitle, int nPageId,
     String strPageName)
    {
      return TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(owner,
       nProfileUserID, sProfileUserName, strURLTitle, nPageId, strPageName);
      }
    public virtual XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCommunityActionsAsURLs(owner);
    }
    public virtual XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner,
     bool bIncludeOneClick, bool bInheritTemplate, int nPageTemplate)
    {
      return TaskAPIUICommunity.GetCommunityActionsAsURLs(owner, bIncludeOneClick,
       bInheritTemplate, nPageTemplate);
    }
    public virtual int GetCommunityIDFromPTURL(IPTURL ptURL)
    {
      return TaskAPIUICommunity.GetCommunityIDFromPTURL(ptURL);
    }
    public virtual String GetCommunityName(AActivitySpace owner, int nCommunityID)
    {
      return TaskAPIUICommunity.GetCommunityName(owner, nCommunityID);
    }
    public virtual int GetCommunityPageIDFromPTURL(IPTURL ptURL)
    {
      return TaskAPIUICommunity.GetCommunityPageIDFromPTURL(ptURL);
    }
    public virtual XPArrayList GetCommunityPagesAsURLs(AActivitySpace owner,
     int nCommunityID)
    {
      return TaskAPIUICommunity.GetCommunityPagesAsURLs(owner, nCommunityID);
      }
    public virtual int GetCurrentCommunityID(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentCommunityID(owner);
    }
    public virtual String GetCurrentCommunityName(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentCommunityName(owner);
    }
    public virtual int GetCurrentCommunityPageID(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentCommunityPageID(owner);
    }
    public virtual String GetCurrentCommunityPageName(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentCommunityPageName(owner);
    }
    public virtual XPArrayList GetCurrentCommunityPagesAsURLs(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentCommunityPagesAsURLs(owner);
    }
    public virtual IPTURL GetCurrentPageAsURL(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentPageAsURL(owner);
    }
    public virtual IPTURL GetCurrentParentCommunityAsURL(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentParentCommunityAsURL(owner);
    }
    public virtual int GetCurrentParentCommunityID(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentParentCommunityID(owner);
    }
    public virtual XPArrayList GetCurrentRelatedCommunitiesAsURLs(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentRelatedCommunitiesAsURLs(owner);
      }
    public virtual int[] GetCurrentRelatedCommununityIDs(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentRelatedCommununityIDs(owner);
    }
    public virtual XPArrayList GetCurrentSubCommunitiesAsURLs(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentSubCommunitiesAsURLs(owner);
    }
    public virtual int[] GetCurrentSubCommunityIDs(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetCurrentSubCommunityIDs(owner);
    }
    public virtual int GetDefaultCommunityID(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetDefaultCommunityID(owner);
    }
    public virtual XPArrayList GetMyCommunitiesAsURLs(AActivitySpace owner,
     bool bUseCachedData)
    {
      return TaskAPIUICommunity.GetMyCommunitiesAsURLs(owner, bUseCachedData);
      }
    public virtual XPArrayList GetMyMandatoryCommunitiesWithTabsAsURLs(AActivitySpace owner,
     bool bUseCachedData)
    {
      return TaskAPIUICommunity.GetMyMandatoryCommunitiesWithTabsAsURLs(owner,
       bUseCachedData);
    }
    public virtual IPTURL GetParentCommunityAsURL(AActivitySpace owner, int nCommunityID)
    {
      return TaskAPIUICommunity.GetParentCommunityAsURL(owner, nCommunityID);
      }
    public virtual int GetParentCommunityID(AActivitySpace owner, int nCommunityID)
    {
      return TaskAPIUICommunity.GetParentCommunityID(owner, nCommunityID);
      }
    public virtual XPArrayList GetRelatedCommununitiesAsURLs(AActivitySpace owner,
     int nCommunityID)
    {
      return TaskAPIUICommunity.GetRelatedCommununitiesAsURLs(owner, nCommunityID);
      }
    public virtual int[] GetRelatedCommununityIDs(AActivitySpace owner, int nCommunityID)
    {
      return TaskAPIUICommunity.GetRelatedCommununityIDs(owner, nCommunityID);
      }
    public virtual XPArrayList GetSubCommununitiesAsURLs(AActivitySpace owner,
     int nCommunityID)
    {
      return TaskAPIUICommunity.GetSubCommununitiesAsURLs(owner, nCommunityID);
      }
    public virtual int[] GetSubCommununityIDs(AActivitySpace owner, int nCommunityID)
    {
      return TaskAPIUICommunity.GetSubCommununityIDs(owner, nCommunityID);
      }
    public virtual IPTURL GetURLForAddCommunityPortletsEditor(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForAddCommunityPortletsEditor(owner);
      }
    public virtual IPTURL GetURLForAddCommunityPortletsFlyout(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForAddCommunityPortletsFlyout(owner);
      }
    public virtual IPTURL GetURLForCommunityKnowledgeDirectory(AActivitySpace owner,
     int nCommunityID)
    {
      return TaskAPIUICommunity.GetURLForCommunityKnowledgeDirectory(owner,
       nCommunityID);
    }
    public virtual IPTURL GetURLForCreateCommunityPage(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForCreateCommunityPage(owner);
    }
    public virtual IPTURL GetURLForCreateCommunityPageOneClick(AActivitySpace owner,
     bool bInheritTemplate, int nPageTemplate)
    {
      return TaskAPIUICommunity.GetURLForCreateCommunityPageOneClick(owner,
       bInheritTemplate, nPageTemplate);
    }
    public virtual XPArrayList GetURLForCurrentCommunity(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForCurrentCommunity(owner);
    }
    public virtual IPTURL GetURLForCurrentCommunityEditor(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForCurrentCommunityEditor(owner);
    }
    public virtual IPTURL GetURLForEditPortletPreferencesEditor(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForEditPortletPreferencesEditor(owner);
      }
    public virtual IPTURL GetURLForJoinCommunitiesEditor(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForJoinCommunitiesEditor(owner);
    }
    public virtual IPTURL GetURLForJoinCurrentCommunityAction(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForJoinCurrentCommunityAction(owner);
      }
    public virtual IPTURL GetURLForUnsubscribeCommunitiesEditor(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForUnsubscribeCommunitiesEditor(owner);
      }
    public virtual IPTURL GetURLForUnsubscribeCurrentCommunityAction(AActivitySpace owner)
    {
      return TaskAPIUICommunity.GetURLForUnsubscribeCurrentCommunityAction(owner);
      }
    public virtual bool IsCurrentCommunityUserProfileCommunity(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsCurrentCommunityUserProfileCommunity(owner);
      }
    public virtual bool IsCurrentPageCommunityPage(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsCurrentPageCommunityPage(owner);
    }
    public virtual bool IsCurrentPageMyPortalPage(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsCurrentPageMyPortalPage(owner);
    }
    public virtual bool IsCurrentUserAbleToEditCurrentCommunityPage(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsCurrentUserAbleToEditCurrentCommunityPage(owner);
      }
    public virtual bool IsCurrentUserCommunityOwner(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsCurrentUserCommunityOwner(owner);
    }
    public virtual bool IsUserAbleToAccessCurrentCommunity(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsUserAbleToAccessCurrentCommunity(owner);
      }
    public virtual bool IsUserAbleToJoinCurrentCommunity(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsUserAbleToJoinCurrentCommunity(owner);
    }
    public virtual bool IsUserMemberOfCurrentCommunity(AActivitySpace owner)
    {
      return TaskAPIUICommunity.IsUserMemberOfCurrentCommunity(owner);
    }
    
    /// <seealso cref="com.plumtree.taskapi.portalui.ITaskAPIUICommunity.IsCommunityMember(AActivitySpace,">int)</seealso>
    public virtual bool IsCommunityMember(AActivitySpace _asOwner, int _nCommunityID)
    {
      IPTSession userSession = (IPTSession) _asOwner.GetUserSession();
      IPTQueryResult membershipList = userSession.GetSessionInfo().GetCurrentCommunityMembership();
      // go through user's list of communities joined
      for (int i = 0;i < membershipList.RowCount();i++)
      {
        // if community specified by commID is in the list
        if (membershipList.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID) == _nCommunityID)
        {
          // user is already a member of community
          return true;
        }
      }
      return false;
    }
    
    /// <seealso cref="com.plumtree.taskapi.portalui.ITaskAPIUICommunity.JoinCommunity(AActivitySpace,">int)</seealso>
    public virtual bool JoinCommunity(AActivitySpace _asOwner, int _nCommunityID)
    {
      // Joining a community will fail if the user is already a member, so check
      // membership first.
      if (IsCommunityMember(_asOwner, _nCommunityID))
      {
        // User is already a member of the community, return false.
        return false;
      }
      try
      {
        IPTSession userSession = (IPTSession) _asOwner.GetUserSession();
        ((IPTCommunityManager) userSession.GetCommunities()).JoinCommunity(_nCommunityID,
         PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE);
      }
      catch (Exception ex)
      {
        log.Error(ex, "Unable to join community " + _nCommunityID);
        throw XPException.GetInstance(ex);
      }
      try
      {
        //PEI : CommunityActions
        // MJD: All of the following code will load all of the available CommunityAction
        // PEIs and process through them.
        IApplication application = _asOwner.GetApplication();
        Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
        if (oa != null)
        {
          for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
          {
            Object o = oa[iCommAction];
            if (o != null)
            {
              ICommunityActions iActions = (ICommunityActions) o;
              iActions.OnAfterUserJoinsCommunity(_asOwner, (IPTSession) _asOwner.GetUserSession(),
               new int[]{_nCommunityID});
            }
          }
        }
      }
      //PEI : CommunityActions : END
      catch (Exception ex)
      {
        // Ignore errors in the PEI
        log.Error(ex, "OnAfterUserJoinsCommunity PEI failed.");
      }
      // User has successfully joined the community.
      return true;
    }
    
    /// <seealso cref="com.plumtree.taskapi.portalui.ITaskAPIUICommunity.LeaveCommunity(AActivitySpace,">int)</seealso>
    public virtual bool LeaveCommunity(AActivitySpace _asOwner, int _nCommunityID)
    {
      // Leaving a community will fail if the user is not a member, so check
      // membership first.
      if (!IsCommunityMember(_asOwner, _nCommunityID))
      {
        // User is not a member of the community, return false.
        return false;
      }
      IPTSession userSession = (IPTSession) _asOwner.GetUserSession();
      IPTCommunityManager myCommunities = (IPTCommunityManager) userSession.GetCommunities();
      try
      {
        myCommunities.QuitCommunity(_nCommunityID);
      }
      catch (Exception ex)
      {
        log.Error(ex, "Unable to leave community " + _nCommunityID);
        throw XPException.GetInstance(ex);
      }
      try
      {
        //PEI : CommunityActions
        // MJD: All of the following code will load all of the available CommunityAction
        // PEIs and process through them.
        IApplication application = _asOwner.GetApplication();
        Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
        if (oa != null)
        {
          for (int iCommAction = 0;iCommAction < oa.Length;iCommAction++)
          {
            Object o = oa[iCommAction];
            if (o != null)
            {
              ICommunityActions iActions = (ICommunityActions) o;
              iActions.OnAfterUserQuitsCommunity(_asOwner, (IPTSession) _asOwner.GetUserSession(),
               new int[]{_nCommunityID});
            }
          }
        }
      }
      //PEI : CommunityActions : END
      catch (Exception ex)
      {
        log.Error(ex, "OnAfterUserQuitsCommunity PEI failed.");
      }
      // User has successfully left the community.
      return true;
    }
  }
}