using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.common.uiparts;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.htmlconstructs;
using com.plumtree.xpshared.htmlconstructs;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// HTML Related TaskAPI functions.
  /// </summary>
  public class TaskAPIUIHTML
  {
    
    /// <summary>
    /// Adds a spacer cell with a cell width of 4to the specified HTMLTableRow
    /// </summary>
    /// <param name="myTableRow">HTMLTableRow to add the spacer cell to</param>
    public static void CreateHorizontalSpacerCell(HTMLTableRow myTableRow)
    {
      NavigationCommonHelpers.CreateHorizontalSpacerCell(myTableRow);
    }
    
    /// <summary>
    /// Gets an HTML Image element for the specified Plumtree Image Construct.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="construct">A Plumtree Image Construct.</param>
    /// <returns>	HTML img element created from the Plumtree Image Construct object.</returns>
    public static HTMLImg GetImageConstruct(AActivitySpace owner, PTConstructType construct)
    {
      return (HTMLImg) UIConstructFactory.GetConstruct(construct, true, owner).GetHTMLElement();
      }
    
    /// <summary>
    /// Gets a blank spacer image element with the specified width and height.
    /// </summary>
    /// <param name="strWidth">Width value that goes directly into the width attribute in the HTML img element.</param>
    /// <param name="strHeight">Height value that goes directly into the width attribute in the HTML img element.</param>
    /// <returns>	HTMLImg element with a spacer image in the specified width and height. </returns>
    public static HTMLImg GetSpacerImage(String strWidth, String strHeight)
    {
      return PlumtreeHelpers.GetSpacerImage(strWidth, strHeight);
    }
    
    /// <summary>
    /// Returns an HTML-encoded version of the input string, or
    /// empty string if input is null. 
    /// </summary>
    /// <param name="strValue">a string of characters to encode for use as HTML text.</param>
    /// <returns>an encoded version of the input, or empty string if <c>null</c>.</returns>
    public static String HTMLEncode(String strValue)
    {
      return XPHttpUtility.HtmlEncode(strValue);
    }
    
    /// <summary>
    /// Returns a decoded version of the input string, 
    /// assuming it was a valid HTML encoding.
    /// </summary>
    /// <param name="strValue">the string to decode.</param>
    /// <returns>a decoded version of the input.</returns>
    /// <throws>XPNullPointerException if input is <c>null</c>.</throws>
    /// <throws>XPUnsupportedEncodingException if an invalid ampersand escape is found.</throws>
    public static String HTMLDecode(String strValue)
    {
      return XPHttpUtility.HtmlDecode(strValue);
    }
    
    /// <param name="e">Element to add table to, or null to not add it to any element</param>
    /// <param name="padding">Table padding</param>
    /// <param name="spacing">Table spacing</param>
    /// <param name="width">Table width (in percentage or pixels) or null if no width is needed</param>
    /// <returns>			HTMLTable element</returns>
    public static HTMLTable CreateTable(HTMLElement e, int padding, int spacing,
     String width)
    {
      HTMLTable table = new HTMLTable();
      if (e != null)
      {
        e.AddInnerHTMLElement(table);
      }
      table.SetCellPadding(padding + "");
      table.SetCellSpacing(spacing + "");
      if (width != null && !"".Equals(width))
      {
        table.SetWidth(width);
      }
      return table;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <returns>			HTMLTableRow element or null if e is null</returns>
    public static HTMLTableRow CreateTableRow(HTMLTable e, String style)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableRow row = new HTMLTableRow();
      e.AddInnerHTMLElement(row);
      if (style != null && !"".Equals(style))
      {
        row.SetStyleClass(style);
      }
      return row;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <returns>			HTMLTableRow element or null if e is null</returns>
    public static HTMLTableRow CreateTableRow(HTMLTable e, PTStyleClass style)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableRow row = CreateTableRow(e, style.GetStyleName());
      return row;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <returns>			HTMLTableCell element or null if e is null</returns>
    public static HTMLTableCell CreateTableCell(HTMLTableRow e, String style)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableCell cell = new HTMLTableCell();
      e.AddInnerHTMLElement(cell);
      if (style != null && !"".Equals(style))
      {
        cell.SetStyleClass(style);
      }
      return cell;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <returns>			HTMLTableCell element or null if e is null</returns>
    public static HTMLTableCell CreateTableCell(HTMLTableRow e, PTStyleClass style)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableCell cell = CreateTableCell(e, (style == null) ? null : style.GetStyleName());
      return cell;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <param name="height">Table cell height</param>
    /// <param name="width">Table cell width (in percentage or pixels)</param>
    /// <returns>			HTMLTableCell element or null if e is null</returns>
    public static HTMLTableCell CreateTableCell(HTMLTableRow e, String style,
     int height, String width)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableCell cell = CreateTableCell(e, style);
      cell.SetHeight(height + "");
      cell.SetWidth(width);
      return cell;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <param name="height">Table cell height</param>
    /// <param name="width">Table cell width (in percentage or pixels)</param>
    /// <returns>			HTMLTableCell element or null if e is null</returns>
    public static HTMLTableCell CreateTableCell(HTMLTableRow e, PTStyleClass style,
     int height, String width)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableCell cell = CreateTableCell(e, (style == null) ? null : style.GetStyleName(),
       height, width);
      return cell;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <param name="value">Content to add to table cell, string is html encoded</param>
    /// <param name="height">Table cell height</param>
    /// <param name="width">Table cell width (in percentage or pixels)</param>
    /// <returns>			HTMLTableCell element or null if e is null</returns>
    public static HTMLTableCell CreateTableCell(HTMLTableRow e, String value,
     String style, int height, String width)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableCell cell = CreateTableCell(e, style, height, width);
      if (value != null)
      {
        cell.AddInnerHTMLEncodedString(value);
      }
      return cell;
    }
    
    /// <param name="e">Element to add table to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <param name="value">Content to add to table cell, string is html encoded</param>
    /// <param name="height">Table cell height</param>
    /// <param name="width">Table cell width (in percentage or pixels)</param>
    /// <returns>			HTMLTableCell element or null if e is null</returns>
    public static HTMLTableCell CreateTableCell(HTMLTableRow e, String value,
     PTStyleClass style, int height, String width)
    {
      if (e == null)
      {
        return null;
      }
      HTMLTableCell cell = CreateTableCell(e, (style == null) ? null : style.GetStyleName(),
       height, width);
      if (value != null)
      {
        cell.AddInnerHTMLEncodedString(value);
      }
      return cell;
    }
    
    /// <param name="e">HTMLTableCell element to add span to</param>
    /// <param name="style">CSS Style for the row or null if no style is needed</param>
    /// <param name="content">Content to add to table cell, string is html encoded</param>
    /// <returns>			The created HTMLSpan or null if e is null</returns>
    public static HTMLSpan CreateSpanToCell(HTMLTableCell e, PTStyleClass style,
     String content)
    {
      if (e == null)
      {
        return null;
      }
      HTMLSpan span = new HTMLSpan();
      e.AddInnerHTMLElement(span);
      span.SetStyleClass(style);
      span.AddInnerHTMLEncodedString(content);
      return span;
    }
    
    /// <param name="e">HTMLTableCell element to add span to</param>
    /// <param name="type">Type of input element</param>
    /// <param name="inputName">Input name</param>
    /// <param name="alt">Alt text</param>
    /// <returns>	</returns>
    public static HTMLInput CreateInputToCell(HTMLTableCell e, HTMLInputTypes type,
     String inputName, String alt)
    {
      if (e == null)
      {
        return null;
      }
      HTMLInput input = new HTMLInput(type, inputName, alt);
      e.AddInnerHTMLElement(input);
      return input;
    }
  }
}