/*
 * Created on Jan 12, 2005
 */
 
using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.utils;
using com.plumtree.xpshared.htmlelements;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// Javascript related TaskAPI functions.  
  /// </summary>
  public class TaskAPIUIJavascript
  {
    
    /// <summary>
    /// Call this function to use SafeJSVars on a page.
    /// Create the container to hold the safe variables.
    /// The container is just a javascript object and we but
    /// the vars on it as object properties.
    /// </summary>
    /// <returns>HTMLScript Element with javascript to initialize SafeJSVars .</returns>
    public static HTMLScript InitializeSafeJSVarElements()
    {
      return JSHelper.InitializeSafeJSVarElements();
    }
    
    /// <summary>
    /// Helper function to define a safe javascript variable.
    /// The safe variable will be defined in its on javascript block, so it won't
    /// affect any other javascript if the assigned value is invalid.
    /// Reference it by using the javascript getSafeVariable or getSafeVariableWarn
    /// helper functions or <c>GetSafeJSVariable</c> or <c>GetSafeJSVariableWarn
    /// </c> java helper functions to generate the javascript calls.
    /// NOTE: The strValue is the string with the javascript value so don't surround
    /// it with quotes. For javascript string values, use the <c>AddSafeJSStringVariable</c>
    /// method.
    /// E.g. 
    /// <c>strValue = new Object()</c> - will assign a new object to the variable while
    /// <c>strValue = "new Object()"</c> - will assign the string "new Object()"   
    /// </summary>
    /// <param name="strName">Name of the variable to create. Should be unqiue from other name on a page.</param>
    /// <param name="strValue">Value of the variable. Either a number or a reference to another javascript variable.</param>
    /// <returns>HTMLScript	Javascript element with javascript to create the specfied variable. </returns>
    /// <seealso cref="AddSafeJSVariable,">GetSafeJSVariable, GetSafeJSVariableWarn</seealso>
    public static HTMLScript AddSafeJSVariable(String strName, String strValue)
    {
      return JSHelper.AddSafeJSVariable(strName, strValue);
    }
    
    /// <summary>
    /// Helper function to define a safe javascript variable.
    /// The safe variable will be defined in its on javascript block, so it won't
    /// affect any other javascript if the assigned value is invalid.
    /// Reference it by using the javascript getSafeVariable or getSafeVariableWarn
    /// helper functions or <c>GetSafeJSVariable</c> or <c>GetSafeJSVariableWarn
    /// </c> java helper \u0009 * functions to generate the javascript calls.
    /// Adds quotes around the provided String and escapes any quotes and whitespace in the string.  
    /// For example, passing in 'Text' (without quotes) will create a javascript string with the value Text.
    /// </summary>
    /// <param name="strName">Name of the variable to create. Should be unqiue from other name on a page.</param>
    /// <param name="strValue">String value of the variable.</param>
    /// <returns>HTMLScript	Javascript element with javascript to create the specfied variable.</returns>
    public static HTMLScript AddSafeJSStringVariable(String strName, String strValue)
    {
      return JSHelper.AddSafeJSVariable(strName, "\'" + TaskAPIUIJavascript.EscapeJavaScriptString(strValue) + "\'");
      }
    
    /// <summary>
    /// Helper function to retrieve a safe javascript variable.
    /// The javascript function will return <c>false</c> if it is unable
    /// to get the variable.
    /// </summary>
    /// <param name="strName">Name of the variable to retrieve.</param>
    /// <returns>
    /// String  		A string with Javascript code to retrieve the named SafeJS variable. The
    /// <c>String</c> should be added to a <c>HTMLScript</c> element.
    /// </returns>
    /// <seealso cref="InitializeSafeJSVarElements,">AddSafeJSVariable, GetSafeJSVariableWarn</seealso>
    public static String GetSafeJSVariable(String strName)
    {
      return JSHelper.GetSafeJSVariable(strName);
    }
    
    /// <summary>
    /// Helper function to retrieve a safe javascript variable.
    /// The javascript function will display a javascript alert error with the name of the variable. 
    /// Use for critical variables that absolutely need to be defined for a page to function.
    /// </summary>
    /// <param name="strName">Name of the variable to retrieve.</param>
    /// <returns>
    /// String  		A string with Javascript code to retrieve the named SafeJS variable. The
    /// <c>String</c> should be added to a <c>HTMLScript</c> element.
    /// </returns>
    /// <seealso cref="InitializeSafeJSVarElements,">AddSafeJSVariable, GetSafeJSVariable</seealso>
    public static String GetSafeJSVariableWarn(String strName)
    {
      return JSHelper.GetSafeJSVariableWarn(strName);
    }
    
    /// <param name="strFunctionName"></param>
    /// <returns></returns>
    public static JSFunctionCallBuilder GetJSFunctionCallBuilder(String strFunctionName)
    {
      return new JSFunctionCallBuilder(strFunctionName);
    }
    
    /// <summary>
    /// Returns a new helper object to generate a <c>String</c> with javascript code to declare
    /// a one-dimensional array.  
    /// </summary>
    /// <returns>	JS1DArrayBuilder object.</returns>
    public static JS1DArrayBuilder GetJS1DArrayBuilder()
    {
      return new JS1DArrayBuilder();
    }
    
    /// <summary>
    /// Returns a new helper object to generate a <c>String</c> with javascript code to declare
    /// a two-dimensional array.
    /// </summary>
    /// <param name="nColumnCount">Number of columns in the array.</param>
    /// <returns>JS2DArrayBuilder object.</returns>
    public static JS2DArrayBuilder GetJS2DArrayBuilder(int nColumnCount)
    {
      return new JS2DArrayBuilder(nColumnCount);
    }
    
    /// <summary>
    /// Escapes a string to use with javascript. Escapes characters such as carriage returns,
    /// tabs and < and >.
    /// </summary>
    /// <param name="strJSString"><c>String</c> to escape.</param>
    /// <returns>Escaped string or empty string if provided string is <c>null</c>.</returns>
    public static String EscapeJavaScriptString(String strJSString)
    {
      return JSHelper.escapeJS(strJSString);
    }
    
    /// <summary>
    /// Generates javascript to include  specified jscomponent onto the page. 
    /// </summary>
    /// <param name="strComponentName">
    /// Name of the JSComponent. Constants for the JSComponents are defined in
    /// <c>ConfigHelper</c>.
    /// </param>
    /// <param name="locale">The locale to use in the jscomponent. Will affect language and date/time formats.</param>
    /// <param name="owner">Current Activityspace.</param>
    /// <seealso cref="ConfigHelper"></seealso>
    /// <returns>	<c>HTMLElementCollection</c> with a script element that includes the specified jscomponent. </returns>
    public static HTMLElementCollection GenerateJSComponentInclude(String strComponentName,
     XPLocale locale, AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      return ConfigHelper.GetJSIncluderJSComponentInclude(strComponentName,
       false, owner, locale);
    }
  }
}