using System;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.search.advanced;
using com.plumtree.portalpages.browsing.search.network;
using com.plumtree.portalpages.browsing.search.results;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.editor;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// Search related TaskAPI functions.  
  /// </summary>
  public class TaskAPIUISearch
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.taskapi.portalui.TaskAPIUISearch");
    
    /// <summary>
    /// Gets an URL to the Advanced Search Page.   
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>IPTURL</c> with the URL to the Advanced Search Page.</returns>
    public static IPTURL GetURLForAdvancedSearchPage(AActivitySpace owner)
    {
      String strPageName = owner.GetName();
      if ((XPStringUtility.CompareIgnoreCase(strPageName, SearchResultAS.STR_MVC_CLASS_NAME) != 0) && (XPStringUtility.CompareIgnoreCase(strPageName,
       AdvancedSearchAS.STR_MVC_CLASS_NAME) != 0))
      {
        String strText = owner.GetString(339, "ptmsgs_portalcommonmsgs");
        String strApplBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
        String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
        int nUserID = TaskAPIUIUser.GetCurrentUserID(owner);
        CommonOpenerOpenASURL url = new CommonOpenerOpenASURL(strText, strApplBaseURL,
         AdvancedSearchAS.STR_MVC_CLASS_NAME, nUserID);
        url.AddControlParameter(ASConstants.CONTROL, EditorStartControl.STR_MVC_CLASS_NAME);
        url.AddControlParameter(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
        url.SetURLImageType(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED, strImageServerURL);
        return url;
      } else
      {
        return null;
      }
    }
    
    /// <summary>
    /// Gets an URL to the Federated Search Page
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns><c>IPTURL</c> with the URL to the Federated Search Page.</returns>
    public static IPTURL GetURLForFederatedSearchPage(AActivitySpace owner)
    {
      String strText = owner.GetString(340, "ptmsgs_portalcommonmsgs");
      String strApplBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
      String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
      int nUserID = TaskAPIUIUser.GetCurrentUserID(owner);
      CommonOpenerOpenASURL url = new CommonOpenerOpenASURL(strText, strApplBaseURL,
       NetworkSearchAS.STR_MVC_CLASS_NAME, nUserID);
      url.SetURLImageType(PTImageType.ACTION_SEARCH_BUTTON_NETWORK, strImageServerURL);
      return url;
    }
  }
}