/*
 */
 
using System;
using com.plumtree.openfoundation.internationalization;
using com.plumtree.openfoundation.util;
using com.plumtree.openlog;
using com.plumtree.portalpages.browsing.login;
using com.plumtree.portalpages.browsing.portalsettings;
using com.plumtree.portaluiinfrastructure.login;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.portaluiinfrastructure.statichelpers;
using com.plumtree.server;
using com.plumtree.taskapi.server;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.constants;
using com.plumtree.uiinfrastructure.login;
using com.plumtree.uiinfrastructure.web;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
using Interpreter=com.plumtree.uiinfrastructure.interpreter.Interpreter;
using com.plumtree.xpshared.htmlconstructs;
namespace com.plumtree.taskapi.portalui
{
  /// <summary>
  /// TaskAPI functions for user related URLs and functions, such as getting personal preferences,
  /// getting object ID of current user and checking user access.
  /// </summary>
  public class TaskAPIUIUser
  {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
     "com.plumtree.taskapi.portalui.TaskAPIUIUser");
    
    /// <summary>
    /// Call this method to obtain the value of a personal setting.
    /// <p />
    /// This value will be retrieved from the user's web session if possible,
    /// otherwise the portal server will be queried.
    /// <p />
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="sSettingName">
    /// String name of personal setting as defined in 
    /// <c>com.plumtree.portaluiinfrastructure.login.PersonalSettingNames</c>, null value if the setting does not exist.
    /// </param>
    /// <throws>
    /// XPException This method will throw an <c>XPException</c> if you do not
    /// pass an <c>ISessionManager</c> already containing the correct subSession.  The
    /// <c>ISessionManager</c> obtained from your Activity Space will contain the correct
    /// subsession.
    /// </throws>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    /// <seealso cref="PersonalSettingNames"></seealso>
    public static Object GetPersonalSettingValue(AActivitySpace owner, String sSettingName)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      return PTPersonalSettingsHelper.GetPersonalSettingValue(sSettingName,
       owner);
    }
    
    /// <summary>
    /// Gets the locale set in user's My Account settings for the current user
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns><c>XPLocale</c> with the user's locale.  </returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static XPLocale GetPersonalSettingsLocale(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      String strLocaleID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE,
       owner);
      return new XPLocale(strLocaleID);
    }
    
    /// <summary>
    /// Checks if the current user is a guest user.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns><c>true</c> if the current user is a guest user, <c>false</c> otherwise.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static bool IsCurrentUserGuestUser(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      ISessionManager sessionMan = owner.GetSubSession();
      Object sesValid = sessionMan.GetAttribute(Interpreter.USERSESSIONVALID);
      if (sesValid == null)
      {
        return false;
      }
      bool bIsGuestUser = !XPConvert.ToBoolean(sesValid);
      return bIsGuestUser;
    }
    
    /// <summary>
    /// Gets the object ID of the current user.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>Object ID of the current user.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static int GetCurrentUserID(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
      return TaskAPIServerUser.GetCurrentUserID(ptSession);
    }
    
    /// <summary>
    /// Gets the name of the current user.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>Name of the current user.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static String GetCurrentUserName(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
      return TaskAPIServerUser.GetCurrentUserName(ptSession);
    }
    
    /// <seealso cref="TaskAPIUISubPortal#GetURLForMyHome(AActivitySpace)"></seealso>
    public static IPTURL GetURLForMyHome(AActivitySpace owner)
    {
      return TaskAPIUISubPortal.GetURLForMyHome(owner);
    }
    
    /// <summary>
    /// Gets the URL for the Login/Logoff link. Only one link is shown at any one time. 
    /// The login link appears if the user is not logged in, while the logoff link appears if the user
    /// is already logged in.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>
    /// 	<c>IPTURL</c> with login or logoff URL, or null if the link should not be displayed, for example in
    /// Edit Default Profile or Preview Page mode.
    /// </returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static IPTURL GetURLForLoginLogoff(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      String strText = "";
      CommonOpenerOpenASURL url = null;
      String strApplBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
      String strImageServerURL = TaskAPIUIPortalConfig.GetImageServerBaseURL(owner);
      String strASName = LoginAS.STR_MVC_CLASS_NAME;
      int nUserID = TaskAPIUIUser.GetCurrentUserID(owner);
      if (IsCurrentUserGuestUser(owner))
      {
        // login
        strText = owner.GetString(336, ResourceConstants.PORTALCOMMONMSGS);
        url = new CommonOpenerOpenASURL(strText, strApplBaseURL, strASName,
         nUserID);
        url.AddControlParameter(ASConstants.CONTROL, LoginControl.STR_MVC_CLASS_NAME);
        url.AddControlParameter(LoginHelper.PARAM_LOGIN, "");
      } else
      {
        // Logoff
        if (!TaskAPIUICommon.IsCurrentPageInEditDefaultProfileMode(owner) && !TaskAPIUICommon.IsCurrentPageInPreviewMode(owner))
        {
          strText = owner.GetString(335, ResourceConstants.PORTALCOMMONMSGS);
          url = new CommonOpenerOpenASURL(strText, strApplBaseURL, strASName,
           nUserID);
          url.AddControlParameter(ASConstants.CONTROL, LoginControl.STR_MVC_CLASS_NAME);
          url.AddControlParameter(LoginHelper.PARAM_DOLOGOUT, "");
          url.AddControlParameter(ASConstants.CLEARSESSION, "true");
        }
      }
      if (url != null)
      {
        url.SetURLImageType(PTImageType.ICON_LOGIN, strImageServerURL);
      }
      return url;
    }
    
    /// <summary>
    /// Checks if the current user has access to the specified Activity Right.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <param name="nActivityRightID">An Activity Rights ID defined in  <c>com.plumtree.server.PT_ACTIVITY_RIGHTS</c></param>
    /// <returns><c>true</c> if the user has access to the Activity Right, <c>false</c> otherwise.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    /// <seealso cref="PT_ACTIVITY_RIGHTS"></seealso>
    public static bool HasAccessToActivityRight(AActivitySpace owner, int nActivityRightID)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
      return TaskAPIServerUser.DoesUserHaveAccessToActivityRight(ptSession,
       nActivityRightID);
    }
    
    /// <summary>
    /// This method gets the user's personalized greeting, normally displayed in the Topbar. 
    /// E.g. "Hi Administrator" 
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>String</c> with the user greeting, or if user greeting cannot be retrieved, a default greeting message.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static String GetWelcomeMessage(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
      String strGreeting = null;
      try
      {
        ISessionManager mgrSession = owner.GetSubSession();
        if (mgrSession == null)
        {
          // when a user first hits the login page, no subsession exists.  Use the default greeting
          // in this case.
          strGreeting = owner.GetString(315, ResourceConstants.PORTALCOMMONMSGS);
          } else
        {
          strGreeting = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.GREETING,
           owner);
          if ((strGreeting == null) || "".Equals(strGreeting))
          {
            // use welcome
            strGreeting = XPResourceManager.FormatMessage(owner.GetString(546,
             ResourceConstants.PORTALCOMMONMSGS), TaskAPIServerUser.GetCurrentUserName(ptSession));
            }
        }
      }
      catch (Exception e)
      {
        // TODOCR DONH: This exception should probably get logged.
        // Just use the default greeting
        strGreeting = owner.GetString(315, ResourceConstants.PORTALCOMMONMSGS);
        }
      return strGreeting;
    }
    
    /// <summary>
    /// Checks if the current user is a member of Administrators Group.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the current user is a member of the Administrators Group, <c>false</c> otherwise.</returns>
    public static bool IsCurrentUserAdministrator(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      IPTSession ptSession = TaskAPIUICommon.GetPTSession(owner);
      return TaskAPIServerUser.DoesUserHaveAccessToActivityRight(ptSession,
       PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
    }
    
    /// <summary>
    /// Checks if the link the Administration portal  should display or not. 
    /// The link is displayed in STANDARD mode and only on non-Preview pages.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>	<c>true</c> if the link to Administration Portal should be displayed, <c>false</c> otherwise.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static bool HasAdminLinkAccess(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      return (IsCurrentUserAdministrator(owner) && !TaskAPIUICommon.IsCurrentPageInPreviewMode(owner) && IsAccessStyleStandard(owner));
      }
    
    /// <summary>
    /// Gets the Access Style for the current user. 
    /// The constants for the supported access styles, Standard, Low-bandwidth and Accessibility,
    /// are defined in <c>AccessStyles</c>.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>An <c>AccessStyles</c> constant with the current Access Style mode.</returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    /// <seealso cref="AccessStyles"></seealso>
    public static AccessStyles GetAccessStyle(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      return owner.GetAccessStyle();
    }
    
    /// <summary>
    /// Checks if the Access Style mode for the current user is the Standard style.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>true if the Access Style for the current user is set to <c>AccessStyles.STANDARD</c></returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    /// <seealso cref="AccessStyles"></seealso>
    public static bool IsAccessStyleStandard(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      AccessStyles style = GetAccessStyle(owner);
      return (style == AccessStyles.STANDARD);
    }
    
    /// <summary>
    /// Checks if the Access Style mode for the current user is the Accessibility style.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>true if the Access Style for the current user is set to <c>AccessStyles.SECTION_508</c></returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    /// <seealso cref="AccessStyles"></seealso>
    public static bool IsAccessStyleAccessibility(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      AccessStyles style = GetAccessStyle(owner);
      return (style == AccessStyles.SECTION_508);
    }
    
    /// <summary>
    /// Checks if the Access Style mode for the current user is the Low-bandwidth style.
    /// </summary>
    /// <param name="owner">Current Activityspace.</param>
    /// <returns>true if the Access Style for the current user is set to <c>AccessStyles.LOW_BANDWIDTH</c></returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    /// <seealso cref="AccessStyles"></seealso>
    public static bool IsAccessStyleLowBandwidth(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      AccessStyles style = GetAccessStyle(owner);
      return (style == AccessStyles.LOW_BANDWIDTH);
    }
    
    /// <summary>
    /// Gets the URL to the My Account settings page, where user's can edit their Portal setttings.
    /// </summary>
    /// <param name="owner">Current Activity space.</param>
    /// <returns>
    /// <c>IPTURL</c> with the URL to user's My Account settings page, or <c>null</c> value 
    /// if the URL is not applicable for the current user or page.
    /// </returns>
    /// <throws><c>XPIllegalArgumentException</c> if the provided <c>AActivityspace</c> is <c>null</c> or not valid.</throws>
    public static IPTURL GetURLForMyAccountPage(AActivitySpace owner)
    {
      TaskAPIUICommon.ValidateActivitySpaceArgument(owner);
      CommonOpenerOpenASURL url = null;
      if (!IsCurrentUserGuestUser(owner) && !TaskAPIUICommon.IsCurrentPageInPreviewMode(owner))
      {
        String strText = owner.GetString(296, "ptmsgs_portalcommonmsgs");
        String strApplBaseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner);
        String strASName = PortalSettingsAS.STR_MVC_CLASS_NAME;
        int nUserID = GetCurrentUserID(owner);
        url = new CommonOpenerOpenASURL(strText, strApplBaseURL, strASName,
         nUserID);
      }
      return url;
    }
  }
}