using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.admin.editors.user;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.server.mock.properties;
using com.plumtree.server.mock.users;
using junit.framework;
namespace com.plumtree.portalpages.test.admin.editors.user
{
  public class UserModelTest : TestCase
  {
    public const int USER_ID = 57;
    protected UserModel m_model;
    protected MockEnvironment m_space = null;
    protected MockPTSession m_userSession = null;
    protected MockPTSession m_impersonatedSession = null;
    protected MockPTServerConfigSettings m_serverConfigSettings = null;
    protected MockPTUserManager m_users = null;
    protected MockPTUser m_user = null;
    /*
     * @see junit.framework.TestCase#setUp()
     */
     
    public override void setUp()
    {
      m_model = new UserModel();
      m_space = new MockEnvironment();
      m_userSession = new MockPTSession();
      m_space.SetUserSession(m_userSession);
      m_model.Init(m_space);
      m_impersonatedSession = (MockPTSession) m_userSession.ImpersonateUser(1);
      m_serverConfigSettings = (MockPTServerConfigSettings) m_userSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
       true);
      m_user = new MockPTUser();
      m_users = (MockPTUserManager) m_impersonatedSession.GetUsers();
      m_users.m_htObjects.PutElement(USER_ID, m_user);
      // Default settings - disabled
      m_serverConfigSettings.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION,
       0);
    }
    /*
     * @see junit.framework.TestCase#tearDown()
     */
     
    public override void tearDown()
    {
      m_model = null;
      m_space = null;
      m_userSession = null;
      m_serverConfigSettings = null;
      m_users = null;
      m_user = null;
    }
    public virtual void testPasswordExpiration()
    {
      // Set the password expiration to a small value - 10
      checkExpiration(10);
    }
    
    /// <summary>
    /// If you accidentally do integer arithmetic instead of long arithmetic
    /// when calculating the expiration time in milliseconds, you can cause
    /// the data to wrap.
    /// </summary>
    public virtual void testLongArithmeticBug()
    {
      // Set the password expiration to a large value that will trigger the
      // arithmetic error.
      checkExpiration(180);
    }
    protected virtual void checkExpiration(int _nDays)
    {
      m_serverConfigSettings.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_EXPIRATION,
       _nDays);
      m_model.ExpirePassword(USER_ID);
      MockPTObjectProperties props = m_user.m_properties;
      Object oLastPasswordChange = props.m_properties.GetElement(PT_INTRINSICS.PT_PASSWORD_LAST_CHANGED);
      long lLastPasswordChange = XPConvert.ToLong(oLastPasswordChange);
      // convert expiration from days to ms
      long lPasswordExpiration = _nDays * (long) (1000 * 60 * 60 * 24);
      // This is the formula we use to expire passwords in the UserModel
      long expectedTime = (XPSystem.GetCurrentTimeMilliSec() - (lPasswordExpiration * 10));
      assertTrue("Checking for value range for password change: " + lLastPasswordChange + ", expected to be around " + expectedTime,
       lLastPasswordChange > 0 && lLastPasswordChange > (expectedTime - 10000) && lLastPasswordChange < (expectedTime + 10000));
      }
  }
}