using System;
using junit.framework;
using com.plumtree.portalpages.browsing.directory.rest;
using com.plumtree.portalpages.browsing.mock.directory;
using com.plumtree.portalpages.rest.utils;
namespace com.plumtree.portalpages.test.browsing.directory.rest
{
  /// <summary>
  /// This tests parsing the incoming JSON payload and setting the
  /// correct data on the model.
  /// </summary>
  public class DirRESTControlTest : TestCase
  {
    public virtual void testProcessSimpleSubmitWithNameAndDesc()
    {
      String strJSON = "{ \"document\": {" + "\"name\": \"test\"," + "\"description\": \"test test\"," + "\"datasourceid\": \"456\"," + "\"contenturl\": \"www.oracle.com\"" + "} }";
      DirRESTControl control = new DirRESTControl();
      MockDirModel model = new MockDirModel();
      control.Init(model, null);
      assertFalse("Card should not be submitted by default.", model.m_bCardSubmitted);
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strJSON);
      control.ProcessAction(parser, 123);
      assertEquals("Incorrect name set on model.", "test", model.GetCardName());
      assertEquals("Incorrect description set on model.", "test test", model.m_strCardSubmitDescription);
      assertEquals("Incorrect data source ID set on model.", 456, model.GetCardSubmitDataSource());
      assertEquals("Incorrect content URL set on model.", "www.oracle.com",
       model.m_strCardSubmitURL);
      assertTrue("Card should be submitted after processing.", model.m_bCardSubmitted);
      }
    public virtual void testProcessSimpleSubmitWithoutNameAndDesc()
    {
      // This is used when the portal should automatically generate the name
      // and description.
      String strJSON = "{ \"document\": {" + "\"datasourceid\": \"456\"," + "\"contenturl\": \"www.oracle.com\"" + "} }";
      DirRESTControl control = new DirRESTControl();
      MockDirModel model = new MockDirModel();
      control.Init(model, null);
      assertFalse("Card should not be submitted by default.", model.m_bCardSubmitted);
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strJSON);
      control.ProcessAction(parser, 123);
      assertNull("No name should be present on model.", model.GetCardName());
      assertNull("No description should be present on model.", model.m_strCardSubmitDescription);
      assertEquals("Incorrect data source ID set on model.", 456, model.GetCardSubmitDataSource());
      assertEquals("Incorrect content URL set on model.", "www.oracle.com",
       model.m_strCardSubmitURL);
      assertTrue("Card should be submitted after processing.", model.m_bCardSubmitted);
      }
    public virtual void testProcessWebServiceSubmit()
    {
      String strJSON = "{ \"document\": {" + "\"name\": \"test\"," + "\"description\": \"test test\"," + "\"datasourceid\": \"456\"," + "\"contenturl\": \"www.oracle.com\"," + "\"type\": \"1111\"," + "\"docid\": \"1234\"," + "\"serverid\": \"4567\"" + "} }";
      DirRESTControl control = new DirRESTControl();
      MockDirModel model = new MockDirModel();
      control.Init(model, null);
      assertFalse("Card should not be submitted by default.", model.m_bCardSubmitted);
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strJSON);
      control.ProcessAction(parser, 123);
      assertEquals("Incorrect name set on model.", "test", model.GetCardName());
      assertEquals("Incorrect description set on model.", "test test", model.m_strCardSubmitDescription);
      assertEquals("Incorrect data source ID set on model.", 456, model.GetCardSubmitDataSource());
      assertEquals("Incorrect content URL set on model.", "www.oracle.com",
       model.m_strCardSubmitURL);
      assertEquals("Incorrect type set on model.", "1111", model.m_strDocUploadType);
      assertEquals("Incorrect doc ID set on model.", "1234", model.m_strDocUploadID);
      assertEquals("Incorrect server ID set on model.", "4567", model.m_strDocUploadServerID);
      assertTrue("Card should be submitted after processing.", model.m_bCardSubmitted);
      }
    public virtual void testError()
    {
    }
  }
}
//		String strJSON = "garbage";
// TODO: test that this sets an error on the model and redirects to the correct page.
