using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.browsing.directory;
using com.plumtree.portalpages.browsing.directory.rest;
using com.plumtree.portalpages.browsing.mock.directory;
using com.plumtree.portalpages.rest;
using com.plumtree.portalpages.rest.utils;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.mock.uiinfrastructure;
namespace com.plumtree.portalpages.test.browsing.directory.rest
{
  /// <summary>
  /// This tests the formatting of the JSON output from the REST API.
  /// </summary>
  public class DirRESTDPTest : TestCase
  {
    public MockEnvironment m_environment = new MockEnvironment();
    public MockDirModel m_model = new MockDirModel();
    public DirRESTDP m_page = new DirRESTDP();
    public override void setUp()
    {
      // This will probably log an error, but it will init what we want.
      m_environment.Init();
      m_environment.m_models.PutElement(DirModel.STR_MVC_CLASS_NAME, m_model);
      m_environment.RegisterPage(m_page);
    }
    public virtual void testSuccess()
    {
      m_model.m_nCardID = 534;
      m_model.m_strCardName = "my test";
      m_model.m_nCardSubmitFolder = 1212;
      m_model.SetFolderPath(m_model.m_nCardSubmitFolder, "test\\mytest\\test");
      MockWebData output = new MockWebData();
      m_page.Display(output);
      String strOutput = output.m_strData;
      assertNotNull("Page output should be non-null.", strOutput);
      assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.StartsWith(strOutput,
       "/*"));
      assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.EndsWith(strOutput,
       "*/"));
      // The parser can handle comment-filtered JSON.
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strOutput);
      assertEquals("Unexpected JSON object name.", DirRESTConstants.DOCUMENT_FORMAT_NAME,
       parser.GetObjectName());
      assertEquals("Unexpected document name.", "my test", parser.GetMember(DirRESTConstants.DOCUMENT_NAME));
      assertEquals("Unexpected document id.", "534", parser.GetMember(DirRESTConstants.DOCUMENT_OBJECT_ID));
      assertEquals("Unexpected document folder ID.", "1212", parser.GetMember(DirRESTConstants.DOCUMENT_FOLDER_ID));
      assertEquals("Unexpected document folder path.", "test\\mytest\\test",
       parser.GetMember(DirRESTConstants.DOCUMENT_FOLDER_PATH));
    }
    public virtual void testError()
    {
      m_model.m_nCardSubmitError = CommonRestErrors.GENERAL.GetCode();
      MockWebData output = new MockWebData();
      m_page.Display(output);
      String strOutput = output.m_strData;
      assertNotNull("Page output should be non-null.", strOutput);
      assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.StartsWith(strOutput,
       "/*"));
      assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.EndsWith(strOutput,
       "*/"));
      // The parser can handle comment-filtered JSON.
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strOutput);
      assertEquals("Unexpected JSON object name.", RESTErrorConstants.ERROR_FORMAT_NAME,
       parser.GetObjectName());
      assertEquals("Unexpected error text.", CommonRestErrors.GENERAL.GetMessage(),
       parser.GetMember(RESTErrorConstants.ERROR_TEXT));
      assertEquals("Unexpected error code.", XPConvert.ToString(CommonRestErrors.GENERAL.GetCode()),
       parser.GetMember(RESTErrorConstants.ERROR_CODE));
    }
    public virtual void testJSEscaping()
    {
      m_model.m_nCardID = 534;
      m_model.m_strCardName = "Card in folder test\\test\\test";
      m_model.m_nCardSubmitFolder = 13214;
      m_model.SetFolderPath(m_model.m_nCardSubmitFolder, "test\\othertest\\test");
      MockWebData output = new MockWebData();
      m_page.Display(output);
      String strOutput = output.m_strData;
      assertNotNull("Page output should be non-null.", strOutput);
      // NOTE: The parser will unescape \'s, so we should check for a single slash in the
      // parsed object, but a double slash in the actual string.
      assertTrue("String data should have escaped slashes in name.", XPStringUtility.IndexOf(strOutput,
       "Card in folder test\\\\test\\\\test") >= 0);
      assertTrue("String data should have escaped slashes in folder path.",
       XPStringUtility.IndexOf(strOutput, "test\\\\othertest\\\\test") >= 0);
      // The parser can handle comment-filtered JSON.
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strOutput);
      assertEquals("Unexpected JSON object name.", DirRESTConstants.DOCUMENT_FORMAT_NAME,
       parser.GetObjectName());
      assertEquals("Document name should be JavaScript normal (i.e. escaped, then unescaped).",
       "Card in folder test\\test\\test", parser.GetMember(DirRESTConstants.DOCUMENT_NAME));
      assertEquals("Document folder path should be normal (i.e. escaped, then unescaped).",
       "test\\othertest\\test", parser.GetMember(DirRESTConstants.DOCUMENT_FOLDER_PATH));
      }
    public virtual void testJSONAttack()
    {
      m_model.m_nCardID = 534;
      m_model.m_strCardName = "my test hack\"}} alert(\'hack\');";
      MockWebData output = new MockWebData();
      m_page.Display(output);
      String strOutput = output.m_strData;
      assertNotNull("Page output should be non-null.", strOutput);
      assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.StartsWith(strOutput,
       "/*"));
      assertTrue("Comment filtered JSON should start with /*.", XPStringUtility.EndsWith(strOutput,
       "*/"));
      // The parser can handle comment-filtered JSON.
      IJSONParser parser = JSONParser.GetInstance();
      parser.ParseJSONObject(strOutput);
      assertEquals("Unexpected JSON object name.", DirRESTConstants.DOCUMENT_FORMAT_NAME,
       parser.GetObjectName());
      assertEquals("Document name should be HTML encoded for safety.", "my test hack&quot;}} alert(\'hack\');",
       parser.GetMember(DirRESTConstants.DOCUMENT_NAME));
      assertEquals("Unexpected document id.", "534", parser.GetMember(DirRESTConstants.DOCUMENT_OBJECT_ID));
      }
  }
}
// TODO: folder ID and folder path
