using System;
using junit.framework;
using com.plumtree.openfoundation.mockobjects;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using com.plumtree.portalpages.browsing.myportal;
using com.plumtree.portalpages.browsing.myportal.mypages;
using com.plumtree.portaluiinfrastructure.statichelpers;
using IPTPage=com.plumtree.server.IPTPage;
using IPTQueryResult=com.plumtree.server.IPTQueryResult;
using PT_PROPIDS=com.plumtree.server.PT_PROPIDS;
using com.plumtree.server.mock.community;
using com.plumtree.server.mock.core;
using com.plumtree.server.mock.portlet;
using com.plumtree.uiinfrastructure.activityspace;
using com.plumtree.uiinfrastructure.web;
namespace com.plumtree.portalpages.test.browsing.myportal
{
  public class MyPortalModelTest : TestCase
  {
    public const int PAGE_ID = 8924;
    public const int PORTLET_ID_ONE = 123;
    public const int PORTLET_ID_TWO = 765;
    public const int PORTLET_ID_THREE = 888;
    public const int PORTLET_BUNDLE_ID = 925;
    protected AActivitySpace m_asOwner;
    protected MyPortalModel m_model;
    protected MockPTSession m_userSession;
    protected ISessionManager m_subSession;
    protected MockPTPage m_page;
    /*
     * @see junit.framework.TestCase#setUp()
     */
     
    public override void setUp()
    {
      m_model = new MyPortalModel();
      m_asOwner = new MyPageAS();
      m_subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
      m_subSession.SetAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG,
       "true");
      m_asOwner.SetPersistentSubSession(m_subSession);
      m_userSession = new MockPTSession();
      m_asOwner.SetUserSession(m_userSession);
      MockPTObjectManager mockPageManager = (MockPTObjectManager) m_userSession.GetPages();
      // Setup the base page for all model calls
      m_page = new MockPTPage();
      // add page to page manager so that it can be found later
      mockPageManager.m_htObjects.PutElement(PAGE_ID, m_page);
      m_model.Init(m_asOwner);
      IXPRequest request = null;
      try
      {
        request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/mypage/home_page/");
        m_asOwner.SetCurrentHTTPRequestResponseObjects(request, null);
      }
      catch (XPException ex)
      {
        ex.PrintStackTrace();
      }
    }
    /*
     * @see junit.framework.TestCase#tearDown()
     */
     
    public override void tearDown()
    {
      m_model = null;
      m_asOwner = null;
      m_subSession = null;
      m_userSession = null;
      m_page = null;
    }
    
    /// <summary>
    /// This tests adding a recently added portlet to the list.
    /// NOTE: This doesn't actually test adding the portlet, just
    /// adding it to the recently added portlet list. 
    /// </summary>
    public virtual void testRecentlyAddedPortletList()
    {
      // Setup 1 portlet
      MockPTObjectManager portletManager = (MockPTObjectManager) m_userSession.GetGadgets();
      portletManager.m_htObjects.PutElement(PORTLET_ID_ONE, new MockPTPortlet());
      XPArrayList portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists at start.",
       portlets);
      Assert.assertEquals("Checking that portlet list is empty at start.",
       0, portlets.GetSize());
      m_model.AddSinglePortlet(PAGE_ID, PORTLET_ID_ONE);
      portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists.", portlets);
      Assert.assertEquals("Checking that portlet list has one item.", 1, portlets.GetSize());
      Assert.assertEquals("Checking that proper portlet got added.", PORTLET_ID_ONE,
       XPConvert.ToInteger(portlets.GetElement(0)));
      m_model.ResetRecentlyAddedPortlets();
      portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists after reset.",
       portlets);
      Assert.assertEquals("Checking that portlet list is empty after reset.",
       0, portlets.GetSize());
    }
    
    /// <summary>
    /// This tests adding a recently remove portlet to the variable.
    /// NOTE: This doesn't actually test removing the portlet, just
    /// adding it to the recently added portlet variable. 
    /// </summary>
    public virtual void testRecentlyRemovedPortlet()
    {
      Assert.assertEquals("Checking that removed portlet is 0 at start.",
       0, m_model.GetRecentlyRemovedPortlet());
      m_model.RemoveSinglePortlet(PAGE_ID, PORTLET_ID_ONE);
      Assert.assertEquals("Checking that proper portlet got removed.", PORTLET_ID_ONE,
       m_model.GetRecentlyRemovedPortlet());
      m_model.ResetRecentlyRemovedPortlet();
      Assert.assertEquals("Checking that removed portlet got reset.", 0, m_model.GetRecentlyRemovedPortlet());
      }
    
    /// <summary>
    /// This tests loading a bundle, checking it against the current
    /// portlets on the page, and then putting the new ones in the
    /// recently added list.
    /// NOTE: This doesn't actually test adding the portlet bundle, just
    /// adding its portlets to the recently added portlet list. 
    /// </summary>
    public virtual void testAddingPortletBundle()
    {
      // Setup 2 portlets
      MockPTObjectManager portletManager = (MockPTObjectManager) m_userSession.GetGadgets();
      portletManager.m_htObjects.PutElement(PORTLET_ID_ONE, new MockPTPortlet());
      portletManager.m_htObjects.PutElement(PORTLET_ID_TWO, new MockPTPortlet());
      // Setup 1 portlet on page (portlet one)
      m_page.m_gadgetQueryData = new Object[][]{new Object[]{PORTLET_ID_ONE,
       "test1"}};
      // Setup a bundle with 2 portlets
      setupBundle();
      XPArrayList portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists at start.",
       portlets);
      Assert.assertEquals("Checking that portlet list is empty at start.",
       0, portlets.GetSize());
      m_model.AddPortletBundle(PAGE_ID, PORTLET_BUNDLE_ID);
      // Check if portlet was actually added to the page.
      XPArrayList addedPortlets = m_page.m_addedPortlets;
      Assert.assertNotNull("Checking that portlets were added to the page (list exists).",
       addedPortlets);
      Assert.assertEquals("Checking that one portlet was added to the page.",
       1, addedPortlets.GetSize());
      Assert.assertEquals("Checking that only portlet 2 got added to the page since portlet 1 was already on the page.",
       PORTLET_ID_TWO, XPConvert.ToInteger(addedPortlets.GetElement(0)));
      // Check if portlet was added to the recent portlet list.
      portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists.", portlets);
      Assert.assertEquals("Checking that portlet list has one item.", 1, portlets.GetSize());
      Assert.assertEquals("Checking that only portlet 2 got added since portlet 1 was already on the page.",
       PORTLET_ID_TWO, XPConvert.ToInteger(portlets.GetElement(0)));
      m_model.ResetRecentlyAddedPortlets();
      portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists after reset.",
       portlets);
      Assert.assertEquals("Checking that portlet list is empty after reset.",
       0, portlets.GetSize());
    }
    
    /// <summary>
    /// This tests converting a portlet bundle into an int[] of portlet IDs.
    /// </summary>
    public virtual void testLoadingPortletBundle()
    {
      // Setup a bundle with 2 portlets
      setupBundle();
      int[] portlets = m_model.GetPortletsInBundle(PORTLET_BUNDLE_ID, false);
      Assert.assertEquals("Checking that portlet list has two items.", 2,
       portlets.Length);
      Assert.assertEquals("Checking first portlet ID.", PORTLET_ID_ONE, portlets[0]);
      Assert.assertEquals("Checking second portlet ID.", PORTLET_ID_TWO, portlets[1]);
      }
    
    /// <summary>
    /// This tests adding a portlet to a page. Verifies page has the correct portlet after adding.
    /// </summary>
    public virtual void testAddSinglePortlet()
    {
      // Setup 1 portlet
      MockPTObjectManager portletManager = (MockPTObjectManager) m_userSession.GetGadgets();
      portletManager.m_htObjects.PutElement(PORTLET_ID_ONE, new MockPTPortlet());
      MockPTPage ptPage = (MockPTPage) m_userSession.GetPages().Open(PAGE_ID,
       false);
      XPArrayList portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists at start.",
       portlets);
      Assert.assertEquals("Checking that portlet list is empty at start.",
       0, portlets.GetSize());
      Assert.assertEquals("Checking that page is empty at start.", 0, ptPage.m_addedPortlets.GetSize());
      m_model.AddSinglePortlet(PAGE_ID, PORTLET_ID_ONE);
      portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists.", portlets);
      Assert.assertEquals("Checking that portlet list has one item.", 1, portlets.GetSize());
      Assert.assertEquals("Checking that proper portlet got added.", PORTLET_ID_ONE,
       XPConvert.ToInteger(portlets.GetElement(0)));
      Assert.assertEquals("Checking that proper portlet got added into page.",
       PORTLET_ID_ONE, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(0)));
      }
    
    /// <summary>
    /// This tests removing a portlet from a page. Verifies page content after removing
    /// </summary>
    public virtual void testRemoveSinglePortlet()
    {
      // Setup 1 portlet and add it to the page
      MockPTObjectManager portletManager = (MockPTObjectManager) m_userSession.GetGadgets();
      portletManager.m_htObjects.PutElement(PORTLET_ID_ONE, new MockPTPortlet());
      MockPTPage ptPage = (MockPTPage) m_userSession.GetPages().Open(PAGE_ID,
       false);
      m_model.AddSinglePortlet(PAGE_ID, PORTLET_ID_ONE);
      XPArrayList portlets = m_model.GetRecentlyAddedPortlets();
      Assert.assertNotNull("Checking that portlet list exists at start.",
       portlets);
      Assert.assertEquals("Checking that portlet list has one portlet at start.",
       1, portlets.GetSize());
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_ONE + " at start.",
       PORTLET_ID_ONE, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(0)));
      m_model.RemoveSinglePortlet(PAGE_ID, PORTLET_ID_ONE);
      int removedPortlet = m_model.GetRecentlyRemovedPortlet();
      Assert.assertNotNull("Checking that portlet list exists.", portlets);
      Assert.assertEquals("Checking that proper portlet got removed.", PORTLET_ID_ONE,
       removedPortlet);
      Assert.assertEquals("Checking that page has zero portlets.", 0, XPConvert.ToInteger(ptPage.m_addedPortlets.GetSize()));
      }
    
    /// <summary>
    /// This tests reordering of portlets in a region on the specified page. Verifies page content after reordering.
    /// Note: Test currently is limited to testing first region in the page.
    /// TODO: Update MockPTPage to handle regions
    /// </summary>
    public virtual void testReassignPortlets()
    {
      // Setup 3 portlets and add it to the page
      MockPTObjectManager portletManager = (MockPTObjectManager) m_userSession.GetGadgets();
      portletManager.m_htObjects.PutElement(PORTLET_ID_ONE, new MockPTPortlet());
      MockPTPage ptPage = (MockPTPage) m_userSession.GetPages().Open(PAGE_ID,
       false);
      m_model.AddSinglePortlet(PAGE_ID, PORTLET_ID_ONE);
      m_model.AddSinglePortlet(PAGE_ID, PORTLET_ID_TWO);
      m_model.AddSinglePortlet(PAGE_ID, PORTLET_ID_THREE);
      Assert.assertEquals("Checking that page has three portlets at start.",
       3, ptPage.m_addedPortlets.GetSize());
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_ONE + " at index 0.",
       PORTLET_ID_ONE, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(0)));
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_TWO + " at index 1.",
       PORTLET_ID_TWO, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(1)));
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_THREE + " at index 2.",
       PORTLET_ID_THREE, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(2)));
      // Test reordering of portlets in region 0.
      int[] arrPortletIDs = {PORTLET_ID_TWO, PORTLET_ID_THREE, PORTLET_ID_ONE};
      m_model.ReassignPortlets(arrPortletIDs, 0, PAGE_ID);
      Assert.assertEquals("Checking that page still has three portlets after reordering.",
       3, ptPage.m_addedPortlets.GetSize());
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_TWO + " at index 0.",
       PORTLET_ID_TWO, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(0)));
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_THREE + " at index 1.",
       PORTLET_ID_THREE, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(1)));
      Assert.assertEquals("Checking that page has portlet " + PORTLET_ID_ONE + " at index 2.",
       PORTLET_ID_ONE, XPConvert.ToInteger(ptPage.m_addedPortlets.GetElement(2)));
      }
    
    /// <summary>
    /// This sets up a portlet bundle with 2 portlets.
    /// </summary>
    public virtual void setupBundle()
    {
      MockPTPortletBundle bundle = new MockPTPortletBundle();
      // id, name
      bundle.m_gadgetQueryData = new Object[][]{new Object[]{PORTLET_ID_ONE,
       "test1"}, new Object[]{PORTLET_ID_TWO, "test2"}};
      MockPTObjectManager portletBundleManager = (MockPTObjectManager) m_userSession.GetGadgetBundles();
      portletBundleManager.m_htObjects.PutElement(PORTLET_BUNDLE_ID, bundle);
      }
  }
}