using System;
using XPRequestSimulator=com.plumtree.openfoundation.mockobjects.XPRequestSimulator;
using XPSessionSimulator=com.plumtree.openfoundation.mockobjects.XPSessionSimulator;
using com.plumtree.openfoundation.util;
using com.plumtree.openfoundation.web;
using MockMyPortalModel=com.plumtree.portalpages.browsing.mock.myportal.MockMyPortalModel;
using ReorderPortletsControl=com.plumtree.portalpages.browsing.myportal.ReorderPortletsControl;
using SetPageControl=com.plumtree.portalpages.browsing.myportal.SetPageControl;
using MyPageAS=com.plumtree.portalpages.browsing.myportal.mypages.MyPageAS;
using PlumtreeHelpers=com.plumtree.portaluiinfrastructure.statichelpers.PlumtreeHelpers;
using MockPTSession=com.plumtree.server.mock.core.MockPTSession;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using ISessionManager=com.plumtree.uiinfrastructure.web.ISessionManager;
using SessionManagerFactory=com.plumtree.uiinfrastructure.web.SessionManagerFactory;
using junit.framework;
using TestCase=junit.framework.TestCase;
namespace com.plumtree.portalpages.test.browsing.myportal
{
  /// <summary>
  /// This class tests reordering portlets via the ReoderPortletsControl
  /// In general, the tests will use a MockMyPortalModel for interaction between
  /// the control and the model and verify the results.
  /// </summary>
  /// <author>btse</author>
  public class ReorderPortletsControlTest : TestCase
  {
    protected int nCommunityId = 200;
    protected int nPageId = 300;
    protected ReorderPortletsControl testObject = null;
    protected AActivitySpace asParent = null;
    protected MockPTSession userSession = null;
    protected MockMyPortalModel myPortalModel = null;
    public ISessionManager subSession = null;
    public ReorderPortletsControlTest(String name) : base(name)
    {
    }
    /*
     * @see junit.framework.TestCase#setUp()
     */
     
    public override void setUp()
    {
      testObject = new ReorderPortletsControl();
      asParent = new MyPageAS();
      subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
      subSession.SetAttribute(PlumtreeHelpers.DPROFILE_EDITOR_SESSION_FLAG,
       "true");
      asParent.SetPersistentSubSession(subSession);
      userSession = new MockPTSession();
      asParent.SetUserSession(userSession);
      myPortalModel = new MockMyPortalModel(3);
      testObject.Init(myPortalModel, asParent);
      IXPRequest request = null;
      try
      {
        request = XPRequestSimulator.CreateGET("http://localhost/portal/server.pt/mypage/home_page/");
        asParent.SetCurrentHTTPRequestResponseObjects(request, null);
      }
      catch (XPException ex)
      {
        ex.PrintStackTrace();
      }
    }
    /*
     * @see junit.framework.TestCase#tearDown()
     */
     
    public override void tearDown()
    {
      testObject = null;
      asParent = null;
      subSession = null;
      userSession = null;
      myPortalModel = null;
    }
    
    /// <summary>
    /// This method tests calling the ReorderPortletsControl to update the portlets in a 
    /// column (region) and verifying the results in the model.
    /// This method will test the following cases:
    /// (1) Reordering of portlets in same column.
    /// (2) Reordering of portlets between columns.
    /// </summary>
    public virtual void testReorderPortletsControl()
    {
      // Add in some initial portlets to the model before testing the control.
      myPortalModel.AddSinglePortlet(nPageId, 1);
      myPortalModel.AddSinglePortlet(nPageId, 2);
      myPortalModel.AddSinglePortlet(nPageId, 3);
      Assert.assertEquals("Portlet count is incorrect.", 3, myPortalModel.GetPortletCount());
      Assert.assertEquals("First Portlet in Column 0 is incorrect.", 1, myPortalModel.GetFirstPortletIndexInColumn(0));
      Assert.assertEquals("Last Portlet in Column 0 is incorrect.", 3, myPortalModel.GetLastPortletIndexInColumn(0));
      // Reorder portlets in the column 0
      String strSourcePortletIDs = "1_2_3";
      String strTargetPortletIDs = "3_2_1";
      XPHashtable htArgs = new XPHashtable();
      htArgs.PutElement(SetPageControl.STR_PAGE_ID, new String[]{XPConvert.ToString(nPageId)});
      htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION, new String[]{XPConvert.ToString(0)});
      htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION_PORTLET_LIST,
       new String[]{strSourcePortletIDs});
      htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION, new String[]{XPConvert.ToString(0)});
      htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION_PORTLET_LIST,
       new String[]{strTargetPortletIDs});
      testObject.CheckActionSecurityAndExecute(htArgs);
      Assert.assertEquals("First Portlet in Column 0 is incorrect.", 3, myPortalModel.GetFirstPortletIndexInColumn(0));
      Assert.assertEquals("Last Portlet in Column 0 is incorrect.", 1, myPortalModel.GetLastPortletIndexInColumn(0));
      // Reorder portlets from column 0 to column 1
      myPortalModel.ResetPortletColumns();
      Assert.assertEquals("Portlet count is incorrect.", 0, myPortalModel.GetPortletCount());
      strSourcePortletIDs = "";
      strTargetPortletIDs = "1_2_3";
      htArgs = new XPHashtable();
      htArgs.PutElement(SetPageControl.STR_PAGE_ID, new String[]{XPConvert.ToString(nPageId)});
      htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION, new String[]{XPConvert.ToString(0)});
      htArgs.PutElement(ReorderPortletsControl.STR_SOURCE_REGION_PORTLET_LIST,
       new String[]{strSourcePortletIDs});
      htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION, new String[]{XPConvert.ToString(1)});
      htArgs.PutElement(ReorderPortletsControl.STR_TARGET_REGION_PORTLET_LIST,
       new String[]{strTargetPortletIDs});
      testObject.CheckActionSecurityAndExecute(htArgs);
      Assert.assertEquals("Portlet count is incorrect.", 3, myPortalModel.GetPortletCount());
      Assert.assertEquals("First Portlet in Column 0 is incorrect.", -1, myPortalModel.GetFirstPortletIndexInColumn(0));
      Assert.assertEquals("Last Portlet in Column 0 is incorrect.", -1, myPortalModel.GetLastPortletIndexInColumn(0));
      Assert.assertEquals("First Portlet in Column 1 is incorrect.", 1, myPortalModel.GetFirstPortletIndexInColumn(1));
      Assert.assertEquals("Last Portlet in Column 1 is incorrect.", 3, myPortalModel.GetLastPortletIndexInColumn(1));
      }
  }
}