using System;
using Assert=junit.framework.Assert;
using TestCase=junit.framework.TestCase;
using XPSessionSimulator=com.plumtree.openfoundation.mockobjects.XPSessionSimulator;
using XPHashtable=com.plumtree.openfoundation.util.XPHashtable;
using XPStringUtility=com.plumtree.openfoundation.util.XPStringUtility;
using XPSystem=com.plumtree.openfoundation.util.XPSystem;
using EnsembleHandlerControl=com.plumtree.portalpages.browsing.sso.ensemble.EnsembleHandlerControl;
using PTConfigService=com.plumtree.portaluiinfrastructure.helpers.PTConfigService;
using MockApplicationManager=com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockApplicationManager;
using MockConfigVarPack=com.plumtree.portaluiinfrastructure.mock.friendlyurl.MockConfigVarPack;
using MockPTConfigHelper=com.plumtree.portaluiinfrastructure.mock.helper.MockPTConfigHelper;
using MockEnvironment=com.plumtree.portaluiinfrastructure.mock.tags.MockEnvironment;
using com.plumtree.server;
using com.plumtree.server.mock;
using MockPTSession=com.plumtree.server.mock.core.MockPTSession;
using AActivitySpace=com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
using ASConstants=com.plumtree.uiinfrastructure.activityspace.ASConstants;
using Redirect=com.plumtree.uiinfrastructure.activityspace.Redirect;
using AppConstants=com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
using ConfigConstants=com.plumtree.uiinfrastructure.application.varpacks.ConfigConstants;
using ConfigVarPack=com.plumtree.uiinfrastructure.application.varpacks.ConfigVarPack;
using HttpUtils=com.plumtree.uiinfrastructure.statichelpers.HttpUtils;
using Application=com.plumtree.uiinfrastructure.web.Application;
using ApplicationManager=com.plumtree.uiinfrastructure.web.ApplicationManager;
using IApplication=com.plumtree.uiinfrastructure.web.IApplication;
using ISessionManager=com.plumtree.uiinfrastructure.web.ISessionManager;
using SessionManagerFactory=com.plumtree.uiinfrastructure.web.SessionManagerFactory;
namespace com.plumtree.portalpages.test.browsing.sso.ensemble
{
  /// <summary>
  /// This class tests Ensemble SSO redirect functionality, It tests various cases of 
  /// the redirect url being properly generated by WCI when Ensemble sends SSO request
  /// In general, the tests will use a MockMyPortalModel for interaction between
  /// the control and the model and verify the results.
  /// </summary>
  /// <author>Ravi Tunuguntla</author>
  public class EnsembleHandlerControlTest : TestCase
  {
    public const String MOCK_ENSEMBLE_TOKEN = "0|fAkEeNsEmBlEtOKeN";
    protected EnsembleHandlerControl testObject = null;
    protected XPHashtable testArgs = null;
    protected AActivitySpace asParent = null;
    protected MockPTSession userSession = null;
    public ISessionManager subSession = null;
    public MockPTConfigHelper m_helper;
    private String testURL;
    private MockConfigVarPack varPack;
    
    /// <param name="name"></param>
    public EnsembleHandlerControlTest(String name) : base(name)
    {
    }
    /*
     * @see junit.framework.TestCase#setUp()
     */
     
    public override void setUp()
    {
      IApplication application = new Application("", "");
      ApplicationManager.SetTestInstance(new MockApplicationManager());
      ((MockApplicationManager) ApplicationManager.GetInstance()).SetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString(),
       application);
      m_helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(m_helper);
      testObject = new EnsembleHandlerControl();
      asParent = new MockEnvironment();
      // Init Mock ConfigVarPack
      if (XPSystem.IsRunningInDotNet())
      {
        varPack = new MockConfigVarPack(ConfigVarPack.APP_PLATFORM_DOT_NET);
        } else
      {
        varPack = new MockConfigVarPack(ConfigVarPack.APP_PLATFORM_JAVA);
        }
      subSession = SessionManagerFactory.GetSessionManager(new XPSessionSimulator());
      asParent.SetPersistentSubSession(subSession);
      userSession = new MockPTSession();
      String[] qsArg = new String[1];
      qsArg[0] = "http%3A//google.com/";
      testURL = "http://localhost/portal/server.pt?space=" + EnsembleHandlerControl.STR_MVC_CLASS_NAME + "&" + EnsembleHandlerControl.ES_POST_REDIRECT_URL + "=" + qsArg[0];
      testArgs = new XPHashtable();
      testArgs.PutElement(ASConstants.SPACENAME, EnsembleHandlerControl.STR_MVC_CLASS_NAME);
      testArgs.PutElement(EnsembleHandlerControl.ES_POST_REDIRECT_URL, qsArg);
      }
    /*
     * @see junit.framework.TestCase#tearDown()
     */
     
    public override void tearDown()
    {
      base.tearDown();
      testObject = null;
      testArgs = null;
      asParent = null;
      userSession = null;
      subSession = null;
      m_helper = null;
      varPack = null;
    }
    
    /// <summary>
    /// Test case when Ensemble sends SSO request for user not logged into portal
    /// </summary>
    public virtual void testSSOLoginAsGuest()
    {
      // Setting SSO LoginToken Timeout to 2 min 
      varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT,
       ConfigConstants.VALUE_ATTRIBUTE, "2");
      asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
      userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_GUEST);
      ((MockEnvironment) asParent).m_userSession = userSession;
      testObject.Init(null, asParent);
      testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
      Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
      String redirectURL = redirect.GetExternalURL();
      Assert.assertEquals("Could not find the expected Redirect URL!", redirectURL,
       "http%3A//google.com/?portal_cookie=did_not_find_cookie");
    }
    
    /// <summary>
    /// Testcase: Ensemble sends sso request for the already logged in user.
    /// </summary>
    public virtual void testSSOLoginAsRealUser()
    {
      // Setting SSO LoginToken Timeout to 2 min 
      varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT,
       ConfigConstants.VALUE_ATTRIBUTE, "2");
      asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
      userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_REGULAR);
      ((MockEnvironment) asParent).m_userSession = userSession;
      testObject.Init(null, asParent);
      testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
      Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
      String redirectURL = redirect.GetExternalURL();
      Assert.assertEquals("Could not find the expected redirect URL!", redirectURL,
       "http%3A//google.com/?portal_cookie=0%7CfAkEpOrTaLtOKeN");
    }
    //@TODO Check Redirect URL also
    
    /// <summary>
    /// Testcase: Ensemble sends sso request with Login Token when user is not logged into WCI.
    /// </summary>
    public virtual void testSSOLoginAsGuestWithToken()
    {
      // Setting SSO LoginToken Timeout to 2 min 
      varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT,
       ConfigConstants.VALUE_ATTRIBUTE, "2");
      asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
      userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_GUEST);
      ((MockEnvironment) asParent).m_userSession = userSession;
      testObject.Init(null, asParent);
      // Adding Ensemble Token to the request Args
      testURL+="&" + EnsembleHandlerControl.WCI_TOKEN + "=" + MOCK_ENSEMBLE_TOKEN;
      testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
      String[] tokArg = new String[1];
      tokArg[0] = MOCK_ENSEMBLE_TOKEN;
      testArgs.PutElement(EnsembleHandlerControl.WCI_TOKEN, tokArg);
      // Setting PortalObjectFactory to use MockPTSession
      MockPortalObjectsFactory factory = new MockPortalObjectsFactory();
      factory.m_session = userSession;
      PortalObjectsFactoryService.setTestInstance(factory);
      Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
      String redirectURL = redirect.GetExternalURL();
      Assert.assertEquals("Could not find the expected redirect URL!", redirectURL,
       "http%3A//google.com/?portal_cookie=0%7CfAkEpOrTaLtOKeN");
      // Reset to null after test is done
      PortalObjectsFactoryService.setTestInstance(null);
    }
    
    /// <summary>
    /// Testcase: Ensemble sends sso request with Login Token for the already logged in user.
    /// </summary>
    public virtual void testSSOLoginAsRealUserWithToken()
    {
      // Setting SSO LoginToken Timeout to 2 min 
      varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT,
       ConfigConstants.VALUE_ATTRIBUTE, "2");
      asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
      userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_REGULAR);
      ((MockEnvironment) asParent).m_userSession = userSession;
      testObject.Init(null, asParent);
      // Adding Ensemble Token to the request Args
      testURL+="&" + EnsembleHandlerControl.WCI_TOKEN + "=" + MOCK_ENSEMBLE_TOKEN;
      testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
      String[] tokArg = new String[1];
      tokArg[0] = MOCK_ENSEMBLE_TOKEN;
      testArgs.PutElement(EnsembleHandlerControl.WCI_TOKEN, tokArg);
      Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
      String redirectURL = redirect.GetExternalURL();
      Assert.assertEquals("Could not find the expected redirect URL!", redirectURL,
       "http%3A//google.com/?portal_cookie=0%7CfAkEpOrTaLtOKeN");
    }
    
    /// <summary>
    /// Testcase when EnsembleSSO feature is turned off in WCI
    /// </summary>
    public virtual void testWithSSODisabled()
    {
      // Setting SSO LoginToken Timeout to 0 min 
      varPack.SetConfigValue(ConfigConstants.MAIN_URLS_SECTION, ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT,
       ConfigConstants.VALUE_ATTRIBUTE, "0");
      asParent.GetApplication().GetVarPackManager().AddVariablePackage(varPack);
      userSession.GetUser().SetUserType(PT_USER_TYPES.PT_USER_TYPE_REGULAR);
      ((MockEnvironment) asParent).m_userSession = userSession;
      testObject.Init(null, asParent);
      testArgs.PutElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL, testURL);
      Redirect redirect = testObject.CheckActionSecurityAndExecute(testArgs);
      String redirectURL = redirect.GetExternalURL();
      Assert.assertEquals("Could not find the expected Redirect URL when SSO is disabled!",
       redirectURL, "http%3A//google.com/?portal_cookie=did_not_find_cookie");
      }
  }
}