using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portalpages.rest.utils;
namespace com.plumtree.portalpages.test.rest.utils
{
  /// <summary>
  /// Tests the JSON generated by JSONSerializer
  /// </summary>
  /// <TODO>
  /// : Currently just outputting result without validation. Validate visually. Need a way to
  /// enumerate hashtable content in a predictable order.
  /// </TODO>
  /// <author>rozhang</author>
  public class JSONSerializerTest : TestCase
  {
    
    /// <author>rozhang</author>
    public virtual void setup()
    {
    }
    
    /// <summary>
    /// Tests for all the supported object types
    /// </summary>
    public virtual void testSimpleHashtable()
    {
      XPHashtable obj = new XPHashtable();
      // try different types
      obj.PutElement("integer1", -2);
      obj.PutElement("integer2", 0);
      obj.PutElement("integer3", 234234);
      obj.PutElement("float1", 23.1);
      obj.PutElement("float2", -0.1);
      obj.PutElement("long", 12345678);
      obj.PutElement("double1", 234234.0);
      obj.PutElement("double2", 234234234);
      obj.PutElement("char", '\n');
      obj.PutElement("char2", 'a');
      obj.PutElement("char3", 'c');
      obj.PutElement("String", "teststring");
      obj.PutElement("bool1", true);
      obj.PutElement("bool2", false);
      XPDateTime dateNow = new XPDateTime();
      obj.PutElement("dateNow", dateNow.GetTimeInMilliSeconds());
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
    
    /// <summary>
    /// Tests an array 
    /// </summary>
    public virtual void testSimpleHashtableWithArray()
    {
      XPHashtable obj = new XPHashtable();
      obj.PutElement("integer1", -2);
      obj.PutElement("String", "teststring");
      XPArrayList list = new XPArrayList();
      list.Add(-2);
      list.Add(0);
      list.Add(16225);
      list.Add(23.1);
      list.Add(-0.1);
      list.Add(234234.0);
      list.Add(234234234);
      list.Add('\n');
      list.Add('a');
      list.Add('c');
      list.Add("teststring");
      list.Add(true);
      list.Add(false);
      obj.PutElement("listproperty", list);
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
    
    /// <summary>
    /// Test serial and nested arrays
    /// </summary>
    public virtual void testSerialNestedArrays()
    {
      XPHashtable obj = new XPHashtable();
      obj.PutElement("integer1", -2);
      obj.PutElement("String", "teststring");
      XPArrayList list = new XPArrayList();
      list.Add(-2);
      list.Add(23.1);
      list.Add(234234.0);
      list.Add('\n');
      XPArrayList list2 = new XPArrayList();
      list2.Add(0);
      list2.Add(-0.1);
      list2.Add(234234234);
      list2.Add('c');
      list2.Add("teststring");
      list.Add(list2);
      XPArrayList list3 = new XPArrayList();
      list3.Add(0);
      list3.Add(-0.1);
      list3.Add(234234234);
      list3.Add('c');
      list3.Add("teststring");
      list.Add(list3);
      list.Add('a');
      list.Add('c');
      list.Add("teststring");
      obj.PutElement("listproperty", list);
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
    
    /// <summary>
    /// Tests serial and nested hashtables
    /// </summary>
    public virtual void testSerialNestedHashtables()
    {
      XPHashtable obj = new XPHashtable();
      // try different types
      obj.PutElement("integer1", -2);
      obj.PutElement("float1", 23.1);
      obj.PutElement("double1", 234234.0);
      obj.PutElement("char", '\n');
      obj.PutElement("String", "teststring");
      XPHashtable obj2 = new XPHashtable();
      // try different types
      obj2.PutElement("l2a_integer1", -2);
      obj2.PutElement("l2a_float1", 23.1);
      obj2.PutElement("l2a_double1", 234234.0);
      obj2.PutElement("l2a_char", 'c');
      obj2.PutElement("l2a_String", "teststring");
      obj.PutElement("nestedObj_L2A", obj2);
      XPHashtable obj3 = new XPHashtable();
      // try different types
      obj3.PutElement("l2g_integer1", -2);
      obj3.PutElement("l2g_float1", 23.1);
      obj3.PutElement("l2g_double1", 234234.0);
      obj3.PutElement("l2g_char", 'c');
      obj3.PutElement("l2g_String", "teststring");
      obj.PutElement("nestedObj_L2B", obj3);
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
    public virtual void testHashtableInArrayNesting()
    {
      XPHashtable obj = new XPHashtable();
      XPArrayList list = new XPArrayList();
      obj.PutElement("array1", list);
      XPHashtable obj1 = new XPHashtable();
      obj1.PutElement("l2_h1_string", "test string");
      obj1.PutElement("l2_h1_integer", -234);
      obj1.PutElement("l2_h1_float", 0.01);
      XPHashtable obj2 = new XPHashtable();
      obj2.PutElement("l2_h2_string", "test string");
      obj2.PutElement("l2_h2_integer", -234);
      obj2.PutElement("l2_h2_float", 0.01);
      XPHashtable obj3 = new XPHashtable();
      obj3.PutElement("l2_h3_bool", true);
      list.Add(obj1);
      list.Add(obj2);
      list.Add(obj3);
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
    
    /// <summary>
    /// Test escape encoding
    /// </summary>
    public virtual void testStringEscapeEncoding()
    {
      XPHashtable obj = new XPHashtable();
      // try different types
      obj.PutElement("singleQuote", "\'");
      obj.PutElement("doubleQuote", "\"");
      obj.PutElement("backSlash", "\\");
      obj.PutElement("forwasrdSlash", "/");
      obj.PutElement("backSpace", "\b");
      obj.PutElement("formFeed", "\f");
      obj.PutElement("newLine", "\n");
      obj.PutElement("carriageReturn", "\r");
      obj.PutElement("horizontalTab", "\t");
      obj.PutElement("greaterThan", ">");
      obj.PutElement("lessThan", "<");
      XPArrayList list = new XPArrayList();
      list.Add("\'");
      list.Add("\"");
      list.Add("\\");
      list.Add("/");
      list.Add("\b");
      list.Add("\f");
      list.Add("\n");
      list.Add("\r");
      list.Add("\t");
      list.Add("<");
      list.Add(">");
      obj.PutElement("arrayEncoding", list);
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
    
    /// <summary>
    /// Test handling of empty and null values
    /// </summary>
    public virtual void testEmptyValues()
    {
      XPHashtable obj = new XPHashtable();
      obj.PutElement("emptypropvalue", "");
      XPArrayList list1 = new XPArrayList();
      obj.PutElement("emptystring", list1);
      JSONSerializer jsonOut = new JSONSerializer(obj);
      XPSystem.Out.Write(jsonOut.GenerateStringRepresentation(false));
    }
  }
}