using System;
using junit.framework;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework;
using com.plumtree.portaluiinfrastructure.helpers;
using com.plumtree.portaluiinfrastructure.mock.classtypedescriptors;
using com.plumtree.portaluiinfrastructure.mock.friendlyurl;
using com.plumtree.portaluiinfrastructure.mock.helper;
using com.plumtree.portaluiinfrastructure.mock.tags;
using com.plumtree.portaluiinfrastructure.tags.data;
using com.plumtree.server;
using com.plumtree.server.mock.core;
using com.plumtree.server.mock.directory;
using com.plumtree.server.mock.webservice;
using com.plumtree.taskapi.portalui;
using com.plumtree.taskapi.portalui.util;
namespace com.plumtree.taskapi.test.portalui
{
  public class TaskAPIUIDirectoryServiceTest : TestCase
  {
    public const int DATA_SOURCE_ID_1 = 12;
    public const String DATA_SOURCE_NAME_1 = "First data source";
    public const int WEB_SERVICE_ID_1 = 1254;
    public const String DATA_SOURCE_PROVIDER_CLSID_1 = "{blah-blah-blah-blah}";
    public const String DATA_SOURCE_PROVIDER_NAME_1 = "first provider name";
    public const int DATA_SOURCE_ID_2 = 232;
    public const String DATA_SOURCE_NAME_2 = "Second data source";
    public const String DATA_SOURCE_URL_2 = "http://www.blah.com";
    public const int WEB_SERVICE_ID_2 = 232654;
    public const String DATA_SOURCE_PROVIDER_CLSID_2 = "{blah-blah-nother-blah}";
    public const String DATA_SOURCE_PROVIDER_NAME_2 = "second provider name";
    public const int DATA_SOURCE_ID_3 = 784;
    public const String DATA_SOURCE_NAME_3 = "Third data source";
    public const String DATA_SOURCE_URL_3 = "http://www.myotherblah.com";
    public const int WEB_SERVICE_ID_3 = 784827;
    public const String DATA_SOURCE_PROVIDER_CLSID_3 = "{blah-and-another-blah}";
    public const String DATA_SOURCE_PROVIDER_NAME_3 = "third provider name";
    protected MockEnvironment m_environment;
    protected MockPTObjectManager m_objMgr;
    protected MockPTWebService m_secondWebService;
    
    /// <summary>
    /// Setup if any is required.
    /// </summary>
    public override void setUp()
    {
      base.setUp();
      m_environment = new MockEnvironment();
      // The doc catalog query only contains object IDs.
      int[] catalogColumns = {PT_PROPIDS.PT_PROPID_OBJECTID};
      Object[][] catalogData = {new Object[]{DATA_SOURCE_ID_1, DATA_SOURCE_ID_2,
       DATA_SOURCE_ID_3}};
      MockPTQueryResult qrCatalogDataSources = new MockPTQueryResult();
      // True means the data does not need to be flipped (I.E. It's in the right format).
      qrCatalogDataSources.SetData(catalogColumns, catalogData, true);
      ((MockPTSession) m_environment.GetUserSession()).m_docCatalog.m_CardSubmitDataSources = qrCatalogDataSources;
      // The Object Manager query returns object IDs and names.
      int[] objMgrColumns = {PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME};
      Object[][] objMgrData = {new Object[]{DATA_SOURCE_ID_1, DATA_SOURCE_ID_2,
       DATA_SOURCE_ID_3}, new Object[]{DATA_SOURCE_NAME_1, DATA_SOURCE_NAME_2,
       DATA_SOURCE_NAME_3}};
      MockPTQueryResult qrObjMgrDataSources = new MockPTQueryResult();
      // True means the data does not need to be flipped (I.E. It's in the right format).
      qrObjMgrDataSources.SetData(objMgrColumns, objMgrData, true);
      MockPTSession ptSession = (MockPTSession) m_environment.GetUserSession();
      m_objMgr = ptSession.m_genericObjectManager;
      m_objMgr.m_bUseStatic = false;
      m_objMgr.m_queryResult = qrObjMgrDataSources;
      // Mock Data Sources
      MockPTDataSource source = new MockPTDataSource();
      source.SetObjectID(DATA_SOURCE_ID_1);
      source.m_strCLSID = DATA_SOURCE_PROVIDER_CLSID_1;
      source.m_nWebServiceID = WEB_SERVICE_ID_1;
      m_objMgr.m_htObjects.PutElement(DATA_SOURCE_ID_1, source);
      source = new MockPTDataSource();
      source.SetObjectID(DATA_SOURCE_ID_2);
      source.m_strCLSID = DATA_SOURCE_PROVIDER_CLSID_2;
      source.m_nWebServiceID = WEB_SERVICE_ID_2;
      m_objMgr.m_htObjects.PutElement(DATA_SOURCE_ID_2, source);
      source = new MockPTDataSource();
      source.SetObjectID(DATA_SOURCE_ID_3);
      source.m_strCLSID = DATA_SOURCE_PROVIDER_CLSID_3;
      source.m_nWebServiceID = WEB_SERVICE_ID_3;
      m_objMgr.m_htObjects.PutElement(DATA_SOURCE_ID_3, source);
      // Mock Web Services
      MockPTWebServiceManager ptWebServices = (MockPTWebServiceManager) ptSession.GetWebServices();
      MockPTWebService webService = new MockPTWebService(PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD,
       DATA_SOURCE_URL_2, AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL);
      ptWebServices.m_htObjects.PutElement(WEB_SERVICE_ID_2, webService);
      // Store this for later processing
      m_secondWebService = webService;
      webService = new MockPTWebService(PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_UPLOAD,
       DATA_SOURCE_URL_3, AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL);
      ptWebServices.m_htObjects.PutElement(WEB_SERVICE_ID_3, webService);
      MockPTConfigHelper helper = new MockPTConfigHelper();
      PTConfigService.setTestPTInstance(helper);
      MockClassTypeDescManager classTypeMgr = new MockClassTypeDescManager();
      helper.m_classTypeManager = classTypeMgr;
      XPHashtable htCLSIDs = new XPHashtable();
      htCLSIDs.PutElement(DATA_SOURCE_PROVIDER_CLSID_1, DATA_SOURCE_PROVIDER_NAME_1);
      htCLSIDs.PutElement(DATA_SOURCE_PROVIDER_CLSID_2, DATA_SOURCE_PROVIDER_NAME_2);
      htCLSIDs.PutElement(DATA_SOURCE_PROVIDER_CLSID_3, DATA_SOURCE_PROVIDER_NAME_3);
      classTypeMgr.SetCLSIDToEnglishNameLookupTable(htCLSIDs);
      // The first data source is web (true), and the second two are file (false)
      XPHashtable htProvInfos = new XPHashtable();
      htProvInfos.PutElement(DATA_SOURCE_PROVIDER_NAME_1, new MockProvInfo(true));
      htProvInfos.PutElement(DATA_SOURCE_PROVIDER_NAME_2, new MockProvInfo(false));
      htProvInfos.PutElement(DATA_SOURCE_PROVIDER_NAME_3, new MockProvInfo(false));
      classTypeMgr.SetEnglishToProvInfoLookupTable(htProvInfos);
    }
    /*
     * @see junit.framework.TestCase#tearDown()
     */
     
    public override void tearDown()
    {
      PTConfigService.setTestPTInstance(null);
    }
    public virtual void testDataSources()
    {
      ITaskAPIUIDirectory task = TaskAPIUIDirectoryService.GetInstance();
      IXPList result = task.GetSubmitDataSources(m_environment);
      Object[][] filter = m_objMgr.m_queryFilterUsed;
      assertNotNull("Query filter used to call object manager should not be null.",
       filter);
      assertEquals("Checking for filter operand.", PT_PROPIDS.PT_PROPID_OBJECTID,
       filter[0][0]);
      assertEquals("Checking for filter operator.", PT_FILTEROPS.PT_FILTEROP_IN,
       filter[1][0]);
      int[] ids = (int[]) filter[2][0];
      assertNotNull("Query filter object ID array should not be null.", ids);
      assertEquals("Checking query filter object ID array length.", 3, ids.Length);
      assertEquals("Checking query filter object ID array first item.", DATA_SOURCE_ID_1,
       ids[0]);
      assertEquals("Checking query filter object ID array second item.", DATA_SOURCE_ID_2,
       ids[1]);
      assertEquals("Checking query filter object ID array third item.", DATA_SOURCE_ID_3,
       ids[2]);
      assertNotNull("Result should be non-null.", result);
      assertEquals("Result length incorrect.", 3, result.GetSize());
      HashtableDataObject source = (HashtableDataObject) result.GetElement(0);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("First result ID incorrect.", DATA_SOURCE_ID_1, XPConvert.ToInteger(source.GetData(SubmitDataSourceConstants.ID)));
      assertEquals("First result name incorrect.", DATA_SOURCE_NAME_1, source.GetData(SubmitDataSourceConstants.NAME));
      source = (HashtableDataObject) result.GetElement(1);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("Second result ID incorrect.", DATA_SOURCE_ID_2, XPConvert.ToInteger(source.GetData(SubmitDataSourceConstants.ID)));
      assertEquals("Second result name incorrect.", DATA_SOURCE_NAME_2, source.GetData(SubmitDataSourceConstants.NAME));
      source = (HashtableDataObject) result.GetElement(2);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("Third result ID incorrect.", DATA_SOURCE_ID_3, XPConvert.ToInteger(source.GetData(SubmitDataSourceConstants.ID)));
      assertEquals("Third result name incorrect.", DATA_SOURCE_NAME_3, source.GetData(SubmitDataSourceConstants.NAME));
      }
    public virtual void testAddingUploadData()
    {
      ITaskAPIUIDirectory task = TaskAPIUIDirectoryService.GetInstance();
      IXPList result = task.GetSubmitDataSources(m_environment);
      assertNotNull("Result should be non-null.", result);
      assertEquals("Result length incorrect.", 3, result.GetSize());
      HashtableDataObject source = (HashtableDataObject) result.GetElement(0);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertNull("First result URL should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.URL));
      assertNull("First result type should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.TYPE));
      assertNull("First result web service ID should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.WEB_SERVICE_ID));
      source = (HashtableDataObject) result.GetElement(1);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertNull("Second result URL should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.URL));
      assertNull("Second result type should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.TYPE));
      assertNull("Second result web service ID should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.WEB_SERVICE_ID));
      source = (HashtableDataObject) result.GetElement(2);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertNull("Third result URL should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.URL));
      assertNull("Third result type should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.TYPE));
      assertNull("Third result web service ID should not be present before adding upload data.",
       source.GetData(SubmitDataSourceConstants.WEB_SERVICE_ID));
      result = task.AddUploadData(m_environment, result);
      assertNotNull("Result should be non-null after adding upload data.",
       result);
      assertEquals("Result length should be the same after adding upload data",
       3, result.GetSize());
      // The first data source is of type web, the second two are file.  This is
      // controlled by the MockProvInfo objects created in setup.
      source = (HashtableDataObject) result.GetElement(0);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("First result URL should be empty after adding upload data.",
       "", source.GetData(SubmitDataSourceConstants.URL));
      assertEquals("First result type incorrect.", SubmitDataSourceConstants.TYPE_WEB,
       source.GetData(SubmitDataSourceConstants.TYPE));
      assertEquals("First result web service ID should be empty after adding upload data.",
       "", source.GetData(SubmitDataSourceConstants.WEB_SERVICE_ID));
      source = (HashtableDataObject) result.GetElement(1);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("Second result URL incorrect after adding URLs.", DATA_SOURCE_URL_2,
       source.GetData(SubmitDataSourceConstants.URL));
      assertEquals("Second result type incorrect.", SubmitDataSourceConstants.TYPE_FILE,
       source.GetData(SubmitDataSourceConstants.TYPE));
      assertEquals("Second result web service ID incorrect after adding upload data.",
       XPConvert.ToString(WEB_SERVICE_ID_2), source.GetData(SubmitDataSourceConstants.WEB_SERVICE_ID));
      source = (HashtableDataObject) result.GetElement(2);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("Third result URL incorrect after adding URLs.", DATA_SOURCE_URL_3,
       source.GetData(SubmitDataSourceConstants.URL));
      assertEquals("Third result type incorrect.", SubmitDataSourceConstants.TYPE_FILE,
       source.GetData(SubmitDataSourceConstants.TYPE));
      assertEquals("Third result web service ID incorrect after adding upload data.",
       XPConvert.ToString(WEB_SERVICE_ID_3), source.GetData(SubmitDataSourceConstants.WEB_SERVICE_ID));
      }
    public virtual void testFilteringOnUploadDataByType()
    {
      // Make the second data source invalid so that it will be removed.
      // 3 is the incorrect value that the Publisher KD and Crawler Data Sources use.
      m_secondWebService.SetCardSubmitType(3);
      runFilterTest();
    }
    public virtual void testFilteringOnUploadDataByURL()
    {
      // Make the second data source invalid so that it will be removed.
      // Remove the remote upload URL so that it is invalid like the
      // Publisher KD and Crawler Data Sources.
      m_secondWebService.SetAbsoluteURL("", AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL);
      runFilterTest();
    }
    public virtual void runFilterTest()
    {
      // The Publisher KD and Crawler Data Sources are set incorrectly
      // to be of type simple and advanced, but they are not (Bug#69636).
      // Test that they are removed correctly by the filtering.
      ITaskAPIUIDirectory task = TaskAPIUIDirectoryService.GetInstance();
      IXPList result = task.GetSubmitDataSources(m_environment);
      assertNotNull("Result should be non-null.", result);
      assertEquals("Result length incorrect.", 3, result.GetSize());
      result = task.AddUploadData(m_environment, result);
      assertNotNull("Result should be non-null after adding upload data.",
       result);
      assertEquals("Result length should be less after filtering on upload data.",
       2, result.GetSize());
      // The first data source is of type web, the second two are file.  This is
      // controlled by the MockProvInfo objects created in setup.  The first file
      // should now be invalid and should not be present.
      HashtableDataObject source = (HashtableDataObject) result.GetElement(0);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("First filtered result URL should be empty after adding upload data.",
       "", source.GetData(SubmitDataSourceConstants.URL));
      assertEquals("First filtered result type incorrect.", SubmitDataSourceConstants.TYPE_WEB,
       source.GetData(SubmitDataSourceConstants.TYPE));
      source = (HashtableDataObject) result.GetElement(1);
      assertNotNull("Hashtabledataobjects in the list should not be null.",
       source);
      assertEquals("Second filtered result URL incorrect after adding URLs.",
       DATA_SOURCE_URL_3, source.GetData(SubmitDataSourceConstants.URL));
      assertEquals("Second filtered result type incorrect.", SubmitDataSourceConstants.TYPE_FILE,
       source.GetData(SubmitDataSourceConstants.TYPE));
    }
    public virtual void testNoDataSources()
    {
      // Remove the data sources added in setup.
      ((MockPTSession) m_environment.GetUserSession()).m_docCatalog.m_CardSubmitDataSources = new MockPTQueryResult();
      ITaskAPIUIDirectory task = TaskAPIUIDirectoryService.GetInstance();
      IXPList result = task.GetSubmitDataSources(m_environment);
      assertNotNull("Result should be non-null.", result);
      assertEquals("Result should be empty.", 0, result.GetSize());
      result = task.AddUploadData(m_environment, result);
      assertNotNull("Result should be non-null after adding upload data.",
       result);
      assertEquals("Result length should be empty.", 0, result.GetSize());
      }
  }
}