using System;
using com.plumtree.openfoundation.util;
using com.plumtree.portaluiinfrastructure.ptlink;
using com.plumtree.server;
using com.plumtree.taskapi.portalui;
using com.plumtree.uiinfrastructure.activityspace;
namespace com.plumtree.taskapi.test.portalui.mock
{
  public class MockTaskAPIUICommunityService : ITaskAPIUICommunity
  {
    
    /// <summary>
    /// UNIT TEST HELPERS BEGIN *
    /// </summary>
    public int m_nJoinedCommunityID = -1;
    public int m_nLeftCommunityID = -1;
    public int m_currCommId = -1;
    public int m_currPageId = -1;
    
    /// <summary>
    /// Access mock Communities with MockAddCommunity, MockRemoveCommunity and MockGetCommunity methods  *
    /// </summary>
    protected XPHashtable m_comms = new XPHashtable();
    protected XPHashtable m_pages = new XPHashtable();
    
    /// <summary>
    /// Each key is a community id (Integer) with value containing a list of sub community ids (Integer) *
    /// </summary>
    protected XPHashtable m_commStructure = new XPHashtable();
    
    /// <summary>
    /// TEST METHOD **
    /// </summary>
    /// <param name="commId"></param>
    /// <param name="commName"></param>
    /// <param name="subCommIds"></param>
    /// <param name="pageIds"></param>
    public virtual void MockAddCommunity(int commId, String commName, int[] subCommIds,
     int[] pageIds)
    {
      CommunityEntry entry = new CommunityEntry(commId, commName);
      if (subCommIds != null)
      {
        entry.SetSubCommunities(subCommIds);
      }
      if (pageIds != null)
      {
        entry.SetCommPages(pageIds);
      }
      m_comms.PutElement(commId, entry);
    }
    
    /// <summary>
    /// TEST METHOD **
    /// </summary>
    /// <param name="commId"></param>
    /// <returns></returns>
    public virtual CommunityEntry MockGetCommunity(int commId)
    {
      return (CommunityEntry) m_comms.GetElement(commId);
    }
    
    /// <summary>
    /// TEST METHOD **
    /// Adds subcommunities to specified community if the subcommunities don't already exist.
    /// Will not overwrite existing subcommunities on the parent community
    /// </summary>
    /// <param name="commId"></param>
    /// <param name="subCommIds"></param>
    public virtual void MockAddSubCommunities(int commId, int[] subCommIds)
    {
      CommunityEntry ce = MockGetCommunity(commId);
      ce.SetSubCommunities(subCommIds);
    }
    
    /// <summary>
    /// TEST METHOD **
    /// Verifies passed in community structure with the mock structure configured in the current instance
    /// </summary>
    /// <param name="topCommId"></param>
    /// <param name="depth">Levels of sub communities to check</param>
    /// <param name="structureMap">Sub community structure data to verify with. Entry key is a comm id (Integer), with list of sub comm values (Integer)</param>
    /// <returns>0 if data is valid or the community id which test data does not correspond, or has subcommunities that does not correspond with the validation data</returns>
    public virtual int VerifySubCommunityStructure(int topCommId, int maxDepth,
     XPHashtable structureMap)
    {
      return RecursiveVerifySubCommunityStructure(topCommId, maxDepth, structureMap,
       0);
    }
    
    /// <param name="topCommId"></param>
    /// <param name="maxDepth"></param>
    /// <param name="structureMap"></param>
    /// <param name="currDepth">Current depth where top level community is 0, first subcommunites are 1 etc.</param>
    /// <returns></returns>
    private int RecursiveVerifySubCommunityStructure(int topCommId, int maxDepth,
     XPHashtable structureMap, int currDepth)
    {
      if (structureMap == null)
      {
        throw new XPIllegalArgumentException("structureMap is null");
      }
      IXPList testSubComms = (IXPList) structureMap.GetElement(topCommId);
      CommunityEntry ce = MockGetCommunity(topCommId);
      IXPList realSubComms = ce.m_subCommIds;
      // does community exist?
      if (ce == null)
      {
        return topCommId;
      }
      // no sub comms?
      if (testSubComms.IsEmpty() && realSubComms.IsEmpty())
      {
        return 0;
      }
      // contain same nr of sub comms?
      if (!(testSubComms == null || testSubComms.IsEmpty()) && realSubComms.IsEmpty())
      {
        return topCommId;
      }
      // check each subcommunity id and their subcommunities
      if (!testSubComms.ContainsAll(realSubComms))
      {
        return topCommId;
      }
      if (currDepth < maxDepth)
      {
        for (int i = 0;i < testSubComms.GetSize();i++)
        {
          int currCommId = ((int) testSubComms.GetElement(i));
          int result = RecursiveVerifySubCommunityStructure(currCommId, maxDepth,
           structureMap, 1);
          if (result != 0)
          {
            return currCommId;
          }
        }
      }
      return 0;
    }
    
    /// <param name="pageId"></param>
    /// <param name="pageName"></param>
    /// <param name="pageType"></param>
    public virtual void MockAddPage(int pageId, String pageName, int pageType)
    {
      PageEntry entry = new PageEntry(pageId, pageName, pageType);
      m_pages.PutElement(pageId, entry);
    }
    
    /// <summary>
    /// TEST METHOD **
    /// </summary>
    /// <param name="commId"></param>
    /// <returns></returns>
    public virtual PageEntry MockGetPage(int pageId)
    {
      return (PageEntry) m_pages.GetElement(pageId);
    }
    
    /// <summary>
    /// UNIT TEST HELPERS END *
    /// </summary>
    public virtual bool CheckUserAccessLevelToCommunity(AActivitySpace owner,
     int nAccessLevel, int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool CheckUserAccessLevelToCurrentCommunity(AActivitySpace owner,
     int nAccessLevel)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool CheckUserAccessLevelToCurrentCommunityPage(AActivitySpace owner,
     int nAccessLevel)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL CreateCommunityCommonOpenerURL(AActivitySpace owner,
     int nCommunityID, String strCommunityName)
    {
      return TaskAPIUICommunity.CreateCommunityCommonOpenerURL(owner, nCommunityID,
       strCommunityName);
    }
    public virtual IPTURL CreateCommunityPageCommonOpenerURL(AActivitySpace owner,
     int nCommunityID, int nCommunityPageID, String strCommunityPageName)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
     int nProfileUserID, String sProfileUserName)
    {
      throw new XPNotImplementedException();
    }
    public virtual IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
     int nProfileUserID, String sProfileUserName, String strURLTitle)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL CreateUserProfilePageCommonOpenerURL(AActivitySpace owner,
     int nProfileUserID, String sProfileUserName, String strURLTitle, int nPageId,
     String strPageName)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual XPArrayList GetCommunityActionsAsURLs(AActivitySpace owner,
     bool bIncludeOneClick, bool bInheritTemplate, int nPageTemplate)
    {
      // TODO Auto-generated method stub
      return null;
    }
    public virtual int GetCommunityIDFromPTURL(IPTURL ptURL)
    {
      return TaskAPIUICommunity.GetCommunityIDFromPTURL(ptURL);
    }
    public virtual String GetCommunityName(AActivitySpace owner, int nCommunityID)
    {
      CommunityEntry ce = MockGetCommunity(nCommunityID);
      return ce.m_commName;
    }
    public virtual int GetCommunityPageIDFromPTURL(IPTURL ptURL)
    {
      // TODO Auto-generated method stub
      return 0;
    }
    public virtual XPArrayList GetCommunityPagesAsURLs(AActivitySpace owner,
     int nCommunityID)
    {
      CommunityEntry ce = MockGetCommunity(nCommunityID);
      if (ce == null)
      {
        throw new XPIllegalStateException("No Community exists with id: " + nCommunityID);
        }
      if (ce.m_commPageIds == null)
      {
        // defensive coding
        ce.m_commPageIds = new XPArrayList();
      }
      return ce.m_commPageIds;
    }
    public virtual int GetCurrentCommunityID(AActivitySpace owner)
    {
      if (m_currCommId == -1)
      {
        throw new XPIllegalStateException("No current Community set!");
      }
      CommunityEntry ce = MockGetCommunity(m_currCommId);
      return ce.m_commId;
    }
    public virtual String GetCurrentCommunityName(AActivitySpace owner)
    {
      if (m_currCommId == -1)
      {
        throw new XPIllegalStateException("No current Community set!");
      }
      CommunityEntry ce = MockGetCommunity(m_currCommId);
      if (ce == null)
      {
        throw new XPIllegalStateException("No Community with current Community id: " + m_currPageId + " was found!");
        }
      return ce.m_commName;
    }
    public virtual int GetCurrentCommunityPageID(AActivitySpace owner)
    {
      return m_currPageId;
    }
    public virtual String GetCurrentCommunityPageName(AActivitySpace owner)
    {
      if (m_currPageId == -1)
      {
        throw new XPIllegalStateException("No current Page set!");
      }
      PageEntry pe = MockGetPage(m_currPageId);
      if (pe == null)
      {
        throw new XPIllegalStateException("No Page with current page id: " + m_currPageId + " was found!");
        }
      return pe.m_pageName;
    }
    public virtual XPArrayList GetCurrentCommunityPagesAsURLs(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetCurrentPageAsURL(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetCurrentParentCommunityAsURL(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual int GetCurrentParentCommunityID(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetCurrentRelatedCommunitiesAsURLs(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual int[] GetCurrentRelatedCommununityIDs(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetCurrentSubCommunitiesAsURLs(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual int[] GetCurrentSubCommunityIDs(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual int GetDefaultCommunityID(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetMyCommunitiesAsURLs(AActivitySpace owner,
     bool bUseCachedData)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetMyMandatoryCommunitiesWithTabsAsURLs(AActivitySpace owner,
     bool bUseCachedData)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetParentCommunityAsURL(AActivitySpace owner, int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual int GetParentCommunityID(AActivitySpace owner, int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetRelatedCommununitiesAsURLs(AActivitySpace owner,
     int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual int[] GetRelatedCommununityIDs(AActivitySpace owner, int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetSubCommununitiesAsURLs(AActivitySpace owner,
     int nCommunityID)
    {
      CommunityEntry ce = MockGetCommunity(nCommunityID);
      XPArrayList list = new XPArrayList();
      XPArrayList subcommids = ce.m_subCommIds;
      for (int i = 0;subcommids != null && i < subcommids.GetSize();i++)
      {
        int subCommId = (int) subcommids.GetElement(i);
        CommunityEntry sce = MockGetCommunity(subCommId);
        if (sce != null)
        {
          list.Add(CreateCommunityCommonOpenerURL(owner, subCommId, sce.m_commName));
          } else
        {
          XPSystem.Out.WriteLine("MockTaskAPIUICommunity.GetSubCommununitiesAsURLs: Unable to find mock Community with id: " + subCommId);
          }
      }
      return list;
    }
    public virtual int[] GetSubCommununityIDs(AActivitySpace owner, int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForAddCommunityPortletsEditor(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForAddCommunityPortletsFlyout(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForCommunityKnowledgeDirectory(AActivitySpace owner,
     int nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForCreateCommunityPage(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForCreateCommunityPageOneClick(AActivitySpace owner,
     bool bInheritTemplate, int nPageTemplate)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual XPArrayList GetURLForCurrentCommunity(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForCurrentCommunityEditor(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForEditPortletPreferencesEditor(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForJoinCommunitiesEditor(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForJoinCurrentCommunityAction(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForUnsubscribeCommunitiesEditor(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual IPTURL GetURLForUnsubscribeCurrentCommunityAction(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool IsCommunityMember(AActivitySpace _asOwner, int _nCommunityID)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool IsCurrentCommunityUserProfileCommunity(AActivitySpace owner)
    {
      return (m_currCommId == PT_INTRINSICS.PT_PROFILE_COMMUNITY);
    }
    public virtual bool IsCurrentPageCommunityPage(AActivitySpace owner)
    {
      return (m_currCommId > 0);
    }
    public virtual bool IsCurrentPageMyPortalPage(AActivitySpace owner)
    {
      return (m_currPageId != -1);
    }
    public virtual bool IsCurrentUserAbleToEditCurrentCommunityPage(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool IsCurrentUserCommunityOwner(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool IsUserAbleToAccessCurrentCommunity(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool IsUserAbleToJoinCurrentCommunity(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool IsUserMemberOfCurrentCommunity(AActivitySpace owner)
    {
      // TODO Auto-generated method stub
      throw new XPNotImplementedException();
    }
    public virtual bool JoinCommunity(AActivitySpace _asOwner, int _nCommunityID)
    {
      m_nJoinedCommunityID = _nCommunityID;
      return true;
    }
    public virtual bool LeaveCommunity(AActivitySpace _asOwner, int _nCommunityID)
    {
      m_nLeftCommunityID = _nCommunityID;
      return true;
    }
    public class CommunityEntry
    {
      public int m_commId;
      public String m_commName;
      public XPArrayList m_subCommIds = new XPArrayList();
      public XPArrayList m_commPageIds = new XPArrayList();
      public CommunityEntry(int commId, String commName)
      {
        m_commId = commId;
        m_commName = commName;
      }
      public virtual void SetSubCommunities(int[] subCommIds)
      {
        for (int i = 0;i < subCommIds.Length;i++)
        {
          m_subCommIds.Add(subCommIds[i]);
        }
      }
      public virtual void SetCommPages(int[] pageIds)
      {
        for (int i = 0;i < pageIds.Length;i++)
        {
          if (!m_commPageIds.Contains(pageIds[i]))
          {
            m_commPageIds.Add(pageIds[i]);
          }
        }
      }
    }
    public class PageEntry
    {
      public const int PAGETYPE_MYPAGE = 0;
      public const int PAGETYPE_COMMUNITY = 1;
      public int m_pageId;
      public String m_pageName;
      public int m_pageType;
      public PageEntry(int pageId, String pageName, int pageType)
      {
        m_pageId = pageId;
        m_pageName = pageName;
        m_pageType = pageType;
      }
    }
  }
}