package com.plumtree.portalpages.admin.approval.document;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.approval.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.approval.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Ben Geislinger
 *
 */
public class DocumentInstanceDescriptor extends AInstanceDescriptor
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.approval.document.DocumentInstanceDescriptor");

	private int iClassID = -1;
	private int iFolderObjectID = -1;
	private int iObjectID	    = -1;

	/**
	 * Creates a new DocumentInstanceDescriptor object.
	 *
	 * @param item
	 * @param ePath
	 */
	public DocumentInstanceDescriptor(DocumentItemDescriptor item,
		HTMLElement ePath, AActivitySpace space)
	{
		super((AItemDescriptor) item, ePath, ApprovalPortalItemType.DOCUMENT,
			space);
	}

	/**
	 *
	 */
	public void Execute()
	{
		
			log.Debug("ENTERING Execute() - iObjectID: " + iObjectID);
		

		IPTSession ptSession = (IPTSession) mySpace.GetUserSession();

		IPTCatalog catalog = ptSession.GetCatalog();

		try
		{
			if (this.GetApprove())
			{
				
					log.Debug("Execute() - About to server APPROVE.");
				

				int[] ia = new int[1];
				ia[0] = iObjectID;

				catalog.SetApprovalStateByFolder(iFolderObjectID,
					PT_CARDREF_STATES.PT_APPROVED, ia);
			}
			else if (this.GetReject())
			{
				
					log.Debug("Execute() - About to server REJECT.");
				

				int[] ia = new int[1];
				ia[0] = iObjectID;

				catalog.RemoveCards(iFolderObjectID, ia);
			}
		}
		catch (Exception ex)
		{
			
				log.Error(ex, "Couldn't approve or reject object.");
			

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, "Couldn't approve object.",
					ex.getMessage());

			myError.SetActivitySpace(mySpace.GetName());
			myError.SetClearWithActivitySpaceChange(true);

			UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(),
				mySpace.GetApplication());
		}
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetClassID()
	{
		return iClassID;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetFolderObjectID()
	{
		return iFolderObjectID;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetObjectID()
	{
		return iObjectID;
	}

	/**
	 *
	 *
	 * @param i
	 */
	public void SetClassID(int i)
	{
		iClassID = i;
	}

	/**
	 *
	 *
	 * @param i
	 */
	public void SetFolderObjectID(int i)
	{
		iFolderObjectID = i;
		super.SetPTFolderID(i);
	}

	/**
	 *
	 *
	 * @param i
	 */
	public void SetObjectID(int i)
	{
		iObjectID = i;
	}
}

