package com.plumtree.portalpages.admin.approval.document;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.approval.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.approval.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 *
 *
 * @author Ben Geislinger
 */
public class DocumentItemDescriptor extends AItemDescriptor
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.approval.document.DocumentItemDescriptor");

	private String sStatus = "";








	private int iClassID = -1;


	private int iObjectID = -1;

	private String sOriginalName = null;
	private String sOriginalDesc = null;

	/**
	 * Creates a new DocumentItemDescriptor object.
	 *
	 * @param name
	 * @param description
	 * @param submittedBy
	 * @param submittedDate
	 * @param space
	 */
	public DocumentItemDescriptor(String name, String description,
		String submittedBy, XPDateTime submittedDate, AActivitySpace space)
	{
		super(name, description, submittedBy, submittedDate, space,
			ApprovalPortalItemType.DOCUMENT);

		sOriginalName = name;
		sOriginalDesc = description;
	}

	/**
	 *
	 */
	public void Execute()
	{
		
			log.Debug("ENTERING Execute() - iObjectID: " + iObjectID);
		

		IPTSession ptSession = (IPTSession) mySpace.GetUserSession();

		IPTCatalog catalog = ptSession.GetCatalog();

		try
		{
			if (this.GetApprove())
			{
				
					log.Debug("Execute() - About to server APPROVE.");
				

				catalog.ApproveCardWhereUnapproved(this.GetObjectID());
			}
			else if (this.GetReject())
			{
				
					log.Debug("Execute() - About to server REJECT.");
				

				catalog.DiscardCardWhereUnapproved(1);
			}
		}
		catch (Exception ex)
		{
			log.Error(ex, "Couldn't approve or reject object.");

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, this.mySpace.GetString( 2420, ResourceConstants.PORTALADMINMSGS ),
					ex.getMessage());

			myError.SetActivitySpace(mySpace.GetName());
			myError.SetClearWithActivitySpaceChange(true);

			UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(),
				mySpace.GetApplication());
		}


		/* update card if name or description has changed */
		String sName = this.GetName();
		String sDesc = this.GetDescription();
		boolean nameChanged = (null!=sName && !sName.equals(sOriginalName));
		boolean descChanged = (null!=sDesc && !sDesc.equals(sOriginalDesc));

		if( nameChanged || descChanged)
		{
			IPTCard card = null;

			try
			{
				/* update name/desc */
				card = catalog.OpenCard( this.GetObjectID(), true );
				if (nameChanged){card.SetName( sName );}
				if (descChanged){card.SetDescription( sDesc );}
				card.SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INDEXONSTORE, 1);

				/* save */
				((IPTServerContext)card).Store();
				((IPTServerContext)card).UnlockObject();
				//	it worked!

				sOriginalName = sName;
				sOriginalDesc = sDesc;
			}
			catch( Exception ex )
			{
				if( card != null )
				{
					//	 just try to unlock it in case an exception was thrown
					//	after opening it.

					try
					{
						((IPTServerContext)card).UnlockObject();
					}
					catch( Exception ex2 )
					{
					}
				}

				if (nameChanged){log.Error(ex, "Couldnt save new name on card.");}
				if (descChanged){log.Error(ex, "Couldnt save new description on card.");}

				UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER, this.mySpace.GetString( 2419, ResourceConstants.PORTALADMINMSGS ),
						ex.getMessage());

				myError.SetActivitySpace(mySpace.GetName());
				myError.SetClearWithActivitySpaceChange(true);

				UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(), mySpace.GetApplication());
			}
		}	//	card changed
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetClassID()
	{
		return iClassID;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetObjectID()
	{
		return iObjectID;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetStatus()
	{
		return sStatus;
	}

	/**
	 *
	 *
	 * @param i
	 */
	public void SetClassID(int i)
	{
		iClassID = i;
	}

	/**
	 *
	 *
	 * @param i
	 */
	public void SetObjectID(int i)
	{
		iObjectID = i;
	}

	/**
	 *
	 *
	 * @param s
	 */
	public void SetStatus(String s)
	{
		sStatus = s;
	}
}

