package com.plumtree.portalpages.admin.editors.adminfolder;

import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the Advanced Settings page of the Admin Folder Editor.
 *
 * @author RickyW
 */
public class AdminFolderAdvDP extends EditorDP
{
	/** class name **/
	public static final String STR_MVC_CLASS_NAME = "AdminFolderAdvDP";

	/**
	 * Customizes the spacing on the left and right sides of the content
	 * table.  The default value is 15.  Set to 0 if you don't want views
	 * to be indented.
	 */
	public AdminFolderAdvDP()
	{
		super();
		super.SetContentTableCellSpacing("15");
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(8, ResourceConstants.PORTALADMINMSGS);
	}

	// localized strings

	/** Localized String: Advanced Settings */


	/** Localized String: Text For SubHeader */


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Advanced Settings page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// For each Section you want to display on that page,
		// copy the line below and change the name of the Section.
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				AdminFolderAdvView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 *
	 *
	 * @return
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// call DisplayJavascript() for all views displayed that have JS.
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				AdminFolderAdvView.STR_MVC_CLASS_NAME).DisplayJavascript());

		return myScripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetHTMLBelowSubHeader()
	 */
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(9,
			ResourceConstants.PORTALADMINMSGS), this.m_asOwner);
	}
}

