package com.plumtree.portalpages.admin.editors.adminfolder;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.subportal.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.securitymatrix.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register the models, views, controls, and display pages
 * for the AdminFolder editor.  This class can also be used to get any of those
 * objects back with the class name.
 *
 * @author RickyW
 */
public class AdminFolderEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.adminfolder.AdminFolderEditorAS");

	/** class name **/
	public static final String STR_MVC_CLASS_NAME = "AdminFolderEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdminFolderEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			// Return the main title of the Editor in create mode.
			return GetString(16, ResourceConstants.PORTALADMINMSGS);
		}
		else
		{
			// Return the main title of the Editor in edit mode.
			return (XPResourceManager.FormatMessage(GetString(2618, ResourceConstants.PORTALADMINMSGS), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (AdminFolderDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (AdminFolderRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = AdminFolderModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(AdminFolderModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		ABOBlankSelectDP dpABOBlankSelect = new ABOBlankSelectDP();
		dpABOBlankSelect.SetRepostControlName(AdminFolderRepostControl.STR_MVC_CLASS_NAME);
		RegisterPage(dpABOBlankSelect);
		RegisterPage(new ABOPopupSelectDP());
		ABOBlankResultsDP dpABOBlankResults = new ABOBlankResultsDP();
		dpABOBlankResults.SetRepostControlName(AdminFolderRepostControl.STR_MVC_CLASS_NAME);
		RegisterPage(dpABOBlankResults);
		RegisterPage(new ABOPopupResultsDP());

		// Register Views
		RegisterView(ABOPopupSelectView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ABOPopupResultsView.STR_MVC_CLASS_NAME, myModel);

		
		AdminFolderAdvDP myAdvDP				    = new AdminFolderAdvDP();
//		AdminFolderBlankSelectDP myABOBlankSelectDP = new AdminFolderBlankSelectDP();
//		AdminFolderABODP myABOSelectDP			    = new AdminFolderABODP();
//		AdminFolderBlankLinksDP myABOBlankLinksDP   = new AdminFolderBlankLinksDP();
//		AdminFolderABOLinksDP myABOLinksDP		    = new AdminFolderABOLinksDP();

		// finally register
		RegisterPage(myAdvDP);
//		RegisterPage(myABOBlankSelectDP);
//		RegisterPage(myABOSelectDP);
//		RegisterPage(myABOBlankLinksDP);
//		RegisterPage(myABOLinksDP);

		// Register Views
		RegisterView(AdminFolderAdvView.STR_MVC_CLASS_NAME, myModel);
//		RegisterView(AdminFolderABOView.STR_MVC_CLASS_NAME, myModel);
//		RegisterView(AdminFolderABOLinksView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(AdminFolderDependenciesView.STR_MVC_CLASS_NAME, myModel);
		
		// Register Controls
		RegisterControl(AdminFolderRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Set the default page
		SetCurrentPage(LocNamesDP.STR_MVC_CLASS_NAME);

		if ( !(this.IsSubSpace()) || !GetParentSpaceName().equals(SubPortalAS.STR_MVC_CLASS_NAME))
		{
			// Create general settings submenu
			int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(18,ResourceConstants.PORTALADMINMSGS));			
			
			// Add subportal settings page
			m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
				AdminFolderAdvDP.STR_MVC_CLASS_NAME);
		}			

		// Create standard settings submenu
		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1700, ResourceConstants.PORTALADMINMSGS));

		// Add Properties and Names page
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		// Add Security page
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		// Add Migration History page
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		
		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{


				int iTitleId = 9;
				int iTipId = 10;
				int iSecondaryTipId = 11;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}
				
								
				
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 * 
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
	    super.SetCurrentPage( page );
	 
	    String sPageName = page.GetName();
	 
	    if( AdminFolderAdvDP.STR_MVC_CLASS_NAME.equals( sPageName ))
	    {
	        this.SetHelpTopic( "PT_AdministrativeFolder_SubportalSettings" ); 
	    }
	}
}

