package com.plumtree.portalpages.admin.editors.adminfolder;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.securitymatrix.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class contains the IPTProperty server object, as well as the set and get
 * methods on that object. This class is called by the AdminFolderRepostControl
 * to  perform the changes on the Object and by the Views AdminFolderAdvView
 * and AdminFolderMainView to display the latest values on the page.
 *
 * @author RickyW
 */
public class AdminFolderModel extends ObjEditorModel
	implements ISecurityMatrixModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.adminfolder.AdminFolderModel");

	/** class name **/
	public static final String STR_MVC_CLASS_NAME = "AdminFolder";

	/** RWW - Constants for client side validation */
	public static final int CLIENT_VALIDATION_MAX_NAME = 63;

	// constants
	private static final boolean RIGHT_NOT_FOUND = false;

	public static final String BR_ELEMENT = "<BR>";


	// member variables

	/** holds the names of the subportal profiles */
	private XPArrayList m_xpalSubPortalInfo;

	/** holds the id of the selected subportal profile */
	private int m_iSelectedProfile;

	/** job name for ABO security change */
	private String m_sJobName;

	/** folder name job created in */
	private String m_sFolderJobCreatedInName;

	/** job ID for ABO security change */
	private int m_nABOJobID;

	public AdminFolderModel()
	{
		super();
		m_xpalSubPortalInfo = new XPArrayList();
	}

	/**
	 * 
	 * @return the current IPTAccessList of the folder whose security is being edited
	 */
	public IPTAccessList GetCurrentFolderACL()
	{
		IPTAdminFolder ptFolder = m_Session.GetAdminCatalog()
			.OpenAdminFolder(m_nObjectID, false);

		// lock the folder for edit								
		IPTServerContext ptSC = (IPTServerContext) ptFolder;
		
		return ptSC.GetACL();
	}

	/**
	 * @param _ptOldACL the IPTAccessList from before the ACLs were changed
	 * @return true if an admin acl was added or an acl was changed to admin.
	 */
	public boolean IsAdminModifiedOnFolder(IPTAccessList _ptOldACL)
	{
		return GetCurrentFolderACL().IsAdminModified(_ptOldACL);
	}
	
	/**
	 * @see com.plumtree.portalpages.admin.editors.adminfolder.IAdminFolderModelRO#ABOJobIDToDisplay()
	 */
	public boolean ABOJobIDToDisplay()
	{
		return (m_nABOJobID != -1);
	}

	/**
	 * Apply the subportal profile to the users in the folder later, using ABO.
	 * 
	 * @param bPropagateAllACLs - If true propagate all acls to child objects
	 * 	 and subfolders, if false propagate only admin acls.
	 */
	public void ApplySecurityChangesUsingABO(boolean bPropagateAllACLs)
	{
		String strErrors = "";
		IPTAdminFolder ptFolder;
		IPTScheduledOperation ptOp;
		IPTServerContext ptSC;

		try
		{
			// get the folder from the db
			ptFolder = (IPTAdminFolder) m_ptObject;
			ptSC = (IPTServerContext) ptFolder;
			ptSC.LockObject();

			// schedule a job - set the job type
			// so that the job will do the correct
			// thing, in our case, merge securites
			// Bug 14313 - Erick says we should use REPLACE instead of MERGE from now on.
			int nAdminFolderJobType;
			if ( bPropagateAllACLs )
			{
				nAdminFolderJobType = PT_ADMIN_FOLDER_JOB_TYPES.PT_ADMIN_FOLDER_JOB_PROPAGATEACL_REPLACE;
			}
			else
			{
				nAdminFolderJobType = PT_ADMIN_FOLDER_JOB_TYPES.PT_ADMIN_FOLDER_JOB_PROPAGATEACL_ADMINSONLY;
			}

			ptFolder.SetJobType(nAdminFolderJobType);

			// save and unlock object from db
			ptSC.Store();
			ptSC.UnlockObject();

			// create our job
			ptOp = (IPTScheduledOperation) ptFolder;
			m_nABOJobID = ptOp.ScheduleImmediateJob();

			// get the job's localized name
			IPTJob myTempJob = (IPTJob) m_Session.
				GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).
				Open(m_nABOJobID, false);
			m_sJobName = myTempJob.GetLocalizedName();

			//MES- Try to get the folder that the job was created in's localized name
			//	NOTE: We MAY not be able to get it, because we may not have security
			//	access.  In this case, we'll use the blank string.
			m_sFolderJobCreatedInName = "";
			try
			{
				IPTAdminFolder myTempAdminFolder = (IPTAdminFolder) m_Session.GetAdminCatalog().
					OpenAdminFolder(PT_INTRINSICS.PT_ADMIN_FOLDER_INTRINSICOPS, false);
				m_sFolderJobCreatedInName = myTempAdminFolder.GetLocalizedName();
			}
			catch (XPException xpe)
			{
				//MES- We're just ignoring all errors on getting the folder name.  We don't
				//	strictly need it, so even if the error is NOT due to a security
				//	violation, it's no big deal.
			}
		}
		catch (Exception ex)
		{
			m_nABOJobID = -1;
		}

		// error handling here
		if (m_nABOJobID == -1)
		{
			
				log.Error(m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) +
					((IPTAdminFolder) m_ptObject).GetClassID());
			

			strErrors += (m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) + BR_ELEMENT);
		}

		if (!"".equals(strErrors))
		{
			RaiseError(strErrors);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdminFolderModel();
	}

	/**
	 * Code executed after done is clicked, after object is saved.
	 */
	public void DoTaskAfterStore()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			// in our world, we won't use this editor to create folders
			// we will use a simple pop-up.  but we could, if we wanted.
		}
		else if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
		}
	}

	/**
	 * Code executed after done is clicked, before object is saved.
	 */
	public void DoTaskBeforeStore()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			// in our world, we won't use this editor to create folders
			// we will use a simple pop-up.  but we could, if we wanted.
		}
		else if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			// get our admin folder
			IPTAdminFolder ptAdminFolder = (IPTAdminFolder) m_ptObject;

			int iCurrentProfile = ptAdminFolder.GetFolderType();

			if (m_iSelectedProfile != iCurrentProfile)
			{
				try
				{
					// set the folder type
					ptAdminFolder.SetFolderType(m_iSelectedProfile);
				} catch (Exception e)
				{
					
						log.Error(e, "AdminFolderModel::DoTaskBeforeStore Unable to set folder type.");
					

					RaiseError(m_asOwner.GetString(2477, ResourceConstants.PORTALADMINMSGS));
				}
			}
		}
	}

	/**
	 * This method will be called when you come back to the main Editor from a sub Editor.
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();

		// if the user clicked on finish, we should
		// reload the dropdown in case a name changed.
		LoadSubPortalProfiles();
	}

	/**
	 * Initialize any settings here.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		// load profile names
		LoadSubPortalProfiles();
		LoadSelectedProfile();

		// RWW - Let the LocNames AS know that it should use a
		// client validation length of 63 for the name field.
		((LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME)).
			m_bUseClientValidationMaxNameOverride = true;
		((LocNamesModel) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME)).
			m_iClientValidationMaxNameOverride = AdminFolderModel.CLIENT_VALIDATION_MAX_NAME;

		// init vars
		m_nABOJobID = -1;

		// check to see if the user has rights to assign
		// a subportal profile.  if not, don't show page.
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
		boolean checkResult		 = ptSession.GetSessionInfo().CheckForActivityRight(
					PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_SUBPORTALS);

		if (checkResult == RIGHT_NOT_FOUND)
		{
			((AdminFolderEditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				AdminFolderAdvDP.STR_MVC_CLASS_NAME);
		}

		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			// in our world, we won't use this editor to create folders
			// we will use a simple pop-up.  but we could, if we wanted.
			// hide this link if we are not in edit mode...
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}
		else if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			if ((GetObjectID() == PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER))
			{
				((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.adminfolder.IAdminFolderModelRO#GetABOJobID()
	 */
	public int GetABOJobID()
	{
		return m_nABOJobID;
	}

	/**
	 * Returns the URL to edit the object.
	 *
	 * @param _nClassID
	 * @param _nObjectID
	 * @param _sEditorASName
	 *
	 * @return ASURL URL to the Editor
	 */
	public ASURL GetEditObjectURL(int _nClassID, int _nObjectID)
	{
		// NOTE: We are not caching the sub editor right now.
		// We may want to in the future if the need arises.
		ASURL myURL = new ASURL(m_asOwner);

		// the actual editor's name
		String sEditorASName = "SubPortalEditor";

		myURL.SetLinkCreateNewSpace(sEditorASName, m_asOwner);
		myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
		myURL.SetSubSpaceKey("AdminFolder" + sEditorASName + _nObjectID);
		myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
			XPConvert.ToString(_nClassID));
		myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
			XPConvert.ToString(_nObjectID));

		return myURL;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the number of SubPortals that were loaded.
	 *
	 * @return int number of profiles
	 */
	public int GetNumSubPortals()
	{
		return (m_xpalSubPortalInfo.GetSize());
	}

	/**
	 * Returns the id of a regular folder.
	 *
	 * @return String ID of regular folder
	 */
	public String GetRegularFolderID()
	{
		return (XPConvert.ToString(PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_REGULARFOLDER));
	}

	/**
	 * Returns the id of the selected subportal.
	 *
	 * @return String ID of selected subportal
	 */
	public String GetSelectedSubPortalID()
	{
		return (XPConvert.ToString(m_iSelectedProfile));
	}

	/**
	 * Returns the id of the subportal at a given position. This is returned as
	 * a string because we only need to do html with the id.
	 *
	 * @return String ID of subportal
	 */
	public String GetSubPortalID(int pos)
	{
		return XPConvert.ToString(((Object[]) m_xpalSubPortalInfo.GetElement(pos))[0]);
	}

	/**
	 * Returns the name of the subportal at a given position.
	 *
	 * @return String name of subportal
	 */
	public String GetSubPortalName(int pos)
	{
		return (String)((Object[]) m_xpalSubPortalInfo.GetElement(pos))[1];
	}

	// helper classes
	public void RaiseError(String strError)
	{
		UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, strError, strError);

		myError.SetActivitySpace(m_asOwner.GetName());
		myError.SetDisplayOnSeparatePage(false);
		myError.SetClearWithActivitySpaceChange(true);
		myError.SetImmediateClear(true);

		UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
			m_asOwner.GetApplication());
	}

	/**
	 * Does nothing for now.
	 */
	public void RepostAdvPage()
	{
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(AdminFolderAdvDP.STR_MVC_CLASS_NAME))
		{
			// using nPageStatus for server validation
			nPageStatus = SaveAdvPage(_htFormData);
		}

		return nPageStatus;
	}

	/**
	 * Sets whether security should be disabled. .
	 */
	public void SetDisableSecurity(boolean bDisableSecurity)
	{
		m_bDisableSecurity = bDisableSecurity;
	}

	/**
	 * Saves the data on the Advanced page.
	 *
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	protected int SaveAdvPage(XPHashtable _htFormData)
	{
		String[] data;
		data = (String[]) _htFormData.GetElement(AdminFolderAdvView.HTMLSELECT_PROFILESELECT);

		// for server side validation
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		if ((null != data) && !(0 == data.length))
		{
			try
			{
				// save selected subportal to model
				m_iSelectedProfile = XPConvert.ToInteger(data[0]);
			}
			catch (Exception ex)
			{
				nPageStatus = RepostControl.PAGE_STATUS_INVALID;

				// raise error to display to user
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null,
						m_asOwner.GetString(28, ResourceConstants.PORTALADMINMSGS));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				
					log.Error("AdminFolderModel::SaveAdvPage Unable to select subportal.  The following exception occured: " +
						ex);
				
			}
		}

		return nPageStatus;
	}

	/**
	 * Retrieves the name of the job created by ABO.
	 */
	public String GetCreatedJobName()
	{
		return m_sJobName;
	}

	/**
	 * Retrieves the name of the folder that ABO created the job in.
	 */
	public String GetFolderNameForCreatedJobs()
	{
		return m_sFolderJobCreatedInName;
	}

	/**
	 * Retrieves the select sub portal profile.
	 */
	private void LoadSelectedProfile()
	{
		try
		{
			// get the selected profile - note that the folder
			// type determines the id of the subfolder, with
			// the exceptions of 0 being a regular folder, and
			// 1 being a community folder (although, we'll never
			// see 1 because you can't edit community folders.
			IPTAdminFolder ptAdminFolder = (IPTAdminFolder) m_ptObject;
			m_iSelectedProfile = ptAdminFolder.GetFolderType();
		}
		catch (Exception ex)
		{
			
				log.Error("AdminFolderModel::LoadSelectedProfile Unable to retrieve selected subportal.  The following exception occured: " +
					ex);
			

			throw new XPException(m_asOwner.GetString(30,
					ResourceConstants.PORTALADMINMSGS), ex);
		}
	}

	/**
	 * Retrieves the sub portal profile names.
	 */
	private void LoadSubPortalProfiles()
	{
		IPTSession ptSession		  = null;
		Object[] myPortalInfo		  = null;
		IPTQueryResult ptQRSubPortals = null;

		try
		{
			// get the user's plumtree session
			ptSession     = (IPTSession) m_asOwner.GetUserSession();

			// retrieve all the subportals in the given folder
			ptQRSubPortals = ptSession.GetSubPortals().Query(PT_PROPIDS.PT_PROPID_OBJECTID |
					PT_PROPIDS.PT_PROPID_NAME,
					-1,
					PT_PROPIDS.PT_PROPID_NAME, 0,
					-1, null);

			// clear old info
			m_xpalSubPortalInfo.Clear();

			// save subportal info to model
			for (int ii = 0; ii < ptQRSubPortals.RowCount(); ii++)
			{
				// add the folder name to the profile name storage array
				myPortalInfo	    = new Object[2];
				myPortalInfo[0]     = new Integer(ptQRSubPortals.ItemAsInt(ii,
						PT_PROPIDS.PT_PROPID_OBJECTID));
				myPortalInfo[1]     = ptQRSubPortals.ItemAsString(ii,
						PT_PROPIDS.PT_PROPID_NAME);
				m_xpalSubPortalInfo.Add(myPortalInfo);
			}
		}
		catch (Exception ex)
		{
			
				log.Error("AdminFolderModel::LoadSubPortalProfiles Unable to retrieve subportals list.  The following exception occured: " +
					ex);
			

			throw new XPException(m_asOwner.GetString(29,
					ResourceConstants.PORTALADMINMSGS), ex);
		}
	}
}


