package com.plumtree.portalpages.admin.editors.adminfolder;

import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.securitymatrix.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This class contains the additional repost actions.
 * The ones specific to the Property Editor (other than
 * "change page", "finish" and "cancel" actions).
 *
 * @author RickyW
 */
public class AdminFolderRepostControl extends ObjEditorRepostControl
{
	/** class name */
	public static final String STR_MVC_CLASS_NAME = "AdminFolderRepost";

	/** our repost options */
	public final static int POSTTOSELF_ACTION_CHANGE_DROPDOWN	    = 20;


	public final static int POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER     = 21;


	public final static int POSTTOSELF_ACTION_APPLY_RECURSIVELY = 22;


	public final static int POSTTOSELF_ACTION_CANCEL_ALL_CHANGES = 24;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdminFolderRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		// set false if don't want normal finish
		boolean doNormalFinish = true;

		// where to go on the next page
		Redirect myRedirect = null;

		// intercept the done button here. if there were
		// changes in security, then redirect to our blank
		// DP which will give the user the option of ABO
		ObjectSecurityModel securityModel = ((ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB));
		if ((_nAction == POSTTOSELF_ACTION_FINISH) && securityModel.HasSecurityChanged())
		{
			if (securityModel.CanPropagateSecurity()) {
				myRedirect = new Redirect();
				myRedirect.SetLinkGetCachedSpace(m_asOwner);
				myRedirect.SetDisplayPage(ABOBlankSelectDP.STR_MVC_CLASS_NAME);
				SetRedirect(myRedirect);
			} else {
				PerformApplySecurity(false);
			}
			// bypass the normal finish
			doNormalFinish = false;
		}

		// since pop-up shares the repost control and
		// opens with no control, we want a bypass
		if (_nAction == POSTTOSELF_ACTION_UNDEFINED)
		{
			doNormalFinish = false;
		}

		// cancel all changes
		if (_nAction == POSTTOSELF_ACTION_CANCEL_ALL_CHANGES)
		{
			_nAction = POSTTOSELF_ACTION_CANCEL ;
		}

		// abo - apply only this folder 
		if (_nAction == POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER)
		{
			PerformApplySecurity(false);
		}

		// abo - apply all acls to child objects and subfolders
		if (_nAction == POSTTOSELF_ACTION_APPLY_RECURSIVELY)
		{
			PerformApplySecurity(true);
		}

		// this is the normal save routine without
		// all our fancy pop-up and redirecting.
		if (doNormalFinish)
		{
			super.PerformAction(_nAction);

			switch (_nAction)
			{
			case POSTTOSELF_ACTION_CHANGE_DROPDOWN:
				((AdminFolderModel) m_model).RepostAdvPage();

				break;
			}
			//fixing bug #20554 removed call to ApplySecurityChangesNow in AdminFolderModel
			//don't want to propagate security when choosing apply only to this folder -mgs 7/28/03
		}
	}
	
	private void PerformApplySecurity(boolean bPropagateAllACLs) {
		//  get the acl before it gets changed by finish, we need it to compare to the new acl
		IPTAccessList ptOldACL = ((AdminFolderModel) m_model).GetCurrentFolderACL();
		// manually save acls on the folders
		((AdminFolderModel) m_model).Finish();
		
		boolean bDisplayJobsPopup = false;
		if (bPropagateAllACLs || ((AdminFolderModel) m_model).IsAdminModifiedOnFolder(ptOldACL)) {
			// now create the ABO job to update security
			((AdminFolderModel) m_model).ApplySecurityChangesUsingABO(bPropagateAllACLs);
			bDisplayJobsPopup = true;
		}
		
		if (bDisplayJobsPopup) {
			// we now redirect to our blank page again
			// so that we can show our jobs pop-up
			Redirect myRedirect = new Redirect();
			myRedirect.SetLinkGetCachedSpace(m_asOwner);
			myRedirect.SetDisplayPage(ABOBlankResultsDP.STR_MVC_CLASS_NAME);
			SetRedirect(myRedirect);
		} else {
			if (m_asOwner.IsSubSpace())
			{
				SetRedirectToCloseSubEditor();
			}
			else 
			{
				// MJD- Redirect (default implementation of GetRedirectAfterFinish 
				// redirects to the previous AS).
				Redirect myRedirect = m_model.GetRedirectAfterFinish();

				// Set this redirect to be a true 302 HTTP redirect so that
				// refreshing the page doesn't finish the editor twice.
				myRedirect.SetIsHTTPRedirect(true);
					
				SetRedirect(myRedirect);
			}
		}
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjEditorRepostControl#DisableSavePopUp()
	 */
	protected boolean DisableSavePopUp()
	{
		return true;
	}

}

