package com.plumtree.portalpages.admin.editors.authsource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.settings.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author OlegS
 */
public abstract class AuthSource4View extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.authsource.AuthSource4View");


	public static final String HTMLCHECKBOX_GROUP = "in_cb_group";


	public static final String HTMLCHECKBOX_DISABLED = "in_cb_disabled";

	public static final String HTMLBUTTON_BROWSE_ = "in_bu_browse_"; // +id


	public static final String ADMINFOLDERTREESPACE = "FolderTree";


	public static final String USERGROUPTREESPACE = "UserGroupTree";


	public static final String HTMLHIDDEN_TREEREPOST = "in_hi_TreeRepostAction";


	public static final String HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE = "in_hi_SpaceID_AF";


	public static final String HTMLHIDDEN_SPACEID_USERGROUPTREESPACE = "in_hi_SpaceID_UG";

	static Spacer spacer15 = new Spacer("15");
	static Spacer spacer2 = new Spacer("2");


	// member variables
	protected PTStyleClass m_styleListItem = null;

	/**
	 *
	 *
	 * @return
	 */
	public HTMLElement Display()
	{
		try
		{
			HTMLElementCollection result = new HTMLElementCollection();
			result.AddInnerHTMLString( "\n" );
			HTMLComment myComment = new HTMLComment( "Begin: Display AuthSource4View");

			result.AddInnerHTMLElement( myComment );

			int mode = GetModel().supportSyncMode();

			if (mode == PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_AUTHONLY)
			{
				DisplayMiniHelp(result, m_asOwner.GetString(1711, ResourceConstants.PORTALADMINMSGS));
			}
			else
			{
				DisplayHiddenInputs(result);

				DisplayHeader(result,
					m_asOwner.GetString(60, ResourceConstants.PORTALADMINMSGS));
				DisplayBody1(result);
				spacer15.display(result);

				DisplayHeader(result,
					m_asOwner.GetString(61, ResourceConstants.PORTALADMINMSGS));
				DisplayBody2(result);
				spacer15.display(result);

				if (GetModel().GetNumDisabledUsers() > 0)
				{
					DisplayHeader(result, m_asOwner.GetString(2660, "ptmsgs_portaladminmsgs"));
					DisplayBody3(result);
				}

			}


			myComment = new HTMLComment( "End: Display AuthSource4View");
			result.AddInnerHTMLElement( myComment );



			return result;
		}
		catch (Exception e)
		{
			log.Error(e, "AuthSource4View::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(80,
					ResourceConstants.PORTALADMINMSGS), e);
		}
	}

	/**
	 *
	 *
	 * @return
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		try
		{
			myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(
					m_asOwner, ADMINFOLDERTREESPACE,
					HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
					HTMLHIDDEN_TREEREPOST,
					m_asOwner.GetString(75, ResourceConstants.PORTALADMINMSGS),
					m_asOwner.GetString(76, ResourceConstants.PORTALADMINMSGS),
					PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
					PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,
					TreeConstants.N_COMPOSITESELECT, false, true, null));

			String hideids = GetModel().joinLists(
				GetModel().listOfAlienGroups(), // not our auth source
				GetModel().listOfSyncGroups()); // already in sync list
			myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(
					m_asOwner, USERGROUPTREESPACE,
					HTMLHIDDEN_SPACEID_USERGROUPTREESPACE,
					HTMLHIDDEN_TREEREPOST,
					m_asOwner.GetString(63, ResourceConstants.PORTALADMINMSGS),
					m_asOwner.GetString(62, ResourceConstants.PORTALADMINMSGS),
					PT_CLASSIDS.PT_USERGROUP_ID,
					PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,
					TreeConstants.N_LEAFSELECT, true, false, hideids));

			myScript.AddInnerHTMLString(
						"function CheckAllAsFirst() { \n"+
						"var frm = document.mainform; \n"+
						"var len = frm.elements.length; \n"+
						"var state = -1; \n"+
						"var i = 0; \n"+
						"for(i=0 ; i<len ; i++) { \n"+
						"if(frm.elements[i].name == 'in_cb_group') { \n"+
						"if(state<0) \n"+
						"state=frm.elements[i].checked; \n"+
						"else if(!frm.elements[i].disabled) \n"+
						"frm.elements[i].checked = state; \n"+
						"} \n"+
						"} \n"+
						"} \n"
				);

			// Open Tree function
			XPStringBuilder sb = new XPStringBuilder(200);
			ASURL popup = new ASURL(m_asOwner);
			popup.SetControl(AuthSourceRepostControl.STR_MVC_CLASS_NAME);
			popup.SetDisplayPage(AuthSourceReenableUsersPopupDP.STR_MVC_CLASS_NAME);
			popup.SetLinkGetCachedSpace(m_asOwner);
			popup.SetSubSpaceKey("ReenableUsersPopup");
			sb.Append("function OpenReenableUsersPopup ()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(popup.GetURLAsString())
			.Append("', '_ReenableUsersPopup', 'location=no,menubar=no,resizable=yes,height=200,width=400');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());


		}
		catch (Exception e)
		{
			log.Error(e, "AuthSource4View.DisplayJavascript couldn't add javascript to the HTMLScript element.");

			throw new XPException(m_asOwner.GetString(80,
					ResourceConstants.PORTALADMINMSGS) + " (Javascript)", e);
		}

		return myScript;
	}

	/**
	 *
	 *
	 * @param type
	 * @param alt
	 * @param w
	 * @param h
	 *
	 * @return
	 */
	protected HTMLImg GetImage(PTImageType type, String alt, String w, String h)
	{
		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(type,
					true, this.m_asOwner);
			HTMLImg myImg		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImg.SetAlt(alt);
			myImg.SetBorder("0");
			myImg.SetWidth(w);
			myImg.SetHeight(h);

			return myImg;
		}
		catch (Exception e)
		{
			log.Error(e, "AuthSourceMainView.GetImage couldn't get image.");

			throw new XPException(m_asOwner.GetString(80,
					ResourceConstants.PORTALADMINMSGS) + " (Image)", e);
		}
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayBody1(HTMLElementCollection result)
	{
		HTMLComment myComment = new HTMLComment( "Begin: DisplayBody AuthSource4View");
		result.AddInnerHTMLElement( myComment );


		DisplayGroupsActionBar(result);
		DisplayMiniHelp(result,m_asOwner.GetString(66, ResourceConstants.PORTALADMINMSGS));
		DisplayGroupList(result);

		myComment = new HTMLComment( "End: DisplayBody AuthSource4View");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayBody2(HTMLElementCollection result)
	{
		HTMLTable myTable;
		HTMLComment myComment = new HTMLComment( "Begin: DisplayBody AuthSource4View");
		result.AddInnerHTMLElement( myComment );


		DisplayMiniHelp(result,
			m_asOwner.GetString(2687, ResourceConstants.PORTALADMINMSGS));
		spacer2.display(result);

		myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myTable.SetBorder("0");
		result.AddInnerHTMLElement(myTable);
		int folderid = GetModel().deletedUserFolderID();
		
		String userLockURL;
		ASURL myURL = new ASURL(m_asOwner);
		UserLockManagerPlumtreeUtilities util = new UserLockManagerPlumtreeUtilities();
		myURL.SetLinkCreateNewSpace(util.GetASName(),
			m_asOwner);
		String strControl = util.GetASControlName();
		if (strControl != null)
		{
			myURL.SetControl(strControl);
		}
		String strDP = util.GetASDPName();
		if (strDP != null)
		{
			myURL.SetDisplayPage(strDP);
		}
		String strQueryString = util.GetASQueryString();
		if (strQueryString != null)
		{
			userLockURL = myURL.GetURLAsString() + strQueryString;
		}
		else
		{
			userLockURL = myURL.GetURLAsString();
		}
		HTMLAnchor userLockA = new HTMLAnchor(userLockURL);
		userLockA.AddInnerHTMLEncodedString(util.GetLinkText(XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE, m_asOwner))));
		
		DisplayCheckboxMsg(myTable, folderid,
			m_asOwner.GetString(70, ResourceConstants.PORTALADMINMSGS),
			XPFormat.Format(m_asOwner.GetString(2688, "ptmsgs_portaladminmsgs"), new String[]{userLockA.GetDisplayString()}),
			HTMLCHECKBOX_DISABLED, 1);
		spacer2.display(result);

		myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myTable.SetBorder("0");
		result.AddInnerHTMLElement(myTable);
		folderid = GetModel().deferredGroupFolderID();
		DisplayFolderBlock(myTable, folderid,
			m_asOwner.GetString(72, ResourceConstants.PORTALADMINMSGS),
			m_asOwner.GetString(73, ResourceConstants.PORTALADMINMSGS),
			HTMLCHECKBOX_DISABLED, 2);

		myComment = new HTMLComment( "End: DisplayBody AuthSource4View");
		result.AddInnerHTMLElement( myComment );

	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayBody3(HTMLElementCollection result)
	{
		HTMLComment myComment = new HTMLComment( "Begin: DisplayBody AuthSource4View");
		result.AddInnerHTMLElement( myComment );

		DisplayMiniHelp(result, m_asOwner.GetString(2661, "ptmsgs_portaladminmsgs"));

		HTMLTable myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myTable.SetBorder("0");
		result.AddInnerHTMLElement(myTable);

		HTMLTableRow myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan("2");
		myCell.SetHeight("20");
		myCell.SetNoWrap(true);
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_reenable", m_asOwner.GetString(2662, "ptmsgs_portaladminmsgs"));
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(m_asOwner.GetString(2662, "ptmsgs_portaladminmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		myInput.SetOnClick("OpenReenableUsersPopup();");

//		myInput.SetOnClick(TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE,
//			HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
//			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP,id),
//			strLang).GetOnClick()); // we create a temp anchor using treehelper and take whatever onclick there is

		myComment = new HTMLComment( "End: DisplayBody AuthSource4View");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param myCell
	 * @param id
	 *
	 * @throws HTMLException
	 */
	protected void DisplayChangeAdminFolderConstruct(HTMLTableCell myCell, int id)
	{
		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();

		HTMLInput myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_BROWSE_+id, "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(m_asOwner.GetString(77, ResourceConstants.PORTALADMINMSGS));
		myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		myInput.SetOnClick(TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE,
			HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP,id),
			strLang).GetOnClick()); // we create a temp anchor using treehelper and take whatever onclick there is

		/* version with icon+link instead of a button
		HTMLAnchor myAnchor = TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE,
				HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
				AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP,id),
				strLang);

		myAnchor.GetOnClick()
		myCell.AddInnerHTMLElement(myAnchor);

		HTMLImg myImg = GetImage(PTImageType.ICON_FOLDER,
				m_asOwner.GetString(77, ResourceConstants.PORTALADMINMSGS), "18", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myAnchor.AddInnerHTMLString(m_asOwner.GetString(77,
				ResourceConstants.PORTALADMINMSGS));
		*/
}

	/**
	 *
	 *
	 * @param myTable
	 * @param folderid
	 * @param s1
	 * @param s2
	 * @param CHECKBOX
	 * @param actionid
	 *
	 * @throws HTMLException
	 */
	protected void DisplayFolderBlock(HTMLTable myTable, int folderid, String s1,
		String s2, String CHECKBOX, int actionid)
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
//		HTMLInput myInput;
		HTMLSpan mySpan;

		DisplayCheckboxMsg(myTable, folderid, s1, null, CHECKBOX, actionid);

		// place in folder
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell.SetHeight("20");
		myCell.SetWidth("30%");
		myCell.SetVAlign("top");
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		mySpan.AddInnerHTMLString(s2);

		// folder
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		if (folderid == -1)
		{
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);

			mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE + m_asOwner.GetString(79, ResourceConstants.PORTALADMINMSGS) +	CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);
		}
		else
		{
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE + XPHttpUtility.HtmlEncode(folderName(folderid)) +	CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);
		}

		// change folder
		DisplayChangeAdminFolderConstruct(myCell, actionid);
	}

	/**
	 *
	 *
	 * @param myTable
	 * @param folderid
	 * @param s1
	 * @param s2
	 * @param CHECKBOX
	 * @param actionid
	 *
	 * @throws HTMLException
	 */
	protected void DisplayCheckboxMsg(HTMLTable myTable, int folderid, String s1,
		String s2, String CHECKBOX, int actionid)
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		// checkbox
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan("2");
		myCell.SetHeight("20");
		myCell.SetNoWrap(true);
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, CHECKBOX, "");
		myInput.SetChecked(folderid != 0);
		myInput.SetValue(XPConvert.ToString(actionid));
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetOnClick("postToSelf(" +	// mj: removed 'Javascript:' from function name
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP,actionid) + ");  return false;");
		myInput.SetOnKeyPress("postToSelf(" +	// mj: removed 'Javascript:' from function name
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP,actionid) + ");  return false;");
		myCell.AddInnerHTMLElement(myInput);

		// message
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE + s1);
		
		if (null != s2 && !s2.equals(""))
		{
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell.SetHeight("20");
			myCell.SetWidth("30%");
			myCell.SetVAlign("top");
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			mySpan.AddInnerHTMLString(s2);
		}
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupList(HTMLElementCollection result)
	{
		HTMLTable myTable;

		HTMLComment myComment = new HTMLComment( "Begin: AuthSourceMainView.DisplayGroupList");
		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("2");
		myTable.SetBorder("0");
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");

		// items
		Object[][] groups = GetModel().fullySyncedGroups();

		if ((groups == null) || (groups[0].length == 0))
		{
			DisplayRowForEmptyList(myTable);
		}
		else
		{
			m_styleListItem = null;
			DisplayGroupListHeader(myTable);

			for (int i = 0; i < groups[0].length; i++)
			{
				int id  = XPConvert.ToInteger(groups[0][i]);
				String name = (String) groups[1][i];
				DisplayGroupListItem(myTable, id, name);
			}
		}

		myComment = new HTMLComment( "End: AuthSourceMainView.DisplayGroupList");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param myTable
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupListHeader(HTMLTable myTable)
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;
		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
		myTable.AddInnerHTMLElement(myRow);

		//1 delete
		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetVAlign("center");
		myCell.SetAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_GROUP,
				m_asOwner.GetString(68, ResourceConstants.PORTALADMINMSGS));
		myInput.SetChecked(false);
		myInput.SetValue("-1"); // all
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetOnClick("CheckAllAsFirst(); return false;");
		myCell.AddInnerHTMLElement(myInput);

		//2 group
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");

		////myCell.SetWidth("150");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(62,
				ResourceConstants.PORTALADMINMSGS));
	}

	/**
	 *
	 *
	 * @param myTable
	 * @param id
	 * @param name
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupListItem(HTMLTable myTable, int id, String name)
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		HTMLImg myImg;
		myRow = new HTMLTableRow();

		m_styleListItem = ((m_styleListItem == null) || (m_styleListItem == PTStyleClass.LIST_ITEM_ONE_BG)) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG;

		myRow.SetStyleClass(m_styleListItem);
		myTable.AddInnerHTMLElement(myRow);

		//1 delete
		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetVAlign("center");
		myCell.SetAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_GROUP,
				m_asOwner.GetString(67, ResourceConstants.PORTALADMINMSGS) + " \"" +
				name + "\"");
		myInput.SetChecked(false);
		myInput.SetValue(XPConvert.ToString(id));
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myCell.AddInnerHTMLElement(myInput);

		//2 group
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		if (id != 0)
		{
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

			// view group on click
			String openGroupURL = PTOpenerLinks.GetJSOpenInSameWindow(
				PTOpenerLinks.GetOpenerJSURLOpenObjID(PT_CLASSIDS.PT_USERGROUP_ID, 
			        id, null, IPTOpenerConstants.OPENER_MODE_EDIT));
			myAnchor.SetOnClick(openGroupURL + "; return false;");

			myImg = GetImage(PTImageType.ICON_GROUP,
					m_asOwner.GetString(62, ResourceConstants.PORTALADMINMSGS), "18","20");
			myImg.SetAlign("absMiddle");
			myAnchor.AddInnerHTMLElement(myImg);
			myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(name));
			myCell.AddInnerHTMLElement(myAnchor);
		}
		else
		{
			myImg = GetImage(PTImageType.ICON_GROUP,m_asOwner.GetString(62, ResourceConstants.PORTALADMINMSGS), "18","20");
			myImg.SetAlign("absMiddle");
			myCell.AddInnerHTMLElement(myImg);
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE+name);
		}

		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupsActionBar(HTMLElementCollection result)
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLAnchor myAnchor;
		HTMLImg myImg;

		HTMLComment myComment = new HTMLComment( "Begin: AuthSource4View.DisplayGroupsActionBar");
		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("0");
		myTable.SetBorder("0");
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

		// add group
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();

		myAnchor = TreeHelper.makeTreeAnchor(USERGROUPTREESPACE,
			HTMLHIDDEN_SPACEID_USERGROUPTREESPACE,
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_ADD_SYNC_GROUP,0), strLang);
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myImg = GetImage(PTImageType.ACTION_ADD,
				m_asOwner.GetString(63, ResourceConstants.PORTALADMINMSGS), "6", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		myImg = GetImage(PTImageType.ICON_GROUP,
				m_asOwner.GetString(63, ResourceConstants.PORTALADMINMSGS), "20", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE+ m_asOwner.GetString(63,
				ResourceConstants.PORTALADMINMSGS) + CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// add all groups
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		// mj: replaced the following line with a blank constructur and SetOnClick()
		// myAnchor = new HTMLAnchor("postToSelf(" +
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf(" +
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_ADD_ALL_SYNC_GROUPS,0) + "); return false;");
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myImg = GetImage(PTImageType.ACTION_ADD,
				m_asOwner.GetString(64, ResourceConstants.PORTALADMINMSGS), "6", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		myImg = GetImage(PTImageType.ICON_GROUP,
				m_asOwner.GetString(64, ResourceConstants.PORTALADMINMSGS), "18", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE+ m_asOwner.GetString(64,
				ResourceConstants.PORTALADMINMSGS) + CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// delete group
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		// mj: replaced the following line with a blank constructur and SetOnClick()
		// myAnchor = new HTMLAnchor("postToSelf(" +
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf(" +
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_DEL_SYNC_GROUP,0) + "); return false;");
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myImg = GetImage(PTImageType.ACTION_DELETE,
				m_asOwner.GetString(65, ResourceConstants.PORTALADMINMSGS), "25", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// last
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetWidth("100%");

		myComment = new HTMLComment( "End: AuthSource4View.DisplayGroupsActionBar");
		result.AddInnerHTMLElement( myComment );


	}

	/**
	 *
	 *
	 * @param result
	 * @param s
	 *
	 * @throws HTMLException
	 */
	protected void DisplayHeader(HTMLElementCollection result, String s)
	{
		result.AddInnerHTMLElement(super.GetHeaderView(s));
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayHiddenInputs(HTMLElementCollection result)
	{
		HTMLInput myInput;

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue((GetModel().lastTreeSpaceId_ADMINFOLDERTREESPACE() == null)
			? "" : GetModel().lastTreeSpaceId_ADMINFOLDERTREESPACE());

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				HTMLHIDDEN_SPACEID_USERGROUPTREESPACE, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue((GetModel().lastTreeSpaceId_USERGROUPTREESPACE() == null)
			? "" : GetModel().lastTreeSpaceId_USERGROUPTREESPACE());

		// hidden input to hold repost action on tree submit
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_TREEREPOST, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue("");
	}

	/**
	 *
	 *
	 * @param result
	 * @param s
	 *
	 * @throws HTMLException
	 */
	protected void DisplayMiniHelp(HTMLElementCollection result, String s)
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		HTMLComment myComment = new HTMLComment( "Begin: AuthSourceMainView.DisplayMiniHelp");
		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myTable.SetBorder("0");
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		mySpan.AddInnerHTMLString(s);

		myComment = new HTMLComment( "End: AuthSourceMainView.DisplayMiniHelp");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param myTable
	 *
	 * @throws HTMLException
	 */
	protected void DisplayRowForEmptyList(HTMLTable myTable)
	{
		HTMLTableRow myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);

		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetStyleClass(PTStyleClass.TIPS_TEXT);

		myCell.AddInnerHTMLElement( new HTMLP() );

		HTMLSpan mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);
		mySpan.AddInnerHTMLString(GetModel().GetEmptyListMainMessage());
		myCell.AddInnerHTMLElement(new HTMLBr());
		myCell.AddInnerHTMLString(GetModel().GetEmptyListInstructions());
		myCell.AddInnerHTMLString("</p>");
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	protected String folderName(int id)
	{
		String result = m_asOwner.GetString(74, ResourceConstants.PORTALADMINMSGS);

		if (id != 0)
		{
			IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

			try
			{
				IPTAdminFolder ptFolder = ptSession.GetAdminCatalog()
					.OpenAdminFolder(id, false);
				result = ptFolder.GetLocalizedName();
			}
			catch (Exception e)
			{
				result = m_asOwner.GetString(78, ResourceConstants.PORTALADMINMSGS);
			}
		}

		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected IAuthSourceModelRO GetModel()
	{
		return (IAuthSourceModelRO) m_model;
	}
}

