package com.plumtree.portalpages.admin.editors.authsource;


// Framework imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author
 */
public class AuthSourceDependenciesView extends ObjDependenciesView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.authsource.AuthSourceDependenciesView");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "AuthSourceDependencies";


	public static final int OFFSET = -1; // <0 use default, 0 none, >0 use specified


	public static final int BREAK = -1; // <0 use default, 0 none, >0 use specified

	protected CreatedHelper m_helper;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AuthSourceDependenciesView();
	}

	/**
	 *
	 *
	 * @return
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		try
		{
			helper().addJobJavascript(myScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "AuthSourceDependenciesView::DisplayJavascript An error occured when trying to display the JavaScript.");
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		helper().displayEmptyRow(result);
		helper().displayTextRow(result,
			m_asOwner.GetString(1718, ResourceConstants.PORTALADMINMSGS), null);
		helper().displayTextRow(result, OFFSET, m_asOwner.GetString(1712, ResourceConstants.PORTALADMINMSGS) + ":",
			model().GetObjectName());
		helper().displayTextRow(result, OFFSET, m_asOwner.GetString(1716, ResourceConstants.PORTALADMINMSGS) + ":",
			model().GetParentFolderPath(), BREAK);
		helper().displayJobRows(result, m_asOwner.GetString(1713, ResourceConstants.PORTALADMINMSGS), m_asOwner.GetString(1714, ResourceConstants.PORTALADMINMSGS));

		String folderpath = model().userFolderPathIfSingle();

		if (folderpath != null)
		{
			helper().displayTextRow(result, m_asOwner.GetString(1717, ResourceConstants.PORTALADMINMSGS), null);
			helper().displayTextRow(result, OFFSET, m_asOwner.GetString(1719, ResourceConstants.PORTALADMINMSGS), folderpath);
		}
		else
		{
			helper().displayTextRow(result, m_asOwner.GetString(1715, ResourceConstants.PORTALADMINMSGS), null);
		}

		helper().displayEmptyRow(result);

		helper().displayEveryoneWarning(result, (AuthSourceModel) m_model, m_asOwner.GetString(1712, ResourceConstants.PORTALADMINMSGS));

		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected CreatedHelper helper()
	{
		if (m_helper == null)
		{
			m_helper = new CreatedHelper(m_asOwner, model());
		}

		return m_helper;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected AuthSourceModel model()
	{
		return (AuthSourceModel) m_model;
	}
}

