package com.plumtree.portalpages.admin.editors.authsource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
/**
 * This class is designed to be subclassed by the two "leaf" Auth Source
 * editors, LDAP and Remote.  Remote incorporates XUI, thereby allowing its use
 * for extensible auth sources.
 *
 * @author OlegS
 */
public abstract class AuthSourceMainView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.authsource.AuthSourceMainView");

	/** HTML element name */
	public static final String HTMLINPUT_AuthenticationSourceCategory = "in_tx_AuthenticationSourceCategory";

	/** HTML element name */
	public static final String HTMLINPUT_TEMPLATES = "in_se_Templates";

	/** HTML element name */
	public static final String HTMLINPUT_PROFILES_ = "in_se_Profiles_"; // +group id

	/** HTML element name */
	public static final String JAVASCRIPT_CREATEDEFAULTPROFILE = "createDefaultProfile";

	/** HTML element name */
	public static final String HTMLCHECKBOX_GROUP = "in_cb_group";

	/** A name for the sub activity space for the admin folder tree */
	public static final String ADMINFOLDERTREESPACE = "FolderTree";

	/** A name for the sub activity space for another admin folder tree */
	public static final String ADMINFOLDERTREESPACE_NEWGROUP = "FolderTreeNG";

	/** A name for the user group tree sub-space */
	public static final String USERGROUPTREESPACE = "UserGroupTree";

	/** HTML element name */
	public static final String HTMLHIDDEN_TREEREPOST = "in_hi_TreeRepostAction";

	/** HTML element name */
	public static final String HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE = "in_hi_SpaceID_AF";

	/** HTML element name */
	public static final String HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE_NEWGROUP = "in_hi_SpaceID_AFNG";

	/** HTML element name */
	public static final String HTMLHIDDEN_SPACEID_USERGROUPTREESPACE = "in_hi_SpaceID_UG";

	public static final String HTMLBUTTON_BROWSE_ = "in_bu_browse_"; // +id

	static Spacer spacer15 = new Spacer("15");


	// member variables
	protected PTStyleClass m_styleListItem = null;

	/**
	 * This function displays the HTML for this view
	 *
	 * @return No return value
	 */
	public HTMLElement Display()
	{
		try
		{
			HTMLElementCollection result = new HTMLElementCollection();


			HTMLComment myComment = new HTMLComment( "Begin: Display AuthSourceMainView");
			result.AddInnerHTMLElement( myComment );

			DisplayHiddenInputs(result);
			DisplayCommonProperties(result);
			spacer15.display(result);

			if (((AuthSourceEditorAS) m_asOwner).WantTemplatesSection() &&
					(EditorStartControl.EDITOR_START_FLAG_CREATE == ((IAuthSourceModelRO) m_model).GetEditorType()))
			{
				DisplayTemplateSelectionHeader(result);
				DisplayTemplateSelectionBody(result);
				spacer15.display(result);
			}

			int mode = GetModel().supportSyncMode();

			if (mode != PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_AUTHONLY)
			{
				DisplayDefaultProfilesHeader(result);
				DisplayProfilesActionBar(result);
				DisplayDefaultProfilesMiniHelp(result);

				Object[][] profiles = GetModel().defaultProfiles();
				DisplayGroupList(result, profiles);
				spacer15.display(result);

				DisplayNewGroupsFolderHeader(result);
				DisplayNewGroupsFolder(result);
			}


			myComment = new HTMLComment( "End: Display AuthSourceMainView");
			result.AddInnerHTMLElement( myComment );

			return result;
		}
		catch (Exception e)
		{
			log.Error("AuthSourceMainView::Display The following error occured when trying to display the HTML: " +
				e.getMessage());

			throw new XPException(m_asOwner.GetString(112,
					ResourceConstants.PORTALADMINMSGS), e);
		}
	}

	/**
	 * This function displays the javascript functions for this view
	 *
	 * @return No return value
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		try
		{
			myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(
					m_asOwner, ADMINFOLDERTREESPACE,
					HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
					HTMLHIDDEN_TREEREPOST,
					m_asOwner.GetString(104, ResourceConstants.PORTALADMINMSGS),
					m_asOwner.GetString(105, ResourceConstants.PORTALADMINMSGS),
					PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
					PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,
					TreeConstants.N_COMPOSITESELECT, false, true, null));

			String hideids = GetModel().joinLists(
				GetModel().listOfAlienGroups(),
				GetModel().listOfMappedGroups());
			myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(
					m_asOwner, USERGROUPTREESPACE,
					HTMLHIDDEN_SPACEID_USERGROUPTREESPACE,
					HTMLHIDDEN_TREEREPOST,
					m_asOwner.GetString(101, ResourceConstants.PORTALADMINMSGS),
					m_asOwner.GetString(102, ResourceConstants.PORTALADMINMSGS),
					PT_CLASSIDS.PT_USERGROUP_ID,
					PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,
					TreeConstants.N_LEAFSELECT, true, false,
					hideids));

			myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(
					m_asOwner, ADMINFOLDERTREESPACE_NEWGROUP,
					HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE_NEWGROUP,
					HTMLHIDDEN_TREEREPOST,
					m_asOwner.GetString(104, ResourceConstants.PORTALADMINMSGS),
					m_asOwner.GetString(105, ResourceConstants.PORTALADMINMSGS),
					PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
					PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,
					TreeConstants.N_COMPOSITESELECT, false, true, null, GetModel().listOfNewGroupsFolder()));

			myScript.AddInnerHTMLString(
			"function CheckAllAsFirst() { \n"+
			"var frm = document.mainform; \n"+
			"var len = frm.elements.length; \n"+
			"var state = -1; \n"+
			"var i = 0; \n"+
			"for(i=0 ; i<len ; i++) { \n"+
			"if(frm.elements[i].name == 'in_cb_group') { \n"+
			"if(state<0) \n"+
			"state=frm.elements[i].checked; \n"+
			"else if(!frm.elements[i].disabled) \n"+
			"frm.elements[i].checked = state; \n"+
			"} \n"+
			"} \n"+
			"} \n"
			);
		}
		catch (Exception e)
		{
			log.Error("AuthSourceMainView.DisplayJavascript couldn't add javascript to the HTMLScript element: " +
				e.getMessage());

			throw new HTMLException(m_asOwner.GetString(112,
					ResourceConstants.PORTALADMINMSGS) + " (Javascript) "+ e);
		}

		return myScript;
	}

	/**
	 *
	 *
	 * @param type
	 * @param alt
	 * @param w
	 * @param h
	 *
	 * @return
	 */
	protected HTMLImg GetImage(PTImageType type, String alt, String w, String h)
	{
		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(type,
					true, this.m_asOwner);
			HTMLImg myImg		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImg.SetAlt(alt);
			myImg.SetBorder("0");
			myImg.SetWidth(w);
			myImg.SetHeight(h);

			return myImg;
		}
		catch (Exception e)
		{
			log.Error("AuthSourceMainView.GetImage couldn't get image: " +
				e.getMessage());

			throw new XPException(m_asOwner.GetString(112,
					ResourceConstants.PORTALADMINMSGS) + " (Image)", e);
		}
	}

	/**
	 *
	 *
	 * @param myCell
	 * @param id
	 *
	 * @throws HTMLException
	 */
	protected void DisplayChangeAdminFolderConstruct(HTMLTableCell myCell, int id)
	{
		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();

		/* version with button instead of icon+link
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_BROWSE_ + id, "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(m_asOwner.GetString(106, ResourceConstants.PORTALADMINMSGS));
		myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		myInput.SetOnClick(TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE,
				HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
				AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_TARGET_FOLDER,id), strLang).GetOnClick()); // we create a temp anchor using treehelper and take whatever onclick there is
		*/

		/* version with icon+link instead of a button */
		HTMLAnchor myAnchor = TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE,
			HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_TARGET_FOLDER,id), strLang);
		myCell.AddInnerHTMLElement(myAnchor);

		HTMLImg myImg = GetImage(PTImageType.ICON_FOLDER,
				m_asOwner.GetString(106, ResourceConstants.PORTALADMINMSGS), "18", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myAnchor.AddInnerHTMLString(m_asOwner.GetString(106,
				ResourceConstants.PORTALADMINMSGS));
		/* */

		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}

	/**
	 *
	 *
	 * @param myCell
	 *
	 * @throws HTMLException
	 */
	protected void DisplayChangeAdminFolderConstruct_NewGroup(HTMLTableCell myCell)
	{

		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();

		HTMLInput myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_BROWSE_ + "ng", "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(m_asOwner.GetString(106, ResourceConstants.PORTALADMINMSGS));
		myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		myInput.SetOnClick(TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE_NEWGROUP,
			HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE_NEWGROUP,
		  AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_NEW_GROUP_FOLDER,0), strLang).GetOnClick()); // we create a temp anchor using treehelper and take whatever onclick there is

		/* version with icon+link instead of a button
		HTMLAnchor myAnchor = TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE_NEWGROUP,
			HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE_NEWGROUP,
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_CHANGE_NEW_GROUP_FOLDER,0), strLang);
		myCell.AddInnerHTMLElement(myAnchor);

		HTMLImg myImg = GetImage(PTImageType.ICON_FOLDER,
				m_asOwner.GetString(106, ResourceConstants.PORTALADMINMSGS), "18", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myAnchor.AddInnerHTMLString(m_asOwner.GetString(106,
				ResourceConstants.PORTALADMINMSGS));
		*/

		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}

	/**
	 * There is only one common property, the auth source category - so we
	 * just display it here...
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayCommonProperties(HTMLElementCollection result)
	{
		result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(1722, ResourceConstants.PORTALADMINMSGS)));

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLInput myInput;

		HTMLComment myComment = new HTMLComment( "Begin: DisplayCommonProperties AuthSourceMainView");
		result.AddInnerHTMLElement( myComment );

		// aj: table for the category
		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		// aj: row for the category
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		// aj: add the "Authentication Source Category" label with a tooltip
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("150");
		myCell.AddInnerHTMLString("<a title=\"" + m_asOwner.GetString(2072, ResourceConstants.PORTALADMINMSGS) + "\" >");
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		myCell.AddInnerHTMLString("</a>");
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		mySpan.AddInnerHTMLString(m_asOwner.GetString(2049, ResourceConstants.PORTALADMINMSGS));

		// aj: new cell for the input or prefix listing
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetAlign("left");
		
		if(EditorStartControl.EDITOR_START_FLAG_EDIT == GetModel().GetEditorType() 
				&& !((IAuthSourceModelRO)m_model).GetAuthSourceCategory().equals(""))
		{
			myCell.AddInnerHTMLEncodedString(((IAuthSourceModelRO)m_model).GetAuthSourceCategory());
		}
		else
		{				
			myInput = new HTMLInput(
					HTMLInputTypes.TEXT, 
					AuthSourceMainView.HTMLINPUT_AuthenticationSourceCategory, 
					"");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetValue(((IAuthSourceModelRO)m_model).GetAuthSourceCategory());
			myInput.SetSize(28);
		}

		myComment = new HTMLComment( "End: DisplayCommonProperties AuthSourceMainView");
		result.AddInnerHTMLElement( myComment );

	}

	/**
	 *
	 *
	 * @param myCell
	 * @param id
	 * @param userid
	 * @param profiles
	 *
	 * @throws HTMLException
	 */
	protected void DisplayDefaultProfilesForGroup(HTMLTableCell myCell, int id,
		int userid, Object[][] profiles)
	{
		HTMLSelect mySelect = new HTMLSelect(HTMLINPUT_PROFILES_ + id, "");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLElement(mySelect);
		mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

		int selectedProfileId = userid;

		for (int i = 0; profiles[0][i] != null; i++)
		{
			int profileId	    = XPConvert.ToInteger(profiles[0][i]);
			String profileName  = (String) profiles[1][i];
			HTMLOption myOption = new HTMLOption(XPConvert.ToString(profileId));
			mySelect.AddInnerHTMLElement(myOption);
			myOption.AddInnerHTMLString(XPHttpUtility.HtmlEncode(profileName));

			if (profileId == selectedProfileId)
			{
				myOption.SetSelected(true);
			}
		}
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayDefaultProfilesHeader(HTMLElementCollection result)
	{
		result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(1725, ResourceConstants.PORTALADMINMSGS)));
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayDefaultProfilesMiniHelp(HTMLElementCollection result)
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLComment myComment = new HTMLComment( "Begin: AuthSourceMainView.DisplayDefaultProfilesMiniHelp");
		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(99,
				ResourceConstants.PORTALADMINMSGS));
		myComment = new HTMLComment( "End: AuthSourceMainView.DisplayDefaultProfilesMiniHelp");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param result
	 * @param profiles
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupList(HTMLElementCollection result, Object[][] profiles)
	{
		HTMLTable myTable;
		HTMLComment myComment = new HTMLComment( "Begin: AuthSourceMainView.DisplayGroupList");

		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("2");

		// header
		DisplayGroupListHeader(myTable);

		// items
		m_styleListItem = null;

		Object[][] groups = GetModel().mappedGroups(0);

		// This loops for the same length as the array,
		// but accesses into the array according to the
		// group ordering stored in the model, rather
		// than the numerical index in the array.
		for (int j = 0; j < groups[0].length; j++)
		{
			// Get the index into the array of the next group to display
			// according to the user selected ordering.
			int i			 = GetModel().groupsOrder(j);

			// Get the information about the current group to display.
			int id		 = XPConvert.ToInteger(groups[0][i]);
			String name		 = (String) groups[1][i];
			int userid   = XPConvert.ToInteger(groups[2][i]);
			int folderid = XPConvert.ToInteger(groups[3][i]);

			// Display the current group
			DisplayGroupListItem(myTable, id, name,
				userid, folderid, profiles);
		}

		myComment = new HTMLComment( "End: AuthSourceMainView.DisplayGroupList");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param myTable
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupListHeader(HTMLTable myTable)

	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;
		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
		myTable.AddInnerHTMLElement(myRow);

		//1 delete
		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetVAlign("center");
		myCell.SetAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_GROUP,
				m_asOwner.GetString(108, ResourceConstants.PORTALADMINMSGS));
		myInput.SetChecked(false);
		myInput.SetValue("-1"); // for all
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetOnClick("CheckAllAsFirst(); return false;");
		myCell.AddInnerHTMLElement(myInput);

		//2 group
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");

		////myCell.SetWidth("150");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(102,
				ResourceConstants.PORTALADMINMSGS));

		//3 profiles
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");

		////myCell.SetWidth("150");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
		mySpan.AddInnerHTMLString(m_asOwner.GetString(1726, ResourceConstants.PORTALADMINMSGS));

		//4 folder
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(107,
				ResourceConstants.PORTALADMINMSGS));
		myCell.SetColSpan("3");

		/*
		//5 change folder
		myCell=new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan=new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
		mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		//6 order
		myCell=new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan=new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
		mySpan.AddInnerHTMLString(m_asOwner.GetString(103, ResourceConstants.PORTALADMINMSGS));
		*/
	}

	/**
	 *
	 *
	 * @param myTable
	 * @param id
	 * @param name
	 * @param userid
	 * @param folderid
	 * @param profiles
	 *
	 * @throws HTMLException
	 */
	protected void DisplayGroupListItem(HTMLTable myTable, int id, String name,
		int userid, int folderid, Object[][] profiles)

	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		HTMLImg myImg;
		myRow = new HTMLTableRow();

		m_styleListItem = ((m_styleListItem == null) || (m_styleListItem == PTStyleClass.LIST_ITEM_ONE_BG)) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG;

		myRow.SetStyleClass(m_styleListItem);
		myTable.AddInnerHTMLElement(myRow);

		//1 delete
		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetVAlign("center");
		myCell.SetAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_GROUP,
				m_asOwner.GetString(109, ResourceConstants.PORTALADMINMSGS) + " \"" +
				name + "\"");
		myInput.SetChecked(false);
		myInput.SetValue(XPConvert.ToString(id));
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetDisabled(id==0);
		myCell.AddInnerHTMLElement(myInput);

		/* temp hack used to be here while SetDisabled() was not working
		if (id == 0) {
			myInput.SetImgBaseUrl("...");

			String s = myInput.GetDisplayString();
			int k    = s.indexOf('>');
			k--; // for slash

			XPStringBuilder sb = new XPStringBuilder(s.substring(0, k));
			sb.Append(" DISABLED");
			sb.Append(s.substring(k));
			myCell.AddInnerHTMLString(sb.ToString());
		}
		else
			myCell.AddInnerHTMLElement(myInput);
		*/

		//2 group
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		if (id != 0)
		{
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

			// view group on click
			String openGroupURL = PTOpenerLinks.GetJSOpenInSameWindow(
				PTOpenerLinks.GetOpenerJSURLOpenObjID(PT_CLASSIDS.PT_USERGROUP_ID, id,
					null, IPTOpenerConstants.OPENER_MODE_EDIT));
			myAnchor.SetOnClick(openGroupURL + "; return false;");

			myImg = GetImage(PTImageType.ICON_GROUP,
					m_asOwner.GetString(102, ResourceConstants.PORTALADMINMSGS), "18","20");
			myImg.SetAlign("absMiddle");
			myAnchor.AddInnerHTMLElement(myImg);
			myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			myAnchor.AddInnerHTMLString(name);
			myCell.AddInnerHTMLElement(myAnchor);
		}
		else
		{
			myImg = GetImage(PTImageType.ICON_GROUP,
					m_asOwner.GetString(102, ResourceConstants.PORTALADMINMSGS), "18","20");
			myImg.SetAlign("absMiddle");
			myCell.AddInnerHTMLElement(myImg);
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE+name);
		}

		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		//3 profiles
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);
		DisplayDefaultProfilesForGroup(myCell, id, userid, profiles);

		//4 folder
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE + XPHttpUtility.HtmlEncode(folderName(folderid)));

		//5 change folder
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetHeight("20");
		myCell.SetNoWrap(true);
		myRow.AddInnerHTMLElement(myCell);
		DisplayChangeAdminFolderConstruct(myCell, id);

		// 6 order
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetHeight("20");
		myCell.SetAlign("right");
		myCell.SetWidth("1%");
		myCell.SetNoWrap(true);
		myRow.AddInnerHTMLElement(myCell);

		if (id != 0)
		{
			DisplayMoveUpDownConstruct(myCell, id);
		}
	}

	/**
	 * Adds hidden HTML elements to the collection being displayed on the page
	 *
	 * @param result The collection to be added to
	 *
	 * @throws HTMLException
	 */
	protected void DisplayHiddenInputs(HTMLElementCollection result)

	{
		HTMLInput myInput;

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue((GetModel().lastTreeSpaceId_ADMINFOLDERTREESPACE() == null)
			? "" : GetModel().lastTreeSpaceId_ADMINFOLDERTREESPACE());

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE_NEWGROUP, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue((GetModel().lastTreeSpaceId_ADMINFOLDERTREESPACE() == null)
			? "" : GetModel().lastTreeSpaceId_ADMINFOLDERTREESPACE());

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				HTMLHIDDEN_SPACEID_USERGROUPTREESPACE, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue((GetModel().lastTreeSpaceId_USERGROUPTREESPACE() == null)
			? "" : GetModel().lastTreeSpaceId_USERGROUPTREESPACE());

		// hidden input to hold repost action on tree submit
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_TREEREPOST, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue("");
	}

	/**
	 *
	 *
	 * @param myCell
	 * @param id
	 *
	 * @throws HTMLException
	 * @throws RuntimeException
	 * @throws XPException
	 */
	protected void DisplayMoveUpDownConstruct(HTMLTableCell myCell, int id)
	{
		PTButtonType[] myType =
		{
			PTButtonType.TOP, PTButtonType.UP, PTButtonType.DOWN,
			PTButtonType.BOTTOM
		};
		int[] myAction =
		{
			AuthSourceRepostControl.ACTION_MOVE_GROUP_TOP,
			AuthSourceRepostControl.ACTION_MOVE_GROUP_UP,
			AuthSourceRepostControl.ACTION_MOVE_GROUP_DOWN,
			AuthSourceRepostControl.ACTION_MOVE_GROUP_BOTTOM
		};

		try
		{
			for (int i = 0; i < 4; i++)
			{
				PTConstruct myConstruct = UIConstructFactory.GetConstruct(myType[i],
						true, this.m_asOwner);
				myConstruct.ReplaceNestedElementsWithHTMLString(myType[i].TITLE_ELEMENT_NAME,
					"");

				HTMLAnchor myAnchor = (HTMLAnchor) myConstruct.GetNestedElement(myType[i].ANCHOR_ELEMENT_NAME);
				myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
					AuthSourceRepostControl.makeAction(myAction[i],id) + "); return false;");
				myCell.AddInnerHTMLElement(myConstruct.GetHTMLElement());
			}
		}
		catch (Exception e)
		{
			log.Error("AuthSourceMainView.DisplayMoveUpDownConstruct couldn't create construct: " +
				e.getMessage());

			throw new XPException(m_asOwner.GetString(112,
					ResourceConstants.PORTALADMINMSGS) + " (Construct)", e);
		}
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayNewGroupsFolder(HTMLElementCollection result)

	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLComment myComment = new HTMLComment( "Begin: AuthSourceMainView.DisplayNewGroupsFolder");
		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		// label
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("150");
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		mySpan.AddInnerHTMLString(m_asOwner.GetString(1728, ResourceConstants.PORTALADMINMSGS));

		// folder
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetAlign("left");
		myRow.AddInnerHTMLElement(myCell);

		int folderid = ((IAuthSourceModelRO) m_model).newGroupFolderId();
		myCell.AddInnerHTMLEncodedString(folderName(folderid));

		// change folder
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetHeight("20");
		myCell.SetNoWrap(true);
		myRow.AddInnerHTMLElement(myCell);
		DisplayChangeAdminFolderConstruct_NewGroup(myCell);

		// last
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetHeight("20");
		myCell.SetNoWrap(true);
		myCell.SetWidth("30%");
		myRow.AddInnerHTMLElement(myCell);

		myComment = new HTMLComment( "End: AuthSourceMainView.DisplayNewGroupsFolder");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayNewGroupsFolderHeader(HTMLElementCollection result)

	{
		result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(1727, ResourceConstants.PORTALADMINMSGS)));
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayProfilesActionBar(HTMLElementCollection result)

	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLAnchor myAnchor;
		HTMLImg myImg;
		HTMLComment myComment = new HTMLComment( "Begin: AuthSourceMainView.DisplayProfilesActionBar");
		result.AddInnerHTMLElement( myComment );

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

		// add group
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();

		myAnchor = TreeHelper.makeTreeAnchor(USERGROUPTREESPACE,
			HTMLHIDDEN_SPACEID_USERGROUPTREESPACE,
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_ADD_GROUP,0), strLang);
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myImg = GetImage(PTImageType.ACTION_ADD,
				m_asOwner.GetString(101, ResourceConstants.PORTALADMINMSGS), "6", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		myImg = GetImage(PTImageType.ICON_GROUP,
				m_asOwner.GetString(64, ResourceConstants.PORTALADMINMSGS), "18", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE+m_asOwner.GetString(101,
				ResourceConstants.PORTALADMINMSGS) + CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// delete group
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		//Set the anchor HREF
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
			AuthSourceRepostControl.makeAction(AuthSourceRepostControl.ACTION_DEL_GROUP,0) + "); return false;");
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myImg = GetImage(PTImageType.ACTION_DELETE,
				m_asOwner.GetString(100, ResourceConstants.PORTALADMINMSGS), "25", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// last
		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetWidth("100%");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myRow.AddInnerHTMLElement(myCell);
		myComment = new HTMLComment( "End: AuthSourceMainView.DisplayProfilesActionBar");
		result.AddInnerHTMLElement( myComment );
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayTemplateSelectionBody(HTMLElementCollection result)

	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLSelect mySelect;
		HTMLComment myComment = new HTMLComment( "Begin: DisplayTemplateSelectionBody AuthSourceMainView");
		result.AddInnerHTMLElement(myComment);
		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("150");

		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		mySpan.AddInnerHTMLString(m_asOwner.GetString(1723, ResourceConstants.PORTALADMINMSGS));

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetAlign("left");
		mySelect = new HTMLSelect(HTMLINPUT_TEMPLATES, "");
		myCell.AddInnerHTMLElement(mySelect);
		mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

		int n = GetModel().numTemplates();

		for (int i = -1; i < n; i++)
		{
			HTMLOption myOption = new HTMLOption(XPConvert.ToString(i));
			mySelect.AddInnerHTMLElement(myOption);

			myOption.AddInnerHTMLString((i == -1)	? m_asOwner.GetString(1724, ResourceConstants.PORTALADMINMSGS) : XPHttpUtility.HtmlEncode(GetModel().templateName(i)));
			if (i == GetModel().selectedTemplate())
				myOption.SetSelected(true);
		}

		myComment = new HTMLComment( "End: DisplayTemplateSelectionBody AuthSourceMainView");
		result.AddInnerHTMLElement(myComment);
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayTemplateSelectionHeader(HTMLElementCollection result)

	{
		result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(94,
					ResourceConstants.PORTALADMINMSGS)));
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	protected String folderName(int id)
	{
		String result = m_asOwner.GetString(110, ResourceConstants.PORTALADMINMSGS);

		if (id != 0)
		{
			IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

			try
			{
				IPTAdminFolder ptFolder = ptSession.GetAdminCatalog()
					.OpenAdminFolder(id, false);
				result = ptFolder.GetLocalizedName();
			}
			catch (Exception e)
			{
				result = m_asOwner.GetString(111, ResourceConstants.PORTALADMINMSGS) +
					": " + XPConvert.ToString(id);
			}
		}

		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected IAuthSourceModelRO GetModel()
	{
		return (IAuthSourceModelRO) m_model;
	}
}

