package com.plumtree.portalpages.admin.editors.authsource;

import com.plumtree.openfoundation.io.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.common.setjob.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author OlegS
 */
public abstract class AuthSourceModel extends ObjEditorModel
	implements IAuthSourceModelRO, PropertyValidatorOwner
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.authsource.AuthSourceModel");

	protected static final String templatesDir	    = "ldap";
	protected static final String templatesPatttern = templatesDir + XPFileSystemObject.GetPathSeparator() + "*.xml";


	public String m_lastTreeSpaceId_ADMINFOLDERTREESPACE = null;


	public String m_lastTreeSpaceId_USERGROUPTREESPACE = null;


	public XPStringBuilder m_errors;


	public int m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED; // set just before SavePage() from SetRepostAction() hook


	public int m_templateSelected = -1;
	
	// aj: the category as a String
	protected String m_sCategory;

	// member variables
	protected XPArrayList m_ActionData = null;
	protected XPArrayList m_groupsOrder;
	protected int m_iddefFolder = 0;
	protected Object m_originalPassword;
	protected boolean m_sameTimeCreatedAndModified;
	protected int m_nReenabled = 0;
	protected boolean m_bImportCrossASMemberships;

	/**
	 * Creates a new AuthSourceModel object.
	 */
	public AuthSourceModel()
	{
		super();
		m_errors = new XPStringBuilder();
		m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
		m_groupsOrder = new XPArrayList();
		m_groupsOrder.Add(new Integer(0));
	}

	public void Init(AActivitySpace parent) {
		super.Init(parent);
	}

	/**
	 *
	 *
	 * @return
	 */
	/**
	 *
	 *
	 * @return
	 */
	public XPStringBuilder GetErrorString()
	{
		return m_errors;
	}

	/**
	 *
	 */
	public void DoTaskAfterStore()
	{
		((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskAfterStoreSetJob();
	}

	/**
	 *
	 */
	public void DoTaskBeforeStore()
	{
		((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStoreSetJob();
	}

	/**
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();

		((SelectPTObjectModel) m_asOwner.GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).DoTaskOnComeBackFromSubEditor();
	}

	/**
	 *
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		Object[][] groups = mappedGroups(0);
		for (int i = 0; i < groups[0].length; i++)
		{
			m_groupsOrder.Add(new Integer(i));
		}

		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		XPDateTime dtc= ptAS.GetCreated();
		XPDateTime dtm= ptAS.GetLastModified();
		m_sameTimeCreatedAndModified=(dtc.GetTimeInMilliSeconds()==dtm.GetTimeInMilliSeconds());

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			((EditorAS)m_asOwner).GetLeftMenu().SetMandatoryPage(false,
				((AuthSourceEditorAS)m_asOwner).GetPageNameMain());

			// aj: load the category here
			m_sCategory = ptAS.GetPrefixString();
			if(m_sCategory == null)
			{
				m_sCategory = "";
			}
		}
		else
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
			
			// aj: category is empty
			m_sCategory = "";
			
			// aj: bug 27447 - create the disabled group folder...
			CreateDisabledGroupFolder(ptAS);
		}

		((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskOnStartSetJob(m_ptObject,
			m_Session, GetEditorType());

		onPossibleChangeOfSyncMode(-1);
		
		// aj: initialize the cross memberships flag
		m_bImportCrossASMemberships = ptAS.GetImportCrossASMembers();
	}

	/**
	 * Creates a disabled group folder and associated with the given
	 * auth source.
	 * 
	 * @param ptAS - IPTAuthSource to associate the disabled folder with...
	 */
	protected void CreateDisabledGroupFolder(IPTAuthSource ptAS)
	{
		int nAuthSourceFolderID = ptAS.GetAdminFolderID();
		if(nAuthSourceFolderID > 0)
		{
			// aj: try to create a new folder, we may not have permissions to
			//     in which case we should not fail
			try{
				IPTAdminCatalog pCat = m_Session.GetAdminCatalog();
				IPTAdminFolder pDisabledGroupFolder = 
					pCat.CreateAdminFolder(nAuthSourceFolderID, 
							PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_REGULARFOLDER);
				pDisabledGroupFolder.SetName(m_asOwner.GetString(3167, ResourceConstants.PORTALADMINMSGS));
				pDisabledGroupFolder.Store();
				pDisabledGroupFolder.UnlockObject();
				int nDisabledGroupFolderID = pDisabledGroupFolder.GetObjectID();
				
				// aj: if successful, then set on the auth source
				if(nDisabledGroupFolderID > 0)
				{
					ptAS.SetDeletedGroupFolderID(nDisabledGroupFolderID);
				}
			} catch (XPException xpe)
			{
				// aj: log and skip this step...
				log.Warn(xpe, "AuthSourceModel::CreateDisabledGroupFolder - Unable to create a 'Groups to Delete' folder for new Authentication Source. User will have to manually create this directory and specify it in the editor.");
			}
		}
	}

	/**
	 *
	 *
	 * @param o
	 *
	 * @return
	 */
	public String ExtractOneElement(Object o)
	{
		if (o == null)
		{
			return null;
		}

		String[] sa   = (String[]) o;
		String result = ((sa == null) || (sa.length < 1)) ? null : sa[0];

		if ((result == null) || (result.trim().length() < 1))
		{
			result = null;
		}

		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetEmptyListInstructions()
	{
		return m_asOwner.GetString(2058, ResourceConstants.PORTALADMINMSGS);
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetEmptyListMainMessage()
	{
		return m_asOwner.GetString(2057, ResourceConstants.PORTALADMINMSGS);
	}

	/**
	 *
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		TraceHelper.Trace("SavePage(" + _sPageName + ")");
		TraceHelper.TraceQueryString(_htFormData);

		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(
					((AuthSourceEditorAS) m_asOwner).GetPageNameMain()))
		{
			nPageStatus = SaveMainPage(_htFormData);
		}
		else if (_sPageName.equals(
					((AuthSourceEditorAS) m_asOwner).GetPageName2()))
		{
			nPageStatus = SavePage2(_htFormData);
		}
		else if (_sPageName.equals(
					((AuthSourceEditorAS) m_asOwner).GetPageName3()))
		{
			nPageStatus = SavePage3(_htFormData);
		}
		else if (_sPageName.equals(
					((AuthSourceEditorAS) m_asOwner).GetPageName4()))
		{
			nPageStatus = SavePage4(_htFormData);
		}
		else if (_sPageName.equals(SetJobDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = ((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
		}

		if(m_nAction==AuthSourceRepostControl.POSTTOSELF_ACTION_FINISH)
			validateAllProperties(); // in case Finish is hit on main or other page
		else if(_sPageName.equals(((AuthSourceEditorAS)m_asOwner).GetPageNameMain()))
			validatePage1Properties();
		else if((!_sPageName.equals(((AuthSourceEditorAS)m_asOwner).GetPageName3())) &&
		(!_sPageName.equals(((AuthSourceEditorAS)m_asOwner).GetPageName4())))
			validatePage2Properties();

		if(m_nAction==AuthSourceRepostControl.POSTTOSELF_ACTION_FINISH ||
		   m_nAction==AuthSourceRepostControl.POSTTOSELF_ACTION_GOTOPAGE) {
			//	validate folders selected on fully sync page; note that onChangeCheckboxForSyncGroup is hit after this point
			IPTAuthSource ptAS = (IPTAuthSource) GetObject();
//			int folderid=ptAS.GetDeletedUserFolderID();
//			if(folderid==-1)
//				SetInvalid(m_asOwner.GetString(2440, ResourceConstants.PORTALADMINMSGS)); //"Folder for disabled users is empty"
			int folderid=ptAS.GetDeletedGroupFolderID();
			if(folderid==-1)
				SetInvalid(m_asOwner.GetString(2441, ResourceConstants.PORTALADMINMSGS)); //"Folder for disabled groups is empty"
		}

		if (m_errors.GetLength() > 0)
		{
			nPageStatus = RepostControl.PAGE_STATUS_INVALID;

			String msg	    = m_asOwner.GetString(2055, ResourceConstants.PORTALADMINMSGS)+ " " + m_errors.ToString();
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, msg, msg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());

			m_errors.SetLength(0);
		}
		return nPageStatus;
	}

	protected void validateAllProperties() {
		validatePage1Properties();
		validatePage2Properties();
	}

	protected void validatePage1Properties() {
		// aj: if there are no errors yet, then go ahead
		//     and validate the category...
		if(m_errors.GetLength() == 0) {
			if(m_sCategory == null || m_sCategory.trim().length() == 0)
			{
				String sErrorMsg = m_asOwner.GetString(3122, ResourceConstants.PORTALADMINMSGS);
				m_errors.Append(sErrorMsg);
			}
		}
	}

	protected void validatePage2Properties() {
	}

	/**
	 *
	 *
	 * @param doFilterByAuthSource
	 *
	 * @return
	 */
	public Object[][] allGroups(boolean doFilterByAuthSource)
	{
		PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetUserGroups());
		int fields						  = PT_PROPIDS.PT_PROPID_OBJECTID |
			PT_PROPIDS.PT_PROPID_NAME; //|PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
		Object[][] filter				  = null;

		if (doFilterByAuthSource)	{
			filter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_USERGROUP_AUTHSOURCE,
					PT_FILTEROPS.PT_FILTEROP_EQ, new Integer(GetObjectID()));
		}

		query.SetMaxRows(10000);
		query.Query(fields, -1, null, filter);
		int n	= query.GetCount();
		// if(n==10000) - filtering will be imperfect

		Object[][] result = null;

		if(n>0) {
			result=new Object[4][n];
			for (int i = 0; i < n; i++)	{
				int id   = XPConvert.ToInteger(query.GetItem(i,
					PT_PROPIDS.PT_PROPID_OBJECTID));
				String name  = (String) query.GetItem(i, PT_PROPIDS.PT_PROPID_NAME);
				result[0][i] = new Integer(id);
				result[1][i] = name;
				result[2][i] = null;
				result[3][i] = null;
			}
		}

		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	public AActivitySpace asOwner()
	{
		return m_asOwner;
	}

	/**
	 *
	 *
	 * @return
	 */
	public Object[][] authPartners()
	{
		PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetAuthSources());
		int fields						  = PT_PROPIDS.PT_PROPID_OBJECTID |
			PT_PROPIDS.PT_PROPID_NAME; //|PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
		Object[][] filter				  = new Object[3][3];
		filter[0][0]					  = new Integer(PT_PROPIDS.PT_PROPID_AUTHSOURCE_SUPPORTSSYNC); // filter SYNCONLY authsources out, cannot use these as partners
		filter[1][0]					  = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		filter[2][0]					  = new Integer(PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_SYNCONLY);
		filter[0][1]					  = new Integer(PT_PROPIDS.PT_PROPID_AUTHSOURCE_AUTHTYPE); // don't want the default Plumtree User Database to appear as AuthPartner
		filter[1][1]					  = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		filter[2][1]					  = new Integer(PT_AUTHTYPES.PT_AUTHTYPE_PLUMTREE);
		filter[0][2]					  = new Integer(PT_PROPIDS.PT_PROPID_OBJECTID); // don't want current object; for creation means id!=0 and is Ok
		filter[1][2]					  = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		filter[2][2]					  = new Integer(GetObjectID());
		query.Query(fields, -1, null, filter);

		int n			  = query.GetCount();
		Object[][] result = new Object[2][n + 1];

		int indPartner;
		for (indPartner = 0; indPartner < n; indPartner++)
		{
			int id   = XPConvert.ToInteger(query.GetItem(indPartner,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String name  = (String) query.GetItem(indPartner, PT_PROPIDS.PT_PROPID_NAME);
			result[0][indPartner] = new Integer(id);
			result[1][indPartner] = name;
		}
		
		// Add SSO Auth Partner
		result[0][indPartner] = new Integer(PT_INTRINSICS.PT_AUTHSOURCE_SSO);
		result[1][indPartner] = m_asOwner.GetString(3064, "ptmsgs_portaladminmsgs");
		
		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int bulkCopyNum()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetBulkCopyNum();
	}

	/**
	 *
	 *
	 * @param m_props
	 * @param ptAS
	 * @param idx_start
	 */
	public void copyDataFromAuthSourceToPropValues(
			XPArrayList m_props,
			IPTAuthSource ptAS, 
			int idx_start)
	{
//		for (IXPEnumerator i = m_props.GetEnumerator(); i.MoveNext();)
//		{
//			PropertyValue pv = (PropertyValue) i.GetCurrent();
//			String name		 = (String) pv.idServer();
//			
//		}

//		IXPPropertyBag ptBag = ptAS.GetProviderInfo();
//		String sCategory = ptBag.ReadAsString("RAP_AUTH_CATEGORY");
//		if(sCategory == null)
//		{
//			m_authenticationSourceCategory = "";
//		} else {
//			m_authenticationSourceCategory = sCategory;
//		}
	}

	protected void SetInvalid(String s) {
		if(s.startsWith("Native exception:")) { // remove unneccesary details
			int b=s.indexOf('[');
			if(b>=0) {
				int e=s.indexOf(']',b);
				if(e>b+10) {
					s=s.substring(b+1,e);
				}
			}
		}
		if(m_errors.ToString().indexOf(s)<0) { // except duplicates
			if(m_errors.GetLength()>0) m_errors.Append("; ");
			m_errors.Append(s);
		}
	}

	/**
	 *
	 *
	 * @param m_props
	 * @param ptAS
	 * @param idx_start
	 */
	public void copyDataFromPropValuesToAuthSource(
			XPArrayList m_props,
			IPTAuthSource ptAS, 
			int idx_start)
	{	
		IXPPropertyBag ptBag = ptAS.GetProviderInfo();
		try {
			ptAS.SetProviderInfo(ptBag);
		} catch(Exception e) {
			SetInvalid(e.getMessage());
		}
	}

	/**
	 * Returns the Auth Source's category
	 *
	 * @return
	 */
	public String GetAuthSourceCategory()
	{
		return m_sCategory;
	}

	/**
	 *
	 *
	 * @return
	 */
	public Object[][] defaultProfiles()
	{
		PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetUsers());
		int fields						  = PT_PROPIDS.PT_PROPID_OBJECTID |
			PT_PROPIDS.PT_PROPID_NAME;
		query.Query(fields, PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES,
			null, null);

		int n			  = query.GetCount();
		Object[][] result = new Object[2][n + 1];

		for (int i = 0; i < n; i++)
		{
			int id   = XPConvert.ToInteger(query.GetFields(i,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String name  = (String) query.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
			result[0][i] = new Integer(id);
			result[1][i] = name;
		}

		result[0][n] = null;

		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int deferredGroupFolderID()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetDeletedGroupFolderID();
	}

	/**
	 *
	 *
	 * @return
	 */
	public int deletedUserFolderID()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetDeletedUserFolderID();
	}

	/**
	 *
	 *
	 * @return
	 */
	public Object[][] fullySyncedGroups()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		Object[] groupIds  = (Object[]) ptAS.GetFullSyncGroups();
		int n			   = (groupIds == null) ? 0 : groupIds.length;
		Object[][] result  = new Object[4][n];

		for (int i = 0; i < n; i++)
		{
			result[0][i]     = groupIds[i];
			result[1][i]     = userGroupName(XPConvert.ToInteger(groupIds[i]));
			result[2][i]     = null; // unused
			result[3][i]     = null; // unused
		}

		return result;
	}

	/**
	 *
	 *
	 * @param j
	 *
	 * @return
	 */
	public int groupsOrder(int j)
	{
		return XPConvert.ToInteger(m_groupsOrder.GetElement(j));
	}

	/**
	 *
	 *
	 * @return
	 */
	public String lastTreeSpaceId_ADMINFOLDERTREESPACE()
	{
		return m_lastTreeSpaceId_ADMINFOLDERTREESPACE;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String lastTreeSpaceId_USERGROUPTREESPACE()
	{
		return m_lastTreeSpaceId_USERGROUPTREESPACE;
	}

	/**
	 * Helper function
	 *
	 * @return
	 */
	public String listOfMappedGroups()
	{
		XPStringBuilder sb = new XPStringBuilder(100);
		Object[][] groups  = mappedGroups(0);

		if (groups != null)
		{
			String clsid = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
			char sep     = (char)0;

			for (int i = 0; i < groups[0].length; i++)
			{
				int id = XPConvert.ToInteger(groups[0][i]);

				if (id != 0)
				{
					if (sep == 0)
					{
						sep = ',';
					}
					else
					{
						sb.Append(sep);
					}

					sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
				}
			}
		}

		return (sb.GetLength() == 0) ? null : sb.ToString();
	}

	/**
	 * Helper function
	 *
	 * @return
	 */
	public String listOfSyncGroups()
	{
		XPStringBuilder sb = new XPStringBuilder(100);
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		Object[] ids	   = (Object[]) ptAS.GetFullSyncGroups();

		if ((ids != null) && (ids.length != 0))
		{
			String clsid = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
			char sep     = (char)0;

			for (int i = 0; i < ids.length; i++)
			{
				int id = XPConvert.ToInteger(ids[i]);

				if (id != 0)
				{
					if (sep == 0)
					{
						sep = ',';
					}
					else
					{
						sb.Append(sep);
					}

					sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
				}
			}
		}

		return (sb.GetLength() == 0) ? null : sb.ToString();
	}

	/**
	 * Helper function
	 *
	 * @return
	 */
	public String listOfUnmappedGroups()
	{
		XPStringBuilder sb	    = new XPStringBuilder(100);
		int nmappedgroups=0;
		if(true) {
			Object[][] mappedgroups = mappedGroups(0); // just to see if there are any
			nmappedgroups=(mappedgroups==null || mappedgroups[0]==null) ? 0 : mappedgroups[0].length;
		}

		if (nmappedgroups>0)
		{
			Object[][] unmappedgroups = unmappedGroups();
			int nunmappedgroups=(unmappedgroups==null || unmappedgroups[0]==null) ? 0 : unmappedgroups[0].length;

			String clsid			  = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
			char sep				  = (char)0;

			for (int i = 0; i < nunmappedgroups; i++)
			{
				int id = XPConvert.ToInteger(unmappedgroups[0][i]);

				if (id != 0)
				{
					if (sep == 0)
					{
						sep = ',';
					}
					else
					{
						sb.Append(sep);
					}

					sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
				}
			}
		}

		return (sb.GetLength() == 0) ? null : sb.ToString();
	}

	/**
	 * Helper function
	 *
	 * @return
	 */
	public String listOfAlienGroups()
	{
		XPStringBuilder sb	    = new XPStringBuilder(100);
		Object[][] allgroups = allGroups(false);
		int nallgroups=(allgroups==null || allgroups[0]==null) ? 0 : allgroups[0].length;

		if (nallgroups>0)
		{
			Object[][] ourgroups = allGroups(true);
			int nourgroups=(ourgroups==null || ourgroups[0]==null) ? 0 : ourgroups[0].length;

			if(nourgroups>0) {
				XPHashtable our=new XPHashtable(nourgroups);
				for(int i=0; i<nourgroups; i++)
				{
					our.PutElement(ourgroups[0][i],"");
				}
				ourgroups=null;
				for(int i=0; i<nallgroups; i++) {
					if(our.GetElement(allgroups[0][i])!=null)
						allgroups[0][i]=null;
				}
			}

			String clsid			  = XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID);
			char sep				  = (char)0;

			for(int i=0; i<nallgroups; i++) {
				Object oid=allgroups[0][i];
				if(oid==null) continue;
				int id = XPConvert.ToInteger(oid);

				if (id != 0)
				{
					if (sep == 0)
					{
						sep = ',';
					}
					else
					{
						sb.Append(sep);
					}

					sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
				}
			}
		}

		return (sb.GetLength() == 0) ? null : sb.ToString();
	}

	/**
	* Helper function
	*
	* @return
	*/
	public String listOfNewGroupsFolder()
	{
		XPStringBuilder sb = new XPStringBuilder(10);
		int id=newGroupFolderId();
		IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();
		try {
			ptSession.GetAdminCatalog().OpenAdminFolder(id, false);			
		}
		catch (Exception e)
		{
			return null;
		}
		
		String clsid = XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
		sb.Append(clsid).Append(',').Append(XPConvert.ToString(id));
		return (sb.GetLength() == 0) ? null : sb.ToString();
	}

	public String joinLists(String lst1,String lst2) {
		String result=null;
		if(lst1 == null)
			result = lst2;
		else {
			if (lst2 == null)
				result = lst1;
			else
				result = lst1 + ',' + lst2;
		}
		return result;
	}

	/**
	 *
	 *
	 * @param reserveTopRows
	 *
	 * @return
	 */
	public Object[][] mappedGroups(int reserveTopRows)
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		Object[] groupIds  = (Object[]) ptAS.GetDefaultProfilesMap_GroupIDs();
		Object[] userIds   = (Object[]) ptAS.GetDefaultProfilesMap_UserIDs();
		Object[] folderIds = (Object[]) ptAS.GetDefaultProfilesMap_FolderIDs();
		boolean modified   = false;
		int n			   = (groupIds == null) ? 0 : groupIds.length;
		n += reserveTopRows;

		Object[][] result = new Object[4][n + 1];

		for (int i = 0; i < reserveTopRows; i++)
		{
			result[0][i]     = null;
			result[1][i]     = null;
			result[2][i]     = null;
			result[3][i]     = null;
		}

		for (int i = reserveTopRows; i < n; i++)
		{
			int j = i - reserveTopRows;
			result[0][i]     = groupIds[j];
			result[1][i]     = userGroupName(XPConvert.ToInteger(groupIds[j]));
			result[2][i]     = userIds[j];

			if ((folderIds[j] == null) ||
					(XPConvert.ToInteger(folderIds[j]) == 0))
			{
				folderIds[j]     = new Integer(GetDefaultFolderId());
				modified		 = true;
			}

			result[3][i] = folderIds[j];
		}

		int iddefUser   = GetDefaultProfileId();
		int iddefFolder = ptAS.GetNewUserFolderID();
		if (iddefFolder == 0)
		{
			iddefFolder     = GetDefaultFolderId();
			modified	    = true;
		}

		result[0][n]     = new Integer(0); // fake zero id for the last one
		result[1][n]     = m_asOwner.GetString(2047, ResourceConstants.PORTALADMINMSGS);
		result[2][n]     = new Integer(iddefUser);
		result[3][n]     = new Integer(iddefFolder);

		if (modified)
		{
			saveGroups(result);
		}

		return result;
	}

	/**
	 * 
	 * @param _fixDeletedfolder - if the folderid no longer exists,
	 * 			replace the id with a default folder
	 * @return
	 */
	public int newGroupFolderId()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		int folderid	   = ptAS.GetNewGroupFolderID();

		if (folderid == 0)
		{
			folderid = GetDefaultFolderId();
			try {
				ptAS.SetNewGroupFolderID(folderid);
			} catch(Exception e) {
				SetInvalid(e.getMessage());
			}
		} 
		return folderid;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int numTemplates()
	{
		return GetPTSession().GetNumberOfSerializedPropertyBags(templatesPatttern);
	}

	/**
	 *
	 *
	 * @return
	 */
	public int selectedPartnerId()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetAuthPartnerID();
	}

	/**
	 *
	 *
	 * @return
	 */
	public int selectedTemplate()
	{
		return m_templateSelected;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int supportSyncMode()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetSupportsSync();
	}

	/**
	 *
	 *
	 * @return
	 */
	public int syncType()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetSyncType();
	}

	/**
	 *
	 *
	 * @param index
	 *
	 * @return
	 */
	public IXPPropertyBag templateContents(int index)
	{
		return GetPTSession().GetSerializedPropertyBag(templatesPatttern, index);
	}

	/**
	 *
	 *
	 * @param index
	 *
	 * @return
	 */
	public String templateName(int index)
	{
		return GetPTSession().GetSerializedPropertyBagName(templatesPatttern,
			index);
	}

	/**
	 *
	 *
	 * @return
	 */
	public Object[][] unmappedGroups()
	{
		Object[][] mappedgroups = mappedGroups(0);
		Object[][] allgroups    = allGroups(true); // can be null
		int nmappedgroups=(mappedgroups==null || mappedgroups[0]==null) ? 0 : mappedgroups[0].length;
		int nallgroups=(allgroups==null || allgroups[0]==null) ? 0 : allgroups[0].length;

		if (nmappedgroups==0)
			return allgroups;

		int nunmappedgroups = nallgroups -	nmappedgroups + 1; // +1 for special "0" in mapped groups, which is never matched

		Object[][] unmappedgroups=null;
		if(nunmappedgroups>0) {
			unmappedgroups = new Object[4][nunmappedgroups];
			int j					  = 0;
			for (int i = 0; i < nallgroups; i++)
			{
				int ida		 = XPConvert.ToInteger(allgroups[0][i]);
				boolean skip = false;

				for (int k = 0; !skip && (k < nmappedgroups); k++)
				{
					int idm = XPConvert.ToInteger(mappedgroups[0][k]);
					skip = (idm == ida);
				}

				if (!skip)
				{
					for (int n = 0; n < 4; n++)
					{
						unmappedgroups[n][j] = allgroups[n][i];
					}

					j++;
				}
			}
		}

		return unmappedgroups;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveMainPage(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		int nActionWithoutID = removeIdFromAction(GetAction());

		if ((AuthSourceRepostControl.ACTION_ADD_GROUP == nActionWithoutID) ||
				(AuthSourceRepostControl.ACTION_ADD_SYNC_GROUP == nActionWithoutID))
		{
			m_lastTreeSpaceId_USERGROUPTREESPACE = ExtractOneElement(_htFormData.GetElement(
						AuthSourceMainView.HTMLHIDDEN_SPACEID_USERGROUPTREESPACE));
		}
		else if ((AuthSourceRepostControl.ACTION_CHANGE_TARGET_FOLDER == nActionWithoutID) ||
				(AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP == nActionWithoutID))
		{
			m_lastTreeSpaceId_ADMINFOLDERTREESPACE = ExtractOneElement(_htFormData.GetElement(
						AuthSourceMainView.HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE));
		}
		else if (AuthSourceRepostControl.ACTION_DEL_GROUP == nActionWithoutID)
		{
			ExtractCheckboxes((String[]) _htFormData.GetElement(
					AuthSourceMainView.HTMLCHECKBOX_GROUP));
		}

		// any action

		// aj: load the category from the form data.  if it's null, then we're probably
		//     in edit mode and it doesn't exist in the form.  otherwise we are in 
		//     create mode and we should persist it to the model and ptobject
		String sCategory = ExtractOneElement(_htFormData.GetElement(AuthSourceMainView.HTMLINPUT_AuthenticationSourceCategory));
		if(sCategory != null)
		{
			m_sCategory = sCategory;
			IPTAuthSource ptAS = (IPTAuthSource) GetObject();
			IXPPropertyBag ptBag = ptAS.GetProviderInfo();
			ptBag.Write("RAP_AUTH_CATEGORY", (m_sCategory != null)?(m_sCategory):(""));
			ptAS.SetProviderInfo(ptBag);
		}

		// save groups, which may have modified default profiles
		ExtractAndSaveDefaultProfiles(_htFormData);

		return nPageStatus;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SavePage2(XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SavePage3(XPHashtable _htFormData)
	{
		int nPageStatus    = RepostControl.PAGE_STATUS_VALID;
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		// fortunately radio button values are the same as in Plumtree.idl
		String s    = ExtractOneElement(_htFormData.GetElement(
					AuthSource3View.HTMLINPUT_AuthenticationAndSynchronizationChoice));
		int oldmode = supportSyncMode();
		int newmode = (s == null) ? 1 : XPConvert.ToInteger(s);
		try {
			ptAS.SetSupportsSync(newmode);
		} catch(Exception e) {
			SetInvalid(e.getMessage());
		}
		s = ExtractOneElement(_htFormData.GetElement(
					AuthSource3View.HTMLINPUT_SynchronizationType));
		try {
			if (null != s)
			{
				ptAS.SetSyncType(XPConvert.ToInteger(s));
			}
		} catch(Exception e) {
			SetInvalid(e.getMessage());
		}
		s = ExtractOneElement(_htFormData.GetElement(
					AuthSource3View.HTMLINPUT_BatchSize));

		try
		{
			if (null != s)
			{
				int nImport = XPConvert.ToInteger(s);
				if (nImport < 10 || nImport > 1000)
				{
					String msg	    = m_asOwner.GetString(2700, ResourceConstants.PORTALADMINMSGS);
					SetInvalid(msg);
				}
				else
				{
					ptAS.SetBulkCopyNum(XPConvert.ToInteger(s));
				}
			}
		}
		catch(Exception e)
		{
			String msg	    = m_asOwner.GetString(2700, ResourceConstants.PORTALADMINMSGS);
			SetInvalid(msg);
		}

		if(newmode==PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_SYNCONLY)
			s = ExtractOneElement(_htFormData.GetElement(
					AuthSource3View.HTMLINPUT_PARTNERS));
		else
			s=null;

		if (s != null)
		{
			try
			{
				ptAS.SetAuthPartnerID(XPConvert.ToInteger(s));
			}
			catch (Exception e)
			{
				String msg	    = m_asOwner.GetString(2060, ResourceConstants.PORTALADMINMSGS);
				SetInvalid(msg);
			}
		}
		else
		{
			try
			{
				ptAS.SetAuthPartnerID(0);
			}
			catch(Exception e)
			{
				SetInvalid(e.getMessage());
			}
		}

		onPossibleChangeOfSyncMode(oldmode);
		
		// aj: finally save the cross AS import mode
		s = ExtractOneElement(_htFormData.GetElement(
				AuthSource3View.HTMLINPUT_CrossAsMemberships));
		if(s != null && s.equals(CommonHTMLStrings.ONE))
		{
			m_bImportCrossASMemberships = true;
		} else {
			m_bImportCrossASMemberships = false;	
		}

		return nPageStatus;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SavePage4(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		int nActionWithoutID = removeIdFromAction(GetAction());

		if (AuthSourceRepostControl.ACTION_DEL_SYNC_GROUP == nActionWithoutID)
		{
			ExtractSyncCheckboxes((String[]) _htFormData.GetElement(
					AuthSource4View.HTMLCHECKBOX_GROUP));
		}
		else if (AuthSourceRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP == nActionWithoutID)
		{
			ExtractDisabledCheckboxes((String[]) _htFormData.GetElement(
					AuthSource4View.HTMLCHECKBOX_DISABLED));
		}
		return nPageStatus;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected int GetAction()
	{
		return m_nAction;
	}

	/**
	 *
	 *
	 * @param id
	 */
	protected void SetDefaultFolderId(int id)
	{
		m_iddefFolder = id;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected int GetDefaultFolderId()
	{
		if (m_iddefFolder == 0)
		{
			IPTAuthSource ptAS = (IPTAuthSource) GetObject();
			m_iddefFolder = ptAS.GetNewGroupFolderID();

			if (m_iddefFolder == 0)
			{
				m_iddefFolder = ptAS.GetNewUserFolderID();
			}

			if (m_iddefFolder == 0)
			{
				m_iddefFolder = ptAS.GetAdminFolderID();
			}
		}

		return m_iddefFolder;
	}

	protected int GetDefaultProfileId() {
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		return ptAS.GetDefaultProfileForNewUsers();
	}

	/**
	 *
	 */
	protected void ClearActionData()
	{
		if (m_ActionData == null)
		{
			m_ActionData = new XPArrayList();
		}
		else
		{
			m_ActionData.Clear();
		}
	}

	/**
	 *
	 *
	 * @param ids
	 */
	protected void ExtractCheckboxes(String[] ids)
	{
		ClearActionData();

		for (int i = 0; (ids != null) && (i < ids.length); i++)
		{
			int id = 0; // 0 not removable

			try
			{
				id = XPConvert.ToInteger(ids[i]);
			}
			catch (Exception e)
			{
			}

			if (id != 0)
			{
				m_ActionData.Add(new Integer(id));
			}
		}
	}

	/**
	 *
	 *
	 * @param ids
	 */
	protected void ExtractDisabledCheckboxes(String[] ids)
	{
		ClearActionData();

		for (int i = 0; (ids != null) && (i < ids.length); i++)
		{
			int id = 0; // expected values are 1 or 2

			try
			{
				id = XPConvert.ToInteger(ids[i]);
			}
			catch (Exception e)
			{
			}

			if (id != 0)
			{
				m_ActionData.Add(new Integer(id));
			}
		}
	}

	/**
	 *
	 *
	 * @param o
	 *
	 * @return
	 */
	protected boolean ExtractOneBoolElement(Object o)
	{
		String s = ExtractOneElement(o);

		return ((s == null) || (s.length() < 1) || (s.charAt(0) != '1'))
		? false : true;
	}

	/**
	 *
	 */
	public void onAddAllSyncGroups()
	{

		Object[][] allgroups=allGroups(true);
		int nallgroups=(allgroups==null || allgroups[0]==null) ? 0 : allgroups[0].length;
		Object[] newsyncgroups=new Object[nallgroups];
		for (int i = 0; i < nallgroups; i++)
			newsyncgroups[i] = allgroups[0][i];
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		try
		{
			ptAS.SetFullSyncGroups(newsyncgroups);
		}
		catch(Exception e)
		{
			SetInvalid(e.getMessage());
		}

		/* this old version actually adds all MAPPED groups
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		Object[] syncgroups  = (Object[]) ptAS.GetFullSyncGroups();
		int nsync	= (syncgroups == null) ? 0 : syncgroups.length;
		Object[][] mappedgroups = mappedGroups(0);
		int nmap = (mappedgroups == null) ? 0 : mappedgroups[0].length;
		int ntmp = nsync + nmap;
		Object[] tmp = new Object[ntmp];
		int k = 0;

		for (; k < nmap; k++)
			tmp[k] = mappedgroups[0][k];

		for (int i = 0; i < nsync; i++)
		{
			Object id    = syncgroups[i];
			boolean skip = false;

			for (int j = 0; !skip && (j < k); j++)
				skip = (id.equals(tmp[j]));

			if (!skip)
				tmp[k++] = id;
		}

		Object[] newsyncgroups = new Object[k];

		for (int i = 0; i < k; i++)
			newsyncgroups[i] = tmp[i];

		ptAS.SetFullSyncGroups(newsyncgroups);
		*/
	}

	/**
	 *
	 *
	 * @param id
	 */
	public void onAddSyncGroup(int id)
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		Object[] oldids    = (Object[]) ptAS.GetFullSyncGroups();
		int oldlen		   = (oldids == null) ? 0 : oldids.length;
		Object[] newids    = new Object[oldlen + 1];
		int i			   = 0;
		boolean dup		   = false;

		for (; (i < oldlen) && !dup; i++)
		{
			newids[i] = oldids[i];

			for (int j = 0; (j < oldlen) && !dup; j++)
			{
				dup |= (id == XPConvert.ToInteger(oldids[j]));
			}
		}

		if (!dup)
		{
			newids[i] = new Integer(id);
			try
			{
				ptAS.SetFullSyncGroups(newids);
			}
			catch(Exception e)
			{
				SetInvalid(e.getMessage());
			}
		}
	}

	/**
	 *
	 */
	public void onRemoveSyncGroup()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		Object[] oldids    = (Object[]) ptAS.GetFullSyncGroups();

		if ((oldids == null) || (oldids.length < 1))
		{
			return;
		}

		Object[] newids = new Object[oldids.length];
		for (int i = 0; i < oldids.length; i++)
			newids[i]=oldids[i];

		for (IXPEnumerator j = m_ActionData.GetEnumerator(); j.MoveNext();)
		{
			int id = XPConvert.ToInteger(j.GetCurrent());

			if (id == -1)
			{
				newids = null;

				break;
			}

			for (int i = 0; i < oldids.length; i++)
			{
				if (XPConvert.ToInteger(oldids[i]) == id)
				{
					newids[i] = null;
					break;
				}
			}
		}

		Object[] newids2 = null;

		if (newids != null)
		{
			int n = 0;

			for (int i = 0; i < newids.length; i++)
			{
				if (newids[i] != null)
				{
					n++;
				}
			}

			if (n == 0)
			{
				newids = null;
			}
			else
			{
				newids2 = new Object[n];

				int k = 0;

				for (int i = 0; i < newids.length; i++)
				{
					if (newids[i] != null)
					{
						newids2[k++] = newids[i];
					}
				}
			}
		}

		try
		{
			ptAS.SetFullSyncGroups(newids2);
		}
		catch(Exception e)
		{
			SetInvalid(e.getMessage());
		}
	}

	protected static int removeIdFromAction(int action)
	{
		return AuthSourceRepostControl.removeIdFromAction(action);
	}

	/**
	 *
	 *
	 * @param ids
	 */
	protected void ExtractSyncCheckboxes(String[] ids)
	{
		ClearActionData();

		for (int i = 0; (ids != null) && (i < ids.length); i++)
		{
			int id = -2;

			try
			{
				id = XPConvert.ToInteger(ids[i]);
			}
			catch (Exception e)
			{
			}

			if (id != -2)
			{
				m_ActionData.Add(new Integer(id));
			}
		}
	}

	/**
	 * Action to be taken when a group is added to the list
	 *
	 * @param id
	 */
	public void onAddGroup(int id)
	{
		Object[][] groups = mappedGroups(1); // reserve one row at the top
		groups[0][0]     = new Integer(id);
		groups[1][0]     = userGroupName(id);
		groups[2][0]     = new Integer(GetDefaultProfileId());
		groups[3][0]     = new Integer(GetDefaultFolderId());

		// inserting new mapped group at 0th row index
		m_groupsOrder.Insert(0, new Integer(0));
		// bump all the rest down one row
		for (int i = groups[0].length - 1; i > 0; i--) // adjust order

		{
			m_groupsOrder.SetElement(i, new Integer(XPConvert.ToInteger(m_groupsOrder.GetElement(i)) + 1));
		}

		saveGroups(groups);
	}

	/**
	 *
	 *
	 * @param k
	 */
	public void onChangeCheckboxForSyncGroup(int k)
	{
		boolean bChecked = false;

		if (!m_ActionData.IsEmpty())
		{
			for (IXPEnumerator i = m_ActionData.GetEnumerator(); i.MoveNext();)
			{
				if (XPConvert.ToInteger(i.GetCurrent()) == k)
				{
					bChecked = true;
				}
			}
		}

		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		try
		{
		if (!bChecked)
		{
			switch (k)
			{
			case 1:
				ptAS.SetDeletedUserFolderID(0);

				break;

			case 2:
				ptAS.SetDeletedGroupFolderID(0);

				break;
			}
		}
		else
		{
			switch (k)
			{
			case 1:
				ptAS.SetDeletedUserFolderID(-1);

				break;

			case 2:
				ptAS.SetDeletedGroupFolderID(-1);

				break;
			}
		}
		}
		catch(Exception e)
		{
			SetInvalid(e.getMessage());
		}
	}

	/**
	 * Action take when the selected folder is changed
	 *
	 * @param id
	 * @param folderid
	 */
	public void onChangeFolder(int id, int folderid)
	{
		Object[][] groups = mappedGroups(0);

		for (int j = 0; j < groups[0].length; j++)
		{
			int i   = XPConvert.ToInteger(m_groupsOrder.GetElement(j));
			int idi = XPConvert.ToInteger(groups[0][i]);

			if (idi == id)
			{
				groups[3][i] = new Integer(folderid);

				if (id == 0)
				{ // the "All Users" folder serves as default if the default is not set

					if (m_iddefFolder == 0)
					{
						SetDefaultFolderId(folderid);
					}
				}

				break;
			}
		}

		saveGroups(groups);
	}

	/**
	 *
	 *
	 * @param folderid
	 */
	public void onChangeFolderForNewGroups(int folderid)
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		try
		{
			ptAS.SetNewGroupFolderID(folderid);
		}
		catch(Exception e)
		{
			SetInvalid(e.getMessage());
		}
	}

	/**
	 * Event handler for when the folder is changed for a sync group
	 *
	 * @param id
	 * @param folderid
	 */
	public void onChangeFolderForSyncGroup(int id, int folderid)
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		try
		{
			switch (id)
			{
			case 1:
				ptAS.SetDeletedUserFolderID(folderid);
				break;
			case 2:
				ptAS.SetDeletedGroupFolderID(folderid);
				break;
			}
		}
		catch(Exception e)
		{
			SetInvalid(e.getMessage());
		}
	}

	/**
	 * Action to be taken when a group is moved in the list
	 *
	 * @param id
	 * @param dir
	 */
	public void onMoveGroup(int id, int dir)
	{
		Object[][] groups = mappedGroups(0);

		for (int j = 0; j < groups[0].length; j++)
		{
			int i   = XPConvert.ToInteger(m_groupsOrder.GetElement(j));
			int idi = XPConvert.ToInteger(groups[0][i]);

			if (idi == id)
			{
				int k = -1;

				switch (dir)
				{
				case -2:
					k = 0;

					break;

				case -1:
					k = j - 1;

					break;

				case +1:
					k = j + 1;

					break;

				case +2:
					k = groups[0].length - 1 - 1;

					break; // -1 for last one that is unmoveable
				}

				if ((k >= 0) && (k <= (groups[0].length - 1 - 1)))
				{
					if (dir > 0)
					{
						for (int n = j; n < k; n++)
						{
							Object tmp = m_groupsOrder.GetElement(n);
							m_groupsOrder.SetElement(n, m_groupsOrder.GetElement(n+1));
							m_groupsOrder.SetElement(n + 1, tmp);
						}
					}
					else
					{
						for (int n = k; n < j; n++)
						{
							Object tmp = m_groupsOrder.GetElement(n);
							m_groupsOrder.SetElement(n, m_groupsOrder.GetElement(n+1));
							m_groupsOrder.SetElement(n + 1, tmp);
						}
					}
				}

				break;
			}
		}

		saveGroups(groups);
	}

	/**
	 *
	 *
	 * @param oldmode
	 */
	public void onPossibleChangeOfSyncMode(int oldmode)
	{
		int mode = supportSyncMode();

		if (mode != oldmode)
		{
			boolean authonly = (mode == PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_AUTHONLY);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(authonly,
				SetJobDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(authonly,
				((AuthSourceEditorAS) m_asOwner).GetPageName4());
		}
	}

	/**
	 * Action to be taken when a group is removed from the list
	 */
	public void onRemoveGroup()
	{
		Object[][] groups = mappedGroups(0);

		if (groups == null)
		{
			return;
		}

		for (IXPEnumerator j = m_ActionData.GetEnumerator(); j.MoveNext();)
		{
			int id = XPConvert.ToInteger(j.GetCurrent());

			for (int i = 0; i < groups[0].length; i++)
			{
				if (groups[0][i] != null)
				{
					int idi = XPConvert.ToInteger(groups[0][i]);

					if (idi != 0)
					{ // 0 non removable

						if ((idi == id) || (id == -1)) // -1 - remove all
						{
							groups[0][i] = null;
						}
					}
				}
			}
		}

		saveGroups(groups);
	}

	/**
	 * Action to be taken when a group is removed from the list
	 */
	public void onReenableUsers()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		m_nReenabled = ptAS.EnableAgentDisabledUsers();		
	}
	
	public int GetNumDisabledUsers()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();
		int nDisabled = ptAS.GetAgentDisabledUsersCount();
		return nDisabled;				
	}

	public int GetNumReenabledUsers()
	{
		return m_nReenabled;				
	}

	/**
	 * Save the information about he selected groups to the model class
	 *
	 * @param groups
	 */
	protected void saveGroups(Object[][] groups)
	{
		int n					 = groups[0].length - 1; // -1 - don't alloc for the last one
		Object[] vsaUserGroupIDs = new Object[n];
		Object[] vsaUserIDs		 = new Object[n];
		Object[] vsaFolderIDs    = new Object[n];
		IPTAuthSource ptAS		 = (IPTAuthSource) GetObject();
		int nAddedGroups  		 = 0;

		for (int j = 0; j < groups[0].length; j++)
		{
			int i = XPConvert.ToInteger(m_groupsOrder.GetElement(j));

			if (groups[0][i] == null)
			{
				continue; // group removed
			}

			int groupid = XPConvert.ToInteger(groups[0][i]);

			if (groupid == 0)
			{
				try
				{
					ptAS.SetDefaultProfileForNewUsers(XPConvert.ToInteger(groups[2][i]));
					ptAS.SetNewUserFolderID(XPConvert.ToInteger(groups[3][i]));
				}
				catch(Exception e)
				{
					SetInvalid(e.getMessage());
				}
			}
			else
			{
				vsaUserGroupIDs[nAddedGroups]     = groups[0][i];
				vsaUserIDs[nAddedGroups]		   = groups[2][i];
				vsaFolderIDs[nAddedGroups]		   = groups[3][i];
				nAddedGroups++;
			}
		}

		Object[] vsaUserGroupIDs2 = null;
		Object[] vsaUserIDs2	  = null;
		Object[] vsaFolderIDs2    = null;

		if (nAddedGroups > 0)
		{
			vsaUserGroupIDs2     = new Object[nAddedGroups];
			vsaUserIDs2			 = new Object[nAddedGroups];
			vsaFolderIDs2		 = new Object[nAddedGroups];

			for (int i = 0; i < nAddedGroups; i++)
			{
				vsaUserGroupIDs2[i]     = vsaUserGroupIDs[i];
				vsaUserIDs2[i]		    = vsaUserIDs[i];
				vsaFolderIDs2[i]	    = vsaFolderIDs[i];
			}
		}

		try
		{
			ptAS.SetDefaultProfilesMap(vsaUserGroupIDs2, vsaUserIDs2, vsaFolderIDs2);
			ptAS.SetUseDefaultProfilesMap(nAddedGroups > 0);
		}
		catch(Exception e)
		{
			SetInvalid(e.getMessage());
		}


		for (int i = 0; i < m_groupsOrder.GetSize(); i++) // erase order (which went to DB)
		{
			m_groupsOrder.SetElement(i, new Integer(i));
		}
	}

	protected void ExtractAndSaveDefaultProfiles(XPHashtable _htFormData) {
		Object[][] groups=mappedGroups(0);
		if(groups == null) return;
		boolean modified=false;
		for(int i=0; i < groups[0].length; i++) {
			if(groups[0][i]==null) continue;
			int id=XPConvert.ToInteger(groups[0][i]);
			String value=ExtractOneElement(_htFormData.GetElement(AuthSourceMainView.HTMLINPUT_PROFILES_ + id));
			if(value==null) continue;
			int dpid=-1;
			try {
				dpid=XPConvert.ToInteger(value);
			} catch(Exception e)
			{
				log.Error(e, "AuthSourceModel::ExtractDefaultProfiles Unexpected non-numeric value "+value);
			}
			if(dpid<0) {
				log.Error("AuthSourceModel::ExtractDefaultProfiles Unexpected non-numeric value "+value);
				continue;
			}
			int newdpid = dpid;
			modified|=(newdpid != XPConvert.ToInteger(groups[2][i]));
			groups[2][i] = new Integer(newdpid);
		}
		if(modified)
			saveGroups(groups);
	}

	/**
	 *
	 *
	 * @return
	 */
	public String userFolderPathIfSingle()
	{ // null if not single

		String result     = null;
		int folderid	  = 0;
		Object[][] groups = mappedGroups(0);

		for (int i = 0; i < groups[0].length; i++)
		{
			Object tmp = groups[3][i];

			if (tmp == null)
			{
				continue;
			}

			int folderidi = XPConvert.ToInteger(tmp);

			if (folderidi != folderid)
			{
				if (folderid == 0)
				{
					folderid = folderidi;
				}
				else
				{ // multiple folders
					folderid = 0;

					break;
				}
			}
		}

		if (folderid != 0)
		{
			IPTAdminFolder ptFolder = m_Session.GetAdminCatalog()
				.OpenAdminFolder(folderid, false);

			if (ptFolder != null)
			{
				result = ptFolder.GetPath();
			}
		}

		return result;
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	protected String userGroupName(int id)
	{
		String result = m_asOwner.GetString(2047, ResourceConstants.PORTALADMINMSGS);

		if (id != 0)
		{
			try
			{
				IPTUserGroup ptGroup = (IPTUserGroup) m_Session.GetUserGroups()
					.Open(id, false);
				result = ptGroup.GetLocalizedName();
			}
			catch (Exception e)
			{
				result = m_asOwner.GetString(2052, ResourceConstants.PORTALADMINMSGS) + ": " +
					XPConvert.ToString(id);
			}
		}

		return result;
	}

	public boolean sameTimeCreatedAndModified() {
		return m_sameTimeCreatedAndModified;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.authsource.IAuthSourceModelRO#ImportCrossASMemberships()
	 */
	public boolean ImportCrossASMemberships() {
		return m_bImportCrossASMemberships;
	}
}

