package com.plumtree.portalpages.admin.editors.authsource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Popup Display Page for confirming that a bulk re-enable operation succeeded.
 * 
 * @author Jennifer Sun
 *
 */
public class AuthSourceReenableUsersConfirmPopupDP extends AFormDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.authsource.AuthSourceReenableUsersConfirmPopupDP");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "AuthSourceReenableUsersConfirmPopup";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display()
	 */
	public void Display(IWebData pageData)
	{
		HTMLPage myPage = new HTMLPage();

		// Set the HTMLPage as the data to be sent to the browser.
		pageData.SetData(myPage);

		HTMLHead myHead = new HTMLHead();
		myPage.SetHead(myHead);

		HTMLTitle myTitle = new HTMLTitle(m_asOwner.GetString(2665, "ptmsgs_portaladminmsgs"));

		HTMLBody myBody = new HTMLBody();
		myPage.SetBody(myBody);
		myBody.SetMarginHeight("0");
		myBody.SetMarginWidth("0");
		myBody.SetLeftMargin("0");
		myBody.SetTopMargin("0");

		try
		{
			// Set to dark background color
			myBody.SetStyleClass(PTStyleClass.ALERT_DIALOG_BG);

			myHead.AddInnerHTMLElement(myTitle);

			myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
			myHead.AddInnerHTMLElement(DisplayJavascript());
			myHead.AddInnerHTMLElement(DisplayJavaScriptFromChild());

			HTMLForm myForm;
			HTMLInput myInput;

			// Form and hidden inputs
			myForm = new HTMLForm("");
			myBody.AddInnerHTMLElement(myForm);

			myForm.AddInnerHTMLElement(new HTMLComment(
					"Begin: Display Form and hidden inputs"));

			myForm.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(), 
				m_asOwner.GetName(), m_asOwner.IsSubSpace()));
			myForm.SetMethod(GetRepostTypeIsPost() ? POST : GET);
			myForm.SetName(HTMLFORM_NAME);

			// Hidden Inputs
			// The action for the repost control to perform (repost, finish, cancel, etc...)
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					RepostControl.HTMLINPUT_POSTTOSELF, "");
			myForm.AddInnerHTMLElement(myInput);
			myInput.SetValue(XPConvert.ToString(
					RepostControl.POSTTOSELF_ACTION_UNDEFINED));

			// Name of passthru control to run when PASSTHRU action is selected
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					RepostControl.HTMLINPUT_PASSTHRU_CONTROL, "");
			myForm.AddInnerHTMLElement(myInput);

			// Arguments to pass to passthru control when PASSTHRU action is selected
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					RepostControl.HTMLINPUT_PASSTHRU_ARGS, "");
			myForm.AddInnerHTMLElement(myInput);

			// Name of space to POST this form to.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					ASConstants.SPACENAME_INPUT, "");
			myForm.AddInnerHTMLElement(myInput);
			myInput.SetValue(GetOwner().GetName());

			// ID of space to POST this form to.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					ASConstants.SPACEID_INPUT, "");
			myForm.AddInnerHTMLElement(myInput);
			myInput.SetValue(GetOwner().GetSpaceID());

			// Name of control to POST this form to.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					ASConstants.CONTROL_INPUT, "");
			myForm.AddInnerHTMLElement(myInput);
			myInput.SetValue(GetRepostControlName());

			// Name of display page to display after POST.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, ASConstants.PAGE_INPUT,
					"");
			myForm.AddInnerHTMLElement(myInput);
			myInput.SetValue(GetOwner().GetCurrentPage().GetName());

			myForm.AddInnerHTMLElement(new HTMLComment(
					"End: Display Form and hidden inputs"));

			myForm.AddInnerHTMLElement(m_asOwner.GetView(
					AuthSourceReenableUsersConfirmPopupView.STR_MVC_CLASS_NAME).Display());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Display: The following HTML error occured when trying to display the HTML.");
			
		}
		catch (Exception e)
		{
			
				log.Error(e, "Display: The following error occured when trying to display the HTML.");
			
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()

	{
		return m_asOwner.GetView(AuthSourceReenableUsersConfirmPopupView.STR_MVC_CLASS_NAME)
		.Display();
	}

	/**
	 * Display the javascript from the view
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();

		scripts.AddInnerHTMLElement(m_asOwner.GetView(AuthSourceReenableUsersConfirmPopupView.STR_MVC_CLASS_NAME).DisplayJavascript());
		
		return scripts;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()
	 */
	public String GetFormTitle() {
		return null;
	}
}

