package com.plumtree.portalpages.admin.editors.authsource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Popup view for the bulk re-enable operation.
 * @author Jennifer Sun
 *
 */
public class AuthSourceReenableUsersPopupView implements IView
{
	/** object name */
	public static final String STR_MVC_CLASS_NAME = "AuthSourceReenableUsersPopup";

	/** HTML Object names */
	public static final String HTMLBUTTON_APPLY_NOW   = "in_bu_ApplyNow";

	/** Cancel Button */
	public static final String HTMLBUTTON_CANCEL = "in_bu_Cancel";

	/** mvc objects */
	AActivitySpace m_asOwner;
	IAuthSourceModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AuthSourceReenableUsersPopupView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result   = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLInput myInput;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
//		HTMLBr myBr			= new HTMLBr();

		//Create a banner table
		result.AddInnerHTMLElement(new HTMLComment(
				"Begin: BANNER table"));

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetBorder(CommonHTMLStrings.ZERO);
		myTable.SetWidth(CommonHTMLStrings.ZERO);
		myTable.SetCellPadding(CommonHTMLStrings.ZERO);
		myTable.SetCellSpacing("10");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
		myCell.AddInnerHTMLString(m_asOwner.GetString(2660, "ptmsgs_portaladminmsgs"));

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myRow.AddInnerHTMLElement(myCell);
		myCell.AddInnerHTMLString(m_asOwner.GetString(2664, "ptmsgs_portaladminmsgs"));
		myCell.AddInnerHTMLElement(new HTMLP());
		
		Object[] args = {XPConvert.ToString(m_asModel.GetNumDisabledUsers())};
		myCell.AddInnerHTMLString(XPFormat.Format(m_asOwner.GetString(2663, "ptmsgs_portaladminmsgs"), args));

		result.AddInnerHTMLElement(new HTMLComment(
				"End: BANNER table"));

		// Add buttons
		result.AddInnerHTMLElement(new HTMLComment(
				"Begin: Footer buttons table"));

		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetBorder(CommonHTMLStrings.ZERO);
		myTable.SetWidth(CommonHTMLStrings.ZERO);
		myTable.SetCellPadding(CommonHTMLStrings.ZERO);
		myTable.SetCellSpacing("10");

		// 1st Row
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		myCell.SetNoWrap(true);
			
		myRow.AddInnerHTMLElement(myCell);

		// Apply Now button
		myInput = new HTMLInput(HTMLInputTypes.BUTTON,
				HTMLBUTTON_APPLY_NOW, "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(m_asOwner.GetString(1212, "ptmsgs_portaladminmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		myInput.SetOnClick("ReenableNow" + "(); return false;");
			
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		// Cancel button
		myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CANCEL, "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(m_asOwner.GetString(1214, "ptmsgs_portaladminmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		myInput.SetOnClick("window.close(); return false;");

		result.AddInnerHTMLElement(new HTMLComment(
				"End: Footer buttons table"));
			
		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		// JavaScript to open the create folder popup
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb  = new XPStringBuilder(300);
		sb.Append("\n");
		sb.Append("function ").Append("ReenableNow").Append("()\n");
		sb.Append("{\n");
		sb.Append(AFormDP.JAVASCRIPT_SUBMIT_FORM)
		.Append("(").Append(AuthSourceRepostControl.ACTION_REENABLE_USERS)
		.Append(");\n");
		sb.Append("}\n");
		sb.Append("\n");

		myScript.AddInnerHTMLString(sb.toString());

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_asModel     = (IAuthSourceModelRO) model;
	}
}

