package com.plumtree.portalpages.admin.editors.authsource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.common.setjob.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author OlegS
 */
public abstract class AuthSourceRepostControl extends ObjEditorRepostControl
{
	/** Bulk Re-Enable Users */
	public final static int ACTION_REENABLE_USERS = 84;

	/** Delete group */
	public final static int ACTION_DEL_GROUP = 99;

	/** Add group */
	public final static int ACTION_ADD_GROUP = 98;

	/** Create default profile */
	public final static int ACTION_CREATE_DEFAULT_PROFILE = 97;

	/** Move group to the top of the list */
	public final static int ACTION_MOVE_GROUP_TOP = 96; // + group id * 100

	/** Move group up one */
	public final static int ACTION_MOVE_GROUP_UP = 95; // + group id * 100

	/** Move group down one */
	public final static int ACTION_MOVE_GROUP_DOWN = 94; // + group id * 100

	/** Move group to the bottom of the list */
	public final static int ACTION_MOVE_GROUP_BOTTOM = 93; // + group id * 100

	/** Change the target folder for the group */
	public final static int ACTION_CHANGE_TARGET_FOLDER = 92; // + group id * 100

	/** Add a sync group */
	public final static int ACTION_ADD_SYNC_GROUP = 91; // + group id * 100

	/** Add all sync groups */
	public final static int ACTION_ADD_ALL_SYNC_GROUPS = 90;

	/** Delete a sync group */
	public final static int ACTION_DEL_SYNC_GROUP = 89; // + group id * 100

	/** Change the folder for the sync group */
	public final static int ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP = 88; // + 1 or 2 * 100 // TODO: make this 100

	/** Change the folder where the created groups go */
	public final static int ACTION_CHANGE_NEW_GROUP_FOLDER = 87;

	/** Synchronization radio button selection changed  */
	public final static int ACTION_SYNC_CHOICE_CHANGED = 86;

	/** Validate button pressed  */
	public final static int ACTION_VALIDATE = 85; // LDAP only but defined here
		
	public static int makeAction(int action,int groupid) {
		return groupid*100+action;
	}

	/**
	 * Remove the ID from the action
	 *
	 * @param action The action being taken
	 *
	 * @return the integer with the ID removed
	 */
	public static int removeIdFromAction(int action)
	{
		int groupid=action/100;
		return action-groupid*100;
	}
	
	protected static int getIdFromAction(int action)
	{
		return action/100;
	}

	/**
	 * Returns the model class
	 *
	 * @return
	 */
	protected AuthSourceModel GetModel()
	{
		return (AuthSourceModel) m_model;
	}

	/**
	 * Function called on repost
	 *
	 * @param _nAction The action to take
	 */
	protected void PerformAction(int _nAction)
	{
		TraceHelper.Trace("PerformAction " + _nAction);
		super.PerformAction(_nAction);

		((SetJobRepostControl) m_asOwner.GetControl(SetJobRepostControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,m_htFormData);

		int nActionWithoutID = removeIdFromAction(_nAction);

		if (ACTION_ADD_GROUP == nActionWithoutID)
		{
			XPArrayList lst = TreeHelper.GetSelection(m_asOwner,
					AuthSourceMainView.USERGROUPTREESPACE);

			for (IXPEnumerator i = lst.GetEnumerator(); i.MoveNext();)
			{
				int id = XPConvert.ToInteger(i.GetCurrent());
				GetModel().onAddGroup(id);
			}
		}
		else if (ACTION_MOVE_GROUP_TOP == nActionWithoutID)
		{
			GetModel().onMoveGroup(getIdFromAction(_nAction), -2);
		}
		else if (ACTION_MOVE_GROUP_UP == nActionWithoutID)
		{
			GetModel().onMoveGroup(getIdFromAction(_nAction), -1);
		}
		else if (ACTION_MOVE_GROUP_DOWN == nActionWithoutID)
		{
			GetModel().onMoveGroup(getIdFromAction(_nAction), +1);
		}
		else if (ACTION_MOVE_GROUP_BOTTOM == nActionWithoutID)
		{
			GetModel().onMoveGroup(getIdFromAction(_nAction), +2);
		}
		else if (ACTION_CHANGE_TARGET_FOLDER == nActionWithoutID)
		{
			XPArrayList lst = TreeHelper.GetSelection(m_asOwner,
					AuthSourceMainView.ADMINFOLDERTREESPACE);

			if (!lst.IsEmpty())
			{
				int id = XPConvert.ToInteger(lst.GetElement(0));
				GetModel().onChangeFolder(getIdFromAction(_nAction), id);
			}
		}
		else if (ACTION_DEL_GROUP == nActionWithoutID)
		{
			GetModel().onRemoveGroup();
		}
		else if (ACTION_CHANGE_NEW_GROUP_FOLDER == nActionWithoutID)
		{
			XPArrayList lst = TreeHelper.GetSelection(m_asOwner,
					AuthSourceMainView.ADMINFOLDERTREESPACE_NEWGROUP);

			if (!lst.IsEmpty())
			{
				int id = XPConvert.ToInteger(lst.GetElement(0));
				GetModel().onChangeFolderForNewGroups(id);
			}
		}
		else if (ACTION_ADD_SYNC_GROUP == nActionWithoutID)
		{
			XPArrayList lst = TreeHelper.GetSelection(m_asOwner,
					AuthSource4View.USERGROUPTREESPACE);

			for (IXPEnumerator i = lst.GetEnumerator(); i.MoveNext();)
			{
				int id = XPConvert.ToInteger(i.GetCurrent());
				GetModel().onAddSyncGroup(id);
			}
		}
		else if (ACTION_DEL_SYNC_GROUP == nActionWithoutID)
		{
			GetModel().onRemoveSyncGroup();
		}
		else if (ACTION_ADD_ALL_SYNC_GROUPS == nActionWithoutID)
		{
			GetModel().onAddAllSyncGroups();
		}
		else if (ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP == nActionWithoutID)
		{
			XPArrayList lst = TreeHelper.GetSelection(m_asOwner,
					AuthSource4View.ADMINFOLDERTREESPACE);

			if (!lst.IsEmpty())
			{
				int id = XPConvert.ToInteger(lst.GetElement(0));
				GetModel().onChangeFolderForSyncGroup(getIdFromAction(_nAction),id);
			}
			else
			{ // from checkbox
				GetModel().onChangeCheckboxForSyncGroup(getIdFromAction(_nAction));
			}
		}
		else if (ACTION_REENABLE_USERS == nActionWithoutID)
		{
			GetModel().onReenableUsers();
			
			Redirect doneRedirect = new Redirect();
			doneRedirect.SetLinkGetCachedSpace(m_asOwner);
			doneRedirect.SetControl(STR_MVC_CLASS_NAME);
			doneRedirect.SetSubSpaceKey("ReenableUsersPopup");
			doneRedirect.SetDisplayPage(AuthSourceReenableUsersConfirmPopupDP.STR_MVC_CLASS_NAME);
			SetRedirect(doneRedirect);
		}
		else if (ACTION_SYNC_CHOICE_CHANGED == nActionWithoutID)
		{
			// do nothing
		}
	}

	/**
	 * Set the action to be taken on repost
	 */
	protected void SetRepostAction()
	{
		super.SetRepostAction();
		GetModel().m_nAction = m_nAction;
	}

}

