package com.plumtree.portalpages.admin.editors.authsource.plumtree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.authsource.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * Model for the Plumtree auth source editor. Currently does nothing.
 *
 * @author mikej
 */
public class PlumtreeAuthSourceEditorModel extends ObjEditorModel
{
    public static final String STR_MVC_CLASS_NAME = "PlumtreeAuthSourceModel";

    /**
     * Returns the Class name.
     *
     * @return String
     */
    public String GetName()
    {
        return STR_MVC_CLASS_NAME;
    }

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create()
    {
        return new PlumtreeAuthSourceEditorModel();
    }
    
	/**
	 *
	 *
	 * @return
	 */
	public Object[][] authPartners()
	{
		PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetAuthSources());
		int fields						  = PT_PROPIDS.PT_PROPID_OBJECTID |
			PT_PROPIDS.PT_PROPID_NAME; //|PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;
		Object[][] filter				  = new Object[3][3];
		filter[0][0]					  = new Integer(PT_PROPIDS.PT_PROPID_AUTHSOURCE_SUPPORTSSYNC); // filter SYNCONLY authsources out, cannot use these as partners
		filter[1][0]					  = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		filter[2][0]					  = new Integer(PT_AUTHSOURCE_SUPPORTSSYNCMODES.PT_AUTHSOURCESUPPORTSSYNCMODE_SYNCONLY);
		filter[0][1]					  = new Integer(PT_PROPIDS.PT_PROPID_AUTHSOURCE_AUTHTYPE); // don't want the default Plumtree User Database to appear as AuthPartner
		filter[1][1]					  = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		filter[2][1]					  = new Integer(PT_AUTHTYPES.PT_AUTHTYPE_PLUMTREE);
		filter[0][2]					  = new Integer(PT_PROPIDS.PT_PROPID_OBJECTID); // don't want current object; for creation means id!=0 and is Ok
		filter[1][2]					  = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		filter[2][2]					  = new Integer(GetObjectID());
		query.Query(fields, -1, null, filter);

		int n			  = query.GetCount();
		Object[][] result = new Object[2][n + 1];

		int indPartner;
		for (indPartner = 0; indPartner < n; indPartner++)
		{
			int id   = XPConvert.ToInteger(query.GetItem(indPartner,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String name  = (String) query.GetItem(indPartner, PT_PROPIDS.PT_PROPID_NAME);
			result[0][indPartner] = new Integer(id);
			result[1][indPartner] = name;
		}
		
		// Add SSO Auth Partner
		result[0][indPartner] = new Integer(PT_INTRINSICS.PT_AUTHSOURCE_SSO);
		result[1][indPartner] = m_asOwner.GetString(3064, "ptmsgs_portaladminmsgs");
		
		return result;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int selectedPartnerId()
	{
		IPTAuthSource ptAS = (IPTAuthSource) GetObject();

		return ptAS.GetAuthPartnerID();
	}
	
	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		nPageStatus = super.SavePage(_sPageName, _htFormData);
		
		if (_sPageName.equals(MainDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = SaveMainPage(_htFormData);
		}
					
		return nPageStatus;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveMainPage(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;
		
		String strPartner = ModelHelper.GetFormElementString(_htFormData, AuthSourceSelectAuthPartnerView.HTMLINPUT_PARTNERS, "");
		
		IPTAuthSource ptAS = (IPTAuthSource)GetObject();
		if (strPartner != null)
		{
			ptAS.SetAuthPartnerID(XPConvert.ToInteger(strPartner));
		}
		else
		{
			ptAS.SetAuthPartnerID(0);
		}

		return nPageStatus;
	}
}

