package com.plumtree.portalpages.admin.editors.bestbets;


// Framework Imports
import com.plumtree.openfoundation.internationalization.XPLocale;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.serversettings.search.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.search.admin.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author CraigS, based on JulieF template
 */
public class BestBetModel extends EditorModel implements IBestBetModelRO,
	IBestBetModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.bestbets.BestBetModel");


	public static final String STR_MVC_CLASS_NAME = "BestBet";


	public static final int MAX_TARGETS = 20;
	protected String m_originalSearchString = null;
	protected String m_searchString	    = null;
	protected String m_setupSearchString = null;
	protected XPArrayList m_arrListTargets = new XPArrayList();
	protected boolean m_bIsBestBetInDB = false; 
	/**
	 *
	 */
	public void ActionOnRepost()
	{
		// Anything needed here?
	}

	//
	// IBestBetModel implementation
	//
	public void AddTarget(String newTargId, String newTargApp,
		String newTargName)
	{
		if (m_arrListTargets.GetSize() >= MAX_TARGETS)
		{
			log.Error("already have " + m_arrListTargets.GetSize() + " targets");
			return;
		}
		final int MAX_NAME_LENGTH = 250;

		if (newTargName.length() > MAX_NAME_LENGTH)
		{
			newTargName = newTargName.substring(0, MAX_NAME_LENGTH);
		}

		IPTBestBetTarget bbTarget = PortalObjectsFactory.CreateBestBetTarget();
		bbTarget.setId(newTargId);
		bbTarget.setType(newTargApp);
		bbTarget.setName(newTargName);
		m_arrListTargets.Add(bbTarget);
	}

	/**
	 * Implements some actions to perform on start.
	 * @param formData
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable formData)
	{
		IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();

		boolean isAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession);
		boolean hasRight = ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SEARCH_SERVER_TUNING);
		if(!(isAdmin || hasRight))
		{
			return false;
		}	
		m_originalSearchString = null;
		m_bIsBestBetInDB = false;
		m_searchString     = "";
		m_setupSearchString = "";
		m_arrListTargets = new XPArrayList();

		String[] item     = (String[]) formData.GetElement(BestBetRepostControl.HTMLINPUT_ITEM_TO_EDIT_ON_START);

		if (null != item)
		{
			int indexIntoParentModel = -1; // zero-based index into displayed Best Bet list thats maintained by parent model.
			try
			{
				indexIntoParentModel = XPConvert.ToInteger(item[0]);
			}
			catch (Exception e)
			{
				throw XPException.GetInstance(e);
			}
			if (indexIntoParentModel >= 0)
			{
				// Ask our parent space for its cached info on this item
				AActivitySpace parentSpace = m_asOwner.GetParentSpace();

				if (null != parentSpace)
				{
					ISearchServerTuningEditorModelRO parentModel = (ISearchServerTuningEditorModelRO) (parentSpace.GetModel(SearchServerTuningEditorModel.STR_MVC_CLASS_NAME));

					if (null != parentModel && indexIntoParentModel < parentModel.GetNumBestBetsOnPage())
					{
						// initialize it
						m_searchString     = parentModel.GetBestBetTrigger(indexIntoParentModel);
						m_setupSearchString = parentModel.GetBestBetSetupString(indexIntoParentModel);
						m_originalSearchString = m_searchString;
						m_bIsBestBetInDB = (parentModel.HasBestBetBeenNewlyAdded(indexIntoParentModel) == false);
						m_arrListTargets = new XPArrayList();
						IXPList listOriginal = parentModel.GetBestBetTargets(indexIntoParentModel);
						for(int i=0; i < listOriginal.GetSize(); i++)
						{
							IPTBestBetTarget origTarget = (IPTBestBetTarget)listOriginal.GetElement(i);
								
							IPTBestBetTarget bbTarget = PortalObjectsFactory.CreateBestBetTarget();
							bbTarget.setId(origTarget.getId());
							bbTarget.setType(origTarget.getType());
							bbTarget.setName(origTarget.getName());
							m_arrListTargets.Add(bbTarget);
						}
					}
				}
			}
		}

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new BestBetModel();
	}

	/**
	 *
	 *
	 * @param id
	 */
	public void DeleteTarget(int id)
	{
		if ((id <= 0) || (id > _numTargets()))
		{
			
				log.Error("id out of range: id=" + id + " numTargets=" + _numTargets());
			

			return;
		}
		m_arrListTargets.RemoveAt(id-1);
	}

	public void MoveTargetUp(int id)
	{
		if(id > 1 && id <= MAX_TARGETS)
		{
			SwapTarget(id, id-1);
		}
	}

	public void MoveTargetDown(int id)
	{
	    if(id > 0 && id < _numTargets())
			SwapTarget(id,id+1);
	}

	public void MoveToTop(int id)
	{
		if(id > 1 && id <= MAX_TARGETS)
		{
			SwapTarget(1, id);
		}
	}

	public void MoveToBottom(int id)
	{
	    if(_numTargets() == id)
			return;
	    else
			SwapTarget(_numTargets(),id);
	}

	protected void SwapTarget(int id1, int id2)
	{
		String tempId 	= GetTargetId(id1);
		String tempApp 	= GetTargetApp(id1);
		String tempName = GetTargetName(id1);

		SetTargetApp(id1, GetTargetApp(id2));
		SetTargetName(id1,GetTargetName(id2));
		SetTargetId(id1,GetTargetId(id2));

		SetTargetApp(id2, tempApp);
		SetTargetName(id2, tempName);
		SetTargetId(id2, tempId);
	}

	/**
	 * Implements actions when the user clicks on "Finish".
	 */
	public void Finish()
	{
		// This editor is always run as a subeditor of the
		// Search Server Settings editor, which handles saving any changes
		// made here.  Just notify it that we may have changed.
		updateParentSpaceOnSubEditorClose();
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetMaxTargets()
	{
		return MAX_TARGETS;
	}

	/**
	 * Returns the Class name.
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetNumTargets()
	{
		return _numTargets();
	}

	//
	// IBestBetModelRO implementation
	//
	public String GetSearchString()
	{
		return m_searchString;
	}

	//
	// IBestBetModelRO implementation
	//
	public String GetSetupSearchString()
	{
		return m_setupSearchString;
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	public String GetTargetApp(int id)
	{
		IPTBestBetTarget bbTarget = (IPTBestBetTarget)m_arrListTargets.GetElement(id-1);
		if(bbTarget == null) return null;

		return bbTarget.getType();
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	public String GetTargetId(int id)
	{
		IPTBestBetTarget bbTarget = (IPTBestBetTarget)m_arrListTargets.GetElement(id-1);
		if(bbTarget == null) return null;

		return bbTarget.getId();
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	public String GetTargetName(int id)
	{
		IPTBestBetTarget bbTarget = (IPTBestBetTarget)m_arrListTargets.GetElement(id-1);
		if(bbTarget == null) return null;

		return bbTarget.getName();
	}

	public void SetTargetApp(int id, String newApp)
	{
		IPTBestBetTarget bbTarget = (IPTBestBetTarget)m_arrListTargets.GetElement(id-1);
		if(bbTarget != null)
		{
			bbTarget.setType(newApp);
		}
	}

	public void SetTargetName(int id, String newName)
	{
		IPTBestBetTarget bbTarget = (IPTBestBetTarget)m_arrListTargets.GetElement(id-1);
		if(bbTarget != null)
		{
			bbTarget.setName(newName);
		}
	}

	public void SetTargetId(int id, String newID)
	{
		IPTBestBetTarget bbTarget = (IPTBestBetTarget)m_arrListTargets.GetElement(id-1);
		if(bbTarget != null)
		{
			bbTarget.setId(newID);
		}
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param pageName
	 * @param formData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String pageName, XPHashtable formData)
	{
		if (pageName.equals(BestBetEditorDP.STR_MVC_CLASS_NAME))
		{
			return SaveMainPage(formData);
		}

		return RepostControl.PAGE_STATUS_INVALID;
	}

	/**
	 *  Called (via Finish()) when the
	 *  Done button is pressed, when this editor is running as a subeditor of the
	 *  SearchServerSettings editor.  Informs the parent editor of the changes that
	 *  have been made.
	 */
	public void updateParentSpaceOnSubEditorClose()
	{
		ISearchServerTuningEditorModelRO parentModel = GetParentModel();

		if (null != parentModel)
		{
			parentModel.UpdateBestBetFromSubEditor(m_originalSearchString, m_bIsBestBetInDB, m_searchString, m_setupSearchString, m_arrListTargets);
		}
	}


	/**
	 * Saves the data on the Main page.
	 * @param _formData
	 */
	protected int SaveMainPage(XPHashtable formData)
	{
		String[] data;

		boolean clickedFinish = false;

		// Some errors should only be raised if the user is clicking "Finish".
		data = (String[]) formData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
		if (data[0].equals(XPConvert.ToString(RepostControl.POSTTOSELF_ACTION_FINISH)))
		{
			clickedFinish = true;
		}

		data = (String[]) formData.GetElement(BestBetEditorView.SEARCH_STRING_SETTING);

		if ((null != data) && !(0 == data.length))
		{
			// Trim whitespace from the query string
			m_searchString = data[0].trim();
			// Make the query string lower case.
			XPLocale locale = new XPLocale(m_asOwner.GetLocale());
 			m_searchString = XPStringUtility.ToLowerCase(m_searchString, locale);

			// Get the string used to find Best Bet targets
			String[] setupSearchData = (String[]) formData.GetElement(StartSearchControl.USER_QUERY);

			if(setupSearchData != null && setupSearchData.length > 0)
			{
				m_setupSearchString = setupSearchData[0];
			}
			
			if (clickedFinish)
			{
				if (0 == m_searchString.length())
				{
					// Raise an error
					UIError err = new UIError(UIErrorLevel.FRIENDLY,
                                    UIErrorScope.CURRENT_USER, null,
  					                m_asOwner.GetString(171, ResourceConstants.PORTALADMINMSGS),
                                    m_asOwner.GetString(171, ResourceConstants.PORTALADMINMSGS));
					UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(),
                                    m_asOwner.GetApplication());

					return RepostControl.PAGE_STATUS_INVALID;
				}
			}

			// Check whether the user has entered a search string that duplicates another BB
			ISearchServerTuningEditorModelRO parentModel = GetParentModel();

			if (null != parentModel && clickedFinish)
			{
				boolean isNotDup = parentModel.CheckDuplicateBestBetQuery(m_originalSearchString, m_searchString, !m_bIsBestBetInDB);

				if (!isNotDup)
				{
					// Raise an error
					UIError err = new UIError(UIErrorLevel.FRIENDLY,
							UIErrorScope.CURRENT_USER, null,

						m_asOwner.GetString(173, ResourceConstants.PORTALADMINMSGS),
							m_asOwner.GetString(173, ResourceConstants.PORTALADMINMSGS));
					UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(),
						m_asOwner.GetApplication());

					return RepostControl.PAGE_STATUS_INVALID;
				}
			} // end parentModel != null
		}
		else // data == null || data.length == 0
		{
			log.Warn("BestBetModel::SaveMainPage Search string parameter was not in query string.");
			return RepostControl.PAGE_STATUS_INVALID;
		}

		// We don't want to allow saving the page if no targets have been defined.
		if (clickedFinish && (0 == _numTargets()))
		{
			UIError err = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null,

				m_asOwner.GetString(172, ResourceConstants.PORTALADMINMSGS),
					m_asOwner.GetString(172, ResourceConstants.PORTALADMINMSGS));
			UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());

			return RepostControl.PAGE_STATUS_INVALID;
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 *  Helper method to get the parent space's model interface, if any.
	 */
	private ISearchServerTuningEditorModelRO GetParentModel()
	{
		AActivitySpace parentSpace = m_asOwner.GetParentSpace();

		if (null != parentSpace)
		{
			return (ISearchServerTuningEditorModelRO) (parentSpace.GetModel(SearchServerTuningEditorModel.STR_MVC_CLASS_NAME));
		}

		return null;
	}
	
	private int _numTargets()
	{
		if(m_arrListTargets == null) return 0;
		return m_arrListTargets.GetSize();
	}
}

