package com.plumtree.portalpages.admin.editors.bestbets;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * @author CraigS, based on JulieF template
 */
public class BestBetRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.bestbets.BestBetRepostControl");


	public static final String STR_MVC_CLASS_NAME = "BestBetRepost";

	public final static int POSTTOSELF_NOOP = 10;
	public final static int POSTTOSELF_ACTION_DELTARGS = 11;
	public final static int POSTTOSELF_ACTION_ADDTARG = 12;

	public final static int POSTTOSELF_ACTION_DELTARG_START = 13;
	public final static int POSTTOSELF_ACTION_DELTARG_END = 33;
	public final static int POSTTOSELF_ACTION_MOVETARGUP_START = 34;
	public final static int POSTTOSELF_ACTION_MOVETARGUP_END = 54;
	public final static int POSTTOSELF_ACTION_MOVETARGDOWN_START = 55;
	public final static int POSTTOSELF_ACTION_MOVETARGDOWN_END = 75;
	public final static int POSTTOSELF_ACTION_MOVETOBOTTOM_START = 76;
	public final static int POSTTOSELF_ACTION_MOVETOBOTTOM_END = 96;
	public final static int POSTTOSELF_ACTION_MOVETOTOP_START = 97;
	public final static int POSTTOSELF_ACTION_MOVETOTOP_END = 117;


	public final static String HTMLINPUT_SELECTED_ITEM = "in_cb_selectedItem";


	public final static String HTMLINPUT_ITEM_TO_EDIT_ON_START = "inititem";


	public final static String HIDDEN_ADD_DELETE = "in_hi_add_delete";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new BestBetRepostControl();
	}

	/**
	 * Returns the Class name.
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 * @param int
	 */
	protected void PerformAction(int action)
	{
		super.PerformAction(action);

		BestBetModel bbModel = (BestBetModel) m_model;

		if(action == POSTTOSELF_NOOP)
		{
			// PTDEbug something here
		}
		else if(action >= POSTTOSELF_ACTION_MOVETOBOTTOM_START && action <= POSTTOSELF_ACTION_MOVETOBOTTOM_END)
		{
			int nTargetNum = action -  POSTTOSELF_ACTION_MOVETOBOTTOM_START;
			bbModel.MoveToBottom(nTargetNum);
		}
		else if(action >= POSTTOSELF_ACTION_MOVETOTOP_START && action <= POSTTOSELF_ACTION_MOVETOTOP_END)
		{
			int nTargetNum = action -  POSTTOSELF_ACTION_MOVETOTOP_START;
			bbModel.MoveToTop(nTargetNum);
		}
		else if(action >= POSTTOSELF_ACTION_MOVETARGUP_START && action <= POSTTOSELF_ACTION_MOVETARGUP_END)
		{
			int nTargetNum = action -  POSTTOSELF_ACTION_MOVETARGUP_START;
		    bbModel.MoveTargetUp(nTargetNum);
		}
		else if(action >= POSTTOSELF_ACTION_MOVETARGDOWN_START && action <= POSTTOSELF_ACTION_MOVETARGDOWN_END)
		{
			int nTargetNum = action -  POSTTOSELF_ACTION_MOVETARGDOWN_START;
		    bbModel.MoveTargetDown(nTargetNum);
		}
		else if(action >= POSTTOSELF_ACTION_DELTARG_START && action <= POSTTOSELF_ACTION_DELTARG_END)
		{
			int nTargetNum = action -  POSTTOSELF_ACTION_DELTARG_START;
			bbModel.DeleteTarget(nTargetNum);
		}
		else if(action == POSTTOSELF_ACTION_DELTARGS)
		{
				boolean done = false;
			    // Deletion order matters here--must go back to front.
				for(int j = bbModel.GetNumTargets(); j >= 1; j--)
				{
				    if (m_htFormData.ContainsKey(BestBetEditorView.DEL_TARGET_CB + XPConvert.ToString(j)))
				    {
				    	done = true;
						bbModel.DeleteTarget(j);
				    }
				}
			    if(!done && m_htFormData.ContainsKey(HIDDEN_ADD_DELETE))
			    {
					String[] item = (String[]) m_htFormData.GetElement(HIDDEN_ADD_DELETE);
					if(item[0] != null && ! item[0].equals(""))
					{
						int nTargDel = 0;
						try { nTargDel = XPConvert.ToInteger(item[0]); } catch(Exception e) { nTargDel = -1; }
						if(nTargDel > 0) bbModel.DeleteTarget(nTargDel);
					}
			    }
		}
		else if(action == POSTTOSELF_ACTION_ADDTARG)
		{
				String key = null;
				if(m_htFormData.ContainsKey(HIDDEN_ADD_DELETE))
					key = HIDDEN_ADD_DELETE;
				else if(m_htFormData.ContainsKey(HTMLINPUT_SELECTED_ITEM))
					key = HTMLINPUT_SELECTED_ITEM;
				if (key != null)
				{
					String[] item = (String[]) m_htFormData.GetElement(key);
					try 
					{
						int resultNum = XPConvert.ToInteger(item[0]);
	
						ISearchResultModelRO _searchModel = (ISearchResultModelRO) (m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME));

						String strNewTargetId = XPConvert.ToString(_searchModel.GetResultBestBetKey(resultNum));
						String strNewTargetApp = XPConvert.ToString(_searchModel.GetResultApp(resultNum));
						boolean bTargetIsNew = true;
						
						for(int i=1; bTargetIsNew && i <= bbModel.GetNumTargets(); i++)
						{
						    String strTargetId = bbModel.GetTargetId(i);
						    String strTargetApp = bbModel.GetTargetApp(i);
						    if(strTargetId.equals(strNewTargetId) && strTargetApp.equals(strNewTargetApp))
						    {
						        bTargetIsNew = false;
						    }
						}
						if(bTargetIsNew)
						{
						    bbModel.AddTarget(strNewTargetId, strNewTargetApp,_searchModel.GetResultName(resultNum));
						}
					}
					catch(Exception e)
					{
						
							log.Error(e, e.getMessage());
						
					}
				}
		}
	}

	public static int GetMoveUpCode(int id)
	{
		if(id <= 1 || id > 20) // Can't move up past #1 spot.
			return POSTTOSELF_NOOP;
		else
			return POSTTOSELF_ACTION_MOVETARGUP_START + id;
	}
	
	public static int GetMoveDownCode(int id)
	{
	    if(id < 1 || id > 20)
			return POSTTOSELF_NOOP;
	    else
			return POSTTOSELF_ACTION_MOVETARGDOWN_START + id;
	}

	public static int GetMoveTopCode(int id)
	{
		if(id <= 1 || id > 20) // Can't move up past #1 spot.
			return POSTTOSELF_NOOP;
		else
			return POSTTOSELF_ACTION_MOVETOTOP_START + id;
	}

	public static int GetMoveBottomCode(int id)
	{
	    if(id < 1 || id > 20)
			return POSTTOSELF_NOOP;
	    else
			return POSTTOSELF_ACTION_MOVETOBOTTOM_START + id;
	}
}

