package com.plumtree.portalpages.admin.editors.bestbets;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public class SearchBoxView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.bestbets.SearchBoxView");

	public static final String STR_MVC_CLASS_NAME   = "SearchBoxView";
	protected AActivitySpace _parent;
	protected IBaseSearchResultModelRO _searchModel;
	protected IBestBetModelRO _bbModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SearchBoxView();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable table = new HTMLTable();
		result.AddInnerHTMLElement(table);
		HTMLTableRow row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);
		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		try
		{
			// Make a searchform factory with a unique name
			SearchFormFactory factory = new SearchFormFactory(AFormDP.HTMLFORM_NAME,
					AFormDP.HTMLFORM_NAME, _parent,
				/* completeForm= */ false);

			// Use ten items per page, since we're in a popup.
			factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS,
				10);

			// Restrict to same types as banner search.
			factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
				StartSearchControl.GetBannerSearchObjectTypes());

     		// Suppress header, footer, and canvas portlets
      		factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_GADGET_SEARCH_TYPE,
                                 SearchSettingCollection.GADGET_SEARCH_TYPE_BANNERSEARCH);

			// Hack: Force the form to be submitted if the user hits enter in the
			// search box.  Dangerous, this can cause double submits if not used carefully.
			factory.ForceSubmitOfEnclosingForm();

			// Display the guts of the form
			result.AddInnerHTMLElement(factory.GetResult());
			HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT,
					factory.GetInputBoxName(), "myID");
			input.SetOnKeyDown(factory.GetInputBoxOnKeyDown());
			input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			input.SetSize(30);

			if (_searchModel.IsInitialized())
			{
				input.SetValue(_searchModel.GetSearchString());
			}
			else
			{
				// for an initial search, get the current query string out of the
				// best-bet model
				input.SetValue(_bbModel.GetSetupSearchString());
			}

			cell.AddInnerHTMLElement(input);
			//result.AddInnerHTMLElement(input);

			// Add space before the search button
			//result.AddInnerHTMLString("&nbsp;&nbsp;");
			//cell.AddInnerHTMLString("&nbsp;&nbsp;");

			// Add submit button
			HTMLAnchor submitLink = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			submitLink.SetOnClick(factory.GetAnchorOnClick());
			submitLink.AddInnerHTMLElement(SearchFormFactory.GetSearchButton(
					_parent));
			//result.AddInnerHTMLElement(submitLink);
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetVAlign("middle");
			cell.AddInnerHTMLElement(submitLink);
		}
		catch (HTMLException e)
		{
			
				log.Error(e, e.getMessage());
			

			throw XPException.GetInstance(e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		// by default, return nothing
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		_searchModel     = (IBaseSearchResultModelRO) model;
		_parent			 = parent;

		// Get the best-bet model as well
		_bbModel = (IBestBetModelRO) _parent.GetModel(BestBetModel.STR_MVC_CLASS_NAME);
	}
}

