package com.plumtree.portalpages.admin.editors.common.setjob;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section is used to display the Job Owner section.
 *
 * @author Julie Fournier
 */
public class ObjectOwnerView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.common.setjob.ObjectOwnerView");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "ObjectOwner";

	/** HTML Object name: Change owner button */
	public static final String HTMLBUTTON_OPEN_OWNERTREE = "in_bu_OpenOwnerTree";

	/**
	 * HTML Object names: owner tree ID */
	public static final String HTMLINPUT_OWNERTREEASID = "in_hi_OwnerTreeSpaceID";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectOwnerView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLSpan mySpan;
		HTMLInput myInput;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						179, ResourceConstants.PORTALADMINMSGS)));

			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetVAlign("top");
			myCell.SetNoWrap(true);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(178,
					ResourceConstants.PORTALADMINMSGS));
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);

			// SCC: this can happen when the user does not have read access to the owner or the administrator
			String strOwnerName = ((ISetJobModelRO) m_model).GetOwnerName();
			if(null == strOwnerName)
			{
				// "Job Owner"
				strOwnerName = m_asOwner.GetString(180,
						ResourceConstants.PORTALADMINMSGS);		 
			}
			myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strOwnerName));
			myCell.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLString(SPACE);

			if (((ISetJobModelRO) m_model).IsSysAdmin())
			{
				myInput = new HTMLInput(HTMLInputTypes.BUTTON,
						HTMLBUTTON_OPEN_OWNERTREE, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

				myInput.SetValue(m_asOwner.GetString(179,
						ResourceConstants.PORTALADMINMSGS));
				myInput.SetOnClick("OpenTree(document." +
					EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_OWNERTREEASID +
					"); return false;");

				// hidden input with the owner tree space ID
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_OWNERTREEASID, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetValue(((ISetJobModelRO) m_model).GetOwnerTreeSpaceID());
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "ObjectOwnerView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(177,
					ResourceConstants.PORTALADMINMSGS), e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		if (((ISetJobModelRO) m_model).IsSysAdmin())
		{
			// The URL to open a new tree
			ASURL myNewTree = new ASURL(m_asOwner);

			myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
			myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
			myNewTree.SetSubSpaceKey(SetJobModel.SUBSPACE_KEY_OWNERTREE);
			myNewTree.AddControlArgument(StartTreeControl.ROOT_ID,
				XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
			myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT, false);
			myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE,
				TreeConstants.N_LEAFSELECT);
			myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
				TreeConstants.N_SERVERSUBMIT);
			myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
				EditorDP.HTMLFORM_NAME);
			myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
				HTMLINPUT_OWNERTREEASID);
			myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
				"ChangeOwner");
			myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
				PT_CLASSIDS.PT_USER_ID);
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				PT_CLASSIDS.PT_USER_ID + "," +
				((ISetJobModelRO) m_model).GetOwnerID());
			myNewTree.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(1781, ResourceConstants.PORTALADMINMSGS));
			myNewTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
				m_asOwner.GetString(1780, ResourceConstants.PORTALADMINMSGS));

			// The url to open a previously opened server user tree
			// This needs to have the SpaceID added to it.
			ASURL myOldTree = new ASURL(m_asOwner);
			myOldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
			myOldTree.IsSubSpace();

			try
			{
				XPStringBuilder sb = new XPStringBuilder(400);

				// Open Tree function
				sb.Append("function OpenTree(myInput)\n");
				sb.Append("{\n");
				sb.Append("  if (myInput.value == '') {\n");
				sb.Append("    window.open('").Append(myNewTree.GetURLAsString())
				.Append("', '_blank1', '")
				.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
				sb.Append("  } else {\n");
				sb.Append("    window.open('").Append(myOldTree.GetURLAsString())
				.Append("&").Append(ASConstants.SPACEID)
				.Append("=' + myInput.value").Append(", '_blank1', '")
				.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
				sb.Append("  }\n");
				sb.Append("}\n");

				myScript.AddInnerHTMLString(sb.ToString());

				// On return from Tree function
				sb = new XPStringBuilder(200);
				sb.Append(" function ChangeOwner()");
				sb.Append(" {");
				sb.Append(" 	postToSelf('" +
					SetJobRepostControl.POSTTOSELF_ACTION_CHANGE_OWNER + "');");
				sb.Append(" }");

				myScript.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "ObjectOwnerView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
						he.getMessage());
				
			}
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

