package com.plumtree.portalpages.admin.editors.common.setjob;

import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This DP displays the Views for the object owner
 * and the Job selector table.
 *
 * @author Julie Fournier
 */
public class SetJobDP extends EditorDP {
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SetJob";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return (m_asOwner.GetString(181, ResourceConstants.PORTALADMINMSGS));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()  {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1667, ResourceConstants.PORTALADMINMSGS),
			this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// JF- Job owner view
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(ObjectOwnerView.STR_MVC_CLASS_NAME))
				.Display());

		// JF- Spacer table
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// JF- Job selector tab
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB))
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	 {
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(ObjectOwnerView.STR_MVC_CLASS_NAME)
				.DisplayJavascript());
		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)
				.DisplayJavascript());

		return myScripts;
	}
}

