package com.plumtree.portalpages.admin.editors.communitytemplate;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.inherit.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 * @author michaeld
 */
public class CommunityTemplateEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.communitytemplate.CommunityTemplateEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommTemp";

	/** SelectPTObject Model for communities that use the template */
	public static final String PLUGIN_COMMUNITIES = "CommunitiesList";

	/** SelectPTObject Model for selecting page templates */
	public static final String PLUGIN_SELECT_PAGE_TEMPLATE = "SelectPageTemplate";

	/** SelectPTObject Model for selecting a header */
	public static final String PLUGIN_SELECT_HEADER = "SelectHeader";

	/** SelectPTObject Model for selecting a footer */
	public static final String PLUGIN_SELECT_FOOTER = "SelectFooter";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityTemplateEditorAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(189, ResourceConstants.PORTALADMINMSGS);
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(2604, ResourceConstants.PORTALADMINMSGS), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (CommunityTemplateDepView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Returns the class name of the Community Template Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (CommunityTemplateRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Community Template Activity Space.
	 */
	public void Init()
	{
		m_strModelName = CommunityTemplateModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = (EditorModel) GetModel(m_strModelName);

		// Register DisplayPages
		RegisterPage(new CommunityTemplateMainDP());

		RegisterPage(new CommunityTemplateCommunitiesDP());
		RegisterPage(new HeaderAndFooterSelectorDP());

		// Register Views
		RegisterView(HeaderAndFooterSelectorView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(CommunityTemplateDepView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(CommunityTemplateRepostControl.STR_MVC_CLASS_NAME,
			myModel);
		RegisterControl(HeaderAndFooterRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register the select PTObject list as a plug-in section
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			PLUGIN_SELECT_PAGE_TEMPLATE);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPageTemplateModel = GetModel(PLUGIN_SELECT_PAGE_TEMPLATE);
		RegisterView(SelectPageTemplateView.STR_MVC_CLASS_NAME,
			PLUGIN_SELECT_PAGE_TEMPLATE, mySelectPageTemplateModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_SELECT_PAGE_TEMPLATE, mySelectPageTemplateModel);

		// Register the select PTObject list as a plug-in section
		RegisterModel(InheritListModel.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITIES);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myCommunitiesModel = GetModel(PLUGIN_COMMUNITIES);
		RegisterView(CommunitiesListView.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITIES, myCommunitiesModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITIES, myCommunitiesModel);

		// Set default page
		SetCurrentPage(CommunityTemplateMainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(192,
					ResourceConstants.PORTALADMINMSGS));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityTemplateMainDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityTemplateCommunitiesDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1784, ResourceConstants.PORTALADMINMSGS));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{


				int iTitleId = 15;
				int iTipId = 16;
				int iSecondaryTipId = 17;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}


			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if( CommunityTemplateMainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_CommunityTemplate_MainSettings" );
		}
		else if ( HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_HeaderandFooter" );
		}
	}
}

