package com.plumtree.portalpages.admin.editors.communitytemplate;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.inherit.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 *
 *
 * @author michaeld
 */
public class CommunityTemplateModel extends ObjEditorModel
	implements IEditorModelRO, IHeaderAndFooterModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.communitytemplate.CommunityTemplateModel");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommTemp";

	/** Repost Action: From Tree */
	public static final int POSTTOSELF_ACTION_RETURN_FROM_TREE = 32;

	/** List Key: Header */
	public static final int LIST_KEY_HEADER = 2;

	/** List Key: Footer */
	public static final int LIST_KEY_FOOTER = 3;

	public static final int HEADERFOOTER_ID_FORCE_SUBPORTAL = -1;

	/** Name of the Footer **/
	private String m_strFooterName;

	/** Name of the Header **/
	private String m_strHeaderName;

	/** If true, enables the force subportal header/footer checkbox **/
	private boolean m_bIsTemplateSelector = true;

	/** Form Data */
	private XPHashtable m_htFormData;

	/** Old Selected Objects */
	private XPSortedDictionary m_xpsdOldSelectedObjects;
	private boolean m_bFooterHasCommunityPrefs;
	private boolean m_bHeaderHasCommunityPrefs;

	/** Have the page templates changed? Set in before store method, used in after store method. */
	private boolean m_bPageTemplateChanged;

	/** PortletID of the Footer **/
	private int m_nFooterID = 0;

	/** Portlet ID of the Header **/
	private int m_nHeaderID = 0;

	//
	// Header and Footer Category END
	//

	public CommunityTemplateModel()
	{
		m_htFormData = new XPHashtable();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityTemplateModel();
	}

	/**
	 * Code executed after the object is stored.
	 */
	public void DoTaskAfterStore()
	{
		if (m_nEditorType == EditorStartControl.EDITOR_START_FLAG_CREATE)
		{
			PTGrowableSortedArrayWrapper aSelectedObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE)).GetItems();

			for (int i = 0; i < aSelectedObjectValues.GetCount(); i++)
			{
				int oObjectID = XPConvert.ToInteger(aSelectedObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID));
				((IPTCommunityTemplate) m_ptObject).AddPageTemplate(oObjectID);
			}
		}
		else
		{
			if (m_bPageTemplateChanged)
			{
				// Start ABO
				((IPTScheduledOperation) m_ptObject).ScheduleImmediateJob();
			}
		}
	}

	/**
	 * Initializes IPTProperty with the property type member  variable just
	 * before we store the object in the DB. Also sets 2 other values to
	 * default.
	 */
	public void DoTaskBeforeStore()
	{
		m_bPageTemplateChanged = false;

		if (m_nEditorType == EditorStartControl.EDITOR_START_FLAG_EDIT)
		{
			// Add and Remove page templates
			PTGrowableSortedArrayWrapper aSelectedObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE)).GetItems();

			int oObjectID;
			int[] arrPageTemplateIDs						   = new int[aSelectedObjectValues.GetCount()];

			for (int i = 0; i < aSelectedObjectValues.GetCount(); i++)
			{
				oObjectID     = XPConvert.ToInteger(aSelectedObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID));

				arrPageTemplateIDs[i] = oObjectID;

				if (m_xpsdOldSelectedObjects.ContainsKey(new Integer(oObjectID)))
				{
					m_xpsdOldSelectedObjects.RemoveElement(new Integer(oObjectID));
				}
				else
				{
					((IPTCommunityTemplate) m_ptObject).AddPageTemplate(arrPageTemplateIDs[i]);
					m_bPageTemplateChanged = true;
				}
			}

			IXPEnumerator xpeKeys = m_xpsdOldSelectedObjects.GetKeys();

			while (xpeKeys.MoveNext())
			{
				((IPTCommunityTemplate) m_ptObject).RemovePageTemplate(XPConvert.ToInteger(xpeKeys.GetCurrent()));
				m_bPageTemplateChanged = true;
			}

			((IPTCommunityTemplate) m_ptObject).UpdatePageTemplateOrder(arrPageTemplateIDs);
		}


		if ( ((IPTCommunityTemplate) m_ptObject).GetHeaderID() != m_nHeaderID )
		{
			// Set Header ID
			((IPTCommunityTemplate) m_ptObject).SetHeaderID(m_nHeaderID);
		}

		if ( ((IPTCommunityTemplate) m_ptObject).GetFooterID() != m_nFooterID )
		{
			// Set Footer ID
			((IPTCommunityTemplate) m_ptObject).SetFooterID(m_nFooterID);
		}
	}

	// END ***************** helper methods *****************

	/**
	 * Initializes the property type member variable with  the one from
	 * IPTProperty in Edit mode and the default  value in create mode.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		StartSelectPageTemplate();

		//    	StartSelectHeaderOrFooter(CommunityTemplateEditorAS.strStorageSelectHeader);
		//    	StartSelectHeaderOrFooter(CommunityTemplateEditorAS.strStorageSelectFooter);
		//       executed just after the Object was created or retrieved from the DB.
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			// ***CHANGE_HERE SECURITY PAGE*** Hide the security page in edit mode
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(false,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
		}
		else
		{
			// ***CHANGE_HERE SECURITY PAGE*** Hide the security page in edit mode
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

		StartHeaderAndFooter();
		StartCommunities();
	}

	/**
	 * Not a community return -1.
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetCommunityID()
	 */
	public int GetCommunityID()
	{
		return -1;
	}

	/**
	 *
	 *
	 * @param name
	 *
	 * @return
	 */
	public String GetData(String name)
	{
		String[] values = (String[]) m_htFormData.GetElement(name);

		if (values == null)
		{
			return "";
		}

		return values[0];
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetFooterHasCommunityPrefs()
	{
		return m_bFooterHasCommunityPrefs;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetFooterID()
	{
		
			log.Debug("Footer for this community is: " + m_nFooterID);
		

		return m_nFooterID;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetFooterName()
	 */
	public String GetFooterName()
	{
		
			log.Debug("Footer name for this community is: " + m_strFooterName);
		

		return m_strFooterName;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetHeaderHasCommunityPrefs()
	{
		return m_bHeaderHasCommunityPrefs;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetHeaderID()
	{
		
			log.Debug("Header for this community is: " + m_nHeaderID);
		

		return m_nHeaderID;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetHeaderName()
	 */
	public String GetHeaderName()
	{
		
			log.Debug("Header name for this community is: " + m_strHeaderName);
		

		return m_strHeaderName;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndFooterModel#IsTemplateSelector()
	 */
	public boolean IsTemplateSelector()
	{
		return m_bIsTemplateSelector;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * This method gets the selected items from the tree.
	 */
	public void RefreshItemFromFooterTree(XPHashtable _htFormData)
	{
		if (m_asOwner.GetSubSpaceExists(
					HeaderAndFooterSelectorView.TREE_FOOTER_SUBSPACE))
		{
			AActivitySpace asTree  = m_asOwner.GetSubSpace(HeaderAndFooterSelectorView.TREE_FOOTER_SUBSPACE);
			ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList itemList   = treeModel.GetSelectedItems();

			if (itemList.GetSize() != 1)
			{
				
					log.Error("Footer tree selected wrong number of items.  Expecting 1, got " +
						itemList.GetSize());
				
			}

			TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

			if (item == null)
			{
				log.Error("Tree selected item null");
				// TODO CR DLH: Shouldn't we do something here?  Otherwise it's easy to get NPEs.
			} else
			{
				m_nFooterID					   = item.m_nObjectID;
				m_strFooterName				   = item.GetName();
				m_bFooterHasCommunityPrefs     = GatewayUtils.GetPortletSupportsPersonalization(m_nFooterID,
					PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
					GetPTSession());
			}
		}
		else
		{
			
				log.Error("Unable to retrieve the footer portlet tree subspace. Subspace does not exist.");
			
		}
	}

	/**
	 *
	 *
	 * @param _htFormData
	 */
	public void RefreshItemFromHeaderTree(XPHashtable _htFormData)
	{
		if (m_asOwner.GetSubSpaceExists(
					HeaderAndFooterSelectorView.TREE_HEADER_SUBSPACE))
		{
			AActivitySpace asTree  = m_asOwner.GetSubSpace(HeaderAndFooterSelectorView.TREE_HEADER_SUBSPACE);
			ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList itemList   = treeModel.GetSelectedItems();

			if (itemList.GetSize() != 1)
			{
				
					log.Error("Banner tree selected wrong number of items.  Expecting 1, got " +
						itemList.GetSize());
				
			}

			TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

			if (item == null)
			{
				
					log.Error("Tree selected item null");
				
			}

			m_nHeaderID					   = item.m_nObjectID;
			m_strHeaderName				   = item.GetName();
			m_bHeaderHasCommunityPrefs     = GatewayUtils.GetPortletSupportsPersonalization(m_nHeaderID,
					PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
					GetPTSession());
		}
		else
		{
			
				log.Error("Unable to retrieve the footer portlet tree subspace. Subspace does not exist.");
			
		}
	}

	// BEGIN ***************** helper methods *****************
	// END ***************** repost action methods *****************

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		// Switch between your DP and for each one call
		//       the associated save method
		if (_sPageName.equals(CommunityTemplateMainDP.STR_MVC_CLASS_NAME))
		{
			// if this is the display page where you have your select ptobject you need to
			// call the associated saveSection method.
			((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE)).SaveSection(_htFormData);
		}
		else if (_sPageName.equals(HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME))
		{
			// if this is the display page where you have your select ptobject you need to
			// call the associated saveSection method.
			//			((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.strStorageSelectHeader)).
			//				SaveSection(_htFormData);
			// if this is the display page where you have your select ptobject you need to
			// call the associated saveSection method.
			//			((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.strStorageSelectFooter)).
			//				SaveSection(_htFormData);

		}
		return nPageStatus;
	}

	/**
	 *
	 *
	 * @param bHeader
	 */
	public void SetDefaultHeaderOrFooter(boolean bHeader)
	{
		if (bHeader)
		{
			m_nHeaderID     = 0;

			m_strHeaderName				   = m_asOwner.GetString(212,
					ResourceConstants.PORTALADMINMSGS);
			m_bHeaderHasCommunityPrefs     = false;
		}
		else
		{
			m_nFooterID     = 0;

			m_strFooterName				   = m_asOwner.GetString(213,
					ResourceConstants.PORTALADMINMSGS);
			m_bFooterHasCommunityPrefs     = false;
		}
	}

	public void SetUseForceSubPortal(boolean bForce)
	{
		if ( bForce)
		{
			m_nHeaderID = HEADERFOOTER_ID_FORCE_SUBPORTAL;
			m_nFooterID = HEADERFOOTER_ID_FORCE_SUBPORTAL;
			m_strHeaderName = m_asOwner.GetString(2159, ResourceConstants.PORTALADMINMSGS);
			m_strFooterName = m_asOwner.GetString(2160, ResourceConstants.PORTALADMINMSGS);

		} else {
			m_nHeaderID = 0;
			m_nFooterID = 0;
			m_strHeaderName = m_asOwner.GetString(212, ResourceConstants.PORTALADMINMSGS);
			m_strFooterName = m_asOwner.GetString(213, ResourceConstants.PORTALADMINMSGS);
		}
	}

	/**
	 * This is a function used in the community editor to determine whether the
	 * footer was set in the community template, in which case we disable some
	 * of the buttons on the footer selection page.  When we're in the community
	 * template editor, we just return true.
	 *
	 * @return true
	 */
	public boolean UsingFooterFromCommunityTemplate()
	{
		return false;
	}

	/**
	 * This is a function used in the community editor to determine whether the
	 * header was set in the community template, in which case we disable some
	 * of the buttons on the header selection page.  When we're in the community
	 * template editor, we just return true.
	 *
	 * @return true
	 */
	public boolean UsingHeaderFromCommunityTemplate()
	{
		return false;
	}

	/**
	 * Helper method to start the Selected Header or Footer List.
	 *
	 */
	private void StartHeaderAndFooter()
	{
		int nObjectID = 0;

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			try
			{
				nObjectID = ((IPTCommunityTemplate) m_ptObject).GetHeaderID();

				if ( CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nObjectID )
				{
					m_strHeaderName = m_asOwner.GetString(2159, ResourceConstants.PORTALADMINMSGS);
					m_nHeaderID = nObjectID;
				}
				else
				{
					IPTQueryResult ptqrObjects = this.m_Session.GetGadgets()
						.QuerySingleObject(nObjectID);

					if (ptqrObjects.RowCount() == 1)
					{
						// DCA - delay htmlencoding til used in view
						//m_strHeaderName				   = XPHttpUtility.HtmlEncode(ptqrObjects.ItemAsString(0,
						//		PT_PROPIDS.PT_PROPID_NAME));
						m_strHeaderName				   = ptqrObjects.ItemAsString(0,
								PT_PROPIDS.PT_PROPID_NAME);
						m_nHeaderID					   = nObjectID;

						int nWebServiceID			   = ptqrObjects.ItemAsInt(0,
								PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);
						m_bHeaderHasCommunityPrefs     = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
								PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
								m_Session);
					}
					// No header stored, using default
					else
					{
						m_strHeaderName				   = m_asOwner.GetString(212,
								ResourceConstants.PORTALADMINMSGS);
						m_bHeaderHasCommunityPrefs     = false;
					}
				}
			}
			catch (Exception e)
			{
				
					log.Warn("Couldn't get the stored header ID: " + nObjectID +
						"  for CommunityTemplate ");
				
			}

			try
			{
				nObjectID = ((IPTCommunityTemplate) m_ptObject).GetFooterID();

				if ( CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nObjectID )
				{
					m_strFooterName = m_asOwner.GetString(2160, ResourceConstants.PORTALADMINMSGS);
					m_nFooterID		= nObjectID;
				}
				else
				{
					IPTQueryResult ptqrObjects = this.m_Session.GetGadgets()
						.QuerySingleObject(nObjectID);

					if (ptqrObjects.RowCount() == 1)
					{
						// DCA - delay htmlencoding til used in view
						//m_strFooterName				   = XPHttpUtility.HtmlEncode(ptqrObjects.ItemAsString(0,
						//		PT_PROPIDS.PT_PROPID_NAME));
						m_strFooterName				   = ptqrObjects.ItemAsString(0,
								PT_PROPIDS.PT_PROPID_NAME);
						m_nFooterID					   = nObjectID;

						int nWebServiceID			   = ptqrObjects.ItemAsInt(0,
								PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);
						m_bFooterHasCommunityPrefs     = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
								PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
								m_Session);
					}
					else
					{
						m_strFooterName				   = m_asOwner.GetString(213,
								ResourceConstants.PORTALADMINMSGS);
						m_bFooterHasCommunityPrefs     = false;
					}
				}
			}
			catch (Exception e)
			{
				
					log.Warn("Couldn't get the stored header ID: " + nObjectID +
						"  for CommunityTemplate ");
				
			}
		}
		else
		{
			m_nFooterID     = 0;
			m_nHeaderID     = 0;

			m_strFooterName     = m_asOwner.GetString(213,
					ResourceConstants.PORTALADMINMSGS);

			m_strHeaderName				   = m_asOwner.GetString(212,
					ResourceConstants.PORTALADMINMSGS);
			m_bFooterHasCommunityPrefs     = false;
			m_bHeaderHasCommunityPrefs     = false;
		}
	}

	/**
	 * Helper method to start the Communities List.
	 *
	 */
	private void StartCommunities()
	{
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			InheritListModel inheritModel = ((InheritListModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_COMMUNITIES));
	
			inheritModel.InitializeInheritList(
				m_asOwner.GetString(3044, ResourceConstants.PORTALADMINMSGS),
				PT_CLASSIDS.PT_COMMUNITY_ID, 67);
			
			inheritModel.SetEmptyListMessages(
				m_asOwner.GetString(3045, ResourceConstants.PORTALADMINMSGS),
				"");
	
			//     Use the method bellow to set the icon to display on each row.
			//     (By default there will be no icon.)
			inheritModel.SetDefaultRowIcon(PTImageType.ICON_COMMUNITY);
	
			// Add inherited communities.
			inheritModel.SetDefaultObjects(
				m_Session, 
				PT_CLASSIDS.PT_COMMUNITY_ID, 
				m_nObjectID,
				PT_PROPIDS.PT_PROPID_COMMUNITY_COMMUNITYTEMPLATEID,
				PT_PROPIDS.PT_PROPID_COMMUNITY_INHERITCOMMUNITYTEMPLATE);
		}
		else
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				CommunityTemplateCommunitiesDP.STR_MVC_CLASS_NAME);
		}
	}

	/**
	 * Takes a query result of page templates and sets up the member variables from
	 * it.
	 *
	 * @param IASQueryResult ptqrPortlets
	 * @return Object[][]
	 */
	private Object[][] SetupPageTemplates(IASQueryResult asqrPageTemplates, SelectPTObjectModel selectPTObject)
	{
		int nPageTemplateCount;

		if (null == asqrPageTemplates)
		{
			nPageTemplateCount = 0;
		}
		else
		{
			nPageTemplateCount = asqrPageTemplates.GetCount();
		}

		Object[][] arrReturn = new Object[nPageTemplateCount][SelectPTObjectModel.EXPLIST_COL_MAX];
		m_xpsdOldSelectedObjects = new XPSortedDictionary();

		for (int i = 0; i < nPageTemplateCount; i++)
		{
			arrReturn[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX]		= new Integer(selectPTObject.m_nNextIndex);
			selectPTObject.m_nNextIndex++;
			arrReturn[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]				   = new Integer(PT_CLASSIDS.PT_PAGETEMPLATE_ID);
			arrReturn[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]				   = asqrPageTemplates.GetFields(i,
					PT_PROPIDS.PT_PROPID_OBJECTID);
			arrReturn[i][SelectPTObjectModel.EXPLIST_COL_STRING]				   = (String) asqrPageTemplates.GetFields(i,
					PT_PROPIDS.PT_PROPID_NAME);

			// Setup Old Selected Portlets
			m_xpsdOldSelectedObjects.PutElement(arrReturn[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID],
				"");
		}

		return arrReturn;
	}

	// BEGIN ***************** save DP methods *****************
	// END ***************** save DP methods *****************
	//***** Private methods

	/**
	 * Helper method to start the Selected Page Template List.
	 *
	 */
	private void StartSelectPageTemplate()
	{
		SelectPTObjectModel selectPTObject = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityTemplateEditorAS.PLUGIN_SELECT_PAGE_TEMPLATE));

		/* Initialize the Select PTObject list.
		          _sSectionTitle: Main title.
		          _sSectionSubTitle: Sub title.
		          _imgAddIcon: Icon for the add action.
		          _sAddLabel: Text to display next to the add icon.
		          _arrObjectClassIDs Class ID of the Objects displayed on the list.
		          _nListKey: In case you have multiple Expandable Lists on
		                 the same DP, they should have a different key
		                 (otherwise, just set it to 1).
		   */
		selectPTObject.InitializeSelectPTObject(m_asOwner.GetString(199,
				ResourceConstants.PORTALADMINMSGS),
			m_asOwner.GetString(200, ResourceConstants.PORTALADMINMSGS),
			PTImageType.ICON_PAGE_TEMPLATE,
			m_asOwner.GetString(201, ResourceConstants.PORTALADMINMSGS),
			new int[] { PT_CLASSIDS.PT_PAGETEMPLATE_ID }, 1);

		selectPTObject.SetEnableMoveRowActions(true);

		selectPTObject.SetTreeTitle(m_asOwner.GetString(201,
				ResourceConstants.PORTALADMINMSGS));
		selectPTObject.SetTreeSubTitle(m_asOwner.GetString(1785, ResourceConstants.PORTALADMINMSGS));

		selectPTObject.SetEmptyListMessages(m_asOwner.GetString(208,
				ResourceConstants.PORTALADMINMSGS),
			m_asOwner.GetString(209, ResourceConstants.PORTALADMINMSGS));

		int[][] anObjectToHide = new int[1][SelectPTObjectModel.HIDE_COL_MAX];
		anObjectToHide[0][SelectPTObjectModel.HIDE_COL_CLASSID]		 = PT_CLASSIDS.PT_PAGETEMPLATE_ID;
		anObjectToHide[0][SelectPTObjectModel.HIDE_COL_OBJECTID]     = PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID;

		selectPTObject.SetHiddenObjects(anObjectToHide);

		//     Use the method bellow to set the icon to display on each row.
		//     (By default there will be no icon.)
		selectPTObject.SetDefaultRowIcon(PTImageType.ICON_PAGE_TEMPLATE);

		// Setup initial page templates
		IASQueryResult asqrPageTemplates = null;

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			ASQueryResultWrapper qrw = new ASQueryResultWrapper(((IPTCommunityTemplate) m_ptObject).QueryPageTemplates());
			asqrPageTemplates = qrw;
		}

		Object[][] arrDefaultPageTemplates = SetupPageTemplates(asqrPageTemplates, selectPTObject);

		// Add default rows.
		selectPTObject.SetDefaultObjects(arrDefaultPageTemplates);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndFooterModel#GetCommunityFolderID()
	 */
	public int GetCommunityFolderID()
	{
		return -1;
	}

}

