package com.plumtree.portalpages.admin.editors.condition;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 *
 */
public class RuleEditorMainDP extends EditorDP
{
	public static final String STR_MVC_CLASS_NAME = "RuleEditorMainDP";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetEditorTitle();
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());
		result.AddInnerHTMLElement(HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2966, "ptmsgs_portaladminmsgs"), m_asOwner));
		
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		
		// Do some formatting
		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myTable.SetBorder(CommonHTMLStrings.ZERO);
		myTable.SetAlign(CommonHTMLStrings.CENTER);
		myTable.SetCellPadding(CommonHTMLStrings.ZERO);
		myTable.SetCellSpacing("15");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.AddInnerHTMLElement(m_asOwner.GetView(ErrorView.STR_MVC_CLASS_NAME).Display());
				
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.AddInnerHTMLElement(m_asOwner.GetView(CreateRuleView.STR_MVC_CLASS_NAME).Display());

		// Display Condition Type Expandable Lists
		IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
		while (condTypes.MoveNext()) {
			AConditionType current = (AConditionType) condTypes.GetCurrent();
			IView condListView = m_asOwner.GetView(current.GetConditionTypeIdentifier());
			
			if (null != condListView) {
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.AddInnerHTMLElement(condListView.Display());
			}
		}
			 
		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(CreateRuleView.STR_MVC_CLASS_NAME).DisplayJavascript());
		
		// Display Condition Type Expandable Lists
		IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
		while (condTypes.MoveNext()) {
			AConditionType current = (AConditionType) condTypes.GetCurrent();
			IView condListView = m_asOwner.GetView(current.GetConditionTypeIdentifier());
		
			if (null != condListView) {
				myScripts.AddInnerHTMLElement(condListView.DisplayJavascript());
			}
		}
			 
		return myScripts;
	}
}

