package com.plumtree.portalpages.admin.editors.condition;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.condition.*;
import com.plumtree.portalpages.condition.conditiontypes.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 *
 *
 */
public class RuleEditorModel extends ObjEditorModel implements IRuleEditorModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.condition.RuleEditorModel");

	public static final String STR_MVC_CLASS_NAME = "RuleEditorModel";
	
	private int m_nSubportalActionID;
	private String m_sSubportalTreeSpaceID;
	private String m_strExpressionName;

	public RuleEditorModel()
	{
			super();
			m_bDisableSecurity = true;
	}
		
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RuleEditorModel();
	}

	/**
	 * Code executed after the object is stored.
	 *
	 */
	public void DoTaskAfterStore()
	{		
		// Save Condition Type Expandable Lists as Subexpressions
		IPTExpressionInfo ptInfo = null;
		IPTExpression ptExpression;
		XPArrayList xpArSubExpressions = new XPArrayList();
		IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
		while (condTypes.MoveNext()) {
			AConditionType current = (AConditionType) condTypes.GetCurrent();
			try {
			    ptInfo = GetSubExpressions(current);
			} catch (Exception e) {
			    IXPEnumerator arSubEnum = xpArSubExpressions.GetEnumerator();
			    while (arSubEnum.MoveNext()) {
			        ptInfo = (IPTExpressionInfo) arSubEnum.GetCurrent();
			        m_Session.GetExpressions().Delete(ptInfo.GetObjectID());
			    }
			    IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
				XPResourceManager xpRM     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
				
		        GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN), 
		                "GetConditionValue ", null, true, UIErrorLevel.SERIOUS, 
		                current.GetValidationFailedString(xpRM, m_asOwner.GetLanguage()));
			}
			if (null != ptInfo) {
				xpArSubExpressions.Add(ptInfo);
			}
		}
		if (xpArSubExpressions.IsEmpty()) {
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN), 
				"RuleEditorModel::DoTaskAfterStore ", null, true, UIErrorLevel.SERIOUS, m_asOwner.GetString(2859, "ptmsgs_portaladminmsgs"));

		}
		
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			if (((IPTExpression) m_ptObject).IsCondition()) {
				// we have a condition, delete old condition settings
				((IPTExpression) m_ptObject).SetConditionTypeID(-1);
				((IPTExpression) m_ptObject).SetConditionValue(ValueTypeEnum.INVALID, null);
			} else {
				int[] arSubExpressions = ((IPTExpression) m_ptObject).QuerySubExpressionIDs();
				// TODO code review - is this too inefficient? we're basically creating new expression objects on every edit
				// delete old sub expressions
				m_Session.GetExpressions().DeleteObjects(arSubExpressions);
				((IPTExpression) m_ptObject).SetOperatorID(OperatorEnum.INVALID);
			}	
		}
		
		if (1 == xpArSubExpressions.GetSize()) {
			// since there's only one sub expression, might as well combine w/ parent expression
			ptInfo = (IPTExpressionInfo) xpArSubExpressions.GetElement(0);
			if (ptInfo.IsCondition()) {
				// the sub expression was a condition, copy it's condition type and value
				((IPTExpression) m_ptObject).SetConditionTypeID(ptInfo.GetConditionTypeID());
				IValue objCondValue = ptInfo.GetConditionValue();
				((IPTExpression) m_ptObject).SetConditionValue(objCondValue.GetType(), objCondValue.GetValue());
			} else {
				// the sub expression was an expression, copy it's operator id and it's sub expressions
				((IPTExpression) m_ptObject).SetOperatorID(ptInfo.GetOperatorID());
				((IPTExpression) m_ptObject).AddSubExpressions(ptInfo.QuerySubExpressionIDs());
				// remove subexpressions so that they don't get deleted because they are now the parent expression's sub expressions
				ptExpression = (IPTExpression) m_Session.GetExpressions().Open(ptInfo.GetObjectID(), false);
				ptExpression.RemoveSubExpressions(ptInfo.QuerySubExpressionIDs());
			}
			// delete this expression since it's info has been copied to the parent expressions
			m_Session.GetExpressions().Delete(ptInfo.GetObjectID());
		} else {
			// there is more than one sub expressions, they need to be OR'ed
			int[] arSubExpressions = new int[xpArSubExpressions.GetSize()];
			for (int i=0; i<xpArSubExpressions.GetSize(); i++) {
				ptInfo = (IPTExpressionInfo) xpArSubExpressions.GetElement(i);
				arSubExpressions[i] = ptInfo.GetObjectID();
			}
			((IPTExpression) m_ptObject).SetOperatorID(OperatorEnum.AND);
			 // add sub expressions to parent expression
			((IPTExpression) m_ptObject).AddSubExpressions(arSubExpressions);
		}
		
		ptExpression = (IPTExpression) m_ptObject;
		try {
			// set description
		    String strDescription = GetDescription(ptExpression.GetConditionTypeID(), ptExpression.GetConditionValue(),
					ptExpression.GetOperatorID(), ptExpression.QuerySubExpressionIDs());
		    strDescription = GeneralHelpers.TruncateLongString(strDescription, 250, false);
			ptExpression.SetDescription(strDescription);
		} catch (Exception e) {
		    log.Error("RuleEditorModel::DoTaskAfterStore Unable to set the Description. The following exception occured: " + e);
		}
				 
		// store object again
		ptExpression.LockObject();
		try {
		    ptExpression.Store();
		} catch (Exception e) {
		    log.Error("RuleEditorModel::DoTaskAfterStore Unable to store the object. The following exception occured: " + e);
		} finally {
		    ptExpression.UnlockObject();
		}
	}

	/**
	 * 
	 * @param ptExpression
	 * @return
	 */
	private String GetDescription(int nConditionTypeID, IValue objCondtionValue, int nOperatorID, int[] arSubExpressionIDs) {
		if (-1 != nConditionTypeID && nOperatorID == -1) {
			AConditionType condType = (AConditionType) ConditionTypeManager.GetInstance().GetHashedConditionTypes().
				GetElement(new Integer(nConditionTypeID));
			return condType.GetDescriptionString(objCondtionValue, (IPTSession) m_asOwner.GetUserSession());
		} else {
			String strOpName = null;
			switch(nOperatorID) {
				case OperatorEnum.AND:
					strOpName = " AND ";
					break;
				case OperatorEnum.OR:
					strOpName = " OR ";
					break;
			}
			XPStringBuilder sbDescription = new XPStringBuilder();
			IPTExpressionManager ptExpressionManager = (IPTExpressionManager) m_Session.GetExpressions();
			IPTExpressionInfo ptExpressionInfo;
			sbDescription.Append("(");
			for (int i=0; i<arSubExpressionIDs.length; i++) {
				ptExpressionInfo = ptExpressionManager.CachedOpenExpressionInfo(arSubExpressionIDs[i]);
				if (OperatorEnum.NOT == nOperatorID) {
					sbDescription.Append("NOT ").Append(GetDescription(ptExpressionInfo.GetConditionTypeID(), ptExpressionInfo.GetConditionValue(),
						ptExpressionInfo.GetOperatorID(), ptExpressionInfo.QuerySubExpressionIDs()));
				} else {
					sbDescription.Append(GetDescription(ptExpressionInfo.GetConditionTypeID(), ptExpressionInfo.GetConditionValue(),
						ptExpressionInfo.GetOperatorID(), ptExpressionInfo.QuerySubExpressionIDs()));
					if (arSubExpressionIDs.length-1 != i) {
						sbDescription.Append(strOpName);
					}
				}
			}
			sbDescription.Append(")");
			return sbDescription.ToString();
		}
		
	}

	/**
	 * Code executed before the object is stored.
	 *
	 */
	public void DoTaskBeforeStore()
	{
		try
		{
			((IPTExpression) m_ptObject).SetName(m_strExpressionName);
		}
		catch (Exception e)
		{
			log.Error("RuleEditorModel::DoTaskBeforeStore Unable to set the Name: " + m_strExpressionName +
					". The following exception occured: " + e);
			throw new XPException(m_asOwner.GetString(2860, "ptmsgs_portaladminmsgs"), e);
		}
				
		try
		{
			((IPTExpression) m_ptObject).SetActionType(ActionTypeEnum.SUBPORTAL);
			((IPTExpression) m_ptObject).SetActionValue(m_nSubportalActionID);
		}
		catch (Exception e)
		{
			log.Error("RuleEditorModel::DoTaskBeforeStore Unable to set the Subportal Action: " + m_nSubportalActionID +
					". The following exception occured: " + e);
			throw new XPException(m_asOwner.GetString(2861, "ptmsgs_portaladminmsgs"), e);
		}
		
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			try
			{
				RulesListModel listModel = (RulesListModel) m_asOwner.GetParentSpace().GetModel(SubportalRulesManagerAS.SUBPORTAL_RULES_LIST);
				((IPTExpression) m_ptObject).SetTopicPos(listModel.m_nNextIndex + 1);
			}
			catch (Exception e)
			{
				log.Error("RuleEditorModel::DoTaskBeforeStore Unable to set the Rank. The following exception occured: " + e);
				throw new XPException(m_asOwner.GetString(2862, "ptmsgs_portaladminmsgs"), e);
			}
		}

	}

	/**
	 * Code executed when the Editor is starting.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		// Initialize Condition Type Expandable Lists
		IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
		while (condTypes.MoveNext()) {
			AConditionType current = (AConditionType) condTypes.GetCurrent();
			ExpListModel conditionsList = (ExpListModel) m_asOwner.GetModel(current.GetConditionTypeIdentifier());
			current.InitializeMyConditionsList(conditionsList, m_asOwner.GetLanguage());
		}
			 
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			m_strExpressionName = m_asOwner.GetString(3144, "ptmsgs_portaladminmsgs");
			m_nSubportalActionID = -1;
		}

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			try
			{
				m_strExpressionName = ((IPTExpression) m_ptObject).GetLocalizedName();
			}
			catch (Exception e)
			{
				log.Error("RuleEditorModel::DoTaskOnStartEditor Unable to get the Rule's Name. The following exception occured: " +
					e);
				m_strExpressionName = m_asOwner.GetString(3144, "ptmsgs_portaladminmsgs");
			}
			
			try
			{
				m_nSubportalActionID = ((IPTExpression) m_ptObject).GetActionValue();
			}
			catch (Exception e)
			{
				log.Error("RuleEditorModel::DoTaskOnStartEditor Unable to get the Rule's Subportal Action. The following exception occured: " +
					e);
				m_nSubportalActionID = -1;
			}
			
			// Reload sub expression into their list
			try 
			{
				if (((IPTExpression) m_ptObject).IsCondition()) {
					IPTExpressionManager ptExpressionManager = (IPTExpressionManager) m_Session.GetExpressions();
					AddSubExpressionToList(ptExpressionManager.CachedOpenExpressionInfo(m_nObjectID));
				} else {
					int[] nSubExpressionIDs = ((IPTExpression) m_ptObject).QuerySubExpressionIDs();
					AddMultipleSubExpressionsToList(nSubExpressionIDs);
				}
			}
			catch (Exception e)
			{

			}
		}
	
	}
	
	/**
	 * Implement some code to execute when the user clicks on "Cancel".
	 *
	 */
	public void Cancel()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			try
			{
			    if (m_ptObject.GetLockState() != PT_LOCKSTATES.PT_NEWLYCREATED) {
					// delete expression on cancel
					m_Session.GetExpressions().Delete(GetObjectID());
			    }
			}
			catch (Exception e)
			{
				log.Error("RuleEditorModel::Cancel Unable to delete Expression with ID: " +  GetObjectID()
					+ ". The following exception occured: " + e);
			}
		}
	}

	/**
	 * Returns the User TreeSpace ID.
	 *
	 * @return String
	 */
	public String GetAccessEdit()
	{
		return XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);
		
		if (_htFormData.ContainsKey(CreateRuleView.HTMLTEXT_RULE_NAME))
		{
			String[] aDataValue = (String[]) _htFormData.GetElement(CreateRuleView.HTMLTEXT_RULE_NAME);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				m_strExpressionName = aDataValue[0];
			}
		}
		
		if (_sPageName.equals(RuleEditorMainDP.STR_MVC_CLASS_NAME))
		{
			// Initialize Condition Type Expandable Lists
			IXPEnumerator condTypes = ConditionTypeManager.GetInstance().GetArrayConditionTypes().GetEnumerator();
			while (condTypes.MoveNext()) {
				AConditionType current = (AConditionType) condTypes.GetCurrent();
				ExpListModel condListModel = (ExpListModel) m_asOwner.GetModel(current.GetConditionTypeIdentifier());
				nPageStatus = condListModel.SaveSection(_htFormData);
			}
		}

		return nPageStatus;
	}

	/**
	 * Sets the new Subportal ID in a member variable.
	 */
	public void SetSubportalActionOnRepost()
	{
		TreeAS asSubportalTree = (TreeAS) m_asOwner.GetSubSpace("SubportalTree");

		if (asSubportalTree != null)
		{
			ITreeModelRO myTree    = (ITreeModelRO) asSubportalTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected = myTree.GetSelectedItems();

			for (int i = 0; i < mySelected.GetSize(); i++)
			{
				m_nSubportalActionID = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;

				log.Debug("RuleEditorModel::SetSubportalActionOnRepost New Subportal ID: " +
					m_nSubportalActionID);
			}
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.condition.IRuleEditorModelRO#GetSubportalActionName()
	 */
	public String GetSubportalActionName()
	{
		String subportalName = null;
	
		try
		{
			if (-1 != m_nSubportalActionID) {
				IPTSubPortal objSubPortal = (IPTSubPortal) m_Session.GetSubPortals().Open(m_nSubportalActionID, false);
				subportalName = objSubPortal.GetLocalizedName();
			}
		}
		catch (Exception e)
		{
			
		 	log.Error("RuleEditorModel::GetSubportalActionName Unable to get the Subportal Name. The following exception occured: " +
				e);
			return null;
		}
	
		return subportalName;
	}

	/**
	 * Sets the new Subportal TreeSpace ID in a member variable.
	 *
	 * @param _sSubportalTreeSpaceID
	 */
	public void SetSubportalTreeSpaceID(String _sSubportalTreeSpaceID)
	{
		m_sSubportalTreeSpaceID = _sSubportalTreeSpaceID;

		log.Debug("InvitationModel::SetSubportalTreeSpaceID New User TreeSpace ID: " +
			_sSubportalTreeSpaceID);
	}
		
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.condition.IRuleEditorModelRO#GetSubportalTreeSpaceID()
	 */
	public String GetSubportalTreeSpaceID() {
		return m_sSubportalTreeSpaceID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.condition.IRuleEditorModelRO#GetExpressionName()
	 */
	public String GetExpressionName() {
		return m_strExpressionName;
	}
	
	private IPTExpressionInfo GetSubExpressions(AConditionType objCondType) {
		
		ExpListModel condListModel = (ExpListModel) m_asOwner.GetModel(objCondType.GetConditionTypeIdentifier());
		int nCount = condListModel.GetNumObjects();
		
		if (0 == nCount) {
			return null;
		} else {
			int[] expressions = new int[nCount];
			IPTExpressionManager ptExpressionManager = (IPTExpressionManager) m_Session.GetExpressions();
			IPTExpression ptExpression = null;
			
			for(int i=0; i<nCount; i++) {
			    Object objCondValue = null;
			    try { 
			        objCondValue = objCondType.GetConditionValue(i, condListModel.GetItems());
			    } catch (ValidationFailedException vfe) {
			        // delete invalid subexpressions
			        for (int j=0; j<nCount; j++) {
			            if (expressions[j] > 0) {
			                ptExpressionManager.Delete(expressions[j]);
			            }
			        }
			        throw vfe;
			    }
			    
				ptExpression = (IPTExpression) ptExpressionManager.Create(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
				ptExpression.SetName(m_strExpressionName + "-" + objCondType.GetConditionTypeIdentifier());
				ptExpression.SetConditionTypeID(objCondType.GetTypeID());
				ptExpression.SetConditionValue(objCondType.GetConditionValueType(), objCondValue);
				ptExpression.Store();
				ptExpression.UnlockObject();
				expressions[i] = ptExpression.GetObjectID();
			}
			
			if (1 == nCount) {
				return ptExpressionManager.CachedOpenExpressionInfo(expressions[0]);
			} else {
				ptExpression = (IPTExpression) ptExpressionManager.Create(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
				ptExpression.SetName(m_strExpressionName + "-" + objCondType.GetConditionTypeIdentifier());
				ptExpression.SetOperatorID(OperatorEnum.OR);
				ptExpression.Store();
				ptExpression.UnlockObject();
				ptExpression.AddSubExpressions(expressions);
				return ptExpressionManager.CachedOpenExpressionInfo(ptExpression.GetObjectID());
			}
		}
	}
	
	/**
	 * @param nSubExpressionIDs
	 */
	private void AddMultipleSubExpressionsToList(int[] nSubExpressionIDs) {
		
		IPTExpressionManager ptExpressionManager = (IPTExpressionManager) m_Session.GetExpressions();
		IPTExpressionInfo ptInfo;
		for (int i=0; i<nSubExpressionIDs.length; i++) {
			ptInfo = ptExpressionManager.CachedOpenExpressionInfo(nSubExpressionIDs[i]);
			if (ptInfo.IsCondition()) {
				AddSubExpressionToList(ptInfo);
			} else {
				AddMultipleSubExpressionsToList(ptInfo.QuerySubExpressionIDs());
			}
		}
	}
	
	/**
	 * @param info
	 */
	private void AddSubExpressionToList(IPTExpressionInfo ptInfo) {
		
		AConditionType objCondType = (AConditionType) ConditionTypeManager.GetInstance().GetHashedConditionTypes().
			GetElement(new Integer(ptInfo.GetConditionTypeID()));
		if (ptInfo.GetConditionValue().GetType() == objCondType.GetConditionValueType()) {
			ExpListModel conditionsList = (ExpListModel) m_asOwner.GetModel(objCondType.GetConditionTypeIdentifier());
			IPTSession ptUserSession = (IPTSession) m_asOwner.GetUserSession();
			objCondType.AddItemToMyConditionsList(ptInfo.GetConditionValue().GetValue(), conditionsList, ptUserSession);
		} else {
			log.Error("RuleEditorModel::AddSubExpressionToList Unable to add a condition value to the list. The value type of the condition is wrong.");
		}
	}
}

