package com.plumtree.portalpages.admin.editors.crawler;


// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This DP displays the Views for the main page.
 *
 * @author Julie Fournier
 */
public abstract class AMainDP extends EditorDP
{
	/**
	 * Returns HTML for common Crawler Views.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement GetHTMLForCommonView()
	{
		HTMLElementCollection views = new HTMLElementCollection();
		
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).Display());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				DestFolderSettingsView.STR_MVC_CLASS_NAME)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY)).Display());

		return views;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(216, "ptmsgs_portaladminmsgs"));
	}
	
	/**
	 * Returns the page title. By default it is the same as the left navigation string.
	 *
	 * @return String
	 */
	public String GetPageTitle()
	{
		String sDSName = ((CrawlerModel) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetDataSourceName();
		
		return GetLeftNavString() + " - " 
			+ XPResourceManager.FormatMessage(m_asOwner.GetString(2141, "ptmsgs_portaladminmsgs"),  XPHttpUtility.HtmlEncode(sDSName));
	}


	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)
			.DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY)
			.DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				DestFolderSettingsView.STR_MVC_CLASS_NAME)
			.DisplayJavascript());

		return myScripts;
	}
}

