package com.plumtree.portalpages.admin.editors.crawler;

import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This DP displays the Views for the advanced settings page.
 *
 * @author Julie Fournier
 */
public class AdvSettingsDP extends EditorDP
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "CrAdvSettings";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(215, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
   /**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() 
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(2469, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
		throws HTMLException
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement((m_asOwner.GetView(
				CrawlerEditorAS.STR_MVC_STORAGE_NAME_LANGUAGE)).Display());

		/* JQ: Combined the DefaultConfView with the RejectedDocsView since
		 * they both dealt with rejection and rejected docs
		 */
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				RejectedDocsView.STR_MVC_CLASS_NAME)).Display());

		// JF- The following View is in Edit mode only
		CrawlerModel myModel = (CrawlerModel) m_asOwner.GetModel(m_asOwner.m_strModelName);
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == myModel.GetEditorType())
		{
			/* Importing docs view */
			views.AddInnerHTMLElement(EditorView.GetSpacerTable());
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
					ImportingDocsView.STR_MVC_CLASS_NAME)).Display());
		}
		
		// olegs - added
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				CrawlerTagView.STR_MVC_CLASS_NAME)).Display());				
		// end
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
		        CrawlerThreadConfigView.STR_MVC_CLASS_NAME)).Display());				

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}
	
	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				ImportingDocsView.STR_MVC_CLASS_NAME)
			.DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				RejectedDocsView.STR_MVC_CLASS_NAME)
			.DisplayJavascript());

		return myScripts;
	}
}

