package com.plumtree.portalpages.admin.editors.crawler;


// Framework imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author Julie Fournier
 */
public class CrawlerDependenciesView extends ObjDependenciesView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.crawler.CrawlerDependenciesView");

	/** Member variables */
	private CreatedHelper m_chHelper	  = null;

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "CrawlerDependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CrawlerDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (CrawlerModel) model);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Adds javascript for creating or adding to jobs
	 *
	 * @return
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		try
		{
			m_chHelper.addJobJavascript(myScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "CrawlerDependenciesView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		//Display the standard success message
		m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(1399, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());

		//Text: This job will display the following operations:
		m_chHelper.displayTextRow(result, m_asOwner.GetString(2388, "ptmsgs_portaladminmsgs"), null);
		
		//Start a list
		m_chHelper.beginList(result);

		int nFolderID = ((ObjEditorModel) m_model).GetFolderID();

		m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
				PT_CLASSIDS.PT_SAVEDSEARCH_ID, null,
				nFolderID, m_asOwner.GetString(2389, "ptmsgs_portaladminmsgs"), m_asOwner, null, true));

		//Display the jobs
		m_chHelper.displayJobRows(result, m_asOwner.GetString(2201, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2202, "ptmsgs_portaladminmsgs"));

		m_chHelper.displayEmptyRow(result);

		//Display the standard warning if everyone has access to this object
		m_chHelper.displayEveryoneWarning(result, (CrawlerModel) m_model, m_asOwner.GetString(2298, "ptmsgs_portaladminmsgs"));

		return result;
	}
}

