package com.plumtree.portalpages.admin.editors.crawler;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.common.setjob.*;
import com.plumtree.portalpages.admin.editors.doctypemap.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.linksettings.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the AS class for the Crawler Editor.
 *
 * @author Julie Fournier
 */
public abstract class CrawlerEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.crawler.CrawlerEditorAS");

	/**
	 * Select Jobs storage name*/
	public static final String STR_MVC_STORAGE_NAME_SELECT_FOLDER = "SelectFolderCrawlerEditor";

	/**
	 * Link Settings storage name*/
	public static final String STR_MVC_STORAGE_NAME_LINK_SETTINGS = "LinkSettingsCrawlerEditor";

	/**
	 * Content Language storage name*/
	public static final String STR_MVC_STORAGE_NAME_LANGUAGE = "ContentLanguageCrawlerEditor";

	/**
	 * Card Security storage name*/
	public static final String STR_MVC_STORAGE_NAME_CARD_SECURITY = "CardSecurityCrawlerEditor";

	/**
	 * Doc Type Map storage name*/
	public static final String STR_MVC_STORAGE_NAME_TYPE_MAP = "TypeMapCrawlerEditor";

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (CrawlerDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Init method for the Crawler Editor.
	 */
	public void Init()
	{
		super.Init();

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				int iTitleId = 18;
				int iTipId = 19;
				int iSecondaryTipId = 20;
								
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}
											
			
			
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	 * Helper method to register classes for the Document Type Map page.
	 * We are creating the Views and the Models dynamically depending on
	 * the number of sections that we get from the crawler document type object.
	 * Warning: This method has to be called after the editor has been initialized.
	 *
	 * @param _ptCrawler
	 */
	public void RegisterClassesForDocumentType(int _nDocMapSectionCount)
	{
		for (int i = 0; i < _nDocMapSectionCount; i++)
		{
			RegisterModel(GbDocTypeListModel.STR_MVC_CLASS_NAME,
				STR_MVC_STORAGE_NAME_TYPE_MAP + i);

			// Get back the Model we just registered because we need it to register the Section and the Control
			IModel myGbDocTypeListModel = GetModel(STR_MVC_STORAGE_NAME_TYPE_MAP +
					i);
			((GbDocTypeListModel) myGbDocTypeListModel).SetModelID(i);
			RegisterView(GbDocTypeListView.STR_MVC_CLASS_NAME,
				STR_MVC_STORAGE_NAME_TYPE_MAP + i, myGbDocTypeListModel);
			RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
				STR_MVC_STORAGE_NAME_TYPE_MAP + i, myGbDocTypeListModel);
		}
	}

	/**
	 * Helper method to be called by classes that extends this one.
	 *
	 * @param _myModel
	 */
	public void RegisterCommonCrawlerClasses(IModel _myModel)
	{
		// Register Common DisplayPages
		RegisterPage(new LinkSettingsDP());
		RegisterPage(new DocTypeDP());
		RegisterPage(new SetJobDP());
		RegisterPage(new AdvSettingsDP());

		// Register Common Views
		RegisterView(DestFolderSettingsView.STR_MVC_CLASS_NAME, _myModel);
		RegisterView(ImportingDocsView.STR_MVC_CLASS_NAME, _myModel);
		RegisterView(RejectedDocsView.STR_MVC_CLASS_NAME, _myModel);
		RegisterView(CrawlerDependenciesView.STR_MVC_CLASS_NAME, _myModel);
		RegisterView(CrawlerTagView.STR_MVC_CLASS_NAME, _myModel);
		RegisterView(ExistingCardsView.STR_MVC_CLASS_NAME, _myModel);
		RegisterView(CrawlerThreadConfigView.STR_MVC_CLASS_NAME, _myModel);

		// Register classes for select Folder
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_SELECT_FOLDER);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_SELECT_FOLDER,
			GetModel(STR_MVC_STORAGE_NAME_SELECT_FOLDER));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_SELECT_FOLDER,
			GetModel(STR_MVC_STORAGE_NAME_SELECT_FOLDER));

		// Register classes for the set job and for the object owner
		RegisterModel(SetJobModel.STR_MVC_CLASS_NAME);
		RegisterControl(SetJobRepostControl.STR_MVC_CLASS_NAME,
			GetModel(SetJobModel.STR_MVC_CLASS_NAME));
		RegisterView(ObjectOwnerView.STR_MVC_CLASS_NAME,
			GetModel(SetJobModel.STR_MVC_CLASS_NAME));

		// Register classes for Job selector
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
			GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
			GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));

		// Register classes for Link Settings Page
		RegisterModel(LinkSettingsPlugInModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_LINK_SETTINGS);
		RegisterView(LinkSettingsPlugInView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_LINK_SETTINGS,
			GetModel(STR_MVC_STORAGE_NAME_LINK_SETTINGS));

		// Register classes Card Language
		RegisterModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_LANGUAGE);
		RegisterView(CardLanguagePlugInView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_LANGUAGE,
			GetModel(STR_MVC_STORAGE_NAME_LANGUAGE));
		RegisterControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_LANGUAGE,
			GetModel(STR_MVC_STORAGE_NAME_LANGUAGE));

		// JF- Register classes for card security page
		RegisterModel(ObjectSecurityModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_CARD_SECURITY);

		ObjectSecurityModel myModel = (ObjectSecurityModel) GetModel(STR_MVC_STORAGE_NAME_CARD_SECURITY);
		myModel.SetCardACL(true);

		RegisterView(ObjectSecurityView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_CARD_SECURITY, myModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_CARD_SECURITY, myModel);
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (LinkSettingsDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Crawler_DocumentSettings");
		}
		else if (DocTypeDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Crawler_DocumentType");
		}
		else if (AdvSettingsDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Crawler_AdvancedSettings");
		}
		else if (SetJobDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_SetJob");
		}
	}
}

