package com.plumtree.portalpages.admin.editors.crawler;


// Framework Imports
import com.plumtree.portalpages.admin.editors.common.setjob.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * This is the main repost control for the Crawler Editor.
 *
 * @author Julie Fournier
 */
public abstract class CrawlerRepostControl extends ObjEditorRepostControl
{
	/** Repost action: Clear deletion history */
	public final static int POSTTOSELF_ACTION_CLEAR_DELETION_HISTORY = 10;

	/** Repost action: Clear rejection history */
	public final static int POSTTOSELF_ACTION_CLEAR_REJECTION_HISTORY = 11;
	
	/** Repost action: change mirroring status */
	public final static int POSTTOSELF_ACTION_CHANGE_MIRRORING_STATUS = 12;
	

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		((ExpListControl) m_asOwner.GetControl(CrawlerEditorAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).PerformRepostAction(_nAction,
			m_htFormData);

		((SetJobRepostControl) m_asOwner.GetControl(SetJobRepostControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
			m_htFormData);

		((CardLanguagePlugInRepostControl) m_asOwner.GetControl(CrawlerEditorAS.STR_MVC_STORAGE_NAME_LANGUAGE)).PerformRepostAction(_nAction,
			m_htFormData);

		((ExpListControl) m_asOwner.GetControl(CrawlerEditorAS.STR_MVC_STORAGE_NAME_CARD_SECURITY)).PerformRepostAction(_nAction,
			m_htFormData);

		int nDocTypeSectionCount = ((CrawlerModel) m_model).GetDocMapSectionCount();

		for (int i = 0; i < nDocTypeSectionCount; i++)
		{
			((ExpListControl) m_asOwner.GetControl(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP +
				i)).PerformRepostAction(_nAction, m_htFormData);
		}

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_CLEAR_DELETION_HISTORY:
			((CrawlerModel) m_model).ClearDeletionHistory();

			break;

		case POSTTOSELF_ACTION_CLEAR_REJECTION_HISTORY:
			((CrawlerModel) m_model).ClearRejectionHistory();

			break;
			
		case POSTTOSELF_ACTION_CHANGE_MIRRORING_STATUS:
			((CrawlerModel) m_model).ChangeMirroringStatus();

			break;
		}
	}
}

