package com.plumtree.portalpages.admin.editors.crawler;

// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.IPTCrawler;
import com.plumtree.server.PT_CRAWL_INFO;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
/**
 * 
 * @author Oleg Sinitsin
 */
public class CrawlerThreadConfigView extends EditorView {
    private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
            CrawlerThreadConfigView.class);
    /**
     * Class name for the activity space
     */
    public static final String STR_MVC_CLASS_NAME = "CrCrawlerThreadConfig";
    public static final String HTMLTEXT_NUM_PULL_THREADS = "in_tx_PullingThreads";
    public static final String HTMLTEXT_NUM_PROCESS_THREADS = "in_tx_ProcessingThreads";

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create() {
        return new CrawlerThreadConfigView();
    }

    /**
     * 
     * @return
     */
    public HTMLElement Display() {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLTableCell myCell;
        HTMLTableRow myRow;
        HTMLInput myInput;
        HTMLSpan mySpan;
        IXPPropertyBag crawlerRuntimeConfig = ((ICrawlerModelRO) m_model).GetRuntimeConfiguration();
        String pullingTreads = crawlerRuntimeConfig.ReadAsString(PT_CRAWL_INFO.MAX_NUMBER_PULLING_THREADS);
        String processingTreads = crawlerRuntimeConfig.ReadAsString(PT_CRAWL_INFO.MAX_NUMBER_PROCESSING_THREADS);
        try {
            result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(2913, "ptmsgs_portaladminmsgs")));
            HTMLTable myTable = new HTMLTable();
            result.AddInnerHTMLElement(myTable);
            myTable.SetWidth("100%");
            myTable.SetBorder("0");
            myTable.SetCellPadding("5");
            myTable.SetCellSpacing("0");
            /* add the pulling threads config number */
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetWidth("150");
            myCell.SetVAlign("top");
            myCell.SetNoWrap(true);
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            mySpan = new HTMLSpan();
            myCell.AddInnerHTMLElement(mySpan);
            mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
            mySpan.AddInnerHTMLString(m_asOwner.GetString(2914, "ptmsgs_portaladminmsgs"));
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetWidth("100%");
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLTEXT_NUM_PULL_THREADS, "");
            myCell.AddInnerHTMLElement(myInput);
            myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
            myInput.SetSize(2);
            myInput.SetMaxLength(2);
            myInput.SetValue(pullingTreads);
            /* add processing threads number */
            myRow = new HTMLTableRow();
            myTable.AddInnerHTMLElement(myRow);
            myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetWidth("150");
            myCell.SetVAlign("top");
            myCell.SetNoWrap(true);
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            mySpan = new HTMLSpan();
            myCell.AddInnerHTMLElement(mySpan);
            mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
            mySpan.AddInnerHTMLString(m_asOwner.GetString(2915, "ptmsgs_portaladminmsgs"));
            myCell = new HTMLTableCell();
            myRow.AddInnerHTMLElement(myCell);
            myCell.SetWidth("100%");
            myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
            myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLTEXT_NUM_PROCESS_THREADS, "");
            myCell.AddInnerHTMLElement(myInput);
            myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
            myInput.SetSize(2);
            myInput.SetMaxLength(2);
            myInput.SetValue(processingTreads);
            
        } catch (Exception e) {
            log.Error(e, "Display() : The following error occured when trying to display the HTML: " + e.getMessage());
            throw new XPException(m_asOwner.GetString(1796, "ptmsgs_portaladminmsgs"), e);
        }
        return result;
    }

    /**
     * Returns the Class name.
     * 
     * @return String
     */
    public String GetName() {
        return STR_MVC_CLASS_NAME;
    }
}