package com.plumtree.portalpages.admin.editors.crawler;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View class for the Destination Folders.
 *
 * @author Julie Fournier
 */
public class DestFolderSettingsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.crawler.DestFolderSettingsView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "DestFolderSettings";

	/**
	 * HTML Object name: Mirror checkbox */
	public static final String HTMLCHECKBOX_MIRROR = "in_cb_Mirror";

	/**
	 * HTML Object name: Apply Filters checkbox */
	public static final String HTMLCHECKBOX_APPLY_FILTERS = "in_cb_ApplyFilters";

	/**
	 * HTML Object name: Approve Documents checkbox */
	public static final String HTMLCHECKBOX_APPROVE_DOCS = "in_cb_ApproveDocs";

	/**
	 * HTML Object name: Import Security checkbox */
	public static final String HTMLCHECKBOX_IMPORT_SECURITY = "in_cb_ImportSecurity";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DestFolderSettingsView();
	}

	/**
	 * Returns the HTML for this View.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLInput myInput;
		HTMLSpan mySpan;

		boolean bSupportMirroring = ((ICrawlerModelRO) m_model).GetSupportMirroring();

		int nTaxSettings     = ((ICrawlerModelRO) m_model).GetTaxSettings();
		int nCrawlerSettings = ((ICrawlerModelRO) m_model).GetCrawlerSettings();

		try
		{
			result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());

			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetVAlign("top");
			myCell.SetNoWrap(true);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(240,
					"ptmsgs_portaladminmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetWidth("100%");

			if (bSupportMirroring)
			{
				if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((ICrawlerModelRO) m_model).GetEditorType())
				{
					myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLCHECKBOX_MIRROR, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
					myInput.SetValue("1");

					myInput.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						CrawlerRepostControl.POSTTOSELF_ACTION_CHANGE_MIRRORING_STATUS +
					");");

					if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR &
							nCrawlerSettings))
					{
						myInput.SetChecked(true);
					}

					myCell.AddInnerHTMLString(m_asOwner.GetString(241,
							"ptmsgs_portaladminmsgs"));
				}
				else
				{
					if (0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR &
							nCrawlerSettings))
					{
						myCell.AddInnerHTMLString(m_asOwner.GetString(243,
								"ptmsgs_portaladminmsgs"));
					}
					else
					{
						myCell.AddInnerHTMLString(m_asOwner.GetString(242,
								"ptmsgs_portaladminmsgs"));
					}
				}

				myCell.AddInnerHTMLElement(new HTMLBr());
			}

			if ((!bSupportMirroring) ||
					(0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR &
					nCrawlerSettings)))
			{
				myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
						HTMLCHECKBOX_APPLY_FILTERS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
				myInput.SetValue("1");

				if (0 == (PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_ONLY_APPLY_SUBFOLDER_FILTERS &
						nTaxSettings))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(m_asOwner.GetString(245,
						"ptmsgs_portaladminmsgs"));
				myCell.AddInnerHTMLElement(new HTMLBr());
			}

			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_APPROVE_DOCS, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myInput.SetValue("1");

			if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ALL_CARDS_AS_APPROVED &
					nCrawlerSettings))
			{
				myInput.SetChecked(true);
			}

			myCell.AddInnerHTMLString(m_asOwner.GetString(246,
					"ptmsgs_portaladminmsgs"));


			if (((ICrawlerModelRO) m_model).GetSupportsACLImport())
			{
				myCell.AddInnerHTMLElement(new HTMLBr());
				myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
						HTMLCHECKBOX_IMPORT_SECURITY, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
				myInput.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
					RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");");
				myInput.SetValue("1");

				if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_ACL_IMPORT &
						nCrawlerSettings))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(m_asOwner.GetString(1799, "ptmsgs_portaladminmsgs"));

				IPTServerContext ptscCrawler = (IPTServerContext) ((ICrawlerModelRO) m_model).GetObject().GetInterfaces("IPTServerContext");

				if ((0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_ACL_IMPORT & nCrawlerSettings))
					&& (ptscCrawler.GetLockState() !=  PT_LOCKSTATES.PT_NEWLYCREATED))
				{
					IPTQueryResult ptqrUnmappedExternalDomains = ((ICrawlerModelRO) m_model).GetUnmappedExternalDomains();

					if (null != ptqrUnmappedExternalDomains)
					{
						myCell.AddInnerHTMLElement(new HTMLBr());

						if (ptqrUnmappedExternalDomains.RowCount() <= 0)
	        			{
							myCell.AddInnerHTMLString(m_asOwner.GetString(1800, "ptmsgs_portaladminmsgs"));
	        			}
	        			else
	        			{
	        				myCell.AddInnerHTMLString(m_asOwner.GetString(1801, "ptmsgs_portaladminmsgs"));

	        				for (int i = 0; i < ptqrUnmappedExternalDomains.RowCount(); i ++)
	        				{
	        					myCell.AddInnerHTMLElement(new HTMLBr());
	        					myCell.AddInnerHTMLString("- " + ptqrUnmappedExternalDomains.ItemAsString(i, PT_PROPIDS.PT_PROPID_ACLSYNCUNMAPPED_EXTERNALDOMAIN));
	        				}

	        				myCell.AddInnerHTMLElement(new HTMLBr());
	        				myCell.AddInnerHTMLString(m_asOwner.GetString(1802, "ptmsgs_portaladminmsgs"));
	        			}
					}
				}
			}

		}
		catch (Exception e)
		{
			
				log.Error(e, "DestFolderSettingsView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(238,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns Java Script for that Section.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript;

		try
		{
			XPStringBuilder sb = new XPStringBuilder(200);

			if (((CrawlerModel) m_model).m_bDisplayMirroringAlert)
			{
				sb.Append("alert(\"" +
					m_asOwner.GetString(244, "ptmsgs_portaladminmsgs") + "\")\n");

				// JF- We display this only once when we page is reloaded.
				((CrawlerModel) m_model).m_bDisplayMirroringAlert = false;
			}

			myScript = new HTMLScript("text/javaScript");
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			
				log.Error(e, "DestFolderSettingsView::DisplayJavascript The following error occured when trying to display" +
					"the JavaScript: " + e.getMessage());
			

			throw new XPException(m_asOwner.GetString(239,
					"ptmsgs_portaladminmsgs"), e);
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

