package com.plumtree.portalpages.admin.editors.crawler;


// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This DP displays the Views for the document type page.
 *
 * @author Julie Fournier
 */
public class DocTypeDP extends EditorDP
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "CrDocType";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(247, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
   /**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() 
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(2467, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		ICrawlerModelRO myModel  = (ICrawlerModelRO) ((EditorAS) m_asOwner).GetModel(((EditorAS) m_asOwner).m_strModelName);
		int nDocTypeSectionCount = myModel.GetDocMapSectionCount();

		for (int i = 0; i < nDocTypeSectionCount; i++)
		{
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP +
					i)).Display());

			views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		ICrawlerModelRO myModel  = (ICrawlerModelRO) ((EditorAS) m_asOwner).GetModel(((EditorAS) m_asOwner).m_strModelName);
		int nDocTypeSectionCount = myModel.GetDocMapSectionCount();

		for (int i = 0; i < nDocTypeSectionCount; i++)
		{
			myScripts.AddInnerHTMLElement(m_asOwner.GetView(CrawlerEditorAS.STR_MVC_STORAGE_NAME_TYPE_MAP +
					i).DisplayJavascript());
		}

		return myScripts;
	}
}

