package com.plumtree.portalpages.admin.editors.crawler;


// Plumtree Server
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View for the Import Documents section.
 * 
 * @author Julie Fournier
 */
public class ImportingDocsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.crawler.ImportingDocsView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "CrImportingDocs";

	/**
	 * HTML Object name: Import only new docs checkbox */
	public static final String HTMLCHECKBOX_IMPORT_ONLY_NEW_DOCS = "in_cb_OnlyNewDocs";

	/**
	 * HTML Object name: already imported docs radio button */
	public static final String HTMLRADIO_ALREADY_IMPORTED = "in_ra_AlreadyImported";

	/**
	 * HTML Object name: refresh ACLs checkbox */
	public static final String HTMLCHECKBOX_REFRESH_ACLS = "in_cb_RefreshACLs";

	/**
	 * HTML Object name: refresh them checkbox */
	public static final String HTMLCHECKBOX_REFRESH_THEM = "in_cb_RefreshThem";

	/**
	 * HTML Object name: sort them checkbox */
	public static final String HTMLCHECKBOX_SORT_THEM = "in_cb_SortThem";

	/**
	 * HTML Object name: regenerate links checkbox */
	public static final String HTMLCHECKBOX_REGENERATE_LINKS = "in_cb_RegenerateDelLinks";

	/**
	 * HTML Object name: clear history button */
	public static final String HTMLBUTTON_CLEAR_DEL_HISTORY = "in_bu_ClearHistory";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ImportingDocsView();
	}

	/**
	 * Returns the HTML for this View.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLInput myInput;
		HTMLSpan mySpan;

		int nCrawlerSettings = ((ICrawlerModelRO) m_model).GetCrawlerSettings();

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						250, "ptmsgs_portaladminmsgs")));

			// 1st table: Import only new docs
			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			if (((ICrawlerModelRO) m_model).GetImportOnlyNewLinks())
			{
				if (0 == (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR))
				{
					myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLCHECKBOX_IMPORT_ONLY_NEW_DOCS, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
					myInput.SetChecked(true);
					myInput.SetOnClick("postToSelf(" +
						EditorRepostControl.POSTTOSELF_ACTION_SIMPLEREPOST +
						"); return false;");
					myInput.SetValue("1");

					myCell.AddInnerHTMLString(m_asOwner.GetString(252,
							"ptmsgs_portaladminmsgs"));
				}
				else
				{
					myCell.AddInnerHTMLString(m_asOwner.GetString(251,
							"ptmsgs_portaladminmsgs"));
				}

				// 2nd table: other settings
				myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth("100%");
				myTable.SetBorder("0");
				myTable.SetCellPadding("5");
				myTable.SetCellSpacing("0");

				// 1st Row - Don't import docs already inmported
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("150");
				myCell.SetVAlign("top");
				myCell.SetNoWrap(true);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(253,
						"ptmsgs_portaladminmsgs"));

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				myInput = new HTMLInput(HTMLInputTypes.RADIO,
						HTMLRADIO_ALREADY_IMPORTED, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
				myInput.SetValue("" +
					PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_CRAWLER_NEW_CARDS +
					"");

				if (PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS != (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(m_asOwner.GetString(254,
						"ptmsgs_portaladminmsgs"));

				myCell.AddInnerHTMLElement(new HTMLBr());

				myInput = new HTMLInput(HTMLInputTypes.RADIO,
						HTMLRADIO_ALREADY_IMPORTED, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
				myInput.SetValue("" +
					PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS +
					"");

				if (PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS == (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_IMPORT_ONLY_DATA_SOURCE_NEW_CARDS))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(m_asOwner.GetString(255,
						"ptmsgs_portaladminmsgs"));

				// 2nd Row - When revisiting previouly imported documents
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("150");
				myCell.SetVAlign("top");
				myCell.SetNoWrap(true);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(256,
						"ptmsgs_portaladminmsgs"));

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				if (0 != (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_ACL_IMPORT))
				{
					myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLCHECKBOX_REFRESH_ACLS, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
					myInput.SetValue("1");

					if (0 != (nCrawlerSettings &
							PT_CRAWLER_SETTINGS.PT_CRAWLER_FORCE_ACL_REFRESH))
					{
						myInput.SetChecked(true);
					}

					myCell.AddInnerHTMLString(m_asOwner.GetString(257,
							"ptmsgs_portaladminmsgs"));
					myCell.AddInnerHTMLElement(new HTMLBr());
				}

				myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
						HTMLCHECKBOX_REFRESH_THEM, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
				myInput.SetValue("1");

				if (0 != (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_REFRESH_RECRAWLED_CARDS))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(m_asOwner.GetString(258,
						"ptmsgs_portaladminmsgs"));
				myCell.AddInnerHTMLElement(new HTMLBr());

				if (0 == (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR))
				{
					myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLCHECKBOX_SORT_THEM, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
					myInput.SetValue("1");

					if (0 != (nCrawlerSettings &
							PT_CRAWLER_SETTINGS.PT_CRAWLER_RETAXONOMIZE_RECRAWLED_CARDS))
					{
						myInput.SetChecked(true);
					}

					myCell.AddInnerHTMLString(m_asOwner.GetString(259,
							"ptmsgs_portaladminmsgs"));
					myCell.AddInnerHTMLElement(new HTMLBr());
				}

				myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
						HTMLCHECKBOX_REGENERATE_LINKS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
				myInput.SetValue("1");

				if (0 != (nCrawlerSettings &
						PT_CRAWLER_SETTINGS.PT_CRAWLER_RECRAWL_DELETED_CARDS))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(m_asOwner.GetString(260,
						"ptmsgs_portaladminmsgs"));
				myCell.AddInnerHTMLString(SPACE);
				myCell.AddInnerHTMLString(SPACE);

				myInput = new HTMLInput(HTMLInputTypes.BUTTON,
						HTMLBUTTON_CLEAR_DEL_HISTORY, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

				myInput.SetValue(m_asOwner.GetString(261,
						"ptmsgs_portaladminmsgs"));
				myInput.SetOnClick("ConfirmDeleteHistory();");
			}
			else
			{
				myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
						HTMLCHECKBOX_IMPORT_ONLY_NEW_DOCS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
				myInput.SetValue("1");
				myInput.SetOnClick("postToSelf(" +
					EditorRepostControl.POSTTOSELF_ACTION_SIMPLEREPOST +
					"); return false;");

				myCell.AddInnerHTMLString(m_asOwner.GetString(252,
						"ptmsgs_portaladminmsgs"));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "ImportingDocsView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(262,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns Java Script for that Section.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript;

		try
		{
			XPStringBuilder sb = new XPStringBuilder(300);
			myScript = new HTMLScript("text/javaScript");

			if (((CrawlerModel) m_model).m_nDeletionCards > 0)
			{
				sb.Append("alert(\"" +
					XPResourceManager.FormatMessage(m_asOwner.GetString(263,
							"ptmsgs_portaladminmsgs"),
						"" + ((CrawlerModel) m_model).m_nDeletionCards + "") +
					"\");\n");

				((CrawlerModel) m_model).m_nDeletionCards = 0;
			}
			
			sb.Append("function ConfirmDeleteHistory()\n");
			sb.Append("{\n");
			sb.Append("  if (confirm(\"" + m_asOwner.GetString(2156, "ptmsgs_portaladminmsgs") + "\"))\n");
			sb.Append("  {\n");
			sb.Append("    postToSelf(" +	CrawlerRepostControl.POSTTOSELF_ACTION_CLEAR_DELETION_HISTORY +	");\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			
				log.Error(e, "ImportingDocsView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(264,
					"ptmsgs_portaladminmsgs"), e);
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

