package com.plumtree.portalpages.admin.editors.crawler;


// Plumtree Server
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View for the Rejected Documents section.
 * 
 * @author Julie Fournier
 */
public class RejectedDocsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.crawler.RejectedDocsView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "CrRejectedDocs";

	/**
	 * HTML Object name: re-import docs radio button */
	public static final String HTMLRADIO_REIMPORT_DOCS = "in_ra_ReImportDocs";

	/**
	 * HTML Object name: clear history button */
	public static final String HTMLBUTTON_CLEAR_REJ_HISTORY = "in_bu_ClearHistory";

	/**
	 * HTML Object name: Rejected Documents radio button */
	public static final String HTMLRADIO_REJECTED_DOCS = "in_ra_RejectedDocs";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RejectedDocsView();
	}

	/**
	 * Returns the HTML for this View.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLInput myInput;
		HTMLSpan mySpan;

		int nCrawlerSettings = ((ICrawlerModelRO) m_model).GetCrawlerSettings();
		boolean bSupportMirroring = ((ICrawlerModelRO) m_model).GetSupportMirroring();
		int nTaxSettings		  = ((ICrawlerModelRO) m_model).GetTaxSettings();
		int nEditorType		  	  = ((ICrawlerModelRO) m_model).GetEditorType();
		boolean bHeaderSet		  = false;
		try
		{
			/* Defualt Rejected Documents (moved from DefaultConfView.java) */
			if ((!bSupportMirroring) ||
				(0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR & nCrawlerSettings)))
			{
				/* set the header */
				result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
							268, "ptmsgs_portaladminmsgs")));
				bHeaderSet = true;
				
				myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth("100%");
				myTable.SetBorder("0");
				myTable.SetCellPadding("5");
				myTable.SetCellSpacing("0");

				// 1st Row - when Rejected documents are found
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				
				// 1st cell - instruction text
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("150");
				myCell.SetNoWrap(true);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
				mySpan.AddInnerHTMLString(
					m_asOwner.GetString(2592, "ptmsgs_portaladminmsgs"));
				
				// 2nd cell - radio buttons
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				myInput = new HTMLInput(HTMLInputTypes.RADIO,
						HTMLRADIO_REJECTED_DOCS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
				myInput.SetValue("0");

				if (0 != (PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_PUT_REJECTED_CARDS_IN_UNCLASSIFIED &
						nTaxSettings))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(
					m_asOwner.GetString(2593,"ptmsgs_portaladminmsgs"));
				myCell.AddInnerHTMLElement(new HTMLBr());

				myInput = new HTMLInput(HTMLInputTypes.RADIO,
						HTMLRADIO_REJECTED_DOCS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
				myInput.SetValue("1");

				if (0 == (PT_TAXONOMIST_SETTINGS.PT_TAXONOMIST_PUT_REJECTED_CARDS_IN_UNCLASSIFIED &
						nTaxSettings))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(
					m_asOwner.GetString(2594, "ptmsgs_portaladminmsgs"));
			}


			/* Rejected Documents History
			 * The following View is in Edit mode only
			 */
			if ((EditorStartControl.EDITOR_START_FLAG_EDIT == nEditorType) &&
				(0 == (nCrawlerSettings & PT_CRAWLER_SETTINGS.PT_CRAWLER_MIRROR)))
			{
				/* set header if not set */
				if (!bHeaderSet)
				{
					result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						268, "ptmsgs_portaladminmsgs")));
				}

				myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth("100%");
				myTable.SetBorder("0");
				myTable.SetCellPadding("5");
				myTable.SetCellSpacing("0");
	
				// 1st Row - When revisting rejected docs
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
	
				// 1st cell - instruction text
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("150");
				myCell.SetNoWrap(true);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				
				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
				mySpan.AddInnerHTMLString(
					m_asOwner.GetString(2591, "ptmsgs_portaladminmsgs"));

				// 2nd cell - radio buttons
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("100%");
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
	
				myInput = new HTMLInput(HTMLInputTypes.RADIO,
						HTMLRADIO_REIMPORT_DOCS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
				myInput.SetValue("0");

				if (0 == (PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS &
					nCrawlerSettings))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(
					m_asOwner.GetString(2596,"ptmsgs_portaladminmsgs"));
				myCell.AddInnerHTMLElement(new HTMLBr());

				myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_REIMPORT_DOCS, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_RADIO);
				myInput.SetValue("1");

				if (0 != (PT_CRAWLER_SETTINGS.PT_CRAWLER_IGNORE_PREVIOUSLY_REJECTED_CARDS &
					nCrawlerSettings))
				{
					myInput.SetChecked(true);
				}

				myCell.AddInnerHTMLString(
					m_asOwner.GetString(2594,"ptmsgs_portaladminmsgs"));

				/* clear rejection history button */	
				myCell.AddInnerHTMLString(SPACE);
				myCell.AddInnerHTMLString(SPACE);

				myInput = new HTMLInput(HTMLInputTypes.BUTTON,
						HTMLBUTTON_CLEAR_REJ_HISTORY, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
	
				myInput.SetValue(m_asOwner.GetString(2595, "ptmsgs_portaladminmsgs"));
				myInput.SetOnClick("ConfirmRejectionHistory();");
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "RejectedDocsView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(272,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns Java Script for that Section.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript;

		try
		{
			XPStringBuilder sb = new XPStringBuilder(300);
			myScript = new HTMLScript("text/javaScript");

			if (((CrawlerModel) m_model).m_nRejectionCards > 0)
			{
				sb.Append("alert(\"" +
					XPResourceManager.FormatMessage(m_asOwner.GetString(273,
							"ptmsgs_portaladminmsgs"),
						"" + ((CrawlerModel) m_model).m_nRejectionCards + "") +
					"\");\n");

				((CrawlerModel) m_model).m_nRejectionCards = 0;
			}
			
			sb.Append("function ConfirmRejectionHistory()\n");
			sb.Append("{\n");
			sb.Append("  if (confirm(\"" + m_asOwner.GetString(2156, "ptmsgs_portaladminmsgs") + "\"))\n");
			sb.Append("  {\n");
			sb.Append("    postToSelf(" +	CrawlerRepostControl.POSTTOSELF_ACTION_CLEAR_REJECTION_HISTORY +	");\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			
				log.Error(e, "RejectedDocsView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(274,
					"ptmsgs_portaladminmsgs"), e);
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

