package com.plumtree.portalpages.admin.editors.datasource;

// Framework imports
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author
 */
public class DataSourceDependenciesView extends ObjDependenciesView
{
	//Member variables
	private CreatedHelper m_chHelper	  = null;


	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "DataSourceDependenciesView";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DataSourceDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (DSModel) model);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		//Display the standard success message
		m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2105, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());

		m_chHelper.displayTextRow(result, m_asOwner.GetString(2106, "ptmsgs_portaladminmsgs"), null);
		m_chHelper.beginList(result);

		//Display Create Crawler link
		int nFolderID = ((ObjEditorModel) m_model).GetFolderID();
		
		//Get the providerCLSID from the data source object
		IPTDataSource myDataSource = (IPTDataSource) ((ObjEditorModel) m_model).GetObject();
		String strProviderCLSID = myDataSource.GetDataSourceProviderCLSID();
		
		String strArg = "&dataSourceID=" + ((DSModel)m_model).GetObjectID();
		
		m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
				PT_CLASSIDS.PT_CRAWLER_ID, strProviderCLSID,
				nFolderID, m_asOwner.GetString(2107, "ptmsgs_portaladminmsgs"), m_asOwner, strArg, true));

		//Display the standard warning if everyone has access to this object
		m_chHelper.displayEveryoneWarning(result, (DSModel) m_model, m_asOwner.GetString(2105, "ptmsgs_portaladminmsgs"));

		return result;
	}
}

