/**
 * Created on Dec 30, 2002
 * by adolfoc
 */
package com.plumtree.portalpages.admin.editors.datasource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author adolfoc
 */
public class DataSourceSelectWebServiceModel extends EditorHelperModel
	implements IDataSourceSelectWebServiceModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.datasource.DataSourceSelectWebServiceModel");

	public static final String STR_MVC_CLASS_NAME = "DataSourceSelectWebServiceModel";

	/**
	 * This member defines a static string used to identify when m_htFormData
	 * has been initialized.
	 */
	public static final String DEFAULTDATA = "Default Data";

	/**
	 * Our DataSource - handed to us in InitPModel
	 */
	private IPTDataSource m_ptDataSource = null;

	/**
	 * The following member holds a pointer to the Web Service object that
	 * this DataSource depends on. NOTE: The Web Service can change at any
	 * time and is NOT necessarily up-to-date. Do not use this member
	 * directly, but call GetWSObject() to get an up-to-date Web Service.
	 */
	private IPTWebService m_ptWebService = null;

	/**
	 * This member contains form data sent to this control (used for the Tree control, mostly).
	 */
	private XPHashtable m_htFormData;

	/**
	 * This member is used in determining whether or not the web service changed - whether
	 * or not we need to apprise our peers of the change.
	 */
	private int m_nOldWebServiceID = 0;

	public DataSourceSelectWebServiceModel()
	{
		super();
		m_htFormData = new XPHashtable();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DataSourceSelectWebServiceModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()
	 */
	public void DoTaskBeforePStore()
	{
		// Web Service Section
		IPTServerContext ptscWS = (IPTServerContext) m_ptWebService.GetInterfaces(
				"IPTServerContext");

		m_ptDataSource.SetWebServiceID(ptscWS.GetObjectID());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnPModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String, String)
	 */
	public void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
	{
		// AGC- This model initiates this change - it doesn't consume it.
	}

	/**
	 * @see com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)
	 */
	public String GetData(String name)
	{
		String[] values = (String[]) m_htFormData.GetElement(name);

		if (values == null)
		{
			return DEFAULTDATA;
		}

		return values[0];
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Call this method to set the WebServiceObject to a new one.
	 */
	public IPTWebService GetWSObject()
	{
		return m_ptWebService;
	}

	/**
	 * Returns the name value from m_strWebServiceTreeData.
	 * @return String
	 */
	public String GetWebServiceName()
	{
		if (null == m_ptWebService)
		{
			return null;
		}

		return m_ptWebService.GetLocalizedName();
	}

	/**
	 * Returns the selected web service ID.
	 * @return int
	 */
	public int GetWebServiceID()
	{
		return m_nOldWebServiceID;
	}

	/**
	 * Returns the path value from m_strWebServiceTreeData.
	 * @return String
	 */
	public String GetWebServicePath()
	{
		if (null == m_ptWebService)
		{
			return null;
		}

		int nAdminFolderID = m_ptWebService.GetAdminFolderID();

		DSModel mParentModel = (DSModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);
		IPTSession ptSession	  = mParentModel.GetPTSession();

		IPTAdminCatalog ptAFCatalog = ptSession.GetAdminCatalog();

		try
		{
			IPTAdminFolder ptAFParent = ptAFCatalog.OpenAdminFolder(nAdminFolderID, false);
	
			String strPath			  = ptAFParent.GetPath();
	
			return strPath;
		} catch(PTException pte)
		{
			return null;
		}
		
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)
	 */
	public void InitPModel(IPTDataSource ptDataSource)
	{
		m_ptDataSource = ptDataSource;

		DSModel mParentModel = (DSModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);
		int lWebServiceObjectID;

		switch (mParentModel.GetPMode())
		{
		case DSModel.PMODE_CREATE:
			// AGC- We may have been passed in a WebServiceID by a popup tree when
			// we were created. If so, let's get it and select it.
			int creatorID = mParentModel.GetCreatorID();
			if (creatorID != -1)
			{
				lWebServiceObjectID = creatorID;
				SetWSObject(lWebServiceObjectID);
			}

			break;

		default:

		lWebServiceObjectID = ptDataSource.GetWebServiceID();

			try {
				IPTSession ptSession		    = mParentModel.GetPTSession();
				IPTWebService ptWebServiceToSet = (IPTWebService) ptSession.GetWebServices()
					.Open(lWebServiceObjectID, false);


				m_ptWebService     = ptWebServiceToSet;

				// Don't forget to update the Old Web service ID.
				m_nOldWebServiceID = lWebServiceObjectID;
			} catch (Exception e)
			{
				log.Error(e, "DataSourceSelectWebService::InitPModel Could not retrieve webservice from DataSource. View will be non-read-only.");
				
				// AGC- We only force writable if (for some reason) the
				// WebService could not be found/set - which might happen if
				// we are imported from a broken object delivery package.

				m_ptWebService = null;
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ISelectWebServiceModelRO#IsWebServiceChangeable()
	 */
	public boolean IsWebServiceChangeable()
	{
		DSModel mParentModel = (DSModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);
		return mParentModel.IsWebServiceChangeable();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ISelectWebServiceModelRO#IsWebServiceRemovable()
	 */
	public boolean IsWebServiceRemovable()
	{
		DSModel mParentModel = (DSModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);
		return mParentModel.IsWebServiceRemovable();
	}

	/**
	 * This method gets the selected items from the tree.
	 */
	public void RefreshItemFromTree()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(DSEditorAS.WSTREE_SUBSPACE))
			{
				AActivitySpace asTree  = m_asOwner.GetSubSpace(DSEditorAS.WSTREE_SUBSPACE);
				ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList itemList   = treeModel.GetSelectedItems();

				if (itemList.GetSize() != 1)
				{
					
						log.Error("Tree selected wrong number of items.  Expecting 1, got " +
							itemList.GetSize());
					
				}

				TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

				if (item == null)
				{
					
						log.Error("Tree selected item null");
					
				} else
				{
					SetWSObject(item.m_nObjectID);
				}
			}
		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			
				log.Warn(e, "Unknown Error RefreshItemFromTree.");
			
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		if (IsWebServiceChangeable())
		{
			// Store our form data for later use - especially for use in the tree control.
			int nSize				 = _htFormData.GetSize();
			IXPEnumerator xpKeys     = _htFormData.GetKeys();

			for (int i = 0; i < nSize; i++)
			{
				xpKeys.MoveNext();

				m_htFormData.PutElement((String) xpKeys.GetCurrent(),
					(String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
			}

			RefreshItemFromTree();

			if (null != m_ptWebService)
			{
				return RepostControl.PAGE_STATUS_VALID;
			}
			else
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null,
						m_asOwner.GetString(594, "ptmsgs_portaladminmsgs"),
						m_asOwner.GetString(594, "ptmsgs_portaladminmsgs"));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				return RepostControl.PAGE_STATUS_INVALID;
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	
	/**
	 * This method clears the selected items from the tree.
	 */
	public void ClearWebService()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(DSEditorAS.WSTREE_SUBSPACE))
			{
				AActivitySpace asTree = m_asOwner.GetSubSpace(DSEditorAS.WSTREE_SUBSPACE);
				ATreeModel treeModel  = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
				treeModel.ClearSelectedItems();
			}

			m_ptWebService = null;
			m_nOldWebServiceID = 0;

			DSModel mParentModel = (DSModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);
			mParentModel.SetWebServiceID(0);
		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			
				log.Warn(e, "Unknown Error ClearRemoteServer.");
			
		}
	}


	/**
	 * Call this method to set the WebServiceObject to a new one.
	 * Returns true if the update was successful AND the webservice was changed.
	 * Returns false if the update failed OR the new Webservice was identical to
	 * the existing web service.
	 */
	private boolean SetWSObject(int nObjectID)
	{
		DSModel mParentModel = (DSModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);

		if (0 >= nObjectID)
		{
			m_ptWebService = null;
		}
		boolean bUpdated = false;
		try
		{
			// Let's only make the change if necessary
			if (m_nOldWebServiceID != nObjectID)
			{
				// Oh my, it changed.
				IPTSession ptSession		    = mParentModel.GetPTSession();
				IPTWebService ptWebServiceToSet = (IPTWebService) ptSession.GetWebServices()
					.Open(nObjectID, false);

				// MES- CR: Is reinitialization of Portlets supported?
				// AGC- Yes. Specifically allowed so that we can do this.
//				m_ptDataSource.SetProviderCLSID(strProviderID);
				m_ptWebService     = ptWebServiceToSet;

				// Don't forget to update the Old Web service ID.
				m_nOldWebServiceID = nObjectID;
				mParentModel.SetWebServiceID(nObjectID);
				bUpdated = true;

				// We must tell our peers of the change. It may have significant consequences.
//				mParentModel.UpdatePSubModels();
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "DataSourceSelectWebServiceModel::GetWSObject - Unable to change Web Service object. Continuing with existing Web Service (which may be null): " +
					e.getMessage());
			
		}

		return bUpdated;
	}
}

