package com.plumtree.portalpages.admin.editors.defaultprofile;


// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File:EditDefaultProfileTopView.java
 * -----------------------------------
 *
 * @author NaveenP
 */
public class EditDefaultProfileTopView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.defaultprofile.EditDefaultProfileTopView");

	public static final String STR_MVC_CLASS_NAME = "EditDefaultProfileTop";


	/** Activity Space Owner */
	protected AActivitySpace m_asOwner;

	/** Model */
	protected EditDefaultProfileModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EditDefaultProfileTopView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		//mainTable components
		HTMLTable mainTable    = new HTMLTable();
		HTMLTableRow mainRow   = new HTMLTableRow();
		HTMLTableCell mainCell;
		HTMLInput mainInput;

		try
		{
			mainRow.SetVAlign(CommonHTMLStrings.CENTER);

			HTMLImg spaceImg = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
					true, m_asOwner).GetHTMLElement();
			spaceImg.SetWidth(CommonHTMLStrings.TWO);
			spaceImg.SetHeight(CommonHTMLStrings.ONE);
			spaceImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			spaceImg.SetBorder(CommonHTMLStrings.ZERO);

			mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
			mainTable.SetCellPadding(CommonHTMLStrings.ZERO);
			mainTable.SetHeight("65");
			mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
			mainTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			mainTable.SetCellPadding(CommonHTMLStrings.ZERO);
			mainTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			mainTable.SetBorder(CommonHTMLStrings.ZERO);

			mainTable.AddInnerHTMLElement(mainRow);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetWidth("55%");
			mainCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetAlign(CommonHTMLStrings.CENTER);
			mainCell.SetStyleClass(PTStyleClass.BAN_HEADER);

			mainCell.AddInnerHTMLString(XPResourceManager.FormatMessage(
					m_asOwner.GetString(331, "ptmsgs_portalbrowsingmsgs"),
					XPHttpUtility.HtmlEncode(m_asModel.GetUserName())));

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetAlign(CommonHTMLStrings.CENTER);
			mainCell.SetStyleClass(PTStyleClass.BAN_HEADER);


			if(m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
			{
				mainInput = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_Finish",
					m_asOwner.GetString(330, "ptmsgs_portalbrowsingmsgs"));
				mainInput.SetOnClick("postToSelf(" + RepostControl.POSTTOSELF_ACTION_FINISH + ");");
			} else {
				mainInput = new HTMLInput(HTMLInputTypes.SUBMIT,
					RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH,
					m_asOwner.GetString(330, "ptmsgs_portalbrowsingmsgs"));
			}
			mainInput.SetValue(m_asOwner.GetString(329,
					"ptmsgs_portalbrowsingmsgs"));
			mainInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			mainCell.AddInnerHTMLElement(mainInput);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetWidth("15%");
			mainCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			result.AddInnerHTMLElement(mainTable);
		}
		catch (Exception e)
		{
			log.Error(e, e.getMessage());
		}

		return result;
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		XPStringBuilder sb = new XPStringBuilder(50);

		HTMLScript myScript = new HTMLScript("text/javaScript");

		try
		{
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace space)
	{
		m_asOwner     = space;
		m_asModel     = (EditDefaultProfileModel) model;
	}
}

