package com.plumtree.portalpages.admin.editors.defaultprofile;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * File: SetEditDefaultProfileControl.java
 * ----------------------------------
 *
 * @author NaveenP
 */
public class SetEditDefaultProfileControl implements ILoginControl, IHTTPControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.defaultprofile.SetEditDefaultProfileControl");

	public static final String STR_MVC_CLASS_NAME = "SetEditDefaultProfile";

	public static final String m_UserID = "EditUserID";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private EditDefaultProfileModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String[] sValues = (String[]) arguments.GetElement(m_UserID);

		if (sValues == null)
		{
			
				log.Error("could not find user id in query string.");
			
	
			return null;
		}

		int nUserID = XPConvert.ToInteger(sValues[0]);

		try
		{
			m_asModel.SetUser(nUserID);
		}
		catch (Exception e)
		{
			log.Warn(e, "Error starting up Profile Edit mode.");
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, e.getMessage(),
					e.getMessage());
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
			
			// DCA - redirect to previous space if an exception occurs
			Redirect result = new Redirect();
			// JF- If the parent space is already in the cache, we redirect to it.
			if (null != m_asOwner.GetParentSpace())
			{
				result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
			}
			// JF- If not, we redirect to a new one.
			else
			{	
				result.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
			}
			return result;
		}

		return null;
	}

	/**
	 * 
	 *
	 * @param request 
	 * @param webdata
	 */
	public void SetHTTPItems(IXPRequest request, IWebData webdata)
	{
		m_asModel.SetHTTPItems(request, webdata);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetEditDefaultProfileControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#DoGetSession()
	 */
	public boolean DoGetSession()
	{
		// The interpreter should ask us for the session.
		return true;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.ILoginControl#GetSession()
	 */
	public Object GetSession()
	{
		return m_asModel.GetSession();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (EditDefaultProfileModel) model;
		m_asOwner     = space;
	}

	/**
	 *
	 * @see com.plumtree.portaluiinfrastructure.activityspace.ILoginControl#SetRedirectForUseAfterLogin(Redirect)
	 */
	public void SetRedirectForUseAfterLogin(Redirect r)
	{
	}
}

