package com.plumtree.portalpages.admin.editors.doctypemap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Document Type Map Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author SudhaS
 */

// ***CHANGE_HERE*** Change the name of the class.
// ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
//       when you are done.
public class GbDocTypeEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeEditorAS");

	// ***CHANGE_HERE*** Set the class name.
	// ***COMMENT_1*** All the AS in Plumtree need to have a unique name.


	public static final String STR_MVC_CLASS_NAME = "GbDocTypeMapEditor";


	public static final String strStorageGbDocTypeList = "GbDocTypeListStorage";


private static final String sClassName = "com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GbDocTypeEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(320, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * Returns the class name of the Document Type Map Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		// ***CHANGE_HERE*** Replace GbDocTypeRepostControl below with your RepostControl.
		return (GbDocTypeRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		// ***CHANGE_HERE*** Replace PropModel below with your Model.
		m_strModelName = GbDocTypeModel.STR_MVC_CLASS_NAME;

		// Warning: m_myModel must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(GbDocTypeModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		// ***CHANGE_HERE*** Register each DP of your AS.
		//RegisterPage(new GbDocTypeMainDP());
		//RegisterPage(new GbDocTypePopUpDP());
		//RegisterView(GbDocTypePopUpView.STR_MVC_CLASS_NAME, myModel);
		// Register Controls
		// ***CHANGE_HERE*** Register each Control of your AS.
		RegisterControl(GbDocTypeRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register Migration History Plugin
		RegisterModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME);
		RegisterView(MigrationHistoryView.STR_MVC_CLASS_NAME,
			GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME));
		RegisterPage(new MigrationHistoryPluginDP());

		// Set default page
		// ***CHANGE_HERE*** Replace PropMainDP below with the default DP.
		// (It will be the page selected by default when the user starts the Editor).
		//SetCurrentPage(GbDocTypeMainDP.STR_MVC_CLASS_NAME);
		//Sets left nav menu
		// ***CHANGE_HERE*** Set the left nav menu using StartNewSubMenu and AddLinkToSubMenu.
		// BEGIN Sub menu "General Settings"
		//int nMenuOneID = m_mEditorMenu.StartNewSubMenu(_ui_PropertyLeftNavTitleMain);
		//m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GbDocTypeMainDP.STR_MVC_CLASS_NAME);
		// END Sub menu "General Settings"
		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				tm.SetGeneratingClass( sClassName );



				int iTitleId = 30;
				int iTipId = 31;
				int iSecondaryTipId = 32;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}



			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	 *
	 */
	public void InitGlobalDocumentSections()
	{
		try
		{
			// JF- We start to build the left navigation
			int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(321,
						"ptmsgs_portaladminmsgs"));



			IModel myModel = GetModel(GbDocTypeModel.STR_MVC_CLASS_NAME);

			IASQueryResult asqrSections = ((IGbDocTypeModelRO) myModel).GetSections();

			for (int i = 0; i < asqrSections.GetCount(); i++)
			{
				//int nSectionID = XPConvert.ToInteger(asqrSections.GetFields(i, PT_PROPIDS.PT_PROPID_DTMSECTION_ID));
				//String strSectionName = (String) asqrSections.GetFields(i, PT_PROPIDS.PT_PROPID_DTMSECTION_NAME);
				GbDocTypeMainDP myGbDocTypeDP = new GbDocTypeMainDP(i);

				RegisterPage(myGbDocTypeDP, myGbDocTypeDP.GetName());

				if (i == 0)
				{
					SetCurrentPage(myGbDocTypeDP);
				}

				// JF- Add the page to the left nav menu
				m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
					myGbDocTypeDP.GetName());

				// Register Views
				// ***CHANGE_HERE*** Register each Section of your AS.
				// Register GbDocTypeList
				RegisterModel(GbDocTypeListModel.STR_MVC_CLASS_NAME,
					strStorageGbDocTypeList + i);

				// Get back the Model we just registered because we need it to register the Section and the Control
				IModel myGbDocTypeListModel = GetModel(strStorageGbDocTypeList +
						i);
				((GbDocTypeListModel) myGbDocTypeListModel).SetModelID(i);
				RegisterView(GbDocTypeListView.STR_MVC_CLASS_NAME,
					strStorageGbDocTypeList + i, myGbDocTypeListModel);
				RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
					strStorageGbDocTypeList + i, myGbDocTypeListModel);
			}

			int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1806, "ptmsgs_portaladminmsgs"));

			//m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GbDocTypeMainDP.STR_MVC_CLASS_NAME);
			m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeEditorAS :: Could not get sections - " +
					e);
			
		}
	}

	/**
	  * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	  *
	  * @param IDisplayPage the current Display Page
	  */

	 public void SetCurrentPage(IDisplayPage page)
	 {

		  super.SetCurrentPage( page );
		  String sPageName = page.GetName();

		  String sGlobalDocTypePageName = XPStringUtility.Substring(sPageName, 0, sPageName.length() - 1);
		  if(GbDocTypeMainDP.STR_MVC_CLASS_NAME.equals( sGlobalDocTypePageName))
		  {
				this.SetHelpTopic( "PT_GlobalDocumentTypeMap" );
		  }

		  else  if( MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_MigrationHistoryandStatus" );
		  }
	 }
}

