package com.plumtree.portalpages.admin.editors.doctypemap;


// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the General Info page of the Document Type Map Editor.
 *
 * @author SudhaS
 */

public class GbDocTypeMainDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeMainDP");

	public static final String STR_MVC_CLASS_NAME = "GbDocTypeMapMain";

	public static final String HTMLHIDDEN_POPUP_NAME = "in_hi_PopUpName";

	public static final String HTMLHIDDEN_PAGE_ID = "in_hi_PageID";
	private int m_nGbDocTypePageID;

	// ***CHANGE_HERE*** Update the class name below.
	public GbDocTypeMainDP(int _nGbDocTypePageID)
	{
		m_nGbDocTypePageID = _nGbDocTypePageID;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1680, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 *
	 * @return
	 */
	public int GetGbDocTypeID()
	{
		return m_nGbDocTypePageID;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		// ***CHANGE_HERE*** Returns the String to display on the left navigation menu,
		//       linking to that page.
		String strLeftNav = null;

		try
		{
			strLeftNav = ((IGbDocTypeModelRO) m_asOwner.GetModel(GbDocTypeModel.STR_MVC_CLASS_NAME)).GetSectionName(m_nGbDocTypePageID);
			strLeftNav = XPResourceManager.FormatMessage(m_asOwner.GetString(2476, "ptmsgs_portaladminmsgs"), strLeftNav);
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeDP::GetSections Unable to get sections from Document Type Map. The following exception occured: " +
					e);
			
		}

		return (strLeftNav);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME + m_nGbDocTypePageID;
	}

	/**
	 * Returns the HTML for the General Settings page.
	 *
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// ***CHANGE_HERE*** For each Section you want to display on that page,
		//       copy the line below and change the name of the Section.
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(GbDocTypeEditorAS.strStorageGbDocTypeList +
				m_nGbDocTypePageID)).Display());

		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				HTMLHIDDEN_POPUP_NAME, "");
		result.AddInnerHTMLElement(myInput);

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_PAGE_ID, "");
		myInput.SetValue(XPConvert.ToString(m_nGbDocTypePageID));
		result.AddInnerHTMLElement(myInput);

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	* Display the Javascripts for the Views.
	*
	* @return HTMLScriptCollection
	* @throws HTMLException
	*/
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		// ***CHANGE_HERE*** If that DP doesn't have any JavaScripts,
		//      you can delete the entire DisplayJavaScriptFromChild() method.
		HTMLScriptCollection myScripts = null;

		myScripts = super.DisplayJavaScriptFromChild();

		// ***CHANGE_HERE*** Call the DisplayJavascript() method for all the Views having JavaScripts
		//      displayed by that DP.
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(GbDocTypeEditorAS.strStorageGbDocTypeList +
				m_nGbDocTypePageID).DisplayJavascript());

		return myScripts;
	}
}

