package com.plumtree.portalpages.admin.editors.doctypemap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 *
 *
 * @version $Revision$
 * @author Sudha Sathiaseelan
 */
public class GbDocTypeModel extends GbObjEditorModel
	implements IGbDocTypeModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.doctypemap.GbDocTypeModel");


	public static final String STR_MVC_CLASS_NAME = "GbDocMapType";








	private int m_nSectionsCount;

	// END ***************** save DP methods *****************
	// ***CHANGE_HERE*** Implement the repost action methods that you
	//      will call from your Repost Control.
	// BEGIN ***************** repost action methods *****************

	/**
	 * Modifies the object name on repost.
	 */
	public void ActionOnRepost()
	{
		// Code to perform on repost.
	}

	// ***CHANGE_HERE*** Put your set/get methods and other helper methods
	// BEGIN ***************** helper methods *****************

	/**
	 * Returns the document type sections.
	 *
	 * @param _htFormData
	 *
	 * @return ASQueryResult
	 *
	 * @throws XPException
	 */
	/**
	 * That method is called by the EditorStartControl.  It creates the global
	 * object and puts it in m_ptGlobalObject.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access
	 *         this Editor.
	 * @throws XPException
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{

		if (!m_Session.GetSessionInfo().CheckForActivityRight(
						PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		if (!m_Session.GetSessionInfo().CheckCurrentUserIsAdmin()) return false;

		// Set global object ID with values from QS.
		SetMemberVariablesFromQS(_htFormData);

		try
		{
			// JF- We open the Global Obejct with the ID provided in the QS.
			m_ptGlobalObject = m_Session.OpenGlobalObject(m_nGlobalObjectID, false);
		}
		catch (Exception e)
		{
			
				log.Error(e, "GbObjEditorModel::StartEditor Unable to create Global Object with ID: " +
					m_nGlobalObjectID + ". The following exception occured: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(152,
					"ptmsgs_portalinfrastructure"), e); //_ui_CreateGlobalObjectError
		}

		((GbDocTypeEditorAS) m_asOwner).InitGlobalDocumentSections();
		StartGbDocTypeList();

		StartMigrationHistory();

		DoTaskOnStartEditor(_htFormData);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GbDocTypeModel();
	}

	/**
	 * This method will be called when you come back to the main Editor from a
	 * sub Editor.
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		IASQueryResult qrSections;

		try
		{
			qrSections = GetSections();

			for (int i = 0; i < qrSections.GetCount(); i++)
			{
				((GbDocTypeListModel) m_asOwner.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList +
					i)).DoTaskOnComeBackFromSubEditor(i);
			}
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeModel " + e);
			
		}
	}

	// END ***************** repost action methods *****************

	/**
	 * This method contains the code to store the Document Type Map.
	 */
	public void Finish()
	{
		try
		{
			IASQueryResult qrSections		    = GetSections();
			GbDocTypeListModel myGbDocTypeModel;

			for (int i = 0; i < qrSections.GetCount(); i++)
			{
				myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList +
						i);

				myGbDocTypeModel.Finish();
			}

			// Set the migration status to approved if the checkbox was checked
			((IMigrationHistoryModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).StoreMigrationStatus(PT_CLASSIDS.PT_GLOBALOBJECT_ID, m_nGlobalObjectID);

			IPTServerContext ptscDocTypeMap;
			ptscDocTypeMap = (IPTServerContext) ((IPTDocumentTypeMap) m_ptGlobalObject).GetInterfaces(
					"IPTServerContext");

			ptscDocTypeMap.LockObject();
			ptscDocTypeMap.Store();
			ptscDocTypeMap.UnlockObject();
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeModel " + e);
			
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
			UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(2482, "ptmsgs_portaladminmsgs"),
	 					 m_asOwner.GetString(2482, "ptmsgs_portaladminmsgs"));
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
 				m_asOwner.GetApplication());
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @param _nIndex
	 *
	 * @return
	 *
	 * @throws Exception
	 */
	public String GetSectionName(int _nIndex)

	{
		IASQueryResult asqrSections = GetSections();
		String strSectionName	    = (String) asqrSections.GetFields(_nIndex,
				PT_PROPIDS.PT_PROPID_DTMSECTION_NAME);

		return strSectionName;
	}

	/**
	 *
	 *
	 * @return
	 *
	 * @throws Exception
	 * @throws XPException
	 */
	public IASQueryResult GetSections()

	{
		IPTQueryResult qrSections;

		try
		{
			qrSections = ((IPTDocumentTypeMap) super.m_ptGlobalObject).GetSections();
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeModel::GetSections Unable to get sections from Document Type Map. The following exception occured: " +
					e);
			

			throw new XPException(m_asOwner.GetString(334,
					"ptmsgs_portaladminmsgs"), e);
		}

		return (new ASQueryResultWrapper(qrSections));
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetSectionsCount()
	{
		return m_nSectionsCount;
	}

	// END ***************** helper methods *****************

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		// ***CHANGE_HERE*** Switch between your DP and for each one call
		//       the associated save method.
		if (_sPageName.equals(GbDocTypeMainDP.STR_MVC_CLASS_NAME))
		{
			SaveMainPage(_htFormData);
		}
		else if (_sPageName.equals(MigrationHistoryPluginDP.STR_MVC_CLASS_NAME))
		{
			((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	// ***CHANGE_HERE*** Implement one method per DP to save it
	// BEGIN ***************** save DP methods *****************

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
	}

	/**
	 *
	 */
	protected void StartGbDocTypeList()
	{
		GbDocTypeListModel myGbDocTypeModel = null;

		try
		{
			IASQueryResult qrSections = GetSections();
			m_nSectionsCount = qrSections.GetCount();

			for (int i = 0; i < qrSections.GetCount(); i++)
			{
				myGbDocTypeModel = (GbDocTypeListModel) m_asOwner.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList +
						i);

				String strSectionName	    = (String) qrSections.GetFields(i, PT_PROPIDS.PT_PROPID_DTMSECTION_NAME);
				myGbDocTypeModel.InitializeGbDocTypeList((IPTDocumentTypeMap) m_ptGlobalObject, i, strSectionName);
			}
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeModel::GetSections Unable to get sections from Document Type Map. The following exception occured: " +
					e);
			

			throw new XPException(m_asOwner.GetString(334,
					"ptmsgs_portaladminmsgs"), e);
		}

		// JF- The 2 lines below are only needed if you are going to enable the move row actions
	}

	/**
	 *
	 */
	protected void StartMigrationHistory()
	{
		((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).InitializeHistory(PT_CLASSIDS.PT_GLOBALOBJECT_ID,
			m_nGlobalObjectID);
	}
}

