package com.plumtree.portalpages.admin.editors.doctypemapextension;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Growable Array.
 * The Growable Array is a list of input texts.
 * On add, a new input text populated with the default value
 * will be added at the bottom of the list.
 *
 * @author SudhaS
 */
public class GbDocTypeExtListModel extends ExpListModel
	implements IGbDocTypeExtListModelRO
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "GbDocTypeExtList";

	/**
	 * Number total of columns
	 */
	public static final int EXPLIST_COL_MAX = 3;

	/**
	 * This column contains the Object Class IDs.
	 */
	public static final int EXPLIST_COL_DOCTYPENAME = 1;


	public static final int EXPLIST_COL_DOCTYPEID = 2;

	/**
	 * Second column: the value of the input text. */
	public static final int EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT = 1;

	/**
	 * Icon to display on each row, just before the input text. */
	protected PTImageType m_imgRowIcon;

	/**
	 * This is the String that we doisplay in the list.
	 * E.g.: Object name or folder path.
	 */

	//public static final int EXPLIST_COL_DESCRIPTION = 3;
	//public static final int EXPLIST_COL_URI	= 4;

	/**
	 * This is used on add to populate the input
	 * text of the newly added row.
	 */
	protected String m_sDefaultValue = "";
	protected String m_strSecondAddLabel = "";

	/**
	 *
	 *
	 * @param _oRow
	 */
	public void AddRow(Object[] _oRow)
	{
		super.GetItems().AddRow(_oRow);
	}

	/**
	 * Adds one row at the bottom of the list and
	 * sets the following values:
	 * First column: m_nNextIndex
	 * Second column: m_sDefaultValue
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		boolean bCanAddNewRow = true;

		// JF- Before we add a new row at the end of the list, we check
		// if you don't already have a "new row" in the list.
		// The user doesn't need to have more than one empty row (or row with the default value).
		// JF- Check the array see if we have the default value in it.
		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			if (m_sDefaultValue.equals(m_saData.GetItem(i,
							EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT)))
			{
				// JF- We already have a new row no need to add one more.
				bCanAddNewRow = false;

				break;
			}
		}

		if (bCanAddNewRow)
		{
			AddRowsToList(new String[] { m_sDefaultValue });
		}
	}

	/**
	 * Adds an array of new rows to the list.
	 *
	 * @param _aData
	 */
	public void AddRowsToList(String[] _aData)
	{
		Object[] oRow;

		for (int i = 0; i < _aData.length; i++)
		{
			oRow									   = new Object[EXPLIST_COL_MAX];
			oRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
			m_nNextIndex++;
			oRow[EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = _aData[i];
			super.GetItems().AddRow(oRow);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GbDocTypeExtListModel();
	}

	/**
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
	}

	/**
	 * Return the ASURL object going to the Property Editor as a sub Editor.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor.
	 * If we are going to a new sub Editor, the key can be null and
	 * we will just pass in the default key. If we are going back to an
	 * existing sub Editor, it should be the sub Editor key.
	 * @return ASURL
	 */
	public ASURL GetASURLToProperty(String _sSubSpaceKey,
		String _strDefaultSpace)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = _strDefaultSpace;
		}

		// ***CHANGE_HERE*** If you don't have a class ID, just pass in null for the 2 last arguments.
		// JF- The helper method below will return the right URL. We don't need to figure out
		// if it's a cahed sub Editor or no.
		ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(_strDefaultSpace,
				_sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE,
				ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_DOCUMENTTYPE_ID));

		return myPopUpURL;
	}

	/**
	 *
	 *
	 * @param _nRowIndex
	 *
	 * @return
	 */
	public String GetDocTypeFromRowIndex(int _nRowIndex)
	{
		return XPConvert.ToString(
			super.GetItems().GetItem(_nRowIndex, EXPLIST_COL_DOCTYPEID));
	}

	/**
	 * This method should ge used by the client to
	 * get back the array of values at the end of
	 * the Editor and store them.
	 *
	 * @return String[]
	 */
	public String[] GetListValues()
	{
		String[] aListValues = new String[m_saData.GetCount()];

		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			aListValues[i] = (String) m_saData.GetItem(i,
					EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		}

		return aListValues;
	}

	// ***CHANGE_HERE*** This key is used to create and retrieve sub Editors.
	//private int m_nSubSpaceIndex = 0;

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the icon to display on each row before the
	 * input text.
	 * If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgRowIcon;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetSecondAddLabel()
	{
		return m_strSecondAddLabel;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeGbDocTypeExtList(String _sSectionTitle,
		String _sSectionSubTitle1, PTImageType _imgAddIcon, String _sAddLabel,
		int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[1][5];

		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle1;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "2";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}



	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_DOCTYPENAME,
				EXPLIST_COL_DOCTYPEID
			};

		// JF- Sort array
		// The growable array will always be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_SORTEDARRAY_PROPID_INDEX;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true);
	}

	/**
	* Add the array passed in argument to the list.
	* The array should be created using the EXPLIST_COL
	* constants defined in this class.
	*
	* @param _arrRows Array of rows to add.
	*/
	public void SetDefaultObjects(Object[][] _arrRows)
	{
		super.GetItems().AddRows(_arrRows);
	}

	/**
	 * Sets a new default value.
	 * By default this is an empty string.
	 * This value is used on add to populate the input
	 * text of the newly added row.
	 *
	 * @param _sDefaultValue New value
	 */
	public void SetDefaultValue(String _sDefaultValue)
	{
		m_sDefaultValue = _sDefaultValue;
	}

	/**
	 * Sets the icon to display on each row before the
	 * input text.
	 * By default, no icon is displayed.
	 *
	 * @param _imgRowIcon
	 */
	public void SetRowIcon(PTImageType _imgRowIcon)
	{
		m_imgRowIcon = _imgRowIcon;
	}

	/**
	 *
	 *
	 * @param _strSecondAddLabel
	 */
	public void SetSecondAddLabel(String _strSecondAddLabel)
	{
		m_strSecondAddLabel = _strSecondAddLabel;
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		String sDataKey     = GetUniqueString(GbDocTypeExtListView.HTMLINPUT_ITEM) +
			_nRowIndex;
		String[] aDataValue;

		// JF- For each input text posted by the form, we get the value back
		// and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex,
					EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT, aDataValue[0]);
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
}

