package com.plumtree.portalpages.admin.editors.doctypemapextension;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.crawler.*;
import com.plumtree.portalpages.admin.editors.doctypemap.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 *
 * @author SudhaS
 */


public class GbDocTypeExtModel extends GbObjEditorModel
	implements IGbDocTypeExtModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.doctypemapextension.GbDocTypeExtModel");


	public static final String STR_MVC_CLASS_NAME = "GbDocTypeExtModel";
	protected String m_sSetting1;
	protected String m_sSetting2;
	protected String m_strDocTypeName = "";
	protected String m_strExtension   = "";
	protected boolean m_bAdded		    = false;
	protected boolean m_bEdit		    = false;
	protected int m_nDocTypeID		    = -1;
	protected int m_nGbDocTypeSectionID = -1;
	protected int m_nGbDocTypeModelID = -1;
	protected int m_nRowIndex = -1;

	/**
	 * Code executed when the Editor is starting.
	 *
	 */
	/**
	 * That method is called by the EditorStartControl.
	 * It creates the global object and puts it in m_ptGlobalObject.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		// Set global object ID with values from QS.
		SetMemberVariablesFromQS(_htFormData);

		try
		{
			// JF- We open the Global Obejct with the ID provided in the QS.
			// check to see if this is editing the global document type map or the crawler document type map =mgs
			if (GbDocTypeEditorAS.STR_MVC_CLASS_NAME.equals(m_asOwner.GetParentSpace().GetName())){
				m_ptGlobalObject = m_Session.OpenGlobalObject(m_nGlobalObjectID, false);
			} else { //not the global editor, open up this specific crawler's document type map
				AActivitySpace myParentAS = m_asOwner.GetParentSpace();
				if (myParentAS instanceof CrawlerEditorAS) {
					CrawlerEditorAS crawlerAS = (CrawlerEditorAS)myParentAS;
					CrawlerModel crawlerModel  = (CrawlerModel)myParentAS.GetModel(crawlerAS.m_strModelName);
					m_ptGlobalObject = ((IPTCrawler) crawlerModel.GetObject()).GetDocumentTypeMap();
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "GbObjEditorModel::StartEditor Unable to create Global Object with ID: " +
					m_nGlobalObjectID + ". The following exception occured: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(152,
					"ptmsgs_portalinfrastructure"), e); //_ui_CreateGlobalObjectError
		}

		String[] data = (String[]) _htFormData.GetElement(GbDocTypeListModel.CURRENTSECTION_ID);

		if (data != null)
		{
			m_nGbDocTypeSectionID = XPConvert.ToInteger(data[0]);
		}

		data = (String[]) _htFormData.GetElement(GbDocTypeListModel.DOCTYPE_ID);

		if (data != null)
		{
			m_nDocTypeID = XPConvert.ToInteger(data[0]);
		}

		data = (String[]) _htFormData.GetElement(GbDocTypeListModel.DOCTYPE_NAME);

		if (data != null)
		{
			m_strExtension = data[0];
		}

		data = (String[]) _htFormData.GetElement(GbDocTypeListModel.ROW_INDEX);

		if (data != null)
		{
			m_nRowIndex     = XPConvert.ToInteger(data[0]);
			m_bEdit		    = true;
		}

		data = (String[]) _htFormData.GetElement(GbDocTypeListModel.CURRENTGBDOCTYPEMODEL_ID);
		if (data != null)
		{
			m_nGbDocTypeModelID = XPConvert.ToInteger(data[0]);
		}

		UpdateDocTypeHashTable();



		StartGbDocTypeExtList();

		DoTaskOnStartEditor(_htFormData);

		//StartSelectPTObject();
		//if (m_nActivityID != -1) RemoveAllGroups();
		return true;
	}


	private void UpdateDocTypeHashTable()
	{
		try {

			GbDocTypeEditorAS gbDocTypeEditorAS = (GbDocTypeEditorAS) m_asOwner.GetParentSpace();
			GbDocTypeListModel gbDocTypeListModel = (GbDocTypeListModel) gbDocTypeEditorAS.GetModel(GbDocTypeEditorAS.strStorageGbDocTypeList + m_nGbDocTypeModelID);
			IASQueryResult asqrDocTypes = gbDocTypeListModel.GetValidDocumentTypes(m_nGbDocTypeSectionID);
			XPHashtable htDocTypes = gbDocTypeListModel.GetDocTypeMappings(m_nGbDocTypeModelID);
			for (int i = 0; i < asqrDocTypes.GetCount(); i++) {
				int nServerSavedObjID = XPConvert.ToInteger(asqrDocTypes.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
				String strServerSavedObjName = XPConvert.ToString(asqrDocTypes.GetFields(i, PT_PROPIDS.PT_PROPID_NAME));
				if (!htDocTypes.ContainsKey(new Integer(nServerSavedObjID))) {
					gbDocTypeListModel.SetSingleDocTypeIDToNameMapping(strServerSavedObjName, nServerSavedObjID, m_nGbDocTypeModelID);
				}
			}

		} catch (Exception e) {

			
				log.Error("GbDocTypeExtModel " + e);
			

		}


	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GbDocTypeExtModel();
	}

	/**
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		IASQueryResult ptasqrValidDocTypes = null;

		try
		{
			ptasqrValidDocTypes = GetValidDocumentTypes(m_nGbDocTypeSectionID);
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeExtModel : " + e);
			
		}

		boolean bFound = false;

		if (ptasqrValidDocTypes != null)
		{
			PTGrowableSortedArrayWrapper aDocTypeList = ((GbDocTypeExtListModel) m_asOwner.GetModel(GbDocTypeExtEditorAS.strStorageGbDocTypeExtList)).GetItems();
			GbDocTypeExtListModel myGbDocTypeExtModel = (GbDocTypeExtListModel) m_asOwner.GetModel(GbDocTypeExtEditorAS.strStorageGbDocTypeExtList);

			for (int i = 0; i < ptasqrValidDocTypes.GetCount(); i++)
			{
				if (!m_bAdded)
				{
					int nServerSavedObjID = XPConvert.ToInteger(ptasqrValidDocTypes.GetFields(i,
							PT_PROPIDS.PT_PROPID_OBJECTID));

					for (int j = 0; j < aDocTypeList.GetCount(); j++)
					{
						if (!bFound)
						{
							int nArraySavedObjID = XPConvert.ToInteger(aDocTypeList.GetItem(j,
									GbDocTypeExtListModel.EXPLIST_COL_DOCTYPEID));

							if (nArraySavedObjID == nServerSavedObjID)
							{
								bFound = true;
							}
						}
					}

					if (!bFound)
					{
						Object[] oRow = new Object[GbDocTypeListModel.EXPLIST_COL_MAX];
						oRow[GbDocTypeExtListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(myGbDocTypeExtModel.m_nNextIndex);
						myGbDocTypeExtModel.m_nNextIndex++;
						oRow[GbDocTypeExtListModel.EXPLIST_COL_DOCTYPENAME]     = (String) ptasqrValidDocTypes.GetFields(i,
								PT_PROPIDS.PT_PROPID_NAME);
						oRow[GbDocTypeExtListModel.EXPLIST_COL_DOCTYPEID]	    = new Integer(nServerSavedObjID);
						myGbDocTypeExtModel.AddRow(oRow);
						m_strDocTypeName     = (String) ptasqrValidDocTypes.GetFields(i,
								PT_PROPIDS.PT_PROPID_NAME);
						m_bAdded			 = true;
					}

					bFound = false;
				}
			}
		}
	}

	/**
	 *
	 */
	public void Finish()
	{
		// ***CHANGE_HERE*** Copy the code below to lock, sore and unlock the global object.
		try
		{
			Object[][] ptMappings;
			Object[][] oRows = null;
			ptMappings = (Object[][]) ((IPTDocumentTypeMap) super.m_ptGlobalObject).GetMappings(m_nGbDocTypeSectionID);

			if (!m_bEdit)
			{
				// ***CHANGE_HERE*** Put the code here to set the new settings on the Global Object, before you sore it.
				oRows = new Object[2][ptMappings[0].length + 1];

				for (int i = 0; i < ptMappings[0].length; i++)
				{
					oRows[0][i]     = ptMappings[0][i];
					oRows[1][i]     = ptMappings[1][i];
				}

				oRows[0][ptMappings[0].length]     = m_strExtension;
				oRows[1][ptMappings[0].length]     = new Integer(m_nDocTypeID);
				m_nRowIndex						   = ptMappings[0].length;
			}
			else
			{
				oRows = new Object[2][ptMappings[0].length];

				for (int i = 0; i < ptMappings[0].length; i++)
				{
					oRows[0][i]     = ptMappings[0][i];
					oRows[1][i]     = ptMappings[1][i];
				}

				oRows[0][m_nRowIndex]     = m_strExtension;
				oRows[1][m_nRowIndex]     = new Integer(m_nDocTypeID);
			}

			IPTServerContext ptscDocTypeMap;
			ptscDocTypeMap = (IPTServerContext) ((IPTDocumentTypeMap) m_ptGlobalObject).GetInterfaces(
					"IPTServerContext");
			
			
			//only lock this object if editing the global document type map, if editing a crawler doc type map, the doc type object doesn't need to be locked -mgs
			if (GbDocTypeEditorAS.STR_MVC_CLASS_NAME.equals(m_asOwner.GetParentSpace().GetName()))
				ptscDocTypeMap.LockObject();

			((IPTDocumentTypeMap) m_ptGlobalObject).SetMappings(m_nGbDocTypeSectionID,
				oRows);

			if (GbDocTypeEditorAS.STR_MVC_CLASS_NAME.equals(m_asOwner.GetParentSpace().GetName())){
				ptscDocTypeMap.Store();
				ptscDocTypeMap.UnlockObject();
			}
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeExtModel : " + e);
			
		}

		//ResetInputs();
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetDocTypeID()
	{
		return m_nDocTypeID;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetDocTypeName()
	{
		return m_strDocTypeName;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetExtName()
	{
		return m_strExtension;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetIsAdded()
	{
		return m_bAdded;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetIsEdit()
	{
		return m_bEdit;
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetRow()
	{
		return m_nRowIndex;
	}

	/**
	 *
	 *
	 * @param _nSectionID
	 *
	 * @return
	 *
	 * @throws Exception
	 * @throws XPException
	 */
	public IASQueryResult GetValidDocumentTypes(int _nSectionID)
	{
		IPTQueryResult qrDocTypes;

		try
		{
			qrDocTypes = ((IPTDocumentTypeMap) super.m_ptGlobalObject).GetValidDocumentTypes(_nSectionID);
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeModel::GetValidDocumentTypes Unable to get document types from Document Type Map." +
					" The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(347,
					"ptmsgs_portaladminmsgs"), e);
		}

		return (new ASQueryResultWrapper(qrDocTypes));
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	public int SaveMainPage(XPHashtable _htFormData)
	{
		String[] data;

		data = (String[]) _htFormData.GetElement(GbDocTypeExtDP.HTMLHIDDEN_POPUP_NAME);

		if (data != null)
		{
			data = (String[]) _htFormData.GetElement(GbDocTypeExtListView.HTMLRADIOBTN_SELECT);
		}

		if (data != null)
		{
			m_nDocTypeID = XPConvert.ToInteger(data[0]);
		}

		data = (String[]) _htFormData.GetElement(GbDocTypeExtView.HTMLINPUT_CREATE_EXT);

		if (data != null)
		{
			m_strExtension = data[0];
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(GbDocTypeExtDP.STR_MVC_CLASS_NAME))
		{
			// ***EXAMPLE*** Server validation - get back the status from SaveMainPage
			SaveMainPage(_htFormData);

			//} else if (_sPageName.equals(DevicesDP.STR_MVC_CLASS_NAME)) {
			//	nPageStatus = SaveDevicesPage(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 *
	 *
	 * @param _bAdded
	 */
	public void SetAdded(boolean _bAdded)
	{
		m_bAdded = _bAdded;
	}

	/**
	 *
	 *
	 * @param _bEdit
	 */
	public void SetEdit(boolean _bEdit)
	{
		m_bEdit = _bEdit;
	}

	/**
	 *
	 */
	protected void StartGbDocTypeExtList()
	{
		GbDocTypeExtListModel myGbDocTypeExtModel = (GbDocTypeExtListModel) m_asOwner.GetModel(GbDocTypeExtEditorAS.strStorageGbDocTypeExtList);

		// ***CHANGE_HERE SELECTPTOBJECT*** Initialize the Select PTObject list.
		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		myGbDocTypeExtModel.InitializeGbDocTypeExtList(m_asOwner.GetString(
				341, "ptmsgs_portaladminmsgs"),

		m_asOwner.GetString(342, "ptmsgs_portaladminmsgs"),
		PTImageType.ICON_DOCUMENT_TYPE,

		m_asOwner.GetString(343, "ptmsgs_portaladminmsgs"), 1);



		// ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
		//     Use the method bellow to set the icon to display on each row.
		//     (By default there will be no icon.)
		//myGbDocTypeModel.SetRowIcon(PTImageType.ICON_ADD_GROUP);
		IASQueryResult ptasqrValidDocTypes = null;

		try
		{
			ptasqrValidDocTypes = GetValidDocumentTypes(m_nGbDocTypeSectionID);
		}
		catch (Exception e)
		{
			
				log.Error("GbDocTypeExtModel : " + e);
			
		}

		// JF- The 2 lines below are only needed if you are going to enable the move row actions
		if (ptasqrValidDocTypes != null)
		{
			Object[][] oRows = new Object[ptasqrValidDocTypes.GetCount()][GbDocTypeExtListModel.EXPLIST_COL_MAX];

			for (int i = 0; i < ptasqrValidDocTypes.GetCount(); i++)
			{
				oRows[i][GbDocTypeExtListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(myGbDocTypeExtModel.m_nNextIndex);
				myGbDocTypeExtModel.m_nNextIndex++;
				oRows[i][GbDocTypeExtListModel.EXPLIST_COL_DOCTYPENAME]     = (String) ptasqrValidDocTypes.GetFields(i,
						PT_PROPIDS.PT_PROPID_NAME);
				oRows[i][GbDocTypeExtListModel.EXPLIST_COL_DOCTYPEID]	    = ptasqrValidDocTypes.GetFields(i,
						PT_PROPIDS.PT_PROPID_OBJECTID);
			}

			myGbDocTypeExtModel.SetDefaultObjects(oRows);
		}
	}
}

