package com.plumtree.portalpages.admin.editors.filter;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
* @author MikeS
 *
 */
public class FilterModel extends ObjEditorModel implements IFilterModelRO
{
	public static final String STR_MVC_CLASS_NAME = "Filter";
	private FilterIterator m_FilterIterator;
	private XPHashtable m_TestFilterArgs = null;

	/**
	 *
	 *
	 * @param form
	 */
	public void BuildFilterFromForm(XPHashtable form)
	{
    m_ptObject = FilterForm.BuildFilterFromForm(m_asOwner, form, (IPTFilter) m_ptObject);

		// Always make sure our FilterIterator is positioned at the
		// start of the correct filter
		m_FilterIterator.InitFromFilter((IPTFilter) m_ptObject);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	*/
	public Object Create()
	{
		return new FilterModel();
	}

	/**
	 * Code executed after the object is stored.
	 *
	 */
	public void DoTaskAfterStore()
	{
	}

	/**
	 * Code executed before the object is stored.
	 *
	 */
	public void DoTaskBeforeStore()
	{
	}

	/**
	 * Code executed when the Editor is starting.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);

			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

		m_FilterIterator = new FilterIterator(m_Session,
				(IPTFilter) m_ptObject, m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the current filter iterator.
	 * @return the current filter iterator.
	 */
	public IFilterIteratorRO GetFilterIterator()
	{
		return m_FilterIterator;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);
		if (_sPageName.equals(MainDP.STR_MVC_CLASS_NAME))
			BuildFilterFromForm(_htFormData);

		// this block was added to prevent the editor from finishing out if
		// server side validation revealed query construct errors
		String data[] = (String[])_htFormData.GetElement("in_hi_PostToSelf");
		if (null != data && data.length > 0)
		{
			int _action = XPConvert.ToInteger(data[0]);
			if (RepostControl.POSTTOSELF_ACTION_FINISH == _action || RepostControl.POSTTOSELF_ACTION_GOTOPAGE == _action) // we're heading for the finish page
			{
				SettingsView fView = (SettingsView)m_asOwner.GetView(SettingsView.STR_MVC_CLASS_NAME);
				if (fView.QueryContainsValidationProblemsOnRender())
					nPageStatus = RepostControl.PAGE_STATUS_INVALID;
			}
		}

		return nPageStatus;
	} 
	
	public void SetTestFilterArgs(XPHashtable filterArgs)
	{
		m_TestFilterArgs = filterArgs;
	}
	
	public void TurnOffFilterReport()
	{
		m_TestFilterArgs = null;
	}
	
	public XPHashtable GetTestFilterArgs()
	{
		return m_TestFilterArgs;
	}
	
	public static class FilterReport
	{
		public int numResults;
		public boolean threwException;
		public String exceptionMessage;
		public XPException exception;
	}
	
	/* The report is generated by creating a new filter from the control args and running
	 * it as an advanced search. A "PASS" is a search that doesn't throw an exception, i.e.
	 * it may return 0 results and still be a pass.
	 */
	public FilterReport GetTestFilterReport()
	{
		if(m_TestFilterArgs == null)
			return null;
		FilterReport retval = new FilterReport();
		try
		{
			IPTFilter testFilter = FilterForm.BuildFilterFromForm(m_asOwner, m_TestFilterArgs, (IPTFilter) null);
			testFilter.GetDescription();
			IPTSearchRequest req = ((IPTSession)m_asOwner.GetUserSession()).GetSearchRequest();
			IPTSearchQuery q = req.CreateAdvancedQuery(testFilter);
			try
			{
				IPTSearchResponse resp = req.Search(q);
				retval.numResults = resp.GetTotalMatches();
				retval.threwException = false;	

			}
			catch(Exception e)
			{
				SearchExecutionException eprime = SearchUIUtility.GetI18NException(e,m_asOwner);
				if(! SearchUIUtility.ExceptionHiddenInPageSource(eprime))
					throw eprime;
				else 
					throw e;
			}
		}
		catch(Exception e)
		{
			XPException exp = new XPException(e);
			retval.threwException = true;
			retval.exceptionMessage = exp.GetMessage();
			retval.exception = exp;
		}
		return retval;
	}
}

