package com.plumtree.portalpages.admin.editors.filter;


// Framework Imports
import com.plumtree.portalpages.common.search.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
* @author MikeS
 *
 */
public class MainDP extends EditorDP
{

	public static final String STR_MVC_CLASS_NAME = "FilMain";

	/**
	* Displays some HTML after the body tag and before the form tag.
	* For example this is used by pages using a DHTML calendar to display the div tag.
	* The function is optional.  If it exists, it will be called by the framework, and
	* the resulting HTMLElement will be added in the right place.
	*
	* @return HTMLElement
	*/
	public HTMLElementCollection DisplayHTMLBeforeForm()
	{
		return FilterView.GetPagePreFormContent(m_asOwner);
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(377, "ptmsgs_portaladminmsgs"));
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1679, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		HTMLElement report = (m_asOwner.GetView(TestFilterView.STR_MVC_CLASS_NAME)).Display();
		views.AddInnerHTMLElement(report);
				
		views.AddInnerHTMLElement((m_asOwner.GetView(
				SettingsView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 *
	 *
	 * @return
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// ***CHANGE_HERE SELECTPTOBJECT*** Display JavaScripts for the Select PTObject list.
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				SettingsView.STR_MVC_CLASS_NAME).DisplayJavascript());

		myScripts.AddInnerHTMLElement( ConfigHelper.GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSDATEPICKER, GetOwner()) );
		
		return myScripts;
	}
}

