package com.plumtree.portalpages.admin.editors.group;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.treeiterator.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This version of the tree allows for browsing and
 * selecting of objects with no hierarchical structure
 *
 * @author RickyW
 */
public class ActivityRightsTreeModel extends ATreeModel implements ITreeModel,
	ITreeModelRO, IRepostModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.group.ActivityRightsTreeModel");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "ActivityRightsTree";

	// localized strings: internal

	/** localized string: All Activity Rights */

	// localized strings: errors

	/** localized string: Unable to load activity rights tree */

	// member variables

	/** Tree iterator */
	protected IPTTreeIterator m_ptIterator = null;

	/** Storage to keep track of select items **/
	private XPHashtable m_xphtSelected;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ActivityRightsTreeModel();
	}

	/**
	 * This is called when a node is expanded.  Since activity rights
	 * is a flat list, there will be no recursive thoughts here.  This simply
	 * retrieves all the activity rights available to the user and puts it on
	 * the tree as leaf items.
	 *
	 * @param bExpand expands the branch
	 * @param nNodeID the uniqueid for this node
	 */
	public void ExpandNode(boolean bExpand, int nNodeID)
	{
		super.ExpandNode(bExpand, nNodeID);

		// Always expand the dummy title to show all rights
		TreeCompositeNode node = (TreeCompositeNode) m_Root.GetNode(nNodeID);
		node.m_bExpanded = true;

		// Populate with activity rights
		try
		{
			IPTQueryResult ptQRRights = ((IPTSession) m_asOwner.GetUserSession()).
				GetSessionInfo().QueryActivityRights();
				
			TreeLeafNode myLeaf;
						
			if (null != ptQRRights)
			{
				PTSortedArrayWrapper sortedRights;

				// create sort by name.		
				int[][] arrSort = new int[1][2];
				arrSort[0][0] = PT_PROPIDS.PT_PROPID_NAME;
				arrSort[0][1] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
					
				// use helper class to sort data by name.
				sortedRights = new PTSortedArrayWrapper();
				sortedRights.Initialize(ptQRRights.Columns(), ptQRRights.Data(), arrSort, true);
				
				for (int ii = 0; ii < sortedRights.GetCount(); ii ++)
				{
					myLeaf = new TreeLeafNode(GetNextUniqueID());
					myLeaf.SetName(XPConvert.ToString(sortedRights.GetItem(ii, PT_PROPIDS.PT_PROPID_NAME)));
					myLeaf.m_nObjectID = XPConvert.ToInteger(sortedRights.GetItem(ii, PT_PROPIDS.PT_PROPID_OBJECTID));
					myLeaf.m_nClassID = PT_CLASSIDS.PT_ACTIVITY_ID;
					myLeaf.m_Image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ACTIVITY_RIGHT).GetHTMLElement(); 
	
					// determine if the right should be selected
					// by checking against our internal storage 
					if (m_xphtSelected.ContainsKey("" + myLeaf.m_nObjectID))
					{
						myLeaf.m_bSelected = true;
					}
	
					node.AddLeafChild(myLeaf);
				}
			}
			else
			{
				// if there are no rights, then perhaps add a
				// message here.  we have not yet encountered
				// this situation, so this may be unnecessary.				
			}
		}
		catch (Exception ex)
		{
			
				log.Error("ActivityRightsTreeModel::Expand Node Unable to load activity rights tree.  The following exception occured: " +
					ex);
			

			throw new XPException(m_asOwner.GetString(396,
					"ptmsgs_portaladminmsgs"), ex);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		m_xphtSelected = new XPHashtable();
	}

	/**
	 * Initializes and begins the loading of the tree.
	 */
	public void LoadRights()
	{
		// Root is simply a dummy title
		m_Root     = new TreeCompositeNode(GetNextUniqueID());

		m_Root.SetName(m_asOwner.GetString(395, "ptmsgs_portaladminmsgs"));

		if (!m_bShowRoot)
		{
			ExpandNode(true, m_Root.m_nTreeNodeID);
		}
	}

	/**
	 * If there are multiple class ids, determine which
	 * ones to display.  For activity rights, we only
	 * have 1 class id, so this method is unimplemented.
	 *
	 * @param nIDs determines which classids to display
	 */
	public void SetClassIDsToDisplay(int[] nIDs)
	{
		// Activity rights do not need this currently.
	}

	/**
	 * Determines what items in the tree are to be displayed.
	 *
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToDisplay(int[])
	 *
	 * @param nIDs determines which nodes are not hidden.
	 */
	public void SetObjectIDsToDisplay(int[] nIDs)
	{
		// Activity rights do not need this currently.
	}

	/**
	 * Determines what items in the tree are hidden.
	 *
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToHide(int[])
	 *
	 * @param nIDs determines which nodes are hidden
	 */
	public void SetObjectIDsToHide(int[] nIDs)
	{
		// Activity rights do not need this currently.
	}

	/**
	 * Determines what items in the tree are selected.
	 *
	 * @param nIDs determines which nodes are selected
	 */
	public void SetObjectIDsToSelect(int[] nIDs)
	{
		// clear selected list
		m_xphtSelected.Clear();

		// add selected elements to internal list
		for (int ii = 0; ii < nIDs.length; ii++)
		{
			m_xphtSelected.PutElement("" + nIDs[ii], "");
		}
	}
}

