package com.plumtree.portalpages.admin.editors.group;

// Server import
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author 
 */
public class GroupDependenciesView extends ObjDependenciesView
{
	//Member variables
	private CreatedHelper m_chHelper	  = null;


	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "GroupDependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GroupDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (GroupModel) model);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		//Display the standard success message
		m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2204, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());

		SelectActivityRightsModel mySelectActivityRightsModel = ((SelectActivityRightsModel) m_asOwner.GetModel(GroupEditorAS.strStorageSelectActivityRights));

		PTGrowableSortedArrayWrapper arrRights = mySelectActivityRightsModel.GetItems();

		//If there are no activity rights, warn the user and provide a link back to the group editor
		if (null == arrRights || arrRights.GetCount() == 0)
		{
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2205, "ptmsgs_portaladminmsgs"), null);

			m_chHelper.beginList(result);

			String strArgs = null;

			strArgs = strArgs + "&" + ASConstants.PAGE + "=" + GroupActivityRightsDP.STR_MVC_CLASS_NAME;
			
			 
			m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
					PT_CLASSIDS.PT_USERGROUP_ID, null,
					((GroupModel)m_model).GetObjectID(), m_asOwner.GetString(2206, "ptmsgs_portaladminmsgs"), m_asOwner, IPTOpenerConstants.OPENER_MODE_EDIT, strArgs, true));
		}
		else
		{
			//Text: The following rights have been assigned to this group:
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2207, "ptmsgs_portaladminmsgs"), null);
			//Start a list of activity rights
			m_chHelper.beginList(result);

			for (int i=0; i < arrRights.GetCount(); i++)
			{
				m_chHelper.displayListRow((String) arrRights.GetItem(i, SelectActivityRightsModel.EXPLIST_COL_STRING));
			}
		}

		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(
						GroupEditorAS.strStorageMemberSelectPTObject);

		PTGrowableSortedArrayWrapper arrMembers = mySelectPTObjectModel.GetItems();

		//If there are no members, warn the user and provide a link back to the group editor
		if (null == arrMembers || arrMembers.GetCount() == 0)
		{
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2208, "ptmsgs_portaladminmsgs"), null);

			m_chHelper.beginList(result);

			String strArgs = null;
			
			strArgs = strArgs + "&" + ASConstants.PAGE + "=" + GroupMainSettingsDP.STR_MVC_CLASS_NAME;
			

			m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
					PT_CLASSIDS.PT_USERGROUP_ID, null,
					((GroupModel)m_model).GetObjectID(), m_asOwner.GetString(2209, "ptmsgs_portaladminmsgs"), m_asOwner, IPTOpenerConstants.OPENER_MODE_EDIT, strArgs, true));
		}

		return result;
	}
}

