package com.plumtree.portalpages.admin.editors.group;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.selectptobjectsbytype.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Activity Space for Group Objects.  A group is a collection of users and/or
 * other groups.
 * 
 * This activity space has the following pages and views:
 * 	- GroupMainSettingsDP - group memberships page (default page) (left nav)
 * 	 +--> SelectPTObjectView - parent groups
 *   +--> SelectPTObjectView - direct user/group member
 *   +--> SelectPTObjectView - RO, dynamic members
 * 
 *  - GroupDynamicRulesDP - group dynamic memberships page (left nav)
 *   +--> DynamicRulesView - dynamic rules filters
 *   +--> DynamicMembersPreviewView - dynamic members preview button
 * 		- GroupDynamicMembersPreviewPopupDP - the popup display page (preview popup button)
 *       +--> SelectPTObjectView - RO, dynamic members preview
 * 
 *  - GroupActivityRightsDP - group activity rights page (left nav)
 *   +--> SelectActivityRightsView - activity rights
 *   +--> SelectActivityRightsView - inherited rights
 *
 * @author rickyw
 */
public class GroupEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.group.GroupEditorAS");

	/** class name */
	public static final String STR_MVC_CLASS_NAME = "GroupEditor";

	// member variables

	/** Constant for Member SelectIPTObject storage name */
	public static final String strStorageMemberSelectPTObject = "GroupMemberSelectPTObject";
	
	/** Constant for Dynamic Member SelectIPTObject storage name */
	public static final String strStorageDynMemberSelectPTObject = "GroupDynMemberSelectPTObject";
	
	/** Constant for DynamicRulesChooserView storage name */
	public static final String strDynamicRulesChooser = "DynamicRulesChooser";
	
	/** Constant for Dynamic Member Preview Popup SelectIPTObject storage name */
	public static final String strStorageDynMemberPreviewPopup = "GroupDynMemberPreviewPopup";

	/** Constant for Parent Group SelectIPTObject storage name */
	public static final String strStorageParentGroupSelectPTObject = "ParentGroupSelectPTObject";

	/** Constant for Rights SelectActivityRights storage name */
	public static final String strStorageSelectActivityRights = "GroupSelectActivityRights";

	/** Constant for Inherited Rights SelectInheritedRights storage name */
	public static final String strStorageSelectInheritedRights = "GroupSelectInheritedRights";

	private static final String sClassName = "com.plumtree.portalpages.admin.editors.group.GroupEditorAS";

	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GroupEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (GroupDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Gets the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
		{
			return GetString(398, "ptmsgs_portaladminmsgs");
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(2609, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (GroupRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		// SE: logging
		log.FunctionBegin("GroupEditorAS::Init");
		
		// Get and initialize my data model.
		m_strModelName = GroupModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		RegisterPage(new GroupMainSettingsDP());
		RegisterPage(new GroupDynamicRulesDP());
		RegisterPage(new GroupDynamicMembersPreviewPopupDP());
		RegisterPage(new GroupActivityRightsDP());

		// Register Views
		RegisterView(GroupDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(GroupRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Default Page - main settings instead of localized names
		SetCurrentPage(GroupMainSettingsDP.STR_MVC_CLASS_NAME);

		// Register Plug-In: Member SelectPTObjectsByTypeModel
		// (just like SelectPTObject, but displays groups then users)
		RegisterModel(SelectPTObjectsByTypeModel.STR_MVC_CLASS_NAME, strStorageMemberSelectPTObject);
		
		IModel myMemberSelectPTObjectModel = GetModel(strStorageMemberSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageMemberSelectPTObject, myMemberSelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageMemberSelectPTObject, myMemberSelectPTObjectModel);

		// Register Plug-In: Dynamic Member SelectPTObject (RO)
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageDynMemberSelectPTObject);

		IModel myDynMemberSelectPTObjectModel = GetModel(strStorageDynMemberSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageDynMemberSelectPTObject, myDynMemberSelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageDynMemberSelectPTObject, myDynMemberSelectPTObjectModel);

		// Register Plug-In: Parent Group SelectPTObject
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageParentGroupSelectPTObject);

		IModel myParentGroupSelectPTObjectModel = GetModel(strStorageParentGroupSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageParentGroupSelectPTObject, myParentGroupSelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageParentGroupSelectPTObject, myParentGroupSelectPTObjectModel);
		
		// Register Plug-In: Rights SelectList
		RegisterModel(SelectActivityRightsModel.STR_MVC_CLASS_NAME, strStorageSelectActivityRights);

		IModel myRightsActivityRightsSelectModel = GetModel(strStorageSelectActivityRights);
		RegisterView(SelectActivityRightsView.STR_MVC_CLASS_NAME, strStorageSelectActivityRights, myRightsActivityRightsSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectActivityRights, myRightsActivityRightsSelectModel);

		// Register Plug-In: Inherited Rights SelectList
		RegisterModel(SelectActivityRightsModel.STR_MVC_CLASS_NAME, strStorageSelectInheritedRights);

		IModel myInheritedRightsSelectModel = GetModel(strStorageSelectInheritedRights);
		RegisterView(SelectActivityRightsView.STR_MVC_CLASS_NAME, strStorageSelectInheritedRights, myInheritedRightsSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageSelectInheritedRights, myInheritedRightsSelectModel);
		
		// Register Plug-In: Dynamic Rules Chooser
		RegisterView(DynamicRulesView.STR_MVC_CLASS_NAME, myModel);
		
		// Register Plug-In: Dynamic Members Preview Button
		RegisterView(DynamicMembersPreviewView.STR_MVC_CLASS_NAME, myModel);
		
		// Register Plug-In: Dynamic Members Preview SelectPTObject (RO)
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strStorageDynMemberPreviewPopup);

		IModel myDynMemberPreviewModel = GetModel(strStorageDynMemberPreviewPopup);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strStorageDynMemberPreviewPopup, myDynMemberPreviewModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageDynMemberPreviewPopup, myDynMemberPreviewModel);

		// Sets Left-Nav Menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(400, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupMainSettingsDP.STR_MVC_CLASS_NAME);
		// aj: note - the link below is hidden in DoTaskOnStartEditor() when we are dealing with remote groups
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupDynamicRulesDP.STR_MVC_CLASS_NAME);			
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupActivityRightsDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "Standard Settings"
		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1829, "ptmsgs_portaladminmsgs"));


		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);


		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);


		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		((ObjectSecurityModel) GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetLeftNavString(GetString(402, "ptmsgs_portaladminmsgs"));

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass(sClassName);

				int iTitleId        = 36;
				int iTipId          = 37;
				int iSecondaryTipId = 38;

				tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));

				HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId, "ptmsgs_tips"));

				tm.SetTip(e);

				String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");

				if (!("none_do_not_translate".equals(sSecondary)))
				{
					e = new HTMLGenericElement(sSecondary);

					tm.SetSecondarTip(e);
				}
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}

		//	Got the tips model
		// SE: logging
		log.FunctionEnd("GroupEditorAS::Init");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (GroupMainSettingsDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Group_MainSettings");
		}
		else if (GroupActivityRightsDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Group_ActivityRights");
		}
		else if (LocNamesDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_PropertiesandNames");
		}
		else if (ObjectSecurityDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Security");
		}
		else if (MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_MigrationHistoryandStatus");
		} 
		else if (GroupDynamicRulesDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Group_DynamicMembershipRules");
		}
	}
}
