package com.plumtree.portalpages.admin.editors.group;

// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 *
 */
public class GroupMainSettingsDP extends EditorDP {
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.group.GroupMainSettingsDP");
		
	/** class name */
	public static final String STR_MVC_CLASS_NAME = "GroupMainDP";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return m_asOwner.GetString(2519, "ptmsgs_portaladminmsgs");
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		// aj: the sub header should be different for remote groups vs. normal ones
		if(((IGroupModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).IsRemoteGroup())
		{
			return HTMLConstructHelpers.GetSubHeader(
					m_asOwner.GetString(2709, "ptmsgs_portaladminmsgs"),
					this.m_asOwner);
		} else {
			return HTMLConstructHelpers.GetSubHeader(
				m_asOwner.GetString(1663, "ptmsgs_portaladminmsgs"),
				this.m_asOwner);
		}
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay() {
		// SE: logging
		log.FunctionBegin("GroupMainSettingDP::PageDisplay");
		
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());
		
		result.AddInnerHTMLElement(ExpListView.GetHiddenInputsForPagination());

		HTMLElementCollection views = new HTMLElementCollection();
		
		// The Everyone group contains all the users in the portal.  The memberships cannot be edited.
		if (((IGroupModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetObjectID()  == 
			PT_INTRINSICS.PT_USERGROUP_EVERYONE)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER,
				null,
				m_asOwner.GetString(2676, "ptmsgs_portaladminmsgs"),
				"");
			
			myError.SetTitle("");
			myError.SetActivitySpace(m_asOwner.GetName());
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),m_asOwner.GetApplication());
		}

		// display parent group select ptobject
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(GroupEditorAS.strStorageParentGroupSelectPTObject))
				.Display());					

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// display member select ptobject
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(GroupEditorAS.strStorageMemberSelectPTObject))
				.Display());
		
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// display dynamic member select ptobject
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(GroupEditorAS.strStorageDynMemberSelectPTObject))
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		// SE: logging
		log.FunctionEnd("GroupMainSettingDP::PageDisplay");
		
		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// Display JavaScripts for the members PTObject list.
		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(GroupEditorAS.strStorageMemberSelectPTObject)
				.DisplayJavascript());

		// Display JavaScripts for the dynamic members PTObject list.
		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(GroupEditorAS.strStorageDynMemberSelectPTObject)
				.DisplayJavascript());
		
		// Display JavaScripts for the parent groups PTObject list.
		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(GroupEditorAS.strStorageParentGroupSelectPTObject)
				.DisplayJavascript());
				
		myScripts.AddInnerHTMLElement(ExpListView.GetJavaScriptsForPagination(m_asOwner));

		return myScripts;
	}
}

