package com.plumtree.portalpages.admin.editors.group;


// Foundation Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is the implementation of the Expandable List
 * framework for the the Select List.
 * The Select List is a list of objects.
 * New objects can be added to the list by selecting
 * them from the associated Object tree.
 * The list is by default sorted by name ascending.
 *
 * @author RickyW
 */
public class SelectActivityRightsModel extends ExpListModel
	implements ISelectActivityRightsModelRO
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SelectActivityRights";

	/**
	 * Key name used by the Activity Space to store the tree. */
	public static final String SUBSPACE_NAME_SELECTTREE = "SelectActivityRightsTree";

	/**
	 * Number total of columns */
	public static final int EXPLIST_COL_MAX = 4;

	/**
	 * This column contains the Object Class IDs.
	 */
	public static final int EXPLIST_COL_CLASSID = 1;

	/**
	 * This column contains the Object IDs.
	 */
	public static final int EXPLIST_COL_OBJECTID = 2;

	/**
	 * This is the String that we doisplay in the list.
	 * E.g.: Object name or folder path.
	 */
	public static final int EXPLIST_COL_STRING = 3;

	/**
	 * Default initial size for the sorted array.
	 */
	public static final int EXPLIST_DEFAULT_INITIAL_SIZE = 50;

	/**
	 * Is this instance for inherited rights?  Defaults to no.
	 */
	protected boolean m_bIsInherited;

	/**
	 * Icon to display on each row, just before the input text. */
	protected PTImageType m_imgRowIcon;

	/**
	 * Tree Space ID. The first time the ID is empty and a new AS is opened,
	 * but after that, we save the ID and the same tree AS is reopened each time. */
	protected String m_sTreeSpaceID = "";

	/**
	 * Class ID of the Objects displayed on the list. */
	protected int[] m_arrObjectClassIDs;

	/**
	 * Clear the list and add all the values from the tree.
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		SaveTreeID(_htFormData);

		ActivityRightsTreeAS asTree = (ActivityRightsTreeAS) m_asOwner.GetSubSpace(GetUniqueString(
					SUBSPACE_NAME_SELECTTREE));

		if (null != asTree)
		{
			ITreeModelRO myTree    = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected = myTree.GetSelectedItems();
			Object[] oNewRow;

			// JF- We clear the array before we start adding the selected items from the tree.
			super.GetItems().ClearArray();

			for (int i = 0; i < mySelected.GetSize(); i++)
			{
				oNewRow										  = new Object[EXPLIST_COL_MAX];
				oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
				m_nNextIndex++;
				oNewRow[EXPLIST_COL_CLASSID]	  = new Integer(((TreeLeafNode) mySelected.GetElement(
							i)).m_nClassID);
				oNewRow[EXPLIST_COL_OBJECTID]     = new Integer(((TreeLeafNode) mySelected.GetElement(
							i)).m_nObjectID);
				oNewRow[EXPLIST_COL_STRING]		  = ((TreeLeafNode) mySelected.GetElement(i)).GetName();

				super.GetItems().AddRow(oNewRow);
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectActivityRightsModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the array of Class ID of the Objects
	 * displayed on the list as a String.
	 * E.g.: "2,45,3"
	 *
	 * This is the format used by the tree.
	 *
	 * @return String
	 */
	public String GetObjectClassIDs()
	{
		String sClassIDs = "";

		// JF- We loop through the array of IDs and add each ID 
		// to the String.
		for (int i = 0; i < m_arrObjectClassIDs.length; i++)
		{
			if (0 != sClassIDs.length())
			{
				sClassIDs += ",";
			}

			sClassIDs += (XPConvert.ToString(m_arrObjectClassIDs[i]));
		}

		return sClassIDs;
	}

	/**
	 * Returns the icon to display on each row before the
	 * input text.
	 * If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgRowIcon;
	}

	/**
	 * Returns a String of Activity Right Object IDs.
	 * E. g.: "ObjID1, objID2, objID3, etc"
	 *
	 * This is the format used by this tree.
	 *
	 * @return String
	 */
	public String GetSelectedItems()
	{
		String sSelectedItems = "";

		// RW - loop through array and add object id to string
		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			// JS- Add the separator
			if (0 != sSelectedItems.length())
			{
				sSelectedItems += ",";
			}

			sSelectedItems += m_saData.GetItem(i, EXPLIST_COL_OBJECTID);
		}

		return sSelectedItems;
	}

	/**
	 * Returns tree AS ID.
	 *
	 * @return String
	 */
	public String GetTreeSpaceID()
	{
		return m_sTreeSpaceID;
	}

	/**
	 * Returns whether this list is inherited rights.
	 *
	 * @return boolean
	 */
	public boolean GetIsInherited()
	{
		return m_bIsInherited;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _arrObjectClassIDs Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 * @param _bIsInherited are we dealing with inherited rights.
	 */
	public void InitializeSelectList(String _sSectionTitle,
		String _sSectionSubTitle, PTImageType _imgAddIcon, String _sAddLabel,
		int[] _arrObjectClassIDs, int _nListKey, boolean _bIsInherited)
	{
		Object[][] arrExpListColInfo = new Object[1][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_STRING);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = new Boolean(!_bIsInherited);

		m_arrObjectClassIDs = _arrObjectClassIDs;

		m_bIsInherited = _bIsInherited;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
				EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING
			};

		// JF- Sort array
		// The growable array will always be sorted by the String column (the one displayed).
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_STRING;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null bellow)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true,
			EXPLIST_DEFAULT_INITIAL_SIZE);
	}

	/**
	 * Add the array passed in argument to the list.
	 * The array should be created using the EXPLIST_COL
	 * constants defined in this class.
	 *
	 * @param _arrRows Array of rows to add.
	 */
	public void SetDefaultObjects(Object[][] _arrRows)
	{
		super.GetItems().AddRows(_arrRows);
	}

	/**
	 * Because this select list needs to support both move
	 * row actions enable and disable, we need to change the
	 * colspan of the header row when this happens.
	 *
	 * @param _bEnableMoveRowActions
	 */
	public void SetEnableMoveRowActions(boolean _bEnableMoveRowActions)
	{
		super.SetEnableMoveRowActions(_bEnableMoveRowActions);

		if (m_bEnableMoveRowActions)
		{
			// JF- If the move row actions are enabled, this will 
			// create one more cell at the end of each row and 
			// we need to reflect that change on the header row.
			m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "2";
		}
		else
		{
			m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
		}
	}

	/**
	 * Sets the icon to display on each row before the
	 * input text.
	 * By default, no icon is displayed.
	 *
	 * @param _imgRowIcon
	 */
	public void SetRowIcon(PTImageType _imgRowIcon)
	{
		m_imgRowIcon = _imgRowIcon;
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		// JF- Nothing to save on repost.
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Helper method to save the Tree ID on repost.
	 *
	 * @param _htFormData Form data
	 */
	protected void SaveTreeID(XPHashtable _htFormData)
	{
		// JF- We save the tree ID only if we don't already have it.
		if (("").equals(m_sTreeSpaceID) &&
				_htFormData.ContainsKey(GetUniqueString(
						SelectActivityRightsView.HTMLINPUT_TREEASID)))
		{
			String[] data = (String[]) _htFormData.GetElement(GetUniqueString(
						SelectActivityRightsView.HTMLINPUT_TREEASID));

			if ((null != data) && !(0 == data.length))
			{
				m_sTreeSpaceID = data[0];
			}
		}
	}
}

