package com.plumtree.portalpages.admin.editors.group;


// Foundation Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Select List list.
 * Is constains the HTML to display the object Array.
 * It gets the data to display from SelectActivityRightsModel.
 *
 * @author RickyW
 */
public class SelectActivityRightsView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.group.SelectActivityRightsView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SelectActivityRights";

	/**
	 * HTML Object names */
	public static final String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";

	/** Localized String: Select Activity Rights */



	/** Localized String: Select Activity Rights */



	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectActivityRightsView();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		// The URL to open a new tree
		ASURL myNewTree = new ASURL(m_asOwner);

		// Tree creation and binding
		myNewTree.SetLinkCreateNewSpace(ActivityRightsTreeAS.STR_MVC_CLASS_NAME,
			m_asOwner);
		myNewTree.SetSubSpaceKey(((ISelectActivityRightsModelRO) m_model).GetUniqueString(
				SelectActivityRightsModel.SUBSPACE_NAME_SELECTTREE));
		myNewTree.SetControl(ActivityRightsStartTreeControl.STR_MVC_CLASS_NAME);

		// Tree configuration
		myNewTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
		myNewTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		myNewTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
			((ISelectActivityRightsModelRO) m_model).GetUniqueString(
				HTMLINPUT_TREEASID));
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
			((ISelectActivityRightsModelRO) m_model).GetUniqueString(
				"OnReturnFromTree"));
		myNewTree.AddControlArgument(AStartTreeControl.CLASS_IDS_TO_DISPLAY,
			((ISelectActivityRightsModelRO) m_model).GetObjectClassIDs());
		myNewTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
		myNewTree.AddControlArgument(ActivityRightsStartTreeControl.SELECTED_ITEMS,
			((ISelectActivityRightsModelRO) m_model).GetSelectedItems());


		myNewTree.AddControlArgument(AStartTreeControl.TITLE,
			m_asOwner.GetString(425, "ptmsgs_portaladminmsgs"));
			
		// set the subtitle display string

		myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(1832, "ptmsgs_portaladminmsgs"));	
			
		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		ASURL myOldTree = new ASURL(m_asOwner);
		myOldTree.SetLinkCreateNewSpace(ActivityRightsTreeAS.STR_MVC_CLASS_NAME,
			m_asOwner);

		XPStringBuilder sb;

		try
		{
			// Open Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function " +
				((ISelectActivityRightsModelRO) m_model).GetUniqueString(
					"OpenTree") + "(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(myNewTree.GetURLAsString())
			.Append("', '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			// On return from Tree function
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((ISelectActivityRightsModelRO) m_model).GetUniqueString(
					"OnReturnFromTree") + "()");
			sb.Append(" {");
			sb.Append(" 	postToSelf('" +
				((ISelectActivityRightsModelRO) m_model).GetUniqueInt(
					ExpListControl.POSTTOSELF_ACTION_ADD) + "');");
			sb.Append(" }");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "SelectActivityRightsView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		result.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// row icon
		PTImageType imgRowIcon = ((ISelectActivityRightsModelRO) m_model).GetRowIcon();

		if (null != imgRowIcon)
		{
			myCell.AddInnerHTMLElement(GetIcon(imgRowIcon));
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}

		// Object Name
		Object oListName = _saData.GetItem(_nRowIndex,
				SelectActivityRightsModel.EXPLIST_COL_STRING);

		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode((String) oListName));

		if (((ISelectActivityRightsModelRO) m_model).GetEnableMoveRowActions())
		{
			result.AddInnerHTMLElement(super.GetHTMLForMoveRowActions(
					_nRowIndex));
		}

		return result;
	}

	/***/
	/**
	 */
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the space below the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		if (((ISelectActivityRightsModelRO) m_model).GetIsInherited())
		{
			// this is a inherited rights list
			// we want to display some messages

			HTMLTable myTable;
			HTMLTableRow myRow;
			HTMLTableCell myCell;
	
			myTable = new HTMLTable();
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// add a spacer			
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myTable.AddInnerHTMLElement(myRow);

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");

			// need to determine if there are any items
			IPTGrowableSortedArrayWrapperRO saData = ((IExpListModelRO) m_model).GetReadOnlyItems();
			if (0 == saData.GetCount())
			{
				// if list is empty use this empty list string
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				myCell.AddInnerHTMLString(m_asOwner.GetString(2167, "ptmsgs_portaladminmsgs"));
			}
			else
			{
				// list is not empty, use this description string
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				myCell.AddInnerHTMLString(m_asOwner.GetString(2166, "ptmsgs_portaladminmsgs"));
			}
		
			return myTable;
		}
		else
		{
			// not a inherited rights list
			// proceed as normal
			
			return null;
		}
	}
	
	/**
	 * Returns the HTML for the add cell in the action bar.
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;
		HTMLInput myInput;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
				true, this.m_asOwner);
		myAddIcon		    = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");
		
		// Object icon
		myConstruct     = UIConstructFactory.GetConstruct(((ISelectActivityRightsModelRO) m_model).GetAddIcon(),
				true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(((ISelectActivityRightsModelRO) m_model).GetUniqueString(
					"OpenTree") + "(document." + AFormDP.HTMLFORM_NAME + "." +
					((ISelectActivityRightsModelRO) m_model).GetUniqueString(
					HTMLINPUT_TREEASID) + "); return false;");

		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(((ISelectActivityRightsModelRO) m_model).GetAddLabel());
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
		myCell.AddInnerHTMLString(SPACE);

		// hidden input with the tree space ID
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				((ISelectActivityRightsModelRO) m_model).GetUniqueString(
					HTMLINPUT_TREEASID), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((ISelectActivityRightsModelRO) m_model).GetTreeSpaceID());

		return myCell;
	}

	/**
	 * Helper method to get the HTML for the icon.
	 * (Each row has an icon before the input text.)
	 *
	 * @return HTMLImg
	 * @throws Exception
	 */
	protected HTMLImg GetIcon(PTImageType _imgRowIcon)
	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct     = UIConstructFactory.GetConstruct(_imgRowIcon, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		return (myImage);
	}
}

