package com.plumtree.portalpages.admin.editors.invitation;

//Server import
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.sendinvitation.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author 
 */
public class InvitationDependenciesView extends ObjDependenciesView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.invitation.InvitationDependenciesView");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "InvitationDependencies";
	
	/** Send Invitation javascript function name */
	public static final String JAVASCRIPT_SEND_INVITATION = "sendInvitation";

	//Member variables
	private CreatedHelper m_chHelper	  = null;


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new InvitationDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Adds javascript for creating or adding to jobs
	 *
	 * @return
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		try
		{
			ASURL sendInvitationURL = new ASURL(m_asOwner);
			sendInvitationURL.SetLinkCreateNewSpace(SendInvitationAS.STR_MVC_CLASS_NAME,
				m_asOwner.GetParentSpace());
			sendInvitationURL.SetControl(InvCodesListControl.STR_MVC_CLASS_NAME);

			// This must be the last argument so we can append the profile ID
			sendInvitationURL.AddControlArgument(InvCodesListModel.CONTROLARGUMENT_OBJECTID,((ObjEditorModel) m_model).GetObjectID());

			XPStringBuilder sb = new XPStringBuilder(500);
			// Send an invitation function
			sb.Append("function ").Append(JAVASCRIPT_SEND_INVITATION).Append("()\n");
			sb.Append("{\n");
			sb.Append("    window.close();");
			sb.Append("    window.opener.location = '").Append
				(sendInvitationURL.GetURLAsString()).Append("'").Append(";\n");
			sb.Append("}\n");
			
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "CrawlerDependenciesView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (InvitationModel) model);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			//Display the standard success message
			m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2210, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());
	
			//Display the sync user target folder
			IPTInvitation myInvite = (IPTInvitation) ((ObjEditorModel) m_model).GetObject();
			int intUserFolderID = myInvite.GetUserFolderID();
			IPTSession mySession = (IPTSession) m_asOwner.GetUserSession();
			
			// get the name
			IPTAdminFolder myFolder = mySession.GetAdminCatalog().OpenAdminFolder(intUserFolderID, false);
			String strName = myFolder.GetLocalizedName();
			
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2211, "ptmsgs_portaladminmsgs") + strName, null);
			//Display the folder for users
			m_chHelper.beginList(result);
			
			//Display the send invitation link
			m_chHelper.displayListRowAnchor(result, m_asOwner.GetString(2212, "ptmsgs_portaladminmsgs"), JAVASCRIPT_SEND_INVITATION + "()");

		}
		catch (Exception e)
		{
			//Report the error
		}
		 
		return result;
	}
}

