package com.plumtree.portalpages.admin.editors.job;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;

/**
 *
 * @version $Revision$
 * @author $author$
 */
public interface IJobModelRO extends IObjEditorModelRO
{
	/**
	 * Returns Continue on errors setting.
	 *
	 * @return int
	 */
	public int GetContinue();

	/**
	 * Returns Log Level setting.
	 *
	 * @return int
	 */
	public int GetLogLevel();

	/**
	 * Returns Array of Operations.
	 *
	 * @return PTGrowableSortedArrayWrapper
	 */
	public PTGrowableSortedArrayWrapper GetOperations();

	/**
	 * Returns Recurrence Interval setting.  For example
	 * this job will run every N minutes, where N is the recurrence interval.
	 *
	 * @return int
	 */
	public int GetRecurrenceInterval();

	/**
	 * Returns Restrictions setting. (0 = none (default), 1 = No Weekday, 2 =
	 * No weekend)
	 *
	 * @return int
	 */
	public int GetRestrictions();

	/**
	 * Returns Schedule Type setting. 0=NEVER, 1=ONCE, >1=PERIODICALLY.  Valid
	 * values are:
	 * PT_SCHEDULETYPE_NEVER = 0 PT_SCHEDULETYPE_ONCE = 1
	 * PT_SCHEDULETYPE_MINUTELY = 2 PT_SCHEDULETYPE_HOURLY = 3
	 * PT_SCHEDULETYPE_DAILY = 4 PT_SCHEDULETYPE_WEEKLY = 5
	 * PT_SCHEDULETYPE_MONTHLY = 6 PT_SCHEDULETYPE_ANNUALLY = 7
	 *
	 * @return int
	 */
	public int GetScheduleType();

	/**
	 * Returns Suspend Checkpoint Interval setting.
	 *
	 * @return int
	 */
	public int GetSuspendCheckpointInterval();

	/**
	 * Returns Suspend Mode setting:  One of PT_SCHEDULE_SUSPEND_MODES:
	 * PT_SCHEDULE_WORK_CONTINUOUSLY (Default),
	 * PT_SCHEDULE_SUSPEND_ON, PT_SCHEDULE_WORK_ON
	 * @return int
	 */
	public int GetSuspendMode();

	/**
	 * Returns timeout setting.
	 *
	 * @return int
	 */
	public int GetTimeout();

	/**
	 * Returns timeout units setting.
	 *
	 * @return int
	 */
	public int GetTimeoutUnits();

	/**
	 * Returns true if the Add an Operation table on the Main DP should not be
	 * displayed.
	 *
	 * @return boolean
	 */
	public boolean IsAddOperationDisabled();

	/**
	 * @return XPLocale
	 */
	public XPLocale GetLocale();

	/**
	 * @return XPTimeZone
	 */
	public XPTimeZone GetTimezone();

	/**
	 * Returns the format pattern for the current locale so that it can be passed into
	 * the date picker control
	 *
	 * @return String
	 */
	public String GetDateFormatPattern();

	/**
	 * Get the Date Time picker control manager
	 *
	 * @return JSDateTimePickerMgr
	 */
	public JSDateTimePickerMgr GetDateTimePickerControlManager();

	/**
	 * Get the Date Time for the RunOnceNow option
	 *
	 * @return XPDateTime
	 */
	public XPDateTime GetRunOnceNowDateTime();

	/**
	 * Returns whether the Folder containing this Job is assigned to any Automation Server
	 *
	 * @return boolean
	 */
	public boolean IsJobFolderRegistered();
}

