package com.plumtree.portalpages.admin.editors.job;

//Server import
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author 
 */
public class JobDependenciesView extends ObjDependenciesView
{
	//Member variables
	private CreatedHelper m_chHelper	  = null;
	

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "JobDependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (JobModel) model);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		//Display the standard success message
		m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2110, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());
				
		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(
						JobEditorAS.m_strStorageSelectPTObject);

		PTGrowableSortedArrayWrapper arrOperations = mySelectPTObjectModel.GetItems();

		if ( !(m_asOwner.IsSubSpace()) )
		{
			//If there are no operations, warn the user and provide a link back to the job editor
			if ( (null == arrOperations) || (arrOperations.GetCount() == 0) )
			{
				m_chHelper.displayTextRow(result, m_asOwner.GetString(2112, "ptmsgs_portaladminmsgs"), null);
	
				m_chHelper.beginList(result);
	
				m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
						PT_CLASSIDS.PT_JOB_ID, null,
						((JobModel)m_model).GetObjectID(), m_asOwner.GetString(2113, "ptmsgs_portaladminmsgs"), m_asOwner, IPTOpenerConstants.OPENER_MODE_EDIT, null, true));
			}
			else
			{
				//Text: This job will display the following operations:
				m_chHelper.displayTextRow(result, m_asOwner.GetString(2111, "ptmsgs_portaladminmsgs"), null);
				//Start a list of operations
				m_chHelper.beginList(result);
	
				for (int i=0; i < arrOperations.GetCount(); i++)
				{
					m_chHelper.displayListRow((String) arrOperations.GetItem(i, SelectPTObjectModel.EXPLIST_COL_STRING));
				}
			}
		}
		
		int intScheduledStatus = ((IJobModelRO) m_model).GetScheduleType();
		
		if (PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER == intScheduledStatus)
		{
			//Inform the user and display the edit link
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2114, "ptmsgs_portaladminmsgs"), null);
			
			m_chHelper.beginList(result);

			m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
					PT_CLASSIDS.PT_JOB_ID, null,
					((JobModel)m_model).GetObjectID(), m_asOwner.GetString(2115, "ptmsgs_portaladminmsgs"), m_asOwner, IPTOpenerConstants.OPENER_MODE_EDIT, null, true));
		}
		else
		{
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2116, "ptmsgs_portaladminmsgs"), null);
			
			XPStringBuilder sb = new XPStringBuilder(100);
			
			if (intScheduledStatus == JobModel.SCHEDULE_TYPE_RUN_ONCE_NOW)
			{
				XPDateTime xpRunOnceNow = ((IJobModelRO) m_model).GetRunOnceNowDateTime();

				if (xpRunOnceNow != null)
				{
					XPDateFormat xpdf = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM, XPDateFormat.MEDIUM);
					String strRunOnceNow = xpdf.Format(xpRunOnceNow);
					sb.Append(m_asOwner.GetString(2126, "ptmsgs_portaladminmsgs")).Append(" ").Append(m_asOwner.GetString(2118, "ptmsgs_portaladminmsgs")).Append(" ").Append(strRunOnceNow);
				}
			}
			else if (intScheduledStatus == PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE)
			{
				JSDateTimePicker ptDateTimePicker = (JSDateTimePicker) ((IJobModelRO) m_model).GetDateTimePickerControlManager().GetComponent("DTP_RunOnce");
				if (ptDateTimePicker.GetDateTimeAsString() != null)
				{
					sb.Append(m_asOwner.GetString(2126, "ptmsgs_portaladminmsgs")).Append(" ").Append(m_asOwner.GetString(2118, "ptmsgs_portaladminmsgs")).Append(" ").Append(ptDateTimePicker.GetDateTimeAsString());
				}
			}
			else
			{
				JSDateTimePicker ptDateTimePicker = (JSDateTimePicker) ((IJobModelRO) m_model).GetDateTimePickerControlManager().GetComponent("DTP_NextRun");
				if (ptDateTimePicker.GetDateTimeAsString() != null)
				{
					sb.Append(m_asOwner.GetString(2117, "ptmsgs_portaladminmsgs")).Append(" ").Append(((IJobModelRO) m_model).GetRecurrenceInterval()).Append(" ").Append(StringFromPTScheduleType(intScheduledStatus)).Append(" ").Append(m_asOwner.GetString(2118, "ptmsgs_portaladminmsgs")).Append(" ").Append(ptDateTimePicker.GetDateTimeAsString());
				}
			}
			m_chHelper.displayTextRow(result, -1, sb.ToString(),
				null);
		}
		
		//Display the standard warning if everyone has access to this object
		m_chHelper.displayEmptyRow(result);
		m_chHelper.displayEveryoneWarning(result, (JobModel) m_model, m_asOwner.GetString(2110, "ptmsgs_portaladminmsgs"));

		IPTScheduler myScheduler = ((IPTSession) m_asOwner.GetUserSession()).GetScheduler();
		ASQueryResultWrapper myQueryResultWrapper = new ASQueryResultWrapper(myScheduler.QueryJobAssignmentsByFolder(((ObjEditorModel) m_model).GetFolderID()));
		
		if ( (null == myQueryResultWrapper) || (myQueryResultWrapper.GetCount() < 1) )
		{
			m_chHelper.displayEmptyRow(result);
			//Let the user know that the job's folder hasn't been registered to a job server
			m_chHelper.displayTextRow(result, m_asOwner.GetString(2127, "ptmsgs_portaladminmsgs"), null);
		}
				
		return result;
	}
	
	/**
	 * This helper function translates PTSCHEDULETYPES units into strings.
	 */
	private String StringFromPTScheduleType(int nScheduleType) 
	{
		switch (nScheduleType) 
		{
			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY :
				return m_asOwner.GetString(2119, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY :
				return m_asOwner.GetString(2121, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY :
				return m_asOwner.GetString(2120, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY :
				return m_asOwner.GetString(2122, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY :
				return m_asOwner.GetString(2123, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_ANNUALY :
				return m_asOwner.GetString(2124, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER :
				return m_asOwner.GetString(2125, "ptmsgs_portaladminmsgs");

			case PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE :
				return m_asOwner.GetString(2126, "ptmsgs_portaladminmsgs");

			default :
				return "";
		}
	}

}

