package com.plumtree.portalpages.admin.editors.job;

// UI Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register the Model and Display Pages
 * created for the Job Editor.
 * This class can also be used to get any of those objects back with
 * the class name.  The Operation Section is implemented with an expandable
 * list, and therefore doesn't have a corresponding view class.
 */
public class JobEditorAS extends ObjEditorAS {
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.job.JobEditorAS");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "JobEditor";

	/** A constant for the Select PTObject storage name */
	public static final String m_strStorageSelectPTObject = "SelectPTObjectJob";

	/** The class name for the tip writer */
	private static final String sClassName = "com.plumtree.portalpages.admin.editors.job.JobEditorAS";

	/** Unique identifier for the Run Once date picker */
	public static final String RUN_ONCE_DATEPICKER = "DTP_RunOnce";

	/** Unique identifier for the Run Once date picker */
	public static final String NEXT_RUN_DATEPICKER = "DTP_NextRun";

	/** Unique identifier for the Run Once date picker */
	public static final String NOT_AFTER_DATEPICKER = "DTP_NotAfter";

	/** Unique identifier for the suspend begin time picker */
	public static final String SUSPEND_BEGIN_TIMEPICKER = "TP_Begin";

	/** Unique identifier for the suspend end time picker */
	public static final String SUSPEND_END_TIMEPICKER = "TP_End";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() {
		return new JobEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName() {
		return (JobDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Sets the Editor title.
	 *
	 */
	public String GetEditorTitle() {
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType()) {
			return (GetString(458, "ptmsgs_portaladminmsgs"));
		} else {
			return (XPResourceManager.FormatMessage(GetString(2619, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName() {
		return (JobRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init() {
		m_strModelName = JobModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		MainDP jobMainDP = new MainDP();

		RegisterView(JobDependenciesView.STR_MVC_CLASS_NAME, myModel);

		RegisterPage(jobMainDP);
		jobMainDP.AddToValidationFunction("WarnFolderRegistered");

		RegisterPage(new HistoryDP());

		//Register the classes from the joblogs package
		RegisterModel(JobLogModel.STR_MVC_CLASS_NAME);

		IModel myJobLogModel = GetModel(JobLogModel.STR_MVC_CLASS_NAME);
		RegisterView(HistoryView.STR_MVC_CLASS_NAME, myJobLogModel);
		RegisterControl(JobLogRepostControl.STR_MVC_CLASS_NAME, myJobLogModel);

		// Register Views
		// Register the select PTObject list as a plug-in section
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, m_strStorageSelectPTObject);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPTObjectModel = GetModel(m_strStorageSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, m_strStorageSelectPTObject, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, m_strStorageSelectPTObject, mySelectPTObjectModel);

		//RegisterView(OperationView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(TimeoutView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ScheduleView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(LoggingView.STR_MVC_CLASS_NAME, myModel);

		// Job Log Download Page -- this needs to be registered after
		// the Job Log Model.
		RegisterPage(new JobLogDownloadDP());

		// Register Controls
		RegisterControl(JobRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Default page
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "Main Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(460, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, HistoryDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1839, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null) {
			try {

				tm.SetGeneratingClass(sClassName);

				int iTitleId = 42;
				int iTipId = 43;
				int iSecondaryTipId = 44;

				tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));

				HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId, "ptmsgs_tips"));

				tm.SetTip(e);

				String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");

				if (!("none_do_not_translate".equals(sSecondary))) {

					e = new HTMLGenericElement(sSecondary);

					tm.SetSecondarTip(e);
				}

			} catch (Exception ex) {
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		//	Got the tips model
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 * Sets the help links for the job editor
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page) {
		super.SetCurrentPage(page);
		String sPageName = page.GetName();

		if (MainDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Job_MainSettings");
		} else if (HistoryDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Job_JobHistory");
		}
	}
}

