package com.plumtree.portalpages.admin.editors.job;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section represents a section of the Main Settings page
 * of the Job Editor.
 * This Section is printed out by MainDP.
 *
 * @author JohnH
 */
public class LoggingView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.job.LoggingView");


	public static final String STR_MVC_CLASS_NAME = "JobLogging";

	// HTML Object names.
	public static final String HTMLSELECT_LEVEL			    = "in_se_Level";


	public static final String HTMLCHECKBOX_SAVECHECKPOINTS = "in_cb_Checkpoints";


	public static final String HTMLINPUT_CHECKPOINTMINUTES = "in_tx_CheckpointMinutes";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LoggingView();
	}

	/**
	 * This method Displays the HTML for the Logging Section on the Main Settings
	 * page of the Job Editor.
	 *
	 * @author JohnH
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;
		HTMLSelect mySelect;
		HTMLOption myOption;
		int intLogLevel;

		try
		{

				log.Info("Entering LoggingView::Display");


			HTMLComment myComment = new HTMLComment( "Begin: Display LoggingView");
			result.AddInnerHTMLElement(myComment);

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						492, "ptmsgs_portaladminmsgs")));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// 1st Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(493,
					"ptmsgs_portaladminmsgs"));

			//Add a table cell for the drop-down
			myCell = new HTMLTableCell();
			myCell.SetWidth("100%");
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			//Add the new select item
			mySelect = new HTMLSelect(HTMLSELECT_LEVEL, HTMLSELECT_LEVEL);
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			//Get the value from the model
			intLogLevel     = ((IJobModelRO) m_model).GetLogLevel();

			//Add the first option
			myOption = new HTMLOption(m_asOwner.GetString(494,
						"ptmsgs_portaladminmsgs"));
			myOption.SetValue("0"); //PT_LOGLEVELS.PT_LOG_SILENT

			if (0 == intLogLevel)
			{
				myOption.SetSelected(true);
			}

			mySpan = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(494,
					"ptmsgs_portaladminmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			//Add the second option
			myOption = new HTMLOption(m_asOwner.GetString(495,
						"ptmsgs_portaladminmsgs"));
			myOption.SetValue("1"); //PT_LOGLEVELS.PT_LOG_LOW

			if (1 == intLogLevel)
			{
				myOption.SetSelected(true);
			}

			mySpan = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(495,
					"ptmsgs_portaladminmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			//Add the third option
			myOption = new HTMLOption(m_asOwner.GetString(496,
						"ptmsgs_portaladminmsgs"));
			myOption.SetValue("2"); //PT_LOGLEVELS.PT_LOG_NORMAL

			if (2 == intLogLevel)
			{
				myOption.SetSelected(true);
			}

			mySpan = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(496,
					"ptmsgs_portaladminmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			//Add the fourth option
			myOption = new HTMLOption(m_asOwner.GetString(497,
						"ptmsgs_portaladminmsgs"));
			myOption.SetValue("3"); //PT_LOGLEVELS.PT_LOG_VERBOSE

			if (3 == intLogLevel)
			{
				myOption.SetSelected(true);
			}

			mySpan = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(497,
					"ptmsgs_portaladminmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			//Add the select box to the cell
			myCell.AddInnerHTMLElement(mySelect);

			//Second Row - Save Checkpoints checkbox
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			//First Cell - the checkbox
			myCell = new HTMLTableCell();
			myCell.SetColSpan("2");
			myCell.SetWidth("100%");
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_SAVECHECKPOINTS, "");

			if (0 != ((IJobModelRO) m_model).GetSuspendCheckpointInterval())
			{
				myInput.SetChecked(true);
			}
			else
			{
				myInput.SetChecked(false);
			}

			myCell.AddInnerHTMLElement(myInput);

			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			myCell.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(499,
					"ptmsgs_portaladminmsgs"));

			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			//Minute input box
			myInput = new HTMLInput(HTMLInputTypes.TEXT,
					HTMLINPUT_CHECKPOINTMINUTES,
					m_asOwner.GetString(500, "ptmsgs_portaladminmsgs"));

			//Set the default not after date
			myInput.SetValue(XPConvert.ToString(
					((IJobModelRO) m_model).GetSuspendCheckpointInterval()));
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetSize(3);
			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			myCell.AddInnerHTMLString(m_asOwner.GetString(500,
					"ptmsgs_portaladminmsgs"));

			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_ITALIC_TEXT);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(2710,
			"ptmsgs_portaladminmsgs"));


			// 1st Row end
			myComment = new HTMLComment( "End: Display LoggingView");
			result.AddInnerHTMLElement(myComment);

		}
		catch (Exception e)
		{

				log.Error(e, "LoggingView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());


			throw new XPException(m_asOwner.GetString(498,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

