package com.plumtree.portalpages.admin.editors.job;


// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The main display page for the job editor
 *
 * @author JohnH
 */
public class MainDP extends EditorDP
{
	/** The unique identifier for this display page */
	public static final String STR_MVC_CLASS_NAME = "JobMain";

	private static final String ui_DatePickerFailed = "Unable to retrieve the date picker javascript construct.  Please validate that your image server is installed correctly.";

	/**
	 * Displays some HTML after the body tag and before the form tag.
	 * For example this is used by pages using a DHTML calendar to display the div tag.
	 * The function is optional.  If it exists, it will be called by the framework, and
	 * the resulting HTMLElement will be added in the right place.
	 *
	 * @return HTMLElement
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm()
	{
		HTMLElementCollection myHTMLBeforeForm = null;

		try
		{
			//Display the DIV tag required for the Date picker control
			IJobModelRO ptROModel = (IJobModelRO) m_asOwner.GetModel(JobModel.STR_MVC_CLASS_NAME);
			myHTMLBeforeForm = ptROModel.GetDateTimePickerControlManager().GetPagePreFormContent();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.WARNING,
						UIErrorScope.CURRENT_USER,
						null,
						ui_DatePickerFailed,
						"");

			myError.SetActivitySpace(m_asOwner.GetName());

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),m_asOwner.GetApplication());
		}

		return myHTMLBeforeForm;
	}

	/**
	 * Returns the HTML that is placed in the HEAD section of this HTML page.
	 *
	 * @return HTMLElement
	 */
	public HTMLElementCollection DisplayHTMLinHEAD()
	{
		HTMLElementCollection retVal = new HTMLElementCollection();

		try
		{
			IJobModelRO ptROModel = (IJobModelRO) m_asOwner.GetModel(JobModel.STR_MVC_CLASS_NAME);
			JSDateTimePickerMgr ptDatePickerMgr = ptROModel.GetDateTimePickerControlManager();
			retVal.AddInnerHTMLElement(ptDatePickerMgr.GetJSIncludes());
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.WARNING,
						UIErrorScope.CURRENT_USER,
						null,
						ui_DatePickerFailed,
						"");

			myError.SetActivitySpace(m_asOwner.GetName());

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),m_asOwner.GetApplication());
		}
		
		//Get access to the PTDate.js file for formatting date strings
		retVal.AddInnerHTMLElement( ConfigHelper.GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSUTIL, GetOwner()) );
		
		return retVal;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(501, "ptmsgs_portaladminmsgs"));
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() throws HTMLException {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1681, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		//Warn the user if the job is currently locked (and the editor is in readonly mode)
		if ( ((IJobModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetIsEditorReadOnly() )
		{
			UIError myError = new UIError(UIErrorLevel.WARNING,
						UIErrorScope.CURRENT_USER,
						null,
						m_asOwner.GetString(1846, "ptmsgs_portaladminmsgs"),
						"");

			myError.SetActivitySpace(m_asOwner.GetName());

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),m_asOwner.GetApplication());
		}

		if (!((IJobModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).IsAddOperationDisabled())
		{
			// Display the Operations list.
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
					JobEditorAS.m_strStorageSelectPTObject)).Display());

			views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		}

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				ScheduleView.STR_MVC_CLASS_NAME)).Display());

		//views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				TimeoutView.STR_MVC_CLASS_NAME)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				LoggingView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				ScheduleView.STR_MVC_CLASS_NAME).DisplayJavascript());

		if (!((IJobModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).IsAddOperationDisabled())
		{
			myScripts.AddInnerHTMLElement(m_asOwner.GetView(
					JobEditorAS.m_strStorageSelectPTObject).DisplayJavascript());
		}

		return myScripts;
	}
}