package com.plumtree.portalpages.admin.editors.job;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section represents a section of the Main Settings page  of the Job Editor.
 * This Section is printed out by MainDP.
 *
 * @author JohnH
 */
public class TimeoutView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.job.TimeoutView");

	/** The name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "JobTimeout";

	/** Ignore errors checkbox */
	public static final String HTMLCHECKBOX_IGNORE = "in_cb_Ignore";

	/** Timeout duration text box */
	public static final String HTMLINPUT_TIMEOUT_DURATION = "in_tx_Duration";

	/** Timeout units */
	public static final String HTMLSELECT_TIMEOUT_UNITS = "in_se_Units";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new TimeoutView();
	}

	/**
	 * This method Displays the HTML for the Timeout Section on the Main Settings
	 * page of the Job Editor.
	 *
	 * @return
	 * @throws XPException
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		//PTDurationCombo myDurationCombo;
		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display TimeoutView");
			result.AddInnerHTMLElement(myComment);

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			//Spacer row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetHeight("3");
			myRow.AddInnerHTMLElement(myCell);

			// 1st Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			//First cell the set timeout text
			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);


			mySpan.AddInnerHTMLString(m_asOwner.GetString(526,
					"ptmsgs_portaladminmsgs"));

			//Second cell - Timeout period for the job
			myCell = new HTMLTableCell();
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nAvailableUnits = PTDurationCombo.DISPLAYHOURS |
				PTDurationCombo.DISPLAYMINUTES;

			if (0 != ((IJobModelRO) m_model).GetTimeout())
			{
				myCell.AddInnerHTMLElement(PTDurationCombo.GetDurationCombo(
						HTMLINPUT_TIMEOUT_DURATION, HTMLSELECT_TIMEOUT_UNITS,
						nAvailableUnits,
						XPConvert.ToString( ((IJobModelRO) m_model).GetTimeout() ),
						((IJobModelRO) m_model).GetTimeoutUnits(), m_asOwner));
			}
			else
			{
				myCell.AddInnerHTMLElement(PTDurationCombo.GetDurationCombo(
						HTMLINPUT_TIMEOUT_DURATION, HTMLSELECT_TIMEOUT_UNITS,
						nAvailableUnits, "", 0, m_asOwner));
			}

			// 1st Row end
			// 2nd Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			//First Cell - The checkbox
			myCell = new HTMLTableCell();
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_IGNORE, "");

			myInput.SetValue("1");

			if (1 == ((IJobModelRO) m_model).GetContinue())
			{
				myInput.SetChecked(true);
			}
			else
			{
				myInput.SetChecked(false);
			}

			myCell.AddInnerHTMLElement(myInput);

			//Second cell - the text
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);


			mySpan.AddInnerHTMLString(m_asOwner.GetString(527,
					"ptmsgs_portaladminmsgs"));


			// 2nd Row end
			myComment = new HTMLComment( "End: Display TimeoutView");
			result.AddInnerHTMLElement(myComment);

		}
		catch (Exception e)
		{
			
				log.Error(e, "TimeoutView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			


			throw new XPException(m_asOwner.GetString(528,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

