package com.plumtree.portalpages.admin.editors.lockbox;

import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

public class LockboxEditorLocNamesDP extends EditorDP
{
	/** The name of this object */
	public static final String STR_MVC_CLASS_NAME = "LockboxEditorLocNames";

	/** Flag used to update mandatory page status only the first time the left nav string is retrieved */
	protected boolean bFirstTimeOnPage = true;

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		// Update mandatory page status the first time left nav string is retrieved.
		UpdateMandatoryPageStatus();

		IObjPropModelRO objPropModel = (IObjPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);

		if (objPropModel.CheckObjectSupportsEOD())
		{
			return m_asOwner.GetString(2909, "ptmsgs_portaladminmsgs");
		}
		else
		{
			return m_asOwner.GetString(0, "ptmsgs_portalinfrastructure");
		}
	}

	/**
	 * Dynamically update mandatory page ststua. In this case, we check the object properties
	 * model to see if it contains any mandatory properties.
	 */
	public void UpdateMandatoryPageStatus()
	{
		if (bFirstTimeOnPage)
		{
			IObjPropModelRO objPropModel = (IObjPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);
			boolean bPageIsMandatory = objPropModel.CheckDisplayPageIsMandatory();
	
			((EditorAS) m_asOwner).GetLeftMenu().SetMandatoryPage(bPageIsMandatory, GetName());
			
			bFirstTimeOnPage = false;
		}
	}

	/**
	 * Implement this method to add HTML below the sub header.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	protected HTMLElement GetHTMLBelowSubHeader() throws HTMLException
	{
		return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2910, "ptmsgs_portaladminmsgs"), this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * The date-picker needs to print some stuff before the form.
	 *
	 * @return HTMLElementCollection
	 *
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLBeforeForm()
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm() throws HTMLException
	{
		IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);

		return iModelRO.GetDateTimePickerControlManager().GetPagePreFormContent();
	}

	/**
	 * Returns the HTML that is placed in the HEAD section of this HTML page.
	 * Add date picker HTML in head.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLinHEAD()
	 */
	public HTMLElementCollection DisplayHTMLinHEAD() throws HTMLException
	{
		IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(ObjPropModel.STR_MVC_CLASS_NAME);

		return iModelRO.GetDateTimePickerControlManager().GetJSIncludes();
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 * @throws HTMLException on error
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay() throws HTMLException
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		//MES- Add the primary name/desc
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME)).Display());

		//MES- Add the list of languages we're localized into, IF we support localization AND we're localized!
		ILocNamesModelRO locNamesModel = (ILocNamesModelRO) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);

		if (locNamesModel.SupportsLocalization() && locNamesModel.GetIsLocalized())
		{
			views.AddInnerHTMLElement(new HTMLBr());
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME)).Display());
		}

		//Add a space
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(LockboxEditorPropertiesView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild() throws HTMLException
	{
		HTMLScriptCollection scripts = super.DisplayJavaScriptFromChild();

		scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME).DisplayJavascript());

		//MES- Add the JavaScript for the list of languages we're localized into, IF we support localization!
		ILocNamesModelRO model = (ILocNamesModelRO) m_asOwner.GetModel(LocNamesModel.STR_MVC_CLASS_NAME);

		if (model.GetIsLocalized())
		{
			scripts.AddInnerHTMLElement(m_asOwner.GetView(LocNamesView.STR_MVC_CLASS_NAME).DisplayJavascript());
		}

		scripts.AddInnerHTMLElement(m_asOwner.GetView(LockboxEditorPropertiesView.STR_MVC_CLASS_NAME).DisplayJavascript());
//		scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_KEYWORDS).DisplayJavascript());

		return scripts;
	}
}

