package com.plumtree.portalpages.admin.editors.page;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.template.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class PageEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.page.PageEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "PageEditor";
	
	/** Page Template List Plugin */
	public static final String PLUGIN_PAGE_TEMPLATE_LIST = "PageTemplateList";

	/** Layout table top */
	public static final int LAYOUTTABLE_TOP = 175;

	/** Layout table left */
	public static final int LAYOUTTABLE_LEFT = 259;

	private static final String sClassName = "com.plumtree.portalpages.admin.editors.page.PageEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PageEditorAS();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(2718, "ptmsgs_portaladminmsgs");
		}
		return (XPResourceManager.FormatMessage(GetString(2719, "ptmsgs_portaladminmsgs"), GetObjectName()));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (PageDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (PageRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = PageEditorModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		PageMainDP myMainPage = new PageMainDP();
		myMainPage.AddToValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
		RegisterPage(myMainPage);
		log.Info("PageEditorAS::Constructor: Register display pages succesful");

		// Register Views
		RegisterView(PageDependenciesView.STR_MVC_CLASS_NAME, myModel);
		log.Info("PageEditorAS::Constructor: Register views succesful");

		// Register Controls
		RegisterControl(PageRepostControl.STR_MVC_CLASS_NAME, myModel);
		log.Info("PageEditorAS::Constructor: Register controls succesful");

		// Set default page
		SetCurrentPage(PageMainDP.STR_MVC_CLASS_NAME);

		// Register common sections
		//      Register each Section/Model for your plug-in sections
		RegisterModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
		IModel myPageLayoutModel = GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
		RegisterView(PageLayoutView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterView(PageLayoutHeaderView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterView(PageLayoutAlternateView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterControl(PageLayoutControl.STR_MVC_CLASS_NAME, myPageLayoutModel);

		// Register the community template selector as a plug-in section
		RegisterModel(PageTemplateListModel.STR_MVC_CLASS_NAME, PLUGIN_PAGE_TEMPLATE_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myPageTemplateListModel = GetModel(PLUGIN_PAGE_TEMPLATE_LIST);
		RegisterView(TemplateListView.STR_MVC_CLASS_NAME, PLUGIN_PAGE_TEMPLATE_LIST,
			myPageTemplateListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_PAGE_TEMPLATE_LIST, myPageTemplateListModel);

		//Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(2723, "ptmsgs_portaladminmsgs"));
		// Main Settings
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PageMainDP.STR_MVC_CLASS_NAME);
		// END Sub menu "General Settings"

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(2724, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );

				int iTitleId = 144;
				int iTipId = 145;
				int iSecondaryTipId = 146;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );
				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );
				tm.SetTip( e );
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
					e = new HTMLGenericElement( sSecondary );
					tm.SetSecondarTip( e );
				}
			}
			catch (Exception ex)
			{
					log.Error(ex, "Couldn't generate tip.");
			}
		}
		 //	Got the tips model
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if( PageMainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Page_MainSettings" );
		}
	}
	
	/**
	 * Adjust the number of pixels for the drag and drop
	 * based on the language of the user.
	 * 
	 * @param asOwner
	 * @return int
	 */
	public static int GetLayoutTableTop(AActivitySpace asOwner)
	{
		String strLang = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue
					(PersonalSettingsHelper.LANGUAGE, asOwner));
	
		int nLayoutTop = LAYOUTTABLE_TOP;
	
		if(strLang.equals("ja")) {
			nLayoutTop += 9;
		} else if (strLang.equals("zh")) {
			nLayoutTop += 9;	
		} else if (strLang.equals("ko")) {
			nLayoutTop += 4;
		} else if (strLang.equals("fr")) {
			nLayoutTop += 2;
		} else if (strLang.equals("de")) {
			nLayoutTop += 2;
		} else if (strLang.equals("en")) {
			nLayoutTop += 0;
		} else if (strLang.equals("it")) {
			nLayoutTop += 0;
		} else if (strLang.equals("pt")) {
			nLayoutTop += 0;
		} else if (strLang.equals("es")) {
			nLayoutTop += 0;
		}
		
		// DCA - check if the page is going to print any errors, adjust the layout position
		if (((ErrorModel) asOwner.
			GetModel(ErrorModel.STR_MVC_CLASS_NAME)).GetErrors().MoveNext()) {
			nLayoutTop += 40;			
		}
		
		if ( !((IPageEditorModelRO)asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetIsMyPage() )
		{
			nLayoutTop += 95;
		}
		
		if ( ((IPageEditorModelRO)asOwner.GetModel(PageEditorModel.STR_MVC_CLASS_NAME)).GetIsDefaultProfileMyPage() )
		{
			nLayoutTop += 12;
		}
		
		return nLayoutTop;
	}
}
