package com.plumtree.portalpages.admin.editors.pagetemplate;

import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class PageTemplateDefaultPageNameDP extends EditorDP
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "PageTemplateDefaultPageName";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(2725, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Implement this method to add HTML below the sub header.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	protected HTMLElement GetHTMLBelowSubHeader() throws HTMLException
	{
		return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(2726, "ptmsgs_portaladminmsgs"), this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 * @throws HTMLException on error
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay() throws HTMLException
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		//MES- Add the primary name/desc
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_PRIMARY_NAME_VIEW)).Display());

		//MES- Add the list of languages we're localized into, IF we support localization AND we're localized!
		ILocNamesModelRO locNamesModel = (ILocNamesModelRO) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME);

		if (locNamesModel.SupportsLocalization() && locNamesModel.GetIsLocalized())
		{
			views.AddInnerHTMLElement(new HTMLBr());
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME_VIEW)).Display());
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild() throws HTMLException
	{
		HTMLScriptCollection scripts = super.DisplayJavaScriptFromChild();

		scripts.AddInnerHTMLElement(m_asOwner.GetView(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_PRIMARY_NAME_VIEW).DisplayJavascript());

		//MES- Add the JavaScript for the list of languages we're localized into, IF we support localization!
		ILocNamesModelRO model = (ILocNamesModelRO) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME);

		if (model.GetIsLocalized())
		{
			scripts.AddInnerHTMLElement(m_asOwner.GetView(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME_VIEW).DisplayJavascript());
		}

		return scripts;
	}
}
