package com.plumtree.portalpages.admin.editors.pagetemplate;


// Plumtree Server Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.inherit.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 * @author michaeld
 */
public class PageTemplateEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.pagetemplate.PageTemplateEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "PageTemplateEditor";

	/** SelectPTObject Model for communities that use the template */
	public static final String PLUGIN_PAGES = "PagesList";

	/** Plug in Key: DefaultPageName */
	public static final String PLUGIN_DEFAULT_PAGE_NAME = "DefaultPageName";
	
	/** Plug in Key: DefaultPageNameView */
	public static final String PLUGIN_DEFAULT_PAGE_NAME_VIEW = "DefaultPageNameView";

	/** Plug in Key: DefaultPagePrimaryNameView */
	public static final String PLUGIN_DEFAULT_PAGE_PRIMARY_NAME_VIEW = "DefaultPagePrimaryNameView";

	/** Plug in Key: DefaultPagePopupNameView */
	public static final String PLUGIN_DEFAULT_PAGE_NAME_POPUP_VIEW = "DefaultPagePopupNameView";

	private static final String sClassName = "com.plumtree.portalpages.admin.editors.pagetemplate.PageTemplateEditorAS";

	/** Layout table top */
	public static final int LAYOUTTABLE_TOP = 175;

	/** Layout table left */
	public static final int LAYOUTTABLE_LEFT = 259;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PageTemplateEditorAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return String strEditorTitle
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(549, "ptmsgs_portaladminmsgs");
		}
		return (XPResourceManager.FormatMessage(GetString(2611, "ptmsgs_portaladminmsgs"), GetObjectName()));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (PageTemplateDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (PageTemplateRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = PageTemplateModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		PageTemplateMainDP myMainPage = new PageTemplateMainDP();
		myMainPage.AddToValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
		RegisterPage(myMainPage);
		PageTemplateDefaultPageNameDP myDefaultPageNamePage = new PageTemplateDefaultPageNameDP();
		myDefaultPageNamePage.AddToValidationFunction(LocNamesPrimaryNameView.VALIDATION_FUNC_NAME);
		RegisterPage(myDefaultPageNamePage);
		RegisterPage(new DefaultPageNamePopUpDP());
		log.Info("PageTemplateEditorAS::Constructor: Register display pages succesful");

		// MJD- Register classes for the localize default page names page
		RegisterModel(LocNamesModel.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME);
		RegisterView(LocNamesView.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME_VIEW,
			GetModel(PLUGIN_DEFAULT_PAGE_NAME));
		RegisterView(LocNamesPrimaryNameView.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_PRIMARY_NAME_VIEW,
			GetModel(PLUGIN_DEFAULT_PAGE_NAME));
		RegisterView(LocNamesPopUpView.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME_POPUP_VIEW,
			GetModel(PLUGIN_DEFAULT_PAGE_NAME));
		RegisterControl(LocNamesRepostControl.STR_MVC_CLASS_NAME, PLUGIN_DEFAULT_PAGE_NAME,
			GetModel(PLUGIN_DEFAULT_PAGE_NAME));

		// Register Views
		RegisterView(PageTemplateDependenciesView.STR_MVC_CLASS_NAME, myModel);
		log.Info("PageTemplateEditorAS::Constructor: Register views succesful");

		// Register Controls
		RegisterControl(PageTemplateRepostControl.STR_MVC_CLASS_NAME, myModel);
		log.Info("PageTemplateEditorAS::Constructor: Register controls succesful");

		// Set default page
		SetCurrentPage(PageTemplateMainDP.STR_MVC_CLASS_NAME);

		// Register common sections
		//      Register each Section/Model for your plug-in sections
		RegisterModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
		IModel myPageLayoutModel = GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
		RegisterView(PageLayoutView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterView(PageLayoutHeaderView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterView(PageLayoutAlternateView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterControl(PageLayoutControl.STR_MVC_CLASS_NAME, myPageLayoutModel);
		
		RegisterPage(new PageTemplatePagesDP());

		// Register the select PTObject list as a plug-in section
		RegisterModel(InheritListModel.STR_MVC_CLASS_NAME,
			PLUGIN_PAGES);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myPagesModel = GetModel(PLUGIN_PAGES);
		RegisterView(CommunitiesListView.STR_MVC_CLASS_NAME,
			PLUGIN_PAGES, myPagesModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_PAGES, myPagesModel);

		//Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(552, "ptmsgs_portaladminmsgs"));
		// Main Settings
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PageTemplateMainDP.STR_MVC_CLASS_NAME);
		// Default Page Name
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PageTemplateDefaultPageNameDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PageTemplatePagesDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1847, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				tm.SetGeneratingClass( sClassName );


				int iTitleId = 45;
				int iTipId = 46;
				int iSecondaryTipId = 47;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if( PageTemplateMainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_PageTemplate_MainSettings" );
		}
		else if( PageTemplateDefaultPageNameDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_PageTemplate_DefaultPageName" );
		}
	}
	
	/**
	 * Adjust the number of pixels for the drag and drop
	 * based on the language of the user.
	 * 
	 * @param asOwner
	 * @return int
	 */
	public static int GetLayoutTableTop(AActivitySpace asOwner)
	{
		String strLang = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue
					(PersonalSettingsHelper.LANGUAGE, asOwner));
	
		int nLayoutTop = LAYOUTTABLE_TOP;
	
		if(strLang.equals("ja"))
		{
			nLayoutTop += 9;
		} 
		else if (strLang.equals("zh"))
		{
			nLayoutTop += 9;	
		}
		else if (strLang.equals("ko"))
		{
			nLayoutTop += 4;
		}
		else if (strLang.equals("fr"))
		{
			nLayoutTop += 2;
		}
		else if (strLang.equals("de"))
		{
			nLayoutTop += 2;
		}
		else if (strLang.equals("en"))
		{
			nLayoutTop += 0;
		}
		else if (strLang.equals("it"))
		{
			nLayoutTop += 0;
		}
		else if (strLang.equals("pt"))
		{
			nLayoutTop += 0;
		}
		else if (strLang.equals("es"))
		{
			nLayoutTop += 0;
		}
		
		// DCA - check if the page is going to print any errors, adjust the layout position
		// TODO-MJD : this doesn't work.
		if (((ErrorModel) asOwner.
			GetModel(ErrorModel.STR_MVC_CLASS_NAME)).GetErrors().MoveNext()) {
			nLayoutTop += 40;			
		}
		return nLayoutTop;
	}
}

