package com.plumtree.portalpages.admin.editors.pagetemplate;


// Framework Imports
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 * @author MichaelD
 */
public class PageTemplateMainDP extends EditorDP
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "PageTemplateMain";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(558, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1682, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay()

	{		
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		//      This is where you print out the plug-in view.
		// This will add some empty space between the two views
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).Display());

		if (! ((IPageLayoutModelRO)m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout() )
		{
			views.AddInnerHTMLElement(m_asOwner.GetView(
			PageLayoutAlternateView.STR_MVC_CLASS_NAME).Display());
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * This is a helper method that all classes that inherit from PlumtreeDP need
	 * to implement.  The method should add whatever HTML the child class wants to
	 * use the DisplayJavaScript and add it to the head.
	 *
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#DisplayJavaScriptFromChild()
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection result = super.DisplayJavaScriptFromChild();

		if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != ((PageTemplateModel) m_asOwner.GetModel(
					PageTemplateModel.STR_MVC_CLASS_NAME)).GetObjectID())
		{
			result.AddInnerHTMLElement(m_asOwner.GetView(PageLayoutHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());

			if ( ((IPageLayoutModelRO)m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout() )
			{
				// DCA - We're going to use the drag and drop layout, set the layout table position
				((PageLayoutView) m_asOwner.GetView(PageLayoutView.STR_MVC_CLASS_NAME)).SetLayoutTablePosition(PageTemplateEditorAS.GetLayoutTableTop(m_asOwner),
						PageTemplateEditorAS.LAYOUTTABLE_LEFT);
							
				result.AddInnerHTMLElement(((PageLayoutView) m_asOwner.GetView(
				PageLayoutView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
			}
			else
			{
				result.AddInnerHTMLElement(((PageLayoutAlternateView)m_asOwner.GetView(
				PageLayoutAlternateView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection());
			}
		}
		else
		{
			HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			myScript.AddInnerHTMLString("\n" + "function " + PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT + "()\n" +
				"{\n" + "	return true;\n" + "};\n");
			result.AddInnerHTMLElement(myScript);
		}

		return result;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLAfterForm()
	 */
	public HTMLElementCollection DisplayHTMLAfterForm()
	{
		HTMLElementCollection collection = new HTMLElementCollection();
		if ( ((IPageLayoutModelRO)m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetUseDragDropLayout() )
		{
			HTMLTable myTable = new HTMLTable();
			myTable.SetOnSelectStart("return false");
			collection.AddInnerHTMLElement(myTable);
			myTable.SetCellPadding(CommonHTMLStrings.ZERO);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			HTMLTableRow myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			HTMLTableCell myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.AddInnerHTMLElement(m_asOwner.GetView(
			PageLayoutView.STR_MVC_CLASS_NAME).Display());
		}
		collection.AddInnerHTMLElement(super.DisplayHTMLAfterForm());

		return collection;
	}

}

