package com.plumtree.portalpages.admin.editors.pagetemplate;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.inherit.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.interpreter.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 *
 * @author michaeld
 */
public class PageTemplateModel extends ObjEditorModel
	implements IObjEditorModelRO
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "PageTemplate";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PageTemplateModel();
	}

	/** Run Page Type Job after store */
	private boolean m_bRunPageTypeJob = false;

	/**
	 * Code executed after the object is stored.
	 */
	public void DoTaskAfterStore()
	{
		if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != m_nObjectID)
		{
			int[][] annPortletOrder = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetColumnOrder();

			for (int i = PortletColumnConstants.NARROW_ONE.ToInt();
					i <= PortletColumnConstants.NARROW_TWO.ToInt(); i++)
			{
				((IPTPageTemplate) m_ptObject).AssignGadgetsEx(annPortletOrder[i],
					i);
			}

			int nFreeFormID = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).FreeFormToBeRemove();
			if ( nFreeFormID != -1 )
			{
				((IPTPageTemplate) m_ptObject).RemoveGadget(nFreeFormID);
			}
			if ( ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetHasFreeFormPortlet() )
			{
				try {
					((IPTPageTemplate) m_ptObject).AddGadgetEx(
						((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetFreeFormPortletID(), -1 );
				} catch (Exception e) {	// DCA - already added freeform gadget
					// DCA - Don't really have to do anything
				}
			}

			if ( m_bRunPageTypeJob )
			{
				((IPTScheduledOperation) ((IPTPageTemplate) m_ptObject)).ScheduleImmediateJob();
			}
		}
	}

	/**
	 * Initializes IPTProperty with the property type member  variable just
	 * before we store the object in the DB. Also sets 2 other values to
	 * default.
	 */
	public void DoTaskBeforeStore()
	{
		if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != m_nObjectID)
		{
			// Get the settings back from the plug-in Model and sets them on the Object before the Framework stores it.
			// Set page type
			int nPageType = ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetPageType();

			if (nPageType != ((IPTPageTemplate) m_ptObject).GetPageType())
			{
				((IPTPageTemplate) m_ptObject).SetPageType(nPageType);

				if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
				{
					// Run job for each page that uses this page template to change its page type
					//  and move its gadgets to the correct column.
					((IPTPageTemplate) m_ptObject).SetJobType(PT_PAGE_TEMPLATE_JOB_TYPES.PT_PAGE_TEMPLATE_JOB_PROPAGATE_PAGETYPE);

					m_bRunPageTypeJob = true;
				}
			}
		}

		((LocNamesModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME)).Finish();
	}

	/**
	 * Initializes the property type member variable with  the one from
	 * IPTProperty in Edit mode and the default  value in create mode.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		int nTableHeight;
		IASQueryResult ptqrPortlets = null;

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			ASQueryResultWrapper qrw = new ASQueryResultWrapper(((IPTPageTemplate) m_ptObject).QueryGadgets());
			ptqrPortlets = qrw;
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(false,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
		}
		else
		{
			// MJD - This is the default default page name
			((IPTPageTemplate)m_ptObject).SetDefaultPageName(m_asOwner.GetString(559,
					"ptmsgs_portaladminmsgs"));

			// MJD - This is the default page type.
			// BT: Use default portlet layout if portlet layouts are enabled.
			if ( LayoutService.getChooserInstance().GetPortletLayoutsEnabled(m_asOwner) )
			{
				// adaptive layout stores a negative value in the page type (negative value of a webservice layout id)
				((IPTPageTemplate)m_ptObject).SetPageType(-PT_INTRINSICS.PT_WEBSERVICE_DEFAULT_PORTLET_LAYOUT);				
			}
			else
			{
				((IPTPageTemplate)m_ptObject).SetPageType(PageTypeConstants.TWO_COLUMN_NARROW_WIDE);				
			}
			
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

		BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
		if ( browser.IsNetscape4() )
		{
			nTableHeight = 800;
		}
		else
		{
			nTableHeight = 400;
		}

		((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetOpenerClassID(PT_CLASSIDS.PT_PAGETEMPLATE_ID);
		((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetOpenerObjectID(m_nObjectID);
		((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SetAllowFreeFormSection(true);
		((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).
			InitializePlugIn((IPTPageTemplate)m_ptObject, nTableHeight, ptqrPortlets, m_Session);
		
		StartDefaultPageNamesList();
		StartPages();
	}

	// END ***************** helper methods *****************

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerClassID()
	 */
	public int GetOpenerClassID()
	{
		return PT_CLASSIDS.PT_PAGETEMPLATE_ID;
	}

	/**
	 * @see com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerCommunityID()
	 */
	public int GetOpenerCommunityID()
	{
		return -1;
	}

	/**
	 * @see com.plumtree.portalpages.common.editpage.IPageLayoutModelRO#GetOpenerObjectID()
	 */
	public int GetOpenerObjectID()
	{
		return m_nObjectID;
	}

	/**
	 * Gets the selected gadget ids as an int array.
	 *
	 * @return int[] anPortletID
	 */
	public XPSortedDictionary GetSelectedPortlets()
	{
		return ((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetSelectedPortlets();
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(PageTemplateMainDP.STR_MVC_CLASS_NAME))
		{
			if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID != m_nObjectID)
			{
				((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
			}
		}
		else if (_sPageName.equals(PageTemplateDefaultPageNameDP.STR_MVC_CLASS_NAME))
		{
			((LocNamesModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME)).SaveSection(_htFormData);
		}

		return nPageStatus;
	}
	
	/**
	 * Helper method to start the localized names  and description list.
	 */
	public void StartDefaultPageNamesList()
	{
		LocNamesModel model = ((LocNamesModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_DEFAULT_PAGE_NAME));
		model.InitializeNameDescEditor(((IPTPageTemplate)m_ptObject).GetDefaultPageLocalizable(), 21);
		model.SetIsNoDescriptions(true);
		model.SetPopUpDisplayPageName(DefaultPageNamePopUpDP.STR_MVC_CLASS_NAME);
		model.SetNameLabel(m_asOwner.GetString(2728, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Helper method to start the Pages List.
	 *
	 */
	private void StartPages()
	{
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			InheritListModel inheritModel = ((InheritListModel) m_asOwner.GetModel(PageTemplateEditorAS.PLUGIN_PAGES));
	
			inheritModel.InitializeInheritList(
				m_asOwner.GetString(3052, ResourceConstants.PORTALADMINMSGS),
				PT_CLASSIDS.PT_PAGE_ID, 67);
			
			inheritModel.SetEmptyListMessages(
				m_asOwner.GetString(3053, ResourceConstants.PORTALADMINMSGS),
				"");
	
			//     Use the method bellow to set the icon to display on each row.
			//     (By default there will be no icon.)
			// TODO-MJD : need new icon
			inheritModel.SetDefaultRowIcon(PTImageType.ICON_MYPAGE);
	
			// Add inherited pages.
			inheritModel.SetDefaultObjects(
				m_Session, 
				PT_CLASSIDS.PT_PAGE_ID, 
				m_nObjectID,
				PT_PROPIDS.PT_PROPID_PAGES_PAGETEMPLATEID,
				PT_PROPIDS.PT_PROPID_PAGES_INHERITPAGETEMPLATE);
		}
		else
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				PageTemplatePagesDP.STR_MVC_CLASS_NAME);
		}
	}
}

