/**
 * Created on Dec 6, 2002 by adolfoc
 */
package com.plumtree.portalpages.admin.editors.portlet;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc 
 * 
 * This class is used to automatically identify and display the
 * appropriate views based on the list of views in the PortletData
 * This should help avoid mistakes with forgetting to display
 * javascript and missing spacers, etc.
 */
public abstract class PPluginDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.portlet.PPluginDP");

	/**
	 * Returns the name of the Help Topic to be used for this
	 * page.
	 * @return
	 */
	public abstract String GetPluginHelpTopic();
	
	/**
	 * Returns an ordered list of the views for this page, in this mode.
	 */
	public abstract XPArrayList GetOrderedViewList(int nPMode);

	/**
	 * Determines whether a specific view is enabled in the suggested mode.
	 */
	public boolean IsEnabled(int nPMode, String strViewName)
	{
		XPArrayList xpalPViews = GetOrderedViewList(nPMode);

		IXPEnumerator xpEnumPSubModels = xpalPViews.GetEnumerator();

		while (xpEnumPSubModels.MoveNext())
		{
			String strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();

			if (0 == strSubModelKeyCurrent.compareTo(strViewName))
			{
				return true;
			}
		}

		return false;
	}

	
	
	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		PortletModel myModel   = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
		XPArrayList xpalPViews = GetOrderedViewList(myModel.GetPMode());

		IXPEnumerator xpEnumPSubModels = xpalPViews.GetEnumerator();

		while (xpEnumPSubModels.MoveNext())
		{
			String strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();

			try
			{
				EditorView pSubViewCurrent = (EditorView) m_asOwner.GetView(strSubModelKeyCurrent);
				views.AddInnerHTMLElement(pSubViewCurrent.Display());
				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
			}
			catch (Exception e)
			{
				log.Error(e, GetName() +
					"::PageDisplay() The following error occured when trying to display the HTML for Section (" +
					strSubModelKeyCurrent + ").");
				

				throw new XPException(m_asOwner.GetString(617,
						"ptmsgs_portaladminmsgs"), e);
			}
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayJavaScriptFromChild()
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection result = super.DisplayJavaScriptFromChild();

		if (null == result)
		{
			result = new HTMLScriptCollection();
		}

		PortletModel myModel   = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
		XPArrayList xpalPViews = GetOrderedViewList(myModel.GetPMode());

		IXPEnumerator xpEnumPSubModels = xpalPViews.GetEnumerator();

		while (xpEnumPSubModels.MoveNext())
		{
			String strSubModelKeyCurrent = (String) xpEnumPSubModels.GetCurrent();

			try
			{
				EditorView pSubViewCurrent = (EditorView) m_asOwner.GetView(strSubModelKeyCurrent);
				HTMLScript currentScript = pSubViewCurrent.DisplayJavascript();
				if (null != currentScript)
				{
					result.AddInnerHTMLElement(currentScript);
				}
			}
			catch (Exception e)
			{
				
					log.Error(e, GetName() +
						"::PageDisplay() The following error occured when trying to display the Javascript for Section (" +
						strSubModelKeyCurrent + ").");
				

				throw new XPException(m_asOwner.GetString(617,
						"ptmsgs_portaladminmsgs"), e);
			}
		}

		return result;
	}
}

