package com.plumtree.portalpages.admin.editors.portlet;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.portlets.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author 
 */
public class PortletDependenciesView extends ObjDependenciesView
{

	/** Constant to pass into display functions specifying whether indentation should be used */
	public static final int OFFSET = -1; // <0 use default, 0 none, >0 use specified 

	/** Constant passed into display functions to specify whether line breaks should be used. 
	 * <0 use default, 0 none, >0 use specified */
	public static final int BREAK = -1; // <0 use default, 0 none, >0 use specified
	
	/** Member variable for the display helper class */
	protected CreatedHelper m_chHelper	  = null;
	
	public static final String FUNC_GoToMandatoryPage = "GoToMandatoryPage";

	
	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "PortletDependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (PortletModel) model);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/***/
	/**
	 */
	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()

	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLAnchor myAnchor;

		m_chHelper.displayEmptyRow(result);
		
		
		if (((PortletModel)m_model).IsTemplate())
		{
			//Display the standard success message
			m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2216, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());

			XPStringBuilder sb = new XPStringBuilder(100);
			sb.Append(PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_CLASSID)
				.Append("=").Append(PT_CLASSIDS.PT_GADGETTEMPLATE_ID)
				.Append("&").Append(PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_ID)
				.Append("=").Append(((ObjEditorModel) m_model).GetObjectID());

			m_chHelper.beginList(result);
						
			m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(PT_CLASSIDS.PT_GADGET_ID, "", ((ObjEditorModel) m_model).GetFolderID(), m_asOwner.GetString(2218, "ptmsgs_portaladminmsgs"), m_asOwner,sb.ToString(), true));
			
			//Display the standard warning if everyone has access to this object
			m_chHelper.displayEveryoneWarning(result, (PortletModel) m_model, m_asOwner.GetString(2216, "ptmsgs_portaladminmsgs"));

		} else
		{
			//Display the standard success message
			m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2215, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());

			int nSize = ((PortletModel)m_model).GetPortletSize();
			if ((PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW == nSize)
				|| (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE == nSize))
			{ 
				//Generate a popup URL to invite people to this community
				ASURL asurl = new ASURL(m_asOwner);
				asurl.SetLinkGetSpaceIfCached(PortletSelectionEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
				asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
				asurl.SetDisplayPage(PortletInvitationPopupDP.STR_MVC_CLASS_NAME);
				asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationID,
					XPConvert.ToString(((PortletModel) m_model).GetObjectID()));
				asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationName,
					((PortletModel) m_model).GetObjectName());
	
				String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(strJSUtilVersionPrefix+"PTWindowUtil.openWindow('" +
					asurl.GetURLAsString() + "', 'SendToOthers', '250','600'); return false;");
	
				m_chHelper.beginList(result);
	
				HTMLSpan mySpan = new HTMLSpan();
				mySpan.AddInnerHTMLString(m_asOwner.GetString(2217, "ptmsgs_portaladminmsgs"));
	
				myAnchor.AddInnerHTMLElement(mySpan);
	
				m_chHelper.displayListRow(myAnchor);
	
				ObjectSecurityModel modelSecurity = (ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB);
				if (modelSecurity.GetSupportMandatoryColumn() == ObjectSecurityModel.MANDCOL_REGULAR)
				{
					// Set the page to the security page for mandatory-ness settings.
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(FUNC_GoToMandatoryPage + "(); return false;");
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(2219, "ptmsgs_portaladminmsgs"));
	
					m_chHelper.displayListRow(myAnchor);
				}
			}

			//Display the standard warning if everyone has access to this object
			m_chHelper.displayEveryoneWarning(result, (PortletModel) m_model, m_asOwner.GetString(2215, "ptmsgs_portaladminmsgs"));
		}

		if(((PortletModel)m_model).IsMandatory())
		{
			m_chHelper.displayWarning(result, m_asOwner.GetString(2391, "ptmsgs_portaladminmsgs"));
		}


		// Row 1 - end
		return result;
	}
	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript() {
		HTMLScript myScript = super.DisplayJavascript();
		if (null == myScript)
		{
			myScript = new HTMLScript("text/javaScript"); 
		}
		
		XPStringBuilder sb;
		sb = new XPStringBuilder(200);
		sb.Append("function " + FUNC_GoToMandatoryPage + "()\n");
		sb.Append("{\n");
		sb.Append("  window.close(); \n");
		sb.Append("  window.opener." + ObjEditorAS.JAVASCRIPT_OBJEDITOR_OPEN);
		sb.Append("('" + ((PortletModel)m_model).GetClassID() + "',");
		sb.Append("'" + ((PortletModel)m_model).GetObjectID() + "',");

		// JF- We don't need the Folder ID in edit mode
		sb.Append("'" + ObjEditorModel.EDITOR_FOLDERID_UNKNOWN + "',");
		sb.Append("'" + IPTOpenerConstants.OPENER_MODE_EDIT + "',");
		sb.Append("'" + m_asOwner.GetParentSpaceName() + "',");
		sb.Append("'" + m_asOwner.GetParentSpaceID() + "',");
		sb.Append("'" + ASConstants.PAGE + "=" + ObjectSecurityDP.STR_MVC_CLASS_NAME);
		if (m_asOwner.IsSubSpace())
		{
			sb.Append("&" + ASConstants.SUBSPACE + "=" + m_asOwner.GetName()); 
		}
		sb.Append("'); \n");
		sb.Append("}\n");

		myScript.AddInnerHTMLString(sb.ToString());
		return myScript;
	}

}

