package com.plumtree.portalpages.admin.editors.portlet;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.portlet.plugins.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public abstract class PortletEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.portlet.PortletEditorAS");

	/** The Object Name of the Remote Server Editor */
	public static final String STR_MVC_CLASS_NAME = "PortletEditor";

	/** StorageKey */
	public static final String Storage_PChooseSelectionView = "STOR_PChooseSelectionView";

	/** StorageKey */
	public static final String Storage_PSelectTemplateView= "STOR_PSelectTemplateView";

	/** StorageKey */
	public static final String Storage_PortletSettingsView = "STOR_PortletSettingsView";

	/** StorageKey */
	public static final String Storage_SelectWebServiceView = "STOR_SelectWebServiceView";

	/** StorageKey */
	public static final String Storage_SetAdminPrefsView = "STOR_PortletSetAdminPrefsView";

	/** Subspace key for the gateway subspace */
	public static final String GATEWAY_SUBSPACE = "PEASGatewaySubSpace";

	/** Subspace key for the gateway subspace */
	public static final String WSTREE_SUBSPACE = "WSTreeSubSpace";

	/** Subspace key for the gateway subspace */
	public static final String PTTREE_SUBSPACE = "PTTreeSubSpace";

	public static final String PEDITORSUBSPACEKEY_PREFIX = "SomePortletSubSpace";
	private static final String sClassName = "com.plumtree.portalpages.admin.editors.portlet.PortletEditorAS";


	/**
	 * This is a helper method that all classes that inherit from AFormDP can override
	 * if they like.  The method provides a hook into the head so that DP's can add javascript.
	 * Simply override and return and HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()
	 *
	 * Override this method to Display javascript from child IViews
	 *
	 * @return HTMLScriptCollection the Javascript from the Child IViews
	 */
	public HTMLScriptCollection DisplayCommonJavaScript()

	{
		HTMLScriptCollection scripts = super.DisplayCommonJavaScript();

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
		scripts.AddInnerHTMLElement(script);

		return scripts;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (PortletDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(607, "ptmsgs_portaladminmsgs");
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(2613, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 *     This adds the gadget invitation link to the help banner.
	 */
	public PTConstruct GetSubBanner()
	{
		PTConstruct mySubBanner = UIConstructFactory.GetConstruct(PTBannerType.BANNER_ACTION_BAR);

		PortletModel modelPortlet = ((PortletModel) GetModel(PortletModel.STR_MVC_CLASS_NAME));
		modelPortlet.AddSendToOthersButtonToHelpBanner(mySubBanner);

		return mySubBanner;
	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#GetRepostControlName()
	 */
	public String GetRepostControlName()
	{
		return (PortletRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		// Get and initialize my data model.
		m_strModelName = PortletModel.STR_MVC_CLASS_NAME;

		super.Init();

		PortletModel myModel = (PortletModel) GetModel(m_strModelName);

		// Register DisplayPages
		RegisterPage(new MainDP());
		myModel.RegisterPPage(MainDP.STR_MVC_CLASS_NAME);

		RegisterPage(new PreCreateDP());
		myModel.RegisterPPage(PreCreateDP.STR_MVC_CLASS_NAME);


		RegisterView(PortletDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Views
		RegisterModel(SelectWebServiceModel.STR_MVC_CLASS_NAME,
			Storage_SelectWebServiceView);
		RegisterView(SelectWebServiceView.STR_MVC_CLASS_NAME,
			Storage_SelectWebServiceView, GetModel(Storage_SelectWebServiceView));
		myModel.RegisterPSubModel(Storage_SelectWebServiceView);

		RegisterModel(PortletSettingsModel.STR_MVC_CLASS_NAME,
			Storage_PortletSettingsView);
		RegisterView(PortletSettingsView.STR_MVC_CLASS_NAME,
			Storage_PortletSettingsView, GetModel(Storage_PortletSettingsView));
		myModel.RegisterPSubModel(Storage_PortletSettingsView);

		RegisterModel(PChooseModel.STR_MVC_CLASS_NAME,
			Storage_PChooseSelectionView);
		RegisterView(PChooseSelectionView.STR_MVC_CLASS_NAME,
			Storage_PChooseSelectionView, GetModel(Storage_PChooseSelectionView));
		myModel.RegisterPSubModel(Storage_PChooseSelectionView);

		RegisterModel(PSelectTemplateModel.STR_MVC_CLASS_NAME,
			Storage_PSelectTemplateView);
		RegisterView(PSelectTemplateView.STR_MVC_CLASS_NAME,
			Storage_PSelectTemplateView, GetModel(Storage_PSelectTemplateView));
		myModel.RegisterPSubModel(Storage_PSelectTemplateView);
		
		RegisterView(PortletEditorHeaderView.STR_MVC_CLASS_NAME, myModel);


		// Register Controls - I'm assuming I need a Repost control.		
		RegisterControl(PortletRepostControl.STR_MVC_CLASS_NAME, myModel);
	
		// Default page
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(609,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, PreCreateDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
		
		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1855, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
		
		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				

				int iTitleId = 48;
				int iTipId = 49;
				int iSecondaryTipId = 50;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}								
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}
	
 

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)

	{
		super.SetCurrentPage( page );
		
		if( ObjectSecurityDP.STR_MVC_CLASS_NAME.equals( page.GetName() ))
		{
			this.SetHelpTopic( "PT_Portlet_Security" );
		}

		// Get the PluginDP's to find their help topic.
		// Note the cast will fail (correctly), if the page is
		// not a Plugin Page DP.
		try
		{
			PPluginDP ppluginPage = (PPluginDP)page;
			SetHelpTopic(ppluginPage.GetPluginHelpTopic());
			
		} catch (Exception e)
		{
			//AGC- This is not a bug. Non Plugin
			
				log.Debug(e, "Couldn't get help from PluginPage - this page is likely not a PPluginDP.");
						
		}
	}
}

