package com.plumtree.portalpages.admin.editors.portlet;

import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class implements the HTML to print out the Editor header.
 * This View is printed out by EditorDP.
 * Editor Views should NOT extend this class.
 * They should extend EditorView instead.
 *
 * @author Julie Fournier
 */
public class PortletEditorHeaderView extends EditorHeaderView
{
	/** Object Name for AS */
	public static final String STR_MVC_CLASS_NAME = "PortletEditorHeader";

	
	// HTML Object names.
	/** HTMLID for the NEXT button */
	public static final String HTMLBUTTON_EDITOR_NEXT = "in_bu_Next";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletEditorHeaderView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
 

	/**
	 * @see com.plumtree.uiinfrastructure.form.FormHeaderView#AddHeaderButtons()
	 */
	protected HTMLElement AddHeaderButtons() 
	{
		HTMLImg myImage;
		HTMLInput myInput;
		PTConstruct myConstruct;


		// Begin Header buttons table
		HTMLTable mySubTable = new HTMLTable();
		mySubTable.SetBorder("0");
		mySubTable.SetCellPadding("5");
		mySubTable.SetCellSpacing("0");

		// button table 1st Row
		HTMLTableRow mySubRow = new HTMLTableRow();
		mySubTable.AddInnerHTMLElement(mySubRow);

		HTMLTableCell mySubCell = new HTMLTableCell();
		mySubRow.AddInnerHTMLElement(mySubCell);
		mySubCell.SetHeight("20");
		mySubCell.SetAlign("right");
		mySubCell.SetVAlign("middle");
		mySubCell.SetNoWrap(true);

		// JF- Only display the done button if the it's not read-only mode.
		if (!((IEditorModelRO) m_model).GetIsEditorReadOnly())
		{
			// AGC- This is really the only thing that's different from the
			// super implementation.
			// Next button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
								HTMLBUTTON_EDITOR_NEXT, "");
			
			myInput.SetValue(m_asOwner.GetString(1856, "ptmsgs_portaladminmsgs"));
						
			myInput.SetOnClick("goToPage('" +
				m_asOwner.GetName() + "', '" +
				MainDP.STR_MVC_CLASS_NAME + "', ''); return false;");			
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			
			mySubCell.AddInnerHTMLElement(myInput);
			mySubCell.AddInnerHTMLString(SPACE);
			
			// Done button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLBUTTON_EDITOR_FINISH, "");
			mySubCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(38,
					"ptmsgs_infrastructure"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);

			myInput.SetOnClick("postToSelf(" +
				EditorRepostControl.POSTTOSELF_ACTION_FINISH +
				"); return false;");
			mySubCell.AddInnerHTMLString(SPACE);
		}

		// Cancel button
		myInput = new HTMLInput(HTMLInputTypes.BUTTON,
				HTMLBUTTON_EDITOR_CANCEL, "");
		mySubCell.AddInnerHTMLElement(myInput);

		myInput.SetValue(m_asOwner.GetString(39, "ptmsgs_infrastructure"));
		myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
		myInput.SetOnClick("postToSelf(" +
			EditorRepostControl.POSTTOSELF_ACTION_CANCEL +
			"); return false;");

		mySubCell = new HTMLTableCell();
		mySubRow.AddInnerHTMLElement(mySubCell);
		mySubCell.SetWidth("1");
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetWidth("1");
		myImage.SetHeight("1");
		myImage.SetBorder("0");
		mySubCell.AddInnerHTMLElement(myImage);
		
		return mySubTable;		
			
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display() {
		return super.Display();
	}

}

