/**
 * Created on Nov 4, 2002
 * by adolfoc
 */
package com.plumtree.portalpages.admin.editors.portlet.plugins;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author AdolfoC
 */
public class PSelectTemplateModel extends EditorHelperModel implements IPSelectTemplateModelRO,
	IPSubModel
{
	
	public static final String STR_MVC_CLASS_NAME = "PSelectTemplateModel";

	/**
	 * This member defines a static string used to identify when m_htFormData
	 * has been initialized.
	 */
	public static final String DEFAULTDATA = "Default Data";

	/**
	 * The portlet template that is currently chosen.
	 */
	protected int m_nTemplateObjectID = 0;
	
	/**
	 * Determines if freeform templates should be shown.
	 */
	protected boolean m_bShowFreeForm = false;

	/**
	 * Determines if header and footer templates should be shown.
	 */
	protected boolean m_bShowHeaderAndFooter = false;
		
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PSelectTemplateModel();
	}


	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()
	 */
	public void DoTaskBeforePStore()
	{
		// AGC- Thankfully, this model/view has nothing to do before store. It's job is over shortly
		// after the object is created.
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnPModeUpdate(int nNewWSMode)
	{
		// AGC- This model/view initiates PMode changes - it generally does not consume them.
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String, String)
	 */
	public void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
	{
		// AGC- This model/view doesn't care - in fact it is unlikely that this view will ever
		// experience this method being called.
	}

	/**
	 * This function actually commits the changes that forces our editor into
	 * the normal create or create from template modes. It is called by the
	 * Portlet Repost Control if "Done" is clicked during PRECREATE mode.
	 */
	public void FinalizeCreation()
	{
		PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);

		// Replace the PTObject the we all use with a new one generated from the template. This 
		// will force the reinitialization of all of our views.
		mParentModel.SetEditedObject(mParentModel.CreateObjectFromTemplate(
				m_nTemplateObjectID));

		mParentModel.SetPMode(PortletModel.PMODE_CREATE_FROMTEMPLATE);
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ITemplateChooserModelRO#GetObjectIDOfTemplate()
	 */
	public int GetObjectIDOfTemplate()
	{
		return this.m_nTemplateObjectID;
	}

	// BEGIN ***************** save DP methods ***************** 


	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)
	 */
	public void InitPModel(IPTGadget ptPortlet)
	{
		// AGC- There is nothing to initialize - this view is only used to create objects.
	}


	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		// Make sure we're in the correct PMODE - the user might have hit the back button
		// or something odd like that. We should never be saved outside of PRECREATE mode.
		PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);

		if (PortletModel.PMODE_PRECREATE != mParentModel.GetPMode())
		{
			return RepostControl.PAGE_STATUS_VALID;			
		}
	
		int nValid = RepostControl.PAGE_STATUS_VALID;

		m_nTemplateObjectID = PortletModelHelper.GetFormElementInt(_htFormData, PSelectTemplateView.HTMLRADIO_PORTLET_CREATEFROM, 0);
		nValid = PortletModelHelper.ValidateIntegerRange(m_nTemplateObjectID, m_asOwner, m_asOwner.GetString(561, "ptmsgs_portaladminmsgs"), nValid, 1, -1);
		
		// We shouldn't go about trying to finalize unless we've got a valid template object id.
		// Bad things will happen otherwise.
		if (RepostControl.PAGE_STATUS_VALID == nValid) {
			// AGC- Now, we're in the right mode, and we're ready for action. - let's boogie.
			FinalizeCreation();
		}

		return nValid;
	}
	
	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.plugins.IPSelectTemplateModelRO#GetAvailableTemplates()
	 */
	public PTObjectManagerQueryWrapper GetAvailableTemplates() {

		PortletModel mParent = (PortletModel)m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
		
		IPTSession ptSession			  = mParent.GetPTSession();
		IPTObjectManager ptObjectManagers = (IPTObjectManager) ptSession.GetObjectManagers(PT_CLASSIDS.PT_GADGETTEMPLATE_ID);
		PTObjectManagerQueryWrapper omqr  = new PTObjectManagerQueryWrapper(ptObjectManagers);

				
		Object[][] arptqf	= PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_ACCESSLEVEL, PT_FILTEROPS.PT_FILTEROP_GTE, new Integer(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT));
		//omqr.SimpleQuery(-1, PT_PROPIDS.PT_PROPID_NAME);
		omqr.Query(-1, -1, null, arptqf);
		
		return omqr;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.plugins.IPSelectTemplateModelRO#GetPortletTemplateID()
	 */
	public int GetPortletTemplateID() {
		return m_nTemplateObjectID;
	}
	
	public boolean GetShowFreeForm() {
		return m_bShowFreeForm; 
	}
	
	public void SetShowFreeForm(boolean bShowFreeForm) {
		m_bShowFreeForm = bShowFreeForm;
	}
	
	public boolean GetShowHeaderAndFooter() {
		return m_bShowHeaderAndFooter; 
	}

	public void SetShowHeaderAndFooter(boolean bShowHeaderAndFooter) {
		m_bShowHeaderAndFooter = bShowHeaderAndFooter;
	}
	
	

}

