/**
 * Created on Dec 30, 2002
 * by adolfoc
 */
package com.plumtree.portalpages.admin.editors.portlet.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author adolfoc
 */
public class PortletSettingsModel extends EditorHelperModel
	implements IPortletSettingsModelRO, IPSubModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.portlet.plugins.PortletSettingsModel");

	public static final String STR_MVC_CLASS_NAME = "PortletSettingsModel";

	/**
	 * Our portlet, passed to us in InitPModel
	 */
	protected IPTGadget m_ptPortlet = null;

	/**
	 * Determines whether the gadget is a personal, community or template type
	 * gadget. Can be one of the enums from PT_GADGET_TYPES. (SettingsView)
	 */
	private int m_intPortletType;

	/**
	 * The size "Narrow" or "Wide" for this
	 * Portlet (SettingsView)
	 */
	private int m_intPortletSize;

	/**
	 * true or false whether or not this portlet should suppress the title bar.
	 * (SettingsView)
	 */
	private boolean m_bSuppressTitleBar = false;

	public PortletSettingsModel()
	{
		super();
		m_intPortletType = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;
		m_intPortletSize = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW;
	}

	// Helper funcs
	public void ChangePortletAlignment(XPHashtable form)
	{
		String[] data = (String[]) form.GetElement(PortletSettingsView.HTMLRADIO_GADGET_ALIGNMENT);

		if ((null != data) && !(0 == data.length))
		{
			m_intPortletSize = XPConvert.ToInteger(data[0]);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletSettingsModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskBeforePStore()
	 */
	public void DoTaskBeforePStore()
	{
		m_ptPortlet.SetSuppressTitleBar(m_bSuppressTitleBar);

		// Settings Section
		switch (m_intPortletSize)
		{
		case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NONE):
		case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW):
		case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE):
		case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER):
		case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER):
		case (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM):
			m_ptPortlet.SetAlignment(m_intPortletSize);

			break;

		default:
			m_ptPortlet.SetAlignment(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NONE);

			
				log.Warn("PortletSettingsModel::DoTaskBeforePStore - Received an invalid Portlet Size. Using PT_GADGETALIGN_NONE instead");
			
		}

		PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);

		if (!mParentModel.IsTemplate())
		{
			switch (m_intPortletType)
			{
			case (PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL):
			case (PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY):
				m_ptPortlet.SetGadgetType(m_intPortletType);

				break;

			default:
				m_ptPortlet.SetGadgetType(PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL);
				m_intPortletType = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;

				log.Warn("PortletSettingsModel::DoTaskBeforePStore - Received an invalid PortletType. Using PT_GADGETTYPE_PERSONAL instead");
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnPModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#DoTaskOnWebServiceUpdate(String, String)
	 */
	public void DoTaskOnWebServiceUpdate(IPTWebService ptWebService)
	{
	}

	/**
	 * Returns the m_intTemplate.
	 * @return int
	 */
	public int GetPortletType()
	{
		return m_intPortletType;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	// Getters and Setters

	/**
	 * Returns the m_intPortletSize.
	 * @return int
	 */
	public int GetPortletSize()
	{
		return m_intPortletSize;
	}

	/**
	 * Returns the m_intSuppressTitleBar.
	 * @return int
	 */
	public boolean GetSuppressTitleBar()
	{
		return m_bSuppressTitleBar;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.portlet.IPSubModel#InitPModel(IPTWebService)
	 */
	public void InitPModel(IPTGadget ptPortlet)
	{
		m_ptPortlet = ptPortlet;

		PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);

		switch (mParentModel.GetPMode())
		{
		case PortletModel.PMODE_CREATE:
			break;

		case PortletModel.PMODE_CREATE_FROMTEMPLATE:
		default:
			m_intPortletSize = ptPortlet.GetAlignment();
			m_bSuppressTitleBar = ptPortlet.GetSuppressTitleBar();
		}

		// AGC- this must be called, even during CREATE in order to determine whether
		// or not we are a template.
		m_intPortletType = ptPortlet.GetGadgetType();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		String[] data;
		data = (String[]) _htFormData.GetElement(PortletSettingsView.HTMLCHECKBOX_SUPPRESS_TITLE_BAR);

		if ((null != data) && !(0 == data.length))
		{
			try
			{
				SetSuppressTitleBar(XPConvert.ToBoolean(data[0]));
			}
			catch (Exception e)
			{
				log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Suppress Title Bar checkbox. Using 0 instead.");
				SetSuppressTitleBar(false);
			}
		}
		else
		{
			SetSuppressTitleBar(false);
		}

		PortletModel mParentModel = (PortletModel) m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);

		if (!mParentModel.IsTemplate())
		{
			data = (String[]) _htFormData.GetElement(PortletSettingsView.HTMLRADIO_GADGET_TYPE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					SetTemplate(XPConvert.ToInteger(data[0]));
				}
				catch (Exception e)
				{
					log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Template checkbox. Using 0 instead.");
					SetTemplate(0);
				}
			}
		}

		data = (String[]) _htFormData.GetElement(PortletSettingsView.HTMLRADIO_GADGET_ALIGNMENT);

		if ((null != data) && !(0 == data.length))
		{
			try
			{
				SetPortletSize(XPConvert.ToInteger(data[0]));
			}
			catch (Exception e)
			{
				log.Warn("PortletSettingsModel::SaveSection - Received invalid value for Portlet Size select. Using 0 instead.");
				SetPortletSize(0);
			}
		}
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Sets the m_intPortletSize.
	 * @param m_intPortletSize The m_intPortletSize to set
	 */
	public void SetPortletSize(int intPortletSize)
	{
		this.m_intPortletSize = intPortletSize;
	}

	/**
	 * Sets the m_intSuppressTitleBar.
	 * @param m_intSuppressTitleBar The m_intSuppressTitleBar to set
	 */
	public void SetSuppressTitleBar(boolean bSuppressTitleBar)
	{
		this.m_bSuppressTitleBar = bSuppressTitleBar;
	}

	/**
	 * Sets the m_intTemplate.
	 * @param m_intTemplate The m_intTemplate to set
	 */
	public void SetTemplate(int intPortletType)
	{
		this.m_intPortletType = intPortletType;
	}
}

