package com.plumtree.portalpages.admin.editors.portlet.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class SelectWebServiceView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.portlet.plugins.SelectWebServiceView");

	public static final String STR_MVC_CLASS_NAME = "PortletSelectWebServiceView";


	/**
	 * Private String that is the function name for the repost javascript called
	 * when the tree control returns
	 */
	private static final String JSREPOST_WEBSERVICE_FUNC	   = "frmRepostWebServiceChosen";
	private static final String JSREPOST_WEBSERVICE_FUNC_INPUT = "frmSetDataWebServiceChosen";

	// HTML Object names.
	public static final String HTMLHIDDEN_WEBSERVICE_SPACE    = "in_hi_WebServiceSpace";
	public static final String HTMLHIDDEN_WEBSERVICE_SELECTED = "in_hi_WebServiceSelected";

	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectWebServiceView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableCell myCell;
		HTMLTableRow myRow;

		HTMLSpan mySpan;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						595, "ptmsgs_portaladminmsgs")));

			// Containing Table
			myTable = PortletViewHelper.AddTable(result);

			ISelectWebServiceModelRO mModel = (ISelectWebServiceModelRO) super.m_model;

			////// Don't forget to HTMLEncode this stuff..... Important!
			String strWebServiceName = mModel.GetWebServiceName();

			// 1st row begins (Top Margin)
			myRow     = PortletViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);

			// 1st row ends
			// 2nd Row - Path info.
			myRow = PortletViewHelper.AddRow(myTable);

			//// Left Margin
			PortletViewHelper.AddLeftMargin(myRow, 5);
			
			// Label
			myCell = PortletViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE,
				m_asOwner.GetString(600, "ptmsgs_portaladminmsgs"));

			
			// Name and button
			

			// Existing Web Service Name
			if ((null == strWebServiceName) ||
					(0 >= strWebServiceName.length()))
			{
				if (SelectWebServiceModel.NO_ACCESS_WS == mModel.GetWebServiceID())
				{
					strWebServiceName = m_asOwner.GetString(2634, "ptmsgs_portaladminmsgs");
				}
				else
				{
					strWebServiceName = m_asOwner.GetString(597, "ptmsgs_portaladminmsgs");
				}
				myCell = PortletViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, strWebServiceName);

			} else {
				// add web service opener link
				HTMLAnchor wsLink = (HTMLAnchor)WSViewHelper.MakeEditObjectLink(PT_CLASSIDS.PT_WEBSERVICE_ID, mModel.GetWebServiceID(), mModel.GetWebServiceName(), m_asOwner);
				myCell = PortletViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
				HTMLSpan wsOpenerSpan = PortletViewHelper.AddSpanToCell(myCell);
				wsOpenerSpan.AddInnerHTMLElement(wsLink);		
			}
					

			// Hidden input for the Space ID for the tree.  That way if you hit the folder
			// tree link twice, it will open the same tree both times.

			String strWebServiceSpaceID = ((ISelectWebServiceModelRO) m_model).GetData(HTMLHIDDEN_WEBSERVICE_SPACE);

			if (strWebServiceSpaceID.equals(SelectWebServiceModel.DEFAULTDATA))
			{
				strWebServiceSpaceID = "";
			}
			
			myCell.AddInnerHTMLElement(PortletViewHelper.MakeHiddenInput(HTMLHIDDEN_WEBSERVICE_SPACE, strWebServiceSpaceID));
			myCell.AddInnerHTMLElement(PortletViewHelper.MakeHiddenInput(HTMLHIDDEN_WEBSERVICE_SELECTED, ((ISelectWebServiceModelRO) m_model).GetData(HTMLHIDDEN_WEBSERVICE_SELECTED)));
			
			
			////// Actual Tree Control
			// allow the user to change the web service only if we're in create mode or the webservice is null for some reason.
			if ((!((ISelectWebServiceModelRO) m_model).IsReadOnly()) && (((ISelectWebServiceModelRO) m_model).GetWebServiceID() != SelectWebServiceModel.NO_ACCESS_WS))
			{
				mySpan = PortletViewHelper.AddSpanToCell(myCell);
				mySpan.AddInnerHTMLString(SPACE);
				
				String strOnClick = JSREPOST_WEBSERVICE_FUNC_INPUT + "(document." +
					AFormDP.HTMLFORM_NAME + "." + HTMLHIDDEN_WEBSERVICE_SPACE +
					"); return false;";

				mySpan.AddInnerHTMLElement(PortletViewHelper.MakeSimpleButton(
						m_asOwner.GetString(598, "ptmsgs_portaladminmsgs"),
						strOnClick));
			}

			//// Right Margin
			PortletViewHelper.AddRightMargin(myRow, 5);

			// 2nd row ends			
			// 3rd Row - Path info.
			myRow = PortletViewHelper.AddRow(myTable);

			//// Left Margin
			PortletViewHelper.AddLeftMargin(myRow, 5);

			//// Label "Web Service Path"
			PortletViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(599, "ptmsgs_portaladminmsgs"));
			

			// Actual Path
			String strWebServicePath = ((ISelectWebServiceModelRO) m_model).GetWebServicePath();

			if (null == strWebServicePath)
			{
				strWebServicePath = "";
			}

			PortletViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE, strWebServicePath);

			//// Right Margin
			PortletViewHelper.AddRightMargin(myRow, 5);

			// Admin Prefs URL 
			

			String strAdminPrefsURL = ((ISelectWebServiceModelRO) m_model).GetAdminPrefsURL();

			if ((null != strAdminPrefsURL) && (strAdminPrefsURL.length() > 0))
			{
				// Spacer Row
				myRow     = PortletViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);
				
				// Row 
				myRow = PortletViewHelper.AddRow(myTable);

				// Left Margin
				PortletViewHelper.AddLeftMargin(myRow, 5);

				myCell=PortletViewHelper.AddLabelCell(myRow, CommonHTMLStrings.TWO, m_asOwner.GetString(603, "ptmsgs_portaladminmsgs"));
				
				// Don't show the Admin preferences if the editor is READ ONLY - this is a security hole otherwise!!!				
				PortletModel parentModel = (PortletModel)m_asOwner.GetModel(PortletModel.STR_MVC_CLASS_NAME);
				if (!parentModel.GetIsEditorReadOnly())
				{
					String strOnClickAdmin = "window.open('" + strAdminPrefsURL + "', 'blank66', 'resizable=1,status=0,toolbar=0,menubar=0,scrollbars=1,location=0,height=480,width=800')";
					myCell.AddInnerHTMLElement(PortletViewHelper.MakeSimpleButton(m_asOwner.GetString(604, "ptmsgs_portaladminmsgs"), strOnClickAdmin));
				} else
				{
					mySpan = PortletViewHelper.AddSpanToCell(myCell);
					mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
					mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(2511, "ptmsgs_portaladminmsgs"));
				}
			
				// Right Margin
				PortletViewHelper.AddRightMargin(myRow, 5);

			}
			
			// Bottom Margin

			PortletViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);
		}
		catch (Exception e)
		{
			
				log.Error(e, "SelectWebServiceView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(596,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		String strFormName = AFormDP.HTMLFORM_NAME;

		// The URL to open a new folder tree
		ASURL newTree = new ASURL(m_asOwner);
		newTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		newTree.SetSubSpaceKey(PortletEditorAS.WSTREE_SUBSPACE);
		newTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		newTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		newTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		newTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		newTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		newTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		newTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			HTMLHIDDEN_WEBSERVICE_SPACE);
		newTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			JSREPOST_WEBSERVICE_FUNC);
		newTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_WEBSERVICE_ID));
		newTree.AddControlArgument(StartTreeControl.QUERY_FILTER,
			XPConvert.ToString(PT_CLASSIDS.PT_WEBSERVICE_ID) + "," +
			XPConvert.ToString(PT_PROPIDS.PT_PROPID_WEBSERVICE_PROVIDERCLSID) +
			"," + XPConvert.ToString(WSModelHelper.WSTYPE_IGP) + "," +
			XPConvert.ToString(WSModelHelper.WSTYPE_HTTPGP));
		newTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(2484, "ptmsgs_portaladminmsgs"));
		newTree.AddControlArgument(StartTreeControl.TITLE,
			m_asOwner.GetString(2484, "ptmsgs_portaladminmsgs"));

		// The url to open a previously opened folder tree
		// This needs to have the SpaceID added to it.
		ASURL oldTree = new ASURL(m_asOwner);
		oldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		oldTree.IsSubSpace();

		HTMLScript result  = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		try
		{
			// Test Server Side From Submit function
			sb = new XPStringBuilder(100);
			sb.Append("function ").Append(JSREPOST_WEBSERVICE_FUNC).Append("()\n");
			sb.Append("{\n");
			sb.Append("  postToSelf(")
			.Append(PortletRepostControl.POSTTOSELF_ACTION_WEB_SERVICE_CHOSEN)
			.Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// Open folder tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JSREPOST_WEBSERVICE_FUNC_INPUT)
			.Append("(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");

			sb.Append("    window.open('").Append(newTree.GetURLAsString())
			.Append			
			("', '_blank1', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(oldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_blank1', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element: " +
					he.getMessage());
			
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

