package com.plumtree.portalpages.admin.editors.portletbundle;


// Plumtree Server Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 * @author michaeld
 */
public class PortletBundleEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.portletbundle.PortletBundleEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "GadgetBundleEditor";

	/** SelectPTObject Model */
	public static final String strStorageSelectPTObject = "SelectPTObject";

	private static final String sClassName = "com.plumtree.portalpages.admin.editors.portletbundle.PortletBundleEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletBundleEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (PortletBundleDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return String strEditorTitle
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(380, "ptmsgs_portaladminmsgs");
		}
		return (XPResourceManager.FormatMessage(GetString(2612, "ptmsgs_portaladminmsgs"), GetObjectName()));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (PortletBundleRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = PortletBundleModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		RegisterPage(new PortletBundleMainDP());
		log.Info("PortletBundleEditorAS::Constructor: Register display pages succesful");

		RegisterView(PortletBundleDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(PortletBundleRepostControl.STR_MVC_CLASS_NAME, myModel);
		log.Info("PortletBundleEditorAS::Constructor: Register controls succesful");

		// Register the select PTObject list as a plug-in section
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPTObjectModel = GetModel(strStorageSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject, mySelectPTObjectModel);

		// Set default page
		SetCurrentPage(PortletBundleMainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(383,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PortletBundleMainDP.STR_MVC_CLASS_NAME);
		// END Sub menu "General Settings"

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1858, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );


				int iTitleId = 51;
				int iTipId = 52;
				int iSecondaryTipId = 53;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}


			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if( PortletBundleMainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_PortletBundle_MainSettings" );
		}
	}
}

