package com.plumtree.portalpages.admin.editors.profilesource;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 *
 */
public class AuthPartnerView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.profilesource.AuthPartnerView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "AuthPartner";

	/**
	 */
	public static final String SELECT_AUTHSOURCE = "in_se_authpartner";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AuthPartnerView();
	}

	/**
	 *
	 * @return
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLTable myTable;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						618, "ptmsgs_portaladminmsgs")));

			//result.AddInnerHTMLElement(super.GetShortSpacerTable());

			// mj: do the instructions table
			myTable = ProfileSourceHelper.ConstructInstructionsTable(m_asOwner.GetString(
						620, "ptmsgs_portaladminmsgs"));
			result.AddInnerHTMLElement(myTable);
			result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());

			// mj: construct the control
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");
			// mj: for debugging
			//myTable.SetBorder("1");

			//myTable.SetAlign("left");
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			// mj: cell for dropdown
			myCell = new HTMLTableCell();
			myCell.SetVAlign("center");
			myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			myCell.SetNoWrap(true);

			myRow.AddInnerHTMLElement(myCell);

			// mj: construct the auth source dropdown
			IProfileSourceModelRO model = (IProfileSourceModelRO) m_model;
			String[][] asAuthSources    = model.GetPartnerList();
			String sSelected		    = XPConvert.ToString(model.GetSelectedPartner());

			if (asAuthSources.length == 0)
			{
				// mj: got back no auth sources; this is an error. if the profile source didn't
				// require an auth partner, this array would have at least one entry.
				myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
				myCell.SetNoWrap(false);

				myCell.AddInnerHTMLString(m_asOwner.GetString(621,
						"ptmsgs_portaladminmsgs"));
			}
			else
			{
				myCell.AddInnerHTMLString(m_asOwner.GetString(618,
						"ptmsgs_portaladminmsgs") + ":");

				myCell = new HTMLTableCell();
				myCell.SetWidth("0");
				myCell.SetVAlign("center");
				myRow.AddInnerHTMLElement(myCell);

				HTMLSelect mySelect = new HTMLSelect(SELECT_AUTHSOURCE,
						SELECT_AUTHSOURCE);
				myCell.SetWidth("0");
				myCell.AddInnerHTMLElement(mySelect);
				mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

				for (int i = 0; i < asAuthSources.length; i++)
				{
					HTMLOption myOption = new HTMLOption(asAuthSources[i][0]);
					mySelect.AddInnerHTMLElement(myOption);
					myOption.AddInnerHTMLString(asAuthSources[i][1]);

					if (sSelected.equals(asAuthSources[i][0]))
					{
						myOption.SetSelected(true);
					}
				}

				myCell = new HTMLTableCell();
				myCell.SetWidth("100%");
				myRow.AddInnerHTMLElement(myCell);
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "AuthPartnerView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(619,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

