package com.plumtree.portalpages.admin.editors.profilesource;


// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The main display page for the profile source editor
 *
 * @author Mike Jahr
 */
public class MainDP extends EditorDP
{
	public static final String STR_MVC_CLASS_NAME = "ProfileSourceMain";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(622, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{

		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1683, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		IProfileSourceModelRO model = (IProfileSourceModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName);

		if (model.IsPartnerSupported())
		{
			views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
					AuthPartnerView.STR_MVC_CLASS_NAME)).Display());
			views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		}

        // mj: display the clear history view
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
            ProfileSourceEditorAS.strMainView)).Display());
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());
        
        // aj: display the unique key chooser
        views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
            UniqueKeyChooserView.STR_MVC_CLASS_NAME)).Display());
        views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// mj: display the membership list
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				ProfileSourceEditorAS.strStorageSelectPTObject)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// ***CHANGE_HERE SELECTPTOBJECT*** Display JavaScripts for the Select PTObject list.
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				ProfileSourceEditorAS.strStorageSelectPTObject)
			.DisplayJavascript());
		
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				UniqueKeyChooserView.STR_MVC_CLASS_NAME).DisplayJavascript());

		return myScripts;
	}
}

