package com.plumtree.portalpages.admin.editors.profilesource;


// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.common.setjob.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.ptmulticolumnlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 *
 */
public abstract class ProfileSourceEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.profilesource.ProfileSourceEditorAS");

	/** Unique Key Chooser Tree */
	public static final String strUniqueKeyTree_SUBSPACE = "PSUniqueKeyTreeSubSpace";
	
	/** SelectPTObject storage */
	public static final String strStorageSelectPTObject = "SelectPTObjectGroups";
	public static final String strMainView = "MainView";

	public static final String strPTMultiColumnList = "PTProfSrcMultiColList";
	private static final String sClassName = "com.plumtree.portalpages.admin.editors.profilesource.ProfileSourceEditorAS";

	/**
	 * Gets the Editor title.
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(623, "ptmsgs_portaladminmsgs");
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(2614, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (ProfileSourceRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		super.Init();

		IModel myModel = GetModel(m_strModelName);
		
		// aj: bug 24020 - add dependencies view
		RegisterView(ProfileSourceDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register the select PTObject list as a plug-in section
		RegisterModel(ProfileSourceSelectPTObjectModel.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPTObjectModel = GetModel(strStorageSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject, mySelectPTObjectModel);

		//Register the PTMulticolumnlist for the property map
		//Register the model, view and control for the property map list
		RegisterModel(PTMultiColumnListModel.STR_MVC_CLASS_NAME,
			strPTMultiColumnList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myMultiColumnListModel = GetModel(strPTMultiColumnList);
		RegisterView(PTMultiColumnListView.STR_MVC_CLASS_NAME,
			strPTMultiColumnList, myMultiColumnListModel);
		RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME,
			strPTMultiColumnList, myMultiColumnListModel);

		// Register Views
        RegisterView(AuthPartnerView.STR_MVC_CLASS_NAME, myModel);
        RegisterView(ClearHistoryView.STR_MVC_CLASS_NAME, strMainView, myModel);
        RegisterView(UniqueKeyChooserView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(ProfileSourceRepostControl.STR_MVC_CLASS_NAME, myModel);

		// mj: register set job stuff
		// Register classes for the set job and for the object owner
		RegisterModel(SetJobModel.STR_MVC_CLASS_NAME);
		RegisterControl(SetJobRepostControl.STR_MVC_CLASS_NAME,
			GetModel(SetJobModel.STR_MVC_CLASS_NAME));
		RegisterView(ObjectOwnerView.STR_MVC_CLASS_NAME,
			GetModel(SetJobModel.STR_MVC_CLASS_NAME));

		// Register classes for Job selector
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
			GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
			GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				tm.SetGeneratingClass( sClassName );


				int iTitleId = 54;
				int iTipId = 55;
				int iSecondaryTipId = 56;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}


			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	 * Registers DisplayPages for the editor, including the custom
	 * display pages in the given array. Inits the left nav menu.
	 *
	 */
	protected void RegisterPages(IDisplayPage[] arrDPs)
	{
		// mj: register dps
		RegisterPage(new MainDP());
		RegisterPage(new PropertyMapDP());
		RegisterPage(new SetJobDP());

		// mj: set default page
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		// mj: set left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(625,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);

		for (int i = 0; (arrDPs != null) && (i < arrDPs.length); i++)
		{
			RegisterPage(arrDPs[i]);
			m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, arrDPs[i].GetName());
		}

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PropertyMapDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SetJobDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1863, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();
		if (PropertyMapDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_ProfileSource_PropertyMap");
		}
		else if (SetJobDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_SetJob");
		}
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (ProfileSourceDependenciesView.STR_MVC_CLASS_NAME);
	}
}

