package com.plumtree.portalpages.admin.editors.profilesource;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.common.setjob.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.ptmulticolumnlist.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 *
 *
 * @version $Revision$
 * @author $author$
 */
public abstract class ProfileSourceModel extends ObjEditorModel
	implements IProfileSourceModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.profilesource.ProfileSourceModel");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "ProfileSource";

	/** The number of non-plumtree object columns in the mapping list */
	public static final int MAPLIST_NUMCOLUMNS = 1;

	/** The zero-based position of the Plumtree object in the mapping list */
	public static final int MAPLIST_PTOBJECTPOSITION = 0; //Zero-based list position for the PT object column

	/** Member variable for the Provider CLSID */
	protected String m_sProviderCLSID;

	/** Member variable for the property map information */
	protected Object[][] m_arrPropMapInfo; //This is a 2 dim array 0,0= mapped field, 1,0=mapped PropertyID
	protected Object[][] m_arrOriginalPropMapInfo; // This will contain the original prop map for comparison

	/** Member variable for the Auth Partners list */
	protected String[][] m_asAuthPartners;

	/** Member variable for the partner ID */
	protected int m_nPartnerID;
	
	/** Member variable for tree picker space ID */
	protected String m_sUniqueKeyTreePickerSpaceID;
	
	/** Member variable for the selected property's name */
	protected String m_strUniqueKeyPropertyName;

	/**
	 * Method for retrieving the partner query method
	 *
	 * @return
	 */
	public abstract Object[][] GetPartnerQueryFilter();

	/**
	 * Returns the ProviderCLSID
	 *
	 * @return String
	 */
	public abstract String GetProviderCLSID();

	/**
	 * Returns true if the partner is mandatory
	 *
	 * @return
	 */
	public abstract boolean IsPartnerMandatory();

	/**
	 * Returns true if Partner is supported
	 *
	 * @return
	 */
	public abstract boolean IsPartnerSupported();

	/**
	 * Code executed after the object is stored.
	 */
	public void DoTaskAfterStore()
	{
		try
		{
			((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskAfterStoreSetJob();
		}
		catch (Exception e)
		{
			
				log.Error("ProfileSourceModel::DoTaskAfterStore: Unable to store the job information. " +
					"The following exception occured: " + e);
			
		}
	}

	/**
	 * Code executed before the object is stored.
	 * @throws XPException
	 */
	public void DoTaskBeforeStore()
	{
		super.DoTaskBeforeStore();

		IPTProfileSource ptPS = (IPTProfileSource) m_ptObject;

		// get back the values from the select ptobject
		PTGrowableSortedArrayWrapper aSelectPTObjectValues = ((SelectPTObjectModel) m_asOwner.GetModel(ProfileSourceEditorAS.strStorageSelectPTObject)).GetItems();

		
			for (int i = 0; i < aSelectPTObjectValues.GetCount(); i++)
			{
				log.Info("Select PTObject value: classID: " +
					aSelectPTObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_CLASSID) +
					" - objectID: " +
					aSelectPTObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID) +
					" - object name: " +
					aSelectPTObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_STRING));
			}
		

		// mj: get the list of group ids
		Object[] anGroups = new Object[aSelectPTObjectValues.GetCount()];

		for (int i = 0; i < aSelectPTObjectValues.GetCount(); i++)
		{
			try
			{
				int objectid = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID));
				int classid  = XPConvert.ToInteger(aSelectPTObjectValues.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_CLASSID));

				
					log.Debug("DoTaskBeforeStore: group[" + i + "] classid=" +
						classid + "; objectid=" + objectid);
				

				switch (classid)
				{
				case PT_CLASSIDS.PT_USER_ID:
					anGroups[i] = new Integer(-objectid);

					break;

				case PT_CLASSIDS.PT_USERGROUP_ID:
					anGroups[i] = new Integer(objectid);

					break;

				default:

					// mj: what class did we get?
					
						log.Error("DoTaskBeforeStore: unexpected classid " + classid);
					

					// mj: for lack of a better option, treat it like a group
					anGroups[i] = new Integer(objectid);
				}
			}
			catch (Exception e)
			{
				
					log.Error(e, "DoTaskBeforeStore: unable to get item " + i +
						" from SelectPTObject.");
				
			}
		}

		
			log.Debug("DoTaskBeforeStore: clsid   = " + m_sProviderCLSID);
			log.Debug("DoTaskBeforeStore: partner = " + m_nPartnerID);
		

		try
		{
			// mj: store the group list
			ptPS.SetGroupList(anGroups);

			// mj: store provider clsid
			ptPS.SetProviderCLSID(m_sProviderCLSID);

			// mj: store the auth source partner
			ptPS.SetAuthSourcePartner(m_nPartnerID);
		}
		catch (Exception e)
		{
			
				log.Error(e, "DoTaskBeforeStore: exception while setting Profile Source properties.");
			
		}

		//This is a 2 dim array 0,0=property ID, 1,0=mapped element
		try
		{
			if (null != m_arrPropMapInfo)
			{
				ptPS.SetPropertyMap(m_arrPropMapInfo);
				
				// aj: bug 26284, clear history if the property map has
				//     changed...
				if(PropertyMapHasChanged())
				{
					ptPS.ClearHistory();
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error("ProfileSourceModel::DoTaskBeforeStore: Unable to set the property map information" +
					". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(638,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStoreSetJob();
		}
		catch (Exception e)
		{
			
				log.Error("ProfileSourceModel::DoTaskBeforeStore: Unable to store the job information. " +
					"The following exception occured: " + e);
			
		}
	}

	/**
	 * Does a simple match of the original prop map info
	 * vs. the new one.  If it differs, we return true...
	 * 
	 * @return - true if the propmap has changed, false otherwise...
	 */
	protected boolean PropertyMapHasChanged()
	{
		// aj: m_arrPropMapInfo will be null if the property map page has not
		//     been visited (e.g.  the prop map hasn't been edited)
		if(m_arrPropMapInfo == null)
		{
			return false;
		}
		
		// aj: if the prop map has been visited, then check array lengths for a
		//     fail fast condition...
		if((m_arrOriginalPropMapInfo == null && m_arrPropMapInfo[0].length > 0)
				|| (m_arrOriginalPropMapInfo != null 
						&& m_arrOriginalPropMapInfo[0].length != m_arrPropMapInfo[0].length
					)
			)
		{
			return true;
		}
		
		// aj: if original is null at this point, we're false since our last check
		//     didn't cause us to return true (e.g. both lists are empty)
		if(m_arrOriginalPropMapInfo == null)
		{
			return false;
		}
		
		// aj: finally do the comparison of actual values
		int nLength = m_arrOriginalPropMapInfo[0].length;
		for(int i=0; i<nLength; i++)
		{
			int nPropID = XPConvert.ToInteger(m_arrPropMapInfo[0][i]);
			String sMappingName = XPConvert.ToString(m_arrPropMapInfo[1][i]);
			
			boolean bMatchedEntry = false;
			for(int j=0; j<nLength; j++)
			{
				int nOrigPropID = XPConvert.ToInteger(m_arrOriginalPropMapInfo[0][j]);
				String sOrigMappingName = XPConvert.ToString(m_arrOriginalPropMapInfo[1][j]);
				
				// aj: if we get a match mark it and break...
				if(nPropID == nOrigPropID 
						&& XPStringUtility.EqualsIgnoreCase(sMappingName, sOrigMappingName)
					)
				{
					bMatchedEntry = true;
					break;
				}
			}
			
			if(!bMatchedEntry)
			{
				return true;
			}
		}
		
		// aj: if we get here, then there was no change...
		return false;
	}
	
	/**
	 * This method will be called when you come back to the main Editor from a
	 * sub Editor.
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();

		((SelectPTObjectModel) m_asOwner.GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB)).DoTaskOnComeBackFromSubEditor();
	}

	/**
	 * Code executed when the Editor is starting.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		StartPropMapList();
		
		// aj: save the original prop map list
		m_arrOriginalPropMapInfo = ((IPTProfileSource) m_ptObject).GetPropertyMap();

		// Do not display the security page in create mode.
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
		}

		// mj: init the SelectPTObject plug-in
		StartSelectPTObject();

		((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).DoTaskOnStartSetJob(m_ptObject,
			m_Session, GetEditorType());

		// mj: init auth partner list
		InitAuthPartners();

		// mj: init defaults
		m_nPartnerID		 = PT_INTRINSICS.PT_NULL_OBJECTID;
		m_sProviderCLSID     = GetProviderCLSID();

		// mj: if we're editing the object, populate member variables
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			IPTProfileSource ptPS = (IPTProfileSource) m_ptObject;

			try
			{
				m_nPartnerID = ptPS.GetAuthSourcePartner();
			}
			catch (Exception e)
			{
				Error("DoTaskOnStartEditor", e,
					m_asOwner.GetString(640, "ptmsgs_portaladminmsgs"));
			}

			try
			{
				PopulateSelectPTObject((Object[]) ptPS.GetGroupList());
			}
			catch (Exception e)
			{
				Error("DoTaskOnStartEditor", e,
					m_asOwner.GetString(641, "ptmsgs_portaladminmsgs"));
			}
		}
		
		// aj: the default is empty, this will get set on a repost...
		m_sUniqueKeyTreePickerSpaceID	= "";
		
		// aj: prop name is empty by default
		m_strUniqueKeyPropertyName = GetPropName(((IPTProfileSource) m_ptObject).GetPortalUniqueKey());

	}

    /**
     * Repost action for clearing the history
     *
     */
    public void ClearHistory()
    {
    	// aj: this doesn't happen in real-time anymore, it will happen
    	//     the next time the profile sync agent is run.  this prevents
    	//     browser timeouts when there are a lot of signatures to 
    	//     delete
        ((IPTProfileSource) m_ptObject).ClearHistory();
    }

	/**
	 * Returns the partner list
	 *
	 * @return String[][]
	 */
	public String[][] GetPartnerList()
	{
		return m_asAuthPartners;
	}

	/**
	 * Returns the selected partner id
	 *
	 * @return int
	 */
	public int GetSelectedPartner()
	{
		return m_nPartnerID;
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus;
		
		// aj: always save the parent first
		nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(MainDP.STR_MVC_CLASS_NAME) 
				&& ProfileSourceRepostControl.PAGE_STATUS_VALID == nPageStatus)
		{
			nPageStatus = SaveMainPage(_htFormData);
		}
		else if (_sPageName.equals(PropertyMapDP.STR_MVC_CLASS_NAME)
				&& ProfileSourceRepostControl.PAGE_STATUS_VALID == nPageStatus)
		{
			nPageStatus = SavePropMapPage(_htFormData);
		}
		else if (_sPageName.equals(SetJobDP.STR_MVC_CLASS_NAME)
				&& ProfileSourceRepostControl.PAGE_STATUS_VALID == nPageStatus)
		{
			((SetJobModel) m_asOwner.GetModel(SetJobModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
		}

		return nPageStatus;
	}

	/**
	 * Saves the main page - auth partners, group/user selection and unique key chooser.
	 * 
	 * @param _htFormData
	 */
	protected int SaveMainPage(XPHashtable _htFormData) {
		((SelectPTObjectModel) m_asOwner.GetModel(ProfileSourceEditorAS.strStorageSelectPTObject)).SaveSection(_htFormData);

		String[] asVals;
		
		try
		{
			asVals = (String[]) _htFormData.GetElement(AuthPartnerView.SELECT_AUTHSOURCE);
			m_nPartnerID = XPConvert.ToInteger(asVals[0]);
		}
		catch (Exception e)
		{
			// mj: this might be because no auth sources were available. ignore the error.
			//if ( log.IsErrorEnabled() )
			//log.Error(e, "SavePage: unable to retrieve the auth partner.");
		}
		
		try{
			asVals = (String[]) _htFormData.GetElement(UniqueKeyChooserView.RADIO_UNIQUEKEY);
			int nUniqueKeyValue = XPConvert.ToInteger(asVals[0]);
			int nChoosenProp = 0;
			
			switch(nUniqueKeyValue)
			{
				case(UniqueKeyChooserView.USER_UNIQUE_NAME):
					nChoosenProp = PT_PROFILE_UNIQUE_KEYS.USER_UNIQUE_NAME;
					break;
				case(UniqueKeyChooserView.USER_AUTH_NAME):
					nChoosenProp = PT_PROFILE_UNIQUE_KEYS.USER_AUTHENTICATION_NAME;
					break;
				
				case(UniqueKeyChooserView.USER_PROP):
					int nTreeProp = RefreshPropertyFromTree();
				
					// aj: raise error if we didn't get a value from the tree,
					//     and nothing is already set...
					if(nTreeProp == 0 && GetUniqueKey() <= 0)
					{
						PlumtreeHelpers.SetUIError(
								m_asOwner, 
								OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN), 
								"ProfileSourceModel::SaveMainPage", 
								null, 
								false, 
								UIErrorLevel.SERIOUS, 
								m_asOwner.GetString(3130, ResourceConstants.PORTALADMINMSGS));
						return ProfileSourceRepostControl.PAGE_STATUS_INVALID;
					} else {
						// aj: otherwise use the prop from the tree...
						if(nTreeProp > 0)
						{
							nChoosenProp = nTreeProp;
						} else {
							nChoosenProp = GetUniqueKey();
						}
					}
				
					break;
				
				default:
					nChoosenProp = PT_PROFILE_UNIQUE_KEYS.USER_UNIQUE_NAME;
			}
			
			// aj: set the value on the object...
			SetUniqueKey(nChoosenProp);
		} catch (Exception e)
		{
			log.Error(e, "An error occurred while saving the main page of a Profile Source.");
			return ProfileSourceRepostControl.PAGE_STATUS_INVALID;
		}
		
		// aj: grab the space id for the tree picker
		asVals = (String[]) _htFormData.GetElement(UniqueKeyChooserView.HTMLHIDDEN_UNIQUEKEY_PROPERTY_SPACE);
		m_sUniqueKeyTreePickerSpaceID = (((asVals.length > 0) && (asVals[0] != null))?(asVals[0]):(""));
		
		return ProfileSourceRepostControl.PAGE_STATUS_VALID;
	}
	
	private int RefreshPropertyFromTree()
	{
		int nUniqueKeyValue = 0;
		
		try
		{
			if (m_asOwner.GetSubSpaceExists(
						ProfileSourceEditorAS.strUniqueKeyTree_SUBSPACE))
			{
				// aj: if the subspace exists, someone choose something - so clear what we had
				m_strUniqueKeyPropertyName = "";
				
				AActivitySpace asTree  = m_asOwner.GetSubSpace(ProfileSourceEditorAS.strUniqueKeyTree_SUBSPACE);
				ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList itemList   = treeModel.GetSelectedItems();
	
				// aj: should be size 0 or 1
				if (itemList.GetSize() > 0)
				{
					TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
	
					if (item == null)
					{
							log.Error("Tree selected item null");	
					} else 
					{
						nUniqueKeyValue = item.m_nObjectID;
						m_strUniqueKeyPropertyName	    = item.GetName();
					}
				}
			}
		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			log.Warn("Unknown Error RefreshItemFromTree: e: " + e.getMessage());
		}
		
		return nUniqueKeyValue;
	}

	/**
	 * Sets the selected partner
	 *
	 * @param nID The ID for the selected partner
	 */
	public void SetSelectedPartner(int nID)
	{
		m_nPartnerID = nID;
	}

	public static String GetUserProperties(IPTSession ptSession)
	{
		try
		{
			IPTObjectPropertyMap ptPropMap = (IPTObjectPropertyMap)
				ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP, false);

			IPTQueryResult ptQR =
				ptPropMap.QueryClassPropertyMappings(PT_CLASSIDS.PT_USER_ID, PT_PROPIDS.PT_PROPID_OBJECTID);

			int nCount = ptQR.RowCount();
			if (nCount > 0)
			{
				XPStringBuilder sb = new XPStringBuilder(nCount*8);
				String sClass = "" + PT_CLASSIDS.PT_PROPERTY_ID + ',';

				for (int i = 0; i < nCount; i++)
				{
					if (i > 0)
					{
						sb.Append(',');
					}

					sb.Append(sClass).Append(ptQR.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID));
				}

				return sb.ToString();
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "An error occurred when trying get the list of valid user properties.");
			
		}

		return null;
	}

	/**
	 * Initializes the multi-column list for mapping properties
	 */
	public void StartPropMapList()
	{
		PTMultiColumnListModel myListModel = (PTMultiColumnListModel) m_asOwner.GetModel(ProfileSourceEditorAS.strPTMultiColumnList);

		//Set the number of columns.
		//Login form page
		myListModel.SetNumColumns(MAPLIST_NUMCOLUMNS);
		myListModel.SetIncludePTSelect(true);
		myListModel.SetPTObjectPosition(MAPLIST_PTOBJECTPOSITION);

		String[] arrPropMapSubTitles = new String[MAPLIST_NUMCOLUMNS];

		arrPropMapSubTitles[0] = m_asOwner.GetString(633,
				"ptmsgs_portaladminmsgs");

		myListModel.InitializePTMultiColumnList(m_asOwner.GetString(631,
				"ptmsgs_portaladminmsgs"),

		m_asOwner.GetString(632, "ptmsgs_portaladminmsgs"),
			arrPropMapSubTitles, PTImageType.ICON_PROPERTY,

		m_asOwner.GetString(634, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_PROPERTY_ID }, 2);

		// Use the method below to set the value to populate a newly created input text.
		// (By default it will be a null array, so it MUST be initialized.
		//Login form page
		String[] arrPropMapDefaults = new String[MAPLIST_NUMCOLUMNS];

		arrPropMapDefaults[0] = m_asOwner.GetString(639,
				"ptmsgs_portaladminmsgs");
		myListModel.SetDefaultValue(arrPropMapDefaults);

		myListModel.SetRowIcon(PTImageType.ICON_PROPERTY);
		myListModel.SetTreeMultiSelect(true);
		myListModel.SetTreeSubTitle(m_asOwner.GetString(539, "ptmsgs_portaladminmsgs"));
		myListModel.SetTreeTitle(m_asOwner.GetString(538, "ptmsgs_portaladminmsgs"));

		// mj: restrict the list to user properties
		myListModel.SetDisplayObjects(GetUserProperties(m_Session));

		//Set the message and instructions to display when the list is empty.
		myListModel.SetEmptyListMessages(m_asOwner.GetString(635,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(636, "ptmsgs_portaladminmsgs"));

		//Get the name value pairs from the model in edit mode,
		//and populate them in here
		try
		{
			IPTProfileSource ptPS = (IPTProfileSource) m_ptObject;
			Object[][] arrMap;
			arrMap = (Object[][]) ptPS.GetPropertyMap();
			
			if (arrMap[0].length > 0)
			{
				int intCount = arrMap[0].length;

				if (intCount > 0)
				{
					//String strObjName;
					String[] arrNames = new String[intCount];

					int nRowCount = 0;

					PTObjectManagerQueryWrapper omqrProperty = new PTObjectManagerQueryWrapper(m_Session.GetProperties());

					//for each row, set the elements of the row growable array
					for (int i = 0; i < intCount; i++)
					{
						// get the name
						int intObjID = XPConvert.ToInteger(arrMap[0][i]);
						omqrProperty.QuerySingleObject(intObjID);

						// mj: only add the row to the map if the property still exists
						if (1 == omqrProperty.GetCount())
						{
							arrNames[nRowCount] = (String) omqrProperty.GetFields(0,
									PT_PROPIDS.PT_PROPID_NAME);
							if (i != nRowCount)
							{
								arrMap[0][nRowCount] = arrMap[0][i];
								arrMap[1][nRowCount] = arrMap[1][i];
							}

							nRowCount++;
						}
					}

					if (nRowCount > 0)
					{
						Object[][] oRows  = new Object[nRowCount][MAPLIST_NUMCOLUMNS + 4];

						for (int i = 0; i < nRowCount; i++)
						{
							int intObjID = XPConvert.ToInteger(arrMap[0][i]);
							//omqrProperty.QuerySingleObject(intObjID);

							// Set the class ID
							oRows[i][PTMultiColumnListModel.EXPLIST_COL_CLASSID +
							MAPLIST_PTOBJECTPOSITION] = new Integer(PT_CLASSIDS.PT_PROPERTY_ID);

							// Set the Object ID
							oRows[i][PTMultiColumnListModel.EXPLIST_COL_OBJECTID +
							MAPLIST_PTOBJECTPOSITION] = new Integer(intObjID);

							// Set the Object name
							oRows[i][PTMultiColumnListModel.EXPLIST_COL_STRING +
							MAPLIST_PTOBJECTPOSITION] = arrNames[i];

							// Set the mapped UserInfo element
							if (1 == MAPLIST_PTOBJECTPOSITION)
							{
								oRows[i][1] = (String) arrMap[1][i];
							}
							else
							{
								oRows[i][4] = (String) arrMap[1][i];
							}
						}

						// Then add the array to the list
						myListModel.SetDefaultObjects(oRows);
					}
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error("ProfileSourceModel::StartPropMapList	An error occurred when trying populate the property map select list.  Exception: " +
					e);
			
		}
	}

	/**
	 * Method Error.
	 *
	 * @param e
	 * @param sMethod
	 * @param sMessage "ptmsgs_portaladminmsgs")
	 * @throws XPException
	 */
	protected static void Error(String sMethod, Exception e, String sMessage)

	{
		
			XPStringBuilder sbErr = new XPStringBuilder(128);
			sbErr.Append(sMethod).Append(": ").Append(sMessage);
			log.Error(e, sbErr.ToString());
		

		//throw new XPException(sMessage, e);
	}

	/**
	 * Method InitAuthPartners.
	 */
	protected void InitAuthPartners()
	{
		PTObjectManagerQueryWrapper query = new PTObjectManagerQueryWrapper(m_Session.GetAuthSources());

		// mj: sort array; we want to sort by name
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = PT_PROPIDS.PT_PROPID_NAME;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// mj: construct query filter to include only ldap auth sources
		Object[][] arrFilter = GetPartnerQueryFilter();

		// mj: run the query
		query.Query(PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_OBJECTID,
			-1, arrSort, arrFilter);

		int nFirst = 0;

		if (IsPartnerMandatory())
		{
			// mj: init and fill our array
			m_asAuthPartners = new String[query.GetCount()][2];
		}
		else
		{
			// mj: no partner option
			m_asAuthPartners     = new String[query.GetCount() + 1][2];

			m_asAuthPartners[0][0]     = XPConvert.ToString(PT_INTRINSICS.PT_NULL_OBJECTID);
			m_asAuthPartners[0][1]     = m_asOwner.GetString(642,
					"ptmsgs_portaladminmsgs");
			nFirst					   = 1;
		}

		for (int i = 0; i < query.GetCount(); i++)
		{
			int id					    = XPConvert.ToInteger(query.GetItem(i,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String sName				    = (String) query.GetItem(i,
					PT_PROPIDS.PT_PROPID_NAME);
			m_asAuthPartners[i + nFirst][0] = XPConvert.ToString(id);
			m_asAuthPartners[i + nFirst][1] = sName;
		}
	}

	/**
	 * Populates the Group Select PTObject with data
	 *
	 * @param aoGroups Object[]
	 */
	protected void PopulateSelectPTObject(Object[] aoGroups)
	{
		// mj: if it's null or empty, do nothing
		if ((aoGroups == null) || (aoGroups.length == 0))
		{
			return;
		}

		//     Use the code below to initialize the list with preselected objects.
		Object[][] oRows = new Object[aoGroups.length][SelectPTObjectModel.EXPLIST_COL_MAX];

		// mj: cache the user and group managers
		PTObjectManagerQueryWrapper userQuery  = new PTObjectManagerQueryWrapper(m_Session.GetUsers());
		PTObjectManagerQueryWrapper groupQuery = new PTObjectManagerQueryWrapper(m_Session.GetUserGroups());

		int nOut = 0;

		for (int i = 0; i < aoGroups.length; i++)
		{
			// JF- The 2 lines below are only needed if you are going to enable the move row actions
			//oRows[0][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer( mySelectPTObjectModel.m_nNextIndex );
			//mySelectPTObjectModel.m_nNextIndex ++;
			// mj: if the id is < 0, it's really an individual user
			int nID = XPConvert.ToInteger(aoGroups[i]);

			// mj: we will set these two variables differently if it's a user
			PTObjectManagerQueryWrapper query = groupQuery;
			int nClassID					  = PT_CLASSIDS.PT_USERGROUP_ID;

			// mj: user ids are stored as negative
			if (nID < 0)
			{
				nID			 = -nID;
				query		 = userQuery;
				nClassID     = PT_CLASSIDS.PT_USER_ID;
			}

			try
			{
				// mj: do the query
				query.QuerySingleObject(nID);
				//JH - check here to make sure the group (or user) has not been deleted from the system
				if ( query.GetCount() > 0 )
				{
					String sName = (String) query.GetItem(0,
							PT_PROPIDS.PT_PROPID_NAME);

					// mj: set the row contents
					oRows[nOut][SelectPTObjectModel.EXPLIST_COL_CLASSID]	   = new Integer(nClassID);
					oRows[nOut][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = new Integer(nID);
					oRows[nOut][SelectPTObjectModel.EXPLIST_COL_STRING]	   = sName;
					nOut++;
				}
			}
			catch (Exception e)
			{
				
					log.Error(e, "PopulateSelectPTObject: unable to query for " +
						((nClassID == PT_CLASSIDS.PT_USER_ID) ? "user" : "group") +
						" id " + nID);
				
			}
		}

		// JF- Then add the array to the list
		//JH - First check that we actually added anything to the array - we may not have if the groups
		//referenced have been deleted
		if (nOut > 0)
		{
			// mj: resize the array if necessary
			if (nOut < aoGroups.length)
			{
				Object[][] oTemp = new Object[nOut][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nOut; i++)
				{
					for (int j = 0; j < SelectPTObjectModel.EXPLIST_COL_MAX; j++)
					{
						oTemp[i][j] = oRows[i][j];
					}
				}

				oRows = oTemp;
			}
			SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(ProfileSourceEditorAS.strStorageSelectPTObject);
			mySelectPTObjectModel.SetDefaultObjects(oRows);
		}
	}

	/**
	 * Saves the data on the property map page.
	 *
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 * @throws XPException
	 */
	protected int SavePropMapPage(XPHashtable _htFormData)
	{
		try
		{
			((PTMultiColumnListModel) m_asOwner.GetModel(ProfileSourceEditorAS.strPTMultiColumnList)).SaveSection(_htFormData);

			//Now retrieve the non Plumtree select elements
			Object[][] arrMappingInfo = ((PTMultiColumnListModel) m_asOwner.GetModel(ProfileSourceEditorAS.strPTMultiColumnList)).GetListValues();

			PTGrowableSortedArrayWrapper arrItems;
			arrItems = ((PTMultiColumnListModel) m_asOwner.GetModel(ProfileSourceEditorAS.strPTMultiColumnList)).GetItems();

			int intNumItems = arrItems.GetCount();

			m_arrPropMapInfo = new Object[2][intNumItems];

			if (intNumItems > 0)
			{
				for (int i = 0; i < intNumItems; i++)
				{
					m_arrPropMapInfo[0][i]     = arrItems.GetItem(i,
							PTMultiColumnListModel.EXPLIST_COL_OBJECTID +
							MAPLIST_PTOBJECTPOSITION);
					m_arrPropMapInfo[1][i]     = arrMappingInfo[0][i];
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error("ProfileSourceModel::SavePropMapPage " +
					m_asOwner.GetString(637, "ptmsgs_portaladminmsgs") + "  " +
					"The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(637,
					"ptmsgs_portaladminmsgs"), e);
		}

		return ProfileSourceRepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Helper method to start the Select PTObject List.
	 */
	protected void StartSelectPTObject()
	{
		ProfileSourceSelectPTObjectModel mySelectPTObjectModel = (ProfileSourceSelectPTObjectModel) m_asOwner.GetModel(ProfileSourceEditorAS.strStorageSelectPTObject);

		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(
				643, "ptmsgs_portaladminmsgs"),

		m_asOwner.GetString(644, "ptmsgs_portaladminmsgs"),
			PTImageType.ICON_MEMBER,

		m_asOwner.GetString(645, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_USER_ID, PT_CLASSIDS.PT_USERGROUP_ID }, 1);

		// mj: set tree title
		mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(643, "ptmsgs_portaladminmsgs"));

		// ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
		//     Use the method below to set the icon to display on each row.
		//     (By default there will be no icon.)
		mySelectPTObjectModel.SetRowIconByClassID(PT_CLASSIDS.PT_USER_ID,
			PTImageType.ICON_USER);
		// set icon for groups
		mySelectPTObjectModel.SetRowIconByClassID(PT_CLASSIDS.PT_USERGROUP_ID,
			PTImageType.ICON_GROUP);

		// ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
		//     Use the method below to set the message and instructions to display when the list is empty.
		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(646,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(647, "ptmsgs_portaladminmsgs"));
	}

	// AGC- Added this because it is defined in IProfileSourceModelRO
	// Abstract classes in .NET must define each method in an interface.
	// This code wasn't jumping.
	public abstract String GetPropertyMapInstructions();
	
	public int GetUniqueKey()
	{
		IPTProfileSource ptPS = (IPTProfileSource) m_ptObject;
		return ptPS.GetPortalUniqueKey();
	}

	public void SetUniqueKey(int nUniqueKey)
	{
		// aj: set the unique key directly on the profile source object,
		//     an exception will be thrown if the key is invalid
		IPTProfileSource ptPS = (IPTProfileSource) m_ptObject;
		ptPS.SetPortalUniqueKey(nUniqueKey);
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.profilesource.IProfileSourceModelRO#GetUniqueKeyPropertyName()
	 */
	public String GetUniqueKeyPropertyName() {
		return m_strUniqueKeyPropertyName;
	}
	
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.profilesource.IProfileSourceModelRO#GetUserProperties()
	 */
	public String GetUserProperties() {
		return GetUserProperties(m_Session);
	}
	
	/**
	 * Helper to lookup the property name given a property ID.  Will only match
	 * properties that are properly mapped to the user object.
	 * 
	 * @param nPropID - property id to resolve
	 * @return a String that represents the name of the property.  empty-String if the property
	 * 	doesn't exist or is not mapped to the user object. 
	 */
	public String GetPropName(int nPropID)
	{
		String sName = "";
		try
		{
			IPTObjectPropertyMap ptPropMap = (IPTObjectPropertyMap)
				m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_OBJECTPROPERTYMAP, false);

			IPTQueryResult ptQR =
				ptPropMap.QueryClassPropertyMappings(PT_CLASSIDS.PT_USER_ID, PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME);

			int nCount = ptQR.RowCount();
			for(int i=0; i<nCount; i++)
			{
				int nCurrPropID = ptQR.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				if(nCurrPropID == nPropID)
				{
					sName = ptQR.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
					break;
				}
			}
		}
		catch (Exception e)
		{
				log.Error(e, "An error occurred when trying looking up the property name.");
		}

		return sName;
	}
	
	public String GetUniqueKeyPickerSpaceID()
	{
		return m_sUniqueKeyTreePickerSpaceID;
	}
}

