package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.portaluiinfrastructure.editor.*;

/**
 * Read-only interface for property model.
 *
 * @author josephc
 */
public interface IPropModelRO extends IObjEditorModelRO
{
	/**
	 * Return pick list validation function
	 *
	 * @return Pick list validation function
	 */
	public String GetManagedPicklistValidationFunction();

	/**
	 * Returns name of database table used for pick table
	 *
	 * @return Name of database table used for pick table
	 */
	public String GetPickTable();

	/**
	 * Returns pick table types (PT_PICKTABLE_TYPES)
	 *
	 * @return Pick type
	 */
	public int GetPickType();

	/**
	 * Returns property type (PT_PROPERTY_TYPES)
	 *
	 * @return Property type
	 */
	public int GetPropertyType();

	/**
	 * Returns reference class
	 *
	 * @return Reference class
	 */
	public int GetReferenceClass();

	/**
	 * Returns true if property is always a card property
	 *
	 * @return True if property is always a card property
	 */
	public boolean IsAlwaysCardProperty();

	/**
	 * Returns true if property is a card property
	 *
	 * @return True if property is a card property
	 */
	public boolean IsCardProperty();

	/**
	 * Returns true if property is mandatory
	 *
	 * @return True if property is mandatory
	 */
	public boolean IsMandatory();

	/**
	 * Returns true if property is multi-valued
	 *
	 * @return True if property is multi-valued
	 */
	public boolean IsMultiValued();

	/**
	 * Returns true if property is searchable
	 *
	 * @return True if property is searchable
	 */
	public boolean IsSearchable();

	/**
	 * Returns true if property is an URL
	 *
	 * @return True if property is an URL
	 */
	public boolean IsURL();

	/**
	 * Returns true if property is visible
	 *
	 * @return True if property is visible
	 */
	public boolean IsVisible();

	/**
	 * Returns true if property is read-only
	 *
	 * @return True if property is read-only
	 */
	public boolean IsReadOnly();
}

