package com.plumtree.portalpages.admin.editors.property;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Main display page for property editor
 *
 * @author josephc
 */
public class MainDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.property.MainDP");

	/** Class name for MainDP */
	public static final String STR_MVC_CLASS_NAME = "PropMain";

	/** JavaScript function name for managed picklist validation */
	public static final String JAVASCRIPT_VALIDATE_MANAGEDPICKLIST = "PropValidateManagedPicklist";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(655, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay()
	{
		IPropModelRO asModel = (IPropModelRO) m_asOwner.GetModel(PropModel.STR_MVC_CLASS_NAME);

		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(SettingsView.STR_MVC_CLASS_NAME)).Display());

		if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF != asModel.GetPropertyType() &&
			PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != asModel.GetPropertyType())
		{
			switch (asModel.GetPickType())
			{
			case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST:
				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
				views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PropEditorAS.strPickListValuesList)).Display());

				break;

			case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
			case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
				views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PickTableView.STR_MVC_CLASS_NAME)).Display());

				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
				views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(PropEditorAS.strPickTableColumnList)).Display());

				break;

			default:
				break;
			}
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 * @throws XPException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(PropEditorAS.strPickListValuesList).DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(PropEditorAS.strPickTableColumnList).DisplayJavascript());

		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		XPStringBuilder sb;

		IPropModelRO asModel = (IPropModelRO) m_asOwner.GetModel(PropModel.STR_MVC_CLASS_NAME);
		String sJSFunctionName = asModel.GetManagedPicklistValidationFunction();

		try
		{
			// Validate Managed Picklist function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JAVASCRIPT_VALIDATE_MANAGEDPICKLIST).Append("(cardID)\n");
			sb.Append("{\n");
			sb.Append("  if (null != document.").Append(EditorDP.HTMLFORM_NAME).Append(".").Append(SettingsView.HTMLSELECT_PICKTYPE).Append(")\n");
			sb.Append("  {\n");
			sb.Append("    if (\"").Append(PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST).Append("\" == document.").Append(EditorDP.HTMLFORM_NAME).Append(".").Append(SettingsView.HTMLSELECT_PICKTYPE).Append(".value) \n");
			sb.Append("    {\n");
			sb.Append("       return ").Append(sJSFunctionName).Append("();\n");
			sb.Append("    }\n");
			sb.Append("  }\n");
			sb.Append("  return true;\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
			myScripts.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DirEditDP::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.getMessage());
			

			throw new XPException(m_asOwner.GetString(653, "ptmsgs_portaladminmsgs"), he);
		}

		return myScripts;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1685, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}
}

