package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * Model for pick list values list plugin.  This model is required for validation of
 * pick list values.
 *
 * @author josephc
 */
public class PickListValuesListModel extends GrowableListModel implements IGrowableListModelRO
{
	/** Class name for PickListValuesListModel */
	public static final String STR_MVC_CLASS_NAME = "PickListValuesList";

	/** Property type */
	private int m_nPropType;

	/**
	 * Creates a new PickListValuesListModel object.
	 */
	public PickListValuesListModel()
	{
		super();
		m_nPropType = PT_PROPERTY_TYPES.PT_PROPTYPE_INVALID;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PickListValuesListModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Sets the property type, and removes all rows in the list.
	 *
	 * @param _nPropType Property type
	 */
	public void ResetPickList(int _nPropType)
	{
		m_nPropType = _nPropType;

		m_saData.ClearArray();
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData)
	{
		String sDataKey = GetUniqueString(GrowableListView.HTMLINPUT_ITEM) + _nRowIndex;
		String[] aDataValue;

		// JF- For each input text posted by the form, we get the value back 
		// and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				String strValue = aDataValue[0];

				try
				{
					// TODO: Currently we will save the value even if it is invalid.  Currently, server-side validation
					// only takes place when page is changed or editor is finished.
					_saData.SetItem(_nRowIndex, EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT, strValue);

					// TODO: Validate value by attempting to convert it into an object. An exception will be thrown if the
					// string is invalid and cannot be converted.  Ideally this would be called before we set the value in
					// the list.
					ObjPropModel.GetPropValueFromString(strValue, m_nPropType);
				}
				catch (Exception e)
				{
					String strErrorMsg = m_asOwner.GetString(1864, "ptmsgs_portaladminmsgs") + strValue;
					UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, strErrorMsg, strErrorMsg);
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

					return RepostControl.PAGE_STATUS_INVALID;
				}
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
}

