package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View for entering database table name for a pick table
 *
 * @author josephc
 */
public class PickTableView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.property.PickTableView");

	/** Class name for PickTableView */
	public static final String STR_MVC_CLASS_NAME = "PickTableView";

	/** Input name for pick table */
	public static final String HTMLINPUT_PICKTABLE = "in_tx_PickTable";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PickTableView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLInput myInput;

		try
		{
			String strPickTable = ((IPropModelRO) m_model).GetPickTable();

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(657, "ptmsgs_portaladminmsgs")));

			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding(CommonHTMLStrings.FIVE);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			myCell.SetWidth("150");
			myCell.SetVAlign(CommonHTMLStrings.TOP);

			myCell.AddInnerHTMLString(m_asOwner.GetString(658, "ptmsgs_portaladminmsgs"));

			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_PICKTABLE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(32);
			myInput.SetSize(50);

			if (null != strPickTable)
			{
				myInput.SetValue(strPickTable);
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "PickTableView::Display The following error occured when trying to display the HTML: " + e.getMessage());
			

			throw new XPException(m_asOwner.GetString(656, "ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

