package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author josephc
 */
public class PickTreeColumnsListModel extends MultiColumnListModel implements IMultiColumnListModelRO
{
	/** Class name for PickTreeColumnsListModel */
	public static final String STR_MVC_CLASS_NAME = "PickTreeColumnsList";

	/** Pick table type */
	protected int m_nPickType;

	/**
	 * Creates a new PickTreeColumnsListModel object.
	 */
	public PickTreeColumnsListModel()
	{
		super();
		m_nPickType = PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_INVALID;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PickTreeColumnsListModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @param _nPickType
	 */
	public void SetPickType(int _nPickType)
	{
		m_nPickType = _nPickType;

		switch (m_nPickType)
		{
		case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE:
			SetIsListReadOnly(false);

			break;

		case PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST:
			SetIsListReadOnly(true);

			break;
		}
	}

	/**
	 *
	 */
	public void ClearColumns()
	{
		m_saData.ClearArray();

		Object[][] arrDefault = new String[2][1];
		arrDefault[0][0]     = m_arrDefaultValue[0];
		arrDefault[1][0]     = m_arrDefaultValue[1];
		AddRowsToList(arrDefault);
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 *
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData)
	{
		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append(MultiColumnListView.HTMLINPUT_ITEM);

		int nStatus = RepostControl.PAGE_STATUS_VALID;

		for (int i = 1; i <= m_intNumColumns; i++)
		{
			String sDataKey = GetUniqueString(sb.Append(i).ToString()) + _nRowIndex;
			String[] aDataValue;

			// JF- For each input text posted by the form, we get the value back
			// and set the new value in the array.
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && (0 != aDataValue.length))
			{
				String strValue = aDataValue[0];

				if ((null != strValue) && (0 != strValue.length()))
				{
					_saData.SetItem(_nRowIndex, i, strValue);
				}
				else
				{
					// raise error to display to user
					String strColumnName;

					if (1 == i)
					{
						strColumnName = m_asOwner.GetString(676, "ptmsgs_portaladminmsgs");
					}
					else
					{
						strColumnName = m_asOwner.GetString(678, "ptmsgs_portaladminmsgs");
					}

					String strErrorMsg = XPResourceManager.FormatMessage(m_asOwner.GetString(2515, "ptmsgs_portaladminmsgs"), strColumnName, XPConvert.ToString(_nRowIndex + 1));
					UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, strErrorMsg, strErrorMsg);
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

					nStatus = RepostControl.PAGE_STATUS_INVALID;
				}
			}
		}

		return nStatus;
	}
}

