package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Activity space for property editor
 *
 * @author josephc
 */
public class PropEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.property.PropEditorAS");

	/** Class name for PropEditorAS */
	public static final String STR_MVC_CLASS_NAME = "PropEditor";

	/** Class name */
	private static final String sClassName = "com.plumtree.portalpages.admin.editors.property.PropEditorAS";

	/** Storage name for growable pick list values */
	public static final String strPickListValuesList = "PickListValuesList";

	/** Storage name for pick table columns */
	public static final String strPickTableColumnList = "PickTableColumnList";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PropEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (PropDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType())
		{
			return GetString(659, "ptmsgs_portaladminmsgs");
		}
		else
		{
			return XPResourceManager.FormatMessage(GetString(660, "ptmsgs_portaladminmsgs"), GetObjectName());
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (PropRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = PropModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		RegisterPage(new MainDP());

		// Register Views
		RegisterView(SettingsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(PickTableView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(PropDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(PropRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Picklist Growable list
		RegisterModel(PickListValuesListModel.STR_MVC_CLASS_NAME, strPickListValuesList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myPickListValuesListModel = GetModel(strPickListValuesList);
		RegisterView(GrowableListView.STR_MVC_CLASS_NAME, strPickListValuesList, myPickListValuesListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strPickListValuesList, myPickListValuesListModel);

		// PickTree Column List
		RegisterModel(PickTreeColumnsListModel.STR_MVC_CLASS_NAME, strPickTableColumnList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myPickTreeColumnList = GetModel(strPickTableColumnList);
		RegisterView(MultiColumnListView.STR_MVC_CLASS_NAME, strPickTableColumnList, myPickTreeColumnList);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strPickTableColumnList, myPickTreeColumnList);

		// Default page
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(661, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(2187, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );


				int iTitleId = 57;
				int iTipId = 58;
				int iSecondaryTipId = 59;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}

		//	Got the tips model
	}
	
	/**
	 * Set the help page for this editor. 
	 *
	 * @param page 
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);
		String sPageName = page.GetName();

		if (MainDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("pt_property_mainsettings");
		}
	}
}

