package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * Repost control for property editor
 */
public class PropRepostControl extends ObjEditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.property.PropRepostControl");

	/** Class name for PropRepostControl */
	public static final String STR_MVC_CLASS_NAME = "PropRepost";

	public final static int POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS = 8;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PropRepostControl();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Perform repost action for property editor. Also calls repost action for pick list
	 * values growable list and pick table column list.
	 *
	 * @param _nAction
	 *
	 * @see com.plumtree.uiinfrastructure.form.RepostControl#PerformAction(int)
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		((ExpListControl) m_asOwner.GetControl(PropEditorAS.strPickListValuesList)).PerformRepostAction(_nAction, m_htFormData);

		((ExpListControl) m_asOwner.GetControl(PropEditorAS.strPickTableColumnList)).PerformRepostAction(_nAction, m_htFormData);
	}
	
	/**
	 * Get the current page name and call the save method on the model. Overrides the default
	 * behavior of SaveCurrentPage so that server-side validation is always enabled
	 * instead of only on change of page or finish of editor.
	 */
	protected void SaveCurrentPage()
	{
		// We always save the data on the page except on cancel.
		if (POSTTOSELF_ACTION_CANCEL != m_nAction)
		{
			// JF- Get back the page name from the form.
			String[] data = (String[]) m_htFormData.GetElement(ASConstants.PAGE_INPUT);

			if (data == null)
			{
				data = (String[]) m_htFormData.GetElement(ASConstants.PAGE);
			}

			if (data == null)
			{
				
					log.Error("RepostControl::SaveCurrentPage The page name has not been posted by the form.");
				

				throw new XPException(
					"Unexpected error when trying to save the current page.");
			}

			if ((0 != data.length) && (null != data[0]))
			{
				// JF- Save the page
				m_nPageStatus = m_model.SavePage(data[0], m_htFormData);

				switch(m_nAction)
				{
					case POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS:
					{
						UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(),
												m_asOwner.GetApplication());

						
							log.Info("RepostControl::SaveCurrentPage Just cleared all errors on UIErrorHandler " +
								"because this is not a Finish or Change Page action.");
																							
					}
					break;
					
					default:
						break;
				}

				// JIC - Enable server side validate for all actions
				/*
				// JF- Only enable server validation when the user is changing page or finishing the Editor.
				if ((POSTTOSELF_ACTION_GOTOPAGE != m_nAction) &&
						(POSTTOSELF_ACTION_FINISH != m_nAction))
				{
					UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(),
						m_asOwner.GetApplication());

					
						log.Info("RepostControl::SaveCurrentPage Just cleared all errors on UIErrorHandler " +
							"because this is not a Finish or Change Page action.");
					
				}
				*/

				
					log.Debug("RepostControl::SaveCurrentPage Saving page: " +
						data[0]);
				
			}
			else
			{
				
					log.Warn("RepostControl::SaveCurrentPage The page name value is invalid. The page will not be saved.");
				
			}
		}
	}
}

