package com.plumtree.portalpages.admin.editors.property;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View for property settings
 *
 * @author josephc
 */
public class SettingsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.property.SettingsView");

	/** Class name for SettingsView */
	public static final String STR_MVC_CLASS_NAME = "PropSettings";

	/** Select for property type */
	public static final String HTMLSELECT_PROPTYPE = "in_se_PropType";

	/** Select for reference class */
	public static final String HTMLSELECT_REFCLASS = "in_se_RefClass";

	/** Select for pick type */
	public static final String HTMLSELECT_PICKTYPE = "in_se_PickType";

	/** Checkbox for visible property */
	public static final String HTMLCHECKBOX_VISIBLE = "in_cb_visible";

	/** Checkbox for read-only property */
	public static final String HTMLCHECKBOX_READONLY = "in_cb_readonly";

	/** Checkbox for card property */
	public static final String HTMLCHECKBOX_CARDPROP = "in_cb_cardprop";

	/** Checkbox for mandatory property */
	public static final String HTMLCHECKBOX_MANDATORY = "in_cb_mandatory";

	/** Checkbox for searchable property */
	public static final String HTMLCHECKBOX_SEARCHABLE = "in_cb_searchable";

	/** Checkbox for URL property */
	public static final String HTMLCHECKBOX_URL = "in_cb_url";

	/** Checkbox for multi-valued property */
	public static final String HTMLCHECKBOX_MULTIVALUED = "in_cb_multivalued";

	/** Array of different pick table types */
	private static int[] m_arPickTableType = new int[]
	{
		PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_NONE,
		PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_MANAGED_PICKLIST,
		PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_UNMANAGED_PICKLIST,
		PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE
	};

	/** Array of property type */
	private static int[] m_arPropertyTypes = new int[]
	{
		PT_PROPERTY_TYPES.PT_PROPTYPE_STRING, PT_PROPERTY_TYPES.PT_PROPTYPE_LONG,
		PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE, PT_PROPERTY_TYPES.PT_PROPTYPE_DATE,
		PT_PROPERTY_TYPES.PT_PROPTYPE_REF, PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED
	};

	/** Array of pick table type names */
	private String[] m_arPickTableTypeNames;

	/** Array of property type names */
	private String[] m_arPropertyNames;



	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SettingsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		IPropModelRO iModelRO = (IPropModelRO) m_model;
		
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableRow myRow;

		try
		{
			boolean bIsAlwaysCardProp = iModelRO.IsAlwaysCardProperty();
			boolean bIsCardProp = iModelRO.IsCardProperty();
			int nPropType = iModelRO.GetPropertyType();
			boolean bIsURL = iModelRO.IsURL();
			int nPickType = iModelRO.GetPickType();
			boolean bIsSearchable = iModelRO.IsSearchable();
			boolean bIsVisible = iModelRO.IsVisible();
			boolean bIsMandatory = iModelRO.IsMandatory();
			boolean bIsMultivalued = iModelRO.IsMultiValued();
			boolean bIsReadOnly = iModelRO.IsReadOnly();
			boolean bIsEncrypted = (PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED == nPropType);
			
			if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == nPropType)
			{
				bIsAlwaysCardProp = true;
			}

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(2015, "ptmsgs_portaladminmsgs")));

			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding(CommonHTMLStrings.FIVE);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);

			// Value type
			myRow = GetPropertyTypeRow(nPropType);
			myTable.AddInnerHTMLElement(myRow);

			myRow = GetCharacteristicsRow(bIsURL, m_asOwner.GetString(2026, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_URL, m_asOwner.GetString(2021, "ptmsgs_portaladminmsgs"), PT_PROPERTY_TYPES.PT_PROPTYPE_STRING != nPropType, false);
			myTable.AddInnerHTMLElement(myRow);

			myRow = GetCharacteristicsRow(bIsCardProp, m_asOwner.GetString(2020, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_CARDPROP, null, bIsAlwaysCardProp, false);
			myTable.AddInnerHTMLElement(myRow);

			myRow = GetCharacteristicsRow(bIsVisible, m_asOwner.GetString(2034, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_VISIBLE, null, false, true);
			myTable.AddInnerHTMLElement(myRow);


			myRow = GetCharacteristicsRow(bIsReadOnly, m_asOwner.GetString(2269, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_READONLY, null, false, true);
			myTable.AddInnerHTMLElement(myRow);

			myRow = GetCharacteristicsRow(bIsSearchable, m_asOwner.GetString(2033, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_SEARCHABLE, null, !bIsVisible||bIsEncrypted, false);
			myTable.AddInnerHTMLElement(myRow);

			myRow = GetCharacteristicsRow(bIsMandatory, m_asOwner.GetString(2022, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_MANDATORY, null, !bIsVisible||bIsReadOnly, false);
			myTable.AddInnerHTMLElement(myRow);

			myRow = GetCharacteristicsRow(bIsMultivalued, m_asOwner.GetString(2023, "ptmsgs_portaladminmsgs"), HTMLCHECKBOX_MULTIVALUED, null, bIsEncrypted, false);
			myTable.AddInnerHTMLElement(myRow);

			if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF != nPropType &&
			    PT_PROPERTY_TYPES.PT_PROPTYPE_DATE != nPropType)
			{
				myRow = GetPickTypeSelectRow(nPickType);
				myTable.AddInnerHTMLElement(myRow);
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "SettingsView::Display The following error occured when trying to display the HTML: " + e.getMessage());
			

			throw new XPException(m_asOwner.GetString(2014, "ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns a table row for the current property characteristic.
	 *
	 * @param bChecked True if checkbox is to be checked
	 * @param strDescription Description of characteristic
	 * @param strInputName Input name of characteristic
	 * @param bReadOnlyMode Disabled mode
	 *
	 * @return Table row for property characteristic
	 *
	 * @throws HTMLException
	 */
	private HTMLTableRow GetCharacteristicsRow(boolean bChecked, String strDescription, String strInputName, String strCharacteristicLabel, boolean bDisableInput, boolean bOnClickReposts) 
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		myCell.SetWidth("150");
		myCell.SetVAlign(CommonHTMLStrings.TOP);

		if (null != strCharacteristicLabel)
		{
			myCell.AddInnerHTMLString(strCharacteristicLabel);
		}

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, strInputName, "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetChecked(bChecked);
		myInput.SetDisabled(bDisableInput);
		
		if (bOnClickReposts)
		{
			myInput.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + PropRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS + ");");
		}

		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		mySpan.AddInnerHTMLString(strDescription);

		return myRow;
	}

	/**
	 * Returns a table row for selecting the pick type of the property
	 *
	 * @param nPickType Pick type characteristic of property
	 *
	 * @return Table row for selecting the pick type
	 *
	 * @throws HTMLException
	 */
	private HTMLTableRow GetPickTypeSelectRow(int nPickType) 
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLSelect mySelect;
		HTMLOption myOption;

		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		myCell.SetWidth("150");
		myCell.SetVAlign(CommonHTMLStrings.TOP);

		myCell.AddInnerHTMLString(m_asOwner.GetString(2024, "ptmsgs_portaladminmsgs"));

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		// Pick type select
		mySelect = new HTMLSelect(HTMLSELECT_PICKTYPE, "");
		mySelect.SetOnChange(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + PropRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS + ");");
		myCell.AddInnerHTMLElement(mySelect);

		// Initialize pick table type names
		if (null == m_arPickTableTypeNames)
		{
			m_arPickTableTypeNames = new String[]
			{

				m_asOwner.GetString(2017, "ptmsgs_portaladminmsgs"),

				m_asOwner.GetString(2016, "ptmsgs_portaladminmsgs"),

				m_asOwner.GetString(2019, "ptmsgs_portaladminmsgs"),

				m_asOwner.GetString(2018, "ptmsgs_portaladminmsgs")
			};
		}
		
		// Drop down for pick table types
		for (int i = 0; i < m_arPickTableType.length; i++)
		{
			myOption = new HTMLOption(XPConvert.ToString(m_arPickTableType[i]));
			mySelect.AddInnerHTMLElement(myOption);
			myOption.SetSelected(m_arPickTableType[i] == nPickType);

			mySpan = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
			mySpan.AddInnerHTMLString(m_arPickTableTypeNames[i]);
		}

		return myRow;
	}

	/**
	 * Returns a table row for selecting the type of the property
	 *
	 * @param nPropType Property type
	 *
	 * @return Table row for selecting the type of the property
	 *
	 * @throws HTMLException
	 */
	private HTMLTableRow GetPropertyTypeRow(int nPropType) 
	{
		String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE, m_asOwner);
		
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLSpan mySpan;

		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
		myCell.SetWidth("150");
		myCell.SetVAlign(CommonHTMLStrings.TOP);

		myCell.AddInnerHTMLString(m_asOwner.GetString(2025, "ptmsgs_portaladminmsgs"));

		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		IPropModelRO iModelRO = (IPropModelRO)m_model;
		boolean bCreateMode = (EditorStartControl.EDITOR_START_FLAG_CREATE == iModelRO.GetEditorType());

		if (bCreateMode)
		{
			// Initialize array of property names
			if (null == m_arPropertyNames)
			{
				m_arPropertyNames = new String[]
				{

					m_asOwner.GetString(2031, "ptmsgs_portaladminmsgs"),

					m_asOwner.GetString(2029, "ptmsgs_portaladminmsgs"),

					m_asOwner.GetString(2028, "ptmsgs_portaladminmsgs"),

					m_asOwner.GetString(2027, "ptmsgs_portaladminmsgs"),

					m_asOwner.GetString(2030, "ptmsgs_portaladminmsgs"),

					m_asOwner.GetString(2834, "ptmsgs_portaladminmsgs")
				};
			}
			
			// Show dropdown for selecting property type
			mySelect = new HTMLSelect(HTMLSELECT_PROPTYPE, "");
			mySelect.SetOnChange(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + PropRepostControl.POSTTOSELF_ACTION_REDIRECT_AFTER_CHANGE_SETTINGS + ");");

			for (int i = 0; i < m_arPropertyTypes.length; i++)
			{
				myOption     = new HTMLOption(XPConvert.ToString(m_arPropertyTypes[i]));
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
				mySpan.AddInnerHTMLString(m_arPropertyNames[i]);
				mySelect.AddInnerHTMLElement(myOption);
				myOption.SetSelected(m_arPropertyTypes[i] == nPropType);
			}

			myCell.AddInnerHTMLElement(mySelect);

			if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == nPropType)
			{
				int nRefClassID = iModelRO.GetReferenceClass();
			
				// Get the list of all the classes in the system
				ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
	
				int[] arAllClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs(PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage());
	
				// Show dropdown for reference class
				mySelect = new HTMLSelect(HTMLSELECT_REFCLASS, "");
				myCell.AddInnerHTMLElement(mySelect);
								
				for (int i = 0; i < arAllClassIDs.length; i++)
				{
					myOption     = new HTMLOption(XPConvert.ToString(arAllClassIDs[i]));
					mySpan		 = new HTMLSpan();
					myOption.AddInnerHTMLElement(mySpan);
					mySpan.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
					
					mySpan.AddInnerHTMLString(ptClassTypeDescManager.GetClassTypeLocalizedName(arAllClassIDs[i], strLangID));
					mySelect.AddInnerHTMLElement(myOption);
					myOption.SetSelected(arAllClassIDs[i] == nRefClassID);
				}
			}
		}
		else
		{
			// show text
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			switch (nPropType)
			{
			case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:

				myCell.AddInnerHTMLString(m_asOwner.GetString(2027, "ptmsgs_portaladminmsgs"));

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:

				myCell.AddInnerHTMLString(m_asOwner.GetString(2029, "ptmsgs_portaladminmsgs"));

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:

				myCell.AddInnerHTMLString(m_asOwner.GetString(2028, "ptmsgs_portaladminmsgs"));

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_STRING:

				myCell.AddInnerHTMLString(m_asOwner.GetString(2031, "ptmsgs_portaladminmsgs"));

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_ENCRYPTED:

				myCell.AddInnerHTMLString(m_asOwner.GetString(2834, "ptmsgs_portaladminmsgs"));

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
			{
				int nRefClassID = iModelRO.GetReferenceClass();
				
				// Get the list of all the classes in the system
				ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
				String strClassName = ptClassTypeDescManager.GetClassTypeLocalizedName(nRefClassID, strLangID);
			

				myCell.AddInnerHTMLString(m_asOwner.GetString(2030, "ptmsgs_portaladminmsgs"));
				myCell.AddInnerHTMLString("(");
				myCell.AddInnerHTMLEncodedString(strClassName);
				myCell.AddInnerHTMLString(")");
				
				break;
			}

			default:
				break;
			}
		}

		return myRow;
	}
}

