package com.plumtree.portalpages.admin.editors.propertymap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;

/**
 * @author OlegS
 */
public class Property
{ // property representation internally stored in the model

	XPArrayList attributes;
	boolean added		   = false;
	boolean deleted		   = false;
	boolean edited = false;
	boolean mandatory = false;
	boolean modified  = false;
	int id			  = 0;

	/**
	 * Creates a new Property object.
	 *
	 * @param ptMap
	 * @param id
	 * @param ptSession
	 */
	public Property(IPTPropertyMap ptMap, int id, IPTSession ptSession)
	{
		attributes = new XPArrayList();
		this.id = id;

		// get mapped attributes
		Object[] names = (Object[]) ptMap.GetMappedFieldNames(id);

		for (int i = 0; (names != null) && (i < names.length); i++)
		{
			Object[] names2 = (Object[]) names[i];

			for (int j = 0; j < names2.length; j++)
			{
				attributes.Add((String) names2[j]);
			}
		}

		// get mandatory flag
		PTObjectManagerQueryWrapper omqr = new PTObjectManagerQueryWrapper(ptSession.GetProperties());
		omqr.QuerySingleObject(id);

		if (omqr.GetCount() == 1)
		{
			Object v = omqr.GetFields(0,
					PT_PROPIDS.PT_PROPID_PROP_MANDATORY);
			mandatory = ((v != null) && (XPConvert.ToInteger(v) == 1));
		}
	}

	/**
	 * Creates a new Property object.
	 *
	 * @param ptMap
	 * @param id
	 * @param ptSession
	 * @param added
	 */
	public Property(IPTPropertyMap ptMap, int id, IPTSession ptSession,
		boolean added)
	{
		this(ptMap, id, ptSession);
		this.added = added;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsAdded()
	{
		return added;
	}

	/**
	 *
	 *
	 * @param index
	 *
	 * @return
	 */
	public String GetAttribute(int index)
	{
		return (index < GetNumberOfAttributes())
		? (String) attributes.GetElement(index) : null;
	}

	/**
	 *
	 *
	 * @return
	 */
	public Object[][] GetAttributes()
	{
		int na		 = GetNumberOfAttributes();
		Object[][] a = new Object[1][na];

		for (int i = 0; i < na; i++)
		{
			a[0][i] = GetAttribute(i);
		}

		return a;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsDeleted()
	{
		return deleted;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetId()
	{
		return id;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsInEditMode()
	{
		return edited;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsMandatory()
	{
		return mandatory;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsModified()
	{
		return modified;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetNumberOfAttributes()
	{
		return attributes.GetSize();
	}

	/**
	 *
	 *
	 * @param s
	 */
	public void ReplaceAttributes(String s)
	{
		attributes.Clear();

		for (XPStringTokenizer i = new XPStringTokenizer(s, ",");
				i.HasMoreTokens();)
		{
			String si = i.GetNextToken();
			attributes.Add(si.trim());
		}

		modified = true;
	}
}
