package com.plumtree.portalpages.admin.editors.propertymap;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author OlegS
 */
public class PropertyMapEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.propertymap.PropertyMapEditorAS");


	public static final String STR_MVC_CLASS_NAME = "PropertyMapEditor";

  private static final String sClassName = "com.plumtree.portalpages.admin.editors.propertymap.PropertyMapEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PropertyMapEditorAS();
	}

	public String GetEditorTitle()
	{
		return GetString(700, "ptmsgs_portaladminmsgs");
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetRepostControlName()
	{
		return (PropertyMapEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 *
	 */
	public void Init()
	{
		m_strModelName = PropertyMapEditorModel.STR_MVC_CLASS_NAME;

		// Warning: m_myModel must be initialized before super.Init() is called.
		super.Init();

		
		IModel myModel = GetModel(PropertyMapEditorModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new PropertyMapEditorMainDP());

		// Register Views
		RegisterView(PropertyMapEditorMainView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(PropertyMapEditorRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		// Register Migration History Plugin
		if(!GetModelExists(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME))
		{
			RegisterModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME);
		}
		
		if(!GetViewExists(MigrationHistoryView.STR_MVC_CLASS_NAME)){
			RegisterView(MigrationHistoryView.STR_MVC_CLASS_NAME,
					GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME));
		}
		
		if(!GetPageExists(MigrationHistoryPluginDP.STR_MVC_CLASS_NAME)){
			RegisterPage(new MigrationHistoryPluginDP());
		}
		

		// Set default page
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(PropertyMapEditorMainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1866, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PropertyMapEditorMainDP.STR_MVC_CLASS_NAME);

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1867, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID,
			MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);




		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				tm.SetGeneratingClass( sClassName );



				int iTitleId = 60;
				int iTipId = 61;
				int iSecondaryTipId = 62;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	* @param IDisplayPage the current Display Page
	*/
	public void SetCurrentPage(IDisplayPage page)	{
		super.SetCurrentPage(page);
		String sPageName=page.GetName();
		if(PropertyMapEditorMainDP.STR_MVC_CLASS_NAME.equals(sPageName))
			SetHelpTopic("PT_GlobalDocumentPropertyMap_DocumentPropertyMap");
	}
}

