package com.plumtree.portalpages.admin.editors.propertymap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portalpages.common.objects.sort.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author OlegS
 */
class PTPropertyObjectNameGetter implements IPTObjectNameGetter
{
	/**
	 *
	 *
	 * @param id
	 * @param ptSession
	 *
	 * @return
	 */
	public String GetName(int id, IPTSession ptSession)
	{
		IPTProperty ptProperty = (IPTProperty) ptSession.GetProperties().Open(id, false);

		return (ptProperty == null) ? null : ptProperty.GetLocalizedName();
	}
}


/**
 *
 *
 * @author $author$
 */
public class PropertyMapEditorMainView extends EditorView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.propertymap.PropertyMapEditorMainView");


	public static final String STR_MVC_CLASS_NAME = "PropertyMapEditorMain";


	public static final String HTMLCHECKBOX_PROPERTY = "in_cb_property";


	public static final String HTMLTEXT_PROPEDIT = "in_tx_propedit_"; // + property id

	/* for old javascript submit only??? */


	public static final String HTMLHIDDEN_PROPERTYSELECTED = "in_hi_PropertySelected";


	public static final String PROPTREESPACE		 = "PropertyTree";


	public static final String HTMLHIDDEN_TREEREPOST = "in_hi_TreeRepostAction";


	public static final String HTMLHIDDEN_SPACEID = "in_hi_TreeParentSpaceID";

	// member variables
	protected PTStyleClass m_styleListItem = null;

	/**
	 *
	 *
	 * @param type
	 * @param alt
	 * @param w
	 * @param h
	 *
	 * @return
	 */
	public HTMLImg GetImage(PTImageType type, String alt, String w, String h)
	{
		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(type,
					true, this.m_asOwner);
			HTMLImg myImg		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImg.SetAlt(alt);
			myImg.SetBorder("0");
			myImg.SetWidth(w);
			myImg.SetHeight(h);

			return myImg;
		}
		catch (Exception e)
		{
			log.Error(e, "PropertyMapEditorMainView.getImage couldn't create image: " +
				e.getMessage());

			throw new XPException(m_asOwner.GetString(711,
					"ptmsgs_portaladminmsgs") + " (Image)", e);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PropertyMapEditorMainView();
	}

	/**
	 *
	 *
	 * @return
	 */
	public HTMLElement Display()
	{
		try
		{
			HTMLElementCollection result = new HTMLElementCollection();
			HTMLComment myComment = new HTMLComment( "Begin: Display PropertyMapEditorMainView");
			result.AddInnerHTMLElement(myComment);

			DisplayHiddenInputs(result);

			DisplayObjectHeader(result);
			DisplayActionBar(result);
			DisplayPropertyList(result);
			new Spacer("15").display(result);

			myComment = new HTMLComment( "End: Display PropertyMapEditorMainView");
			result.AddInnerHTMLElement(myComment);

			return result;
		}
		catch (Exception e)
		{
			log.Error("PropertyMapEditorMainView::Display The following error occured when trying to display the HTML: " +
				e /*.getMessage()*/    );

			throw new XPException(m_asOwner.GetString(711,
					"ptmsgs_portaladminmsgs"), e);
		}
	}

	/**
	 *
	 *
	 * @return
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		try
		{
			myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(
					m_asOwner, PROPTREESPACE, HTMLHIDDEN_SPACEID,
					HTMLHIDDEN_TREEREPOST,
					m_asOwner.GetString(708, "ptmsgs_portaladminmsgs"),
					m_asOwner.GetString(715, "ptmsgs_portaladminmsgs"),
					PT_CLASSIDS.PT_PROPERTY_ID,
					PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,
					TreeConstants.N_LEAFSELECT, true, false,
					((PropertyMapEditorModel) GetModel()).makeListOfAlreadyShown()));
		}
		catch (Exception e)
		{
			log.Error(e, "PropertyMapEditorMainView.DisplayJavascript couldn't add javascript to the HTMLScript element: " +
				e.getMessage());

			throw new XPException(m_asOwner.GetString(711,
					"ptmsgs_portaladminmsgs") + " (Javascript)", e);
		}

		return myScript;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected IPropertyMapEditorModelRO GetModel()
	{
		return (IPropertyMapEditorModelRO) m_model;
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayActionBar(HTMLElementCollection result)
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLAnchor myAnchor;
		HTMLImg myImg;
		HTMLComment myComment = new HTMLComment( "Begin: DisplayActionBar PropertyMapEditorMainView");
		result.AddInnerHTMLElement(myComment);
		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

		// add property
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);


		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();


		myAnchor = TreeHelper.makeTreeAnchor(PROPTREESPACE, HTMLHIDDEN_SPACEID,
				PropertyMapEditorRepostControl.ACTION_ADD, strLang);
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myImg = GetImage(PTImageType.ACTION_ADD,m_asOwner.GetString(708, "ptmsgs_portaladminmsgs"), "6", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		myImg = GetImage(PTImageType.ICON_PROPERTY,"","16","20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(708,"ptmsgs_portaladminmsgs") +CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// delete property
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf(" +	// mj: removed 'Javascript:' from function name
		  PropertyMapEditorRepostControl.ACTION_DEL + "); return false;");
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myImg = GetImage(PTImageType.ACTION_DELETE,
				m_asOwner.GetString(707, "ptmsgs_portaladminmsgs"), "25", "25");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);

		// divider
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
		myImg = GetImage(PTImageType.SPACER, "", "1", "1");
		myCell.AddInnerHTMLElement(myImg);

		// last
		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetWidth("100%");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myRow.AddInnerHTMLElement(myCell);
		myComment = new HTMLComment( "End: DisplayActionBar PropertyMapEditorMainView");
		result.AddInnerHTMLElement(myComment);
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayBreak(HTMLElementCollection result)

	{
		result.AddInnerHTMLElement(new HTMLBr());
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayHiddenInputs(HTMLElementCollection result)

	{
		HTMLInput myInput;

		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_SPACEID, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue((GetModel().GetLastTreeSpaceId() == null) ? ""
																   : GetModel()
			.GetLastTreeSpaceId());

		// hidden input to hold repost action on tree submit
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_TREEREPOST, "");
		result.AddInnerHTMLElement(myInput);
		myInput.SetValue("");
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayObjectHeader(HTMLElementCollection result)

	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLComment myComment = new HTMLComment( "Begin: DisplayObjectHeader PropertyMapEditorMainView");
		result.AddInnerHTMLElement(myComment);
		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("0");
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetHeight("20");
		myCell.SetVAlign("center");
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(706,
				"ptmsgs_portaladminmsgs"));
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("10");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myComment = new HTMLComment( "End: DisplayObjectHeader PropertyMapEditorMainView");
		result.AddInnerHTMLElement(myComment);
	}

	/**
	 *
	 *
	 * @param result
	 *
	 * @throws HTMLException
	 */
	protected void DisplayPropertyList(HTMLElementCollection result)

	{
		HTMLTable myTable;
		HTMLComment myComment = new HTMLComment( "Begin: DisplayPropertyList PropertyMapEditorMainView");
		result.AddInnerHTMLElement(myComment);
		myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("2");

		// header
		DisplayPropertyListHeader(myTable);

		// items
		m_styleListItem = null;

		Object[] propertyIDs					 = GetModel().GetPropertyIDs();
		PTObjectIdNamePair[] propertyIdNamePairs = SortObjectByName(propertyIDs,
				GetModel().GetSortAscending());

		for (int i = 0;
				(propertyIdNamePairs != null) &&
				(i < propertyIdNamePairs.length); i++)
		{
			int propId		    = propertyIdNamePairs[i].id;
			String propertyName = (propertyIdNamePairs[i].name == null)
				? GetPropertyName(propId) : propertyIdNamePairs[i].name;
			DisplayPropertyListItem(myTable, propId, propertyName);
		}

		myComment = new HTMLComment( "End: DisplayPropertyList PropertyMapEditorMainView");
		result.AddInnerHTMLElement(myComment);

	}

	/**
	 *
	 *
	 * @param myTable
	 *
	 * @throws HTMLException
	 */
	protected void DisplayPropertyListHeader(HTMLTable myTable)

	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		HTMLImg myImg;
		HTMLSpan mySpan;
		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetVAlign("center");
		myCell.SetAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_PROPERTY,
				m_asOwner.GetString(712, "ptmsgs_portaladminmsgs"));
		myInput.SetChecked(false);
		myInput.SetValue("-1"); // all
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myCell.AddInnerHTMLElement(myInput);
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf(" +	// mj: removed 'Javascript:' from function name
			(PropertyMapEditorRepostControl.ACTION_SORT) + "); return false;");

		myAnchor.AddInnerHTMLString(m_asOwner.GetString(709,
				"ptmsgs_portaladminmsgs"));
		myCell.AddInnerHTMLElement(myAnchor);

		myImg = GetImage(GetModel().GetSortAscending()
				? PTImageType.ICON_ARROW_DESCEND : PTImageType.ICON_ARROW_ASCEND,
				m_asOwner.GetString(716, "ptmsgs_portaladminmsgs"), "16", "16");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetWidth("90%");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);

		mySpan.AddInnerHTMLString(m_asOwner.GetString(710,
				"ptmsgs_portaladminmsgs"));
	}

	/**
	 *
	 *
	 * @param myTable
	 * @param id
	 * @param name
	 *
	 * @throws HTMLException
	 */
	protected void DisplayPropertyListItem(HTMLTable myTable, int id, String name)

	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		HTMLImg myImg;
		boolean editMode = GetModel().IsPropertyInEditMode(id);
		myRow = new HTMLTableRow();

		//encode this name string
		name = XPHttpUtility.HtmlEncode(name);

		m_styleListItem = ((m_styleListItem == null) || (m_styleListItem == PTStyleClass.LIST_ITEM_ONE_BG)) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG;

		myRow.SetStyleClass(m_styleListItem);
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetVAlign("center");
		myCell.SetAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_PROPERTY,
				m_asOwner.GetString(713, "ptmsgs_portaladminmsgs") + " \"" +
				name + "\"");
		myInput.SetChecked(false);
		myInput.SetValue(XPConvert.ToString(id));
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		
		/* bug 21012: why should we disable mandatory properties?  User should
		 * be able to remove any property... for now... NOTE: We may need to 
		 * revist this someday.
		 */
//		myInput.SetDisabled(GetModel().IsPropertyMandatory(id));
		myCell.AddInnerHTMLElement(myInput);

		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myRow.AddInnerHTMLElement(myCell);
		myAnchor     = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf(" +	// mj: removed 'Javascript:' from function name
				(PropertyMapEditorRepostControl.ACTION_EDIT + id) + "); return false;");

		myImg = GetImage(PTImageType.ICON_PROPERTY,
				m_asOwner.GetString(715, "ptmsgs_portaladminmsgs"), "16", "20");
		myImg.SetAlign("absMiddle");
		myAnchor.AddInnerHTMLElement(myImg);
		myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myAnchor.AddInnerHTMLString(name);
		myCell.AddInnerHTMLElement(myAnchor);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell = new HTMLTableCell();
		myCell.SetHeight("20");
		myCell.SetWidth("90%");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myRow.AddInnerHTMLElement(myCell);

		XPStringBuilder sb = new XPStringBuilder(100);
		int na			   = GetModel().GetPropertyNumberOfAttributes(id);
		char sep		   = (char)0;

		for (int i = 0; i < na; i++)
		{
			String s = GetModel().GetPropertyAttribute(id, i);

			if (sep == 0)
			{
				sep = ',';
			}
			else
			{
				sb.Append(sep).Append(' ');
			}

			sb.Append(s);
		}

		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE+CommonHTMLStrings.SPACE);

		if (editMode)
		{
			myInput = new HTMLInput(HTMLInputTypes.TEXT,
					HTMLTEXT_PROPEDIT + XPConvert.ToString(id),
					m_asOwner.GetString(714, "ptmsgs_portaladminmsgs") + " \"" +
					name + "\"");
			myInput.SetValue(sb.ToString());

			int size = sb.GetLength() + 8;

			if (size < 20)
			{
				size = 20;
			}
			else if (size > 80)
			{
				size = 80;
			}

			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetSize(size); // is it possible to set input box size just to 100% of cell width
			myCell.AddInnerHTMLElement(myInput);
		}
		else
		{
			myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sb.ToString()));
		}
	}

	/**
	 *
	 *
	 * @param id
	 *
	 * @return
	 */
	protected String GetPropertyName(int id)
	{
		IPTSession ptSession   = (IPTSession) m_asOwner.GetUserSession();
		IPTProperty ptProperty = (IPTProperty) ptSession.GetProperties().Open(id, false);

		return ptProperty.GetLocalizedName();
	}

	/**
	 *
	 *
	 * @param ids
	 * @param ascending
	 *
	 * @return
	 */
	protected PTObjectIdNamePair[] SortObjectByName(Object[] ids, boolean ascending)
	{
		if (ids == null)
		{
			return null;
		}

		XPArrayList pairs = new XPArrayList(ids.length);

		for (int i = 0; i < ids.length; i++)
		{
			int id = XPConvert.ToInteger(ids[i]);
			pairs.Add(new PTObjectIdNamePair(id));
		}

		XPCollections.Sort(pairs,
			new PTObjectNameComparator(new PTPropertyObjectNameGetter(),
				(IPTSession) m_asOwner.GetUserSession(), ascending));

		// (fails on .NET, replaced below) return (PTObjectIdNamePair[]) pairs.ToArray(result);
		PTObjectIdNamePair[] result = new PTObjectIdNamePair[ids.length];
		for(int i=0; i<ids.length; i++)
			result[i]=(PTObjectIdNamePair)pairs.GetElement(i);
		return result;

		// we don't change source array, but if we wantewd to:
		// for(int i=0; i<ids.length; i++)	ids[i]=new Integer(pairs[i].id);
	}
}

