package com.plumtree.portalpages.admin.editors.remoteserver;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * Activity Space for Remote Server Objects. A Remote Server
 * is the root object that defines the network location of a remote
 * server machine. Remote Servers can host Web Services and other
 * remote  services.
 *
 * @author adolfoc
 */
public class RemoteServerEditorAS extends ObjEditorAS
{
	/** The Object Name of the Remote Server Editor */
	public static final String STR_MVC_CLASS_NAME = "RemoteServerEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RemoteServerEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (RemoteServerDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(727, "ptmsgs_portaladminmsgs");
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(2615, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#GetRepostControlName()
	 */
	public String GetRepostControlName()
	{
		return (RemoteServerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		// Get and initialize my data model.
		m_strModelName = RemoteServerModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		RegisterPage(new MainDP());
		RegisterPage(new AssociatedObjectsDP());

		// Register Views
		RegisterView(RemoteServerPropsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(AssocWebServicesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(RemoteServerDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls - I'm assuming I need a Repost control.		
		RegisterControl(RemoteServerRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Default page
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		// Sub menu "Edit Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(729,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			AssociatedObjectsDP.STR_MVC_CLASS_NAME);


		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1879, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)

	{
		super.SetCurrentPage( page );
		
		String sPageName = page.GetName();
				
		if( AssociatedObjectsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_RemoteServer_AssociatedObjects" );                           
		} else if( MainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_RemoteServer_MainSettings" );                           
		}
	}
}

