package com.plumtree.portalpages.admin.editors.remoteserver;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 * This Section represents the remote server
 * properties section of the Remote Server Editor.
 * This Section is used in MainDP.
 */
public class RemoteServerPropsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.remoteserver.RemoteServerPropsView");


	public static final String STR_MVC_CLASS_NAME = "RemoteServerPropsView";

	// HTML Object names.
	// ***CHANGE_HERE*** Declare some constants for each
	//        HTML object you are using in the display method
	// ***COMMENT_1*** You should follow the HTMLElements naming standards:
	//       <select> starts with in_se
	//       <input button> starts with in_bu
	//       <input text> starts with in_tx
	//       <input checkbox> starts with in_cb
	//       <input radio> starts with in_ra
	//       <textarea> starts with in_ta
	public static final String HTMLINPUT_BASE_URL	    = "in_tx_BaseURL";

	public static final String HTMLRADIO_BASE_AUTH_TYPE = "in_ra_AuthType";

	public static final String HTMLINPUT_LOGIN_NAME = "in_tx_LoginName";

	public static final String HTMLINPUT_PASSWORD = "in_pw_Password";
	public static final String HTMLINPUT_PASSWORD_CONFIRM = "in_pw_Password2";

	public static final String HTMLBUTTON_REPOST = "in_bu_repost";
	public static final String HTMLTEXTAREA_PUBLICKEY = "in_ta_publicKey";


	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RemoteServerPropsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;

		int COLUMNS = 7;

		try
		{
			IRemoteServerModelRO modelRO = (IRemoteServerModelRO) m_model;
			
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						734, "ptmsgs_portaladminmsgs")));

			// Containing Table
			myTable = RSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));

			// 2nd row begins
			myRow = RSViewHelper.AddRow(myTable);
			RSViewHelper.AddSimpleEditBox(myTable, COLUMNS,
				m_asOwner.GetString(736, "ptmsgs_portaladminmsgs"), "",
				modelRO.GetBaseURL(),
				HTMLINPUT_BASE_URL);

			// Middle Spacer
			RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));

			// Radio Category Label
			RSViewHelper.AddSimpleLabel(myTable, COLUMNS,
				m_asOwner.GetString(737, "ptmsgs_portaladminmsgs"));

			// Base URL Auth Type Radio Selection
			int intCurrentAuthType = modelRO.GetAuthType();
			RSViewHelper.AddSimpleRadio(myTable, -COLUMNS,
				m_asOwner.GetString(738, "ptmsgs_portaladminmsgs"),
				HTMLRADIO_BASE_AUTH_TYPE,
				XPConvert.ToString(RemoteServerModel.AUTHTYPE_NONE),
				(RemoteServerModel.AUTHTYPE_NONE == intCurrentAuthType));
			RSViewHelper.AddSimpleRadio(myTable, -COLUMNS,
				m_asOwner.GetString(739, "ptmsgs_portaladminmsgs"),
				HTMLRADIO_BASE_AUTH_TYPE,
				XPConvert.ToString(RemoteServerModel.AUTHTYPE_USER),
				(RemoteServerModel.AUTHTYPE_USER == intCurrentAuthType));
			RSViewHelper.AddSimpleRadio(myTable, -COLUMNS,
				m_asOwner.GetString(740, "ptmsgs_portaladminmsgs"),
				HTMLRADIO_BASE_AUTH_TYPE,
				XPConvert.ToString(RemoteServerModel.AUTHTYPE_ADMIN),
				(RemoteServerModel.AUTHTYPE_ADMIN == intCurrentAuthType));

			//// Login and Password for Admin Radio selection.
			myRow = RSViewHelper.AddRow(myTable);
			RSViewHelper.AddLeftMargin(myRow, COLUMNS);
			RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
			RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
			RSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE,
				m_asOwner.GetString(741, "ptmsgs_portaladminmsgs"));
			RSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.ONE,
				((IRemoteServerModelRO) m_model).GetLoginName(),
				HTMLINPUT_LOGIN_NAME,15);
			RSViewHelper.AddRightMargin(myRow, COLUMNS);

			myRow = RSViewHelper.AddRow(myTable);
			RSViewHelper.AddLeftMargin(myRow, COLUMNS);
			RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
			RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
			RSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE,
				m_asOwner.GetString(742, "ptmsgs_portaladminmsgs"));
			RSViewHelper.AddPasswordBoxCell(myRow, CommonHTMLStrings.ONE,
				RemoteServerModel.NULL_PASSWORD, HTMLINPUT_PASSWORD,15);
			RSViewHelper.AddRightMargin(myRow, COLUMNS);

			myRow = RSViewHelper.AddRow(myTable);
			RSViewHelper.AddLeftMargin(myRow, COLUMNS);
			RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
			RSViewHelper.AddIndentCell(myRow, CommonHTMLStrings.ONE);
			RSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.ONE,
				m_asOwner.GetString(951, "ptmsgs_portaladminmsgs"));
			RSViewHelper.AddPasswordBoxCell(myRow, CommonHTMLStrings.ONE,
				RemoteServerModel.NULL_PASSWORD, HTMLINPUT_PASSWORD_CONFIRM,15);
			RSViewHelper.AddRightMargin(myRow, COLUMNS);

			// spacer -jas
			RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));

			// label for public key -jas
			RSViewHelper.AddSimpleLabel(myTable, COLUMNS,
				m_asOwner.GetString(3054, "ptmsgs_portaladminmsgs"));

			// text area for remote server public key -jas
			myRow = RSViewHelper.AddRow(myTable);
			int nMiddleColumns = RSViewHelper.AddLeftMargin(myRow, COLUMNS);
			RSViewHelper.AddTextAreaCell(myRow, XPConvert.ToString(nMiddleColumns), modelRO.GetPublicKey(), HTMLTEXTAREA_PUBLICKEY);
			RSViewHelper.AddRightMargin(myRow, COLUMNS);
			
			// 6th row begins (bottom margin)
			RSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));

			// 6th row ends
		}
		catch (Exception e)
		{
			
				log.Error(e, "RemoteServerPropsView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(735,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

