package com.plumtree.portalpages.admin.editors.savedsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.ResourceConstants;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author joseq
 *
 * This is the expandable list view that displays collab project names.  It extends ExpListView
 * so that we can override what the add method does (which is open the project picker from collab)
 */
public class CollabExpListView extends ExpListView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
			"com.plumtree.portalpages.browsing.editors.community.PageListView");

    public static final String STR_MVC_CLASS_NAME = "CollabExpListView";

	/** HTML ELLEMENTS constants */
	public final static String HTMLINPUT_HI_SELECTEDIDS   = "in_hi_selectedIDs";

	/** javascript function constants */
	public static final String JAVASCRIPT_CHOOSEPROJECTS = "chooseProject";

	
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO, int)
     */
    public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex) 
    {
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		return result;    
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create() 
    {
        return new CollabExpListView();
    }

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
    public String GetName() 
    {
        return STR_MVC_CLASS_NAME;
    }

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(com.plumtree.xpshared.htmlelements.HTMLTableRow)
	 */
	protected void AddHTMLToActionBar(HTMLTableRow _row)
	{
		super.AddHTMLToActionBar(_row);
		
		HTMLTableCell myCell = new HTMLTableCell();
		_row.AddInnerHTMLElement(myCell);
		
		// Hidden input for selectedIds.
		HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, HTMLINPUT_HI_SELECTEDIDS, HTMLINPUT_HI_SELECTEDIDS);
		input.SetValue("");
		myCell.AddInnerHTMLElement(input);

		// Hidden input for selectedNames.
		input = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, "in_hi_selectedNames", "in_hi_selectedNames");
		input.SetValue("");
		myCell.AddInnerHTMLElement(input);
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
    public HTMLScript DisplayJavascript() 
    {
        HTMLScript script = super.DisplayJavascript();
        
		try
		{
			String gwurl_CollabBase = ((ICollabExpListModelRO) m_model).GetCollabBaseURL(true);

			XPStringBuilder sb = new XPStringBuilder(300);
			sb.Append("function "+JAVASCRIPT_CHOOSEPROJECTS+"()\n");
			sb.Append("{\n");
			sb.Append("   var url = '"+gwurl_CollabBase+"/do/selector/project?selectorCallback=setProject&selectedIDs=';\n");
			sb.Append("   window.open(url,''," +
									"'width=350,height=350,resizable=1,status=0,toolbar=0,menubar=0,scrollbars=1,location=0');\n");
			sb.Append("}\n");
			
			sb.Append("\nfunction setProject(id, name)\n"); 
			sb.Append("{\n");
			sb.Append("  document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_HI_SELECTEDIDS+".value = id;\n");
			sb.Append("  document."+AFormDP.HTMLFORM_NAME+"."+"in_hi_selectedNames"+".value = name;\n");
			sb.Append("  "+AFormDP.JAVASCRIPT_SUBMIT_FORM+"("+((IExpListModelRO) m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD)+");\n");
			sb.Append("}\n");
	
			script.AddInnerHTMLString(sb.ToString());
			
		}
		catch (Exception e)
		{
			log.Error(e, "SavSrchSettingsView::Display The following error occured when trying to display the HTML: " +
				e.getMessage());

			throw new XPException("Unable to dispaly Javascript for CollabExpListView", e);
		}

		return script;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForAddAction()
     */
    protected HTMLTableCell GetHTMLForAddAction() 
    {
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
				true, this.m_asOwner);
		myAddIcon		    = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");
		
		// Object icon
		myConstruct     = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
				true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.AddInnerHTMLString(SPACE);
		myAnchor.SetOnClick(JAVASCRIPT_CHOOSEPROJECTS + "(); return false;");
		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);

		return myCell;
    }
    
	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;

		myCell = new HTMLTableCell();
		myCell.SetWidth("100%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// get the project name
		String sObjectName = (String) _saData.GetItem(_nRowIndex, CollabExpListModel.EXPLIST_COL_NAME);
		
		PTConstruct myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
		HTMLImg spacerImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		spacerImage.SetAlt("---");
		spacerImage.SetWidth(CommonHTMLStrings.FIVE);
		spacerImage.SetBorder("0");
		myCell.AddInnerHTMLElement(spacerImage);

		myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(sObjectName));

		return myCell;
	}
}