package com.plumtree.portalpages.admin.editors.savedsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author joseq
 *
 * This class doesn't change much from SelectPTObjectModel.  The purpose of it is just to 
 * use the QS variables of IPTOpenerConstant for the edit links instead
 * of the ObjEditorModel ones.
 */
public class PortletSelectModel extends SelectPTObjectModel implements IPortletSelectModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		"com.plumtree.portalpages.admin.editors.savedsearch.PortletSelectModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SQPortletSelect";

	private IPTSession m_ptSession;
	private int m_iSnapshotID;
	

	public PortletSelectModel()
	{
		super();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletSelectModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	public void InitializePortletSelectModel(
	        IPTSession _ptSession, int _iSnapshotID, 
	        String _sSectionTitle, String _sSectionSubTitle, int _id)
	{
	    m_ptSession = _ptSession;
	    m_iSnapshotID = _iSnapshotID;
	    
	    InitializeSelectPTObject(
	            _sSectionTitle,
	            _sSectionSubTitle,
	            PTImageType.ICON_PORTLET,
	            m_asOwner.GetString(3016, ResourceConstants.PORTALADMINMSGS), 
		        new int[]{PT_CLASSIDS.PT_GADGET_ID}, 
		        _id); 
	    
	    if (CanCreatePortlet())
	    {
	        SetTableInstructions(m_asOwner.GetString(3017, ResourceConstants.PORTALADMINMSGS));
	    }
	    else
	    {
	        SetTableInstructions(m_asOwner.GetString(3140, ResourceConstants.PORTALADMINMSGS));
	    }
		SetTreeTitle(m_asOwner.GetString(3018, ResourceConstants.PORTALADMINMSGS));
		SetTreeSubTitle(m_asOwner.GetString(3018, ResourceConstants.PORTALADMINMSGS));
		SetEmptyListMessages(
		        m_asOwner.GetString(3019, ResourceConstants.PORTALADMINMSGS),
		        CanCreatePortlet()?m_asOwner.GetString(3020, ResourceConstants.PORTALADMINMSGS):"");

		/* set our options */
		SetDefaultRowIcon(PTImageType.ICON_PORTLET);
		SetEnableMoveRowActions(false);
		DisableAddButton();
		DisableCheckBoxes();
		
		/* set our create array */
		Object[][] arrCreateNewInfo = new Object[1][SelectPTObjectModel.CREATE_NEW_COL_MAX];
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_GADGET_ID);
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ASNAME]	= BaseOpenerAS.STR_MVC_CLASS_NAME;
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_LABEL]   = m_asOwner.GetString(3021, ResourceConstants.PORTALADMINMSGS);
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ICON]  	= PTImageType.ICON_PORTLET;
		SetEnableCreateNew(arrCreateNewInfo);

		/* sets our list.  UNKNOWN ID is when we are in create mode, that's ok, we just 
		 * don't have any default rows */
        if (ObjEditorModel.EDITOR_OBJECTID_UNKNOWN != m_iSnapshotID)
        {
            RefreshPortletList();
            
			/* sort it */
			int[][] arrSort = m_saData.GetSort();
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_STRING;
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

			m_saData.Sort(arrSort);
        }
	}
	
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectModel#DoTaskOnComeBackFromSubEditor()
     */
    public void DoTaskOnComeBackFromSubEditor() 
    {
        RefreshPortletList();
    }

	
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectModel#AddControlParamsToURL(int, com.plumtree.uiinfrastructure.activityspace.ASURL)
     * 
     * This the same code that is in SelectPTObjectModel, except that we are using the 
     * QS variables in IPTOpenerConstants instead of ObjEditorModel ones. 
     */
    public void AddControlParamsToURL(int _nClassID, ASURL myURL) 
    {
		Object oParams = null;
		String[][] arParams = null;
		boolean bFoundFolderID = false;

		for (int i = 0; i < m_arrCreateNewInfo.length; i++)
		{
			int nClassIDFromArray = XPConvert.ToInteger(m_arrCreateNewInfo[i][CREATE_NEW_COL_CLASSID]);

			if (nClassIDFromArray == _nClassID)
			{
				if (m_arrCreateNewInfo[i].length >= CREATE_NEW_COL_MAXWITHPARAMS)
				{
					oParams = m_arrCreateNewInfo[i][CREATE_NEW_COL_PARAMS];

					break;
				}
			}
		}

		if (null != oParams)
		{
			arParams = (String[][]) oParams;
			
			for (int j = 0; j < arParams.length; j++)
			{
				if ((null != arParams[j]) && (2 == arParams[j].length))
				{
					String strName  = arParams[j][PARAM_COL_PARAMNAME];
					
					if ((null != strName) && (0 != strName.length()))
					{
						String strValue = arParams[j][PARAM_COL_PARAMVALUE];
						
						// Add the parameter to the url.
						myURL.AddControlArgument(strName, strValue);
						
						if (strName.equalsIgnoreCase(IPTOpenerConstants.QS_FOLDERID))
						{
							bFoundFolderID = true;
						}
					}
				}
			}
		}
		else
		{
			
				log.Debug("AddControlParamsToURL: Unable to retrieve control info.");
				
		}
		
		if (! bFoundFolderID)
		{
			
			try
			{	
				ObjEditorModel myModel = (ObjEditorModel) m_asOwner
					.GetModel(((ObjEditorAS)m_asOwner).m_strModelName);
				
				int nFolderID = myModel.GetFolderID();
				myURL.AddControlArgument(
				        IPTOpenerConstants.QS_FOLDERID, XPConvert.ToString(nFolderID));
			}
			catch (Exception e)
			{
				
					log.Warn("Could not retrieve the Admin Folder ID from the current Editor." 
						+ " No Admin Folder will be pre-selected in the save-as pop-up of sub Editors.");
				
			}	
		}
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.ISelectPTObjectModelRO#GetCreateNewURL(int, java.lang.String)
     */
    public ASURL GetCreateNewURL(int _nClassID, String _sEditorASName) 
    {
		ASURL myURL = new ASURL(m_asOwner);

		myURL.SetLinkCreateNewSpace(_sEditorASName, m_asOwner);
		myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		myURL.SetSubSpaceKey(_sEditorASName);

		myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_CREATE));
		
		myURL.AddControlArgument(EditorStartControl.QS_DELETE_ON_CANCEL,
			XPConvert.ToString(true));
		
		myURL.AddControlArgument(IPTOpenerConstants.QS_CLASSID,
			XPConvert.ToString(_nClassID));
		
		myURL.AddControlArgument(IPTOpenerConstants.QS_MODE,
				XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_CREATE));

		myURL.AddControlArgument(PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_CLASSID,
	        XPConvert.ToString(PT_CLASSIDS.PT_GADGETTEMPLATE_ID));

		myURL.AddControlArgument(PTPortlets.PORTLET_EDITOR_QS_INT_CREATOR_ID,
	        XPConvert.ToString(PT_INTRINSICS.PT_GADGET_SAVEDSEARCHES));
		
		// Get the extra control arguments
		AddControlParamsToURL(_nClassID, myURL);

		return myURL;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.ISelectPTObjectModelRO#GetEditObjectURL(int, int)
     * 
     * This the same code that is in SelectPTObjectModel, except that we are using the 
     * QS variables in IPTOpenerConstants instead of ObjEditorModel ones. 
     */
    public ASURL GetEditObjectURL(int _nClassID, int _nObjectID) 
    {
		ASURL myURL = new ASURL(m_asOwner);
		
		// JF- For any Object in the list, the sub space key will be 
		// this Model name with the object class id and the object id.
		String sSubEditorKey = STR_MVC_CLASS_NAME + _nClassID + _nObjectID;

		if (m_asOwner.GetSubSpaceExists(sSubEditorKey))
		{
			EditorAS mySubEditor = (EditorAS) m_asOwner.GetSubSpace(sSubEditorKey);
			myURL.SetLinkGetCachedSpace(mySubEditor);
		}
		else
		{
			myURL.SetLinkCreateNewSpace(GetEditorASName(_nClassID), m_asOwner);
			myURL.SetSubSpaceKey(sSubEditorKey);
			
			myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			
			myURL.AddControlArgument(IPTOpenerConstants.QS_CLASSID,
				XPConvert.ToString(_nClassID));

			myURL.AddControlArgument(IPTOpenerConstants.QS_OBJECTID,
				XPConvert.ToString(_nObjectID));

			myURL.AddControlArgument(IPTOpenerConstants.QS_MODE,
				XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_EDIT));
		}

		AddControlParamsToURL(_nClassID, myURL);

		return myURL;
    }
    
    /**
     * sets the id of the query to use.  The list can optionally be refreshed, otherwise,
     * RefreshPortletList() must be called to refresh the list using the newly added 
     * snapshot query id. 
     * 
     * @param _iSnapshotID snapshot query id
     * @param _bRefresh true to refresh the list
     *
     */
    public void SetSnapshotQueryID(int _iSnapshotID, boolean _bRefresh)
    {
        m_iSnapshotID = _iSnapshotID;
        if (_bRefresh)
        {
            RefreshPortletList();
        }
    }
    
	/**
	 * method to refresh the snapshot query's list of portlets.
	 */
   public void RefreshPortletList()
   {
        /* update the portlet list */
        m_saData.ClearArray();
	    
        if (ObjEditorModel.EDITOR_OBJECTID_UNKNOWN != m_iSnapshotID)
        {
	        IPTQueryResult qrPortlets = ((IPTSavedSearch) m_ptSession.GetSavedSearches()
	        	.Open(m_iSnapshotID, false)).QueryPortletList();

			if (qrPortlets.RowCount()>0)
			{
				int cnt = qrPortlets.RowCount();
				Object[][] arPortlets = new Object[cnt][SelectPTObjectModel.EXPLIST_COL_MAX];
			
				for (int i = 0; i < cnt; i++)
				{
				    int id = qrPortlets.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				    
					//TODO: jhq error check
					IPTQueryResult qrResults = m_ptSession.GetGadgets().QuerySingleObject(id);
					String name = qrResults.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
	
					arPortlets[i][EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(m_nNextIndex);
					m_nNextIndex++;

					arPortlets[i][EXPLIST_COL_CLASSID]	= new Integer(PT_CLASSIDS.PT_GADGET_ID);
					arPortlets[i][EXPLIST_COL_OBJECTID]= new Integer(id);
					arPortlets[i][EXPLIST_COL_STRING] 	= name;
				}
				
				m_saData.AddRows(arPortlets);
			}
        }
    }
    
   public boolean CanCreatePortlet()
   {
       return m_ptSession.GetSessionInfo().CheckForActivityRight(
               PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS);   
   }
   
   /**
	* Helper method to get the EditorAS object name from the class ID.
	*
	* @param _nClassID
	*
	* @return String
	*/
	private String GetEditorASName(int _nClassID)
	{
		String sASName		  = null;
		int nClassIDFromArray;

		for (int i = 0; i < m_arrCreateNewInfo.length; i++)
		{
			nClassIDFromArray = XPConvert.ToInteger(m_arrCreateNewInfo[i][CREATE_NEW_COL_CLASSID]);

			if (nClassIDFromArray == _nClassID)
			{
				sASName = (String) m_arrCreateNewInfo[i][CREATE_NEW_COL_ASNAME];

				break;
			}
		}

		return sASName;
	}
}