package com.plumtree.portalpages.admin.editors.savedsearch;


// Framework Imports
import com.plumtree.openfoundation.internationalization.XPLocale;
import com.plumtree.openfoundation.internationalization.XPTimeZone;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.login.PTPersonalSettingsHelper;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author MikeS
 *
 */
public class SavSrchResultsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.savedsearch.SavSrchResultsView");


	public static final String STR_MVC_CLASS_NAME = "SavSrchPreview";
	public static final String ITEMSIZES = "20";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavSrchResultsView();
	}

	/**
	 *
	 *
	 * @return
	 */
	public HTMLElement Display()
	{
		HTMLElement result = new HTMLElementCollection();
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			IPTSearchResponse sr = null;
			int ret				 = 0;

			try
			{
				sr	    = (IPTSearchResponse) ((ISavedSearchModelRO) m_model).GenerateResponse();
				ret     = sr.GetResultsReturned();
			}
			catch (Exception e)
			{
				HTMLSpan errspan = new HTMLSpan();
				errspan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);

				errspan.AddInnerHTMLString(m_asOwner.GetString(564, "ptmsgs_portalcommonmsgs"));
				result.AddInnerHTMLElement(errspan);

				return result;
			}
			if (0 == ret)
			{
				HTMLSpan errspan = new HTMLSpan();
				errspan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);

				errspan.AddInnerHTMLString(m_asOwner.GetString(563, "ptmsgs_portalcommonmsgs"));
				result.AddInnerHTMLElement(errspan);

				return result;
			}

			// we use the image generation stuff from search
			SearchResultModel srm = new SearchResultModel();
			srm.ExternalLightInitialization(sr, m_asOwner);
			
			Object[][] arDisplayFields =  ((ISavedSearchModelRO) m_model).GetDisplayFieldsInfo();
			
			HTMLTable myTable = new HTMLTable();
			myTable.SetStyleClass(PTStyleClass.PLATPORTLET_BORDER);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding(CommonHTMLStrings.ZERO);
			myTable.SetCellSpacing(CommonHTMLStrings.TWO);

			result.AddInnerHTMLElement(myTable);

			/* header row */
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
			myCell = new HTMLTableCell();
			myCell.SetColSpan(XPConvert.ToString(arDisplayFields.length+1));
			myCell.SetHeight("20");
			myCell.SetWidth("85");
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			myCell.AddInnerHTMLString(m_asOwner.GetString(2406, "ptmsgs_portaladminmsgs"));

			/* column names row */
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

			int iPropsDisplayed = 0;
			if (arDisplayFields.length>0)
			{
				/* icon column */
				myCell = new HTMLTableCell();
				myCell.SetHeight("20");
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
				myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	
				/* column names */
				for (int i=0; i<arDisplayFields.length; i++)
				{
				    if (null==arDisplayFields[i][SavedSearchModel.INDEX_DISPLAYPROPNAME])
				    {
				        continue;
				    }
				    
					myCell = new HTMLTableCell();
					myCell.SetHeight("20");
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
					myCell.AddInnerHTMLEncodedString(
					        XPConvert.ToString(arDisplayFields[i][SavedSearchModel.INDEX_DISPLAYPROPNAME]));
					myCell.SetNoWrap(true);
					
					iPropsDisplayed++;
				}
				
				if (iPropsDisplayed==0)
				{
					HTMLSpan errspan = new HTMLSpan();
					errspan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);

					errspan.AddInnerHTMLString(m_asOwner.GetString(3166, ResourceConstants.PORTALADMINMSGS));
					
					return errspan;
				}
				
				/* row for each returned item */
				for (int i = 0; i < ret; i++)
				{
					HTMLTableRow row = new HTMLTableRow();
					myTable.AddInnerHTMLElement(row);
	
					row.SetStyleClass((0 == (i % 2))? 
					        PTStyleClass.LIST_ITEM_ONE_BG : PTStyleClass.LIST_ITEM_TWO_BG);
	
					HTMLTableCell imageCell = new HTMLTableCell();
					imageCell.SetHeight(ITEMSIZES);
					imageCell.SetWidth(ITEMSIZES);
					row.AddInnerHTMLElement(imageCell);
					imageCell.SetStyleClass(PTStyleClass.LIST_TEXT);
	
					HTMLImg icon = (HTMLImg) srm.GetResultIcon(i);
					icon.SetAlign(CommonHTMLStrings.CENTER);
					icon.SetBorder(CommonHTMLStrings.ZERO);
					imageCell.AddInnerHTMLElement((HTMLElement)icon);
	
					/* for each row, loop thru each display field */
					for (int j=0; j<arDisplayFields.length; j++)
					{
						HTMLSpan spanD = new HTMLSpan();
						spanD.SetStyleClass(PTStyleClass.LIST_TEXT);

					    if (null==arDisplayFields[j][SavedSearchModel.INDEX_DISPLAYPROPNAME])
					    {
					        continue;
					    }

						int id = XPConvert.ToInteger(arDisplayFields[j][SavedSearchModel.INDEX_DISPLAYPROPID]);
						int type = XPConvert.ToInteger(arDisplayFields[j][SavedSearchModel.INDEX_DISPLAYPROPTYPE]);
	
						if (type == PT_PROPERTY_TYPES.PT_PROPTYPE_DATE)
						{
							try
							{
							    XPDateTime date;
							    
							    if (id == PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED ||
							        id == PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED)
							    {
							        date = SearchResultModel.ConvertSearchDateTimeToXPDateTime(
								        sr.GetFieldsAsDouble(i, id));
							    }
							    else
							    {
							        date = sr.GetFieldsAsXPDateTime(i, id);
							    }
							    
								XPLocale xpLocale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner);
								XPTimeZone xpTimeZone = PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner);

								XPDateFormat dateFormat = XPDateFormat.GetDateTimeInstance(
									XPDateFormat.SHORT, XPDateFormat.SHORT, 
									xpLocale, xpTimeZone);
							
								spanD.AddInnerHTMLString(dateFormat.Format(date));
							}
							catch (XPNullPointerException enull)
							{
							    spanD.AddInnerHTMLString(CommonHTMLStrings.SPACE);
							}
						}
						/* props are actually floats, not doubles */
						else if (type == PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE)
						{
						    Object value = sr.GetFieldsAsObject(i, id);
						    if (null==value)
						        spanD.AddInnerHTMLString(CommonHTMLStrings.SPACE);
						    else
						        spanD.AddInnerHTMLEncodedString(XPConvert.ToString(XPConvert.ToFloat(value)));
						}
						else
						{
						    Object value = sr.GetFieldsAsObject(i, id);
						    spanD.AddInnerHTMLEncodedString(XPConvert.ToString(value));
						}

						HTMLTableCell valueCell = new HTMLTableCell();
						valueCell.SetHeight(ITEMSIZES);
						row.AddInnerHTMLElement(valueCell);
						valueCell.SetStyleClass(PTStyleClass.LIST_TEXT);
						valueCell.AddInnerHTMLElement(spanD);
					}
				}
			}
			else /* no display fields */
			{
				myCell = new HTMLTableCell();
				myCell.SetColSpan(XPConvert.ToString(arDisplayFields.length+1));
				myCell.SetHeight("20");
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				myCell.AddInnerHTMLString(m_asOwner.GetString(3163, ResourceConstants.PORTALADMINMSGS));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "SavedSearchPortletView::Display. " +
					m_asOwner.GetString(773, "ptmsgs_portaladminmsgs") + ": " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(773,
					"ptmsgs_portaladminmsgs"), e);
		}
		return result;
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

