package com.plumtree.portalpages.admin.editors.savedsearch;


// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.portlets.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author 
 */
public class SavedSearchDependenciesView extends ObjDependenciesView
{
	//Member variables
	private CreatedHelper m_chHelper	  = null;


	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "SavedSearchDependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavedSearchDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (SavedSearchModel) model);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()

	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLAnchor myAnchor;
		
		//Display the standard success message
		String strName = ((ObjEditorModel) m_model).GetObjectName();
		m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2271, "ptmsgs_portaladminmsgs"), strName, ((ObjEditorModel) m_model).GetParentFolderPath());

		/* qry for all portlets created with this qry */
		IPTSession mySession = ((ObjEditorModel) m_model).GetPTSession();
		ASQueryResultWrapper myQR = new ASQueryResultWrapper(((IPTSavedSearch) ((ObjEditorModel) m_model).GetObject()).QueryPortletList());
		
		/* for each portlet, display name and invite link */
		for (int i=0; i<myQR.GetCount(); i++)
		{
			Object intPortletID = myQR.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID);
			
			if (null != intPortletID && XPConvert.ToInteger(intPortletID) > 0)
			{		
			    IPTQueryResult qrPortlet = mySession.GetGadgets().QuerySingleObject(XPConvert.ToInteger(intPortletID));
			    
			    /* show portlet name */
			    m_chHelper.displayTextRow(result, 5, m_asOwner.GetString(2272, "ptmsgs_portaladminmsgs"), 
			            qrPortlet.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME));

				//Generate a popup URL to invite people to the portlet
				ASURL asurl = new ASURL(m_asOwner);
				asurl.SetLinkGetSpaceIfCached(PortletSelectionEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
				asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
				asurl.SetDisplayPage(PortletInvitationPopupDP.STR_MVC_CLASS_NAME);
				asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationID,
					XPConvert.ToString(intPortletID));
				asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationName,
					((SavedSearchModel) m_model).GetObjectName());
		
				String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(strJSUtilVersionPrefix+"PTWindowUtil.openWindow('" +
					asurl.GetURLAsString() + "', 'SendToOthers', '250','600'); return false;");
		
				m_chHelper.beginList(result);
		
				HTMLSpan mySpan = new HTMLSpan();
				mySpan.AddInnerHTMLString(m_asOwner.GetString(2273, "ptmsgs_portaladminmsgs"));
		
				myAnchor.AddInnerHTMLElement(mySpan);
		
				m_chHelper.displayListRow(myAnchor);
			}
		}

		//Display the standard warning if everyone has access to this object
		m_chHelper.displayEveryoneWarning(result, (SavedSearchModel) m_model, m_asOwner.GetString(2271, "ptmsgs_portaladminmsgs"));

		return result;
	}
}