package com.plumtree.portalpages.admin.editors.savedsearch;


// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
* @author MikeS
 *
 */
public class SavedSearchEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.savedsearch.SavedSearchEditorAS");

	public static final String STR_MVC_CLASS_NAME = "SavedSearchEditor";

	public final static String SEARCHCONSTRAINTSVIEW = "SrchConstraints";
	private static final String sClassName = "com.plumtree.portalpages.admin.editors.savedsearch.SavedSearchEditorAS";

	public static final String strCardLanguagePlugInKey = "CardEditorCardLanguagePlugIn";
	
	/** Select collab folders storage name */
	public static final String STR_MVC_SELECT_COLLAB_PROJECT = "SelectCollabProjectEditor";

	/** Select display properties storage name */
	public static final String STR_MVC_SELECT_DISPLAY_PROPS = "SelectDisplayPropsEditor";
	
	/** Select display properties storage name */
	public static final String STR_MVC_SELECT_PORTLETS = "SelectPortletsEditor";
	
	/** Select display properties storage name */
	public static final String STR_MVC_SELECT_CONTENT = "SelectContentFilterEditor";
	
	/**
	  * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	  */
	public Object Create()
	{
		return new SavedSearchEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (SavedSearchDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * This is a helper method that all classes that inherit from AFormDP can override
	 * if they like.  The method provides a hook into the head so that DP's can add javascript.
	 * Simply override and return and HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()
	 *
	 * Override this method to Display javascript from child IViews
	 *
	 * @return HTMLScriptCollection the Javascript from the Child IViews
	 */
	public HTMLScriptCollection DisplayCommonJavaScript()
	{
		HTMLScriptCollection scripts = super.DisplayCommonJavaScript();

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
		scripts.AddInnerHTMLElement(script);

		return scripts;
	}

	/**
	 * Sets the Editor title.
	 *
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return (GetString(762, "ptmsgs_portaladminmsgs"));
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(2616, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SavedSearchRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = SavedSearchModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		SavSrchMainDP mainDP = new SavSrchMainDP();
		mainDP.AddToValidationFunction(SavSrchMainDP.UPDATE_ALERT_JS); 
		RegisterPage(mainDP);

		// Register Views
		RegisterView(SavSrchFilterView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SnapshotQueryRangeView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SnapshotKDConstraintsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SnapshotADConstraintsView.STR_MVC_CLASS_NAME, myModel);
//		RegisterView(SearchConstraintsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SavedSearchDependenciesView.STR_MVC_CLASS_NAME, myModel);
		
		// Register Controls
		RegisterControl(SavedSearchRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Card Language Plug-In
		RegisterModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myCardLanguagePlugInModel = GetModel(strCardLanguagePlugInKey);
		RegisterView(CardLanguagePlugInView.STR_MVC_CLASS_NAME,
			strCardLanguagePlugInKey, myCardLanguagePlugInModel);
		RegisterControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME,
			strCardLanguagePlugInKey, myCardLanguagePlugInModel);

		RegisterPage(new SavSrchResultDP());
		RegisterView(SavSrchResultsView.STR_MVC_CLASS_NAME, myModel);

		RegisterPage(new ResultFormatDP());
		RegisterView(ResultFormatView.STR_MVC_CLASS_NAME, myModel);
		
		
		//****** Register classes for select collab Folder
		RegisterModel(CollabExpListModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_COLLAB_PROJECT);
		
		IModel myCollabListModel = GetModel(STR_MVC_SELECT_COLLAB_PROJECT);
		RegisterView(CollabExpListView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_COLLAB_PROJECT, myCollabListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_COLLAB_PROJECT, myCollabListModel);

		
		//****** Register classes for display property selector
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_PROPS);
		
		IModel myDisplayPropSelectModel = GetModel(STR_MVC_SELECT_DISPLAY_PROPS);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_PROPS, myDisplayPropSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_PROPS, myDisplayPropSelectModel);

		
		//****** Register classes for portlet selector
		RegisterPage(new PortletListDP());
		RegisterModel(PortletSelectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PORTLETS);
		
		IModel myPortletSelectModel = GetModel(STR_MVC_SELECT_PORTLETS);
		RegisterView(PortletSelectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PORTLETS, myPortletSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PORTLETS, myPortletSelectModel);

		
		//****** Register classes for content filter selector
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_CONTENT);
		
		IModel myContentSelectModel = GetModel(STR_MVC_SELECT_CONTENT);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_CONTENT, myContentSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_CONTENT, myContentSelectModel);

		// Default page
		SetCurrentPage(SavSrchMainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(764,
					"ptmsgs_portaladminmsgs"));

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			SavSrchMainDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			ResultFormatDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			SavSrchResultDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
				PortletListDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1882, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"
		
		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				tm.SetGeneratingClass( sClassName );



				int iTitleId = 63;
				int iTipId = 64;
				int iSecondaryTipId = 65;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

  /**
   * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
   *
   * @param IDisplayPage the current Display Page
   */
  public void SetCurrentPage(IDisplayPage page) {

    super.SetCurrentPage( page );

    String sPageName = page.GetName();

    if (SavSrchMainDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SavedSearch_MainSettings" );
    } else if (ResultFormatDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SavedSearch_SavedSearchResultFormat" );
    } else if (SavSrchResultDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SavedSearch_SavedSearchResultPreview" );
    } else if (PortletListDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SavedSearch_SnapshotPortletList" );
    }
  }
}

