package com.plumtree.portalpages.admin.editors.savedsearch;


// Plumtree Server
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.server.search.*;
import com.plumtree.server.search.ptapps.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
* @author MikeS
 *
 */
public class SavedSearchModel extends ObjEditorModel implements ISavedSearchModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.savedsearch.SavedSearchModel");

	public static final String STR_MVC_CLASS_NAME = "SavedSearch";

	public static final int SOURCE_FOLDER_GROUP		 = 0;
	public static final int DESTINATION_FOLDER_GROUP = 1;
	public static final int TOTAL_GROUPS = 2;

	public String m_lastAdmTreeSpaceId = null;
	public String m_lastCatTreeSpaceId = null; //mbstodo

	public int m_nAction;
	protected XPArrayList m_ActionData = null;
	private XPHashtable m_DeleteData   = null;
	protected boolean m_sortAscending;
	private FilterIterator m_FilterIterator;
//	private int m_nPortletSetting;

	// the saved search contained items
	private IPTFilter m_Filter;
	private IPTSearchQuery m_qry;
	private IPTSearchRequest m_req;

	// result formatting parameters
	private String m_strSelectedOrderProp = "0";

	// for limiting search by classids
	private XPArrayList m_ClassIDs;
	private XPArrayList m_admFolderIDs;
	private XPArrayList m_catFolderIDs;
	private boolean m_bAscending     = false;
//	private boolean m_bRecursive;
//	private boolean m_bShowClassIDs = false;
	private boolean m_bSubscriptionEnabled = false;
//	private int m_AbstractCount			   = 0;
	private int m_nMaxResults = 10;

	private XPArrayList m_listCollabProjIDs;   	// limit by Collab Projs
	private XPArrayList m_listDisplayPropsIDs; 	// query return props
	private XPArrayList m_listContentIDs;		// limit by content portlets
	
	/* kd types constants */
	private int m_nKDTypeMask = 0; 	/* holds the repository bitmask */
	public static final int KDTYPES_FOLDERS 	= 1;
	public static final int KDTYPES_DOCUMENTS 	= 2;
	
	/* repository constants */
	private int m_nRepositoryMask = 0; 	/* holds the repository bitmask */
	public static final int REPOSITORY_TYPES_KD 			= 1;
	public static final int REPOSITORY_TYPES_ADMIN 			= 2;
	public static final int REPOSITORY_TYPES_COLLAB 		= 4;
	public static final int REPOSITORY_TYPES_CONTENT 		= 8;
	public static final int REPOSITORY_SETTINGS_ALLFOLDERS 	= 16;
	public static final int REPOSITORY_SETTINGS_ALLDOCUMENTS= 32;
	public static final int REPOSITORY_SETTINGS_SUBFOLDERS 	= 64;
	
	public static final String CLASSID_KDFOLDER 	= XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID);
	public static final String CLASSID_KDDOCUMENT 	= XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID);

	private static final int[] ARR_ROOT_FOLDERID 	= {1};
	
	public static final int INDEX_DISPLAYPROPID 	= 0;
	public static final int INDEX_DISPLAYPROPTYPE 	= 1;
	public static final int INDEX_DISPLAYPROPNAME	= 2;
	
	public SavedSearchModel()
	{
		super();
		m_nAction = RepostControl.POSTTOSELF_ACTION_UNDEFINED;
	}

	/**
	 *
	 *
	 * @return
	 * 
	 * @deprecated ClassIDs are always shown.
	 */
	public boolean AreClassIDsShown()
	{
	    return true;
//		return m_bShowClassIDs;
	}

	/**
	 *
	 *
	 * @param form
	 */
	public void BuildSavedSearchFromForm(XPHashtable form)
	{
		IPTFilter filter = FilterForm.BuildFilterFromForm(m_asOwner, form);

		// If the form contained a filter
		if (null != filter)
		{
			// replace our current filter with the new one
			m_Filter = filter;
		}

		// Make sure our FilterIterator is in sync with our filter
		m_FilterIterator.InitFromFilter(m_Filter);
	}

  /**
   *  Returns the current filter iterator.
   *  @return the current filter iterator.
   */
	public IFilterIteratorRO GetFilterIterator()
	{
		return m_FilterIterator;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	*/
	public Object Create()
	{
		return new SavedSearchModel();
	}

	/**
	 * Code executed before the object is stored.
	 *
	 */
	public void DoTaskBeforeStore()
	{
		BuildSearchObjectsFromState();
		((IPTSavedSearch) m_ptObject).SetSearchQuery(m_qry);
		((IPTSavedSearch) m_ptObject).SetSearchRequest(m_req);
		((IPTSavedSearch) m_ptObject).SetSubscriptionEnabled(m_bSubscriptionEnabled);
		((IPTSavedSearch) m_ptObject).SetReturnProps(ConvertToIntArray(m_listDisplayPropsIDs));
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskAfterStore()
     */
    public void DoTaskAfterStore() 
    {
	    PortletSelectModel myPortletSelectModel = (PortletSelectModel) m_asOwner.
	    		GetModel(SavedSearchEditorAS.STR_MVC_SELECT_PORTLETS);

        if (RepostControl.POSTTOSELF_ACTION_FINISH==m_nAction && 
            myPortletSelectModel.GetItems().GetCount()==0)
        {
	        CreatePortlet();
        }
    }
    
	/**
	 * Code executed when the Editor is starting.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		m_catFolderIDs      	= new XPArrayList();
		m_admFolderIDs      	= new XPArrayList();
		m_listCollabProjIDs 	= new XPArrayList();
		m_listDisplayPropsIDs  	= new XPArrayList();
		m_listContentIDs 		= new XPArrayList();

		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			m_Filter = PortalObjectsFactory.CreateSearchFilter();
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, ObjectSecurityDP.STR_MVC_CLASS_NAME);

			String strDefaultCardLanguageCode = CardLanguagePlugInView.s_AllLanguagesOptionCode;
			((CardLanguagePlugInModel) m_asOwner.GetModel(SavedSearchEditorAS.strCardLanguagePlugInKey)).
					InitializePlugIn(
				        strDefaultCardLanguageCode, 
				        m_asOwner.GetString(1883, "ptmsgs_portaladminmsgs"), 
				        m_asOwner.GetString(1884, "ptmsgs_portaladminmsgs"), 
				        true);

			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
			
			m_nRepositoryMask 	= REPOSITORY_TYPES_KD | REPOSITORY_TYPES_ADMIN | REPOSITORY_SETTINGS_SUBFOLDERS;
			m_nKDTypeMask 		= KDTYPES_FOLDERS | KDTYPES_DOCUMENTS;
			
			/* Default display props */
			m_listDisplayPropsIDs.Add(new Integer(PT_INTRINSICS.PT_PROPERTY_OBJECTNAME));
			m_listDisplayPropsIDs.Add(new Integer(PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED));
		}
		else
		{
			BuildStateFromSearchObjects();
		}
		
		m_FilterIterator = new FilterIterator(m_Session, m_Filter, m_asOwner);
		
		StartSelectPTObject();		
	}
	

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnComeBackFromSubEditor()
     */
    public void DoTaskOnComeBackFromSubEditor() 
    {
        super.DoTaskOnComeBackFromSubEditor();

        /* refresh portlet list */
	    ((PortletSelectModel) m_asOwner.GetModel(SavedSearchEditorAS.STR_MVC_SELECT_PORTLETS)).
	    	RefreshPortletList();
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnChangePage(java.lang.String, java.lang.String)
     */
    public void DoTaskOnChangePage(String _sNewSpace, String _sNewPage) 
    {
        /* save the object so that when editing portlets via the portlet list, 
         * we have the lastest changes. */
        if ( !GetIsEditorReadOnly() &&
             (XPStringUtility.EqualsIgnoreCase(_sNewPage,PortletListDP.STR_MVC_CLASS_NAME)) &&
             (ObjEditorModel.EDITOR_OBJECTID_UNKNOWN != m_nObjectID))
        {
            Finish();
        }
    }

	/**
	 * Helper method to start the Select PTObject List.
	 */
	public void StartSelectPTObject()
	{
		//***** initialize collab project picker
	    CollabExpListModel myCollabExpListModel = (CollabExpListModel) m_asOwner.
	    	GetModel(SavedSearchEditorAS.STR_MVC_SELECT_COLLAB_PROJECT);
	    myCollabExpListModel.InitCollabExpList(m_Session, 1);

	    
	    
		//***** initialize display properties picker
		SelectPTObjectModel mySelectDisplayPropsModel = (SelectPTObjectModel) m_asOwner.
			GetModel(SavedSearchEditorAS.STR_MVC_SELECT_DISPLAY_PROPS);
		mySelectDisplayPropsModel.InitializeSelectPTObject(
		        m_asOwner.GetString(2979, ResourceConstants.PORTALADMINMSGS), 
		        m_asOwner.GetString(2979, ResourceConstants.PORTALADMINMSGS), 
		        PTImageType.ICON_PROPERTY, 
		        m_asOwner.GetString(2980, ResourceConstants.PORTALADMINMSGS), 
		        new int[]{PT_CLASSIDS.PT_PROPERTY_ID}, 
		        2);
		
		mySelectDisplayPropsModel.SetTableInstructions(m_asOwner.GetString(2982, ResourceConstants.PORTALADMINMSGS));
		mySelectDisplayPropsModel.SetTreeTitle(m_asOwner.GetString(2981, ResourceConstants.PORTALADMINMSGS));
		mySelectDisplayPropsModel.SetTreeSubTitle(m_asOwner.GetString(2981, ResourceConstants.PORTALADMINMSGS));

		mySelectDisplayPropsModel.SetEmptyListMessages(
		        m_asOwner.GetString(2983, ResourceConstants.PORTALADMINMSGS),
		        m_asOwner.GetString(2984, ResourceConstants.PORTALADMINMSGS));

		mySelectDisplayPropsModel.SetDefaultRowIcon(PTImageType.ICON_PROPERTY); 
		mySelectDisplayPropsModel.SetEnableMoveRowActions(true);

		/* only display searchable properties */
		String sSearchableProps = GetSearchableProperties();
		if (0<sSearchableProps.length())
		{
		    mySelectDisplayPropsModel.SetDisplayObjects(sSearchableProps);
		}
		else
		{
		    mySelectDisplayPropsModel.DisableAddButton();
		}
		
		
		//***** initialize portlet list picker
		PortletSelectModel mySelectPortletsModel = (PortletSelectModel) m_asOwner.
				GetModel(SavedSearchEditorAS.STR_MVC_SELECT_PORTLETS);
		mySelectPortletsModel.InitializePortletSelectModel(
		        m_Session,
		        m_nObjectID,
		        m_asOwner.GetString(2976, ResourceConstants.PORTALADMINMSGS), 
		        m_asOwner.GetString(2975, ResourceConstants.PORTALADMINMSGS), 
		        3);

		
		//***** initialize content picker
		SelectPTObjectModel mySelectContentModel = (SelectPTObjectModel) m_asOwner.
			GetModel(SavedSearchEditorAS.STR_MVC_SELECT_CONTENT);
		mySelectContentModel.InitializeSelectPTObject(
		        m_asOwner.GetString(3008, ResourceConstants.PORTALADMINMSGS), 
		        m_asOwner.GetString(2985, ResourceConstants.PORTALADMINMSGS), 
		        PTImageType.ICON_PORTLET, 
		        m_asOwner.GetString(2978, ResourceConstants.PORTALADMINMSGS), 
		        new int[]{PT_CLASSIDS.PT_GADGET_ID}, 
		        4);
		
		mySelectContentModel.SetTableInstructions(m_asOwner.GetString(3009, ResourceConstants.PORTALADMINMSGS));
		mySelectContentModel.SetTreeTitle(m_asOwner.GetString(3010, ResourceConstants.PORTALADMINMSGS));
		mySelectContentModel.SetTreeSubTitle(m_asOwner.GetString(3010, ResourceConstants.PORTALADMINMSGS));

		mySelectContentModel.SetEmptyListMessages(
		        m_asOwner.GetString(3011, ResourceConstants.PORTALADMINMSGS),
		        m_asOwner.GetString(3012, ResourceConstants.PORTALADMINMSGS));

		mySelectContentModel.SetDefaultRowIcon(PTImageType.ICON_PORTLET); 
		mySelectContentModel.SetEnableMoveRowActions(false);

		/* only display content server portlets */
		String sContentPortletIDs = GetContentPortlets();
		if (0<sContentPortletIDs.length())
		{
		    mySelectContentModel.SetDisplayObjects(sContentPortletIDs);
		}
		else
		{
		    mySelectContentModel.DisableAddButton();
		}

		
	    if (0<m_listCollabProjIDs.GetSize())
	    {
	        // get the search factory
		    IPTSearchFactory ptsFactory = m_Session.GetSearchFactory();
		    
		    /* get collab qry collection objects */
		    IPTSCollabCollection ptsCollab = ptsFactory.CollabCollection();
		    IPTSField ptsFldProjName = ptsCollab.Name();
		    IPTSField ptsFldProjID = ptsCollab.ParentProjectID();
		    
		    /* get the query req and set the collab qry objects */
		    IPTSQueryRequest ptsReq = ptsFactory.createQueryRequest();
		    ptsReq.setFieldsToReturn(new IPTSField[]{ptsFldProjName, ptsFldProjID});
		    
		    /* for each project id create a IPTSQuery to restrict to */
		    IPTSQuery[] ptsQrys = new IPTSQuery[m_listCollabProjIDs.GetSize()];
			for (int i=0; i<m_listCollabProjIDs.GetSize(); i++)
			{
			    int id = XPConvert.ToInteger(m_listCollabProjIDs.GetElement(i));
			    ptsQrys[i] = ptsCollab.Project(id, new String[]{PTSConstants.TYPE_COLLAB_PROJECTS});
			}
			ptsReq.setQuery("*");
			ptsReq.restrictToAnyOf(ptsQrys);
		    
		    /* execute the qry request */
		    IPTSQueryResponse ptsResp = ptsReq.execute();
		    
		    /* array of project names or ids if we couldn't get the names */
		    Object[][] arProjects;

		    /* populate the arProjects */
		    if (0<ptsResp.getReturnedCount())
		    {
		        arProjects = new Object[ptsResp.getReturnedCount()][2];
		        IXPEnumerator e=ptsResp.getResults();
		        
			    for (int i=0; e.MoveNext(); i++)
			    {
			        IPTSResult obj = (IPTSResult) e.GetCurrent();
			        arProjects[i][0] = obj.getFieldAsObject(ptsFldProjID);
			        arProjects[i][1] = obj.getFieldAsObject(ptsFldProjName);
			    }
		    }
		    else
		    {
			    UIError err = new UIError(
			            UIErrorLevel.WARNING,
			            UIErrorScope.CURRENT_USER, 
			            m_asOwner.GetString(3031, ResourceConstants.PORTALADMINMSGS), 
			            m_asOwner.GetString(3031, ResourceConstants.PORTALADMINMSGS));
			    
			    UIErrorHandler.RaiseError(
			            err,
			            m_asOwner.GetSubSession(),
			            m_asOwner.GetApplication());
			    
			    arProjects = new Object[2][m_listCollabProjIDs.GetSize()];
		        arProjects[0] = m_listCollabProjIDs.ToArray();
		        arProjects[1] = m_listCollabProjIDs.ToArray();			        
		    }

		    /* now set the default objects */
			myCollabExpListModel.SetDefaultObjects(arProjects);
	    }
	    
	    
		// *************** Set display properties
	    if (m_listDisplayPropsIDs.GetSize()>0)
	    {
	        int cnt = m_listDisplayPropsIDs.GetSize();
			Object[][] arProps = new Object[cnt][SelectPTObjectModel.EXPLIST_COL_MAX];
			
			for (int i = 0; i < cnt; i++)
			{
				Object id = m_listDisplayPropsIDs.GetElement(i);

				IPTQueryResult qrResults = m_Session.GetProperties().QuerySingleObject(XPConvert.ToInteger(id));
				Object name;
				if (qrResults.RowCount()>0)
				{
					name = qrResults.ItemAsObject(0, PT_PROPIDS.PT_PROPID_NAME);
				}
				else
				{
				    name = XPResourceManager.FormatMessage(m_asOwner.GetString(3162, ResourceConstants.PORTALADMINMSGS), id);
				}
	
				arProps[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectDisplayPropsModel.m_nNextIndex);
				mySelectDisplayPropsModel.m_nNextIndex++;

				arProps[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	= new Integer(PT_CLASSIDS.PT_PROPERTY_ID);
				arProps[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]= id;
				arProps[i][SelectPTObjectModel.EXPLIST_COL_STRING] 	= name;
			}

			mySelectDisplayPropsModel.SetDefaultObjects(arProps);
		}

	    
		// *************** Set content portlets
	    if (m_listContentIDs.GetSize()>0)
	    {
	        int cnt = m_listContentIDs.GetSize();
			Object[][] arRows = new Object[cnt][SelectPTObjectModel.EXPLIST_COL_MAX];
			
			for (int i = 0; i < cnt; i++)
			{
				Object id = m_listContentIDs.GetElement(i);

				//TODO: jhq error check
				String name;
				IPTGadget ptPortlet;
				try
				{
				    ptPortlet = (IPTGadget) m_Session.GetGadgets().
				    	Open(XPConvert.ToInteger(id), false);
				    
				    name = ptPortlet.GetLocalizedName();
				}
				catch (Exception _e)
				{
				    UIError err = new UIError(
				            UIErrorLevel.WARNING, 
				            UIErrorScope.CURRENT_USER, 
				            _e, 
				            XPResourceManager.FormatMessage(m_asOwner.GetString(3013, ResourceConstants.PORTALADMINMSGS),id),
				    		_e.getMessage());
				    
				    UIErrorHandler.RaiseError(
				            err,
				            m_asOwner.GetSubSession(),
				            m_asOwner.GetApplication());
				    
				    name = XPConvert.ToString(id);
				}
						
				arRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectContentModel.m_nNextIndex);
				mySelectContentModel.m_nNextIndex++;

				arRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	= new Integer(PT_CLASSIDS.PT_GADGET_ID);
				arRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = id;
				arRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] 	= name;
			}

			mySelectContentModel.SetDefaultObjects(arRows);
		}
	}

	private String GetSearchableProperties()
	{
		/* only show properties that are searchable */
		Object[][] filter = new Object[3][2];

		filter[0][0]     = new Integer(PT_PROPIDS.PT_PROPID_PROP_SEARCHABLE);
		filter[1][0]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
		filter[2][0]     = new Integer(1);

		filter[0][1]     = new Integer(PT_PROPIDS.PT_PROPID_ACCESSLEVEL);
		filter[1][1]     = new Integer(PT_FILTEROPS.PT_FILTEROP_GTE);
		filter[2][1]     = new Integer(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
		
		IPTQueryResult qrSearchableProps = m_Session.GetProperties().Query(
		        PT_PROPIDS.PT_PROPID_OBJECTID,
		        -1,
		        PT_PROPIDS.PT_PROPID_NAME,
		        0,
		        -1,
		        filter);
		
		if (0==qrSearchableProps.RowCount())
		{
		    return "";
		}
		
		/* list of displayable objects must be in "clsid,objid" format */
		XPStringBuilder sPropsToDisplay = new XPStringBuilder();
		for (int i=0; i<qrSearchableProps.RowCount(); i++)
		{
		    int id = qrSearchableProps.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
		    sPropsToDisplay.Append(PT_CLASSIDS.PT_PROPERTY_ID);
		    sPropsToDisplay.Append(",");
		    sPropsToDisplay.Append(id);
		    sPropsToDisplay.Append(",");
		}
		
		/* remove the last ',' b4 returning */
		return sPropsToDisplay.Substring(0,sPropsToDisplay.GetLength()-1);
	}
	
	/**
	 * helper method to get content portlet ids
	 */
	private String GetContentPortlets()
	{
	    IPTObjectManager ptOM = m_Session.GetSavedSearches();
	    
	    //RT - Bug 9013018 - We reduce unnecessary queries to DB by checking if the ClassID managed by this
		//ObjectManager is same as classID of Portlets. If they are not same then there is no need to check
		// if object is accessible since managed ClassID is used in ObjectAccessible DB Query.
		
	   if(ptOM.GetManagedClassID() == PT_CLASSIDS.PT_GADGET_ID){
		   int[] arCPortlets = ((IPTSavedSearchManager) ptOM).GetContentPortletIDs();
		    if (0==arCPortlets.length)
		    {
		        return "";
		    }

		    /* list of displayable objects must be in "clsid,objid" format */
			XPStringBuilder sDisplayable = new XPStringBuilder();
			int userid = m_Session.GetSessionInfo().GetCurrentUserID();
			for (int i=0; i<arCPortlets.length; i++)
			{
			    if (ptOM.IsObjectAccessible(arCPortlets[i], userid, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
			    {
				    sDisplayable.Append(PT_CLASSIDS.PT_GADGET_ID);
				    sDisplayable.Append(",");
				    sDisplayable.Append(arCPortlets[i]);
				    sDisplayable.Append(",");
			    }
			}
			
			if (0<sDisplayable.GetLength())
			{
				/* remove the last ',' b4 returning */
				return sDisplayable.Substring(0,sDisplayable.GetLength()-1);
			}
			else
			{
			    return "";
			}
	   } else {
		   return "";
	   }
	}
		
	    
	

	/**
	 *
	 *
	 * @return
	 */
	public IPTSearchResponse GenerateResponse()
	{
		BuildSearchObjectsFromState();

		IPTSearchResponse res = null;

		try
		{
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_BESTBETS, Boolean.FALSE);
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_KWIC, Boolean.FALSE);
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_SPELLCHECK, Boolean.FALSE);
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_QUERYTYPE, "SavSrchPreview");
			
			res = m_req.Search(m_qry);
		}
		catch (Exception e)
		{
			log.Error(e, GetName() + ": Error executing search - " + e.getMessage());
			
			res = null;
			
			XPException i18n = SearchUIUtility.GetI18NException(e, m_asOwner);
			UIError err = new UIError(
				UIErrorLevel.SERIOUS, 
				UIErrorScope.CURRENT_USER, 
				i18n, 
				i18n.GetMessage(),
				"");
				
			err.SetActivitySpace(m_asOwner.GetName());
			err.SetDisplayOnSeparatePage(false);
			err.SetHTMLMessage(((SearchExecutionError)i18n).GetComment());
			err.SetClearWithActivitySpaceChange(true);
			//... To reproduce bug 27811 change (false) to (true) in line below.
			err.SetImmediateClear(false);

			UIErrorHandler.RaiseError(err,m_asOwner.GetSubSession(), m_asOwner.GetApplication());
		}

		return res;
	}

	// interface ISmartSortEditorModelRO
	public XPArrayList GetAdmFolderIDs()
	{
		return m_admFolderIDs;
	}

	/**
	 *
	 *
	 * @return
	 */
	public XPArrayList GetCatFolderIDs()
	{
		return m_catFolderIDs;
	}

	/**
	 *
	 *
	 * @return
	 */
	public XPArrayList GetSelectedFolderIDs(int _type, boolean _accessible)
	{
	    XPArrayList arSelectedIDs = new XPArrayList();
	    
	    
	    /* determine which selected folders to get */
	    if (PT_CLASSIDS.PT_CATALOGFOLDER_ID == _type)
	    {
	        /* seperate the accessible and non-accessible ids */
	        for (int i=0; i<m_catFolderIDs.GetSize(); i++)
	        {
	            Object id = m_catFolderIDs.GetElement(i);
	            
		        if (_accessible == m_Session.GetCatalog().IsCatalogObjectAccessible(_type,
		                XPConvert.ToInteger(id), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
		        {
		            arSelectedIDs.Add(id);
		        }
	        }
	    }
	    else if (PT_CLASSIDS.PT_ADMIN_FOLDER_ID == _type)
	    {
	        /* seperate the accessible and non-accessible ids */
	        for (int i=0; i<m_admFolderIDs.GetSize(); i++)
	        {
	            Object id = m_admFolderIDs.GetElement(i);
	            
		        if (_accessible == m_Session.GetAdminCatalog().IsAdminFolderAccessible(
		                XPConvert.ToInteger(id), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
		        {
		            arSelectedIDs.Add(id);
		        }
	        }
	        // Rob bug#7807316 : always show admin root folder if no folders are selected to show the user that everything under root is searched by default 
	        if ( m_admFolderIDs.GetSize() == 0 ) {
	        	m_admFolderIDs.Add(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER);
	        }
	    }
        
        return arSelectedIDs;
	}
	
	/**
	 *
	 *
	 * @return
	 */
	public String GetLastAdmTreeSpaceId()
	{
		return m_lastAdmTreeSpaceId;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetLastCatTreeSpaceId()
	{
		return m_lastCatTreeSpaceId;
	}

	/* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.savedsearch.ISavedSearchModelRO#GetRepositories()
     */
    public int GetRepositories() 
    {
        return m_nRepositoryMask;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.savedsearch.ISavedSearchModelRO#GetKDTypes()
     */
    public int GetKDTypes() 
    {
        return m_nKDTypeMask;
    }
    
	/**
	 *
	 *
	 * @return
	 */
	public int GetMaxResults()
	{
		return m_nMaxResults;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @return
	 * @deprecated the portlet format & presentation style are now set via the portlet editor 
	 */
	public String GetPortletFormat()
	{
//		return m_strFormat;
	    return null;
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetSelectedOrderProp()
	{
		return m_strSelectedOrderProp;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetSortAscending()
	{
		return m_sortAscending;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsAscending()
	{
		return m_bAscending;
	}

	/**
	 *
	 *
	 * @param strID
	 *
	 * @return
	 */
	public boolean IsClassIDChecked(String strID)
	{
		if (m_ClassIDs == null)
		{
			return true;
		}
		else if(strID.equals(SnapshotADConstraintsView.ALLCLASSIDS))
		{
		    /* for backwards compatibility, in the case where the UI exposed more types than is currently supported */ 
		    return m_ClassIDs.GetSize() >= SnapshotADConstraintsView.ADMIN_TYPES.length;
		}
		
		return m_ClassIDs.Contains(strID);
	}

	/**
	 *
	 *
	 * @param _htFormData
	 */
	public int LoadResultParameters(XPHashtable _htFormData)
	{
	    int status = RepostControl.PAGE_STATUS_VALID;
	    
		/* 0==Relevency, you can not set direction for this therefore one was not set */
		if (!XPStringUtility.EqualsIgnoreCase("0", m_strSelectedOrderProp))
		{
		    m_bAscending 			= ((String[]) _htFormData.GetElement(ResultFormatView.HTMLRADIO_RESULTDIRECTION))[0].equals("asc");
		}
		
		m_strSelectedOrderProp	= ((String[]) _htFormData.GetElement(ResultFormatView.HTMLSELECTORDERPROP))[0];

		try
		{
		    m_nMaxResults = XPConvert.ToInteger(((String[]) _htFormData.GetElement(ResultFormatView.HTMLINPUT_MAXRESULTS))[0]);
		}
		catch (XPFormatException _e)
		{
			UIError err = new UIError(
					UIErrorLevel.SERIOUS, 
					UIErrorScope.CURRENT_USER, 
					_e,
					"Maximum Items displayed must be a Positive Number less than "+Integer.MAX_VALUE/*todo: extract me m_asOwner.GetString(3141, ResourceConstants.PORTALADMINMSGS)*/, 
					_e.GetMessage());
					
			UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			
			status = RepostControl.PAGE_STATUS_INVALID;
		}

		// NOTE: Can't compare to Integer.MAX_VALUE, because it will always be less than this.
		if ((m_nMaxResults > (Integer.MAX_VALUE -1)) || (m_nMaxResults < 0))
		{
			UIError err = new UIError(
					UIErrorLevel.SERIOUS, 
					UIErrorScope.CURRENT_USER, 
					"Maximum Items displayed must be a Positive Number less than "+(Integer.MAX_VALUE - 1)/*todo: extract me m_asOwner.GetString(3141, ResourceConstants.PORTALADMINMSGS)*/,
					"Maximum Items displayed must be a Positive Number less than "+(Integer.MAX_VALUE - 1)/*todo: extract me m_asOwner.GetString(3141, ResourceConstants.PORTALADMINMSGS)*/);
					
			UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			
			status = RepostControl.PAGE_STATUS_INVALID;
		}

		String[] MailData		= (String[]) _htFormData.GetElement(ResultFormatView.HTMLCHECKBOX_MAIL);

		m_bSubscriptionEnabled = false;

		if (null != MailData)
		{
			if (MailData[0].equals("mail"))
			{
				m_bSubscriptionEnabled = true;
			}
		}
		
		return status;
	}

	/**
	 * Add an element to the list of folders
	 */
	public void OnAdd(int intFolderType)
	{
		if (m_ActionData == null)
		{
			m_ActionData = new XPArrayList();
		}

		// get non accessible ids
		// clear the folder array
		// and then add back the non accessible ids
		if (intFolderType == SavedSearchRepostControl.ACTION_ADDADMINFOLDER)
		{
			XPArrayList arNonAccessibleIDs = GetSelectedFolderIDs(PT_CLASSIDS.PT_ADMIN_FOLDER_ID, false);
			m_admFolderIDs.Clear();
			m_admFolderIDs.AddRange(arNonAccessibleIDs);
		}
		else
		{
			XPArrayList arNonAccessibleIDs = GetSelectedFolderIDs(PT_CLASSIDS.PT_CATALOGFOLDER_ID, false);
			m_catFolderIDs.Clear();
			m_catFolderIDs.AddRange(arNonAccessibleIDs);
		}

		/* now add the newly selected ones */
		for (IXPEnumerator i = m_ActionData.GetEnumerator(); i.MoveNext();)
		{
			int id = XPConvert.ToInteger(i.GetCurrent());
			AddFolder(intFolderType, id);
		}
	}

	/**
	 * Delete an element from the list of folders
	 */
	public void OnDel()
	{
		String strCheckboxName = "";

		if (m_DeleteData == null)
		{
			m_DeleteData = new XPHashtable();
		}


		for (IXPEnumerator i = m_DeleteData.GetKeys(); i.MoveNext();)
		{
			int id = XPConvert.ToInteger(i.GetCurrent());
			strCheckboxName = (String) m_DeleteData.GetElement(new Integer(id));
			DeleteFolder(strCheckboxName, id);

			if (id == -1)
			{
				break; // delete all
			}
		}
	}

	/**
	 *
	 */
	public void OnSort()
	{
		m_sortAscending = !m_sortAscending;
	}
	
	/**
	 *
	 */
	public void OnCreatePortlet()
	{
	    PortletSelectModel myPortletSelectModel = (PortletSelectModel) m_asOwner.
	    	GetModel(SavedSearchEditorAS.STR_MVC_SELECT_PORTLETS);
	    
        /* snapshot needs to exist before we can create a portlet */
	    if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
	    {
	        /* this will save the ptobject */
	        Finish();
	        
	        /* we'll refresh the list after we create the new portlet */
	        myPortletSelectModel.SetSnapshotQueryID(m_nObjectID, false);

	        /* we need to trick the object editor that we are still in 
	         * create mode (theoretically, we still are). */
	        SetEditorType(EditorStartControl.EDITOR_START_FLAG_CREATE);
	    }
	   
	    /* create portlet */
	    CreatePortlet();
	    
	    /* refresh the list */
	    myPortletSelectModel.RefreshPortletList();
	}
	
	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		TraceHelper.Trace("SavePage(" + _sPageName + ")");
		TraceHelper.TraceQueryString(_htFormData);

		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(SavSrchMainDP.STR_MVC_CLASS_NAME))
		{
			((CardLanguagePlugInModel) m_asOwner.GetModel(SavedSearchEditorAS.strCardLanguagePlugInKey)).SaveSection(_htFormData);

			if (RepostControl.PAGE_STATUS_INVALID==SaveMainPage(_htFormData))
			{
			    nPageStatus = RepostControl.PAGE_STATUS_INVALID;
			}
			
			LoadClassIDConstraints(_htFormData);
			BuildSavedSearchFromForm(_htFormData);
//			BuildSearchObjectsFromState();
		}
		else if (_sPageName.equals(ResultFormatDP.STR_MVC_CLASS_NAME))
		{
			if (RepostControl.PAGE_STATUS_INVALID==LoadResultParameters(_htFormData))
			{
			    nPageStatus = RepostControl.PAGE_STATUS_INVALID;
			}

			/* save the display prop ids from the exp list to our list */
			SaveDataFromExpListToArrayList(
			        (ExpListModel) m_asOwner.GetModel(SavedSearchEditorAS.STR_MVC_SELECT_DISPLAY_PROPS),
			        m_listDisplayPropsIDs, SelectPTObjectModel.EXPLIST_COL_OBJECTID, 
			        _htFormData);
		}

		/* note: took this out because i don't see why we need to conduct a search after every page save. 
		 * also, there will be times when a search will fail (i.e. search server down, or current user 
		 * doesn't have access to a property (see bug 42737), etc.), but editor should still be functional.*/
//		if (null == GenerateResponse())
//			nPageStatus = RepostControl.PAGE_STATUS_INVALID;

		return nPageStatus;
	}

	/**
	 *
	 *
	 * @return
	 * @deprecated we don't regenerate portlets anymore. instead, via a 'create portlet link', 
	 * a portlet is created and added to an exp list.  this method will always return false.
	 */
	public boolean ShouldRegenerate()
	{
//		return m_bRegeneratePortlet;
	    return false;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean SubscriptionEnabled()
	{
		return m_bSubscriptionEnabled;
	}

	/**
	 * Helper function for adding a folder to the list of folders
	 *
	 * @param intFolderType - The type of folder, Catalog or Admin
	 * @param id The ID of the folder
	 */
	protected void AddFolder(int intFolderType, int id)
	{
		try
		{
			if (intFolderType == SavedSearchRepostControl.ACTION_ADDCATALOGFOLDER)
			{
				m_catFolderIDs.Add(new Integer(id));
			}
			else
			{
				m_admFolderIDs.Add(new Integer(id));
			}
		}
		catch (Exception e)
		{
			log.Error(e, GetName() + ": Failed to add folder - " + e.getMessage());
			throw new XPException(m_asOwner.GetString(770, "ptmsgs_portaladminmsgs") + 3, e);
		}
	}

	/**
	 * Clears the m_ActionData member variable
	 */
	protected void ClearActionData()
	{
		if (m_ActionData == null)
		{
			m_ActionData = new XPArrayList();
		}
		else
		{
			m_ActionData.Clear();
		}
	}

	/**
	 * Clears and recreates the hashtable member variable m_DeleteData
	 *
	 * @param intSize - The size of the new hash table
	 */
	protected void ClearDeleteData(int intSize)
	{
		m_DeleteData = null;
		m_DeleteData = new XPHashtable(intSize);
	}

	/**
	 * Deletes a folder
	 *
	 * @param id
	 */
	protected void DeleteFolder(String strCheckboxName, int id)
	{
		try
		{
			if (XPStringUtility.Compare(strCheckboxName, SavSrchMainDP.HTMLCHECKBOX_CATALOGFOLDER) == 0)
			{
				m_catFolderIDs.Remove(new Integer(id));
			}
			else
			{
				m_admFolderIDs.Remove(new Integer(id));
			}
		}
		catch (Exception e)
		{
			log.Error(e, GetName() + ": Failed to remove folder - " + e.getMessage());
			throw new XPException(m_asOwner.GetString(770, "ptmsgs_portaladminmsgs") + 4, e);
		}
	}

	/**
	 *
	 *
	 * @param o
	 */
	protected void ExtractActionData_FoldersFromCheckboxes(Object oCatalogPost, Object oAdminPost)
	{
		String[] saCatalog = (String[]) oCatalogPost;
		String[] saAdmin = (String[]) oAdminPost;

		int intHTSize = ( (saCatalog == null) ? 0 : saCatalog.length ) + ( (saAdmin == null) ? 0: saAdmin.length) ;

		ClearDeleteData(intHTSize);

		for (int i = 0; (saCatalog != null) && (i < saCatalog.length); i++)
		{
			int id;

			try
			{
				id = XPConvert.ToInteger(saCatalog[i]);
			}
			catch (Exception e)
			{
				continue;
			}

			m_DeleteData.PutElement(new Integer(id), SavSrchMainDP.HTMLCHECKBOX_CATALOGFOLDER);
		}

		for (int i = 0; (saAdmin != null) && (i < saAdmin.length); i++)
		{
			int id;

			try
			{
				id = XPConvert.ToInteger(saAdmin[i]);
			}
			catch (Exception e)
			{
				continue;
			}

			m_DeleteData.PutElement(new Integer(id), SavSrchMainDP.HTMLCHECKBOX_ADMINFOLDER);
		}
	}

	/**
	 *
	 */
	protected void ExtractActionData_FoldersFromTree(int intFolderType)
	{
		ClearActionData();

		// if the above form element was found it means we need to treat
		// the relevant form elements as referring to admin folders
		if (intFolderType == SavedSearchRepostControl.ACTION_ADDCATALOGFOLDER)
		{
			if (m_asOwner.GetSubSpaceExists("CatFolderTree"))
			{
				ATreeAS asFolderTree   = (ATreeAS) m_asOwner.GetSubSpace(
						"CatFolderTree");
				ITreeModelRO myTree    = (ITreeModelRO) asFolderTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList mySelected = myTree.GetSelectedItems();

				for (int i = 0; i < mySelected.GetSize(); i++)
				{
					int id = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
					m_ActionData.Add(new Integer(id));
				}
			}
			 // TODO: else we're doomed
		}
		else
		{
			if (m_asOwner.GetSubSpaceExists("AdminFolderTree"))
			{
				ATreeAS asFolderTree   = (ATreeAS) m_asOwner.GetSubSpace(
						"AdminFolderTree");
				ITreeModelRO myTree    = (ITreeModelRO) asFolderTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList mySelected = myTree.GetSelectedItems();

				for (int i = 0; i < mySelected.GetSize(); i++)
				{
					int id = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
					m_ActionData.Add(new Integer(id));
				}
			}
			 // TODO: else we're doomed
		}
	}

	/**
	 *
	 *
	 * @param o
	 *
	 * @return
	 */
	protected String ExtractOneElement(Object o)
	{
		String[] sa = (String[]) o;

		return ((sa == null) || (sa.length < 1)) ? null : sa[0];
	}

	/**
	 *
	 *
	 * @return
	 */
	protected int GetAction()
	{
		return m_nAction;
	}

	/**
	 *
	 *
	 * @param action
	 *
	 * @return
	 */
	protected int RemoveGroupFromAction(int action)
	{
		if (action >= 1000)
		{
			action -= 1000;
		}

		return action;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveMainPage(XPHashtable _htFormData)
	{
	    /* get the repository info */
	    m_nRepositoryMask = 0;
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_KD_CB))
	        m_nRepositoryMask |= REPOSITORY_TYPES_KD;
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_COLLAB_CB))
	        m_nRepositoryMask |= REPOSITORY_TYPES_COLLAB;
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_CONTENT_CB))
	        m_nRepositoryMask |= REPOSITORY_TYPES_CONTENT;
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_ALL_FOLDERS))
	        m_nRepositoryMask |= REPOSITORY_SETTINGS_ALLFOLDERS;
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_ALL_DOCUMENTS))
	        m_nRepositoryMask |= REPOSITORY_SETTINGS_ALLDOCUMENTS;
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_SUBFOLDERS))
	        m_nRepositoryMask |= REPOSITORY_SETTINGS_SUBFOLDERS;
 
	    /* queries can not constrain on both admin repo & (folders and/or docs) */
	    if (_htFormData.ContainsKey(SnapshotQueryRangeView.HTMLINPUT_ADMIN_CB))
	    {
	        m_nRepositoryMask |= REPOSITORY_TYPES_ADMIN;
	    }
		    
		/* we need to have aleast one repository app selected */
		int nAllAppsMask = 
		    REPOSITORY_TYPES_KD | REPOSITORY_TYPES_ADMIN | 
		    REPOSITORY_TYPES_COLLAB | REPOSITORY_TYPES_CONTENT;
			
	    if (0 == (m_nRepositoryMask & nAllAppsMask))
	    {
	        m_nRepositoryMask = REPOSITORY_TYPES_KD | REPOSITORY_TYPES_ADMIN;
	    }

	    /* get the kd types info */
	    if (0!=(m_nRepositoryMask&REPOSITORY_TYPES_KD))
	    {
		    m_nKDTypeMask = 0;
		    if (_htFormData.ContainsKey(SnapshotKDConstraintsView.HTMLINPUT_KD_FOLDERS_CB))
		        m_nKDTypeMask |= KDTYPES_FOLDERS;
		    if (_htFormData.ContainsKey(SnapshotKDConstraintsView.HTMLINPUT_KD_DOCUMENTS_CB))
		        m_nKDTypeMask |= KDTYPES_DOCUMENTS;
		    
		    /* we need to have atleast one of the kdtypes to be checked */
		    if (m_nKDTypeMask == 0)
		    {
		        m_nKDTypeMask = KDTYPES_FOLDERS | KDTYPES_DOCUMENTS;
		    }
	    }

//	    // store the recursive check box selection
//		m_bRecursive = _htFormData.ContainsKey(SavSrchFilterView.HTMLCHECKBOX_RECURSIVE);

		switch (RemoveGroupFromAction(GetAction()))
		{
		case SavedSearchRepostControl.POSTTOSELF_ACTION_FINISH:

			//			ExtractActionData_OptionsFromCheckboxes(_htFormData);
			break;

		case SavedSearchRepostControl.ACTION_ADDADMINFOLDER:

			/* old jscript submit
			ExtractActionData_FoldersFromTree(_htFormData.GetElement(SmartSortEditorMainView.HTMLHIDDEN_FOLDERSELECTED));
			*/
			ExtractActionData_FoldersFromTree(SavedSearchRepostControl.ACTION_ADDADMINFOLDER);

			m_lastAdmTreeSpaceId = ExtractOneElement(_htFormData.GetElement(
						SavSrchMainDP.HTMLHIDDEN_ADMSPACEID));

			break;

		case SavedSearchRepostControl.ACTION_ADDCATALOGFOLDER:

			ExtractActionData_FoldersFromTree(SavedSearchRepostControl.ACTION_ADDCATALOGFOLDER);

			m_lastCatTreeSpaceId = ExtractOneElement(_htFormData.GetElement(
						SavSrchMainDP.HTMLHIDDEN_CATSPACEID));

			break;

		case SavedSearchRepostControl.ACTION_DEL:
			Object oCatalogPost = _htFormData.GetElement(SavSrchMainDP.HTMLCHECKBOX_CATALOGFOLDER);
			Object oAdminPost = _htFormData.GetElement(SavSrchMainDP.HTMLCHECKBOX_ADMINFOLDER);
			
			ExtractActionData_FoldersFromCheckboxes(oCatalogPost, oAdminPost);

			/* if we delete folders, we need to get a fresh tree so our old selected values aren't in there */
			if (null!=oCatalogPost && ((String[]) oCatalogPost).length>0)
			{
				m_lastCatTreeSpaceId = "";
			}
			if (null!=oAdminPost && ((String[]) oAdminPost).length>0)
			{
				m_lastAdmTreeSpaceId = "";
			}

			break;

		case SavedSearchRepostControl.ACTION_SORT:
			ClearActionData();

			break;
			
		}

		/* Save the collab proj ids from the exp list to our arraylist */
		SaveDataFromExpListToArrayList(
		        ((ExpListModel) m_asOwner.GetModel(SavedSearchEditorAS.STR_MVC_SELECT_COLLAB_PROJECT)),
		        m_listCollabProjIDs, CollabExpListModel.EXPLIST_COL_OBJECTID, 
		        _htFormData);
		
		/* Save the content portlet ids from the exp list to our arraylist */
		SaveDataFromExpListToArrayList(
		        ((ExpListModel) m_asOwner.GetModel(SavedSearchEditorAS.STR_MVC_SELECT_CONTENT)),
		        m_listContentIDs, SelectPTObjectModel.EXPLIST_COL_OBJECTID, 
		        _htFormData);

		return RepostControl.PAGE_STATUS_VALID;
	}

	
	private void SaveDataFromExpListToArrayList(ExpListModel _model, XPArrayList _listData, int _iColToSave, XPHashtable _htFormData)
	{
		_model.SaveSection(_htFormData);

		PTGrowableSortedArrayWrapper saItems = _model.GetItems();

	    _listData.Clear();

	    for (int i=0; i<saItems.GetCount(); i++) 
		{
            _listData.Add(saItems.GetItem(i,_iColToSave));
        }                                                
	}
	
	/**
	 *
	 */
	private void BuildSearchObjectsFromState()
	{
		try
		{
			// we always start with a blank request...
			m_req = m_Session.GetSearchRequest();
		}
		catch(Exception e)
		{
			XPException i18n = SearchUIUtility.GetI18NException(e, m_asOwner);
			UIError err = new UIError(
				UIErrorLevel.SERIOUS, 
				UIErrorScope.ADMIN_USERS, 
				i18n, 
				i18n.GetMessage(),
				"");
				
			err.SetActivitySpace(m_asOwner.GetName());
			err.SetDisplayOnSeparatePage(false);
			err.SetHTMLMessage(((SearchExecutionError)i18n).GetComment());
			err.SetClearWithActivitySpaceChange(true);
			err.SetImmediateClear(true);

			UIErrorHandler.RaiseError(err,m_asOwner.GetSubSession(), m_asOwner.GetApplication());
		}
		
		
		//****************  filter/query settings ***************************/

		/* text search string */
		String strSrchString = m_Filter.GetSearchString();
		if (strSrchString.equals(""))
		{
			m_Filter.SetSearchString("*");
		}

		/* create our query */
		m_qry = m_req.CreateAdvancedQuery(m_Filter);

		/* return props setting */
		if (m_listDisplayPropsIDs.GetSize() > 0)
		{
		    try
		    {
				m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_RET_PROPS,
					ConvertToIntArray(m_listDisplayPropsIDs));
		    }
			catch(Exception e)
			{
				XPException i18n = SearchUIUtility.GetI18NException(e, m_asOwner);
				UIError err = new UIError(
					UIErrorLevel.WARNING, 
					UIErrorScope.CURRENT_USER, 
					i18n, 
					m_asOwner.GetString(3164, ResourceConstants.PORTALADMINMSGS),
					i18n.ToString());
					
				err.SetActivitySpace(m_asOwner.GetName());
				err.SetDisplayOnSeparatePage(false);
				err.SetHTMLMessage(((SearchExecutionError)i18n).GetComment());
				err.SetClearWithActivitySpaceChange(true);
				err.SetImmediateClear(true);

				UIErrorHandler.RaiseError(err,m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
		} /* else, default==return usual fields */

		/* max results */
		m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS, new Integer(m_nMaxResults));

		/* orderby */
		if (!m_strSelectedOrderProp.equals("0"))
		{
			int orderprop = XPConvert.ToInteger(m_strSelectedOrderProp);
			// rob CF #70370, pre 6.1.x portals uses value 10 as the orderby property when sorting by name. 6.1.x and later uses value 1.
			// for the CF, just map 1 to 10. Fix properly in a later release
			if (PT_INTRINSICS.PT_PROPERTY_NAMEINDEX == orderprop)
				orderprop = PT_INTRINSICS.PT_PROPERTY_OBJECTNAME; 

			if (!m_bAscending) 
			{
				orderprop = -orderprop;
			}

			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY, new Integer(orderprop));
		}

		
		
		//****************  language settings ***************************/

		// Get the Langauge constraint
		String strLanguageCode = ((CardLanguagePlugInModel) m_asOwner.
			GetModel(SavedSearchEditorAS.strCardLanguagePlugInKey)).
			GetCardLanguageCode();

		/* set it on the request */
		if (!strLanguageCode.equals(CardLanguagePlugInView.s_AllLanguagesOptionCode))
		{
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE, strLanguageCode);
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE, Boolean.TRUE);
		}
		else
		{
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE, Boolean.FALSE);
		}

		
		
		//**************** abstract types settings ***************************/
		int lAbstractTypeMask = 0;

		/*TODO:jhq according the search team, using abstypes in addition to object type constraints can 
		 * lead to odd behavior.  creaters of snapshot queries should constrain thier queries
		 * based on apps and then object types.  Queries constraining on doc/folder abstypes 
		 * will restrict admin repo querying.
		 */

		/* folders abstract type */
		if (0 != (m_nRepositoryMask&REPOSITORY_SETTINGS_ALLFOLDERS))
		{
			lAbstractTypeMask |= PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_CONTAINERS;
		}

		/* documents abstype */
		if (0 != (m_nRepositoryMask&REPOSITORY_SETTINGS_ALLDOCUMENTS))
		{
			lAbstractTypeMask |= PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_DOCUMENTS;
		}

		/* now lets set the abstract types */ 
		if (lAbstractTypeMask > 0)
		{
			m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES, 
			        new Integer(lAbstractTypeMask));
		}

		/* include subfolders? default==true */
		if (0==(m_nRepositoryMask&REPOSITORY_SETTINGS_SUBFOLDERS))
		{
		    m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS, Boolean.FALSE);
		}
		

		
		//**************** application baised constraints ***************************/
		int lApplicationMask  = 0;

		/* portal app */
		if (0!=(m_nRepositoryMask&REPOSITORY_TYPES_KD) || 0!=(m_nRepositoryMask&REPOSITORY_TYPES_ADMIN))
		{
		    lApplicationMask |= PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL;

		    /* will hold obj type constriants (i.e. kd+admin) */
		    XPArrayList listObjTypeConstriants = new XPArrayList();
		
			/* KD (portal) repository constraints */
			if (0!=(m_nRepositoryMask&REPOSITORY_TYPES_KD))
			{
			    /* if we selected some KD folders, set them now */
				if (m_catFolderIDs.GetSize() > 0)
				{
					m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
					        ConvertToIntArray(m_catFolderIDs));
				}
				else /* default to root folder to deal with 5.0 search legacy wierdness, see bug 43493 */
				{
				    m_catFolderIDs.Add(new Integer(1));
				    m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS, ARR_ROOT_FOLDERID);
				}

				/* should we limit to KD folders */
			    if (0!=(m_nKDTypeMask & KDTYPES_FOLDERS))
			    {
			        listObjTypeConstriants.Add(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
			    }
			    
			    /* should we limit to KD documents */
			    if (0!=(m_nKDTypeMask & KDTYPES_DOCUMENTS))
			    {
			        listObjTypeConstriants.Add(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
			    }
			}
		
			/* admin (portal) repositories settings */
			if (0!=(m_nRepositoryMask&REPOSITORY_TYPES_ADMIN))
			{
				/* add the admin obj types */
				listObjTypeConstriants.AddRange(m_ClassIDs);

				/* add admin folders */
				if (m_admFolderIDs.GetSize() > 0)
				{
					m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
					        ConvertToIntArray(m_admFolderIDs));
				}
				else /* default to root folder to deal with 5.0 search legacy wierdness, see bug 43493 */
				{
				    m_admFolderIDs.Add(new Integer(1));
				    m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS, ARR_ROOT_FOLDERID);
				}
			}

			/* lets set the object types */
			if (0<listObjTypeConstriants.GetSize())
			{
			    m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES, 
			            ConvertToIntArray(listObjTypeConstriants));
			}
		}
		
		/* collab app */
		if (0!=(m_nRepositoryMask&REPOSITORY_TYPES_COLLAB))
		{
		    lApplicationMask |= PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB;
		    
			if (m_listCollabProjIDs.GetSize() > 0)
			{
				m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID,
					ConvertToIntArray(m_listCollabProjIDs));
			}
		}
		
		/* content app */
		if (0!=(m_nRepositoryMask&REPOSITORY_TYPES_CONTENT))
		{
		    lApplicationMask |= PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT;
		    
			if (m_listContentIDs.GetSize() > 0)
			{
				m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID,
					ConvertToIntArray(m_listContentIDs));
			}
		}

		/* default to portal application mask */
		if(0 == lApplicationMask) 	
		{
			lApplicationMask = PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL; 
		}

		/* set application mask */
		m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS, new Integer(lApplicationMask));

		
		
//		m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS, new Boolean(m_bRecursive));
//		if ((m_ClassIDs.GetSize() == 1) &&
//				((String) m_ClassIDs.GetElement(0)).equals(SearchConstraintsView.ALLCLASSIDS))
//		{
//			m_ClassIDs.RemoveAt(0);
//		}
//
//		if (m_ClassIDs.GetSize() > 0)
//		{
//			int[] objIDs = new int[m_ClassIDs.GetSize()];
//			int classidcount	  = 0;
//			int lAbstractTypeMask = 0;
//			int lApplicationMask  = 0;

//			for (int i = 0; i < m_ClassIDs.GetSize(); i++)
//			{
//				int clsid = XPConvert.ToInteger((String) m_ClassIDs.GetElement(i));

//				if (clsid < 9999)
//				{
//					objIDs[classidcount++] = clsid;
//				}
//				else
//				{
//					switch (clsid)
//					{
//					case SearchConstraintsView.DOCUMENT_TYPES:
//						lAbstractTypeMask |= PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_DOCUMENTS;
//
//						break;

//					case SearchConstraintsView.FOLDER_TYPES:
//						lAbstractTypeMask |= PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_CONTAINERS;
//
//						break;

//					case SearchConstraintsView.VIEW_TYPES:
//						lAbstractTypeMask |= PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_OTHER;
//
//						break;

//					case SearchConstraintsView.PORTAL_TYPE:
//						lApplicationMask |= PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL;
//
//						break;
//
//					case SearchConstraintsView.COLLAB_TYPE:
//						lApplicationMask |= PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB;
//
//						break;
//
//					case SearchConstraintsView.CONTENT_TYPE:
//						lApplicationMask |= PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT;
//
//						break;

//					default:
//						break;
//					}
//				}
//			}
//
//			// now set them
////			if (size > 0)
////			{
//				m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES,
//					objIDs);
////			}
//
////			if (lAbstractTypeMask > 0)
////			{
////				m_req.SetSettings(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES,
////					new Integer(lAbstractTypeMask));
////			}
//		}
	}

	
	/**
	 *
	 */
	private void BuildStateFromSearchObjects()
	{
		try
		{
			m_bSubscriptionEnabled     = ((IPTSavedSearch) m_ptObject).GetSubscriptionEnabled();
			
			m_req     = (IPTSearchRequest) ((IPTSavedSearch) m_ptObject).GetSearchRequest();
			m_qry     = (IPTSearchQuery) ((IPTSavedSearch) m_ptObject).GetSearchQuery();

			m_Filter = m_qry.GetContentAsIPTFilter();

			// Set to null to indicate that the default language should be used
			String strDefaultCardLanguageCode = null;
			String strLang					  = m_req.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE);
			boolean limitLang				  = (m_req.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE) != 0);

			if ((null != strLang) && (strLang.length() > 1) && limitLang)
			{
				strDefaultCardLanguageCode = strLang;
			}
			else
			{
				strDefaultCardLanguageCode = CardLanguagePlugInView.s_AllLanguagesOptionCode;
			}

			// Here initialize the language plug-in.
			((CardLanguagePlugInModel) m_asOwner.GetModel(SavedSearchEditorAS.strCardLanguagePlugInKey)).InitializePlugIn(strDefaultCardLanguageCode,
				m_asOwner.GetString(1883, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1884, "ptmsgs_portaladminmsgs"), true);

			/* reset repository mask so we can rebuilt it */
			m_nRepositoryMask = 0;

			// Load Abstract types
			int nMask = m_req.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES);

			/* documents from any source */
			if ((nMask & PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_DOCUMENTS) > 0)
			{
			    /*TODO: jhq- we shouldn't add abs types to the classids */
//				m_ClassIDs.Add(XPConvert.ToString(SearchConstraintsView.DOCUMENT_TYPES));
//				m_AbstractCount++;
				m_nRepositoryMask |= REPOSITORY_SETTINGS_ALLDOCUMENTS;
			}

			/* folders from any source */
			if ((nMask & PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_CONTAINERS) > 0)
			{
			    /*TODO: jhq- we shouldn't add abs types to the classids */
//				m_ClassIDs.Add(XPConvert.ToString(SearchConstraintsView.FOLDER_TYPES));
//				m_AbstractCount++;
				m_nRepositoryMask |= REPOSITORY_SETTINGS_ALLFOLDERS;
			}

			/* this is the "Views (Communities, Portlets, etc.)" option. we are no longer using this 
			 * we are using the admin repo, which encompasses these types */
			if ((nMask & PT_SEARCH_ABSTYPES.PT_SEARCH_ABSTYPES_OTHER) > 0)
			{
//				m_ClassIDs.Add(XPConvert.ToString(SearchConstraintsView.VIEW_TYPES));
//				m_AbstractCount++;
				m_nRepositoryMask |= REPOSITORY_TYPES_ADMIN;
			}

			// Load Applicaton types (also considered abstract in this UI)
			int nAppMask = m_req.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS);
			
		    /*TODO:jhq- remove app/repository type out of here */
//			if ((nAppMask & PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL) > 0)
//			{
//				m_ClassIDs.Add(XPConvert.ToString(SearchConstraintsView.PORTAL_TYPE));
//				m_AbstractCount++;
//				m_nRepositoryMask |= REPOSITORY_TYPES_KD;
//				m_nRepositoryMask |= REPOSITORY_TYPES_ADMIN;
//			}

			/* collab server app */
			if ((nAppMask & PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB) > 0)
			{
			    /*TODO: jhq- we shouldn't add app types to the classids */
//				m_ClassIDs.Add(XPConvert.ToString(SearchConstraintsView.COLLAB_TYPE));
//				m_AbstractCount++;
				m_nRepositoryMask |= REPOSITORY_TYPES_COLLAB;
			}

			/* content server app */
			if ((nAppMask & PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT) > 0)
			{
			    /*TODO: jhq- we shouldn't add abs types to the classids */
//				m_ClassIDs.Add(XPConvert.ToString(SearchConstraintsView.CONTENT_TYPE));
//				m_AbstractCount++;
				m_nRepositoryMask |= REPOSITORY_TYPES_CONTENT;
			}

			/* object type constriants: can be any portal object, kd or admin, 
			 * so we need to manually seperate the two since we handle them differently in the UI */
			Object[] arTypes = (Object[]) m_req.
				GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES);

			/* rest our clsids */
			if (m_ClassIDs == null)
			{
				m_ClassIDs = new XPArrayList();
			}

			/* reset our kd type mask */
			m_nKDTypeMask = 0;

			/* we have obj typ constraints */
			if ((null != arTypes) && (arTypes.length > 0))
			{
			    /* loop thru the returned obj types and add them to the appropriate list/mask */
			    for (int i = 0; i < arTypes.length; i++)
				{
			        String clsid = XPConvert.ToString(arTypes[i]);
				    
					if (XPStringUtility.EqualsIgnoreCase(clsid, CLASSID_KDFOLDER))
					{
					    m_nKDTypeMask |= KDTYPES_FOLDERS;
					}
					else if (XPStringUtility.EqualsIgnoreCase(clsid, CLASSID_KDDOCUMENT))
					{
					    m_nKDTypeMask |= KDTYPES_DOCUMENTS;
					}
					else /* admin object */
					{
						m_ClassIDs.Add(clsid);
					}
				}

			    /* determine which portal repositories where being searched */
				if ( (nAppMask & PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL)>0)
				{
				    /* KD repository */
				    if ( (0!=(m_nKDTypeMask&KDTYPES_FOLDERS)) || (0!=(m_nKDTypeMask&KDTYPES_DOCUMENTS)) )
				    {
				        m_nRepositoryMask |= REPOSITORY_TYPES_KD;
				    }
				    
				    /* admin repository */
				    if (m_ClassIDs.GetSize()>0)
					{
					    m_nRepositoryMask |= REPOSITORY_TYPES_ADMIN;
					}
				}			
			}
			else /* we don't have constraints */ 
			{
			    /* which means that if the portal app was being searched, 
			     * then both repos were being searched */
				if ( (nAppMask & PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL)>0)
				{
			        m_nRepositoryMask |= REPOSITORY_TYPES_KD;
				    m_nRepositoryMask |= REPOSITORY_TYPES_ADMIN;
				}

//			    /* no constraints on object types
//			     * note: just because we are adding all types does NOT necessarily mean 
//			     * that we will be searching portal objects. Below we will check the 
//			     * app mask for the portal app */
//				m_ClassIDs.Add(SearchConstraintsView.ALLCLASSIDS);
//			    m_nKDTypeMask |= KDTYPES_FOLDERS;
//			    m_nKDTypeMask |= KDTYPES_DOCUMENTS;
			}


			// TODO: Verify that in this instance null values are NOT allowed.  GetSettingsAsInt will throw an exception.
			int nOrderProp = m_req.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY);

			if (nOrderProp > 0)
			{
				m_bAscending = true;
			}
			else
			{
				m_bAscending     = false;
				nOrderProp		 = -nOrderProp;
			}

			if (PT_INTRINSICS.PT_PROPERTY_NAMEINDEX == nOrderProp)
				nOrderProp = PT_INTRINSICS.PT_PROPERTY_OBJECTNAME; // this allows the UI to refer to the name property

			m_strSelectedOrderProp = XPConvert.ToString(nOrderProp);

			int nMaxResults = m_req.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS);

			if (nMaxResults > 0)
			{
				m_nMaxResults = nMaxResults;
			}

			Object[] catFldrs = (Object[]) m_req.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS);

			if ((null != catFldrs) && (catFldrs.length > 0))
			{
				for (int i = 0; i < catFldrs.length; i++)
				{
					m_catFolderIDs.Add(catFldrs[i]);
				}
				m_nRepositoryMask |= REPOSITORY_TYPES_KD;
			}

			Object[] admFldrs = (Object[]) m_req.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS);

			if ((null != admFldrs) && (admFldrs.length > 0))
			{
				for (int i = 0; i < admFldrs.length; i++)
				{
					m_admFolderIDs.Add(admFldrs[i]);
				}
				m_nRepositoryMask |= REPOSITORY_TYPES_ADMIN;
			}

			// set the collab project filters
			Object[] collabProjs = (Object[]) m_req.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_COLLAB_PROJECT_ID);

			if ((null != collabProjs) && (collabProjs.length > 0))
			{
				for (int i = 0; i < collabProjs.length; i++)
				{
					m_listCollabProjIDs.Add(collabProjs[i]);
				}
				m_nRepositoryMask |= REPOSITORY_TYPES_COLLAB;
			}

			// set the collab project filters
			Object[] contentPortlets = (Object[]) m_req.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_ASSOC_PORTLET_ID);

			if ((null != contentPortlets) && (contentPortlets.length > 0))
			{
				for (int i = 0; i < contentPortlets.length; i++)
				{
					m_listContentIDs.Add(contentPortlets[i]);
				}
				m_nRepositoryMask |= REPOSITORY_TYPES_CONTENT;
			}

//			m_bRecursive = XPConvert.ToBoolean(m_req.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS));
			if(XPConvert.ToBoolean(m_req.GetSettingsAsObject(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS)))
			{
			   m_nRepositoryMask |= REPOSITORY_SETTINGS_SUBFOLDERS; 
			}
			
			// set the display (ret_props) properties
			Object[] displayProps = ((IPTSavedSearch) m_ptObject).GetReturnProps();

			if ((null != displayProps) && (displayProps.length > 0))
			{
				for (int i = 0; i < displayProps.length; i++)
				{
					m_listDisplayPropsIDs.Add(displayProps[i]);
				}
			}

		}
		catch (Exception e)
		{
			log.Error(e, GetName() + ": Error building search objects- " + e.getMessage());
		}
	}

	/**
	 *
	 *
	 * @param list
	 *
	 * @return
	 */
	private int[] ConvertToIntArray(XPArrayList list)
	{
		return ConvertToIntArray(list.ToArray());
	}

	/**
	 *
	 *
	 * @param ar
	 *
	 * @return
	 */
	private int[] ConvertToIntArray(Object[] ar)
	{
		int[] newAr = new int[ar.length];

		for (int i = 0; i < ar.length; i++)
		{
			newAr[i] = XPConvert.ToInteger(ar[i]);
		}

		return newAr;
	}

	/**
	 *
	 *
	 * @param _htFormData
	 */
	private void LoadClassIDConstraints(XPHashtable _htFormData)
	{
		if (m_ClassIDs == null)
		{
			m_ClassIDs = new XPArrayList();
		}

		m_ClassIDs.Clear();
//		m_AbstractCount = 0;

//		String[] strIDs = (String[]) _htFormData.GetElement(SearchConstraintsView.HTMLCHECKBOX_CLASSID);
		String[] strIDs = (String[]) _htFormData.GetElement(SnapshotADConstraintsView.HTMLINPUT_ADTYPE_PREFIX);

		if (null != strIDs)
		{
			for (int i = 0; i < strIDs.length; i++)
			{
				m_ClassIDs.Add((String) strIDs[i]);

//				if (XPConvert.ToInteger(strIDs[i]) >= 9999) // see SearchConstraints
//				{
//					m_AbstractCount++;
//				}
			}
		}

//		if (m_ClassIDs.GetSize() == 0)
//		{
//			m_ClassIDs.Add(SearchConstraintsView.ALLCLASSIDS);
//		}
	}

	/**
	 *
	 *
	 * @return
	 */
	public IASQueryResult GetProperties()
	{
		return m_FilterIterator.GetPropertiesVisibleToCurrentUser();
	}
	
	/**
	 *
	 *
	 * @return
	 */
	public Object[][] GetDisplayFieldsInfo()
	{
	    int nPropCnt = m_listDisplayPropsIDs.GetSize();
	    
	    Object[][] arIDsAndTypes = new Object[nPropCnt][3]; 
	    
	    for (int i=0; i<nPropCnt; i++)
	    {
	        int id = XPConvert.ToInteger(m_listDisplayPropsIDs.GetElement(i));
	        IPTQueryResult qryProp = m_Session.GetProperties().QuerySingleObject(id);

	        if (null!=qryProp && qryProp.RowCount()>0)
	        {
		        
		        arIDsAndTypes[i][INDEX_DISPLAYPROPID] 	= new Integer(id);
		        arIDsAndTypes[i][INDEX_DISPLAYPROPTYPE] = new Integer(qryProp.ItemAsInt(0,PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
		        arIDsAndTypes[i][INDEX_DISPLAYPROPNAME] = qryProp.ItemAsString(0,PT_PROPIDS.PT_PROPID_NAME);
	        }
	    }
	        
		return arIDsAndTypes;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int[] GetDisplayFields()
	{
		return ConvertToIntArray(m_listDisplayPropsIDs);
	}

    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.savedsearch.ISavedSearchModelRO#IsCollabInstalled()
     */
    public boolean IsCollabInstalled() 
    {
	    IPTServerConfigSettings ptSC = (IPTServerConfigSettings) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);
	    return (0 != ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_COLLAB_SERVER_INSTALLED));
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.admin.editors.savedsearch.ISavedSearchModelRO#IsCollabInstalled()
     */
    public boolean IsContentInstalled() 
    {
	    IPTServerConfigSettings ptSC = (IPTServerConfigSettings) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);
	    return (0 != ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_PLUMTREE_CONTENT_SERVER_INSTALLED));
    }

    /**
	 * returns whether the folder limitations should be applied recursively
	 * to subfolders.
	 * 
	 * @return
	 * 
	 * @deprecated @see GetRepositories() and REPOSITORY_SETTINGS_SUBFOLDERS
	 */
	public boolean GetApplyRecursive()
	{
		return 0 != (m_nRepositoryMask&REPOSITORY_SETTINGS_SUBFOLDERS);
	}
	
	private void CreatePortlet()
	{
	    try
	    {
		    ((IPTSavedSearch) m_ptObject).StoreResultPortlet(
		        (String) m_ptObject.GetName(), 
		        PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL, 
		        true);
	    }
	    catch (PTException pte)
	    {
	        if (PT_RESULTCODES.PT_E_ACCESSDENIED == pte.GetErrorCode())
	        {
				UIError err = new UIError(
						UIErrorLevel.SERIOUS, 
						UIErrorScope.CURRENT_USER, 
						pte,
						m_asOwner.GetString(3141, ResourceConstants.PORTALADMINMSGS), 
						pte.GetMessage());
						
				UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
	        else
	        {
	            throw new XPException(pte);
	        }
	    }
	}
}
