package com.plumtree.portalpages.admin.editors.savedsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author joseq
 *
 * this view displays query constraints for administration folders & objects
 */
public class SnapshotADConstraintsView extends EditorView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
			"com.plumtree.portalpages.admin.editors.savedsearch.SnapshotADConstraintsView");

	public static final String STR_MVC_CLASS_NAME = "SnapshotADConstraints";
	
	/**
	 * html element name prefix for all admin type checkboxes
	 */
	public static final String HTMLINPUT_ADTYPE_PREFIX = "in_cb_ADTYPE_";
	
	/**
	 * javascript name all type checkbox
	 */
	public static final String JAVASCRIPT_ALLCHECKED = "ToggleAllChecked";
	
	/**
	 * token for all types
	 */
	public static final String ALLCLASSIDS = "9999";

	
	public static final int[] ADMIN_TYPES = new int[]
	        { 
	            PT_CLASSIDS.PT_USER_ID,
	            PT_CLASSIDS.PT_USERGROUP_ID,
	            PT_CLASSIDS.PT_AUTHSOURCE_ID,
	            PT_CLASSIDS.PT_ADMIN_FOLDER_ID,
	            PT_CLASSIDS.PT_FILTER_ID,
	            PT_CLASSIDS.PT_SAVEDSEARCH_ID,
	            PT_CLASSIDS.PT_DATASOURCE_ID,
	            PT_CLASSIDS.PT_PROPERTY_ID,
	            PT_CLASSIDS.PT_DOCUMENTTYPE_ID,
	            PT_CLASSIDS.PT_CRAWLER_ID,
	            PT_CLASSIDS.PT_GADGET_ID,
	            PT_CLASSIDS.PT_INVITATION_ID,
	            PT_CLASSIDS.PT_FEDERATEDPORTAL_ID,
	            PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID,
	            PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID,
	            PT_CLASSIDS.PT_GADGETBUNDLE_ID,
	            PT_CLASSIDS.PT_PAGETEMPLATE_ID,
// Note: jobs is not a cached object, therefore, sq's can't use it, as of now PT_CLASSIDS.PT_JOB_ID,
	            PT_CLASSIDS.PT_COMMUNITY_ID,
	            PT_CLASSIDS.PT_PAGE_ID,
	            PT_CLASSIDS.PT_SUBPORTAL_ID
		    };
	
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create() 
    {
        return new SnapshotADConstraintsView();
    }

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
    public String GetName() 
    {
        return STR_MVC_CLASS_NAME;
    }

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
     */
    public HTMLElement Display() 
    {
 		HTMLElementCollection result = new HTMLElementCollection();

        /* common html elements */
        HTMLTable mainTable;
        HTMLTableRow mainRow;
        HTMLTableCell mainCell;
        HTMLInput mainInput;
        HTMLSpan mySpan;

		try
		{
		    /* view header */
	 		result.AddInnerHTMLElement(super.GetHeaderView(
	 		       m_asOwner.GetString(3003, ResourceConstants.PORTALADMINMSGS)));
	        
	        /* outermost table */
	        mainTable = new HTMLTable();
			result.AddInnerHTMLElement(mainTable);
			mainTable.SetWidth("100%");
			mainTable.SetBorder("0");
			mainTable.SetCellPadding("15");
			mainTable.SetCellSpacing("0");

			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
	        /* inner table */
	        mainTable = new HTMLTable();
			mainCell.AddInnerHTMLElement(mainTable);
			mainTable.SetWidth("100%");
			mainTable.SetBorder("0");
			mainTable.SetCellPadding("2");
			mainTable.SetCellSpacing("0");
			

			/* 3 cell row: section title, All types checkbox + title + spacer */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			/* section title */
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetWidth("150");
			
			mySpan = new HTMLSpan();
			mainCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(3004, ResourceConstants.PORTALADMINMSGS));
			
			/* All types checkbox */
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetColSpan("2");
			
			mainInput= new HTMLInput(
			        HTMLInputTypes.CHECKBOX_TYPE, 
			        HTMLINPUT_ADTYPE_PREFIX+ALLCLASSIDS, 
			        m_asOwner.GetString(3005, ResourceConstants.PORTALADMINMSGS));
			mainCell.AddInnerHTMLElement(mainInput);
			mainInput.AddInnerHTMLString(m_asOwner.GetString(3005, ResourceConstants.PORTALADMINMSGS));
			mainInput.SetChecked( ((ISavedSearchModelRO)m_model).IsClassIDChecked(ALLCLASSIDS) );
			mainInput.SetValue(ALLCLASSIDS);
			mainInput.SetOnClick(JAVASCRIPT_ALLCHECKED + "(1, this); return true;");
			mainInput.SetID(ALLCLASSIDS);
			
			/* for each type of admin object display a checkbox and a title, 2 per row */
			for (int i=0; i<ADMIN_TYPES.length; i++)
			{
			    if (i%2==0)
			    {
					/* 3 cell rows: section title spacer, 2 x (checkbox + checkbox title) */
					mainRow = new HTMLTableRow();
					mainTable.AddInnerHTMLElement(mainRow);
					mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
					mainCell = new HTMLTableCell(); /* spacer */
					mainRow.AddInnerHTMLElement(mainCell);
					mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			    }
			    
				/* checkbox #1 cell */
				mainCell = new HTMLTableCell();
				mainRow.AddInnerHTMLElement(mainCell);
				mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				mainCell.SetNoWrap(true);
				
				mainInput= new HTMLInput(
				        HTMLInputTypes.CHECKBOX_TYPE, 
				        HTMLINPUT_ADTYPE_PREFIX, 
				        SearchResultModel.getDisplayableNameForType(m_asOwner,ADMIN_TYPES[i]));
				mainCell.AddInnerHTMLElement(mainInput);
				mainInput.AddInnerHTMLString(SearchResultModel.getDisplayableNameForType(m_asOwner,ADMIN_TYPES[i]));
				mainInput.SetChecked( ((ISavedSearchModelRO)m_model).IsClassIDChecked(XPConvert.ToString(ADMIN_TYPES[i])) );
				mainInput.SetValue(XPConvert.ToString(ADMIN_TYPES[i]));
				mainInput.SetOnClick(JAVASCRIPT_ALLCHECKED + "(0, this);return true;");
				mainInput.SetID("c"+i);
			}
			
			
	        /* folder list section */
			AddEmptyRowToTable(mainTable, "20");

			/* row+cell+table to hold folder list html */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetColSpan("3");

			mainTable = new HTMLTable();
			mainCell.AddInnerHTMLElement(mainTable);
			mainTable.SetWidth("100%");
			mainTable.SetBorder("0");
			mainTable.SetCellPadding("0");
			mainTable.SetCellSpacing("0");
			mainTable.SetStyleClass(PTStyleClass.CUSTOMAPP_BORDER);
			
			/* subtitle row */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.AddInnerHTMLElement(super.GetHeaderView(
			        m_asOwner.GetString(3006, ResourceConstants.PORTALADMINMSGS)));

			/* list row */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			SavSrchMainDP myMainDP = (SavSrchMainDP) m_asOwner.GetPage(SavSrchMainDP.STR_MVC_CLASS_NAME);
			myMainDP.DisplayFolderList(mainCell,PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
		}
		catch (Exception e)
		{
			log.Error(e, "SnapshotADConstraintsView::Display. " + 
			        m_asOwner.GetString(3007, ResourceConstants.PORTALADMINMSGS) + ": " +
				e.getMessage());
			
			throw new XPException(m_asOwner.GetString(3007, ResourceConstants.PORTALADMINMSGS), e);
		}

		return result;
	}
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
    public HTMLScript DisplayJavascript() 
    {
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        XPStringBuilder sb;
		
		// JavaScript to update repository selections
		sb = new XPStringBuilder(300);
		sb.Append("\nvar globalcheckcount = -1;\n");
		sb.Append("\nvar globaltotalcount = "+XPConvert.ToString(ADMIN_TYPES.length)+";\n");
		
		sb.Append("\nfunction " + JAVASCRIPT_ALLCHECKED + "(toggle, item)\n");
		sb.Append("{\n");
		sb.Append("	var allchk = document.getElementById('" + ALLCLASSIDS + "');\n");
		sb.Append("\n");
		sb.Append("	if (-1 == globalcheckcount)	// first time, initialize\n");
		sb.Append("	{\n");
		sb.Append("		globalcheckcount++; // bring it to zero\n");
		sb.Append("		for(i = 0; i < globaltotalcount; i++)\n");
		sb.Append("		{\n");
		sb.Append("			if(document.getElementById('c' + i).checked)\n");
		sb.Append("				globalcheckcount++;\n");
		sb.Append("		}\n");
		sb.Append("	}\n");
		sb.Append("\n");
		sb.Append("	if (0 == toggle)\n");
		sb.Append("	{\n");
		sb.Append("	    if(item.checked)\n");
		sb.Append("		    globalcheckcount++;\n");
		sb.Append("		else\n");
		sb.Append("		    globalcheckcount--;\n");
		sb.Append("	}\n");
		sb.Append("	else if (1 == toggle)\n");
		sb.Append("	{\n");
		sb.Append("		for(i = 0; i < globaltotalcount; i++)\n");
		sb.Append("			document.getElementById('c' + i).checked = item.checked;\n");
		sb.Append("  \n if(item.checked)\n");
		sb.Append("		    globalcheckcount = globaltotalcount;\n");
		sb.Append("		else\n");
		sb.Append("		    globalcheckcount = 0;\n");
		sb.Append("	}\n");
		sb.Append("		allchk.checked = (globalcheckcount>=globaltotalcount);\n");
		sb.Append("}\n");
		myScript.AddInnerHTMLString(sb.ToString());

//		sb = new XPStringBuilder(100);
//		// JavaScript to check all the rows
//		sb.Append("function "+ JAVASCRIPT_CHECKALL + "()\n");
//		sb.Append("{ \n");
//		sb.Append("  var frm = document." + AFormDP.HTMLFORM_NAME +
//			"; \n");
//		sb.Append("  var len = frm.elements.length; \n");
//		sb.Append("  var nValue = frm." +
//				HTMLCHECKBOX_CHECKALL + ".checked; \n");
//		sb.Append("  var i = 0; \n");
//		sb.Append("  \n");
//		sb.Append("  for(i=0 ; i<len ; i++) \n");
//		sb.Append("  { \n");
//		sb.Append("    if (frm.elements[i].name == '" + HTMLCHECKBOX_WEBLINK + "') \n");
//		sb.Append("    { \n");
//		sb.Append("       frm.elements[i].checked = nValue;\n");
//		sb.Append("    } \n");
//		sb.Append("  } \n");
//		sb.Append("}\n");

		return myScript;
    }
}