package com.plumtree.portalpages.admin.editors.savedsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author joseq
 *
 * This class displays the html/javascript for the query range settings of snapshot queries.
 * The query range is the board query settings of which repositories to search.
 */
public class SnapshotQueryRangeView extends EditorView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
			"com.plumtree.portalpages.admin.editors.savedsearch.SnapshotQueryRangeView");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SnapshotQryRange";

	/** html KD checkbox */
	public static final String HTMLINPUT_KD_CB	= "in_cb_KnowledgeDirCB";
	
	/** html administration checkbox */
	public static final String HTMLINPUT_ADMIN_CB	= "in_cb_AdminDirCB";

	/** html collab checkbox */
	public static final String HTMLINPUT_COLLAB_CB	= "in_cb_CollabSvrCB";

	/** html Content checkbox */
	public static final String HTMLINPUT_CONTENT_CB	= "in_cb_ContentSvrCB";

	/** html Content checkbox */
	public static final String HTMLINPUT_ALL_FOLDERS	= "in_cb_All_Folders";

	/** html Content checkbox */
	public static final String HTMLINPUT_ALL_DOCUMENTS	= "in_cb_All_Documents";

	/** html Content checkbox */
	public static final String HTMLINPUT_SUBFOLDERS		= "in_cb_Sub_Folders";

	/** javascript update repository selection */
	public static final String JAVASCRIPT_UPDATE_REPO = "UpdateRepo";

	/** javascript check repository selection */
	public static final String JAVASCRIPT_CHECK_REPO = "CheckRepositories";
	
	
	/* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create() 
    {
        return new SnapshotQueryRangeView();
    }

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
    public String GetName() 
    {
        return STR_MVC_CLASS_NAME;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
    public HTMLScript DisplayJavascript() 
    {
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
        XPStringBuilder sb;
		
		// JavaScript to check repository selections
		sb = new XPStringBuilder(300);
		sb.Append("function " + JAVASCRIPT_CHECK_REPO +"(elem)\n");
		sb.Append("{\n");
		sb.Append("	 var nRepoMask = 0;\n");
		sb.Append("	 if (document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_KD_CB+".checked)\n");
		sb.Append("		nRepoMask |= 1;\n");
		sb.Append("	 if (document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_ADMIN_CB+".checked)\n");
		sb.Append("		nRepoMask |= 2;\n");
		sb.Append("	 if (undefined!=document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_COLLAB_CB+" && document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_COLLAB_CB+".checked)\n");
		sb.Append("		nRepoMask |= 4;\n");
		sb.Append("	 if (undefined!=document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_CONTENT_CB+" && document."+AFormDP.HTMLFORM_NAME+"."+HTMLINPUT_CONTENT_CB+".checked)\n");
		sb.Append("		nRepoMask |= 8;\n");
		sb.Append("		\n");
		sb.Append("	 if (0 == (nRepoMask&15))\n");
		sb.Append("	 {\n");
		sb.Append("		alert(\""+m_asOwner.GetString(3137, ResourceConstants.PORTALADMINMSGS)+"\");\n");
		sb.Append("		elem.checked = !elem.checked;\n");
		sb.Append("		return false;\n");
		sb.Append("	 }\n");
		sb.Append("	 \n");
		sb.Append("  	return true;\n");
		sb.Append("}\n");
		myScript.AddInnerHTMLString(sb.ToString());
		
		// JavaScript to update repository selections
		sb = new XPStringBuilder(300);
		sb.Append("function " + JAVASCRIPT_UPDATE_REPO + "(elem)\n");
		sb.Append("{\n");
		sb.Append("  if (CheckRepositories(elem))\n");
		sb.Append("  {\n");
		sb.Append("     postToSelf('" + SavedSearchRepostControl.POSTTOSELF_ACTION_SIMPLEREPOST+ "');\n");
		sb.Append("  }\n");
		sb.Append("}\n");
		myScript.AddInnerHTMLString(sb.ToString());

		return myScript;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
     */
    public HTMLElement Display() 
    {
 		HTMLElementCollection result = new HTMLElementCollection();

        /* common html elements */
        HTMLTable mainTable;
        HTMLTableRow mainRow;
        HTMLTableCell mainCell;
        HTMLInput mainInput;
        HTMLSpan mySpan;

		try
		{
		    /* bit mask of selected repositories */
		    int nRepositories = ((ISavedSearchModelRO)m_model).GetRepositories();
		    
		    /* view header */
	 		result.AddInnerHTMLElement(super.GetHeaderView(
	 		       m_asOwner.GetString(2996, ResourceConstants.PORTALADMINMSGS)));
	        
	        /* outermost table */
	        mainTable = new HTMLTable();
			result.AddInnerHTMLElement(mainTable);
			mainTable.SetWidth("100%");
			mainTable.SetBorder("0");
			mainTable.SetCellPadding("15");
			mainTable.SetCellSpacing("0");

			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
	        /* inner table */
	        mainTable = new HTMLTable();
			mainCell.AddInnerHTMLElement(mainTable);
			mainTable.SetWidth("100%");
			mainTable.SetBorder("0");
			mainTable.SetCellPadding("2");
			mainTable.SetCellSpacing("0");
			

			/* repository types */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			/* section title */
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetNoWrap(true);
			
			mySpan = new HTMLSpan();
			mainCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(2997, ResourceConstants.PORTALADMINMSGS));
			
			/* KD checkbox */
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
			mainInput= new HTMLInput(
			        HTMLInputTypes.CHECKBOX_TYPE, 
			        HTMLINPUT_KD_CB, 
			        m_asOwner.GetString(2998, ResourceConstants.PORTALADMINMSGS));
			mainCell.AddInnerHTMLElement(mainInput);
			mainInput.AddInnerHTMLString(m_asOwner.GetString(2998, ResourceConstants.PORTALADMINMSGS));
			mainInput.SetChecked((0!=(nRepositories & SavedSearchModel.REPOSITORY_TYPES_KD)));
			mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_TYPES_KD));
			mainInput.SetOnClick(JAVASCRIPT_UPDATE_REPO+"(this)");
			
			/* Admin Dir checkbox */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
			mainInput= new HTMLInput(
			        HTMLInputTypes.CHECKBOX_TYPE, 
			        HTMLINPUT_ADMIN_CB, 
			        m_asOwner.GetString(2999, ResourceConstants.PORTALADMINMSGS));
			mainCell.AddInnerHTMLElement(mainInput);
			mainInput.AddInnerHTMLString(m_asOwner.GetString(2999, ResourceConstants.PORTALADMINMSGS));
			mainInput.SetChecked(0!=(nRepositories & SavedSearchModel.REPOSITORY_TYPES_ADMIN));
			mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_TYPES_ADMIN));
			mainInput.SetOnClick(JAVASCRIPT_UPDATE_REPO+"(this)");
			
			/* Collab checkbox */
			if (((ISavedSearchModelRO)m_model).IsCollabInstalled())
			{
				mainRow = new HTMLTableRow();
				mainTable.AddInnerHTMLElement(mainRow);
				mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				mainCell = new HTMLTableCell();
				mainRow.AddInnerHTMLElement(mainCell);
				mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
	
				mainCell = new HTMLTableCell();
				mainRow.AddInnerHTMLElement(mainCell);
				mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				
				mainInput= new HTMLInput(
				        HTMLInputTypes.CHECKBOX_TYPE, 
				        HTMLINPUT_COLLAB_CB, 
				        m_asOwner.GetString(2992, ResourceConstants.PORTALADMINMSGS));
				mainCell.AddInnerHTMLElement(mainInput);
				mainInput.AddInnerHTMLString(m_asOwner.GetString(2992, ResourceConstants.PORTALADMINMSGS));
				mainInput.SetChecked(0!=(nRepositories & SavedSearchModel.REPOSITORY_TYPES_COLLAB));
				mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_TYPES_COLLAB));
				mainInput.SetOnClick(JAVASCRIPT_UPDATE_REPO+"(this)");
			}
			
			/* Content checkbox */
			if (((ISavedSearchModelRO)m_model).IsContentInstalled())
			{
				mainRow = new HTMLTableRow();
				mainTable.AddInnerHTMLElement(mainRow);
				mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				mainCell = new HTMLTableCell();
				mainRow.AddInnerHTMLElement(mainCell);
				mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
	
				mainCell = new HTMLTableCell();
				mainRow.AddInnerHTMLElement(mainCell);
				mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
				mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				
				mainInput= new HTMLInput(
				        HTMLInputTypes.CHECKBOX_TYPE, 
				        HTMLINPUT_CONTENT_CB, 
				        m_asOwner.GetString(2993, ResourceConstants.PORTALADMINMSGS));
				mainCell.AddInnerHTMLElement(mainInput);
				mainInput.AddInnerHTMLString(m_asOwner.GetString(2993, ResourceConstants.PORTALADMINMSGS));
				mainInput.SetChecked(0!=(nRepositories & SavedSearchModel.REPOSITORY_TYPES_CONTENT));
				mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_TYPES_CONTENT));
				mainInput.SetOnClick(JAVASCRIPT_UPDATE_REPO+"(this)");
			}
			
			AddEmptyRowToTable(mainTable,"15");
			
			/* repository settings */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			/* section title */
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetNoWrap(true);
			
			mySpan = new HTMLSpan();
			mainCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(2994, ResourceConstants.PORTALADMINMSGS));
			
			/* folders from any source checkbox */
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
			mainInput= new HTMLInput(
			        HTMLInputTypes.CHECKBOX_TYPE, 
			        HTMLINPUT_ALL_FOLDERS, 
			        m_asOwner.GetString(2995, ResourceConstants.PORTALADMINMSGS));
			mainCell.AddInnerHTMLElement(mainInput);
			mainInput.AddInnerHTMLString(m_asOwner.GetString(2995, ResourceConstants.PORTALADMINMSGS));
			mainInput.SetChecked((0!=(nRepositories & SavedSearchModel.REPOSITORY_SETTINGS_ALLFOLDERS)));
			mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_SETTINGS_ALLFOLDERS));
			
			/* documents from any source checkbox */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
			mainInput= new HTMLInput(
			        HTMLInputTypes.CHECKBOX_TYPE, 
			        HTMLINPUT_ALL_DOCUMENTS, 
			        m_asOwner.GetString(3000, ResourceConstants.PORTALADMINMSGS));
			mainCell.AddInnerHTMLElement(mainInput);
			mainInput.AddInnerHTMLString(m_asOwner.GetString(3000, ResourceConstants.PORTALADMINMSGS));
			mainInput.SetChecked(0!=(nRepositories & SavedSearchModel.REPOSITORY_SETTINGS_ALLDOCUMENTS));
			mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_SETTINGS_ALLDOCUMENTS));

			/* include sub folders checkbox */
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			mainRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			mainCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
			mainInput= new HTMLInput(
			        HTMLInputTypes.CHECKBOX_TYPE, 
			        HTMLINPUT_SUBFOLDERS, 
			        m_asOwner.GetString(3001, ResourceConstants.PORTALADMINMSGS));
			mainCell.AddInnerHTMLElement(mainInput);
			mainInput.AddInnerHTMLString(m_asOwner.GetString(3001, ResourceConstants.PORTALADMINMSGS));
			mainInput.SetChecked(0!=(nRepositories & SavedSearchModel.REPOSITORY_SETTINGS_SUBFOLDERS));
			mainInput.SetValue(XPConvert.ToString(SavedSearchModel.REPOSITORY_SETTINGS_SUBFOLDERS));
		}
		catch (Exception e)
		{
			log.Error(e, "SnapshotQueryRange::Display. " + 
			        m_asOwner.GetString(3001, ResourceConstants.PORTALADMINMSGS) + ": " +
				e.getMessage());
			
			throw new XPException(m_asOwner.GetString(3001, ResourceConstants.PORTALADMINMSGS), e);
		}

		return result;
    }
}