package com.plumtree.portalpages.admin.editors.subportal;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section represents a section of the Edit Subportal Features page
 * of the SubPortal Editor.
 * This Section is printed out by SubPortalFeaturesDP.
 *
 * @author JohnH
 */
public class FeaturesView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.subportal.FeaturesView");

	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalFeatures";
	

	// Strings to localize.

	/** Javascript function name - openServerCommunityTree **/
	private static final String JAVASCRIPT_SERVER_COMMTREE     = "openServerCommunityTree";
	/** Javascript function name - submitCommunity **/
	private static final String JAVASCRIPT_SERVER_COMMSUBMIT   = "submitCommunity";
	/** Javascript function name - openServerFolderTree **/
	private static final String JAVASCRIPT_SERVER_FOLDERTREE   = "openServerFolderTree";
	/** Javascript function name - submitFolder **/
	private static final String JAVASCRIPT_SERVER_FOLDERSUBMIT = "submitFolder";
	/** Javascript function name - chooseFolderParent **/
	private static final String JAVASCRIPT_SERVER_CHOOSEPARENT = "chooseFolderParent";
	

	// HTML Object names.
	//       <select> starts with in_se
	//       <input button> starts with in_bu
	//       <input text> starts with in_tx
	//       <input checkbox> starts with in_cb
	//       <input radio> starts with in_ra
	//       <textarea> starts with in_ta

	/** MyPages checkbox */
	public static final String HTMLCHECKBOX_MYPAGES			   = "in_cb_MyPages";

	/** Communities checkbox */
	public static final String HTMLCHECKBOX_COMMUNITIES		   = "in_cb_Communities";

	/** Directory checkbox */
	public static final String HTMLCHECKBOX_DIRECTORY		   = "in_cb_Directory";

	/** First page type radio button */
	public static final String HTMLRADIO_FIRSTPAGETYPE		   = "in_ra_FirstPageType";

	/** Choose home community button */
	public static final String HTMLBUTTON_CHOOSECOMM		   = "in_bu_ChooseHomeCommunity";

	/** Hidden element for community space id */
	public static final String HTMLHIDDEN_HOME_COMMUNITY_SPACE = "in_hi_HiddenHomeCommunitySpace";

	/** Hidden element for community id */
	public static final String HTMLHIDDEN_COMMUNITYID	    = "in_hi_CommunityID";

	/** Hidden element for community name */
	public static final String HTMLHIDDEN_COMMUNITYNAME     = "in_hi_CommunityName";

	/** Create community button */
	public static final String HTMLBUTTON_CREATECOMM	    = "in_bu_CreateHomeCommunity";

	/** Choose home folder button  */
	public static final String HTMLBUTTON_CHOOSEFOLDER	    = "in_bu_ChooseHomeFolder";

	/** Hidden element for folder activity space */
	public static final String HTMLHIDDEN_HOME_FOLDER_SPACE = "in_hi_HiddenHomeFolderSpace";

	/** Create folder button */
	public static final String HTMLBUTTON_CREATEFOLDER     = "in_bu_CreateHomeFolder";

	/** Hidden element for folder id */
	public static final String HTMLHIDDEN_FOLDERID		   = "in_hi_FolderID";

	/** Hidden element for folder name */
	public static final String HTMLHIDDEN_FOLDERNAME	   = "in_hi_FolderName";

	/** Related communities checkbox */
	public static final String HTMLCHECKBOX_RELCOMM		   = "in_cb_RelComm";

	/** Related folders checkbox */
	public static final String HTMLCHECKBOX_RELFOLDERS     = "in_cb_RelFolders";

	/** Related portlets checkbox */
	public static final String HTMLCHECKBOX_RELPORTLETS    = "in_cb_RelPortlets";

	/** Related experts checkbox */
	public static final String HTMLCHECKBOX_RELEXPERTS     = "in_cb_RelExperts";

	/** Related content managers checkbox */
	public static final String HTMLCHECKBOX_RELCONTENTMGRS = "in_cb_RelContentMgrs";

	/** Hidden community editor key */
	public static final String HTMLHIDDEN_COMMEDITORKEY   = "in_hi_CommEditorKey";

	/** Hidden folder editor key */
	public static final String HTMLHIDDEN_FOLDEREDITORKEY = "in_hi_FolderEditorKey";

	/** internal data **/
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FeaturesView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;
		HTMLImg myImage;

		try
		{
			result.AddInnerHTMLElement(new HTMLComment("Begin: Display FeaturesView"));

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						860, "ptmsgs_portaladminmsgs")));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("1");

			// 1st Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(862,
					"ptmsgs_portaladminmsgs"));

			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(863,
					"ptmsgs_portaladminmsgs"));

			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			myCell.SetColSpan("2");
			mySpan.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(864,
					"ptmsgs_portaladminmsgs"));

			//1st Row end
			//2nd Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell.SetAlign(CommonHTMLStrings.CENTER);

			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_MYPAGES,
					m_asOwner.GetString(865, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick("DisallowUncheck('" + HTMLCHECKBOX_MYPAGES +
				"','0');");
			myInput.SetValue(XPConvert.ToString(
					PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS));
			myCell.AddInnerHTMLElement(myInput);

			int intAccessType = ((ISubPortalModelRO) m_model).GetAccessType();

			if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS &
					intAccessType) != 0)
			{
				myInput.SetChecked(true);
			}

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.FORM_RADIO);
			myCell.SetAlign(CommonHTMLStrings.CENTER);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_FIRSTPAGETYPE,
					m_asOwner.GetString(865, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick("CheckEnabled('" + HTMLCHECKBOX_MYPAGES + "');");
			myCell.AddInnerHTMLElement(myInput);

			int intDefaultFirstPageType = ((ISubPortalModelRO) m_model).GetDefaultFirstPageType();

			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS == intDefaultFirstPageType)
			{
				myInput.SetChecked(true);
			}

			myInput.SetValue(XPConvert.ToString(PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_MYPAGE,
					true, this.m_asasParent).GetHTMLElement();

			myImage.SetAlt(m_asOwner.GetString(865, "ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(myImage);

			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(865,
					"ptmsgs_portaladminmsgs"));
			mySpan.AddInnerHTMLElement(new HTMLBr());

			myCell.AddInnerHTMLString(m_asOwner.GetString(866,
					"ptmsgs_portaladminmsgs"));

			//2nd Row end
			//3rd Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell.SetAlign(CommonHTMLStrings.CENTER);

			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_COMMUNITIES,
					m_asOwner.GetString(867, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick("DisallowUncheck('" + HTMLCHECKBOX_COMMUNITIES +
				"','1');");
			myInput.SetValue(XPConvert.ToString(
					PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS));
			myCell.AddInnerHTMLElement(myInput);
			intAccessType = ((ISubPortalModelRO) m_model).GetAccessType();

			if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS &
					intAccessType) != 0)
			{
				myInput.SetChecked(true);
			}

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.FORM_RADIO);
			myCell.SetAlign(CommonHTMLStrings.CENTER);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_FIRSTPAGETYPE,
					m_asOwner.GetString(867, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick("CheckEnabled('" + HTMLCHECKBOX_COMMUNITIES +
				"');");
			myCell.AddInnerHTMLElement(myInput);
			intDefaultFirstPageType = ((ISubPortalModelRO) m_model).GetDefaultFirstPageType();

			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS == intDefaultFirstPageType)
			{
				myInput.SetChecked(true);
			}

			myInput.SetValue(XPConvert.ToString(
					PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
					true, this.m_asasParent).GetHTMLElement();

			myImage.SetAlt(m_asOwner.GetString(867, "ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(myImage);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(867,
					"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());

			myCell.AddInnerHTMLString(m_asOwner.GetString(868,
					"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());
			myCell.AddInnerHTMLElement(new HTMLBr());
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_BOLD_ITALIC_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(869,
					"ptmsgs_portaladminmsgs"));
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_ITALIC_TEXT);

			String strHomeCommunity;

			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS != intDefaultFirstPageType)
			{
				strHomeCommunity = m_asOwner.GetString(870,
						"ptmsgs_portaladminmsgs");
			}
			else
			{
				strHomeCommunity = ((ISubPortalModelRO) m_model).GetHomeCommunityName();
			}

			mySpan.AddInnerHTMLEncodedString(strHomeCommunity);
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_COMMUNITYID, "");
			myInput.SetValue(XPConvert.ToString(
					((ISubPortalModelRO) m_model).GetHomeCommunityID()));
			myCell.AddInnerHTMLElement(myInput);
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_COMMUNITYNAME, "");
			myInput.SetValue(strHomeCommunity);
			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLElement(new HTMLBr());

			////// Community Tree Control
			// Hidden input for the Space ID for the tree.  That way if you hit the folder
			// tree link twice, it will open the same tree both times.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_HOME_COMMUNITY_SPACE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(((ISubPortalModelRO) m_model).GetCommSubSpaceID());
			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLBUTTON_CHOOSECOMM,
					m_asOwner.GetString(871, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetStyle("width: 210");
			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS != intDefaultFirstPageType)
			{
				myInput.SetDisabled(true);
			}
				

			myInput.SetValue(m_asOwner.GetString(871, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick(JAVASCRIPT_SERVER_COMMTREE +
				"(document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_HOME_COMMUNITY_SPACE + ");");

			myCell.AddInnerHTMLElement(myInput);

			//Add a hidden field for the sub-editor ID
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_COMMEDITORKEY, "");
			myCell.AddInnerHTMLElement(myInput);

			//Now add the create button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLBUTTON_CREATECOMM,
					m_asOwner.GetString(873, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetStyle("width: 210");
			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS != intDefaultFirstPageType)
			{
				myInput.SetDisabled(true);
			}

			myInput.SetValue(m_asOwner.GetString(873, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick("ChooseCommParentFolder();");

			myCell.AddInnerHTMLElement(myInput);

			//3rd Row end
			//4th Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell.SetAlign(CommonHTMLStrings.CENTER);

			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_DIRECTORY,
					m_asOwner.GetString(879, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick("DisallowUncheck('" + HTMLCHECKBOX_DIRECTORY +
				"','2'); UncheckFeatures();");
			myInput.SetValue(XPConvert.ToString(
					PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS));
			myCell.AddInnerHTMLElement(myInput);
			intAccessType = ((ISubPortalModelRO) m_model).GetAccessType();

			if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					intAccessType) != 0)
			{
				myInput.SetChecked(true);
			}

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.FORM_RADIO);
			myCell.SetAlign(CommonHTMLStrings.CENTER);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_FIRSTPAGETYPE,
					m_asOwner.GetString(879, "ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetOnClick("CheckEnabled('" + HTMLCHECKBOX_DIRECTORY +
				"');");
			intDefaultFirstPageType = ((ISubPortalModelRO) m_model).GetDefaultFirstPageType();

			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS == intDefaultFirstPageType)
			{
				myInput.SetChecked(true);
			}

			myInput.SetValue(XPConvert.ToString(
					PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_KNOWLEDGE_DIRECTORY,
					true, this.m_asasParent).GetHTMLElement();

			myImage.SetAlt(m_asOwner.GetString(875, "ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(myImage);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(879,
					"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());

			myCell.AddInnerHTMLString(m_asOwner.GetString(880,
					"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());
			myCell.AddInnerHTMLElement(new HTMLBr());
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_BOLD_ITALIC_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(875,
					"ptmsgs_portaladminmsgs"));
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_ITALIC_TEXT);

			String strHomeFolder;

			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS != intDefaultFirstPageType)
			{
				strHomeFolder = m_asOwner.GetString(876,
						"ptmsgs_portaladminmsgs");
			}
			else
			{
				strHomeFolder = ((ISubPortalModelRO) m_model).GetHomeFolderName();
			}

			mySpan.AddInnerHTMLEncodedString(strHomeFolder);
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_FOLDERID,
					"");
			myInput.SetValue(XPConvert.ToString(
					((ISubPortalModelRO) m_model).GetHomeFolderID()));
			myCell.AddInnerHTMLElement(myInput);
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_FOLDERNAME, "");
			myInput.SetValue(strHomeFolder);
			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLElement(new HTMLBr());

			////// Folder Tree Control
			// Hidden input for the Space ID for the tree.  That way if you hit the folder
			// tree link twice, it will open the same tree both times.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_HOME_FOLDER_SPACE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(((ISubPortalModelRO) m_model).GetFolderSubSpaceID());

			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLBUTTON_CHOOSEFOLDER,
					m_asOwner.GetString(877, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetStyle("width: 180");
			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS != intDefaultFirstPageType)
			{
				myInput.SetDisabled(true);
			}

			myInput.SetValue(m_asOwner.GetString(877, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick(JAVASCRIPT_SERVER_FOLDERTREE +
				"(document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_HOME_FOLDER_SPACE + ");");

			myCell.AddInnerHTMLElement(myInput);

			//Add a hidden field for the sub-editor ID
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_FOLDEREDITORKEY, "");
			myCell.AddInnerHTMLElement(myInput);

			//Now add the create button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLBUTTON_CREATEFOLDER,
					m_asOwner.GetString(878, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetStyle("width: 180");
			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS != intDefaultFirstPageType)
			{
				myInput.SetDisabled(true);
			}

			myInput.SetValue(m_asOwner.GetString(878, "ptmsgs_portaladminmsgs"));
			myInput.SetOnClick(JAVASCRIPT_SERVER_CHOOSEPARENT + "();");

			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLElement(new HTMLBr());
			myCell.AddInnerHTMLElement(new HTMLBr());

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.LIST_BOLD_ITALIC_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(881,
					"ptmsgs_portaladminmsgs"));

			myTable = new HTMLTable();
			myCell.AddInnerHTMLElement(myTable);

			//1st row of inner table
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			int intRelRes = ((ISubPortalModelRO) m_model).GetRelatedResourcesAccessTypes();
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_RELCOMM, "");
			myInput.SetValue(XPConvert.ToString(
					PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_COMMUNITIES_ACCESS));

			if ((PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_COMMUNITIES_ACCESS &
					intRelRes) != 0)
			{
				myInput.SetChecked(true);
			} else if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					intAccessType) == 0) 
			{
				myInput.SetDisabled(true);		
			}

			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLString(m_asOwner.GetString(882,
					"ptmsgs_portaladminmsgs"));

			//2nd row of inner table
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_RELFOLDERS, "");
			myInput.SetValue(XPConvert.ToString(
					PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_FOLDERS_ACCESS));

			if ((PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_FOLDERS_ACCESS &
					intRelRes) != 0)
			{
				myInput.SetChecked(true);
			} else if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					intAccessType) == 0) 
			{
				myInput.SetDisabled(true);		
			}


			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLString(m_asOwner.GetString(883,
					"ptmsgs_portaladminmsgs"));

			//3rd row of inner table
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_RELPORTLETS, "");
			myInput.SetValue(XPConvert.ToString(
					PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_PORTLETS_ACCESS));

			if ((PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_PORTLETS_ACCESS &
					intRelRes) != 0)
			{
				myInput.SetChecked(true);
			} else if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					intAccessType) == 0) 
			{
				myInput.SetDisabled(true);		
			}


			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLString(m_asOwner.GetString(884,
					"ptmsgs_portaladminmsgs"));

			//4th row of inner table
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_RELEXPERTS, "");
			myInput.SetValue(XPConvert.ToString(
					PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_EXPERTS_ACCESS));

			if ((PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_EXPERTS_ACCESS &
					intRelRes) != 0)
			{
				myInput.SetChecked(true);
			} else if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					intAccessType) == 0) 
			{
				myInput.SetDisabled(true);		
			}


			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLString(m_asOwner.GetString(885,
					"ptmsgs_portaladminmsgs"));

			//5th row of inner table
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_RELCONTENTMGRS, "");
			myInput.SetValue(XPConvert.ToString(
					PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_CONTENTMANAGERS_ACCESS));

			if ((PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_CONTENTMANAGERS_ACCESS &
					intRelRes) != 0)
			{
				myInput.SetChecked(true);
			} else if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					intAccessType) == 0) 
			{
				myInput.SetDisabled(true);		
			}


			myCell.AddInnerHTMLElement(myInput);

			myCell.AddInnerHTMLString(m_asOwner.GetString(886,
					"ptmsgs_portaladminmsgs"));

			result.AddInnerHTMLElement(new HTMLComment("End: Display FeaturesView"));
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::Display", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(887,"ptmsgs_portaladminmsgs"));
		}

		return result;
	}

	/**
	 * Returns Java Script for that Section.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");
		String strFormName  = AFormDP.HTMLFORM_NAME;

		//Disable the appropriate buttons depending on home page type
		try
		{
			XPStringBuilder sb = new XPStringBuilder(100);
			sb.Append("function DisableButton(bEnable, strButtonName)\n");
			sb.Append("{\n");
			sb.Append("		document." + EditorDP.HTMLFORM_NAME +
				".elements[strButtonName].disabled = bEnable;\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}
		
		//Uncheck knowledge directory features when knowledge directory is disabled
		try
		{
			XPStringBuilder sb = new XPStringBuilder(200);
			sb.Append("function UncheckFeatures()\n");
			sb.Append("{\n");
			sb.Append("		if (!document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_DIRECTORY + ".checked) \n");
			sb.Append("		{\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELCOMM + ".checked = false;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELCONTENTMGRS + ".checked = false;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELEXPERTS + ".checked = false;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELFOLDERS + ".checked = false;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELPORTLETS + ".checked = false;\n");
			sb.Append("			DisableFeatures(true);\n");
			sb.Append("		} else { \n");
			sb.Append("			DisableFeatures(false);\n");
			sb.Append("		}\n");
			sb.Append("}\n");
			
			//Diable or Enable knowledge directory features checkboxes
			sb.Append("function DisableFeatures(bDisable)\n");
			sb.Append("{\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELCOMM + ".disabled = bDisable;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELCONTENTMGRS + ".disabled = bDisable;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELEXPERTS + ".disabled = bDisable;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELFOLDERS + ".disabled = bDisable;\n");
			sb.Append("			document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLCHECKBOX_RELPORTLETS + ".disabled = bDisable;\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}


		//Validation to make sure the corresponding checkbox is clicked when
		//a home element radio button is clicked
		try
		{
			XPStringBuilder sb = new XPStringBuilder(400);

			sb.Append("function CheckEnabled(strCheckbox)\n");
			sb.Append("{\n");
			sb.Append("    document." + EditorDP.HTMLFORM_NAME +
				".elements[strCheckbox].checked = true;\n");
			sb.Append("    if (strCheckbox == '" + HTMLCHECKBOX_MYPAGES +
				"')\n");
			sb.Append("    {\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CHOOSECOMM +
				"');\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CREATECOMM +
				"');\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CHOOSEFOLDER +
				"');\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CREATEFOLDER +
				"');\n");
			sb.Append("    }\n");
			sb.Append("    if (strCheckbox == '" + HTMLCHECKBOX_COMMUNITIES +
				"')\n");
			sb.Append("    {\n");
			sb.Append("        DisableButton(false,'" + HTMLBUTTON_CHOOSECOMM +
				"');\n");
			sb.Append("        DisableButton(false,'" + HTMLBUTTON_CREATECOMM +
				"');\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CHOOSEFOLDER +
				"');\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CREATEFOLDER +
				"');\n");
			sb.Append("    }\n");
			sb.Append("    if (strCheckbox == '" + HTMLCHECKBOX_DIRECTORY +
				"')\n");
			sb.Append("    {\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CHOOSECOMM +
				"');\n");
			sb.Append("        DisableButton(true,'" + HTMLBUTTON_CREATECOMM +
				"');\n");
			sb.Append("        DisableButton(false,'" +
				HTMLBUTTON_CHOOSEFOLDER + "');\n");
			sb.Append("        DisableButton(false,'" +
				HTMLBUTTON_CREATEFOLDER + "');\n");
			sb.Append("		   DisableFeatures(false);\n");
			sb.Append("    }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		//Javascript to disallow removing a check from the default (Home) element
		try
		{
			XPStringBuilder sb = new XPStringBuilder(400);

			sb.Append("function DisallowUncheck(strCheckbox, intElement)\n");
			sb.Append("{\n");
			sb.Append("	if ( (document." + EditorDP.HTMLFORM_NAME +
				".elements[strCheckbox].checked == false) && \n");
			sb.Append("		(document." + EditorDP.HTMLFORM_NAME + "." +
				HTMLRADIO_FIRSTPAGETYPE + "[intElement].checked == true) )\n");
			sb.Append("	{\n");

			sb.Append("		alert('" +
				m_asOwner.GetString(889, "ptmsgs_portaladminmsgs") + "');\n");
			sb.Append("		document." + EditorDP.HTMLFORM_NAME +
				".elements[strCheckbox].checked = true;\n");
			sb.Append("	}\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}
		String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
		//Javascript to create a new community
		try
		{
			XPStringBuilder sb = new XPStringBuilder(400);
			sb.Append("function CreateCommunity(myArray)\n");
			sb.Append("{\n");
			sb.Append("  if ((myArray) && (myArray.length > 0)) {\n");
			sb.Append("    "+strJSUtilVersionPrefix+"PTWindowUtil.openWindow('")
			.Append(((ISubPortalModelRO) m_model).GetASURLToCommunity(null)
				.GetURLAsString()).Append(LinkConstants.AMPERSAND).Append(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID)
			.Append(LinkConstants.EQUALS).Append("' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID).Append("+ '").Append(LinkConstants.AMPERSAND).Append(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER)
			.Append(LinkConstants.EQUALS).Append(XPConvert.ToString(true)).Append("', 'PopUpCreateMode', '600','800');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		//Javascript to create a new folder
		try
		{
			XPStringBuilder sb = new XPStringBuilder(400);

			sb.Append("function CreateFolder(myArray)\n");
			sb.Append("{\n");
			sb.Append("  if ((myArray) && (myArray.length > 0)) {\n");
			sb.Append("   "+strJSUtilVersionPrefix+" PTWindowUtil.openWindow('")
			.Append(((ISubPortalModelRO) m_model).GetASURLToFolder(null)
				.GetURLAsString()).Append(LinkConstants.AMPERSAND).Append(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID)
			.Append(LinkConstants.EQUALS).Append("' + myArray[0].").Append(ATreeAS.OBJECT_OBJECT_ID)
				.Append(",'PopUpCreateMode','600','800');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		// The url to open a previously opened tree
		// This needs to have the SpaceID added to it.
		ASURL oldCommTree = new ASURL(m_asOwner);
		oldCommTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		oldCommTree.IsSubSpace();

		// The URL to open a new server communities tree
		ASURL newCommServerTree = new ASURL(m_asOwner);
		newCommServerTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
			m_asasParent);
		newCommServerTree.SetSubSpaceKey(SubPortalAS.strCOMMTREE_SUBSPACE);
		newCommServerTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		newCommServerTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		newCommServerTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
			XPConvert.ToString(false));
		newCommServerTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		newCommServerTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		newCommServerTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		newCommServerTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			HTMLHIDDEN_HOME_COMMUNITY_SPACE);
		newCommServerTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			JAVASCRIPT_SERVER_COMMSUBMIT);
		newCommServerTree.AddControlArgument(StartTreeControl.COMMUNITY_MODE, AObjectTreeModel.ALLCOMMUNITIES);

		newCommServerTree.AddControlArgument(StartTreeControl.TITLE,
			m_asOwner.GetString(872, "ptmsgs_portaladminmsgs"));

		newCommServerTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(871, "ptmsgs_portaladminmsgs"));
		newCommServerTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));

		try
		{
			XPStringBuilder sb = new XPStringBuilder(300);

			// Submit function
			sb.Append("function ").Append(JAVASCRIPT_SERVER_COMMSUBMIT).Append("()\n");
			sb.Append("{\n");
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(")
			.Append(SubPortalRepostControl.POSTTOSELF_ACTION_COMMTREESUBMIT)
			.Append(");\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

			// Open server user tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JAVASCRIPT_SERVER_COMMTREE).Append("(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('")
			.Append(newCommServerTree.GetURLAsString()).Append("', '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(oldCommTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		ASURL oldFolderTree = new ASURL(m_asOwner);
		oldFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		oldFolderTree.IsSubSpace();

		// The URL to open a new server folder tree
		ASURL newFolderTree = new ASURL(m_asOwner);
		newFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		newFolderTree.SetSubSpaceKey(SubPortalAS.strFOLDERTREE_SUBSPACE);
		newFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		newFolderTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		newFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		newFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFCOMPOSITESELECT));
		newFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		newFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		newFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			HTMLHIDDEN_HOME_FOLDER_SPACE);
		newFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			JAVASCRIPT_SERVER_FOLDERSUBMIT);

		newFolderTree.AddControlArgument(StartTreeControl.TITLE,
			m_asOwner.GetString(874, "ptmsgs_portaladminmsgs"));

		newFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(877, "ptmsgs_portaladminmsgs"));
		newFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));

		try
		{
			XPStringBuilder sb = new XPStringBuilder(300);

			//Submit function
			sb = new XPStringBuilder(100);
			sb.Append("function ").Append(JAVASCRIPT_SERVER_FOLDERSUBMIT)
			.Append("()\n");
			sb.Append("{\n");
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(")
			.Append(SubPortalRepostControl.POSTTOSELF_ACTION_FOLDERTREESUBMIT)
			.Append(");\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

			// Open server user tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JAVASCRIPT_SERVER_FOLDERTREE).Append("(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(newFolderTree.GetURLAsString())
			.Append("', '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(oldFolderTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		//START NEW STUFF HERE
		// The URL to display the tree for selecting a parent folder we'll use in creating a home folder
		ASURL createFolderTree = new ASURL(m_asOwner);
		createFolderTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		createFolderTree.SetSubSpaceKey(SubPortalAS.strFOLDERTREE_SUBSPACE);
		createFolderTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		createFolderTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		createFolderTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		createFolderTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFCOMPOSITESELECT));
		createFolderTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_JAVASCRIPTSUBMIT));  //Client side submit mode
		createFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		// DCA - we don't want to save space id, because it interferes w/ choose home folder tree pop up
		//createFolderTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
		//	HTMLHIDDEN_HOME_FOLDER_SPACE);
		createFolderTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
		   "CreateFolder"); // this is what the tree will call on finish

		createFolderTree.AddControlArgument(StartTreeControl.TITLE,m_asOwner.GetString(1887, "ptmsgs_portaladminmsgs"));

		createFolderTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(1886, "ptmsgs_portaladminmsgs"));

		createFolderTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));

		try
		{
			XPStringBuilder sb = new XPStringBuilder(300);

			// Open folder tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JAVASCRIPT_SERVER_CHOOSEPARENT).Append("()\n");
			sb.Append("{\n");
			// DCA - clear out space id to make choose home community tree pop up reinitialize
			sb.Append("document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_HOME_FOLDER_SPACE + ".value = '';\n");
			sb.Append("    window.open('").Append(createFolderTree.GetURLAsString())
			.Append("', '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		// The URL to display the tree for selecting a parent folder we'll use in creating a home community
		ASURL createCommunityTree = new ASURL(m_asOwner);
		createCommunityTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asasParent);
		createCommunityTree.SetSubSpaceKey(SubPortalAS.strCOMMTREE_SUBSPACE);
		createCommunityTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		createCommunityTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		createCommunityTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		createCommunityTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFCOMPOSITESELECT));
		createCommunityTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_JAVASCRIPTSUBMIT));  //Client side submit mode
		createCommunityTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		// DCA - we don't want to save space id, because it interferes w/ choose home community tree pop up
		//createCommunityTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
		//	HTMLHIDDEN_CREATE_COMMUNITY_SPACE);
		createCommunityTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
		   "CreateCommunity"); // this is what the tree will call on finish

		createCommunityTree.AddControlArgument(StartTreeControl.TITLE,m_asOwner.GetString(1887, "ptmsgs_portaladminmsgs"));

		createCommunityTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(2518, "ptmsgs_portaladminmsgs"));

		createCommunityTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));

		try
		{
			XPStringBuilder sb = new XPStringBuilder(300);

			// Open folder tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append("ChooseCommParentFolder").Append("()\n");
			sb.Append("{\n");
			// DCA - clear out space id to make choose home community tree pop up reinitialize
			sb.Append("document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_HOME_COMMUNITY_SPACE + ".value = '';\n");
			sb.Append("    window.open('").Append(createCommunityTree.GetURLAsString())
			.Append("', '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
		}

		if (((SubPortalModel) m_model).GetHomeCommunityError()) {
			try
			{
				XPStringBuilder sb = new XPStringBuilder(100);
				sb.Append("alert('" + m_asOwner.GetString(2629,"ptmsgs_portaladminmsgs") + "');");
				myScript.AddInnerHTMLString(sb.ToString());
				((SubPortalModel) m_model).SetHomeCommunityError(false);
	
			}
			catch (Exception e)
			{
				GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), "FeaturesView::DisplayJavascript", e, true, UIErrorLevel.SERIOUS, 
					m_asOwner.GetString(888,"ptmsgs_portaladminmsgs"));
			}
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent     = parent;
		m_model			 = (ISubPortalModelRO) model;
	}
}


