package com.plumtree.portalpages.admin.editors.subportal;

// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.server.*;

/**
 * This Section represents a section of the Edit Subportal Login Settings page
 * of the SubPortal Editor.
 * This Section is printed out by SubPortalLoginDP.
 * 
 * @author WilliamA
 */
public class LoginSettingsView extends EditorView {

	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.subportal.LoginSettingsView");

	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalLoginSettings";

	// HTML Object names.
	//       <select> starts with in_se
	//       <input button> starts with in_bu
	//       <input text> starts with in_tx
	//       <input checkbox> starts with in_cb
	//       <input radio> starts with in_ra
	//       <textarea> starts with in_ta
	public static final String HTMLHIDDEN_SELECTED_GUEST = "in_hi_guest";
	public static final String HTMLHIDDEN_GUEST_TREE_SUBSPACEID = "in_hi_guest_tree";
	public static final String HTMLBUTTON_SELECT_GUEST = "in_bu_selectguest";

	public static final String HTMLRADIO_LOGIN = "in_ra_login";
	public static final String HTMLRADIO_LOGOUT = "in_ra_logout";
	public static final String HTMLCHECKBOX_SSO = "in_cb_sso";

	public static final String GUEST_TREE_SUBSPACE = "SubportalGuestTree";
	
	// public static final String HTMLSELECT_GUEST = "in_se_guest";
	// public static final String HTMLRADIO_SSOVENDOR = "in_ra_ssovendor";
	
	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() {
		return new LoginSettingsView();
	}

		
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display() {
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;	
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLInput myInput;
		HTMLSpan mySpan;
		
		try 
		{
			// ** Guest Settings **
			
			mySpan = new HTMLSpan();
			result.AddInnerHTMLElement(mySpan);
						
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
				2804, "ptmsgs_portaladminmsgs")));
									
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// instruction row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
			myCell.SetColSpan("2");
			myCell.SetHeight("25");
			myRow.AddInnerHTMLElement(myCell);

			myCell.AddInnerHTMLString(m_asOwner.GetString(2808,
					"ptmsgs_portaladminmsgs"));

			// guest-user tree picker row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			String strSelectedGuest = ((ISubPortalModelRO) m_model).GetGuestUserName();
			int nSelectedGuestID = ((ISubPortalModelRO) m_model).GetGuestUserID();

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetWidth("25%");
			myCell.SetNoWrap(true);

			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
			mySpan.AddInnerHTMLEncodedString(m_asOwner.GetString(3033, "ptmsgs_portaladminmsgs"));  // "Guest User:"
			myCell.AddInnerHTMLElement(mySpan);
			myCell.AddInnerHTMLEncodedString(" ");
			
			if (strSelectedGuest != null)
			{
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);				
				mySpan.AddInnerHTMLEncodedString(strSelectedGuest);
				myCell.AddInnerHTMLElement(mySpan);
			}
			
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetWidth("75%");
			myCell.SetNoWrap(true);

			// hidden input user Folder Name for validation
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_SELECTED_GUEST, "");
			result.AddInnerHTMLElement(myInput);
			myInput.SetValue(XPConvert.ToString(nSelectedGuestID));

			// hidden input with the tree subspace ID
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_GUEST_TREE_SUBSPACEID, "");
			result.AddInnerHTMLElement(myInput);

			String strGuestTreeSubSpaceID = ((ISubPortalModelRO) m_model).GetGuestTreeSubSpaceID();
			
			if (null == strGuestTreeSubSpaceID)
			{
				myInput.SetValue("");
			}
			else
			{
				myInput.SetValue(strGuestTreeSubSpaceID);
			}		

			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_SELECT_GUEST, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(3032, "ptmsgs_portaladminmsgs")); // "Select a Guest User"
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("openGuestTree(document." +	AFormDP.HTMLFORM_NAME + 
				"." + HTMLHIDDEN_GUEST_TREE_SUBSPACEID + ");");
			// guest-user tree picker row end

			/*			
			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			//myCell.SetColSpan("2");
			myCell.SetHeight("25");
			myRow.AddInnerHTMLElement(myCell);
			
			mySelect = new HTMLSelect(HTMLSELECT_GUEST,
				"subPortalLoginSettings");
			myCell.AddInnerHTMLElement(mySelect);			
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			IASQueryResult IASprofiles = ((ISubPortalModelRO) m_model).GetProfiles();
			
			String strProfileName;
			int nProfileID;

			for (int i = 0; i < IASprofiles.GetCount(); i++)
			{
				nProfileID		   = XPConvert.ToInteger(IASprofiles.GetFields(i,
						PT_PROPIDS.PT_PROPID_OBJECTID));

				IPTSession ptSession = ((ISubPortalModelRO) m_model).GetPTSession();
				boolean bObjectIsAccessible = ptSession.GetUsers().IsObjectAccessible( nProfileID,
					ptSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);

				if (bObjectIsAccessible) {
					strProfileName     = (String) IASprofiles.GetFields(i,
							PT_PROPIDS.PT_PROPID_NAME);

					String optionValue = XPConvert.ToString(nProfileID);
					myOption		   = new HTMLOption(optionValue);

					if ((null != strProfileName) && (strProfileName.equals(strSelectedGuest)))
					{
						myOption.SetSelected(true);
					}

					mySelect.AddInnerHTMLElement(myOption);
					myOption.AddInnerHTMLEncodedString(strProfileName);
				}
			}
			*/


			result.AddInnerHTMLElement(EditorView.GetSpacerTable());
			
			// ** Login Page Settings **
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
				2805, "ptmsgs_portaladminmsgs")));

			// GuestRedirectOnLogin setting
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// instruction row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
			myCell.SetColSpan("2");
			myCell.SetHeight("25");
			myRow.AddInnerHTMLElement(myCell);

			myCell.AddInnerHTMLString(m_asOwner.GetString(2809,
					"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(3036,
				"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(mySpan);

			String[] optionLabels = new String[2];
			optionLabels[0] = m_asOwner.GetString(2812,
				"ptmsgs_portaladminmsgs");
			optionLabels[1] = m_asOwner.GetString(2813,
				"ptmsgs_portaladminmsgs");
			String[] optionValues = new String[2];
			optionValues[0] = "0";
			optionValues[1] = "1";

			int selectedOption;
			if (((ISubPortalModelRO) m_model).GetGuestRedirectToLogin())
				selectedOption = 1;
			else
				selectedOption = 0;
								
			for (int i=0; i<optionLabels.length; i++) 
			{
				//row begin 			
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

				myCell = new HTMLTableCell();
				myCell.SetWidth("1%");
				myCell.SetAlign("center");
				myRow.AddInnerHTMLElement(myCell);
				myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_LOGIN,
					optionLabels[i]);
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetValue(optionValues[i]);

				if (i == selectedOption)
				{
					myInput.SetChecked(true);
				}

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("99%");
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
				mySpan.AddInnerHTMLString(optionLabels[i]);
				myCell.AddInnerHTMLElement(mySpan);
				//Row End
			}

			// result.AddInnerHTMLElement(EditorView.GetSpacerTable());

			// RedirectOnLogout setting
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// instruction row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
			myCell.SetColSpan("2");
			myCell.SetHeight("25");
			myRow.AddInnerHTMLElement(myCell);

			myCell.AddInnerHTMLString(m_asOwner.GetString(2810,
					"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(3037,
				"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(mySpan);
			
			optionLabels = new String[2];
			optionLabels[0] = m_asOwner.GetString(2812,
				"ptmsgs_portaladminmsgs");
			optionLabels[1] = m_asOwner.GetString(2813,
				"ptmsgs_portaladminmsgs");
			optionValues = new String[2];
			optionValues[0] = "0";
			optionValues[1] = "1";

			if (((ISubPortalModelRO) m_model).GetRedirectOnLogout())
				selectedOption = 1;
			else
				selectedOption = 0;
					
			for (int i=0; i<optionLabels.length; i++) 
			{
				//row begin 				
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

				myCell = new HTMLTableCell();
				myCell.SetWidth("1%");
				myCell.SetAlign("center");
				myRow.AddInnerHTMLElement(myCell);
				myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_LOGOUT,
					optionLabels[i]);
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetValue(optionValues[i]);

				if (i == selectedOption)
				{
					myInput.SetChecked(true);
				}

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("99%");
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
				mySpan.AddInnerHTMLString(optionLabels[i]);
				myCell.AddInnerHTMLElement(mySpan);
				//Row End
			}
			
			result.AddInnerHTMLElement(EditorView.GetSpacerTable());
						
			// ** SSO Vendor **
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
				2806, "ptmsgs_portaladminmsgs")));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// instruction row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
			myCell.SetColSpan("2");
			myCell.SetHeight("25");
			myRow.AddInnerHTMLElement(myCell);

			myCell.AddInnerHTMLString(m_asOwner.GetString(2811,
					"ptmsgs_portaladminmsgs"));

			int nSSOVendor = ((ISubPortalModelRO) m_model).GetSSOVendor();
			int nDefaultSSOVendor = ((ISubPortalModelRO) m_model).GetDefaultSSOVendor();

			// "Disable SSO" checkbox
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myCell.SetWidth("1%");
			myCell.SetAlign("center");
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLCHECKBOX_SSO,
				m_asOwner.GetString(2814, "ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue("0");

			if (0 == nDefaultSSOVendor)
			{
				// This means SSO is disabled globally (in the portal config file)
				myInput.SetChecked(true);
				myInput.SetDisabled(true);
			} else if (0 == nSSOVendor)
			{
				myInput.SetChecked(true);
			}

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("99%");
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(2814,
				"ptmsgs_portaladminmsgs"));
			myCell.AddInnerHTMLElement(mySpan);
			
			// WilliamA - Following is the SSO vendor selection UI -
			// disabled for Martok (Martok has only "disable SSO" checkbox)
			/*
			optionLabels = new String[6];
			optionLabels[0] = m_asOwner.GetString(2814,
				"ptmsgs_portaladminmsgs");
			optionLabels[1] = m_asOwner.GetString(2815,
				"ptmsgs_portaladminmsgs");
			optionLabels[2] = m_asOwner.GetString(2816,
				"ptmsgs_portaladminmsgs");
			optionLabels[3] = m_asOwner.GetString(2817,
				"ptmsgs_portaladminmsgs");
			optionLabels[4] = m_asOwner.GetString(2818,
				"ptmsgs_portaladminmsgs");
			optionLabels[5] = m_asOwner.GetString(2819,
				"ptmsgs_portaladminmsgs");
			int[] optionVal = new int[6];
			optionVal[0] = 0;
			optionVal[1] = 2;
			optionVal[2] = 3;
			optionVal[3] = 5;
			optionVal[4] = 50;
			optionVal[5] = 100;
			
			for (int i=0; i<optionLabels.length; i++) 
			{
				//row begin 			
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

				myCell = new HTMLTableCell();
				myCell.SetWidth("1%");
				myCell.SetAlign("center");
				myRow.AddInnerHTMLElement(myCell);
				myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_SSOVENDOR,
					optionLabels[i]);
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetValue(XPConvert.ToString(optionVal[i]));

				if (optionVal[i] == nSSOVendor)
				{
					myInput.SetChecked(true);
				}

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetWidth("99%");
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
				mySpan.AddInnerHTMLString(optionLabels[i]);
				myCell.AddInnerHTMLElement(mySpan);
				//Row End
			}
			*/
			
		} catch (Exception e)
		{		
			log.Error(e, "LoginSettingsView::Display The following error occured when trying to display the HTML: " +
				e.getMessage());
			
			throw new XPException(m_asOwner.GetString(2820,
				"ptmsgs_portaladminmsgs"), e);
		}
		
		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		String strFormName = AFormDP.HTMLFORM_NAME;

		// The URL to open a new user Folder tree
		ASURL newGuestTreeURL = new ASURL(m_asOwner);
		newGuestTreeURL.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		newGuestTreeURL.SetSubSpaceKey(GUEST_TREE_SUBSPACE);
		newGuestTreeURL.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		newGuestTreeURL.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		newGuestTreeURL.AddControlArgument(StartTreeControl.MULTI_SELECT,
			XPConvert.ToString(false));
		newGuestTreeURL.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		newGuestTreeURL.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		newGuestTreeURL.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			HTMLHIDDEN_GUEST_TREE_SUBSPACEID);
		newGuestTreeURL.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			"guestSubmit");
			
		newGuestTreeURL.AddControlArgument(StartTreeControl.TITLE, m_asOwner.GetString(3032, "ptmsgs_portaladminmsgs"));
		newGuestTreeURL.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(3032, "ptmsgs_portaladminmsgs"));
		
		newGuestTreeURL.AddControlArgument(StartTreeControl.ACCESS_LEVEL,
			PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
		newGuestTreeURL.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
		
		// Add filter to the tree (guest usertype only)
		XPStringBuilder filter = new XPStringBuilder(100);
		filter.Append(PT_CLASSIDS.PT_USER_ID);
		filter.Append(",");
		filter.Append(PT_PROPIDS.PT_PROPID_USER_USERTYPE);
		filter.Append(",");
		filter.Append(PT_USER_TYPES.PT_USER_TYPE_GUEST);
		newGuestTreeURL.AddControlArgument(StartTreeControl.QUERY_FILTER,
			filter.ToString());

		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		ASURL oldGuestTreeURL = new ASURL(m_asOwner);
		oldGuestTreeURL.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		oldGuestTreeURL.IsSubSpace();

		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		try
		{
			// Open user tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append("openGuestTree").Append("(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('")
			.Append(newGuestTreeURL .GetURLAsString()).Append("', '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('")
			.Append(oldGuestTreeURL .GetURLAsString()).Append("&")
			.Append(ASConstants.SPACEID).Append("=' + myInput.value").Append(", '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

			// Submit function
			sb = new XPStringBuilder(100);
			sb.Append("function guestSubmit()\n");
			sb.Append("{\n");
			sb.Append("  postToSelf(")
			.Append(SubPortalRepostControl.POSTTOSELF_ACTION_GUESTTREESUBMIT).Append(");\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(100);
			sb.Append("function CheckGuest()\n");
			sb.Append("{\n");
			sb.Append("  if (document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_SELECTED_GUEST + ".value == '') { \n");

			sb.Append("		alert(\"" + m_asOwner.GetString(3034, "ptmsgs_portaladminmsgs") + "\");\n");
			sb.Append("      return false;\n");
			sb.Append("  }\n");
			sb.Append("  return true;\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException e)
		{
			log.Error(e, "LoginSettingsView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					e.GetMessage());

			throw new XPException(m_asOwner.GetString(3035, "ptmsgs_portaladminmsgs"), e);
		}

		return myScript;
	}

}
