package com.plumtree.portalpages.admin.editors.subportal;

// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This View class implements the Stylesheet selector UI in the form
 * of a drop-down list.
 * 
 * @author WilliamA
 */
public class StylesheetView extends EditorView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.subportal.StylesheetView");

	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalStylesheet";

	// HTML Object names.
	//       <select> starts with in_se
	//       <input button> starts with in_bu
	//       <input text> starts with in_tx
	//       <input checkbox> starts with in_cb
	//       <input radio> starts with in_ra
	//       <textarea> starts with in_ta
	public static final String HTMLSELECT_STYLESHEET = "in_se_StyleSheet";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new StylesheetView();
	}
	
	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Stylesheet drop-down selector
		HTMLTable myTable;
		HTMLTableCell myCell;
		HTMLTableRow myRow;

		try 
		{
			myTable = new HTMLTable();

			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetWidth("100");
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			
			// myCell.AddInnerHTMLString("Style Sheet:");
			myCell.AddInnerHTMLString(m_asOwner.GetString(2784,
				"ptmsgs_portaladminmsgs"));
			myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			HTMLSelect styleSelect = new HTMLSelect(HTMLSELECT_STYLESHEET,
				"subPortalStyleSheet");
			styleSelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
		
			HTMLOption styleOption = null;
			
			ISubPortalModelRO myModel = (ISubPortalModelRO)m_model;
			String strStyleSheet = myModel.GetStyleSheet();
					
			// Add the default "Use Portal Style" option as first option
			styleOption = new HTMLOption("");
			styleOption.AddInnerHTMLString(m_asOwner.GetString(2786,
				"ptmsgs_portaladminmsgs"));

			styleSelect.AddInnerHTMLElement(styleOption);

			// Add the rest of available stylesheet names			
			IXPDictionary styleSheets = myModel.GetStyleSheetOptions();
			if (null != styleSheets)
			{
				IXPDictionaryEnumerator options = styleSheets.GetEnumerator();				
				while (options.MoveNext())
				{
					IXPDictionaryEntry option = options.GetCurrentDictionaryEntry();
					String styleName = (String)option.GetKey();
					String styleCssFile = (String)option.GetValue();

					styleOption = new HTMLOption(styleCssFile);
					styleOption.AddInnerHTMLString(styleName);

					styleSelect.AddInnerHTMLElement(styleOption);
				}
			}

			if ( (null != strStyleSheet) && (!strStyleSheet.equals("")) )
			{
				try 
				{
					styleSelect.SetValue(strStyleSheet);
				} catch (Exception e)
				{
					// no match for the selected style sheet
				}				
			}
			
			myCell.AddInnerHTMLElement(styleSelect);
			myCell = new HTMLTableCell();
			myCell.SetWidth("100%");
			myRow.AddInnerHTMLElement(myCell);

			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetColSpan("3");
			myRow.AddInnerHTMLElement(myCell);

			// Warning about styles and layout modes
			myCell.AddInnerHTMLString(m_asOwner.GetString(3207, ResourceConstants.PORTALADMINMSGS));
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Common"), 
				"StylesheetView::Display", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(2783,"ptmsgs_portaladminmsgs"));
		}

		return result;
	}

	/**
	 * Returns Java Script for that Section.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}
		
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
