package com.plumtree.portalpages.admin.editors.subportal;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register all the Model, Views, Display Pages,  and
 * Controls created for the SubPortal Editor. This class can also be used to
 * get any of those objects back with  the class name.
 *
 * @author JohnH
 */
public class SubPortalAS extends ObjEditorAS {
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.subportal.SubPortalAS");

	/** Unique identifier for this activity space class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalEditor";

	/** Unique identifier for the Header SelectPTObject plug-in */
	public static final String STR_MVC_STORAGE_NAME_SELECT_HEADER = "SelectPTObjectHeader";

	/** Unique identifier for the Footer SelectPTObject plug-in */
	public static final String STR_MVC_STORAGE_NAME_SELECT_FOOTER = "SelectPTObjectFooter";

	/** Unique identifier for the Folder SelectPTObject plug-in */
	public static final String STR_MVC_STORAGE_NAME_SELECT_FOLDER = "SelectPTObjectFolder";

	/** Unique identifier for sitemap folder links plug-in section */
	//public static final String STR_MVC_SITEMAP_PLUGIN = "SiteMapFolderPlugIn";


	/** sub-space key for Communities tree */
	public static final String strCOMMTREE_SUBSPACE = "SubPortalCommTreeSubSpace";

	/** sub-space key for Folders tree */
	public static final String strFOLDERTREE_SUBSPACE = "SubPortalFolderTreeSubSpace";

	/** sub-space key for the Admin folder tree */
	public static final String ADMINFOLDERTREE_SUBSPACE = "SubPortalAdminFolderSubSpace";

	private static String sClassName = "com.plumtree.portalpages.admin.editors.subportal.SubPortalAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() {
		return new SubPortalAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle() {
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(m_strModelName)).GetEditorType()) {
			//Return the main title of the Editor in create mode.
			return (GetString(899, "ptmsgs_portaladminmsgs"));
		} else {
			//Return the main title of the Editor in edit mode.
			return (XPResourceManager.FormatMessage(GetString(2620, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName() {
		return (SubPortalDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 *
	 * @return
	 */
	public String GetRepostControlName() {
		return (SubPortalRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init() {
		m_strModelName = SubPortalModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(SubPortalModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages

		// Features DP
		RegisterPage(new SubPortalFeaturesDP());

		// Banner DP
		RegisterPage(new SubPortalBannerDP());

		//Navigation DP
		SubPortalNavDP navDP = new SubPortalNavDP();
		RegisterPage(navDP);
		navDP.AddToValidationFunction(SiteMapFolderPlugInView.JAVASCRIPT_CHECKNAVLINKNAME);

		// Login Settings DP
		SubPortalLoginDP loginDP = new SubPortalLoginDP();
		RegisterPage(loginDP);
		// add validation function for guest user selection
		loginDP.AddToValidationFunction("CheckGuest");

		// Layout DP
		RegisterPage(new SubPortalLayoutDP());

		// Register Views
		RegisterView(FeaturesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(NavigationView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SubPortalDependenciesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(StylesheetView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(LoginSettingsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(LayoutView.STR_MVC_CLASS_NAME, myModel);
		
		// Register Controls
		RegisterControl(SubPortalRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Set default page
		SetCurrentPage(SubPortalFeaturesDP.STR_MVC_CLASS_NAME);

		// Register plug-in sections
		// Sitemap link plug-in
		RegisterModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);

		IModel mySiteMapPluginModel = GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		//Register the display page
		RegisterPage(new SiteMapCreateWebLinkDP());
		//The Site map folder views
		RegisterView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		RegisterView(SiteMapCreateWebLinkView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		//The site map folder control
		RegisterControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME, mySiteMapPluginModel);

		//SelectPTObject Plug-Ins
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_HEADER);
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOOTER);
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOLDER);

		IModel mySelectPTHeaderModel = GetModel(STR_MVC_STORAGE_NAME_SELECT_HEADER);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_HEADER, mySelectPTHeaderModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_HEADER, mySelectPTHeaderModel);

		IModel mySelectPTFooterModel = GetModel(STR_MVC_STORAGE_NAME_SELECT_FOOTER);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOOTER, mySelectPTFooterModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOOTER, mySelectPTFooterModel);

		IModel mySelectPTObjectModel = GetModel(STR_MVC_STORAGE_NAME_SELECT_FOLDER);
		RegisterView(SelectAdminFolderView.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOLDER, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_STORAGE_NAME_SELECT_FOLDER, mySelectPTObjectModel);

		//Sets left nav menu
		// Set the left nav menu using StartNewSubMenu and AddLinkToSubMenu.
		// BEGIN Sub menu "Edit Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(901, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalFeaturesDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalBannerDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalNavDP.STR_MVC_CLASS_NAME);
		
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalLoginDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubPortalLayoutDP.STR_MVC_CLASS_NAME);
		// END Sub menu "Edit Settings"

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1890, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null) {
			try {

				tm.SetGeneratingClass(sClassName);

				int iTitleId = 66;
				int iTipId = 67;
				int iSecondaryTipId = 68;

				tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));

				HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId, "ptmsgs_tips"));

				tm.SetTip(e);

				String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");

				if (!("none_do_not_translate".equals(sSecondary))) {

					e = new HTMLGenericElement(sSecondary);

					tm.SetSecondarTip(e);
				}

			} catch (Exception ex) {
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		//	Got the tips model

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 * Sets the help links for the subportal editor
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page) {
		super.SetCurrentPage(page);
		String sPageName = page.GetName();

		if (SubPortalFeaturesDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Subportal_MainSettings");
		} else if (SubPortalBannerDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Subportal_HeaderandFooter");
		} else if (SubPortalNavDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Subportal_NavigationOptions");
		} else if (SiteMapCreateWebLinkDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_SelectLinks_WebPages");
		} else if (SubPortalLoginDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Subportal_LoginSettings");
		} else if (SubPortalLayoutDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
			this.SetHelpTopic("PT_Subportal_Layout");
		}
	}
}