package com.plumtree.portalpages.admin.editors.subportal;

// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the Banner & Footer page of the SubPortal Editor.
 *
 * @author JohnH
 */
public class SubPortalBannerDP extends EditorDP {
	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalBanner";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return (m_asOwner.GetString(902, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()  {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1652, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}


	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Choose Header & Filter page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// Stylesheet drop-down selector
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(StylesheetView.STR_MVC_CLASS_NAME))
				.Display());
		
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		
		// Header & footer selectors
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER))
				.Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER))
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER)
				.DisplayJavascript());
		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER)
				.DisplayJavascript());

		return myScripts;
	}

	// ***CHANGE_HERE*** This method is optional. 
	//      You can implement it if you want to display some HTML in the head.
	//		If that method exists the framework will automatically call it
	//      and the HTML returned will get displayed in the head tag.
	//      WARNING: META and LINK tags only should be returned.

	/*public HTMLElementCollection DisplayHTMLinHEAD() throws HTMLException
	{
	    HTMLElementCollection myHTMLinHead = new HTMLElementCollection();
	    // ***CHANGE_HERE*** Add your HTML to the myHTMLinHead HTML collection.
	
	    return(myHTMLinHead);
	}*/

	// ***CHANGE_HERE*** This method is optional. 
	//      You can implement it if you want to display some HTML after 
	//      the BODY tag and before the FORM tag.
	//		If that method exists, the framework will automatically call it.
	//      E.g.: DIV tags should go in that method.

	/*public HTMLElementCollection DisplayHTMLBeforeForm() throws HTMLException
	{
	    HTMLElementCollection myHTMLBeforeForm = new HTMLElementCollection();
	    // ***CHANGE_HERE*** Add your HTML to the myHTMLBeforeForm HTML collection.
	
	    return(myHTMLBeforeForm);
	}*/
}

