package com.plumtree.portalpages.admin.editors.subportal;

import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the Edit Subportals Layout page of the SubPortal Editor.
 */
public class SubPortalLayoutDP extends EditorDP
{
	/** Unique identifier for this class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalLayout";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		// Adaptive Layout Settings
		return (m_asOwner.GetString(3201, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()  {
		return HTMLConstructHelpers.GetSubHeader(
			// Control whether or not Adaptive Page Layouts are enabled for this Experience Definition.
			m_asOwner.GetString(3202, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(
			((EditorView) m_asOwner.GetView(LayoutView.STR_MVC_CLASS_NAME))
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(LayoutView.STR_MVC_CLASS_NAME)
				.DisplayJavascript());
		
		return myScripts;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}
}