package com.plumtree.portalpages.admin.editors.subportal;

// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is class is used to edit the guest user and login settings
 * of the SubPortal.
 *
 * @author William Adjie-Winoto
 */
public class SubPortalLoginDP extends EditorDP {

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalLogin";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return (m_asOwner.GetString(2803, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()  {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(2807, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Choose Header & Filter page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// Stylesheet drop-down selector
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(LoginSettingsView.STR_MVC_CLASS_NAME))
				.Display());
		
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		
		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		
		myScripts.AddInnerHTMLElement(m_asOwner
				.GetView(LoginSettingsView.STR_MVC_CLASS_NAME)
				.DisplayJavascript());

		return myScripts;
	}

}
