package com.plumtree.portalpages.admin.editors.subportal;


import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.adminfolder.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portalpages.browsing.editors.folder.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.impl.community.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;


/**
 * This class contains the IPTSubPortal server object,  as well as the set and
 * get methods on that object. This class is called by the
 * SubPortalRepostControl class to perform  the changes on the Object and by
 * the Section classes  to display the latest values on the page.
 *
 * @author JohnH
 */
public class SubPortalModel extends ObjEditorModel implements ISubPortalModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.subportal.SubPortalModel");

	/** Unique identifier for this class */
	public static final String STR_MVC_CLASS_NAME = "SubPortal";

	/** Default value for mandatory links ID.  This value is used when there are no mandatory links */
	public static final int NO_MANDATORY_LINKS = 0;

	/** PTGuestLogin object's name suffix */
	private static final String LOGIN_SETTINGS_SUFFIX = " Login Settings";
	
	/** The identifier for the Community Editor sub-activity space */
	private String m_strCommSubSpaceID = "";

	/** The identifier for the Folder Editor sub-activity space */
	private String m_strFolderSubSpaceID = "";

	/** Member variable containing the home community name */
	private String m_strHomeCommunityName = "";

	/** Member variable containing the home folder name */
	private String m_strHomeFolderName = "";

	/** Member variable containing the access type (MyPage, Community, or Knowledge Directory) */
	private int m_intAccessType;

	/** Member variable containing the Object ID of the default first page for the subportal */
	private int m_intDefaultFirstPage = 0;

	/** Member variable containing the type of the first page in the subportal */
	private int m_intDefaultFirstPageType;

	/** Member variable containing the Object ID of the selected footer portlet, if applicable */
	private int m_intFooterID = 0;

	/** Member variable containing the Object ID of the selected header portlet, if applicable */
	private int m_intHeaderID = 0;

	/** Member variable containing the Stylesheet name for the Subportal */
	private String m_strStyleSheet = null;
	
	/** Member variable containing available options for Stylesheet names */
	private IXPDictionary m_styleSheets = null;
	
	/** Member variable containing the object ID of the home community */
	private int m_intHomeCommunityID = 0;

	/** Member variable containing the object ID of the home folder */
	private int m_intHomeFolderID = 0;
	
	/** Member variable to check whether the Home Community exist */
	private boolean m_bHomeCommunityError = false;

	/** Member variable containing the navigation scheme for this subportal */
	private int m_intNavigationScheme;

	/** Member variable containing whether or not Layouts are enabled for this subportal */
	private boolean m_bLayoutEnabled = true;
	
	/** Member variable containing the selected layout options by the layout chooser for this subportal */
	private String m_strLayoutOptions = "";

	/** Member variable containing a bitmask of related resource types the subportal allows access to */
	private int m_intRelatedResourcesAccessTypes = 0;

	/** The Object IDs for the folders that this subportal is associated with */
	private PTGrowableSortedArrayWrapper m_arrFolderIDs;

	/** Boolean variable to track whether a newly created folder has been moved out of
	 * the unclassified area or not */
	private boolean m_bFolderUnclassified = true;

	/** Member variable to store the SiteMapFolder object that is associated with this subportal */
	private IPTSiteMapFolder m_ptLinksFolder;

	/** Member variable to store the PTGuestLogin object that is associated with this subportal */
	private IPTGuestLogin m_ptGuestLogin;

	// Flag to indicate whether the m_ptGuestLogin obj is a newly created one or existing one
	private boolean m_bNewGuestLogin;
		
	/** Member variable containing the guest-user-ID property of Guest Login object */
	private String m_strGLGuestUserName;  // for read part (get)
	private int m_nGLGuestUserID = PT_INTRINSICS.PT_NULL_OBJECTID;	// for write part (set)

	/** Guest tree picker subspace ID */
	private String m_strGuestTreeSubSpaceID = "";
	
	/** Member variable containing the GuestRedirectToLogin property of Guest Login object */
	private boolean m_bGLGuestRedirectToLogin;
	
	/** Member variable containing the RedirectOnLogout property of Guest Login object */
	private boolean m_bGLRedirectOnLogout;
	
	/** Member variable containing the SSOVendor property of Guest Login object */
	private int m_nGLSSOVendor;
	
	private boolean m_bIsGuestLoginDirty = false; 
	
	private XPHashtable m_htInitFolderValues;

	/** Member variable indicating whether or not this editor has been cancelled. */
	private boolean m_bCancelled = false;

	public SubPortalModel()
	{
		super();
		m_intAccessType = PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS +
				PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS +
				PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS;
		m_intRelatedResourcesAccessTypes = PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_COMMUNITIES_ACCESS + 
				PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_CONTENTMANAGERS_ACCESS + 
				PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_EXPERTS_ACCESS + 
				PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_FOLDERS_ACCESS + 
				PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_PORTLETS_ACCESS;
		m_intDefaultFirstPageType = PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS;
		m_intNavigationScheme = NavTypeConstants.NAVTYPE_ID_HORIZONTAL_DHTML_DROPDOWN_JSPORTALMENU;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SubPortalModel();
	}

	// BEGIN ***************** Framework methods *****************

	/**
	 * Initializes the property type member variable with  the one from
	 * IPTProperty in Edit mode and the default  value in create mode.
	 *
	 * @param _htFormData
	 * @throws XPException
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		StartSelectPTHeader();
		StartSelectPTFooter();
		StartSelectPTFolder();
		InitializeSiteMapPlugIn();
		
		//Populate the member variables if the editor is in Edit mode
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			try
			{
				m_intAccessType = ((IPTSubPortal) m_ptObject).GetAccessType();
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Access Type. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(904,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				m_intDefaultFirstPageType = ((IPTSubPortal) m_ptObject).GetDefaultFirstPageType();
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Default First Page Type. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(906,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				//Default mypages access does not have a first page..
				if (m_intDefaultFirstPageType != PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS)
				{
					m_intDefaultFirstPage = ((IPTSubPortal) m_ptObject).GetDefaultFirstPage();
				}
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Default First Page. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(905,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				if (0 != m_intDefaultFirstPage)
				{
					if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS == m_intDefaultFirstPageType)
					{
						IPTQueryResult myQueryResult;
						myQueryResult			   = m_Session.GetCommunities()
							.QuerySingleObject(m_intDefaultFirstPage);
						if (myQueryResult.RowCount() > 0) {
							m_strHomeCommunityName     = myQueryResult.ItemAsString(0,
									PT_PROPIDS.PT_PROPID_NAME);
							m_intHomeCommunityID	   = m_intDefaultFirstPage;
						} else {
							m_bHomeCommunityError = true;
						}
					}
					else
					{
						try
						{
							IPTFolder myFolder = m_Session.GetCatalog()
								.OpenFolder(m_intDefaultFirstPage, false);
							m_strHomeFolderName     = myFolder.GetLocalizedName();
							m_intHomeFolderID	    = m_intDefaultFirstPage;
						}
						catch (Exception e)
						{
							
								log.Error("SubPortalModel::DoTaskOnStartEditor: Unbable to retrieve home folder, setting to Root Folder.");
							

							m_intDefaultFirstPage     = m_Session.GetCatalog()
								.GetRootFolder().GetObjectID();
							m_strHomeFolderName		  = m_Session.GetCatalog()
								.GetRootFolder().GetLocalizedName();
						}
					}
				}
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Default First Page Name. The following exception occured: " +
						e);
				
				
				throw new XPException(m_asOwner.GetString(905,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				m_intFooterID = ((IPTSubPortal) m_ptObject).GetFooterID();
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Footer ID. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(907,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				m_intHeaderID = ((IPTSubPortal) m_ptObject).GetHeaderID();
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Header ID. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(908,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				m_intNavigationScheme = ((IPTSubPortal) m_ptObject).GetNavigationScheme();
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Navigation Scheme. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(910,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				m_intRelatedResourcesAccessTypes = ((IPTSubPortal) m_ptObject).GetRelatedResourcesAccessType();
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the Related Resources Access Types. The following exception occured: " +
						e);
				

				throw new XPException(m_asOwner.GetString(911,
						"ptmsgs_portaladminmsgs"), e);
			}

			try
			{
				m_bLayoutEnabled = ((IPTSubPortal) m_ptObject).GetLayoutEnabled();
				m_strLayoutOptions = ((IPTSubPortal) m_ptObject).GetLayoutOptions();
			}
			catch (Exception e)
			{
				log.Error(e, "SubPortalModel::DoTaskOnStartEditor Unable to get the Layout Mode.");

				throw new XPException(m_asOwner.GetString(3199, ResourceConstants.PORTALADMINMSGS), e);
			}

			((EditorAS) m_asOwner).GetLeftMenu().HideLink(false,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
		}
		else
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

		// WilliamA - Retrieve the list of available stylesheets
		try 
		{
			XPLocale locale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner);		
			String communityThemesURL = GetCommunityThemesURL(); 
            if ((!"http://".equals(communityThemesURL.substring(0,7))) && 
                (!"https://".equals(communityThemesURL.substring(0,8)))) 
            {
                // DCA - url must be relative
                String strRequestScheme = m_asOwner.GetCurrentHTTPRequest().GetScheme();
                String strRequestServer = m_asOwner.GetCurrentHTTPRequest().GetServerName();
                int iRequestPort = m_asOwner.GetCurrentHTTPRequest().GetServerPort();
                communityThemesURL = strRequestScheme + "://" + strRequestServer 
                + ":" + iRequestPort + communityThemesURL;
            }
            
			m_styleSheets = SubPortalUtils.getStyleSheetList(communityThemesURL, locale);
			
			if (null != m_ptObject)
			{
				m_strStyleSheet = ((IPTSubPortal) m_ptObject).GetStyleSheet();
			}			
		}
		catch (Exception e)
		{
			log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the stylesheet options. The following exception occured: " +
					e);		

			// can't get list of style sheets move on
		}
		
		// WilliamA - Populate member variables for the Login Settings page
		InitializeGuestLoginPlugIn();				
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Finish()
	 */
	public void Finish()
	{
		if (m_bCancelled)
		{
			// If we have already cancelled the editor, then we have cleaned up
			// (e.g. deleted the Site Map Links folder) and should not try to
			// store anything.

			log.Info("Subportal editor attempting to save after already being cancelled.  This is not possible.  Ignoring.");

			String strCancelledMessage = m_asOwner.GetString(3155, ResourceConstants.PORTALADMINMSGS);

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
				UIErrorScope.CURRENT_USER, null,
				strCancelledMessage, strCancelledMessage);
			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			// throw an exception to tell the SaveObjectRepostControl to
			// cancel the rest of the process.
			throw new XPException(strCancelledMessage);
		}

		super.Finish();
	}

	/**
	 * Initializes IPTSubPortal with the member  variables just before we store
	 * the object in the DB.
	 * @throws XPException
	 */
	public void DoTaskBeforeStore()
	{
		//If we're in create mode, we need to first create a new sitemapfolder object, then set the
		//mandatory links ID property.  Otherwise, we just need to store the possibly edited site map
		//folder object
		try
		{
			if (null != m_ptLinksFolder)
			{
				SiteMapFolderPlugInModel myModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
				XPArrayList arrLinks = myModel.GetLinks();
				if (arrLinks.GetSize() > 0)
				{
                    if (m_ptLinksFolder.GetLockState() != PT_LOCKSTATES.PT_NEWLYCREATED) {
                        m_ptLinksFolder.LockObject();
                    }
				    m_ptLinksFolder.Store();
				    m_ptLinksFolder.UnlockObject();

					((IPTSubPortal) m_ptObject).SetMandatoryLinksID(m_ptLinksFolder.GetObjectID());

					myModel.StoreLinks();
				}
				else
				{
                    if (m_ptLinksFolder.GetLockState() != PT_LOCKSTATES.PT_NEWLYCREATED) {
                        m_Session.GetSiteMapFolders().Delete(m_ptLinksFolder.GetObjectID());
                    }
					((IPTSubPortal) m_ptObject).SetMandatoryLinksID(NO_MANDATORY_LINKS);
					// DCA - no longer needed
					m_ptLinksFolder = null;
				}

			}
		}
		catch (Exception e)
		{
			if (null != m_ptLinksFolder)
			{
			    m_ptLinksFolder.UnlockObject();
			}
			XPStringBuilder sb = new XPStringBuilder(100);
			sb.Append(m_asOwner.GetString(2101, "ptmsgs_portaladminmsgs")).Append(e);

			
				log.Error("SubPortalModel::DoTaskBeforeStore " + sb.ToString());
			
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, null, sb.ToString(),
					sb.ToString());
			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(), m_asOwner.GetApplication());
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetAccessType(m_intAccessType);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Access Type with value: " +
					m_intAccessType + ". The following exception occured: " +
					e);
			

			throw new XPException(m_asOwner.GetString(912,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetDefaultFirstPageType(m_intDefaultFirstPageType);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Default First Page Type with value: " +
					m_intDefaultFirstPageType +
					". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(914,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			//If it is a directory page, and m_intDefaultFirstPage is 0, set to the Root folder
			if (0 == m_intDefaultFirstPage)
			{
				if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS == m_intDefaultFirstPageType)
				{
					((IPTSubPortal) m_ptObject).SetDefaultFirstPage(m_Session.GetCatalog()
						.GetRootFolder().GetObjectID());
				}
			}
			else
			{
				((IPTSubPortal) m_ptObject).SetDefaultFirstPage(m_intDefaultFirstPage);
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Default First Page with value: " +
					m_intDefaultFirstPage +
					". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(913,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetFooterID(m_intFooterID);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Footer ID with value: " +
					m_intFooterID + ". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(915,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetHeaderID(m_intHeaderID);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Header ID with value: " +
					m_intHeaderID + ". The following exception occured: " + e);
			
			throw new XPException(m_asOwner.GetString(916,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetStyleSheet(m_strStyleSheet);
		}
		catch (Exception e)
		{
			
			log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Style Sheet with value: " +
				m_strStyleSheet + ". The following exception occured: " + e);
			
			throw new XPException(e);
		}

		try
		{
			//Only set the navigation scheme if the user has changed it from the default of zero
			if (0 != m_intNavigationScheme)
				((IPTSubPortal) m_ptObject).SetNavigationScheme(m_intNavigationScheme);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Navigation Scheme with value: " +
					m_intNavigationScheme +
					". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(918,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetRelatedResourcesAccessType(m_intRelatedResourcesAccessTypes);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskBeforeStore Unable to set the Related Resources Access Types with value: " +
					m_intRelatedResourcesAccessTypes +
					". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(919,
					"ptmsgs_portaladminmsgs"), e);
		}

		try
		{
			((IPTSubPortal) m_ptObject).SetLayoutEnabled(m_bLayoutEnabled);
			((IPTSubPortal) m_ptObject).SetLayoutOptions(m_strLayoutOptions);
		}
		catch (Exception e)
		{
			log.Error(e, "SubPortalModel::DoTaskBeforeStore Unable to set the Layout mode with value: " +
				m_bLayoutEnabled);
			throw new XPException(m_asOwner.GetString(3200, ResourceConstants.PORTALADMINMSGS), e);
		}
	}

	/**
	 * Code executed after the object is stored.
	 */
	public void DoTaskAfterStore()
	{
		//Create (or delete) the association with admin folders
		int intFolderID = 0;
		IPTAdminFolder myFolder;
		try
		{
			//Check each item in the list against the initial list in m_htInitFolderValues.  If the key is there, update its value
			//to 1.  Then disassociate all the zeros.

			if ( (null != m_arrFolderIDs) && (m_arrFolderIDs.GetCount() > 0) )
			{
				for (int i = 0; i < m_arrFolderIDs.GetCount(); i++)
				{
					intFolderID = XPConvert.ToInteger(m_arrFolderIDs.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID));
					IPTSubPortal ptscSubPortal = ((IPTSubPortal) m_ptObject);

					int myObjectID = ptscSubPortal.GetObjectID();

					if (myObjectID > 0)
					{
						Object myFolderID = new Integer(intFolderID);
						if ( (null != m_htInitFolderValues) && (m_htInitFolderValues.ContainsKey(myFolderID)) )
						{
							m_htInitFolderValues.PutElement(myFolderID, new Integer(1));
						}

						myFolder = m_Session.GetAdminCatalog().OpenAdminFolder(intFolderID, true);
						myFolder.SetFolderType(myObjectID);
						myFolder.Store();
						myFolder.UnlockObject();
					}
				}
			}
			//Now detach the folders that were not found
			if (null != m_htInitFolderValues)
			{
				IXPEnumerator myEnum = m_htInitFolderValues.GetKeys();
				while (myEnum.MoveNext())
				{
					if (0 == XPConvert.ToInteger(m_htInitFolderValues.GetElement(myEnum.GetCurrent())))
					{
						myFolder = m_Session.GetAdminCatalog().OpenAdminFolder(XPConvert.ToInteger(myEnum.GetCurrent()), true);
						myFolder.SetFolderType(0);
						myFolder.Store();
						myFolder.UnlockObject();
					}
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::DoTaskAfterStore Unable to set the subportal property on the selected folders" +
					". The following exception occured: " + e);
			
			//Raise the error that the folder could not be set
			XPStringBuilder sb = new XPStringBuilder(100);

			sb.Append(m_asOwner.GetString(1896, "ptmsgs_portaladminmsgs")).Append(intFolderID);
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, sb.ToString(),
					sb.ToString());
			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(), m_asOwner.GetApplication());

		}
		
		// WilliamA - Save the associated Guest Login object of this subportal
		if (null == m_ptGuestLogin)
		{
			log.Warn("The guest login object is null for subportal " + m_ptObject.GetName());
		} 
		else if (m_bIsGuestLoginDirty) 
		{
			// only save if any of the guest/login setting is changed			
			try
			{
				// Set the submitted values to the object's properties

				// note: m_nGLGuestUserID will equal to PT_INTRINSICS.PT_NULL_OBJECTID 
				// if the user did not select a new guest user. So in this case, 
				// if m_nGLGuestUserID == PT_INTRINSICS.PT_NULL_OBJECTID
				// don't call SetGuestUserID
					
				if (PT_INTRINSICS.PT_NULL_OBJECTID != m_nGLGuestUserID)				
					m_ptGuestLogin.SetGuestUserID(m_nGLGuestUserID);
					
				m_ptGuestLogin.SetGuestRedirectToLogin(m_bGLGuestRedirectToLogin);
				m_ptGuestLogin.SetRedirectOnLogout(m_bGLRedirectOnLogout);
				m_ptGuestLogin.SetSSOVendor(m_nGLSSOVendor);
				
				// Set the name of the guest login obj to be the same as subportal's
				m_ptGuestLogin.SetName(((IPTSubPortal)m_ptObject).GetName() + LOGIN_SETTINGS_SUFFIX);

				// Shouldn't lock the Object if this is a new one
				if (!m_bNewGuestLogin)
				{
				    m_ptGuestLogin.LockObject();
				}
				
				m_ptGuestLogin.Store();
				// DCA - we're no longer dirty
				m_bIsGuestLoginDirty = false;
			} 
			catch (Exception e)
			{
				log.Error("SubPortalModel::DoTaskAfterStore Unable to save the Guest Login object of the subportal " +
					m_ptObject.GetName() + ". The following exception occured: " + e);
			}
			finally
			{
			    m_ptGuestLogin.UnlockObject();
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()
	 */
	public void Cancel()
	{
		super.Cancel();
		// need to delete the newly created sitemap folder if we cancel out of the editor - otherwise it gets orphaned.
		if (null != m_ptLinksFolder)
		{
            if (m_ptLinksFolder.GetLockState() == PT_LOCKSTATES.PT_NEWLYCREATED) {
                m_bCancelled = true;
                return;
            }
			IPTQueryResult ptqrLinks = m_ptLinksFolder.QueryLinks();
			if (ptqrLinks.RowCount() == 0)
			{
				m_Session.GetSiteMapFolders().Delete(m_ptLinksFolder.GetObjectID());
				//DCA - set mandatory links ID to 0 if it's not
				IPTSubPortal ptSubportal = (IPTSubPortal) m_ptObject;
				if (ptSubportal.GetMandatoryLinksID() != NO_MANDATORY_LINKS) {
				    ptSubportal.SetMandatoryLinksID(NO_MANDATORY_LINKS);
				    ptSubportal.LockObject();
				    try {
				        ptSubportal.Store();
				    } catch (Exception e) {
				        XPStringBuilder sb = new XPStringBuilder(100);
						sb.Append(m_asOwner.GetString(2101, "ptmsgs_portaladminmsgs")).Append(e);

						
							log.Error("SubPortalModel::Cancel " + sb.ToString());
						
						UIError myError = new UIError(UIErrorLevel.SERIOUS,
								UIErrorScope.CURRENT_USER, null, sb.ToString(),
								sb.ToString());
						UIErrorHandler.RaiseError(myError,
							m_asOwner.GetSubSession(), m_asOwner.GetApplication());
				    } finally {
				        ptSubportal.UnlockObject();
				    }
				}
			}
		}
		
		// WilliamA - The newly created GuestLogin object is not saved (stored) 
		// yet, so no need to delete; comment these out: 
		// need to delete the newly created Guest Login object if we cancel out 
		// of the editor (CREATE mode)
		/*
		if (null != m_ptGuestLogin)
		{		
			if (m_bNewGuestLogin)
			{
				IPTServerContext ptsc = (IPTServerContext) m_ptGuestLogin.GetInterfaces("IPTServerContext");
				m_Session.GetGuestLogins().Delete(ptsc.GetObjectID());
			} 
		}
		*/

		// Mark this editor as cancelled so we can't accidentally try to store it
		// after we've cleaned up the site map folders, among other things.
		m_bCancelled = true;
	}

	/**
	 * This method will be called when you come back to the main Editor from a
	 * sub Editor.
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();

		//Retrieve the footer that has been created
		((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).DoTaskOnComeBackFromSubEditor();

		AActivitySpace myFolderSpace = m_asOwner.GetSubSpace(FolderEditorAS.STR_MVC_CLASS_NAME);
		if (null != myFolderSpace)
		{
			
			
			int nHomeFolderID = ((FolderEditorModel)myFolderSpace.GetModel(FolderEditorModel.STR_MVC_CLASS_NAME)).GetObjectID();
			// Check if the user has at least select access to the folder, no way to do this in the tree.
			
			
			
			m_intHomeFolderID = nHomeFolderID; 
			m_strHomeFolderName = ((FolderEditorModel)myFolderSpace.GetModel(FolderEditorModel.STR_MVC_CLASS_NAME)).GetObjectName();
			m_asOwner.DeleteSubSpace(FolderEditorAS.STR_MVC_CLASS_NAME);
			m_bFolderUnclassified = true;
		}

		AActivitySpace myCommSpace = m_asOwner.GetSubSpace(CommunityEditorAS.STR_MVC_CLASS_NAME);
		if (null != myCommSpace)
		{
			m_intHomeCommunityID = ((CommunityEditorModel)myCommSpace.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).GetCommunityID();
			m_strHomeCommunityName = ((CommunityEditorModel)myCommSpace.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).GetObjectName();
			m_asOwner.DeleteSubSpace(CommunityEditorAS.STR_MVC_CLASS_NAME);
		}
	}

	// END ***************** Framework methods *****************

	// BEGIN ***************** Helper Functions *****************

	/**
	 * Return the ASURL object going to the Community Editor as a sub Editor.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor. If we are going to a new
	 *        sub Editor, the key can be null and  we will just pass in the
	 *        default key. If we are going back to an  existing sub Editor, it
	 *        should be the sub Editor key.
	 *
	 * @return ASURL
	 */
	public ASURL GetASURLToCommunity(String _sSubSpaceKey)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = CommunityEditorAS.STR_MVC_CLASS_NAME;
		}

		// JF- The helper method below will return the right URL. We don't need to figure out
		// if it's a cached sub Editor or no.
		ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(CommunityEditorAS.STR_MVC_CLASS_NAME,
				_sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE,
				ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));

		return myPopUpURL;
	}

	/**
	 * Return the ASURL object going to the Folder Editor as a sub Editor.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor. If we are going to a new
	 *        sub Editor, the key can be null and  we will just pass in the
	 *        default key. If we are going back to an  existing sub Editor, it
	 *        should be the sub Editor key.
	 *
	 * @return ASURL
	 */
	public ASURL GetASURLToFolder(String _sSubSpaceKey)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = FolderEditorAS.STR_MVC_CLASS_NAME;
		}

		// JF- The helper method below will return the right URL. We don't need to figure out
		// if it's a cached sub Editor or no.
		ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(FolderEditorAS.STR_MVC_CLASS_NAME,
				_sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE,
				ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));

		return myPopUpURL;
	}

	/**
	 * Return the ASURL object going to the Folder Editor as a sub Editor.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor. If we are going to a new
	 *        sub Editor, the key can be null and  we will just pass in the
	 *        default key. If we are going back to an  existing sub Editor, it
	 *        should be the sub Editor key.
	 *
	 * @return ASURL
	 */
	public ASURL GetASURLToAdminFolder(String _sSubSpaceKey)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = AdminFolderEditorAS.STR_MVC_CLASS_NAME;
		}

		// JF- The helper method below will return the right URL. We don't need to figure out
		// if it's a cached sub Editor or no.
		ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(AdminFolderEditorAS.STR_MVC_CLASS_NAME,
				_sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE,
				ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));

		return myPopUpURL;
	}


	/**
	 * This method gets the selected items from the tree, setting member
	 * variables for ObjectID and name of the object selected.  It is called
	 * on repost.
	 *
	 * @param intObjectType intObjectType - 0 for Community, 1 for Folders
	 */
	public void RefreshItemFromTree(int intObjectType)
	{
		String strSubSpaceID;

		if (0 == intObjectType)
		{
			strSubSpaceID = SubPortalAS.strCOMMTREE_SUBSPACE;
		}
		else
		{
			strSubSpaceID = SubPortalAS.strFOLDERTREE_SUBSPACE;
		}

		if (m_asOwner.GetSubSpaceExists(strSubSpaceID))
		{
			AActivitySpace asTree  = m_asOwner.GetSubSpace(strSubSpaceID);
			ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList itemList   = treeModel.GetSelectedItems();

			if (itemList.GetSize() != 1)
			{
				
					log.Error("Tree selected wrong number of items.  Expecting 1, got " +
						itemList.GetSize());

					UIError myError = new UIError(UIErrorLevel.FRIENDLY,
							UIErrorScope.CURRENT_USER, null, "None Selected",
							"Extended Error Message...");
					UIErrorHandler.RaiseError(myError,
						m_asOwner.GetSubSession(), m_asOwner.GetApplication());
				
			}

			TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

			if (item == null)
			{
				
					log.Error("Tree selected item null");
				
			}

			
			if (0 == intObjectType)
			{
				// The Community tree only shows communities the current user has select access to
				m_intHomeCommunityID	   = item.m_nObjectID;
				m_strHomeCommunityName     = item.GetName();
//				
			}
			else
			{
				if (! GetPTSession().GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID, 
																		item.m_nObjectID, 
																		PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT) 
					)
				{
					String errorMsg = XPResourceManager.FormatMessage(	m_asOwner.GetString(1725, "ptmsgs_portalbrowsingmsgs"), 
																		item.GetName()
																		);
					UIError myError = new UIError(	UIErrorLevel.FRIENDLY, 
													UIErrorScope.CURRENT_USER, 
													null, 
													errorMsg,
													errorMsg);
					UIErrorHandler.RaiseError(	myError,
												m_asOwner.GetSubSession(),
												m_asOwner.GetApplication());																	
				}
				else 
				{
					m_intHomeFolderID	    = item.m_nObjectID;
					m_strHomeFolderName     = item.GetName();
				}
			}
		}
	}

	/**
	 * This method gets the selected guest from the tree, setting member
	 * variables for ObjectID and name of the guest selected.  It is called
	 * on repost.
	 */
	public void RefreshSelectedGuestFromTree()	
	{
		AActivitySpace asGuestTree = (AActivitySpace) m_asOwner.GetSubSpace(LoginSettingsView.GUEST_TREE_SUBSPACE);

		if (asGuestTree != null)
		{
			ITreeModelRO myTree    = (ITreeModelRO) asGuestTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected = myTree.GetSelectedItems();

			for (int i = 0; i < mySelected.GetSize(); i++)
			{
				int tmp = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
				if (tmp != m_nGLGuestUserID)
				{
					m_nGLGuestUserID = tmp;
					m_bIsGuestLoginDirty = true;
				
					// update the m_strGLGuestUserName (used by the read op)
					IPTUser ptGuestUser = (IPTUser)m_Session.GetUsers().Open(m_nGLGuestUserID, false);
					m_strGLGuestUserName = ptGuestUser.GetLoginName();
					
					log.Debug("SubPortalModel::SaveLoginSettingsPage New guest user ID: {0}",
						m_nGLGuestUserID);					
				}
			}
		}
	}
	
	// END ***************** Helper Functions *****************

	// BEGIN ***************** SelectPTObject Initialization Functions *****************

	/**
	 * Helper method to start the Select PTObject List.
	 */
	public void StartSelectPTFolder()
	{
		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER);

		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(1891, "ptmsgs_portaladminmsgs"),
		m_asOwner.GetString(781, "ptmsgs_portaladminmsgs"),
		PTImageType.ICON_FOLDER,
		m_asOwner.GetString(1893, "ptmsgs_portaladminmsgs"),
		new int[] { PT_CLASSIDS.PT_ADMIN_FOLDER_ID }, 4);

		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_FOLDER);

		mySelectPTObjectModel.SetTreeMultiSelect(true);

		mySelectPTObjectModel.SetTreeLeafType(TreeConstants.N_LEAFCOMPOSITESELECT);

		mySelectPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(1897, "ptmsgs_portaladminmsgs"));

		mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(1897, "ptmsgs_portaladminmsgs"));

		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(1894, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(1895, "ptmsgs_portaladminmsgs"));

		//enable object creation
		Object[][] arrCreateNewInfo = new Object[1][SelectPTObjectModel.CREATE_NEW_COL_MAX];
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ASNAME]	    = AdminFolderEditorAS.STR_MVC_CLASS_NAME;
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_LABEL]     = m_asOwner.GetString(1903, "ptmsgs_portaladminmsgs");
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ICON]	  = PTImageType.ICON_FOLDER;

		mySelectPTObjectModel.SetEnableCreateNew(arrCreateNewInfo);

		//Get the folder if we are in edit mode
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			try
			{
				ASQueryResultWrapper ptqrFolders = new ASQueryResultWrapper(((IPTSubPortal) m_ptObject).QueryAdminFolders());

				int intCount = ptqrFolders.GetCount();

				m_htInitFolderValues = new XPHashtable(intCount);

				if (intCount > 0)
				{
					Object[][] oRows = new Object[intCount][SelectPTObjectModel.EXPLIST_COL_MAX];

					//Dictionaries for the names/ids of the operations
					//Get all the possible classes that can be used as operations
					for (int i = 0; i < intCount; i++)
					{
						String strObjName = (String) ptqrFolders.GetFields(i,
								PT_PROPIDS.PT_PROPID_NAME);
						Object oObjID  = ptqrFolders.GetFields(i,
								PT_PROPIDS.PT_PROPID_OBJECTID);

						// Set the class ID
						oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_ADMIN_FOLDER_ID);

						// Set the Object ID
						oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = oObjID;

						// Set the Object name
						oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING] = strObjName;

						//Add the existing values to this hash as keys, with value = 0.  after storage of the subportal object
						//this hashtable will be inspected looking for values that have been removed
						m_htInitFolderValues.PutElement(oObjID, new Integer(0));
					}

					// Then add the array to the list
					mySelectPTObjectModel.SetDefaultObjects(oRows);
				}
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::StartSelectPTObject	An error occurred when trying populate the folder select list.  Exception: " +
						e);
				
			}
		}
	}

	/**
	 * Helper method to start the Select PTObject List.
	 */
	public void StartSelectPTFooter()
	{
		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER);
		int nPortletAlignment					  = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER;

		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(
				926, "ptmsgs_portaladminmsgs"),

		m_asOwner.GetString(927, "ptmsgs_portaladminmsgs"),
			PTImageType.ICON_FOOTER,

		m_asOwner.GetString(928, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_GADGET_ID }, 3);

		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_FOOTER);
		mySelectPTObjectModel.SetTreeMultiSelect(false);
		mySelectPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(1898, "ptmsgs_portaladminmsgs"));
		mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(1898, "ptmsgs_portaladminmsgs"));
		mySelectPTObjectModel.SetTreeQueryFilter(PT_CLASSIDS.PT_GADGET_ID,
			PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT,
			new int[] { nPortletAlignment });

		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(929,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(930, "ptmsgs_portaladminmsgs"));

		//Get the footers if we are in edit mode
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			try
			{
				PTObjectManagerQueryWrapper ptqrFooters = new PTObjectManagerQueryWrapper(m_Session.GetGadgets());
				ptqrFooters.QuerySingleObject(((IPTSubPortal) m_ptObject).GetFooterID());

				int intCount = ptqrFooters.GetCount();

				if (intCount > 0)
				{
					Object[][] oRows = new Object[1][SelectPTObjectModel.EXPLIST_COL_MAX];

					//Dictionaries for the names/ids of the operations
					//Get all the possible classes that can be used as operations
					for (int i = 0; i < intCount; i++)
					{
						String strObjName = (String) ptqrFooters.GetItem(i,
								PT_PROPIDS.PT_PROPID_NAME);
						Object oObjID  = ptqrFooters.GetItem(i,
								PT_PROPIDS.PT_PROPID_OBJECTID);

						// Set the class ID
						oRows[0][SelectPTObjectModel.EXPLIST_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_GADGET_ID);

						// Set the Object ID
						oRows[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = oObjID;

						// Set the Object name
						oRows[0][SelectPTObjectModel.EXPLIST_COL_STRING] = strObjName;
					}

					// Then add the array to the list
					mySelectPTObjectModel.SetDefaultObjects(oRows);
				}
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::StartSelectPTObject	An error occurred when trying populate the Footer select list.  Exception: " +
						e);
				
			}
		}
	}

	/**
	 * Helper method to start the Select PTObject List.
	 */
	public void StartSelectPTHeader()
	{
		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER);
		int nPortletAlignment					  = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER;

		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(
				923, "ptmsgs_portaladminmsgs"),

		m_asOwner.GetString(924, "ptmsgs_portaladminmsgs"),
			PTImageType.ICON_BANNER,

		m_asOwner.GetString(925, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_GADGET_ID }, 2);

		mySelectPTObjectModel.SetTreeQueryFilter(PT_CLASSIDS.PT_GADGET_ID,
			PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT,
			new int[] { nPortletAlignment });
		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_BANNER);
		mySelectPTObjectModel.SetTreeMultiSelect(false);
		mySelectPTObjectModel.SetTreeSubTitle(m_asOwner.GetString(1899, "ptmsgs_portaladminmsgs"));
		mySelectPTObjectModel.SetTreeTitle(m_asOwner.GetString(1899, "ptmsgs_portaladminmsgs"));

		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(931,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(932, "ptmsgs_portaladminmsgs"));

		//Get the header if we are in edit mode
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			try
			{
				PTObjectManagerQueryWrapper ptqrHeaders = new PTObjectManagerQueryWrapper(m_Session.GetGadgets());
				ptqrHeaders.QuerySingleObject(((IPTSubPortal) m_ptObject).GetHeaderID());

				int intCount = ptqrHeaders.GetCount();

				if (intCount > 0)
				{
					Object[][] oRows = new Object[1][SelectPTObjectModel.EXPLIST_COL_MAX];

					//Grab the result and put it into the control
					for (int i = 0; i < intCount; i++)
					{
						String strObjName = (String) ptqrHeaders.GetItem(i,
								PT_PROPIDS.PT_PROPID_NAME);
						Object oObjID  = ptqrHeaders.GetItem(i,
								PT_PROPIDS.PT_PROPID_OBJECTID);

						// Set the class ID
						oRows[0][SelectPTObjectModel.EXPLIST_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_GADGET_ID);

						// Set the Object ID
						oRows[0][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = oObjID;

						// Set the Object name
						oRows[0][SelectPTObjectModel.EXPLIST_COL_STRING] = strObjName;
					}

					// Then add the array to the list
					mySelectPTObjectModel.SetDefaultObjects(oRows);
				}
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::StartSelectPTObject	An error occurred when trying populate the Header select list.  Exception: " +
						e);
				
			}
		}
	}

	/**
	 * Helper method to initialize the plug-in section for navigation link
	 * creation
	 */
	public void InitializeSiteMapPlugIn()
	{
		SiteMapFolderPlugInModel mySiteMapFolderModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		try
		{
			if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
			{
				//First get the folder
				int intLinksFolder = ((IPTSubPortal) m_ptObject).GetMandatoryLinksID();

				if ( intLinksFolder != NO_MANDATORY_LINKS)
				{
					m_ptLinksFolder = (IPTSiteMapFolder) m_Session.GetSiteMapFolders().Open(intLinksFolder, false);
				}
				else
				{
					m_ptLinksFolder = (IPTSiteMapFolder) m_Session.GetSiteMapFolders().Create(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
					m_ptLinksFolder.SetName(m_asOwner.GetString(2530, "ptmsgs_portaladminmsgs"));
					m_ptLinksFolder.SetIsLocalized(true);
					// Fix for #8433320, SiteMapFolderPluginModel not able to open sitemapfolder when the object hasnt been saved
					m_ptLinksFolder.Store();
					m_ptLinksFolder.UnlockObject();
				}

			}
			else
			{
				//Need to create a sitemapfolder object
				m_ptLinksFolder = (IPTSiteMapFolder) m_Session.GetSiteMapFolders().Create(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
				m_ptLinksFolder.SetName(m_asOwner.GetString(2530, "ptmsgs_portaladminmsgs"));
				m_ptLinksFolder.SetIsLocalized(true);
				// Fix for #8433320, SiteMapFolderPluginModel not able to open sitemapfolder when the object hasnt been saved
				m_ptLinksFolder.Store();
				m_ptLinksFolder.UnlockObject();
				
			}
			
			mySiteMapFolderModel.InitializePlugIn(m_ptLinksFolder);
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::InitializeSiteMapPlugIn " + m_asOwner.GetString(2099, "ptmsgs_portaladminmsgs") +
					e);
			

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
				UIErrorScope.CURRENT_USER, null,m_asOwner.GetString(2099, "ptmsgs_portaladminmsgs"), "");
			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

	}

	/**
	 * Helper method to initialize the plug-in section for Login Settings
	 * (the Guest Login object of this subportal)
	 */
	public void InitializeGuestLoginPlugIn()
	{
		try 
		{
		    IPTSubPortal ptscSubPortal = (IPTSubPortal) m_ptObject;

			int nSubPortalID = ptscSubPortal.GetObjectID();
						
			IPTObjectManager ptObjMgr = m_Session.GetGuestLogins();
			IPTGuestLoginManager ptGuestLoginMgr = (IPTGuestLoginManager)ptObjMgr;

			if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
			{
				m_ptGuestLogin = null;
			} else
			{
				m_ptGuestLogin = (IPTGuestLogin)ptGuestLoginMgr.OpenBySubPortalID(nSubPortalID, false);				
			}

			// if this subportal has no associated guest login object yet
			// (happens on CREATE mode, and sometimes on EDIT mode for subportals that don't
			// have explicit guest-login assignment yet (e.g., in upgrade scenario);
			// these subportals, by default, use the login settings from x_config.xml and 
			// PTConfig.xml, and have no associated guest login object at install/upgrade time). 			
			if (null == m_ptGuestLogin)
			{
				m_ptGuestLogin = (IPTGuestLogin)ptObjMgr.Create(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
				m_ptGuestLogin.SetSubPortalID(nSubPortalID);
				m_bNewGuestLogin = true;
				
				// set properties of Guest Login to default values
				m_ptGuestLogin.SetGuestUserID(PT_INTRINSICS.PT_USER_GUEST);
				m_ptGuestLogin.SetGuestRedirectToLogin(true);
				m_ptGuestLogin.SetRedirectOnLogout(true);
				m_ptGuestLogin.SetSSOVendor(GetDefaultSSOVendor());				
			}
			else
			{
				m_bNewGuestLogin = false;
			}
		} catch (Exception e)
		{
			log.Error(e, "SubPortalModel::InitializeGuestLoginPlugIn encountered an error.");
		}
		
		// WilliamA - Populate member variables for the Login Settings page
		if (null == m_ptGuestLogin)
		{
			log.Error("The guest login object is null for subportal " + m_ptObject.GetName());
		}		
		else
		{
			try 
			{
				m_strGLGuestUserName = m_ptGuestLogin.GetGuestUserName();			
				m_bGLGuestRedirectToLogin = m_ptGuestLogin.GetGuestRedirectToLogin();
				m_bGLRedirectOnLogout = m_ptGuestLogin.GetRedirectOnLogout();
				m_nGLSSOVendor = m_ptGuestLogin.GetSSOVendor();
				
				m_bIsGuestLoginDirty = false;
			}
			catch (Exception e)
			{
				log.Error("SubPortalModel::DoTaskOnStartEditor Unable to get the guest login properties. The following exception occured: " +
						e);		

				throw new XPException(m_asOwner.GetString(2821,
						"ptmsgs_portaladminmsgs"), e);
			}
		}			
	}
	
	// END ***************** SelectPTObject Initialization Functions *****************

	// BEGIN ***************** save DP methods *****************

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(SubPortalFeaturesDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = SaveFeaturesPage(_htFormData);
		}
		else if (_sPageName.equals(SubPortalBannerDP.STR_MVC_CLASS_NAME))
		{
			SaveBannerPage(_htFormData);
		}
		else if (_sPageName.equals(SubPortalNavDP.STR_MVC_CLASS_NAME))
		{
			SaveNavPage(_htFormData);
		} 
		else if (_sPageName.equals(SubPortalLoginDP.STR_MVC_CLASS_NAME))
		{
			SaveLoginSettingsPage(_htFormData);
		}
		else if (_sPageName.equals(SubPortalLayoutDP.STR_MVC_CLASS_NAME))
		{
			SaveLayoutSettingsPage(_htFormData);
		}

		return nPageStatus;
	}

	/**
	 * Saves the data on the SubPortal Features page.
	 *
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	protected int SaveFeaturesPage(XPHashtable _htFormData)
	{
		String[] data;

		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		//m_arrFolderIDs
		try
		{
			//Save the Data in the tree
			((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).SaveSection(_htFormData);

			m_arrFolderIDs = ((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).GetItems();
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::RefreshMandatoryLinksID	An error occurred when trying to save the Folder ID.  Exception: " +
					e);
			
		}
		
		try
		{
			m_intAccessType     = 0; //reset this to zero before saving it again
			data			    = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_MYPAGES);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intAccessType = XPConvert.ToInteger(data[0]);
			}

			data = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_COMMUNITIES);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intAccessType += XPConvert.ToInteger(data[0]);
			}

			data = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_DIRECTORY);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intAccessType += XPConvert.ToInteger(data[0]);
			}

			
				log.Debug("SubPortalModel::SaveFeaturesPage New Access Type: " +
					m_intAccessType);
			
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::SaveFeaturesPage An error occured when trying to save the Access Type. Exception: " +
					e);
			
		}

		if (0 == m_intAccessType)
		{
			
				log.Warn("SubPortalModel::SaveFeaturesPage No Access Types specified.");
			
		}

		//m_intDefaultFirstPageType
		data = (String[]) _htFormData.GetElement(FeaturesView.HTMLRADIO_FIRSTPAGETYPE);

		if ((null != data) && !(data[0].equals("")))
		{
			try
			{
				int intType = XPConvert.ToInteger(data[0]);

				if (intType == PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS)
				{
					m_intDefaultFirstPageType = intType;
					// DCA - if m_intAccessType was not set (probably because the nave type is null)
					// set it as just the m_intDefaultFirstPageType
					if (0 == m_intAccessType)
					{
						m_intAccessType = intType;
					}
				}
				else if (intType == PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS)
				{
					m_intDefaultFirstPageType = intType;
					// DCA - if m_intAccessType was not set (probably because the nave type is null)
					// set it as just the m_intDefaultFirstPageType
					if (0 == m_intAccessType)
					{
						m_intAccessType = intType;
					}
				}
				else if (intType == PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS)
				{
					m_intDefaultFirstPageType = intType;
					// DCA - if m_intAccessType was not set (probably because the nave type is null)
					// set it as just the m_intDefaultFirstPageType
					if (0 == m_intAccessType)
					{
						m_intAccessType = intType;
					}
				}
				else //an invalid value
				{
					m_intDefaultFirstPageType = 0;
				}

				
					log.Debug("SubPortalModel::SaveFeaturesPage New Default First Page: " +
						m_intDefaultFirstPageType);
				
			}
			catch (Exception e)
			{
				
					log.Error("SubPortalModel::SaveFeaturesPage	An error occurred when trying to save the Default First Page.  Exception: " +
						e);
				
			}
		}

		//m_intDefaultFirstPage
		try
		{
			if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS &
					m_intAccessType) != 0)
			{
				if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS == m_intDefaultFirstPageType)
				{
					data = (String[]) _htFormData.GetElement(FeaturesView.HTMLHIDDEN_COMMUNITYID);
					
//						if (! GetPTSession().GetCommunities().IsObjectAccessible(PT_CLASSIDS.PT_COMMUNITY_ID,
//																				 XPConvert.ToInteger(data[0]),
//																				 PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT) 
//							)
//						{
//							UIError myError = new UIError(	UIErrorLevel.FRIENDLY, 
//															UIErrorScope.CURRENT_USER, 
//															null, 
//															"You do not have sufficient access to use the chosen Community as a default Community.",
//															"You need at least SELECT access to a directory folder to select it as the default Community.");
//							UIErrorHandler.RaiseError(	myError,
//														m_asOwner.GetSubSession(),
//														m_asOwner.GetApplication());																																
//						}
				}
			}

			if ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS &
					m_intAccessType) != 0)
			{
				if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS == m_intDefaultFirstPageType)
				{
					data = (String[]) _htFormData.GetElement(FeaturesView.HTMLHIDDEN_FOLDERID);
					
//						if (! GetPTSession().GetCatalog().IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID, 
//																		XPConvert.ToInteger(data[0]), 
//																		PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT) 
//							)
//						{
//							UIError myError = new UIError(	UIErrorLevel.FRIENDLY, 
//															UIErrorScope.CURRENT_USER, 
//															null, 
//															"You do not have sufficient access to use the chosen Directory folder as a default folder.",
//															"You need at least SELECT access to a directory folder to select it as the default folder.");
//							UIErrorHandler.RaiseError(	myError,
//														m_asOwner.GetSubSession(),
//														m_asOwner.GetApplication());																	
//						}
				}
			}

			if (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS != m_intDefaultFirstPageType)
			{
				if ((null != data) && !(data[0].equals("")) &&
						!(data[0].equals("0")))
				{
					m_intDefaultFirstPage = XPConvert.ToInteger(data[0]);

					
						log.Debug("SubPortalModel::SaveFeaturesPage New Default First Page Type: " +
							m_intDefaultFirstPage);
					
				}
				else
				{
					if (m_intDefaultFirstPageType == 0) //Nothing selected
					{
						nPageStatus = RepostControl.PAGE_STATUS_INVALID;

						UIError myError = new UIError(UIErrorLevel.FRIENDLY,

							UIErrorScope.CURRENT_USER, null,
								m_asOwner.GetString(937,
									"ptmsgs_portaladminmsgs"),

							m_asOwner.GetString(937, "ptmsgs_portaladminmsgs"));
						UIErrorHandler.RaiseError(myError,
							m_asOwner.GetSubSession(),
							m_asOwner.GetApplication());
					}

					if (m_intDefaultFirstPageType == PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS) //If you choose Communities or Directory, you need to have also chosen a default
					{
						nPageStatus = RepostControl.PAGE_STATUS_INVALID;

						UIError myError = new UIError(UIErrorLevel.FRIENDLY,

							UIErrorScope.CURRENT_USER, null,
								m_asOwner.GetString(935,
									"ptmsgs_portaladminmsgs"),

							m_asOwner.GetString(936, "ptmsgs_portaladminmsgs"));
						UIErrorHandler.RaiseError(myError,
							m_asOwner.GetSubSession(),
							m_asOwner.GetApplication());
					}

					if (m_intDefaultFirstPageType == PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS)
					{
						m_intDefaultFirstPage     = m_Session.GetCatalog()
							.GetRootFolder().GetObjectID(); //Root folder
						m_intHomeFolderID		  = m_intDefaultFirstPage;
						m_strHomeFolderName		  = m_Session.GetCatalog()
							.GetRootFolder().GetLocalizedName();
					}
				}
			}
			else //the default first page type is mypages, so set the default first page to zero
			{
				m_intDefaultFirstPage = 0;
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::SaveFeaturesPage	An error occurred when trying to save the Default First Page Type.  Exception: " +
					e);
			
		}

		//m_intRelatedResourcesAccessTypes
		try
		{
			m_intRelatedResourcesAccessTypes     = 0; //set to default before resetting
			data								 = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_RELCOMM);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intRelatedResourcesAccessTypes = XPConvert.ToInteger(data[0]);
			}
			else
			{
				m_intRelatedResourcesAccessTypes = 0;
			}

			data = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_RELFOLDERS);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intRelatedResourcesAccessTypes += XPConvert.ToInteger(data[0]);
			}

			data = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_RELPORTLETS);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intRelatedResourcesAccessTypes += XPConvert.ToInteger(data[0]);
			}

			data = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_RELEXPERTS);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intRelatedResourcesAccessTypes += XPConvert.ToInteger(data[0]);
			}

			data = (String[]) _htFormData.GetElement(FeaturesView.HTMLCHECKBOX_RELCONTENTMGRS);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intRelatedResourcesAccessTypes += XPConvert.ToInteger(data[0]);
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::SaveFeaturesPage	An error occurred when trying to save the Related Resources.  Exception: " +
					e);
			
		}

		return nPageStatus;
	}


	/**
	 * Saves the data on the Choose Header & Footer page.
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveBannerPage(XPHashtable _htFormData)
	{
		int nPageStatus					    = RepostControl.PAGE_STATUS_VALID;
		PTGrowableSortedArrayWrapper arrIDs;

		//m_intHeaderID
		try
		{
			arrIDs = ((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER)).GetItems();

			if (0 != arrIDs.GetCount())
			{
				m_intHeaderID = XPConvert.ToInteger(arrIDs.GetItem(0,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID));

				
					log.Debug("SubPortalModel::RefreshHeaderFooter New header: " +
						m_intHeaderID);
				
			}
			else
			{
				//No header
				m_intHeaderID = 0;
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::RefreshHeaderFooter	An error occurred when trying to save the Header.  Exception: " +
					e);
			
		}

		//m_intFooterID
		try
		{
			arrIDs = ((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER)).GetItems();

			if (0 != arrIDs.GetCount())
			{
				m_intFooterID = XPConvert.ToInteger(arrIDs.GetItem(0,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID));

				
					log.Debug("SubPortalModel::RefreshHeaderFooter New Header ID: " +
						m_intHeaderID);
					log.Debug("SubPortalModel::RefreshHeaderFooter New Footer ID: " +
						m_intFooterID);
				
			}
			else
			{
				m_intFooterID = 0;
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::RefreshHeaderFooter	An error occurred when trying to save the Footer.  Exception: " +
					e);
			
		}

		//m_strStyleSheet
		try
		{
			String[] data = (String[])_htFormData.GetElement(StylesheetView.HTMLSELECT_STYLESHEET);
			if (data.length > 0)
			{
				m_strStyleSheet = data[0];
				
				// Set to null if its empty string ("Use Portal Style" option will
				// have an empty string as its value when the HTML form is submitted)
				if ("".equals(m_strStyleSheet))
					m_strStyleSheet = null;
			}			
		}
		catch (Exception e)
		{			
			log.Error("SubPortalModel::SaveBannerPage	An error occurred when trying to save the Stylesheet.  Exception: " +
					e);			
		}
				
		((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER)).SaveSection(_htFormData);

		((SelectPTObjectModel) m_asOwner.GetModel(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER)).SaveSection(_htFormData);

		return nPageStatus;
	}



	/**
	 * Saves the data on the Choose Navigation Design page.
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveNavPage(XPHashtable _htFormData)
	{
		String[] data;
		int nPageStatus					    = RepostControl.PAGE_STATUS_VALID;

		//m_intNavigationScheme
		try
		{
			data = (String[]) _htFormData.GetElement(NavigationView.HTMLRADIO_NAVIGATION);

			if ((null != data) && !(data[0].equals("")))
			{
				m_intNavigationScheme = XPConvert.ToInteger(data[0]);

				
					log.Debug("SubPortalModel::SaveNavPage New Navigation Scheme: " +
						m_intNavigationScheme);
				
			}
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::SaveNavPage	An error occurred when trying to save the Navigation Scheme.  Exception: " +
					e);
			
		}

		//m_arrMandatoryLinks
		try
		{
			((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);

			m_ptLinksFolder = ((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME)).GetPTObject();
		}
		catch (Exception e)
		{
			
				log.Error("SubPortalModel::SaveNavPage " + m_asOwner.GetString(2100, "ptmsgs_portaladminmsgs") +
					e);
			
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null,
					m_asOwner.GetString(2100, "ptmsgs_portaladminmsgs") + e,"");

			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());

			nPageStatus = RepostControl.PAGE_STATUS_INVALID;
		}

		return nPageStatus;
	}

	/**
	 * Saves the data on the Login Settings page.
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveLoginSettingsPage(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		//m_nGLGuestUserID
		try
		{
			String[] data = (String[])_htFormData.GetElement(LoginSettingsView.HTMLHIDDEN_SELECTED_GUEST);
			if (null != data && data.length > 0)
			{
				String str = data[0];
				
				if ((null != str) && (!"".equals(str)))
				{
					int tmp = XPConvert.ToInteger(str);
					// note: tmp will equal to PT_INTRINSICS.PT_NULL_OBJECTID if the user did not select
					// a new guest user. So in this case, if tmp == PT_INTRINSICS.PT_NULL_OBJECTID
					// we keep our current value of m_nGLGuestUserID
					
					if ((PT_INTRINSICS.PT_NULL_OBJECTID != tmp) && 
						(tmp != m_nGLGuestUserID))
					{						
						m_nGLGuestUserID = tmp;
						m_bIsGuestLoginDirty = true;
						
						// update the m_strGLGuestUserName (used by the read op)
						IPTUser ptGuestUser = (IPTUser)m_Session.GetUsers().Open(m_nGLGuestUserID, false);
						m_strGLGuestUserName = ptGuestUser.GetLoginName();
					}					
					log.Debug("SubPortalModel::SaveLoginSettingsPage New guest user ID: {0}",
						m_nGLGuestUserID);
				}					
			}			
		}
		catch (Exception e)
		{			
			log.Error("SubPortalModel::SaveLoginSettingsPage	An error occurred when trying to save the guest user ID.  Exception: " +
					e);			
		}

		//m_bGLGuestRedirectToLogin
		try
		{
			String[] data = (String[])_htFormData.GetElement(LoginSettingsView.HTMLRADIO_LOGIN);
			if (null != data && data.length > 0)
			{
				String str = data[0];
				
				if ((null != str) && (!"".equals(str)))
				{
					boolean tmp = XPConvert.ToBoolean(str);
					if (tmp != m_bGLGuestRedirectToLogin) 
					{
						m_bGLGuestRedirectToLogin = tmp;
						m_bIsGuestLoginDirty = true;
						log.Debug("SubPortalModel::SaveLoginSettingsPage New guest redirect to login: {0}",
							m_bGLGuestRedirectToLogin);						
					}
				}					
			}			
		}
		catch (Exception e)
		{			
			log.Error("SubPortalModel::SaveLoginSettingsPage	An error occurred when trying to save the guest redirect to login setting.  Exception: " +
					e);			
		}

		//m_bGLRedirectOnLogout
		try
		{
			String[] data = (String[])_htFormData.GetElement(LoginSettingsView.HTMLRADIO_LOGOUT);
			if (null != data && data.length > 0)
			{
				String str = data[0];
				
				if ((null != str) && (!"".equals(str)))
				{
					boolean tmp = XPConvert.ToBoolean(str);
					if (tmp != m_bGLRedirectOnLogout)
					{
						m_bGLRedirectOnLogout  = tmp;
						m_bIsGuestLoginDirty = true;
						log.Debug("SubPortalModel::SaveLoginSettingsPage New guest redirect to login: {0}",
							m_bGLRedirectOnLogout);
					}
				}					
			}			
		}
		catch (Exception e)
		{			
			log.Error("SubPortalModel::SaveLoginSettingsPage	An error occurred when trying to save the redirect on logout setting.  Exception: " +
					e);			
		}

		//m_nGLSSOVendor
		try
		{
			// if global SSO setting in the config file is not zero (SSO enabled)
			// check the "Disable SSO" checkbox; otherwise no need to check since
			// the checkbox is disabled.
			if (0 != GetDefaultSSOVendor()) 
			{
				// Check "Disable SSO" checkbox 
				String[] data = (String[])_htFormData.GetElement(LoginSettingsView.HTMLCHECKBOX_SSO);
				if ((null != data) && (data.length > 0))
				{
					// if data is NOT null, that means the checkbox is checked (i.e., SSO is disabled)
					String str = data[0];
				
					if ((null != str) && (!"".equals(str)))
					{
						// str can only contain "0" actually
						int tmp = XPConvert.ToInteger(str);
						if (tmp != m_nGLSSOVendor)
						{
							m_nGLSSOVendor = tmp;
							m_bIsGuestLoginDirty = true;
							log.Debug("SubPortalModel::SaveLoginSettingsPage New SSO Vendor: {0}",
								m_nGLSSOVendor);							
						}						
					} 
				} 
				else
				{
					// if data is null, that means the "Disable SSO" checkbox is NOT checked
					// hence, SSO is enabled.
					// if current value of m_nGLSSOVendor is 0, we need to change that to
					// non-zero. 
					if (m_nGLSSOVendor == 0)
					{
						m_nGLSSOVendor = 1;
						m_bIsGuestLoginDirty = true;
					}
				}
			}
				
			// WilliamA - SSOVendor selection feature is disabled for Martok
			// only "Disable SSO" checkbox is available
			/*
			String[] data = (String[])_htFormData.GetElement(LoginSettingsView.HTMLRADIO_SSOVENDOR);
			if (data.length > 0)
			{
				String str = data[0];
				
				if ((null != str) && (!"".equals(str)))
				{
					m_nGLSSOVendor = XPConvert.ToInteger(str);
					
					log.Debug("SubPortalModel::SaveLoginSettingsPage New SSO Vendor: {0}",
						m_nGLSSOVendor);
				}					
			}
			*/			
		}
		catch (Exception e)
		{			
			log.Error("SubPortalModel::SaveLoginSettingsPage	An error occurred when trying to save the SSO Vendor.  Exception: " +
					e);			
		}

		// set m_strGuestTreeSubSpaceID if found in _htFormData
		try 
		{
			String[] data = (String[]) _htFormData.GetElement(LoginSettingsView.HTMLHIDDEN_GUEST_TREE_SUBSPACEID);

			if (data != null)
			{
				SetGuestTreeSubSpaceID(data[0]);
			}
			
		}
		catch (Exception e)
		{			
			log.Error("SubPortalModel::SaveLoginSettingsPage	An error occurred when trying to save the SSO Vendor.  Exception: " +
					e);			
		}
		
		return nPageStatus;
	}

	/**
	 * Saves the data on the Adaptive Layout Settings page.
	 *
	 * @param _htFormData
	 *
	 * @return
	 */
	protected int SaveLayoutSettingsPage(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		// m_bLayoutEnabled
		try
		{
			// if layouts are enabled globally in the config file, check the
			// "Enable Layouts" checkbox; otherwise no need to check since
			// the checkbox is disabled.
			if (LayoutService.getChooserInstance().GetPageLayoutsEnabled(m_asOwner)) 
			{
				// Check "Enable Adaptive Layout" checkbox 
				String[] data = (String[])_htFormData.GetElement(LayoutView.HTMLCHECKBOX_LAYOUTS);
				
				
				if ((null != data) && (data.length > 0))
				{
					// if data is NOT null, that means the checkbox is checked (i.e., Layouts are enabled)
					String str = data[0];
				
					if ((null != str) && (!"".equals(str)))
					{
						// str can only contain "1" actually
						int tmp = XPConvert.ToInteger(str);

						m_bLayoutEnabled = (tmp == 1);
					}
					// Array of Options set in the Layout Chooser.
					String[] options = (String[]) _htFormData.GetElement(LayoutView.HTMLSELECT_LAYOUTS);

					// Constructing concatenated string with proper delimiters.
					m_strLayoutOptions = "";
					for(int i = 0; i < options.length ; i++)
					{
						m_strLayoutOptions += (i != 0 ? "," : "")  + options[i];
					}
					
				} 
				else
				{
					// if data is null, that means the "Enable Layouts" checkbox is NOT checked
					// hence, layouts are disabled.
					m_bLayoutEnabled = false;
				}
			}
		}
		catch (Exception e)
		{			
			log.Error(e, "SubPortalModel::SaveLayoutSettingsPage	An error occurred when trying to save the Layout Settings.");			
		}
		
		return nPageStatus;
	}

	// END ***************** save DP methods *****************

	// BEGIN ***************** Get and Set methods *****************

	/**
	 * Sets the The type of subportal access (MyPages, Communities, Knowledge
	 * Directory) supported by this subportal.  Valid values are any mask
	 * combination of PT_SUBPORTAL_ACCESSTYPES Defaults to communities
	 *
	 * @param _intAccessType
	 */
	public void SetAccessType(int _intAccessType)
	{
		switch (_intAccessType)
		{
		case (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS):
		case (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS):
		case (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS):
			m_intAccessType = _intAccessType;

			
				log.Debug("SubPortalModel::SetAccessType succeeded.  New value: " +
					_intAccessType);
			

			break;

		default:
			m_intAccessType = PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS +
				PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS +
				PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS;

			
				log.Warn("SubPortalModel::SetAccessType failed, Default used instead.  Received invalid AccessType: " +
					_intAccessType);
			
		}
	}

	/**
	 * Returns the subspace ID used by the Community tree control.  This is
	 * used to ensure that trees that already exist in memory are reused
	 * instead of recreated.
	 * @param _strCommSubSpaceID
	 */
	public void SetCommSubSpaceID(String _strCommSubSpaceID)
	{
		m_strCommSubSpaceID = _strCommSubSpaceID;

		
			log.Debug("SubPortalModel::SetCommSubSpaceID succeeded.  New value: " +
				_strCommSubSpaceID);
		
	}

	/**
	 * Sets the default object ID based on the page type specified.  If the
	 * page type is  PT_SUBPORTAL_COMMUNITIES_ACCESS, then the first page ID
	 * will be the Community ID that  is set to appear as default.  An
	 * analogous result will occur with Directory.  In the case MyPages, this
	 * function will throw an error, because the Users will aldways be
	 * referred to their main MyPage
	 *
	 * @param _intDefaultFirstPage
	 */
	public void SetDefaultFirstPage(int _intDefaultFirstPage)
	{
		m_intDefaultFirstPage = _intDefaultFirstPage;

		
			log.Debug("SubPortalModel::SetDefaultFirstPage succeeded.  New value: " +
				_intDefaultFirstPage);
		
	}

	/**
	 * Sets which page the users will see upon logging in to the subportal: a
	 * MyPage, a Community, or a Directory page.  Valid values are enumerated
	 * in PT_SUBPORTAL_ACCESS_TYPES.
	 *
	 * @param _intDefaultFirstPageType
	 */
	public void SetDefaultFirstPageType(int _intDefaultFirstPageType)
	{
		switch (_intDefaultFirstPageType)
		{
		case (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS):
		case (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS):
		case (PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS):
			m_intDefaultFirstPageType = _intDefaultFirstPageType;

			
				log.Debug("SubPortalModel::SetDefaultFirstPageType succeeded.  New value: " +
					_intDefaultFirstPageType);
			

			break;

		default:
			m_intDefaultFirstPageType = PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS;

			
				log.Warn("SubPortalModel::SetDefaultFirstPageType failed, Communities used instead.  Received invalid AccessType: " +
					_intDefaultFirstPageType);
			
		}
	}

	/**
	 * Returns the subspace ID used by the Folder tree control.  This is used
	 * to ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 * @param _strFolderSubSpaceID
	 */
	public void SetFolderSubSpaceID(String _strFolderSubSpaceID)
	{
		m_strFolderSubSpaceID = _strFolderSubSpaceID;

		
			log.Debug("SubPortalModel::SetFolderSubSpaceID succeeded.  New value: " +
				_strFolderSubSpaceID);
		
	}

	/**
	 * Sets the Footer ID.  If the specified Footer ID doesn't exist, the UI
	 * will revert to the default banner, which cannot be deleted.
	 *
	 * @param _intFooterID
	 */
	public void SetFooterID(int _intFooterID)
	{
		m_intFooterID = _intFooterID;

		
			log.Debug("SubPortalModel::SetFooterID succeeded.  New value: " +
				_intFooterID);
		
	}

	/**
	 * Sets the header ID.  If the specified Header ID doesn't exist, the UI
	 * will revert to the default banner, which cannot be deleted.
	 *
	 * @param _intHeaderID
	 */
	public void SetHeaderID(int _intHeaderID)
	{
		m_intHeaderID = _intHeaderID;

		
			log.Debug("SubPortalModel::SetHeaderID succeeded.  New value: " +
				_intHeaderID);
		
	}

	/**
	 * Sets the Navigation scheme for the subportal.  Valid values are
	 * enumerated in  NavTypes.xml.
	 *
	 * @param _intNavigationScheme
	 */
	public void SetNavigationScheme(int _intNavigationScheme)
	{
		m_intNavigationScheme = _intNavigationScheme;

		
			log.Debug("SubPortalModel::SetNavigationScheme succeeded.  New value: " +
				_intNavigationScheme);
		
	}

	/**
	 * Sets what related resources are accessible to users of this subportal.
	 * The value is any mask combination of PT_RELATED_RESOURCES_ACCESS_TYPES.
	 *
	 * @param _intRelatedResourcesAccessTypes
	 */
	public void SetRelatedResourcesAccessTypes(
		int _intRelatedResourcesAccessTypes)
	{
		switch (_intRelatedResourcesAccessTypes)
		{
		case (PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_COMMUNITIES_ACCESS):
		case (PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_CONTENTMANAGERS_ACCESS):
		case (PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_EXPERTS_ACCESS):
		case (PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_FOLDERS_ACCESS):
		case (PT_RELATED_RESOURCES_ACCESS_TYPES.PT_RELATED_RESOURCES_PORTLETS_ACCESS):
			m_intRelatedResourcesAccessTypes = _intRelatedResourcesAccessTypes;

			
				log.Debug("SubPortalModel::SetRelatedResourcesAccessTypes succeeded.  New value: " +
					_intRelatedResourcesAccessTypes);
			

			break;

		default:

			
				log.Error("SubPortalModel::SetRelatedResourcesAccessTypes failed.  Received invalid value: " +
					_intRelatedResourcesAccessTypes);
			
		}
	}

	/**
	 * Sets whether or not adaptive layouts are enabled for this subportal.
	 *
	 * @param _bLayoutEnabled whether or not layouts are enabled.
	 */
	public void SetLayoutEnabled(boolean _bLayoutEnabled)
	{
		m_bLayoutEnabled = _bLayoutEnabled;
	}

	/**
	 * Sets the home Community Error.
	 *
	 * @param _bHomeCommunityError The boolean to set Home Community Error to.
	 */
	public void SetHomeCommunityError(boolean _bHomeCommunityError)
	{
		m_bHomeCommunityError = _bHomeCommunityError;
	}
	
	
	/**
	 * @return the m_strLayoutOptions
	 */
	public String GetLayoutOptions() {
		return m_strLayoutOptions;
	}

	/**
	 * @param _strOptions the m_strLayoutOptions to set
	 */
	public void SetLayoutOptions(String _strOptions) {
		m_strLayoutOptions = _strOptions;
	}

	/**
	 * Returns whether there was an error initializing the Home Community.
	 *
	 * @return boolean
	 */
	public boolean GetHomeCommunityError()
	{
		return m_bHomeCommunityError;
	}


	/**
	 * Returns the home Community ID.
	 *
	 * @return int
	 */
	public int GetHomeCommunityID()
	{
		return m_intHomeCommunityID;
	}

	/**
	 * Sets the home Community ID.
	 *
	 * @param homeCommunityID The home Community ID to set
	 */
	public void SetHomeCommunityID(int homeCommunityID)
	{
		m_intHomeCommunityID = homeCommunityID;
	}

	/**
	 * Sets the home Community Name.
	 *
	 * @param homeCommunityName The home Community Name to set
	 */
	public void SetHomeCommunityName(String homeCommunityName)
	{
		m_strHomeCommunityName = homeCommunityName;
	}

	/**
	 * Returns the home Community Name.
	 *
	 * @return String
	 */
	public String GetHomeCommunityName()
	{
		return m_strHomeCommunityName;
	}

	/**
	 * Sets the home Folder ID.
	 *
	 * @param homeFolderID The homeFolderID to set
	 */
	public void SetHomeFolderID(int homeFolderID)
	{
		m_intHomeFolderID = homeFolderID;
	}

	/**
	 * Returns the home Folder ID.
	 *
	 * @return int
	 */
	public int GetHomeFolderID()
	{
		return m_intHomeFolderID;
	}

	/**
	 * Sets the home Folder Name.
	 *
	 * @param homeFolderName The home Folder Name to set
	 */
	public void SetHomeFolderName(String homeFolderName)
	{
		m_strHomeFolderName = homeFolderName;
	}

	/**
	 * Returns the home Folder Name.
	 *
	 * @return String
	 */
	public String GetHomeFolderName()
	{
		return m_strHomeFolderName;
	}

	/**
	 * Returns the The type of subportal access (MyPages, Communities,
	 * Knowledge Directory) supported by this subportal.  Valid values are any
	 * mask combination of PT_SUBPORTAL_ACCESSTYPES Defaults to communities
	 *
	 * @return int
	 */
	public int GetAccessType()
	{
		return m_intAccessType;
	}

	/**
	 * Returns the subspace ID used by the Community tree control.  This is
	 * used to ensure that trees that already exist in memory are reused
	 * instead of recreated.
	 *
	 * @return String
	 */
	public String GetCommSubSpaceID()
	{
		return m_strCommSubSpaceID;
	}

	/**
	 * Returns the default object ID based on the page type specified.  If the
	 * page type is  PT_SUBPORTAL_COMMUNITIES_ACCESS, then the first page ID
	 * will be the Community ID that  is set to appear as default.  An
	 * analogous result will occur with Directory.  In the case MyPages, this
	 * function will throw an error, because the Users will always be
	 * referred to their main MyPage
	 *
	 * @return int
	 */
	public int GetDefaultFirstPage()
	{
		return m_intDefaultFirstPage;
	}

	/**
	 * Returns which page the users will see upon logging in to the subportal:
	 * a MyPage, a Community, or a Directory page.  Valid values are
	 * enumerated in PT_SUBPORTAL_ACCESS_TYPES.
	 *
	 * @return int
	 */
	public int GetDefaultFirstPageType()
	{
		return m_intDefaultFirstPageType;
	}

	/**
	 * Returns the subspace ID used by the Folder tree control.  This is used
	 * to ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 *
	 * @return String
	 */
	public String GetFolderSubSpaceID()
	{
		return m_strFolderSubSpaceID;
	}

	/**
	 * Returns the Footer ID.  If the specified Footer ID doesn't exist, the UI
	 * will revert to the default banner, which cannot be deleted.
	 *
	 * @return int
	 */
	public int GetFooterID()
	{
		return m_intFooterID;
	}

	/**
	 * Returns the header ID.  If the specified Header ID doesn't exist, the UI
	 * will revert to the default banner, which cannot be deleted.
	 *
	 * @return int
	 */
	public int GetHeaderID()
	{
		return m_intHeaderID;
	}

	/**
	 * Returns the Stylesheet name.
	 *
	 * @return String
	 */
	public String GetStyleSheet() {
		return m_strStyleSheet;
	}

	/**
	 * Returns the available Stylesheet names.
	 *
	 * @return IXPDictionary
	 */
	public IXPDictionary GetStyleSheetOptions() {
		return m_styleSheets;
	}

	/**
	 * Returns true if the subportal has a PTGuestLogin associated to it, 
	 * or false otherwise.
	 * 
	 * @return boolean
	 */
	public boolean GetIsNewGuestLogin() {
		return (m_bNewGuestLogin && !m_bIsGuestLoginDirty);
	}
	
	/**
	 * Returns the Guest Login name.
	 *
	 * @return String
	 */
	public String GetGuestUserName() 
	{
		return m_strGLGuestUserName;
	}

	/**
	 * Returns the Guest User ID.
	 *
	 * @return int
	 */
	public int GetGuestUserID()
	{
		return m_nGLGuestUserID;
	}
	
	/**
	 * Returns the subspace ID used by the guest tree.  This is used to ensure
	 * that trees that already exist in memory are reused instead of recreated.
	 *
	 * @return String
	 */
	public String GetGuestTreeSubSpaceID() {
		return m_strGuestTreeSubSpaceID;
	}

	/**
	 * Sets the subspace ID used by the guest tree.  This is used to ensure
	 * that trees that already exist in memory are reused instead of recreated.
	 *
	 * @return String
	 */
	public void SetGuestTreeSubSpaceID(String subspaceID) {
		m_strGuestTreeSubSpaceID = subspaceID;
	}
		
	/**
	 * Returns the Guest Redirect To Login setting.
	 *
	 * @return boolean
	 */
	public boolean GetGuestRedirectToLogin()
	{
		return m_bGLGuestRedirectToLogin;
	}

	/**
	 * Returns the Redirect On Logout setting.
	 *
	 * @return boolean
	 */
	public boolean GetRedirectOnLogout()
	{
		return m_bGLRedirectOnLogout;
	}
	
	/**
	 * Returns the SSO Vendor setting of the subportal if it exists or the
	 * default SSO Vendor setting from PTConfig.xml if the subportal has 
	 * no SSO Vendor setting set.
	 *
	 * @return int
	 */
	public int GetSSOVendor() 
	{
		return m_nGLSSOVendor;
	}

	/**
	 * Return the default SSO Vendor setting from PTConfig.xml.
	 * 
	 * @return
	 */
	public int GetDefaultSSOVendor() 
	{
		int nResult = 0;
		
		ConfigVarPack vpConfig = (ConfigVarPack) m_asOwner.GetApplication().GetVarPackManager().GetVariablePackage
			(ConfigVarPack.VARPACK_ID);

		String str = vpConfig.GetConfigValueAsString(
			ConfigConstants.AUTHENTICATION_SECTION, "SSOVendor",
			ConfigConstants.VALUE_ATTRIBUTE);

		if ((null != str) && (!"".equals(str)))
		{
			nResult = XPConvert.ToInteger(str); 
		} else 
		{
			log.Error("Cannot get SSOVendor info from PTconfig.xml");
		}
		
		return nResult;
	}

	/**
	* Get Profiles
	*
	* @return IASQueryResult
	*/
	/*
	public IASQueryResult GetProfiles()
	{
		IASQueryResult result;

		try
		{
			PTObjectManagerQueryWrapper omqr = new PTObjectManagerQueryWrapper(m_Session.GetUsers());
			// omqr.SimpleQuery(PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES,
			// 	 PT_PROPIDS.PT_PROPID_NAME);
			
			Object[][] guestFilter = new Object[3][1];
			guestFilter[0][0]     = new Integer(PT_PROPIDS.PT_PROPID_USER_USERTYPE);
			guestFilter[1][0]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			guestFilter[2][0]     = new Integer(PT_USER_TYPES.PT_USER_TYPE_GUEST);

			omqr.Query(PT_PROPIDS.PT_PROPID_NAME, -1, null, guestFilter);			
			result = omqr;
		}
		catch (Exception e)
		{
			log.Error("SubPortalModel::GetProfiles Unable to get the profiles for Drop Down Menu. " +
				"The following exception occured: " + e);
		
			throw new XPException(m_asOwner.GetString(445,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}
	*/
	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the Navigation scheme for the subportal.  Valid values are
	 * enumerated in  NavTypes.xml.
	 *
	 * @return int
	 */
	public int GetNavigationScheme()
	{
		return m_intNavigationScheme;
	}

	/**
	 * Returns what related resources are accessible to users of this
	 * subportal.  The value is any mask combination of
	 * PT_RELATED_RESOURCES_ACCESS_TYPES.
	 *
	 * @return int
	 */
	public int GetRelatedResourcesAccessTypes()
	{
		return m_intRelatedResourcesAccessTypes;
	}

	/**
	 * @return Whether or not adaptive layouts are enabled for this subportal.
	 */
	public boolean GetLayoutEnabled() {
		return m_bLayoutEnabled;
	}

	/**
	 * Returns whether a newly created folder resides in the unclassified area
	 * of the object admin hierarchy
	 *
	 * @return boolean
	 */
	public boolean GetFolderUnclassified() {
		return m_bFolderUnclassified;
	}

	/**
	 * Returns whether a newly created folder resides in the unclassified area
	 * of the object admin hierarchy
	 *
	 * 	 * @param bFolderUnclassified The bFolderUnclassified to set
	 */
	public void SetFolderUnclassified(boolean bFolderUnclassified) {
		this.m_bFolderUnclassified = bFolderUnclassified;
	}

	// END ***************** Get and Set methods *****************

	// START *************** Helper methods **********************
	protected String GetCommunityThemesURL()
	{
		// generate "http://hostname:port/imageserver/plumtree/common/public/css/community-themes.txt" 
		String strImgSrvURL = ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner);
		String strFwdSlash = "/";

		XPStringBuilder sb = new XPStringBuilder();
		sb.Append(strImgSrvURL);
		if (XPStringUtility.CharAt(strFwdSlash,0) != sb.CharAt(sb.GetLength()-1))
		{
			sb.Append(strFwdSlash);
		}
		sb.Append(ImgSvrURLHelper.STR_L1_DOMAIN_PLUMTREE);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L2_PRODUCT_NAME_COMMON);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L3_SCOPE_PUBLIC);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L4_FILE_TYPE_CSS);
		sb.Append(strFwdSlash);
		sb.Append("community-themes.txt");

		return sb.ToString();
	}
	// END *************** Helper methods **********************	
}