package com.plumtree.portalpages.admin.editors.subportal;

// Framework Imports
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for  the Choose
 * Navigation Design page of the SubPortal Editor.
 *
 * @author JohnH
 */
public class SubPortalNavDP extends EditorDP {
	/** The unique identifier for this class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalNavigation";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return (m_asOwner.GetString(938, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1653, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Navigation Options page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(
			((EditorView) m_asOwner.GetView(NavigationView.STR_MVC_CLASS_NAME))
				.Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
			SiteMapFolderPlugInView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();
		
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) +
			"opennewwindow.js");

		myScripts.AddInnerHTMLElement(script);

		myScripts.AddInnerHTMLElement(m_asOwner.GetView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME).DisplayJavascript());
		// DCA - display javascript for delete action
		myScripts.AddInnerHTMLElement(((SiteMapFolderPlugInView) 
						m_asOwner.GetView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME)).DisplayDeleteJavascript());

		return myScripts;
	}

}

