package com.plumtree.portalpages.admin.editors.subportal;


// UI Imports
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class contains the additional repost actions.
 * The ones specific to the SubPortal Editor (other than
 * "change page", "finish" and "cancel" actions).
 *
 * @author JohnH
 */
public class SubPortalRepostControl extends ObjEditorRepostControl
{
	/** The unique identifier for this class */
	public static final String STR_MVC_CLASS_NAME = "SubPortalRepost";

	/** The submit action for the Community picking tree */
	public final static int POSTTOSELF_ACTION_COMMTREESUBMIT   = 40;

	/** The submit action for the folder picking tree */
	public final static int POSTTOSELF_ACTION_FOLDERTREESUBMIT = 41;

	/** The submit action for the guest picking tree */
	public final static int POSTTOSELF_ACTION_GUESTTREESUBMIT = 42;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SubPortalRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		// You need to call the PerformRepostAction on the plug-in control
		((SiteMapFolderPlugInControl) m_asOwner.GetControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
			m_htFormData);

		// You need to call the PerformRepostAction on the select ptHeader control
		((ExpListControl) m_asOwner.GetControl(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_HEADER)).PerformRepostAction(_nAction,
			m_htFormData);

		// You need to call the PerformRepostAction on the select ptFooter control
		((ExpListControl) m_asOwner.GetControl(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOOTER)).PerformRepostAction(_nAction,
			m_htFormData);
			
		//Now for the folder picker
		((ExpListControl) m_asOwner.GetControl(SubPortalAS.STR_MVC_STORAGE_NAME_SELECT_FOLDER)).PerformRepostAction(_nAction,
			m_htFormData);

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_COMMTREESUBMIT:
			((SubPortalModel) m_model).RefreshItemFromTree(0);

			break;

		case POSTTOSELF_ACTION_FOLDERTREESUBMIT:
			((SubPortalModel) m_model).RefreshItemFromTree(1);
			
			break;
		
		case POSTTOSELF_ACTION_GUESTTREESUBMIT:
			((SubPortalModel) m_model).RefreshSelectedGuestFromTree();
			
			break;
		
		case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_SAVELINKS:
			ClosePopUpDP closeWebLinkDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			HTMLScript scriptWebLink = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			scriptWebLink.AddInnerHTMLString("window.opener.document." + AFormDP.HTMLFORM_NAME + ".submit();\n");
			closeWebLinkDP.SetScript(scriptWebLink);
			closeWebLinkDP.SetToClose(true);
			
			Redirect redirect = new Redirect();
			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			
			SetRedirect(redirect);

			break;
		}
	}
}

