package com.plumtree.portalpages.admin.editors.user;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author SudhaS
 */

public class UserDependenciesView extends ObjDependenciesView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.user.UserDependenciesView");

	//Member variables
	private CreatedHelper m_chHelper	  = null;

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "UserDependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_chHelper = new CreatedHelper(parent, (UserModel) model);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjDependenciesView#GetHTMLForDependencies()
	 */
	protected HTMLElementCollection GetHTMLForDependencies()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		int intParentFolderID = ((ObjEditorModel) m_model).GetFolderID();

		try
		{
			if (PT_INTRINSICS.PT_ADMIN_FOLDER_DEFAULTPROFILES == intParentFolderID)
			{
				//This is a default profile
				m_chHelper.displayEmptyRow(result);

//fixed string concatenation				m_chHelper.displayTextRow(result, m_asOwner.GetString(635, "ptmsgs_portalcommonmsgs") + m_asOwner.GetString(2282, "ptmsgs_portaladminmsgs"), null);
				m_chHelper.displayTextRow(result, m_asOwner.GetString(695, "ptmsgs_portalcommonmsgs"), null);

				m_chHelper.displayTextRow(result, -1, m_asOwner.GetString(2282, "ptmsgs_portaladminmsgs") + ":",
					((ObjEditorModel) m_model).GetObjectName());
					
				//Get the folder
				IPTSession mySession = ((ObjEditorModel) m_model).GetPTSession();
				IPTUser myUser = (IPTUser) ((ObjEditorModel) m_model).GetObject();
				int intAuthSourceID = myUser.GetAuthenticationSourceID();
				if ( 0 != intAuthSourceID )
				{
					IPTAuthSource myAuthSource;
					myAuthSource = (IPTAuthSource) mySession.GetAuthSources().Open(intAuthSourceID, false);
					int intNewUserFolderID = myAuthSource.GetNewUserFolderID();
					if (intNewUserFolderID > 0)
					{
						IPTAdminFolder myFolder = mySession.GetAdminCatalog().OpenAdminFolder(intNewUserFolderID, false); 
						String strFolderPath =  myFolder.GetPath();
						m_chHelper.displayTextRow(result, m_asOwner.GetString(2285, "ptmsgs_portaladminmsgs") + strFolderPath, null);
					}
				}
			}
			else
			{
				//Display the standard success message

				m_chHelper.displaySuccessMessage(result, m_asOwner.GetString(2281, "ptmsgs_portaladminmsgs"), ((ObjEditorModel) m_model).GetObjectName(), ((ObjEditorModel) m_model).GetParentFolderPath());
				
				ISelectPTObjectModelRO myUserModel = (ISelectPTObjectModelRO) m_asOwner.GetModel(UserEditorAS.strStorageSelectPTObject);
						
				IPTGrowableSortedArrayWrapperRO aUserGrowable = myUserModel.GetReadOnlyItems();
		
				if (aUserGrowable.GetCount() == 1) {
					//Inform the user and display the edit link

					m_chHelper.displayTextRow(result, m_asOwner.GetString(2283, "ptmsgs_portaladminmsgs"), null);
		
					m_chHelper.beginList(result);
		
					m_chHelper.displayListRow(PlumtreeHelpers.MakeCreateObjectLink(
						PT_CLASSIDS.PT_USER_ID, null,

					((IUserModelRO)m_model).GetObjectID(), m_asOwner.GetString(2284, "ptmsgs_portaladminmsgs"), m_asOwner, IPTOpenerConstants.OPENER_MODE_EDIT, null, true));
				}
			}
						
			//Display the standard warning if everyone has access to this object

			//m_chHelper.displayEveryoneWarning(result, (UserModel) m_model, m_asOwner.GetString(2281, "ptmsgs_portaladminmsgs"));
		}
		catch (Exception e)
		{
			log.Error(e, "Couldn't display ObjMgrHeaderView");

			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
			UIErrorScope.CURRENT_USER,
				null,

				m_asOwner.GetString(2286, "ptmsgs_portaladminmsgs") + e,"");
			UIErrorHandler.RaiseError(
				myError,
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
		
		return result;
	}
}