package com.plumtree.portalpages.admin.editors.user;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author SudhaS
 */
public class UserEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.user.UserEditorAS");


	public static final String STR_MVC_CLASS_NAME = "UserEditor";


	public static final String strStorageSelectPTObject = "SelectUserPTObject";
	public static final String strDynamicMembershipSelectPTObject = "DynamicMembershipSelectPTObject";


	private static final String sClassName = "com.plumtree.portalpages.admin.editors.user.UserEditorAS";


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 *
	 */
	public String GetDependenciesViewName()
	{
		return (UserDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{

			return GetString(955, "ptmsgs_portaladminmsgs");
		}
		else
		{

			return (XPResourceManager.FormatMessage(GetString(2617, "ptmsgs_portaladminmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (UserRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = UserModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Get back the Model we just registered because we need it to register the Section and the Control
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject);

		IModel mySelectPTObjectModel = GetModel(strStorageSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strStorageSelectPTObject, mySelectPTObjectModel);
		
		// Dynamic Membership view registration
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
				strDynamicMembershipSelectPTObject);

		IModel myDynamicMembershipSelectPTObjectModel = GetModel(strDynamicMembershipSelectPTObject);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
				strDynamicMembershipSelectPTObject, myDynamicMembershipSelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
				strDynamicMembershipSelectPTObject, myDynamicMembershipSelectPTObjectModel);

		// Register DisplayPages
		//RegisterPage(new MainDP());
		MainDP mainDP = new MainDP();
		RegisterPage(mainDP);

		DevicesDP devicesDP = new DevicesDP();
		RegisterPage(devicesDP);

		// Register Views
		RegisterView(LoginView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DevicesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(UserDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(UserRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Default page
		SetCurrentPage(mainDP);

//		int nUserID = ((IPTSession) this.GetUserSession()).GetSessionInfo().GetCurrentUserID();

		// Main DP
		mainDP.AddToValidationFunction("CheckNames");
		devicesDP.AddToValidationFunction("CheckNames");
		mainDP.AddToValidationFunction("CheckMinUserNameLength");
		mainDP.AddToValidationFunction("CheckUsernameNotWhitespace");
		devicesDP.AddToValidationFunction("CheckMinUserNameLength");
		devicesDP.AddToValidationFunction("CheckUsernameIsNumeric");
		devicesDP.AddToValidationFunction("CheckPasswordIsNumeric");
		devicesDP.AddToValidationFunction("CheckMinLength");
		mainDP.AddToValidationFunction("CheckMaxLength");

		//Sets left nav menu

		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(958,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, DevicesDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "Standard Settings"


		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1905, "ptmsgs_portaladminmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);

		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"


		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );

				int iTitleId = 69;
				int iTipId = 70;
				int iSecondaryTipId = 71;

				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );

				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");

				if( !("none_do_not_translate".equals( sSecondary )) )
				{

					e = new HTMLGenericElement( sSecondary );

					tm.SetSecondarTip( e );
				}


			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	  * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	  *
	  * @param IDisplayPage the current Display Page
	  */

	 public void SetCurrentPage(IDisplayPage page)
	 {

		  super.SetCurrentPage( page );
		  String sPageName = page.GetName();
		  if(MainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_User_MainSettings" );
		  }

		  else if( DevicesDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_User_MobileDeviceAuthentication" );
		  }

	 }


}

