package com.plumtree.portalpages.admin.editors.userprofilemanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.userinfopropmap.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.expandablelist.template.*;
import com.plumtree.portaluiinfrastructure.ptmulticolumnlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * The main activity space for the user profile manager.  It registers the
 * classes for the user profile 'community', and the
 * user information property map.
 */
public class UsrProfMgrEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.userprofilemanager.UsrProfMgrEditorAS");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "UserProfileManagerEditor";

	/** pop up constants used for keying pop up display pages */
	public static final String POPUP_KEY = "_popup";

	public static final String RENAME_KEY = "_rename";
	private static final String sClassName = "com.plumtree.portalpages.admin.editors.userprofilemanager.UsrProfMgrEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UsrProfMgrEditorAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 */
	public String GetEditorTitle()
	{
		return (GetString(967, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (UsrProfMgrRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void InitClosePopup()
	{
		// display page that closes popups
		HTMLScript openerScript = new HTMLScript("text/javaScript");

		try
		{
			openerScript.AddInnerHTMLString("window.opener." + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + UsrProfMgrRepostControl.POSTTOSELF_ACTION_ONRETURN_FROM_SUBEDITOR + ");");
		}
		catch (Exception e)
		{
			
				log.Error(e, "UsrProfMgrEditorAS::Init The following error occured when trying to initialize the activity space: " + e.getMessage());
			
		}

		ClosePopUpDP closePopUp = new ClosePopUpDP();
		closePopUp.SetScript(openerScript);
		RegisterPage(closePopUp, ClosePopUpDP.STR_MVC_CLASS_NAME + POPUP_KEY);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void InitTips()
	{
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass(sClassName);

				int iTitleId = 72;
				int iTipId = 73;
				int iSecondaryTipId = 74;

				tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));

				HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId, "ptmsgs_tips"));

				tm.SetTip(e);

				String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");

				if (!("none_do_not_translate".equals(sSecondary)))
				{
					e = new HTMLGenericElement(sSecondary);

					tm.SetSecondarTip(e);
				}
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
	}

	/**
	 * Registers all the user profile community classes for this Activity Space.
	 */
	public void InitProfileCommunityObjects(int _subMenuID)
	{
		RegisterModel(CommunityEditorModel.STR_MVC_CLASS_NAME);

		IModel commModel = GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME);
		RegisterControl(UsrProfCommRepostControl.STR_MVC_CLASS_NAME, commModel);

		// --- COMMUNITY PAGES objects
		UsrProfCommPagesDP myPage = new UsrProfCommPagesDP();
		RegisterPage(myPage);

		// Default page
		SetCurrentPage(myPage);
		m_mEditorMenu.AddLinkToSubMenu(_subMenuID, UsrProfCommPagesDP.STR_MVC_CLASS_NAME);
		RegisterView(UsrProfDisableSiteMapView.STR_MVC_CLASS_NAME, DisableSiteMapView.STR_MVC_CLASS_NAME, commModel);

		// Register the page list as a plug-in section
		RegisterModel(PageListModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_PAGE_LIST);

		// Get back the Model we just registered because we need 
		// it to register the view and the Control
		IModel myPageListModel = GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST);
		RegisterView(PageListView.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_PAGE_LIST, myPageListModel);
		RegisterControl(PageListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_PAGE_LIST, myPageListModel);

		// Register the community template selector as a plug-in section
		RegisterModel(CommunityTemplateSelectorModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myCommunityTemplateSelectorModel = GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR);
		RegisterView(TemplateListView.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR,
				myCommunityTemplateSelectorModel);	
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
				CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR, myCommunityTemplateSelectorModel);
		
		// --- BANNER, HEADER and FOOTER objects
		RegisterPage(new HeaderAndFooterSelectorDP());
		m_mEditorMenu.AddLinkToSubMenu(_subMenuID, HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME);
		RegisterView(HeaderAndFooterSelectorView.STR_MVC_CLASS_NAME, commModel);
		RegisterControl(HeaderAndFooterRepostControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_HEADER_AND_FOOTER_SELECTOR, commModel);

		// --- DEPENDENCY VIEW
		RegisterView(CommunityDependenciesView.STR_MVC_CLASS_NAME, commModel);

		// The following go under the standard settings section
		int stdSettingsMenu = m_mEditorMenu.StartNewSubMenu(GetString(2187, "ptmsgs_portaladminmsgs"));

		// --- SECURITY
		((ObjectSecurityModel) GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetLeftNavString(GetString(221, "ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(stdSettingsMenu, ObjectSecurityDP.STR_MVC_CLASS_NAME);

		// --- MIGRATION HISTORY AND STATUS
		m_mEditorMenu.AddLinkToSubMenu(stdSettingsMenu, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// --- register the following objects because our repost control, 
		//   UsrProfMgrRepostControl calls CommunityEditorRepostControl
		//   and that control calls these models and controls.  in our AS
		//   these won't actually do be used for anything
		IModel myTempModel;

		// --- CommunityGroups list/create page
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST);
		myTempModel = GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST, myTempModel);

		//		RegisterPage(new CommunityEditorCommGroupDP());
		//		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,CommunityEditorAS.m_strRegIDCommGroups, mySelectPTObjectModel);
		// --- Subcommunity list/create page
		RegisterModel(CommunityEditorSubcommunityModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST);
		myTempModel = GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST, myTempModel);

		//		RegisterPage(new CommunityEditorSubcommunityDP());
		//		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,m_strRegIDSubCommunities, mySelectPTObjectModel);
		// --- COMMUNITY PORTLETS
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST);
		myTempModel = GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST, myTempModel);
		RegisterPage(new CommunityEditorCommPortletDP());
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST, myTempModel);
		m_mEditorMenu.AddLinkToSubMenu(_subMenuID, CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the user info property map classes for this Activity Space.
	 */
	public void InitUserInfoPropMapObjects(int _subMenuID)
	{
		// --- USER INFO PROPERTY MAP OBJECTS
		RegisterModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
		RegisterPage(new MainDP());
		RegisterControl(UserInfoPropMapRepostControl.STR_MVC_CLASS_NAME, GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME));

		// --- USER INFO PROPERTY PLUG-IN OBJECTS
		RegisterModel(UserInfoPropMapListModel.STR_MVC_CLASS_NAME, UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN);

		// userinfoprop plug-in model's control and view
		IModel plugInModel = GetModel(UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN);
		RegisterView(PTMultiColumnListView.STR_MVC_CLASS_NAME, UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN, plugInModel);
		RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME, UserInfoPropMapAS.STR_MVC_STORAGE_NAME_PLUG_IN, plugInModel);

		// --- add the userinfo main dp to submenu
		m_mEditorMenu.AddLinkToSubMenu(_subMenuID, MainDP.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (CommunityDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		/* set the main model name and call super class's init */
		m_strModelName = UsrProfMgrModel.STR_MVC_CLASS_NAME;
		super.Init();

		/* get the main model and repost control and register them */
		IModel myModel = GetModel(m_strModelName);
		RegisterControl(UsrProfMgrRepostControl.STR_MVC_CLASS_NAME, myModel);

		/* register the profile layout sections and objects */

		//		InitLayoutPages(myModel);
		// id for the user profile community & prop info submenu
		int editSettingsMenu = m_mEditorMenu.StartNewSubMenu(GetString(383, "ptmsgs_portaladminmsgs"));

		/* initialize the user profile community objects */
		InitProfileCommunityObjects(editSettingsMenu);

		/* initialize the user info property map objects */
		InitUserInfoPropMapObjects(editSettingsMenu);

		/* initialize the close popup objects */
		InitClosePopup();

		/* initialize tips */
		InitTips();
	}

	/**
	 * This is a helper method that all classes that inherit from AFormDP can
	 * override if they like.  The method provides a hook into the head so
	 * that DP's can add javascript. Simply override and return and
	 * HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 *
	 * @return HTMLScriptCollection the Javascript from the Child IViews
	 * @throws HTMLException If error occurs while creating or populating
	 * HTML Elements.
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()
	 *      Override this method to Display javascript from child IViews
	 */
	public HTMLScriptCollection DisplayCommonJavaScript()
	{
		HTMLScriptCollection scripts = super.DisplayCommonJavaScript();

		HTMLScript script = new HTMLScript("text/javascript");
		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(this) + "opennewwindow.js");
		scripts.AddInnerHTMLElement(script);

		script = new HTMLScript("text/javascript");
		scripts.AddInnerHTMLElement(script);

		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("\n").Append("function ").Append(CommunityEditorAS.JS_ALERTSAVEFORPREFS_FUNC).Append("()").Append("{\n").Append("		if ( confirm('").Append(GetString(1228, "ptmsgs_portalbrowsingmsgs")).Append("') )\n").Append("		{\n").Append("			return true;").Append("		}\n").Append("		return false;").Append("}\n");

		script.AddInnerHTMLString(sb.ToString());

		return scripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (UsrProfCommPagesDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_UserProfileManager_ProfilePages");
		}
		else if (HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_Community_HeaderandFooter");
		}
		else if (CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_Community_ThisCommunitysPortlets");
		}
		else if (MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_MigrationHistoryandStatus");
		}
		else if (MainDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			SetHelpTopic("PT_UserProfileManager_UserInformationPropertyMap");
		}
	}
}

