package com.plumtree.portalpages.admin.editors.userprofilemanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.ptutilities.userinfopropmap.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author JHQ
 * @author jennifersu
 *
 * This is the main model for the user profile manager.  Because the user
 * profile manager encompasses multiple activity spaces and models, this model
 * does not extend any particular model (i.e. CommunityEditorModel).  Instead,
 * it calls those models' methods directly.  The models called within here are:
 * CommunityEditorModel, PageListModel, and UserInfoPropMapModel
 */
public class UsrProfMgrModel extends ObjEditorModel implements IUsrProfMgrModelRO, IMigrationModelRO, IDescriptionModelRO
{
	/** object name */
	public static final String STR_MVC_CLASS_NAME = "UserProfileManager";

	/** array of new object ids */
//	private XPArrayList m_newObjectKeys = new XPArrayList();
	private String m_propsDisplayString = "";
//	private XPArrayList m_listOfGlobalUserProps;

	public static final int PT_ACCESS_LIST_ENTRY_READWRITE = 0;

	/** Server object: Plumtree Session */
	protected IPTSession m_Session;

	/**
	 * Flag to know if the current user has system administration activity rights.
	 * We need it to know when to display the migration checkbox.
	 */
	protected boolean m_bIsSysAdmin;

	/** Object migration status */
	private int m_nMigrationStatus;

	public UsrProfMgrModel()
	{
		super();

		m_nMigrationStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()
	 */
	public void Cancel()
	{
		super.Cancel();

		/* cancel usr profile community */
		((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).Cancel();

		/* init user info property map model */
		UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
		propMapModel.Cancel();

	}

	/**
	 * Code executed when the Editor is starting.
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		InitIsSysAdminFlag();

		// --- start the user profile community editor */
		CommunityEditorModel commModel = (CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME);

		commModel.SetEditorType(EditorStartControl.EDITOR_START_FLAG_EDIT);

		_htFormData.PutElement(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, new String[]
			{
				"" + PT_CLASSIDS.PT_COMMUNITY_ID
			});
		_htFormData.PutElement(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID, new String[]
			{
				"" + PT_INTRINSICS.PT_PROFILE_COMMUNITY
			});
		_htFormData.PutElement(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID, new String[]
			{
				"" + PT_INTRINSICS.PT_ADMIN_FOLDER_PROFILECOMMUNITY
			});
		_htFormData.PutElement(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER, new String[]
			{
				XPConvert.ToString(true)
			});

		if (!commModel.CheckEditorAccessAndStart(_htFormData))
		{
			return false;
		}

		// --- modify the pagelist's strings so that it reads "user profile" vs
		//  "community"
		PageListModel myPageListModel = (PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST);
		myPageListModel.SetSectionTitle(m_asOwner.GetString(2195, "ptmsgs_portaladminmsgs"));
		myPageListModel.SetAddLabel(m_asOwner.GetString(2356, "ptmsgs_portaladminmsgs"));

		// --- start the user info property map editor
		UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);

		if (!propMapModel.CheckEditorAccessAndStart(_htFormData))
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(995, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(996, "ptmsgs_portaladminmsgs"));
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			return false;
		}

		// --- for our proposes, we do not need the mandatory column
		((ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetSupportMandatoryColumn(ObjectSecurityModel.MANDCOL_NONE);
		((PriorityDropDownModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_PRIORITY_DROP_DOWN)).SetSupportMandatoryColumn(false);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UsrProfMgrModel();
	}

	/**
	 * Code executed in finish.
	 *
	 */
	public void Finish()
	{
		/* finish user profile community model */
		((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).Finish();

		/* finish user info property map model */
		UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);
		propMapModel.Finish();
	}

	/**
	 * Returns the value of the m_bIsSysAdmin member variable.
	 *
	 * @return boolean
	 */
	public boolean GetIsSysAdmin()
	{
		return m_bIsSysAdmin;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);

		// Get the Session object from the associated AS.
		m_Session = (IPTSession) parent.GetUserSession();
	}

	/**
	 * Returns true if the object description cannot be set/changed from the Editor.
	 * This is here mainly because ObjEditor has this method and the
	 * locNamesPrimaryNameView uses this to determine whether or not to display
	 * the description field and js validation.  For our proposes, we will
	 * always display the discription field.  So this will always return false.
	 *
	 * @return boolean
	 */
	public boolean IsDescriptionDisabled()
	{
		return false;
	}

	/**
	 * Returns true if the migration has already been approved for the current
	 * object.
	 *
	 * @return boolean
	 */
	public boolean IsMigrationApproved()
	{
		if (PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED == m_nMigrationStatus)
		{
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Helper method to save the migration status checkbox.
	 *
	 * @param _htFormData
	 */
	protected void SaveMigrationStatus(XPHashtable _htFormData)
	{
		if (_htFormData.ContainsKey(MigrationHistoryView.HTMLCHECKBOX_MIGRATION))
		{
			m_nMigrationStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED;
		}
		else
		{
			m_nMigrationStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE;
		}
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		/* save page on user profile community */
		if (RepostControl.PAGE_STATUS_INVALID == ((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).SavePage(_sPageName, _htFormData))
		{
			return RepostControl.PAGE_STATUS_INVALID;
		}

		/* save page for user info property map model */
		UserInfoPropMapModel propMapModel = (UserInfoPropMapModel) m_asOwner.GetModel(UserInfoPropMapModel.STR_MVC_CLASS_NAME);

		if (RepostControl.PAGE_STATUS_INVALID == propMapModel.SavePage(_sPageName, _htFormData))
		{
			return RepostControl.PAGE_STATUS_INVALID;
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Helper method to determine activity rights.
	 */
	protected boolean CheckActivityRight()
	{
		return m_Session.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_PROFILE_LAYOUT);
	}

	/**
	 * Helper method to init the isSysAdmin flag.
	 */
	protected void InitIsSysAdminFlag()
	{
		m_bIsSysAdmin = PlumtreeHelpers.CheckCurrentUserIsAdmin(m_Session);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnChangePage(java.lang.String, java.lang.String)
	 */
	public void DoTaskOnChangePage(String _sNewSpaceName, String _sNewPageName)
	{
		super.DoTaskOnChangePage(_sNewSpaceName, _sNewPageName);

		/* finish user profile community model */
		((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskOnChangePage(_sNewSpaceName, _sNewPageName);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnComeBackFromSubEditor()
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();

		/* finish user profile community model */
		((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskOnComeBackFromSubEditor();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskAfterStore()
	 */
	public void DoTaskAfterStore()
	{
		super.DoTaskAfterStore();

		/* finish user profile community model */
		((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskAfterStore();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()
	 */
	public void DoTaskBeforeStore()
	{
		super.DoTaskBeforeStore();

		/* finish user profile community model */
		((CommunityEditorModel) m_asOwner.GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME)).DoTaskBeforeStore();
	}

	/**
	 * if the property display string is empty than that means that no
	 * properties were mapped to user objects via the global object properties
	 * map.
	 *
	 * @return boolean if displaystring is blank.
	 */
	public boolean IsPropertiesMapEmpty()
	{
		return m_propsDisplayString.equals("");
	}
}

