package com.plumtree.portalpages.admin.editors.webservice;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 */
public class AdvURLSettingsDP extends WSPluginDP {
	/** Class Name */
	public static final String STR_MVC_CLASS_NAME = "AdvURLSettingsDP";

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetAllPossibleViews()
	 */
	public XPArrayList GetAllPossibleViews() {
		XPArrayList xpWSViews = new XPArrayList();

		xpWSViews.Add(WebServiceEditorAS.strStorage_HelpURLPluginView);
		xpWSViews.Add(WebServiceEditorAS.strStorage_RemoteConfigPluginView);
		xpWSViews.Add(
			WebServiceEditorAS.strStorage_RemoteMigrationPluginView);

		return xpWSViews;
	}

	
	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return m_asOwner.GetString(1185, "ptmsgs_portaladminmsgs");
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() 
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(3235, "ptmsgs_portaladminmsgs"),
			m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetOrderedViewList(int)
	 */
	public XPArrayList GetOrderedViewList(int nWSMode) {
		XPArrayList xpWSViews = new XPArrayList();

		switch (nWSMode) {
			case WebServiceModel.WSMODE_PORTLET :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_HelpURLPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_RemoteConfigPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_RemoteMigrationPluginView);

				break;

			case WebServiceModel.WSMODE_PAGELET :
				xpWSViews.Add(
						WebServiceEditorAS.strStorage_HelpURLPluginView);
				// TODO: Do we need the remote migration view?
				break;

			case WebServiceModel.WSMODE_INTRINSIC_PORTLET :
				break;

			case WebServiceModel.WSMODE_AWS :
			case WebServiceModel.WSMODE_PWS :
			case WebServiceModel.WSMODE_MWS :
				// AGC- Note, the XUI URL used to be on this page, but it has been
				// moved to the AdvSettings page in order to shorten the number of pages.

				break;

			case WebServiceModel.WSMODE_CWS :
			case WebServiceModel.WSMODE_SWS :
				xpWSViews.Add(WebServiceEditorAS.strStorage_XUIURLPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_RemoteConfigPluginView);

				break;

			case WebServiceModel.WSMODE_NONE :
			default :
				}

		return xpWSViews;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetPluginHelpTopic()
	 */
	public String GetPluginHelpTopic() {
		WebServiceModel mParentModel = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
		switch(mParentModel.GetWSMode())
		{
			case WebServiceModel.WSMODE_PORTLET :
				return "PT_WebService_Portlet_Remote_AdvancedURLSettings";
			case WebServiceModel.WSMODE_PAGELET :
				return "PT_WebService_Pagelet_AdvancedURLSettings";
			case WebServiceModel.WSMODE_CWS :
				return "PT_WebService_Crawler_AdvancedURLSettings";
			case WebServiceModel.WSMODE_SWS :
				return "PT_WebService_Search_AdvancedURLSettings";
			case WebServiceModel.WSMODE_INTRINSIC_PORTLET :
			case WebServiceModel.WSMODE_AWS :
			case WebServiceModel.WSMODE_PWS :
			case WebServiceModel.WSMODE_MWS :
			case WebServiceModel.WSMODE_NONE :
			default :					
		}
		return null;
	}

}

