package com.plumtree.portalpages.admin.editors.webservice;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author AkashJ
 */
public class AuthenticationDP extends WSPluginDP
{
	public static final String STR_MVC_CLASS_NAME = "AuthenticationDP";

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetAllPossibleViews()
	 */
	public XPArrayList GetAllPossibleViews() {
		XPArrayList xpWSViews = new XPArrayList();

		xpWSViews.Add(WebServiceEditorAS.strStorage_BasicAuthPluginView);
		xpWSViews.Add(WebServiceEditorAS.strStorage_CredentialVaultPluginView);
		xpWSViews.Add(WebServiceEditorAS.strStorage_FormLoginPluginView);
		xpWSViews.Add(WebServiceEditorAS.strStorage_FormLoginFieldsPluginView);

		return xpWSViews;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetOrderedViewList(int)
	 */
	public XPArrayList GetOrderedViewList(int nWSMode) {
		XPArrayList xpWSViews = new XPArrayList();

		switch (nWSMode) {
			case WebServiceModel.WSMODE_PORTLET :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_CredentialVaultPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_BasicAuthPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_FormLoginPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_FormLoginFieldsPluginView);

				break;

			case WebServiceModel.WSMODE_CWS :
				xpWSViews.Add(
						WebServiceEditorAS.strStorage_BasicAuthPluginView);

				// aj TODO - should we show this here??
//			xpWSViews.Add(
//					WebServiceEditorAS.strStorage_CredentialVaultPluginView);
//				xpWSViews.Add(
//						WebServiceEditorAS.strStorage_FormLoginPluginView);
//				xpWSViews.Add(
//						WebServiceEditorAS.strStorage_FormLoginFieldsPluginView);
					
				break;
				
			case WebServiceModel.WSMODE_AWS :
			case WebServiceModel.WSMODE_PWS :
			case WebServiceModel.WSMODE_MWS :
			case WebServiceModel.WSMODE_SWS :
				xpWSViews.Add(
						WebServiceEditorAS.strStorage_BasicAuthPluginView);

				break;
			
			case WebServiceModel.WSMODE_INTRINSIC_PORTLET :
			case WebServiceModel.WSMODE_PAGELET :
			case WebServiceModel.WSMODE_NONE :
			default :
				}

		return xpWSViews;
	}
	
	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetPluginHelpTopic()
	 */
	public String GetPluginHelpTopic() {
		WebServiceModel mParentModel = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
		switch(mParentModel.GetWSMode())
		{
			case WebServiceModel.WSMODE_PORTLET :
				return "PT_WebService_RemotePortlet_AuthSettings";
			case WebServiceModel.WSMODE_AWS :
				return "PT_WebService_Authentication_AuthSettings";
			case WebServiceModel.WSMODE_PWS :
				return "PT_WebService_Profile_AuthSettings";
			case WebServiceModel.WSMODE_CWS :
				return "PT_WebService_Crawler_AuthSettings";
			case WebServiceModel.WSMODE_SWS :
				return "PT_WebService_Search_AuthSettings";
			case WebServiceModel.WSMODE_MWS :
				return "PT_WebService_Migration_AuthSettings";
			case WebServiceModel.WSMODE_INTRINSIC_PORTLET :
			case WebServiceModel.WSMODE_PAGELET :
			case WebServiceModel.WSMODE_NONE :
			default :					
		}
		return null;
	}
	
	
	
	/**
	 * Returns the String to display on the left navigation menu, linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(2921, ResourceConstants.PORTALADMINMSGS));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() throws HTMLException {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(2924, ResourceConstants.PORTALADMINMSGS),
			this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

