package com.plumtree.portalpages.admin.editors.webservice;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class HTTPConfigDP extends WSPluginDP 
{
	//MES- CR: Doesn't match class name
	//AGC- CR-Response: Same deal, I was getting name collision, so I changed it.
	//  The name is arbitrary as long as it is reasonably unique.    
	public static final String STR_MVC_CLASS_NAME = "WebServiceHTTPConfigDP";

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetAllPossibleViews()
	 */
	public XPArrayList GetAllPossibleViews() {
		XPArrayList xpWSViews = new XPArrayList();

		xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayCachingPluginView);
		xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
		xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);

		return xpWSViews;
	}

	
	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return m_asOwner.GetString(1188, "ptmsgs_portaladminmsgs");
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1671, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetOrderedViewList(int)
	 */
	public XPArrayList GetOrderedViewList(int nWSMode) {
		XPArrayList xpWSViews = new XPArrayList();

		switch (nWSMode) {
			case WebServiceModel.WSMODE_PORTLET :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewayCachingPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewayPrefixPluginView);

				break;

			case WebServiceModel.WSMODE_PAGELET :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewayCachingPluginView);
					//xpWSViews.Add(WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
					// rob: This view is not displayed in Pagelet WS editors but we add a hardcoded gateway prefix
					// to all pagelet WS so we need this view in the list so that the GW prefix model will save its data.
					// The view is hidden by adding special case logic in WSPluginDP.PageDisplay
					xpWSViews.Add(WebServiceEditorAS.strStorage_GatewayPrefixPluginView); 

				break;

			case WebServiceModel.WSMODE_AWS :
			case WebServiceModel.WSMODE_PWS :
			case WebServiceModel.WSMODE_MWS :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewayPrefixPluginView);
				break;
			
			case WebServiceModel.WSMODE_INTRINSIC_PORTLET :
				break;

			case WebServiceModel.WSMODE_CWS :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewayPrefixPluginView);

				break;

			case WebServiceModel.WSMODE_SWS :
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewaySettingsPluginView);
				xpWSViews.Add(
					WebServiceEditorAS.strStorage_GatewayPrefixPluginView);

				break;

			case WebServiceModel.WSMODE_NONE :
			default :
				}

		return xpWSViews;
	}
	
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.WSPluginDP#GetPluginHelpTopic()
	 */
	public String GetPluginHelpTopic() {
		WebServiceModel mParentModel = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
		switch(mParentModel.GetWSMode())
		{
			case WebServiceModel.WSMODE_PORTLET :
				return "PT_WebService_Portlet_Remote_HTTPConfiguration";
			case WebServiceModel.WSMODE_PAGELET :
				return "PT_WebService_Pagelet_HTTPConfiguration";
			case WebServiceModel.WSMODE_CWS :
				return "PT_WebService_Crawler_HTTPConfiguration";
			case WebServiceModel.WSMODE_SWS :
				return "PT_WebService_Search_HTTPConfiguration";
			case WebServiceModel.WSMODE_AWS :
			case WebServiceModel.WSMODE_PWS :
			case WebServiceModel.WSMODE_MWS :			
				return "PT_WebService_httpconfiguration";
			case WebServiceModel.WSMODE_INTRINSIC_PORTLET :
			case WebServiceModel.WSMODE_NONE :
			default :					
		}
		return null;
	}

}

