package com.plumtree.portalpages.admin.editors.webservice;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;

/**
 * @author adolfoc
 *
 */
public class WSModelHelper extends ModelHelper
{
	/**
	 * Common WS Type CLSIDs. These MUST be uppercase, to facilitate string comparison.
	 */
	public static final String WSTYPE_HTTPGP = PT_PROVIDER_CLSIDS.PT_REMOTEPORTLET_PROVIDER;
	public static final String WSTYPE_HTTPPAGELET = PT_PROVIDER_CLSIDS.PT_REMOTEPAGELET_PROVIDER;
	
	public static final String WSTYPE_IGP = PT_PROVIDER_CLSIDS.PT_INTRINSICPORTLET_PROVIDER;
	public static final String WSTYPE_AWS = PT_PROVIDER_CLSIDS.PT_AUTH_PROVIDER;
	public static final String WSTYPE_PWS = PT_PROVIDER_CLSIDS.PT_PROFILE_PROVIDER;
	public static final String WSTYPE_CWS = PT_PROVIDER_CLSIDS.PT_CRAWL_PROVIDER;
	public static final String WSTYPE_SWS = PT_PROVIDER_CLSIDS.PT_SEARCH_PROVIDER;
	public static final String WSTYPE_MWS = PT_PROVIDER_CLSIDS.PT_MIGRATION_PROVIDER;

	/**
	 * @param strUserInfo 
	 *
	 * @return 
	 */
	public static boolean IsHardcodedUserInfo(String strUserInfo)
	{
		// UUID names are reserved for use by Credential Vault -jas
		if ('{' == XPStringUtility.CharAt(strUserInfo, 0)) return true;
		
		// iterate through all the defined User Info constants -jas
		for (int index = 0; index < PlumtreeExtensibility.PT_USERINFO_ALL.length; index++)
		{
			if ((0 == strUserInfo.compareTo(PlumtreeExtensibility.PT_USERINFO_ALL[index]))) return true;
		}
	
		return false;
	}

	/**
	 * @param ptPropBag 
	 *
	 * @return 
	 */
	public static XPArrayList GetNonHardcodedUserInfo(IXPPropertyBag ptPropBag)
	{
		Object[] aUserInfoList = ptPropBag.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERINFO);
	
		XPArrayList xpalUserInfo = new XPArrayList(0);
	
		if (null != aUserInfoList)
		{
			for (int nCount = 0; nCount < aUserInfoList.length; nCount++)
			{
				String strUserInfo = XPConvert.ToString(aUserInfoList[nCount]);
	
				if (!WSModelHelper.IsHardcodedUserInfo(strUserInfo))
				{
					xpalUserInfo.Add(strUserInfo);
				}
			}
		}
	
		return xpalUserInfo;
	}

	// Helper functions.
	public static XPArrayList GetHardcodedUserInfo(IXPPropertyBag ptPropBag)
	{
		Object[] aUserInfoList = ptPropBag.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERINFO);

		//MES- CR: We're only adding the items that are in the PropBag AND are in the list below- should
		//	we just add the ones from the list below, regardless of whether they're in the PropBag?
		//AGC- CR-Response: Nope! This list is not just the list of any-ol' User info. This is the list of
		//  user info selected for sending to a user. Presence or absence from this list does not just denote that
		//  these items should show up in the UI - it also specifies whether or not the userinfos have been
		//  selected by the user.
		XPArrayList xpalUserInfo = new XPArrayList(0);

		if (null != aUserInfoList)
		{
			for (int nCount = 0; nCount < aUserInfoList.length; nCount++)
			{
				String strUserInfo = XPConvert.ToString(aUserInfoList[nCount]);

				if (WSModelHelper.IsHardcodedUserInfo(strUserInfo))
				{
					xpalUserInfo.Add(strUserInfo);
				}
			}
		}

		return xpalUserInfo;
	}
}

