package com.plumtree.portalpages.admin.editors.webservice;

import com.plumtree.portalpages.admin.editors.webservice.plugins.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * @author adolfoc
 *
 */
public class WebServiceRepostControl extends ObjEditorRepostControl
{
	
	public static final String STR_MVC_CLASS_NAME = "WebServiceRepost";

	/** Repost that occurs when the Remote Server is chosen via Tree Section */
	public final static int POSTTOSELF_ACTION_REMOTE_VIEW_CHOSEN = 66;

	/** Repost that occurs when the WebService Type is chosen via Radio Button */
	public final static int POSTTOSELF_ACTION_WSTYPE_CHOSEN = 67;

	/** Repost that occurs when the WebService Type is removed (not via Tree Section)*/
	public final static int POSTTOSELF_ACTION_REMOTE_VIEW_REMOVED = 68;

	/** Repost that occurs when the credential vault is removed */
	public final static int POSTTOSELF_ACTION_CRED_VAULT_REMOVED = 69;
	
	/** Repost that occurs when the debug user is removed */
	public final static int POSTTOSELF_ACTION_DEBUG_USER_REMOVED = 70;
	
	/** Repost that occurs when the debug portlet is removed */
	public final static int POSTTOSELF_ACTION_DEBUG_PORTLET_REMOVED = 71;
	
	/** Pagelet Editor Actions - Selects a new pagelet library **/
	public final static int POSTTOSELF_ACTION_SET_PAGELETLIBRARY = 80;
	


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new WebServiceRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		// We need to call the PerformRepostAction on the plug-in control
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_UserPrefsListPluginView)).PerformRepostAction(_nAction,
			m_htFormData);

		// We need to call the PerformRepostAction on the plug-in control
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_CommunityPrefsListPluginView)).PerformRepostAction(_nAction,
			m_htFormData);

		// We need to call the PerformRepostAction on the plug-in control
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_SessionPrefsListPluginView)).PerformRepostAction(_nAction,
			m_htFormData);

		// We need to call the PerformRepostAction on the plug-in control
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_ActSecurityPluginView)).PerformRepostAction(_nAction,
			m_htFormData);

		// We need to call the PerformRepostAction on the plug-in control
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_GatewayPrefixPluginView)).PerformRepostAction(_nAction,
			m_htFormData);

		// We need to call the PerformRepostAction on the plug-in control
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_AddUserInfoPluginView)).PerformRepostAction(_nAction,
			m_htFormData);
		
		// aj: repost control for the form field login view
		((ExpListControl) m_asOwner.GetControl(WebServiceEditorAS.strStorage_FormLoginFieldsPluginView)).PerformRepostAction(_nAction,
				m_htFormData);
		
		switch (_nAction)
		{
		//AGC- The one view that affects all others is the Remote Server selection view.
		//if the Remote Server changes or is removed, all of the other views must be notified.		
		case POSTTOSELF_ACTION_REMOTE_VIEW_REMOVED:

			// As a favor to the Remote Server Model, we'll call the ClearRemoteServer method. To be properly
			// graceful, we should farm out this task to a control specifically associated with the remote
			// server plugin. But it's not really worth it for a single method.			
			((RemoteServerPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemoteServerPluginView)).ClearRemoteServer();			

			break;

		case POSTTOSELF_ACTION_REMOTE_VIEW_CHOSEN:
			// Save page is called before we get here - it may error that the package is not
			// up-to-date (or that the remote server's not selected). It shouldn't do that.
			UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			break;
			
		// AGC- the following event occurs if the WSTYPE is changed - mid editor. Under normal circumstances
		// this should not happen. However, this can happen if the Choose Webservice Type view is enabled, which might
		// be done for debugging purposes.
		case POSTTOSELF_ACTION_WSTYPE_CHOSEN:

			// Refresh all of our views...
			((WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).UpdateWSSubModels();

			break;

		case POSTTOSELF_ACTION_CRED_VAULT_REMOVED:

			// As a favor to the Remote Server Model, we'll call the ClearRemoteServer method. To be properly
			// graceful, we should farm out this task to a control specifically associated with the remote
			// server plugin. But it's not really worth it for a single method.			
			((CredentialVaultPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_CredentialVaultPluginView)).ClearLockbox();
			
			break;			
			
		case POSTTOSELF_ACTION_DEBUG_USER_REMOVED:

			//Call the ClearUser method on the model.
			((DebugUserPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_DebugUserPluginView)).ClearUser();
			
			break;			
			
		case POSTTOSELF_ACTION_DEBUG_PORTLET_REMOVED:

			//Call the ClearPortlet method on the model.
			((DebugPortletPluginModel) m_asOwner.GetModel(WebServiceEditorAS.strStorage_DebugPortletPluginView)).ClearPortlet();
			
			break;			

		case POSTTOSELF_ACTION_SET_PAGELETLIBRARY:
			((RemotePageletPickerPluginModel)m_asOwner.GetModel(WebServiceEditorAS.strStorage_RemotePageletPickerView)).RefreshSelectedPageletLibraryName();
			break;
			
		}
	}
}

