package com.plumtree.portalpages.admin.editors.webservice.credvaulttree;


import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.treeiterator.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This version of the tree allows for browsing and
 * selecting of objects with no hierarchical structure
 *
 * @author JosephS
 */
public class CredVaultTreeModel extends ATreeModel implements ITreeModel,
	ITreeModelRO, IRepostModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		CredVaultTreeModel.class);

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "CredVaultTree";

	/** Tree iterator */
	protected IPTTreeIterator m_ptIterator = null;

	/**
	 * Storage for the list of all known credential vaults. This is used in order to
	 * get the CredVault string based on the index into this array (the index is
	 * used in place of an object ID to uniquely identify each User Info).
	 */
	protected XPArrayList m_xpalKnownCredVaults;
	protected XPArrayList m_xpalSelected;

	public CredVaultTreeModel()
	{
		super();
		m_xpalKnownCredVaults = new XPArrayList();
		m_xpalSelected = new XPArrayList();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CredVaultTreeModel();
	}

	/**
	 * This is called when a node is expanded.  Since User Info
	 * is a flat list, there will be no recursive thoughts here.  This simply
	 * retrieves all the User Info available to the user and puts it on
	 * the tree as leaf items.
	 *
	 * @param bExpand expands the branch
	 * @param nNodeID the uniqueid for this node
	 */
	public void ExpandNode(boolean bExpand, int nNodeID)
	{
		super.ExpandNode(bExpand, nNodeID);

		// Always expand the dummy title to show all rights
		TreeCompositeNode node = (TreeCompositeNode) m_Root.GetNode(nNodeID);
		node.m_bExpanded = true;

		// Populate with Profile Sections
		try
		{
			// open the CV -jas
			IPTProfilePage ptCredentialVault = (IPTProfilePage)((IPTSession) m_asOwner.GetUserSession()).GetProfilePages().Open(PT_INTRINSICS.PT_PROFILE_PAGE_CREDENTIAL_VAULT, false);
			
			// get the list of sections, put them in a hash -jas
			Object[] arrSections = ptCredentialVault.GetChildSections();
			XPHashtable mapSections = new XPHashtable();
			for (int i = 0; i < arrSections.length; i++)
			{
				mapSections.PutElement(arrSections[i], null);
			}
			
			IPTObjectManager ptSectionManager = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();

			// I get all the profile sections, then filter them myself using the hash.  This is because the list is
			//	stored in a property bag and thus not queryable.  I don't expect a large volume of profile sections
			//	so I'm hoping this won't be a major issue. -jas
			ASQueryResultWrapper query = new ASQueryResultWrapper(ptSectionManager.SimpleQuery(-1, PT_PROPIDS.PT_PROPID_NAME));

			TreeLeafNode myLeaf;
			int nNumCredVaults = query.GetCount();

			// A stored array of User infos. We need this in order to be able to 
			// uniquely identify each CredVault with an integer (rather than re-write the whole
			// damn Tree to support indexing by string).
			m_xpalKnownCredVaults = new XPArrayList();

			for (int nMapIndex = 0; nMapIndex < nNumCredVaults; nMapIndex++)
			{
				Integer ObjectID = (Integer)query.GetFields(nMapIndex, PT_PROPIDS.PT_PROPID_OBJECTID);
				
				// only show sections that belong to the CV -jas
				if (mapSections.ContainsKey(ObjectID))
				{
					String strCurrentCredVault = XPConvert.ToString(query.GetFields(nMapIndex, PT_PROPIDS.PT_PROPID_NAME));

					// AGC- we need to keep track of the mapped items so we can do
					// selection properly.	        	
					int nCurrentCredVaultIndex = m_xpalKnownCredVaults.Add(strCurrentCredVault);
					myLeaf				   = new TreeLeafNode(GetNextUniqueID());
					myLeaf.SetName(strCurrentCredVault);
					myLeaf.m_nObjectID     = XPConvert.ToInteger(ObjectID);
					myLeaf.m_nClassID	   = PT_CLASSIDS.PT_PROFILESECTION_ID; //AGC- Not Used.
					
					myLeaf.m_Image = (HTMLImg)UIConstructFactory.GetConstruct(PTImageType.ICON_LOCKBOX).GetHTMLElement();

					// TODOCR: donh myLeaf.GetName() returns the name truncated to 50,
					// and myLeaf.GetEncodedName() returns it truncated and HTMLEncoded
					// The data is stored in the encoded format, so GetEncodedName
					// is faster than GetName().  The truncation may cause problems
					// here.
					if (m_xpalSelected.Contains(myLeaf.GetName()))
					{
						myLeaf.m_bSelected = true;
						m_xpmSelectedItems.PutElement(myLeaf.m_nClassID + "," +
								myLeaf.m_nObjectID, myLeaf);
					}
	
					node.AddLeafChild(myLeaf);
				}
			}
		}
		catch (Exception ex)
		{
			
				log.Error("CredVaultTreeModel::Expand Node Unable to load lockbox tree.  The following exception occured: " +
					ex);
			

			throw new XPException(m_asOwner.GetString(2870, "ptmsgs_portaladminmsgs"), ex);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the list of CredVault strings that the Tree knows about (is
	 * displaying).
	 *
	 * @return XPArrayList
	 */
	public XPArrayList GetTreeCredVaults()
	{
		return m_xpalKnownCredVaults;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
	}

	/**
	 * Initializes and begins the loading of the tree.
	 */
	public void LoadCredVault()
	{
		// Root is simply a dummy title
		m_Root				 = new TreeCompositeNode(GetNextUniqueID());
		m_Root.SetName(m_asOwner.GetString(2871, "ptmsgs_portaladminmsgs"));

		if (!m_bShowRoot)
		{
			ExpandNode(true, m_Root.m_nTreeNodeID);
		}
	}

	/**
	 * If there are multiple class ids, determine which
	 * ones to display.  For User Info, we only
	 * have 1 class id, so this method is unimplemented.
	 *
	 * @param nIDs determines which classids to display
	 */
	public void SetClassIDsToDisplay(int[] nIDs)
	{
		// User Info do not need this currently.
	}

	/**
	 * Determines what items in the tree are to be displayed.
	 *
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToDisplay(int[])
	 *
	 * @param nIDs determines which nodes are not hidden.
	 */
	public void SetObjectIDsToDisplay(int[] nIDs)
	{
	}

	/**
	 * Determines what items in the tree are hidden.
	 *
	 * @see com.plumtree.uiinfrastructure.tree.ITreeModel#SetObjectIDsToHide(int[])
	 *
	 * @param nIDs determines which nodes are hidden
	 */
	public void SetObjectIDsToHide(int[] nIDs)
	{
		// User Info do not need this currently.
	}

	/**
	 * Determines what items in the tree are selected.
	 *
	 * @param nIDs determines which nodes are selected
	 */
	public void SetObjectIDsToSelect(int[] nIDs)
	{
		// AGC- Not used by User Info
	}

	/**
	 * Sets the userinfos that are currently selected.
	 *
	 * @param arsCredVaults
	 */
	public void SetCredVaultsToSelect(XPArrayList xpalCredVaults)
	{
		ClearSelectedItems();
		m_xpalSelected = xpalCredVaults;
	}

	/**
	 * Sets the userinfos that are currently selected.
	 *
	 * @param arsCredVaults
	 */
	public void SetCredVaultsToSelect(String[] arsCredVaults)
	{
		SetCredVaultsToSelect(WSModelHelper.StringArrayToXPArray(arsCredVaults));
	}

}

