/**
 * Created on Oct 30, 2002
 *
 * To change this generated comment edit the template variable "filecomment":

 * To enable and disable the creation of file comments go to

 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author adolfoc
 *
 */
public class AWSSettingsPluginModel extends EditorHelperModel
	implements IAWSSettingsPluginModelRO, IWSSubModel
{
	
	public static final String STR_MVC_CLASS_NAME = "AWSSettingsPlugin";

	/**
	 * This mask is used by our view to send time data to us in units that we
	 * support.
	 */
	public static final int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES |
		PTDurationCombo.DISPLAYSECONDS;
		
	/**
	 * This is the default soap timeout for Authentication - 30 seconds.
	 */
	public static final long DEFAULT_AUTH_SOAP_TIMEOUT = 30 * 1000;

	/**
	 * This is the default soap timeout for Synchronization - 5 minutes.
	 */
	public static final long DEFAULT_SYNC_SOAP_TIMEOUT = 5 * 60 * 1000;
	
	/**
	 * Timeout information for Authentication.
	 */
	protected PTDuration m_ptdAuthSOAPTimeout;
	
	/**
	 * Timeout information for Synchronization.
	 */
	protected PTDuration m_ptdSyncSOAPTimeout;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * The location of the Authentication URL for this Web Service.
	 */
	private String m_strAuthURL = "";

	/**
	 * We might get the Remote Server Base URL from
	 * our parent model if it is a WebService Model. It is stored here.
	 */
	private String m_strBaseURL = "";

	/**
	 * The location of the Synchronization URL for this Web Service.
	 */
	private String m_strSyncURL = "";

	public AWSSettingsPluginModel()
	{
		super();
		m_ptdAuthSOAPTimeout = new PTDuration(DEFAULT_AUTH_SOAP_TIMEOUT, NMASK_SUPPORTED_UNITS);
		m_ptdSyncSOAPTimeout = new PTDuration(DEFAULT_SYNC_SOAP_TIMEOUT, NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AWSSettingsPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PTC_HTTPAWS_AUTHURL, m_strAuthURL);
		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PTC_HTTPAWS_SYNCURL, m_strSyncURL);
		
		// aj: persist the auth timeout seperately from the sync timeout
		WSModelHelper.PBWrite(ptProviderInfo,
				AExtensibilityConstants.PTC_HTTPAWS_AUTH_TIMEOUT,
				m_ptdAuthSOAPTimeout.GetMilliseconds());
		WSModelHelper.PBWrite(ptProviderInfo,
				AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
				m_ptdSyncSOAPTimeout.GetMilliseconds());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
		m_strBaseURL = strRemoteServerBaseURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * The location of the Authentication URL for this Web Service.
	 * @returns String
	 */
	public String GetAuthURL()
	{
		return m_strAuthURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()
	 */
	public String GetBaseURL()
	{
		return m_strBaseURL;
	}

	/**
	 * Returns timeout setting for Authentication.
	 *
	 * @return PTDuration
	 */
	public PTDuration GetAuthDuration()
	{
		return m_ptdAuthSOAPTimeout;
	}
	
	/**
	 * Returns timeout setting for Synchronization.
	 *
	 * @return PTDuration
	 */
	public PTDuration GetSyncDuration()
	{
		return m_ptdSyncSOAPTimeout;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * The location of the Synchronization URL for this Web Service.
	 * @returns String
	 */
	public String GetSyncURL()
	{
		return m_strSyncURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return AWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		SetAuthURL(WSModelHelper.PBReadString(ptProviderInfo,
				AExtensibilityConstants.PTC_HTTPAWS_AUTHURL, m_strAuthURL));
		SetSyncURL(WSModelHelper.PBReadString(ptProviderInfo,
				AExtensibilityConstants.PTC_HTTPAWS_SYNCURL, m_strSyncURL));
		
		// aj: load the timeouts seperately
		m_ptdAuthSOAPTimeout = 
			new PTDuration(
					WSModelHelper.PBReadInt(
							ptProviderInfo,
							AExtensibilityConstants.PTC_HTTPAWS_AUTH_TIMEOUT,
							m_ptdAuthSOAPTimeout.GetMilliseconds()), 
					NMASK_SUPPORTED_UNITS);
		m_ptdSyncSOAPTimeout = 
			new PTDuration(
					WSModelHelper.PBReadInt(
							ptProviderInfo, 
							AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT, 
							m_ptdSyncSOAPTimeout.GetMilliseconds()), 
					NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		SetAuthURL(WSModelHelper.GetFormElementString(_htFormData,
				AWSSettingsPluginView.HTMLINPUT_AUTH_URL, GetAuthURL()));
		SetSyncURL(WSModelHelper.GetFormElementString(_htFormData,
				AWSSettingsPluginView.HTMLINPUT_SYNC_URL, GetSyncURL()));

		// aj: we want to detect bad stuff with a negative timeout default
		PTDuration ptdDefault = new PTDuration(-1L, NMASK_SUPPORTED_UNITS);
		
		// aj: grab the two timeouts from the form data
		m_ptdAuthSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				AWSSettingsPluginView.HTMLINPUT_AUTH_TIMEOUT_DURATION,
				AWSSettingsPluginView.HTMLSELECT_AUTH_TIMEOUT_UNITS, ptdDefault);
		m_ptdSyncSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				AWSSettingsPluginView.HTMLINPUT_SYNC_TIMEOUT_DURATION,
				AWSSettingsPluginView.HTMLSELECT_SYNC_TIMEOUT_UNITS, ptdDefault);

		int nValid = RepostControl.PAGE_STATUS_VALID;

		if ((null == m_strBaseURL) || (m_strBaseURL.length() <= 0))
		{
			// AGC- Validation: When the BaseURL is not set, we must validate both that the URLS are non empty, and that
			// the ones that are non-empty are valid URLs. We cannot do this through concatenation (too bad).
			nValid = WSModelHelper.ValidateNonEmptyString(m_strAuthURL +
					m_strSyncURL, m_asOwner,
					m_asOwner.GetString(1047, "ptmsgs_portaladminmsgs"), nValid);

			if ((null != m_strAuthURL) && (m_strAuthURL.length() > 0))
			{
				nValid = WSModelHelper.ValidateIsURLString(m_strAuthURL,
						m_asOwner, m_asOwner.GetString(1916, "ptmsgs_portaladminmsgs"), nValid);
			}

			if ((null != m_strSyncURL) && (m_strSyncURL.length() > 0))
			{
				nValid = WSModelHelper.ValidateIsURLString(m_strSyncURL,
						m_asOwner, m_asOwner.GetString(1917, "ptmsgs_portaladminmsgs"), nValid);
			}
		}
		else
		{
			// AGC- Validation: Either the AuthURL or the SyncURL must be set, so we can validate this be checking that the concat is non-empty.		
			nValid = WSModelHelper.ValidateNonEmptyString(m_strAuthURL +
					m_strSyncURL, m_asOwner,
					m_asOwner.GetString(1047, "ptmsgs_portaladminmsgs"), nValid);
		}

		// aj: verify the two timeouts
		//	a) auth should be between 1 second and 5 minutes
		//	b) sync should be between 1 second and 360 minutes ( 6 hours)
		nValid = WSModelHelper.ValidateDurationRange(m_ptdAuthSOAPTimeout,
				m_asOwner, m_asOwner.GetString(1918, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 90);
		nValid = WSModelHelper.ValidateDurationRange(m_ptdSyncSOAPTimeout,
				m_asOwner, m_asOwner.GetString(3133, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 60 * 6);

		return nValid;
	}

	/**
	 * The location of the Authentication  URL for this Web Service.
	 */
	public void SetAuthURL(String strAuthURL)
	{
		m_strAuthURL = strAuthURL.trim();
	}

	/**
	 * The location of the Synchronization URL for this Web Service.
	 */
	public void SetSyncURL(String strSyncURL)
	{
		m_strSyncURL = strSyncURL.trim();
	}
}

