package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.constants.ResourceConstants;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class AWSSettingsPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.AWSSettingsPluginView");

	
	public static final String STR_MVC_CLASS_NAME = "AWSSettingsPluginView";

	/**
	 * Seperate URLs for sync vs. auth.
	 */
	public static final String HTMLINPUT_AUTH_URL		  = "in_tx_AuthURL";
	public static final String HTMLINPUT_SYNC_URL		  = "in_tx_SyncURL";
	
	/**
	 * Authentication timeout & units.
	 */
	public static final String HTMLINPUT_AUTH_TIMEOUT_DURATION = "in_tx_AuthTimeout";
	public static final String HTMLSELECT_AUTH_TIMEOUT_UNITS = "in_se_AuthTimeoutUnits";
	
	/**
	 * Synchronization timeout & units.
	 */
	public static final String HTMLINPUT_SYNC_TIMEOUT_DURATION = "in_tx_SyncTimeout";	
	public static final String HTMLSELECT_SYNC_TIMEOUT_UNITS = "in_se_SyncTimeoutUnits";

	/**
	 * The name of our validation function. This must be added by the Page to the
	 * page level validation function. See WSPluginDP for details.
	 */
	public static final String VALIDATION_FUNCTION_NAME = "IsValidAWSSettings";

	/** Localized String: The SOAP timeout must be a valid integer between 1 second and 90 minutes */

	
	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AWSSettingsPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1049, "ptmsgs_portaladminmsgs")));

			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, "5");

			// 1st row ends
			// 2nd row begins
			String strBaseURL = ((IAWSSettingsPluginModelRO) m_model).GetBaseURL();

			//////// Auth URL
			String strDefault = ((IAWSSettingsPluginModelRO) m_model).GetAuthURL();
			WSViewHelper.AddSimpleEditBox(myTable, 5,
				m_asOwner.GetString(1050, "ptmsgs_portaladminmsgs"),
				strBaseURL, strDefault, HTMLINPUT_AUTH_URL);

			//////// Auth URL Timeout
			PTDuration ptdDefault = ((IAWSSettingsPluginModelRO) m_model).GetAuthDuration();
			WSViewHelper.AddSimpleDurationCombo(myTable, 5,
				m_asOwner.GetString(1052, ResourceConstants.PORTALADMINMSGS),
				HTMLINPUT_AUTH_TIMEOUT_DURATION, HTMLSELECT_AUTH_TIMEOUT_UNITS, ptdDefault, m_asOwner);
			
			//////// Sync URL
			strDefault = ((IAWSSettingsPluginModelRO) m_model).GetSyncURL();
			WSViewHelper.AddSimpleEditBox(myTable, 5,
				m_asOwner.GetString(1051, "ptmsgs_portaladminmsgs"),
				strBaseURL, strDefault, HTMLINPUT_SYNC_URL);
			
			//////// Sync URL Timeout
			ptdDefault = ((IAWSSettingsPluginModelRO) m_model).GetSyncDuration();
			WSViewHelper.AddSimpleDurationCombo(myTable, 5,
				m_asOwner.GetString(3134, ResourceConstants.PORTALADMINMSGS),
				HTMLINPUT_SYNC_TIMEOUT_DURATION, HTMLSELECT_SYNC_TIMEOUT_UNITS, ptdDefault, m_asOwner);

			//Spacer Row
			WSViewHelper.AddEmptyRow(myTable, "5");



			// 6th row (spacer row)
			WSViewHelper.AddEmptyRow(myTable, "5");
		}
		catch (Exception e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1048,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result  = new HTMLScript("text/javaScript");
		XPStringBuilder sb = new XPStringBuilder(400);

		try
		{
			sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
			sb.Append("{\n");

			WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);

			if (WebServiceModel.WSMODE_AWS == mParent.GetWSMode())
			{
				sb.Append(WSViewHelper.ValidateNumericInputJS(
						WSPluginDP.HTMLFORM_NAME,
						AWSSettingsPluginView.HTMLINPUT_AUTH_TIMEOUT_DURATION,
						m_asOwner.GetString(1053, "ptmsgs_portaladminmsgs")));
			}

			sb.Append(" 	return true;\n");
			sb.Append("}\n\n");
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he.GetMessage());
		}

		return result;
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

