/**
 * Created on Oct 30, 2002
 *
 * To change this generated comment edit the template variable "filecomment":

 * To enable and disable the creation of file comments go to

 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.group.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author adolfoc
 *
 */
public class ActSecurityPluginModel extends SelectActivityRightsModel
	implements IActSecurityPluginModelRO, IWSSubModel
{
	
	public static final String STR_MVC_CLASS_NAME = "ActSecurityPlugin";

	/**
	 * Every Growable list used within an editor must have a unique ID. It just
	 * so happens that it is easy to accidentally collide (since the unique ID's
	 * are set to 0 and 1 a lot). I'm going to give myself an offset, so that I
	 * am less likely to collide with someone else's unique ID). It doesn't really
	 * matter what this number is, as long as no one else chooses the same one for
	 * another ExpList.
	 */
	private static final int m_nUniqueIDOffset = 636;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * This list of rights includes rights found in the Web Service that the
	 * user does not have the ability to change (not in the list of rights they
	 * can select). This list is remembered so that it can be re-added to
	 * the Web Service when we are done.
	 */
	private XPArrayList m_xpalURI_RightsNotForDisplay;

	public ActSecurityPluginModel()
	{
		super();
		m_xpalURI_RightsNotForDisplay = new XPArrayList();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ActSecurityPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		// Get the URI's for the selected rights.
		// First, query all of the rights I have access to.
		IPTSession ptSession				   = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();
		IPTSessionInfo ptSessionInfo		   = ptSession.GetSessionInfo();
		IPTQueryResult ptQRRightsIHaveAccessTo = ptSessionInfo.QueryActivityRights();

		XPArrayList xpalURI_RightsToStore = new XPArrayList();

		// get newly selected rights
		PTGrowableSortedArrayWrapper saData = GetItems();

		for (int nRights = 0; nRights < saData.GetCount(); nRights++)
		{
			int nCurrentRightID = WSModelHelper.ObjectToInt(saData.GetItem(
						nRights, SelectActivityRightsModel.EXPLIST_COL_OBJECTID),
					-1);

			// It's possible that the rights the user had access to changed while the editor was open.
			// If they lost access to a right, the GetURIFromObjectID will return a blank string. 
			String strCurrentSelectedURI = GetURIFromObjectID(ptQRRightsIHaveAccessTo,
					nCurrentRightID);

			if ((null != strCurrentSelectedURI) &&
					(strCurrentSelectedURI.length() > 0))
			{
				xpalURI_RightsToStore.Add(strCurrentSelectedURI);
			}
		}

		// AGC- Here's where we add back the rights that were originally on this object, but
		// the user didn't have access to...
		int nAccessibleRightsCount = m_xpalURI_RightsNotForDisplay.GetSize();

		for (int nInAccessibleRights = 0;
				nInAccessibleRights < nAccessibleRightsCount;
				nInAccessibleRights++)
		{
			String strCurrentInAccessibleRight = (String) m_xpalURI_RightsNotForDisplay.GetElement(nInAccessibleRights);

			// It's possible that the rights the user had access to changed while the editor was open.
			// This might allow the user to select a right that is already in this not-accessible list.
			// We check to make sure that no duplicates are generated here.	
			if (!xpalURI_RightsToStore.Contains(strCurrentInAccessibleRight))
			{
				xpalURI_RightsToStore.Add(strCurrentInAccessibleRight);
			}
		}

		// Store this into the propertybag at PTC_HTTPGADGET_ACTIVITYRIGHTS as an object array of strings.
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		ptProviderInfo.Write(AExtensibilityConstants.PTC_HTTPGADGET_ACTIVITYRIGHTS,
			xpalURI_RightsToStore.ToArray());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		InitializeSelectList(m_asOwner.GetString(1019, "ptmsgs_portaladminmsgs"),
			
		m_asOwner.GetString(1020, "ptmsgs_portaladminmsgs"),
			PTImageType.ICON_ACTIVITY_RIGHT,
			
		m_asOwner.GetString(1021, "ptmsgs_portaladminmsgs"), new int[] {  },
			m_nUniqueIDOffset, false);

		super.SetEmptyListMessages(m_asOwner.GetString(1022,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(1023, "ptmsgs_portaladminmsgs"));

		/*
		 * The following code is a little complicated, so here's the
		 * explanation:
		 *
		 * This view is editing the list of ActivityRights that will be sent to
		 * the Web Service being edited. There are a few interesting cases that
		 * we need to cover, however:
		 *
		 * 1. The Web Service contains an activity right entered imported via
		 * package that is not yet installed in the system. We want to preserve
		 * these if possible.
		 *
		 * 2. The Web Service contains an activity right that the current user
		 * does not have access to. We do not want to show these to the user or
		 * allow them to remove them if they are set.
		 *
		 */
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		// retrieve activity rights from the property bag
		Object[] aRightsFromWS = ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PTC_HTTPGADGET_ACTIVITYRIGHTS);

		// turn this into an XPArralist so that I can use the Contains method...
		XPArrayList xpalURI_RightsFromWS = WSModelHelper.ObjectArrayToXPArray(aRightsFromWS);

		// Query all of the rights I have access to.
		IPTSession ptSession		 = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();
		IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();

		// Contains the list of Rights the user has access to - including URI, ObjectID and Name.
		IPTQueryResult ptQRRightsIHaveAccessTo = ptSessionInfo.QueryActivityRights();

		// Contains a list of Rights that the user has access to AND are in the WS. This is the
		// list of Rights that will be displayed to the user.		
		XPArrayList xpalURI_RightsToDisplay = new XPArrayList();

		for (int nIndex = 0; nIndex < xpalURI_RightsFromWS.GetSize(); nIndex++)
		{
			String strURI_CurrentRightFromWS = (String) xpalURI_RightsFromWS.GetElement(nIndex);
			// Will be null if the pte is malformed. Happened in bug 906334
			if ( strURI_CurrentRightFromWS != null )
			{
				if (CanSelectAccessRight(ptQRRightsIHaveAccessTo, strURI_CurrentRightFromWS)) {
					xpalURI_RightsToDisplay.Add(strURI_CurrentRightFromWS);
				} else {
					m_xpalURI_RightsNotForDisplay.Add(strURI_CurrentRightFromWS);
				}
			}
		}

		// AGC- It is easier to use two for loops here because we need to know the
		// length of the list of rights to display before building arRightsToDisplay below. 
		// initialize building of data for SelectList
		int nRightsCount			 = xpalURI_RightsToDisplay.GetSize();
		Object[][] arRightsToDisplay = new Object[nRightsCount][SelectActivityRightsModel.EXPLIST_COL_MAX];

		// add rights to data
		for (int nSelectIndex = 0; nSelectIndex < nRightsCount; nSelectIndex++)
		{
			String strCurrentURIForDisplay = (String) xpalURI_RightsToDisplay.GetElement(nSelectIndex);
			
			// retrieve the objectID and Name from the query results
			int nCurrentActivityID   = GetObjectIDFromURI(ptQRRightsIHaveAccessTo,
					strCurrentURIForDisplay);
			String sCurrentRightName = GetNameFromURI(ptQRRightsIHaveAccessTo,
					strCurrentURIForDisplay);

			// build array for SelectPTObject
			arRightsToDisplay[nSelectIndex][SelectActivityRightsModel.EXPLIST_COL_CLASSID]	    = new Integer(PT_CLASSIDS.PT_ACTIVITY_ID);
			arRightsToDisplay[nSelectIndex][SelectActivityRightsModel.EXPLIST_COL_OBJECTID]     = new Integer(nCurrentActivityID);
			arRightsToDisplay[nSelectIndex][SelectActivityRightsModel.EXPLIST_COL_STRING]	    = sCurrentRightName;
		}

		// load data into SelectPTObject
		SetDefaultObjects(arRightsToDisplay);
	}

	/**
	 * 
	 *
	 * @param ptQRRightsIHaveAccessTo 
	 * @param strRightURI 
	 *
	 * @return 
	 */
	private boolean CanSelectAccessRight(IPTQueryResult ptQRRightsIHaveAccessTo, String strRightURI)
	{
		if (null == ptQRRightsIHaveAccessTo)
		{
			return false;
		}

		int nRowCount = ptQRRightsIHaveAccessTo.RowCount();

		for (int nIndex = 0; nIndex < nRowCount; nIndex++)
		{
			if (0 == strRightURI.compareTo(ptQRRightsIHaveAccessTo.ItemAsString(nIndex, PT_PROPIDS.PT_PROPID_ACTIVITY_URI)))
			{
				return true;
			}
		}

		return false;
	}

	/**
	 * 
	 *
	 * @param ptQRRightsIHaveAccessTo 
	 * @param strRightURI 
	 *
	 * @return 
	 */
	private String GetNameFromURI(IPTQueryResult ptQRRightsIHaveAccessTo,
		String strRightURI)
	{
		if (null == ptQRRightsIHaveAccessTo)
		{
			return "";
		}

		int nRowCount = ptQRRightsIHaveAccessTo.RowCount();

		for (int nIndex = 0; nIndex < nRowCount; nIndex++)
		{
			if (0 == strRightURI.compareTo(ptQRRightsIHaveAccessTo.ItemAsString(
							nIndex, PT_PROPIDS.PT_PROPID_ACTIVITY_URI)))
			{
				return ptQRRightsIHaveAccessTo.ItemAsString(
						nIndex, PT_PROPIDS.PT_PROPID_NAME);
			}
		}

		return "";
	}

	/**
	 * 
	 *
	 * @param ptQRRightsIHaveAccessTo 
	 * @param strRightURI 
	 *
	 * @return 
	 */
	private int GetObjectIDFromURI(IPTQueryResult ptQRRightsIHaveAccessTo,
		String strRightURI)
	{
		if (null == ptQRRightsIHaveAccessTo)
		{
			return -1;
		}

		int nRowCount = ptQRRightsIHaveAccessTo.RowCount();

		for (int nIndex = 0; nIndex < nRowCount; nIndex++)
		{
			if (0 == strRightURI.compareTo(ptQRRightsIHaveAccessTo.ItemAsString(
							nIndex, PT_PROPIDS.PT_PROPID_ACTIVITY_URI)))
			{
				return ptQRRightsIHaveAccessTo.ItemAsInt(nIndex, PT_PROPIDS.PT_PROPID_OBJECTID);
			}
		}

		return -1;
	}

	/**
	 * 
	 *
	 * @param ptQRRightsIHaveAccessTo 
	 * @param nRightID 
	 *
	 * @return 
	 */
	private String GetURIFromObjectID(IPTQueryResult ptQRRightsIHaveAccessTo,
		int nRightID)
	{
		if (null == ptQRRightsIHaveAccessTo)
		{
			return "";
		}

		int nRowCount = ptQRRightsIHaveAccessTo.RowCount();

		for (int nIndex = 0; nIndex < nRowCount; nIndex++)
		{
			if (nRightID == ptQRRightsIHaveAccessTo.ItemAsInt(nIndex, PT_PROPIDS.PT_PROPID_OBJECTID))
			{
				return ptQRRightsIHaveAccessTo.ItemAsString(nIndex, PT_PROPIDS.PT_PROPID_ACTIVITY_URI);
			}
		}

		return "";
	}
}

