package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.userinfotree.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class AddUserInfoPluginView extends GrowableListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.AddUserInfoPluginView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "AddUserInfoPluginView";

	/** Localized String: Add Existing User Info */

	/**
	 * HTML Object names */
	public static final String HTMLINPUT_TREEASID = "in_hi_TreeSpaceID";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AddUserInfoPluginView();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		// The URL to open a new tree
		ASURL myNewTree = new ASURL(m_asOwner);

		// Tree creation and binding
		myNewTree.SetLinkCreateNewSpace(UserInfoTreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		myNewTree.SetSubSpaceKey(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
				AddUserInfoPluginModel.SUBSPACE_NAME_SELECTTREE));
		myNewTree.SetControl(UserInfoStartTreeControl.STR_MVC_CLASS_NAME);

		// Tree configuration
		myNewTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
		myNewTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		myNewTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
			((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
				HTMLINPUT_TREEASID));
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
			((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
				"OnReturnFromTree"));
		myNewTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));
//		myNewTree.AddControlArgument(UserInfoRefreshTreeControl.SELECTED_USERINFOS,
//			UserInfoRefreshTreeControl.UserInfosToString(((AddUserInfoPluginModel)m_model).GetListValues()));

		// AGC- Commented out until I figure out how to fix selection.

		/*        myNewTree.AddControlArgument(UserInfoStartTreeControl.SELECTED_ITEMS,
		            ((IAddUserInfoPluginModelRO)m_model).GetSelectedItems());
		            */

		myNewTree.AddControlArgument(AStartTreeControl.TITLE,
			m_asOwner.GetString(2537, "ptmsgs_portaladminmsgs"));

		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		ASURL myOldTree = new ASURL(m_asOwner);
		myOldTree.SetLinkCreateNewSpace(UserInfoTreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		myOldTree.SetControl(UserInfoRefreshTreeControl.STR_MVC_CLASS_NAME);
//		myOldTree.AddControlArgument(UserInfoRefreshTreeControl.SELECTED_USERINFOS,
//			UserInfoRefreshTreeControl.UserInfosToString(((AddUserInfoPluginModel)m_model).GetListValues()));
			
		XPStringBuilder sb;

		try
		{
			String strControlAppend = UserInfoRefreshTreeControl.UserInfoToStringJSFunc(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(""));
			// Open Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function " +
				((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
					"OpenTree") + "(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(myNewTree.GetURLAsString())
			.Append("' + ").Append(strControlAppend).Append(", '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value + ").Append(strControlAppend)
			.Append(", '_blank3', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			// On return from Tree function
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
					"OnReturnFromTree") + "()");
			sb.Append(" {");
			sb.Append(" 	postToSelf('" +
				((IAddUserInfoPluginModelRO) m_model).GetUniqueInt(
					ExpListControl.POSTTOSELF_ACTION_ADD) + "');");
			sb.Append(" }");
			
			sb.Append(UserInfoRefreshTreeControl.UserInfoToStringJS(((IAddUserInfoPluginModelRO) m_model).GetUniqueString(""), HTMLINPUT_ITEM));

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "SelectActivityRightsView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#AddHTMLToActionBar(com.plumtree.xpshared.htmlelements.HTMLTableRow)
	 */
	protected void AddHTMLToActionBar(HTMLTableRow _myRow)
	{
		super.AddHTMLToActionBar(_myRow);
		_myRow.AddInnerHTMLElement(GetHTMLForAddUserInfoAction());
	}

	/**
	 * Returns the HTML for the add cell in the action bar.
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAddUserInfoAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;
		HTMLInput myInput;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// Add icon
		HTMLImg myAddIcon;
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
				true, this.m_asOwner);
		myAddIcon		    = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");
		
		// Object icon
		myConstruct     = UIConstructFactory.GetConstruct(((IAddUserInfoPluginModelRO) m_model).GetAddIcon(),
				true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		// mj: replaced the following line with a blank constructur and SetOnClick()
		// myAnchor = new HTMLAnchor(
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(
				((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
					"OpenTree") + "(document." + AFormDP.HTMLFORM_NAME + "." +
				((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
					HTMLINPUT_TREEASID) + ");");
		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(m_asOwner.GetString(1911, "ptmsgs_portaladminmsgs"));
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
		myCell.AddInnerHTMLString(SPACE);

		// hidden input with the tree space ID
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				((IAddUserInfoPluginModelRO) m_model).GetUniqueString(
					HTMLINPUT_TREEASID), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((IAddUserInfoPluginModelRO) m_model).GetTreeSpaceID());

		return myCell;
	}
	
	/**
	 * Returns the HTML for the add cell in the action bar.
	 *
	 * @return HTMLTableCell
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_NEW,
				true, this.m_asOwner);
		myAddIcon		    = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");
		
		// Object icon
		myConstruct     = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
				true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.AddInnerHTMLString(SPACE);
		myAnchor.SetOnClick("postToSelf('" +
			((IExpListModelRO) m_model).GetUniqueInt(
				ExpListControl.POSTTOSELF_ACTION_ADD) + "'); return false;");
		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);

		return myCell;
	}

}

