package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class AssocObjectsPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.AssocObjectsPluginView");

	
	public static final String STR_MVC_CLASS_NAME = "AssocObjectsPluginView";

	/**
	 * List of CLASSIDs to display in the associated objects view
	 */
	int[] m_arnCLASSIDSToDisplay;

	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * A simple boolean for determining wether the next row should be grey or not.
	 */
	private boolean m_bRowColor = true;

	public AssocObjectsPluginView()
	{
		super();
		m_arnCLASSIDSToDisplay = new int[]{PT_CLASSIDS.PT_GADGET_ID, PT_CLASSIDS.PT_GADGETTEMPLATE_ID, PT_CLASSIDS.PT_AUTHSOURCE_ID, PT_CLASSIDS.PT_DATASOURCE_ID, PT_CLASSIDS.PT_FEDERATEDPORTAL_ID, PT_CLASSIDS.PT_PROFILESOURCE_ID};
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AssocObjectsPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1042, "ptmsgs_portaladminmsgs")));

			// Containing Table
			myTable = WSViewHelper.AddListTable(result);

			// row 1 begins - The header for the object table.			
			//mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_asOwner.GetString(722, "ptmsgs_portaladminmsgs")));
			// The headers:
			String[] arsHeaders = new String[4];
			arsHeaders[0]     = "";
			arsHeaders[1]     = m_asOwner.GetString(1043,
					"ptmsgs_portaladminmsgs");
			arsHeaders[2]     = m_asOwner.GetString(1044,
					"ptmsgs_portaladminmsgs");
			arsHeaders[3]	  = m_asOwner.GetString(1915, "ptmsgs_portaladminmsgs");					
			WSViewHelper.AddSimpleTableHeader(myTable, arsHeaders);


			// rows 2-x begin - The table itself.
			int nItemsDisplayed = 0;

			for (int nIndex = 0; nIndex < m_arnCLASSIDSToDisplay.length;
					nIndex++)
			{
				int nCLASSID = m_arnCLASSIDSToDisplay[nIndex];

				IASQueryResult ptQRAssocWebServices = ((IAssocObjectsPluginModelRO) m_model).GetAssocObjects(nCLASSID);

				if ((null != ptQRAssocWebServices) &&
						(ptQRAssocWebServices.GetCount() > 0))
				{
					nItemsDisplayed += DisplayObjectList(myTable,
						ptQRAssocWebServices, nCLASSID);
				}
			}

			if (nItemsDisplayed <= 0)
			{
				myRow = WSViewHelper.AddRow(myTable);				
				WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.THREE,
					m_asOwner.GetString(1046, "ptmsgs_portaladminmsgs"));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "AssocWebServicesView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1041,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/** Returns a collection of rows and what not that can be added to a table. */
	public int DisplayObjectList(HTMLTable parentTable,
		IASQueryResult ptQRtoDisplay, int nCLASSID)
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		int nMaxCount = ptQRtoDisplay.GetCount();

		WebServiceModel mParent = (WebServiceModel) m_asasParent.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
		IPTSession ptSession    = mParent.GetPTSession();
		String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE, m_asOwner);

		for (int nRowIndex = 0; nRowIndex < nMaxCount; nRowIndex++)
		{
			myRow = WSViewHelper.AddRow(parentTable);

			// Add Class description			
			String strProvCLSID						    = WSViewHelper.GetQRValueAsString(ptQRtoDisplay,
					nRowIndex, PT_PROPIDS.PT_PROPID_GADGET_PROVIDERCLSID);

			// Icon
			myCell = WSViewHelper.AddIconCell(myRow, CommonHTMLStrings.ONE,
					nCLASSID, strProvCLSID, strLangID);

			// Do the alternate color line thingy.
			WSViewHelper.SetRowColor(myCell, m_bRowColor);

			
			int nObjectID  = WSViewHelper.GetQRValueAsInt(ptQRtoDisplay,
					nRowIndex, PT_PROPIDS.PT_PROPID_OBJECTID);
			int nFolderID  = WSViewHelper.GetQRValueAsInt(ptQRtoDisplay,
					nRowIndex, PT_PROPIDS.PT_PROPID_FOLDERID);
			String strPath = WSViewHelper.GetAdminFolderPath(ptSession,
					nFolderID);
			String strName = WSViewHelper.GetQRValueAsString(ptQRtoDisplay,
					nRowIndex, PT_PROPIDS.PT_PROPID_NAME);


			// Name
			myCell		   = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE, "");
			mySpan		   = WSViewHelper.AddSpanToCell(myCell);
			mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
			mySpan.AddInnerHTMLElement(WSViewHelper.MakeEditObjectLink(
					nCLASSID, nObjectID, strName, m_asOwner));
			mySpan.AddInnerHTMLString(SPACE);

			// AGC- Add the Description on the following line.
			// Description
			Object objValue = ptQRtoDisplay.GetFields(nRowIndex,
					PT_PROPIDS.PT_PROPID_DESCRIPTION);
			String strDesc  = "";

			if (null != objValue)
			{
				strDesc = XPConvert.ToString(objValue);
			}
			
			if ((null != strDesc) && (strDesc.length() > 0))
			{
				mySpan = WSViewHelper.AddSpanToCell(myCell);
				mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
				mySpan.AddInnerHTMLElement(new HTMLBr());
				mySpan.AddInnerHTMLEncodedString(strDesc);
			}

			// Do the alternate color line thingy.
			WSViewHelper.SetRowColor(myCell, m_bRowColor);
			
			// Path
			myCell		   = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
			mySpan		   = WSViewHelper.AddSpanToCell(myCell);
			mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
			mySpan.AddInnerHTMLEncodedString(strPath);
			mySpan.AddInnerHTMLString(SPACE);

			// Do the alternate color line thingy.
			WSViewHelper.SetRowColor(myCell, m_bRowColor);

			// Type
			myCell = WSViewHelper.AddTypeCell(myRow, CommonHTMLStrings.ONE,
					nCLASSID, strProvCLSID, strLangID);

			// Do the alternate color line thingy.
			WSViewHelper.SetRowColor(myCell, m_bRowColor);


			m_bRowColor = !m_bRowColor;
		}

		return nMaxCount;
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

