/**
 * Created on Oct 29, 2002 To change this generated comment edit the template
 * variable "filecomment": Window>Preferences>Java>Templates. To enable and
 * disable the creation of file comments go to Window>Preferences>Java>Code
 * Generation.
 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.security.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.constants.ResourceConstants;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author adolfoc
 */
public class BasicAuthPluginModel extends EditorHelperModel
	implements IBasicAuthPluginModelRO, IWSSubModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.BasicAuthPluginModel");

	/**
	 * Localized String: Error String: You must specify a user name and
	 * password in order to use Administrator basic authentication settings
	 */

	/** This object's name */
	public static final String STR_MVC_CLASS_NAME = "BasicAuth";

	/**
	 * The following static strings are used by the Section as values returned by
	 * the Authentication Type radio buttons. The HTMLRADIO_BASE_AUTH_TYPE
	 * input must return one and only one of these strings. The value of these
	 * strings is irrelevant - they merely must be unique and URL/HTML safe.
	 */
	public static final int AUTHTYPE_REMOTE_SERVER = 0;
	public static final int AUTHTYPE_USER = 1;
	public static final int AUTHTYPE_ADMIN = 2;
	public static final int AUTHTYPE_LOCKBOX = 3;

	/** This response variable gets us the Basic Auth Settings */
	public static final String HTMLRADIO_BASE_AUTH_TYPE = "in_ra_BaseAuthType";

	/** This response variable gets us the Login Name */
	public static final String HTMLINPUT_LOGIN_NAME = "in_tx_LoginName";

	/** This response variable gets us the Password */
	public static final String HTMLINPUT_PASSWORD = "in_pw_Password";

	/**
	 * This string is used in lieu of returning the actual password to the
	 * client. If this string is unchanged - we will assume that the client
	 * has not changed the password and not reset it.
	 */
	public static final String NULL_PASSWORD = "************";

	/** The Web Service object being edited by our parent Web Service editor */
	IPTWebService m_ptWebService = null;

	/** This member contains our Login Name */
	private String m_strLoginName = "";

	/**
	 * This member is used in determining whether the login name has changed
	 * (if the object was edited, say). We use this in order to determine when
	 * to blank the password when the object is edited.
	 */
	private String m_strOriginalLoginName = "";

	/** This member contains our Password */
	private String m_strPassword = "";

	/** This member contains our Basic Auth settings */
	private int m_intAuthTypeRadio;

	public BasicAuthPluginModel()
	{
		super();
		m_intAuthTypeRadio = AUTHTYPE_REMOTE_SERVER;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new BasicAuthPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		// Set the Authentication Info
		switch (m_intAuthTypeRadio)
		{
		case AUTHTYPE_USER:
		case AUTHTYPE_LOCKBOX:
			ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME);
			ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD);
			
			// aj: AUTHTYPE_USER => PlumtreeExtensiblity.BASIC_AUTH_TYPE_PORTAL_AUTH (1)
			//     AUTHTYPE_LOCKBOX => PlumtreeExtensbility.BASIC_AUTH_TYPE_LOCKBOX_AUTH (2)
			WSModelHelper.PBWrite(ptProviderInfo,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
				((m_intAuthTypeRadio == AUTHTYPE_USER)?(1):(2)));

			break;

		case AUTHTYPE_ADMIN:
			WSModelHelper.PBWrite(ptProviderInfo,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
				0);

			// Make sure we don't overwrite any existing password if it (and the Login Name)
			// wasn't changed.
			WSModelHelper.PBWrite(ptProviderInfo,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME,
				m_strLoginName);

			if ((0 != NULL_PASSWORD.compareTo(m_strPassword)) ||
					((0 == NULL_PASSWORD.compareTo(m_strPassword)) &&
					(0 != m_strLoginName.compareTo(m_strOriginalLoginName))))
			{
				// AGC- Don't forget to cipher the bastard...
				//MES- CR: Need to handle the case where user changed username but not password- decrypt the old
				//	password and re-encrypt with new username.
				
				IXPCrypto xpcpPass = XPCrypto.GetInstance(XPCryptoType.AES_128);
				
				if (0 == NULL_PASSWORD.compareTo(m_strPassword))
				{
					String strOldCryptedPassword = WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD, "");
					if (strOldCryptedPassword.length() > 0)
					{
						m_strPassword = xpcpPass.Decrypt(strOldCryptedPassword, m_strOriginalLoginName); 
					} 
				}
				
				String strCryptPass		 = xpcpPass.Encrypt(m_strPassword,
						m_strLoginName);

				WSModelHelper.PBWrite(ptProviderInfo,
					AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD,
					strCryptPass);
			}

			break;

		default: //AUTHTYPE_NONE
			ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME);
			ptProviderInfo.Remove(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHPASSWORD);
			WSModelHelper.PBWrite(ptProviderInfo,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION,
				0);
		}

		// If this object is ever accessed again before this model goes away, we want to
		// make sure that the original login name is updated correctly.
		m_strOriginalLoginName = WSModelHelper.PBReadString(ptProviderInfo,
				AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME, "");
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,
	 *      String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * Returns the strAuthTypeRadio.
	 *
	 * @return String
	 */
	public int GetAuthType()
	{
		return m_intAuthTypeRadio;
	}

	/**
	 * Returns the strLoginName. Note that there is no getter for the Password
	 * (it is never sent back to the client).
	 *
	 * @return String
	 */
	public String GetLoginName()
	{
		return m_strLoginName;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();

		if (null != ptProviderInfo)
		{
			m_strLoginName			   = "";
			m_strOriginalLoginName     = "";
			m_strPassword			   = "";
			m_intAuthTypeRadio		   = AUTHTYPE_REMOTE_SERVER;

			if (EditorStartControl.EDITOR_START_FLAG_CREATE != ((WebServiceModel) m_asOwner.GetModel(
						WebServiceModel.STR_MVC_CLASS_NAME)).GetEditorType())
			{
				m_strLoginName = WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_BASICAUTHNAME, m_strLoginName);
				m_strOriginalLoginName     = m_strLoginName;
				m_strPassword			   = NULL_PASSWORD;

				int nGetSendUserAuth = WSModelHelper.PBReadInt(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_SENDUSERBASICAUTHENTICATION, 0);
				
				// aj: 1 => PlumtreeExtensibility.BASIC_AUTH_TYPE_PORTAL_AUTH
				//     2 => PlumtreeExtensibility.BASIC_AUTH_TYPE_LOCKBOX_AUTH
				if (nGetSendUserAuth == 1)
				{
					m_strLoginName			   = "";
					m_strOriginalLoginName     = "";
					m_intAuthTypeRadio		   = AUTHTYPE_USER;
				}
			    else if (nGetSendUserAuth == 2)
			    {
					m_strLoginName			   = "";
					m_strOriginalLoginName     = "";
					m_intAuthTypeRadio		   = AUTHTYPE_LOCKBOX;
			    }
				else if ((null == m_strLoginName) ||
						(0 >= m_strLoginName.length()))
				{
					m_intAuthTypeRadio = AUTHTYPE_REMOTE_SERVER;
				}
				else
				{
					m_intAuthTypeRadio = AUTHTYPE_ADMIN;
				}
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;
		
		SetLoginName(WSModelHelper.GetFormElementString(_htFormData, HTMLINPUT_LOGIN_NAME, GetLoginName()));
		
		SetPassword(WSModelHelper.GetFormElementString(_htFormData, HTMLINPUT_PASSWORD, m_strPassword));
		
		SetAuthType(WSModelHelper.GetFormElementInt(_htFormData, HTMLRADIO_BASE_AUTH_TYPE, GetAuthType()));
		
		// Validation
		if (AUTHTYPE_ADMIN == m_intAuthTypeRadio)
		{
			return WSModelHelper.ValidateLoginPassword(m_strLoginName, m_strPassword, NULL_PASSWORD, m_asOwner, m_asOwner.GetString(1054, "ptmsgs_portaladminmsgs"), RepostControl.PAGE_STATUS_VALID);
		}
		
		// aj: if we're using lock box auth, we need to make
		//     sure a lockbox is selected...
		if(m_intAuthTypeRadio == AUTHTYPE_LOCKBOX)
		{
			// aj: first check if the model exists
			boolean bModelExists = 
				m_asOwner.GetModelExists(WebServiceEditorAS.strStorage_CredentialVaultPluginView);
			int nLockBoxID = 0;
			
			// aj: if the model exists, get the lock box id
			if(bModelExists)
			{
				nLockBoxID = 
				((ICredentialVaultPluginModelRO) 
					m_asOwner.GetModel(WebServiceEditorAS.strStorage_CredentialVaultPluginView))
					.GetLockboxObjectID();
			}
			
			// aj: if either the lockbox didn't exist, or the lockbox is not choosen, 
			//     then we can raise an error here...
			nPageStatus = WSModelHelper.ValidateBool(nLockBoxID != 0, 
					m_asOwner, 
					m_asOwner.GetString(2973, ResourceConstants.PORTALADMINMSGS), 
					nPageStatus);
		}

		return nPageStatus;
	}

	/**
	 * Sets the strAuthTypeRadio.
	 *
	 * @param intAuthTypeRadio The strAuthTypeRadio to set
	 */
	public void SetAuthType(int intAuthTypeRadio)
	{
		// We must receive one of the Radio value strings above (AUTHTYPE_REMOTE_SERVER, 
		// ...USER, ...LOCKBOX or ...ADMIN). These will determine what gets stored in the 
		// Remote Server object.
		switch (intAuthTypeRadio)
		{
		case AUTHTYPE_REMOTE_SERVER:
		case AUTHTYPE_USER:
		case AUTHTYPE_ADMIN:
		case AUTHTYPE_LOCKBOX:
			this.m_intAuthTypeRadio = intAuthTypeRadio;

			break;

		default:

			
				log.Error("BasicAuthSettingsPluginModel::SetAuthType(" +
					intAuthTypeRadio +
					") an invalid AuthType was received. The Authtype will be set to REMOTE SERVER.");
			
		}
	}

	/**
	 * Sets the strLoginName.
	 *
	 * @param strLoginName The strLoginName to set
	 */
	public void SetLoginName(String strLoginName)
	{
		this.m_strLoginName = strLoginName;
	}

	/**
	 * Sets the strPassword. Note that there is no getter for the Password.
	 *
	 * @param strPassword The strPassword to set
	 */
	public void SetPassword(String strPassword)
	{
		if (XPStringUtility.Compare(NULL_PASSWORD, strPassword) != 0)
		{
			this.m_strPassword = strPassword;
		}
	}
}

