package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author adolfoc
 */
public class CWSSettingsPluginModel extends EditorHelperModel
	implements ICWSSettingsPluginModelRO, IWSSubModel
{
	/** This object's name */
	public static final String STR_MVC_CLASS_NAME = "CWSSettings";

	/**
	 * This mask is used by our view to send time data to us in units that we
	 * support.
	 */
	public static final int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES |
		PTDurationCombo.DISPLAYSECONDS;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * We might get the Remote Server Base URL from
	 * our parent model if it is a WebService Model. It is stored here.
	 */
	private String m_strBaseURL = "";

	/** Logging object and booleans */
	/** URL to this Web Service (To be combined with the BaseURL from the Remote Server)
	 * (RemoteServerPluginView) */
	private String m_strContainerURL = "";

	/** Document URL to this Web Service (To be combined with the BaseURL from the Remote Server)
	 * (RemoteServerPluginView) */
	private String m_strDocumentURL = "";

	/** Upload URL to this Web Service (To be combined with the BaseURL from the Remote Server)
	 * (RemoteServerPluginView) */
	private String m_strUploadURL = "";
	
	/**
	 * Timeout information.
	 */
	protected PTDuration m_ptdSOAPTimeout;

	protected PTDuration m_ptdGatewayTimeout;

	public CWSSettingsPluginModel()
	{
		super();
		m_ptdSOAPTimeout = new PTDuration(300000, NMASK_SUPPORTED_UNITS);
		m_ptdGatewayTimeout = new PTDuration(20000, NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CWSSettingsPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT, AExtensibilityConstants.PT_PROPBAG_FORMAT_HTTPGADGET_INIT);
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_CONTAINERURL, GetContainerURL());
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_DOCUMENTURL, GetDocumentURL());
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL, GetUploadURL());
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT, m_ptdSOAPTimeout.GetMilliseconds());
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT, m_ptdGatewayTimeout.GetMilliseconds());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
		m_strBaseURL = strRemoteServerBaseURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetBaseURL()
	 */
	public String GetBaseURL()
	{
		return m_strBaseURL;
	}

	/**
	 * Returns the CWS Container URL
	 *
	 * @return String
	 */
	public String GetContainerURL()
	{
		return m_strContainerURL;
	}

	/**
	 * Returns the CWS Document URL
	 *
	 * @return String
	 */
	public String GetDocumentURL()
	{
		return m_strDocumentURL;
	}

	/**
	 * Returns the CWS Document URL
	 *
	 * @return String
	 */
	public String GetUploadURL()
	{
		return m_strUploadURL;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return CWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
		
		SetContainerURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_CONTAINERURL, m_strContainerURL));
		SetDocumentURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_DOCUMENTURL, m_strDocumentURL));
		SetUploadURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPCWS_UPLOADURL, m_strUploadURL));
		
		m_ptdSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(
					ptProviderInfo,
					AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
					m_ptdSOAPTimeout.GetMilliseconds()), NMASK_SUPPORTED_UNITS);

		m_ptdGatewayTimeout = new PTDuration(WSModelHelper.PBReadInt(
					ptProviderInfo,
					AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT,
					m_ptdGatewayTimeout.GetMilliseconds()), NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		SetContainerURL(WSModelHelper.GetFormElementString(_htFormData, CWSSettingsPluginView.HTMLINPUT_CONTAINER_URL, GetContainerURL()));
		SetDocumentURL(WSModelHelper.GetFormElementString(_htFormData, CWSSettingsPluginView.HTMLINPUT_DOCUMENT_URL, GetDocumentURL()));
		SetUploadURL(WSModelHelper.GetFormElementString(_htFormData, CWSSettingsPluginView.HTMLINPUT_UPLOAD_URL, GetUploadURL()));

		m_ptdSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				CWSSettingsPluginView.HTMLINPUT_TIMEOUT_SOAPDURATION,
				CWSSettingsPluginView.HTMLSELECT_TIMEOUT_SOAPUNITS, m_ptdSOAPTimeout);

		m_ptdGatewayTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				CWSSettingsPluginView.HTMLINPUT_TIMEOUT_GATEWAYDURATION,
				CWSSettingsPluginView.HTMLSELECT_TIMEOUT_GATEWAYUNITS, m_ptdGatewayTimeout);

		int nValid = RepostControl.PAGE_STATUS_VALID;


		if ((null == m_strBaseURL) || (m_strBaseURL.length() <= 0))
		{
			nValid = WSModelHelper.ValidateIsURLString(m_strContainerURL, m_asOwner, m_asOwner.GetString(1919, "ptmsgs_portaladminmsgs"), nValid);
			nValid = WSModelHelper.ValidateIsURLString(m_strDocumentURL, m_asOwner, m_asOwner.GetString(1919, "ptmsgs_portaladminmsgs"), nValid);			
		}
		else
		{
			nValid = WSModelHelper.ValidateNonEmptyString(m_strContainerURL, m_asOwner, m_asOwner.GetString(1072, "ptmsgs_portaladminmsgs"), nValid);
			nValid = WSModelHelper.ValidateNonEmptyString(m_strDocumentURL, m_asOwner, m_asOwner.GetString(1072, "ptmsgs_portaladminmsgs"), nValid);
		}

		nValid = WSModelHelper.ValidateDurationRange(m_ptdSOAPTimeout,
				m_asOwner, m_asOwner.GetString(1920, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 90);


		nValid = WSModelHelper.ValidateDurationRange(m_ptdGatewayTimeout,
				m_asOwner, m_asOwner.GetString(1921, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 90);

		return nValid;
	}

	/**
	 * Sets the CWS Container URL
	 *
	 * @param strWebServiceURL The m_strWebServiceURL to set
	 */
	public void SetContainerURL(String strWebServiceURL)
	{		    	
		m_strContainerURL = strWebServiceURL;
	}

	/**
	 * Sets the CWS Document URL
	 *
	 * @param strWebServiceURL The m_strWebServiceURL to set
	 */
	public void SetDocumentURL(String strWebServiceURL)
	{
		m_strDocumentURL = strWebServiceURL;
	}

	/**
	 * Sets the CWS Document URL
	 *
	 * @param strWebServiceURL The m_strWebServiceURL to set
	 */
	public void SetUploadURL(String strWebServiceURL)
	{
		m_strUploadURL = strWebServiceURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetGatewayDuration()
	 */
	public PTDuration GetGatewayDuration() {
		return m_ptdGatewayTimeout;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ICWSSettingsPluginModelRO#GetSOAPDuration()
	 */
	public PTDuration GetSOAPDuration() {
		return m_ptdSOAPTimeout;
	}

}

