package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author josephs
 *
 */
public class CredentialVaultPluginModel extends EditorHelperModel
	implements ICredentialVaultPluginModelRO, IWSSubModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		CredentialVaultPluginModel.class);

	public static final String STR_MVC_CLASS_NAME = "CredentialVaultPlugin";

	/**
	 * This member defines a static string used to identify when m_htFormData
	 * has been initialized.
	 */
	public static final String DEFAULTDATA = "Default Data";

	// Name of template (null means nothing selected)
	protected String m_strLockboxName = null;

	/**
	 * Tree Data for the Remote Server for this Web Service (Remote Server)
	 */

	// Object ID of template (0 means nothing selected)
	protected int m_nLockboxObjectID = 0;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * This member contains form data sent to this control (used for the Tree control, mostly).
	 */
	private XPHashtable m_htFormData;

	public CredentialVaultPluginModel()
	{
		super();
		m_htFormData = new XPHashtable();
	}

	/**
	 * This method clears the selected items from the tree.
	 */
	public void ClearLockbox()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(
						WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE))
			{
				AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE);
				ATreeModel treeModel  = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
				treeModel.ClearSelectedItems();
			}

			m_nLockboxObjectID     = 0;
			m_strLockboxName	    = "";

		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			
			log.Warn(e, "Unable to clear Lockbox.");
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CredentialVaultPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		// store settings to the provider info property bag -jas
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_LOCKBOX_ID, m_nLockboxObjectID);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)
	 */
	public String GetData(String name)
	{
		String[] values = (String[]) m_htFormData.GetElement(name);

		if (values == null)
		{
			return DEFAULTDATA;
		}

		return values[0];
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the name of the Remote Server
	 *
	 * @return String
	 */
	public String GetLockboxName()
	{
		return m_strLockboxName;
	}

	/**
	 * Returns the name of the Remote Server
	 *
	 * @return String
	 */
	public int GetLockboxObjectID()
	{
		return m_nLockboxObjectID;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(IPTWebService)
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		// read settings from provider info -jas
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();		
		m_nLockboxObjectID = WSModelHelper.PBReadInt(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_LOCKBOX_ID, m_nLockboxObjectID);

		if (0 != m_nLockboxObjectID)
		{
			// read the name -jas
			try
			{
				IPTObjectManager ptSectionManager = ((IPTSession) m_asOwner.GetUserSession()).GetProfileSections();
				IPTProfileSection ptSection = (IPTProfileSection)ptSectionManager.Open(m_nLockboxObjectID, false);

				m_strLockboxName     = ptSection.GetLocalizedName();
			}
			catch (Exception e)
			{
				
				log.Warn(e, "Unable to access Lockbox object: " + e.getMessage());				
			}
		}
	}

	/**
	 * This method gets the selected items from the tree.
	 */
	public void RefreshItemFromTree()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE))
			{
				AActivitySpace asTree  = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_LOCKBOX_SUBSPACE);
				ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList itemList   = treeModel.GetSelectedItems();

				if (itemList.GetSize() > 0)
				{
					TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);
	
					if (item == null)
					{
						
							log.Error("Tree selected item null");
						
					} else 
					{
						m_nLockboxObjectID     = item.m_nObjectID;
						m_strLockboxName	    = item.GetName();
					}
				}
			}
		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			
				log.Warn(e, "Unknown Error RefreshItemFromTree.");
			
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		// Store our form data for later use - especially for use in the tree control.
		int nSize				 = _htFormData.GetSize();
		IXPEnumerator xpKeys     = _htFormData.GetKeys();

		for (int i = 0; i < nSize; i++)
		{
			xpKeys.MoveNext();
			
			m_htFormData.PutElement((String) xpKeys.GetCurrent(),
				(String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
		}

		RefreshItemFromTree();

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ICredentialVaultPluginModelRO#IsRemoteServerSecure()
	 */
	public boolean IsRemoteServerSecure() {
		// TODO Auto-generated method stub
		return true;
	}

}

