
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.OpenLogService;
import com.plumtree.openlog.OpenLogger;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.ATreeAS;
import com.plumtree.uiinfrastructure.tree.ATreeModel;
import com.plumtree.uiinfrastructure.tree.ITreeModelRO;
import com.plumtree.uiinfrastructure.tree.TreeLeafNode;

/**
 * @author JaneD
 *
 */
public class DebugPortletPluginModel extends EditorHelperModel
	implements IDebugPortletPluginModelRO, IWSSubModel
{
	
	public static final String STR_MVC_CLASS_NAME = "DebugPortletPlugin";

	/**
	 * This member defines a static string used to identify when m_htFormData
	 * has been initialized.
	 */
	public static final String DEFAULTDATA = "Default Data";
	
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
			"com.plumtree.portalpages.admin.editors.webservice.plugins.DebugPortletPluginModel");
	
	/**
	 * This member contains form data sent to this control (used for the Tree control, mostly).
	 */
	private XPHashtable m_htFormData;
	
	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * Portlet id of the portlet for which the debug tracing is turned on.
	 * Zero means no portlet selected (i.e. tracing on for ALL portlets). 
	 */
	private int m_nPortletID = 0;
	
	/**
	 * Name of the portlet for which the debug tracing is turned on.
	 * If this is null, that means no portlet is selected (i.e. tracing on for ALL portlet).
	 */
	private String m_strPortletName = null;
	
	/**
	 * ID of the web service being edited.
	 */
	private int m_nWebServiceID = 0;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DebugPortletPluginModel();
	}

	public DebugPortletPluginModel()
	{
		super();
		m_htFormData = new XPHashtable();
	}
	
	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		
		WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_DEBUG_PORTLET_ID, m_nPortletID);
		
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()
	 */

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;
		
		m_nWebServiceID = m_ptWebService.GetObjectID();

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		m_nPortletID = WSModelHelper.PBReadInt(ptProviderInfo,  PlumtreeExtensibility.PT_DEBUG_PORTLET_ID, m_nPortletID);
		
		UpdatePortletName();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		// Store our form data for later use - especially for use in the tree control.
		int nSize				 = _htFormData.GetSize();
		IXPEnumerator xpKeys     = _htFormData.GetKeys();

		for (int i = 0; i < nSize; i++)
		{
			xpKeys.MoveNext();
			
			m_htFormData.PutElement((String) xpKeys.GetCurrent(),
				(String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
		}

		RefreshItemFromTree();

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * This method gets the selected items from the tree.
	 */
	public void RefreshItemFromTree()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(
					WebServiceEditorAS.strTREE_SECOND_SUBSPACE))
			{
				AActivitySpace asTree  = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_SECOND_SUBSPACE);
				ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList itemList   = treeModel.GetSelectedItems();

				if (itemList.GetSize() > 0)
				{
					TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

					if (item == null)
					{
		
						log.Error("Tree selected item null");
					
					} else 
					{
						m_nPortletID     = item.m_nObjectID;
						m_strPortletName	    = item.GetName();
					}
				}
			}
		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
		
		log.Warn(e, "Unknown Error RefreshItemFromTree.");
		
		}
	}


	/**
	 * Returns the portlet id of the portlet for which debugging is turned on.
	 * If it returns 0, that means debugging should be turned on for ALL portlets.
	 *
	 * @return 
	 */
	public int GetPortletID()
	{
		return m_nPortletID;
	}
	
	/**
	 * Returns the portlet name of the portlet for which debugging is turned on.
	 * If it returns null, that means debugging should be turned on for ALL portlets.
	 *
	 * @return 
	 */
	public String GetPortletName()
	{
		return m_strPortletName;
	}
	
	/**
	 * @see com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)
	 */
	public String GetData(String name)
	{
		String[] values = (String[]) m_htFormData.GetElement(name);

		if (values == null)
		{
			return DEFAULTDATA;
		}

		return values[0];
	}

	/**
	 * This method clears the selected items from the tree.
	 */
	public void ClearPortlet()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(
						WebServiceEditorAS.strTREE_SECOND_SUBSPACE))
			{
				AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_SECOND_SUBSPACE);
				ATreeModel treeModel  = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
				treeModel.ClearSelectedItems();
			}

			m_nPortletID     = 0;
			m_strPortletName = null;

		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			
				log.Warn(e, "Unknown Error ClearPortlet.");
			
		}
	}
	
	/**
	 * Returns web service id.
	 *
	 */
	public int GetWebServiceID()
	{
		return m_nWebServiceID;
	}

	/**
	 * Set the name of the portlet internally.
	 *
	 */
	private void UpdatePortletName()
	{
		if (m_nPortletID == 0)
		{
			m_strPortletName = null;
			return;
		}
		
		try
		{
			IPTSession ptSession = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();

			IPTGadget ptPortlet = (IPTGadget) ptSession.GetGadgets().Open(m_nPortletID, false);
			
			m_strPortletName = ptPortlet.GetLocalizedName();
		}
		catch (Exception e)
		{
			
				log.Warn(e, "DebugPortletPluginModel::UpdatePortletName - Unable to access portlet object. Continuing with no portlet selected: " +
					e.getMessage());
			
		}


	}
}


