
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.OpenLogService;
import com.plumtree.openlog.OpenLogger;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.ATreeAS;
import com.plumtree.uiinfrastructure.tree.ATreeModel;
import com.plumtree.uiinfrastructure.tree.ITreeModelRO;
import com.plumtree.uiinfrastructure.tree.TreeLeafNode;

/**
 * @author JaneD
 *
 */
public class DebugUserPluginModel extends EditorHelperModel
	implements IDebugUserPluginModelRO, IWSSubModel
{
	
	public static final String STR_MVC_CLASS_NAME = "DebugUserPlugin";

	/**
	 * This member defines a static string used to identify when m_htFormData
	 * has been initialized.
	 */
	public static final String DEFAULTDATA = "Default Data";
	
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
			"com.plumtree.portalpages.admin.editors.webservice.plugins.DebugUserPluginModel");
	
	/**
	 * This member contains form data sent to this control (used for the Tree control, mostly).
	 */
	private XPHashtable m_htFormData;
	
	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * User id of the user for which the debug tracing is turned on.
	 * Zero means no user selected (i.e. tracing on for ALL users). 
	 */
	private int m_nUserID = 0;
	
	/**
	 * User name of the user for which the debug tracing is turned on.
	 * If this is null, that means no user is selected (i.e. tracing on for ALL users).
	 */
	private String m_strUserName = null;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DebugUserPluginModel();
	}

	public DebugUserPluginModel()
	{
		super();
		m_htFormData = new XPHashtable();
	}
	
	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		
		WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_DEBUG_USER_ID, m_nUserID);
		
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()
	 */

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		m_nUserID = WSModelHelper.PBReadInt(ptProviderInfo,  PlumtreeExtensibility.PT_DEBUG_USER_ID, m_nUserID);
		
		UpdateUserName();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		// Store our form data for later use - especially for use in the tree control.
		int nSize				 = _htFormData.GetSize();
		IXPEnumerator xpKeys     = _htFormData.GetKeys();

		for (int i = 0; i < nSize; i++)
		{
			xpKeys.MoveNext();
			
			m_htFormData.PutElement((String) xpKeys.GetCurrent(),
				(String[]) _htFormData.GetElement(xpKeys.GetCurrent()));
		}

		RefreshItemFromTree();

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * This method gets the selected items from the tree.
	 */
	public void RefreshItemFromTree()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(
					WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE))
			{
				AActivitySpace asTree  = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE);
				ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList itemList   = treeModel.GetSelectedItems();

				if (itemList.GetSize() > 0)
				{
					TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

					if (item == null)
					{
		
						log.Error("Tree selected item null");
					
					} else 
					{
						m_nUserID     = item.m_nObjectID;
						m_strUserName	    = item.GetName();
					}
				}
			}
		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
		
		log.Warn(e, "Unknown Error RefreshItemFromTree.");
		
		}
	}


	/**
	 * Returns the user id of the user for which debugging is turned on.
	 * If it returns 0, that means debugging should be turned on for ALL users.
	 *
	 * @return 
	 */
	public int GetUserID()
	{
		return m_nUserID;
	}
	
	/**
	 * Returns the user name of the user for which debugging is turned on.
	 * If it returns null, that means debugging should be turned on for ALL users.
	 *
	 * @return 
	 */
	public String GetUserName()
	{
		return m_strUserName;
	}
	
	/**
	 * @see com.plumtree.portalpagessample.form.ISampleFormModelRO#GetData(String)
	 */
	public String GetData(String name)
	{
		String[] values = (String[]) m_htFormData.GetElement(name);

		if (values == null)
		{
			return DEFAULTDATA;
		}

		return values[0];
	}

	/**
	 * This method clears the selected items from the tree.
	 */
	public void ClearUser()
	{
		try
		{
			if (m_asOwner.GetSubSpaceExists(
						WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE))
			{
				AActivitySpace asTree = m_asOwner.GetSubSpace(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE);
				ATreeModel treeModel  = (ATreeModel) asTree.GetModel(ATreeAS.TREEMODEL);
				treeModel.ClearSelectedItems();
			}

			m_nUserID     = 0;
			m_strUserName = null;

		}
		catch (Exception e)
		{
			// This may simply be because the tree was cancelled with no node set.
			
				log.Warn(e, "Unknown Error ClearUser.");
			
		}
	}

	/**
	 * Set the name of the user internally.
	 *
	 */
	private void UpdateUserName()
	{
		if (m_nUserID == 0)
		{
			m_strUserName = null;
			return;
		}
		
		try
		{
			IPTSession ptSession = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();

			IPTUser ptUser = (IPTUser) ptSession.GetUsers().Open(m_nUserID, false);
			
			m_strUserName = ptUser.GetLocalizedName();
		}
		catch (Exception e)
		{
			
				log.Warn(e, "DebugUserPluginModel::UpdateUserName - Unable to access user object. Continuing with no user selected: " +
					e.getMessage());
			
		}


	}
}


