package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This view allows you to choose the Remote Server used
 * by this Web Service
 *
 * @author adolfoc
 */
public class DebugUserPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.DebugUserPluginView");

	/** The object name */

	public static final String STR_MVC_CLASS_NAME = "DebugUserPluginView";

	/**
	 * Private String that is the function name for the repost javascript called
	 * when the tree control returns
	 */
	private static final String JSREPOST_USER_FUNC		 = "frmRepostUserChosen";
	private static final String JSREPOST_USER_FUNC_INPUT = "frmSetDataUserChosen";
	private static final String JSREPOST_USERREMOVE_FUNC = "frmRepostUserRemoved";

	// HTML Object names.
	public static final String HTMLHIDDEN_USER_SPACE    = "in_hi_UserSpace";
	public static final String HTMLHIDDEN_USER_SELECTED = "in_hi_UserSelected";
	public static final String HTMLBUTTON_USER_REMOVE = "in_bu_RemoveUser";

	private AActivitySpace m_asasParent;
	private IDebugUserPluginModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DebugUserPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableCell myCell;
		HTMLTableRow myRow;

		HTMLSpan mySpan;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						2952, "ptmsgs_portaladminmsgs")));
			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, "6");

			// 1st row ends
			// 2nd row begins
			myRow = WSViewHelper.AddRow(myTable);

			//// Left Margin
			WSViewHelper.AddLeftMargin(myRow, 6);
			
			int iUserID = m_model.GetUserID();
			boolean bTraceForAllUsers = (iUserID == 0);

			myCell = WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(2953, "ptmsgs_portaladminmsgs"));
			if (bTraceForAllUsers)
			{
				myCell = WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(2956, "ptmsgs_portaladminmsgs"));
			} else {
				// add remote server opener link
				HTMLAnchor rsLink = (HTMLAnchor)WSViewHelper.MakeEditObjectLink(PT_CLASSIDS.PT_USER_ID, m_model.GetUserID(), m_model.GetUserName(), m_asOwner);
				myCell = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
				HTMLSpan rsOpenerSpan = WSViewHelper.AddSpanToCell(myCell);
				rsOpenerSpan.AddInnerHTMLElement(rsLink);		
			}

			mySpan = WSViewHelper.AddSpanToCell(myCell);
			mySpan.AddInnerHTMLString(SPACE);
			
			////// Actual Tree Control
			// Hidden input for the Space ID for the tree.  That way if you hit the folder
			// tree link twice, it will open the same tree both times.
			String strUserSpaceID = m_model.GetData(HTMLHIDDEN_USER_SPACE);

			if (strUserSpaceID.equals(
						DebugUserPluginModel.DEFAULTDATA))
			{
				mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_USER_SPACE, ""));
			}
			else
			{
				mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_USER_SPACE, strUserSpaceID));
			}
			

			String strOnClick	    = JSREPOST_USER_FUNC_INPUT +
				"(document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_USER_SPACE + "); return false;";
			String strOnClickRemove = JSREPOST_USERREMOVE_FUNC +
				"(document." + AFormDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_USER_SPACE + "); return false;";

				mySpan.AddInnerHTMLString(SPACE);
				mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(
						m_asOwner.GetString(2954, "ptmsgs_portaladminmsgs"),
						strOnClick));

				// Add a remove button if the remote server is non-null.
				if (!bTraceForAllUsers)
				{
					mySpan.AddInnerHTMLString(SPACE);

					mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleButton(
							m_asOwner.GetString(2955, "ptmsgs_portaladminmsgs"),
							strOnClickRemove, HTMLBUTTON_USER_REMOVE));
				}

			mySpan.AddInnerHTMLElement(WSViewHelper.MakeHiddenInput(HTMLHIDDEN_USER_SELECTED, m_model.GetData(HTMLHIDDEN_USER_SELECTED)));  

			// Right Margin
			WSViewHelper.AddRightMargin(myRow, 6);

			// 2nd row ends			
			// 3rd Row - Path info.
			myRow = WSViewHelper.AddRow(myTable);

			//// Left Margin
			WSViewHelper.AddLeftMargin(myRow, 6);

			// 4th row begins
			WSViewHelper.AddEmptyRow(myTable, "6");

			// 4th row ends
		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(2957,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		String strFormName = AFormDP.HTMLFORM_NAME;

		// The URL to open a new remote folder tree
		ASURL newDebugUserTree = new ASURL(m_asOwner);

		newDebugUserTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
			m_asasParent);
		newDebugUserTree.SetSubSpaceKey(WebServiceEditorAS.strTREE_DEBUGUSER_SUBSPACE);
		newDebugUserTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		newDebugUserTree.AddControlArgument(StartTreeControl.ROOT_ID, "1");
		newDebugUserTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
			XPConvert.ToString(false));
		newDebugUserTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		newDebugUserTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		newDebugUserTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			strFormName);
		newDebugUserTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			HTMLHIDDEN_USER_SPACE);
		newDebugUserTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			JSREPOST_USER_FUNC);
		newDebugUserTree.AddControlArgument(StartTreeControl.TITLE,
			m_asOwner.GetString(2958, "ptmsgs_portaladminmsgs"));
		newDebugUserTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(2959, "ptmsgs_portaladminmsgs"));			
		newDebugUserTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));

		// The url to open a previously opened remote folder tree
		// This needs to have the SpaceID added to it.
		ASURL oldDebugUserTree = new ASURL(m_asOwner);
		oldDebugUserTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME,
			m_asasParent);
		oldDebugUserTree.IsSubSpace();

		HTMLScript result  = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		try
		{

			// Test Server Side From Submit function
			sb = new XPStringBuilder(100);
			sb.Append("function ").Append(JSREPOST_USER_FUNC).Append("()\n");
			sb.Append("{\n");
			sb.Append("  postToSelf(")
			.Append(WebServiceRepostControl.POSTTOSELF_ACTION_REMOTE_VIEW_CHOSEN)
			.Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());
			
			// Test Server Side From Submit function
			sb = new XPStringBuilder(100);
			sb.Append("function ").Append(JSREPOST_USERREMOVE_FUNC)
			.Append("()\n");
			sb.Append("{\n");
			sb.Append("  postToSelf(")
			.Append(WebServiceRepostControl.POSTTOSELF_ACTION_DEBUG_USER_REMOVED)
			.Append(");\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// Open remote folder tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JSREPOST_USER_FUNC_INPUT)
			.Append("(myInput)\n");
			sb.Append("{\n");
			sb.Append("  if (myInput.value == '') {\n");
			sb.Append("    window.open('")
			.Append(newDebugUserTree.GetURLAsString()).Append("', '_blank1', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  } else {\n");
			sb.Append("    window.open('")
			.Append(oldDebugUserTree.GetURLAsString()).Append("&")
			.Append(ASConstants.SPACEID).Append("=' + myInput.value").Append(", '_blank1', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("  }\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element: " +
					he.getMessage());
			
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent     = parent;
		m_model			 = (IDebugUserPluginModelRO) model;
	}

}

