package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The FormLoginPluginView allows an administrator to specify a
 * login URL and post URL for form-based login.  In addition it
 * allows the administrator to specify where the username and
 * password to be sent come form and what fields to use.
 * 
 * @author akashj
 */
public class FormLoginPluginView extends EditorView
{
	/** Logging stuff */
	// commenting out logger because it is not used - CVN
	//	private static OpenLogger log = OpenLogService.GetLogger(
	//		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
	//		"com.plumtree.portalpages.admin.editors.webservice.plugins.FormLoginPluginView");

	/** Number of columns in view */
	private static final int COLUMNS = 7;
	
	/** This object's name */
	public static final String STR_MVC_CLASS_NAME = "FormLoginPluginView";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FormLoginPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTableRow myRow;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						2922, ResourceConstants.PORTALADMINMSGS)));

			HTMLTable myTable = WSViewHelper.AddTable(result);
				
			////////////////////////////////
			// 0 - row (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
			
			////////////////////////////////
			// 0 row extra - instructions
			myRow = WSViewHelper.AddRow(myTable);
			WSViewHelper.AddLeftMargin(myRow, COLUMNS);
			WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.FIVE, 
					m_asOwner.GetString(2933, ResourceConstants.PORTALADMINMSGS));	
			WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
			
			
			////////////////////////////////
			// 0 - spacer row
			WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));

			
			////////////////////////////////
			// 1st row - login URL row
			myRow = WSViewHelper.AddRow(myTable);
			
			// Left Margin
			WSViewHelper.AddLeftMargin(myRow, COLUMNS);

			// 1st cell - "Login URL: "
			WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(2925, ResourceConstants.PORTALADMINMSGS));

			// 2nd cell - login URL input
			WSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.THREE,
					((IFormLoginPluginModelRO) m_model).GetLoginURL(),
					FormLoginPluginModel.HTMLINPUT_LOGINURL, 64);
			
			// Right Margin
			WSViewHelper.AddRightMargin(myRow, COLUMNS);

			
			/////////////////////////////////
			// 2nd row - POST URL row
			myRow = WSViewHelper.AddRow(myTable);
			
			// Left Margin
			WSViewHelper.AddLeftMargin(myRow, COLUMNS);

			// 1st cell - "Login URL: "
			WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, m_asOwner.GetString(2926, ResourceConstants.PORTALADMINMSGS));

			// 2nd cell - login URL input
			WSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.THREE,
					((IFormLoginPluginModelRO) m_model).GetPostURL(),
					FormLoginPluginModel.HTMLINPUT_POSTURL, 64);
			
			// Right Margin
			WSViewHelper.AddRightMargin(myRow, COLUMNS);
			
			
			////////////////////////////////
			// 3rd row - space row
			WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
			
			// aj: we'll use this to know our current auth type
			int nCurrentCredentialType = ((IFormLoginPluginModelRO)m_model).GetCredentialType();
			
			
			/////////////////////////////////
			// 3rd row - extra - text to describe what the radios are for
			myRow = WSViewHelper.AddRow(myTable);
			
			// Left Margin
			WSViewHelper.AddLeftMargin(myRow, COLUMNS);

			// 1st cell - "Specify the credentials to be sent to the POST URL: "
			WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.FIVE, 
					m_asOwner.GetString(2932, ResourceConstants.PORTALADMINMSGS));
			
			// Right Margin
			WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
			
			/////////////////////////////////
			// 4th row - no credentials radio row
			WSViewHelper.AddSimpleRadio(myTable, COLUMNS,
					m_asOwner.GetString(2929, ResourceConstants.PORTALADMINMSGS),
					FormLoginPluginModel.HTMLRADIO_CREDENTIAL_TYPE,
					XPConvert.ToString(FormLoginPluginModel.CREDENTIAL_TYPE_NONE),
					(FormLoginPluginModel.CREDENTIAL_TYPE_NONE == nCurrentCredentialType),
					"disableFormField('" + FormLoginPluginModel.HTMLINPUT_PASSWORD_FIELD_NAME + "', true); disableFormField('" + FormLoginPluginModel.HTMLINPUT_USERNAME_FIELD_NAME + "', true);");
			
			
			/////////////////////////////////
			// 5th row - portal auth radio row
			WSViewHelper.AddSimpleRadio(myTable, COLUMNS,
					m_asOwner.GetString(2930, ResourceConstants.PORTALADMINMSGS),
					FormLoginPluginModel.HTMLRADIO_CREDENTIAL_TYPE,
					XPConvert.ToString(FormLoginPluginModel.CREDENTIAL_TYPE_PORTAL_AUTH),
					(FormLoginPluginModel.CREDENTIAL_TYPE_PORTAL_AUTH == nCurrentCredentialType),
					"disableFormField('" + FormLoginPluginModel.HTMLINPUT_PASSWORD_FIELD_NAME + "', false); disableFormField('" + FormLoginPluginModel.HTMLINPUT_USERNAME_FIELD_NAME + "', false);");		
			
			
			/////////////////////////////////
			// 6th row - lockbox auth radio row
			WSViewHelper.AddSimpleRadio(myTable, COLUMNS,
					m_asOwner.GetString(2931, ResourceConstants.PORTALADMINMSGS),
					FormLoginPluginModel.HTMLRADIO_CREDENTIAL_TYPE,
					XPConvert.ToString(FormLoginPluginModel.CREDENTIAL_TYPE_LOCKBOX_AUTH),
					(FormLoginPluginModel.CREDENTIAL_TYPE_LOCKBOX_AUTH == nCurrentCredentialType),
					"disableFormField('" + FormLoginPluginModel.HTMLINPUT_PASSWORD_FIELD_NAME + "', false); disableFormField('" + FormLoginPluginModel.HTMLINPUT_USERNAME_FIELD_NAME + "', false);");		
			
			
			////////////////////////////////
			// 7th row - space row
			WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));

			
			// aj: bug 43142, username/password field should be disabled if the NONE selection
			//     is choosen
			boolean bDisableAuthFields = (FormLoginPluginModel.CREDENTIAL_TYPE_NONE == nCurrentCredentialType);
			
			/////////////////////////////////
			// 8th row - username field row
			myRow = WSViewHelper.AddRow(myTable);
			
			// Left Margin
			WSViewHelper.AddLeftMargin(myRow, COLUMNS);
			
			// 1st cell - "Username Field Name: "
			WSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.TWO, 
					m_asOwner.GetString(2927, ResourceConstants.PORTALADMINMSGS));

			// 2nd cell - field name URL input
			WSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.THREE,
					((IFormLoginPluginModelRO) m_model).GetUsernameFieldName(),
					FormLoginPluginModel.HTMLINPUT_USERNAME_FIELD_NAME, 32, 
					bDisableAuthFields, FormLoginPluginModel.HTMLINPUT_USERNAME_FIELD_NAME);
			
			// Right Margin
			WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
			
			
			/////////////////////////////////
			// 9th row - password field row
			myRow = WSViewHelper.AddRow(myTable);
			
			// Left Margin
			WSViewHelper.AddLeftMargin(myRow, COLUMNS);
			
			// 1st cell - "Password Field Name: "
			WSViewHelper.AddSubLabelCell(myRow, CommonHTMLStrings.TWO, 
					m_asOwner.GetString(2928, ResourceConstants.PORTALADMINMSGS));

			// 2nd cell - field name URL input
			WSViewHelper.AddEditBoxCell(myRow, CommonHTMLStrings.THREE,
					((IFormLoginPluginModelRO) m_model).GetPasswordFieldName(),
					FormLoginPluginModel.HTMLINPUT_PASSWORD_FIELD_NAME, 32, 
					bDisableAuthFields, FormLoginPluginModel.HTMLINPUT_PASSWORD_FIELD_NAME);
			
			// Right Margin
			WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
			
			
			/////////////////////////////////
			// LAST row (Bottom Margin)
			WSViewHelper.AddEmptyRow(myTable, XPConvert.ToString(COLUMNS));
		}
		catch (Exception e)
		{
			throw new XPException(m_asOwner.GetString(2923, ResourceConstants.PORTALADMINMSGS),
				e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = new HTMLScript("text/javaScript");

		// aj: bug 43142, javascript to toggle the username/password fields
		XPStringBuilder sb = new XPStringBuilder(512);
//		function disableFormFiled(fieldID)
//		{
//		    obj = document.getElementByID(fieldId);
//			obj.disabled = !(obj.disabled);
//		}
		sb.Append("\nfunction disableFormField(fieldId, fieldStatus)\n");
		sb.Append("{ \n");
		sb.Append("  obj = document.getElementById(fieldId);\n");
		sb.Append("  obj.disabled = fieldStatus;\n");
		// aj: the following two lines are for debugging
//		sb.Append("  var z = (obj.disabled) ? 'disabled' : 'enabled';\n");
//		sb.Append("  alert(obj.type + ' now ' + z);\n");
		sb.Append("} \n");
		
		// aj: add to the jscript for the view
		result.AddInnerHTMLString(sb.ToString());
		return result;
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
	}
}

