/**
 * Created on Oct 30, 2002
 *
 * To change this generated comment edit the template variable "filecomment":

 * To enable and disable the creation of file comments go to

 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author adolfoc
 *
 */
public class GatewayCachingPluginModel extends EditorHelperModel
	implements IGatewayCachingPluginModelRO, IWSSubModel
{
	
	public static final String STR_MVC_CLASS_NAME = "GatewayCachingPlugin";

	/**
	 * This mask is used by our view to send time data to us in units that we
	 * support.
	 */
	public static final int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYDAYS |
		PTDurationCombo.DISPLAYHOURS | PTDurationCombo.DISPLAYMINUTES |
		PTDurationCombo.DISPLAYSECONDS;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * Suppress Errors information.
	 */
	private boolean m_bSuppressErrors = true;

	/**
	 * Timeout information.
	 */
	protected PTDuration m_ptdMinCache;
	protected PTDuration m_ptdMaxCache;

	public GatewayCachingPluginModel()
	{
		super();
		m_ptdMinCache = new PTDuration(0, NMASK_SUPPORTED_UNITS);
		m_ptdMaxCache = new PTDuration(1000 * 60 * 60 * 24 * 20, NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GatewayCachingPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		//AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
		// the propertybag as SECONDS.
		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MINC,
			m_ptdMinCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS));

		//AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
		// the propertybag as SECONDS.
		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MAXC,
			m_ptdMaxCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS));

		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_HIDEERR, m_bSuppressErrors);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return GatewayCachingPluginView.VALIDATION_FUNCTION_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();

		//AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
		// the propertybag as SECONDS.
		m_ptdMinCache = new PTDuration(
			WSModelHelper.PBReadInt(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MINC, m_ptdMinCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS)),
			PTDurationCombo.DISPLAYSECONDS,
			NMASK_SUPPORTED_UNITS);

		//AGC- Note the "PTDurationCombo.DISPLAYSECONDS". Unlike most of the other timeouts. This is stored in
		// the propertybag as SECONDS.
		m_ptdMaxCache = new PTDuration(
					WSModelHelper.PBReadInt(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_MAXC, m_ptdMaxCache.GetDurationInUnits(PTDurationCombo.DISPLAYSECONDS)),
					PTDurationCombo.DISPLAYSECONDS,
					NMASK_SUPPORTED_UNITS);
	
		m_bSuppressErrors = WSModelHelper.PBReadBool(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_HIDEERR, m_bSuppressErrors);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		
		m_ptdMinCache = WSModelHelper.GetFormElementDuration(_htFormData,
			GatewayCachingPluginView.HTMLINPUT_MINCACHE_DURATION,
			GatewayCachingPluginView.HTMLSELECT_MINCACHE_UNITS, m_ptdMinCache);

		m_ptdMaxCache = WSModelHelper.GetFormElementDuration(_htFormData,
			GatewayCachingPluginView.HTMLINPUT_MAXCACHE_DURATION,
			GatewayCachingPluginView.HTMLSELECT_MAXCACHE_UNITS, m_ptdMaxCache);
		
		//AGC- Because these are checkboxes, we want to make sure that if they are not set, we return false - hence the false in thefollowing statements.
		m_bSuppressErrors = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewayCachingPluginView.HTMLCHECKBOX_SUPRESS_ERRORS);

		int nValid = RepostControl.PAGE_STATUS_VALID;
		nValid = WSModelHelper.ValidateDurationRange(m_ptdMinCache,
				m_asOwner, m_asOwner.GetString(1922, "ptmsgs_portaladminmsgs"), nValid, 0,
				1000 * 60 * 60 * 24 * 20);

		nValid = WSModelHelper.ValidateDurationRange(m_ptdMaxCache,
				m_asOwner, m_asOwner.GetString(1923, "ptmsgs_portaladminmsgs"), nValid, 0,
				1000 * 60 * 60 * 24 * 20);
				

		nValid = WSModelHelper.ValidateBool((m_ptdMinCache.GetMilliseconds() <= m_ptdMaxCache.GetMilliseconds()), m_asOwner, m_asOwner.GetString(1924, "ptmsgs_portaladminmsgs"), nValid);

		return nValid;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayCachingPluginModelRO#SuppressErrorsChecked()
	 */
	public boolean SuppressErrorsChecked()
	{
		return m_bSuppressErrors;
	}
	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayCachingPluginModelRO#GetMaxCacheDuration()
	 */
	public PTDuration GetMaxCacheDuration() {
		return m_ptdMaxCache;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayCachingPluginModelRO#GetMinCacheDuration()
	 */
	public PTDuration GetMinCacheDuration() {
		return m_ptdMinCache;
	}

}

