package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class GatewayCachingPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.GatewayCachingPluginView");

	public static final String STR_MVC_CLASS_NAME = "GatewayCachingPluginView";

	/**
	 * The name of our validation function. This must be added by the Page to the
	 * page level validation function. See WSPluginDP for details.
	 */
	public static final String VALIDATION_FUNCTION_NAME = "IsValidGatewayCache";

	public static final String HTMLINPUT_MINCACHE_DURATION = "in_tx_MinCache";
	public static final String HTMLSELECT_MINCACHE_UNITS   = "in_se_MinCacheUnits";
	public static final String HTMLINPUT_MAXCACHE_DURATION = "in_tx_MaxCache";
	public static final String HTMLSELECT_MAXCACHE_UNITS   = "in_se_MaxCacheUnits";
	public static final String HTMLCHECKBOX_SUPRESS_ERRORS = "in_cb_SuppressErrors";

	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GatewayCachingPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1082, "ptmsgs_portaladminmsgs")));
			myTable = WSViewHelper.AddTable(result);
			
			// Last row begins
			WSViewHelper.AddEmptyRow(myTable, "5");
			
			WSViewHelper.AddSimpleDurationCombo(myTable, 5,
				m_asOwner.GetString(1083, "ptmsgs_portaladminmsgs"),
				HTMLINPUT_MINCACHE_DURATION, HTMLSELECT_MINCACHE_UNITS, 
				((IGatewayCachingPluginModelRO)m_model).GetMinCacheDuration(), m_asOwner);

			WSViewHelper.AddSimpleDurationCombo(myTable, 5,
				m_asOwner.GetString(1084, "ptmsgs_portaladminmsgs"),
				HTMLINPUT_MAXCACHE_DURATION, HTMLSELECT_MAXCACHE_UNITS, 
				((IGatewayCachingPluginModelRO)m_model).GetMaxCacheDuration(), m_asOwner);
			
			WSViewHelper.AddSimpleCheckbox(myTable, 5,
				m_asOwner.GetString(1085, "ptmsgs_portaladminmsgs"),
				HTMLCHECKBOX_SUPRESS_ERRORS, 
				CommonHTMLStrings.ONE, 
				((IGatewayCachingPluginModelRO) m_model).SuppressErrorsChecked(), 
				"");

			// Last row begins
			WSViewHelper.AddEmptyRow(myTable, "5");
		}
		catch (Exception e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1081,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result  = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		XPStringBuilder sb = new XPStringBuilder(300);
		WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
		
		try
		{
			
			sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
			sb.Append("{\n");

			

			if (WebServiceModel.WSMODE_CWS == mParent.GetWSMode())
			{
				sb.Append(WSViewHelper.ValidateNumericInputJS(
						WSPluginDP.HTMLFORM_NAME,
						HTMLINPUT_MINCACHE_DURATION,
						m_asOwner.GetString(1086, "ptmsgs_portaladminmsgs")));

				sb.Append(WSViewHelper.ValidateNumericInputJS(
						WSPluginDP.HTMLFORM_NAME,
						HTMLINPUT_MAXCACHE_DURATION,
						m_asOwner.GetString(1087, "ptmsgs_portaladminmsgs")));

			}

			sb.Append(" 	return true;\n");
			sb.Append("}\n\n");
			result.AddInnerHTMLString(sb.ToString());
			
		}
		catch (HTMLException he)
		{
			log.Error(he.getMessage());
		}

		return result;
 	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

