package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the model for the plugin that allows users to configure the gateway space for a web service.
 * For Martok, I added a second column that allows users to specify which URLs should refresh in-place. -jas
 * 
 * @author adolfoc
 * @author josephs
 */
public class GatewayPrefixPluginModel extends MultiColumnListModel
	implements IGatewayPrefixPluginModelRO, IWSSubModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.GatewayPrefixPluginModel");

	public static final String STR_MVC_CLASS_NAME = "GatewayPrefixPlugin";


	/**
	 * Every Growable list used within an editor must have a unique ID. It just
	 * so happens that it is easy to accidentally collide (since the unique ID's
	 * are set to 0 and 1 a lot). I'm going to give myself an offset, so that I
	 * am less likely to collide with someone else's unique ID). It doesn't really
	 * matter what this number is, as long as no one else chooses the same one for
	 * another ExpList.
	 */
	private static final int m_nUniqueIDOffset = 646;

	// note that these are 0-based, whereas the similar constants in the View are 0-based, 
	// for uiinfrastructure reasons I don't entirely fathom -jas
	private static final int COLUMN_URL = 0;
	private static final int COLUMN_REFRESH_FLAG = 1;
	private static final int NUM_COLUMNS = 2;

	private static final String[] m_arrDefaultValuesAbsolute = { "", "" };
	private static final String[] m_arrDefaultValuesRelative = { ".", "" };

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	
	/**
	 * We might get the Remote Server Base URL from
	 * our parent model if it is a WebService Model. It is stored here.
	 */
	private String m_strBaseURL = "";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GatewayPrefixPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		Object[][] aGrowableArrayValues = GetListValues();

		XPArrayList aGatewayList = new XPArrayList();
		XPArrayList aRefreshList = new XPArrayList();

		// Turn this into an Object array so that we can store it.			
		for (int nIndex = 0; nIndex < aGrowableArrayValues[0].length; nIndex++)
		{
			String strNewValue = XPConvert.ToString(aGrowableArrayValues[COLUMN_URL][nIndex]);
			String strRefreshFlag = XPConvert.ToString(aGrowableArrayValues[COLUMN_REFRESH_FLAG][nIndex]);

			// AGC- Warning... We're doing a trim here. I think it is valid, but
			// it is worth noting.
			strNewValue = strNewValue.trim();
			if (0 < strNewValue.length())
			{
				if (strRefreshFlag == "")
				{
					aGatewayList.Add(strNewValue);
					log.Debug("Adding gateway prefix: " + strNewValue);
				}
				else
				{
					aRefreshList.Add(strNewValue);
					log.Debug("Adding refresh prefix: " + strNewValue);
				}
			}			
		}
		
		/** SPECIAL CASING FOR PAGELET WEBSERVICE EDITORS **/
		
		// Add a hardcoded gateway prefix for Pagelet Webservices. This prefix is used to properly size
		// pagelets through embedded iframes in pagelets to make cross domain calls to ensemble server
		final String ensembleGatewayPrefix = "/inject/v2/csapi/.";  
		
		WebServiceModel myModel = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
		if ( myModel.GetWSMode() == WebServiceModel.WSMODE_PAGELET ) {
			aGatewayList.Clear();
			aGatewayList.Add(ensembleGatewayPrefix); 
		}

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PROXYSPACE, aGatewayList.ToArray());
		ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_GATEWAY_REFRESH_SPACE, aRefreshList.ToArray());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
		if (strRemoteServerBaseURL == null) strRemoteServerBaseURL = "";
		m_strBaseURL = strRemoteServerBaseURL;
		
		// default value is "." when there's a base URL -jas
		if (strRemoteServerBaseURL == "")
		{
			SetDefaultValue(m_arrDefaultValuesAbsolute);
		}
		else
		{
			SetDefaultValue(m_arrDefaultValuesRelative);
		}		
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IGatewayPrefixPluginModelRO#GetBaseURL()
	 */
	public String GetBaseURL()
	{
		return m_strBaseURL;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		String strPrefListAddLabel = "";

		strPrefListAddLabel = m_asOwner.GetString(1089, "ptmsgs_portaladminmsgs");
		
		// set up the names of the columns -jas
		String[] strColumnNames = { m_asOwner.GetString(1088, "ptmsgs_portaladminmsgs"), m_asOwner.GetString(2825, "ptmsgs_portaladminmsgs") };
		InitializeMultiColumnList(m_asOwner.GetString(2556, "ptmsgs_portaladminmsgs"),
			strColumnNames,
			PTImageType.ICON_URL, 
			strPrefListAddLabel, 
			m_nUniqueIDOffset);

		SetDefaultValue(m_arrDefaultValuesAbsolute);
		
		// override the default key names so we can use a checkbox instead of a text input -jas
		String[] arrKeys = { GatewayPrefixPluginView.HTMLINPUT_URL, GatewayPrefixPluginView.HTMLCHECKBOX_REFRESH };		
		SetFormDataKeys(arrKeys);

		SetDeleteIcon(PTImageType.ACTION_DELETE);

		// Get our state from the ptObject.
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		
		// add the refresh space -jas
		Object[] aRefreshSpace		  = ptProviderInfo.ReadAsObject1DArray(PlumtreeExtensibility.PT_PROPBAG_GATEWAY_REFRESH_SPACE);
		int nLength = 0;
		if (null != aRefreshSpace)
		{
			nLength = aRefreshSpace.length;
		}
		
		String[][] astrPrefsList = new String[NUM_COLUMNS][nLength];

		for (int nIndex = 0; nIndex < nLength; nIndex++)
		{
			// add the URL and set the checkbox to CHECKED -jas
			astrPrefsList[COLUMN_URL][nIndex] = XPConvert.ToString(aRefreshSpace[nIndex]);
			astrPrefsList[COLUMN_REFRESH_FLAG][nIndex] = CommonHTMLStrings.ONE;
		}
		AddRowsToList(astrPrefsList);

		// now add the gateway space -jas
		Object[] aGatewaySpace		  = ptProviderInfo.ReadAsObject1DArray(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_PROXYSPACE);

		nLength = 0;
		if (null != aGatewaySpace)
		{
			nLength = aGatewaySpace.length;
		}
		
		// add one to leave room for a blank row -jas
		astrPrefsList = new String[NUM_COLUMNS][nLength];

		for (int nIndex = 0; nIndex < nLength; nIndex++)
		{
			// add the URL and set the checkbox to UNCHECKED -jas
			astrPrefsList[COLUMN_URL][nIndex] = XPConvert.ToString(aGatewaySpace[nIndex]);
			astrPrefsList[COLUMN_REFRESH_FLAG][nIndex] = "";
		}

		AddRowsToList(astrPrefsList);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.expandablelist.growablelist.IGrowableListModelRO#GetAlertMessage()
	 */
	public String GetAlertMessage() {
		// no message needed because validation type is NONE -jas
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.expandablelist.growablelist.IGrowableListModelRO#GetClientValidationType()
	 */
	public int GetClientValidationType() {
		return GrowableListModel.CLIENT_VALIDATION_TYPE_NONE;
	}
}

