package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.EditorHelperModel;
import com.plumtree.uiinfrastructure.form.*;

/**
 * Model for editing advanced gateway settings.
 * 
 * @author josephs
 *
 */
public class GatewaySettingsPluginModel
	extends EditorHelperModel
	implements IWSSubModel, IGatewaySettingsPluginModelRO {

	public static final String STR_MVC_CLASS_NAME = "GatewaySettingsPlugin";

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/*
	 * The settings this plugin manages. -jas
	 */
	private boolean m_bUseHostedDisplayMode = false;
	private boolean m_bTransformJS = false;
	private boolean m_bTransformCSS = false;

	/**
	 * Whether or not to send a timezone to the portlet.
	 * @returns boolean
	 */
	public boolean GetUseHostedDisplayMode()
	{
		return m_bUseHostedDisplayMode;
	}

	/**
	 * Whether or not to send a timezone to the portlet.
	 * @returns boolean
	 */
	public boolean GetTransformJS()
	{
		return m_bTransformJS;
	}

	/**
	 * Whether or not to send a timezone to the portlet.
	 * @returns boolean
	 */
	public boolean GetTransformCSS()
	{
		return m_bTransformCSS;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() 
	{
		return new GatewaySettingsPluginModel();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName() 
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData) 
	{
		m_bUseHostedDisplayMode = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewaySettingsPluginView.HTMLCHECKBOX_HOSTED_DISPLAY_MODE);
		m_bTransformJS = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewaySettingsPluginView.HTMLCHECKBOX_TRANSFORM_JAVASCRIPT);
		m_bTransformCSS = WSModelHelper.GetFormCheckboxBool(_htFormData, GatewaySettingsPluginView.HTMLCHECKBOX_TRANSFORM_CSS);

		return RepostControl.PAGE_STATUS_VALID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore() 
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		
		// set the flags -jas
		int nGatewaySettings = 0;
		if (m_bUseHostedDisplayMode) nGatewaySettings |= PlumtreeExtensibility.GATEWAY_FLAGS_HOSTED_DISPLAY_MODE;
		if (m_bTransformJS) nGatewaySettings |= PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_JAVASCRIPT;
		if (m_bTransformCSS) nGatewaySettings |= PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_CSS;

		WSModelHelper.PBWrite(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_GATEWAY_FLAGS, nGatewaySettings);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(java.lang.String, java.lang.String, java.lang.String)
	 */
	public void DoTaskOnRemoteServerUpdate(
		String strRemoteServerID,
		String strRemoteServerName,
		String strRemoteServerBaseURL) {

	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode) {

	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction() {
		return null;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(com.plumtree.server.IPTWebService)
	 */
	public void InitWSModel(IPTWebService ptWebService) 
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		
		// read the flags -jas
		int nGatewaySettings = WSModelHelper.PBReadInt(ptProviderInfo, PlumtreeExtensibility.PT_PROPBAG_GATEWAY_FLAGS, 0);
		m_bUseHostedDisplayMode = (nGatewaySettings & PlumtreeExtensibility.GATEWAY_FLAGS_HOSTED_DISPLAY_MODE) > 0;
		m_bTransformJS = (nGatewaySettings & PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_JAVASCRIPT) > 0;
		m_bTransformCSS = (nGatewaySettings & PlumtreeExtensibility.GATEWAY_FLAGS_TRANSFORM_CSS) > 0;
	}

}
