package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.uiinfrastructure.editor.EditorView;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View for editing advanced gateway settings.
 * 
 * @author josephs
 *
 */
public class GatewaySettingsPluginView extends EditorView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		GatewaySettingsPluginView.class);

	public static final String STR_MVC_CLASS_NAME = "GatewaySettingsPluginView";

	public static final String HTMLCHECKBOX_HOSTED_DISPLAY_MODE = "in_cb_HostedDisplayMode";
	public static final String HTMLCHECKBOX_TRANSFORM_JAVASCRIPT     = "in_cb_TransformJS";
	public static final String HTMLCHECKBOX_TRANSFORM_CSS     = "in_cb_TransformCSS";

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() 
	{
		return new GatewaySettingsPluginView();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName() 
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display() 
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLInput myInput;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1033, "ptmsgs_portaladminmsgs")));

			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, "5");

			// 1st row ends
			// 2nd row
			IGatewaySettingsPluginModelRO modelRO = (IGatewaySettingsPluginModelRO) m_model;

			DrawCheckBox(myTable, HTMLCHECKBOX_HOSTED_DISPLAY_MODE, "1",
				m_asOwner.GetString(2822, "ptmsgs_portaladminmsgs"),
				modelRO.GetUseHostedDisplayMode());

			DrawCheckBox(myTable, HTMLCHECKBOX_TRANSFORM_JAVASCRIPT, "1",
				m_asOwner.GetString(2823, "ptmsgs_portaladminmsgs"),
				modelRO.GetTransformJS());

			DrawCheckBox(myTable, HTMLCHECKBOX_TRANSFORM_CSS, "1",
				m_asOwner.GetString(2824, "ptmsgs_portaladminmsgs"),
				modelRO.GetTransformCSS());
			
			// last row (spacer row)
			WSViewHelper.AddEmptyRow(myTable, "5");
		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1032,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	// Helper Function:
	private void DrawCheckBox(HTMLTable myTable, String strHTTP,
		String strValue, String strUI, boolean bChecked)
	{
		WSViewHelper.AddSimpleCheckbox(myTable, 5, strUI, strHTTP, strValue, bChecked, "");
	}
}
