package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This model is used to store the activity space for portlet help pages.
 *
 * @author josephc
 */
public class IntrinsicHelpSpacePluginModel extends EditorHelperModel
	implements IIntrinsicHelpSpacePluginModelRO, IWSSubModel
{
	/** Class name for IntrinsicHelpSpacePluginModel */
	public static final String STR_MVC_CLASS_NAME = "IntrinsicHelpSpacePlugin";

	/** Logger for IntrinsicHelpSpacePluginModel */
	/** Flag for debug logging */
	/** Flag for error logging */
	/** Flag for warning logging */
	/** Flag for info logging */
	/** Flag for fatal error logging */
	/** The Web Service object being edited by our parent Web Service editor */
	IPTWebService m_ptWebService = null;

	/** Intrinsic portlet help activity space */
	private String m_strHelpURL = "";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IntrinsicHelpSpacePluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_HELP_URL, m_strHelpURL);

		int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();

		if ((null == m_strHelpURL) || (0 >= m_strHelpURL.trim().length()))
		{
			nSupportsPersonalization = nSupportsPersonalization &
				~PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_HELPPAGE;
		}
		else
		{
			nSupportsPersonalization = nSupportsPersonalization |
				PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_HELPPAGE;
		}

		m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,
	 *      String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * Gets the intrinsic portlet help URL
	 *
	 * @return Intrinsic portlet URL
	 *
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IIntrinsicHelpSpacePluginModelRO#GetHelpURL()
	 */
	public String GetHelpURL()
	{
		return m_strHelpURL;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		SetHelpURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_HELP_URL, m_strHelpURL));
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		SetHelpURL(WSModelHelper.GetFormElementString(_htFormData, IntrinsicHelpSpacePluginView.HTMLINPUT_HELP_SPACE, m_strHelpURL));

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Sets the help URL.
	 *
	 * @param strHelpURL Activity space for help
	 */
	public void SetHelpURL(String strHelpURL)
	{
		m_strHelpURL = strHelpURL;
	}
}

