package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * Model for setting portlet class identifier.
 *
 * @author josephc
 */
public class IntrinsicPortletWSSettingsPluginModel extends EditorHelperModel implements IIntrinsicPortletWSSettingsPluginModelRO, IWSSubModel
{
	/** Class name for IntrinsicPortletWSSettingsPluginModel */
	public static final String STR_MVC_CLASS_NAME = "IntrinsicPortletWSSettingsPlugin";

	/** The Web Service object being edited by our parent Web Service editor */
	private IPTWebService m_ptWebService = null;

	/** Portlet class identifier */
	private String m_strPortletClassIdentifier = "";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IntrinsicPortletWSSettingsPluginModel();
	}

	/**
	 * Store the property bag format for intrinsic portlets as well as the
	 * portlet class identifier into the provider info property bag for
	 * intrinsic portlet web services.
	 *
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT, AExtensibilityConstants.PT_PROPBAG_FORMAT_INTRINSICGADGET_INIT);
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_CLASSID, m_strPortletClassIdentifier);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,
	 *      String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID, String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the portlet class identifier
	 *
	 * @return Portlet class identifier
	 *
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IIntrinsicPortletWSSettingsPluginModelRO#GetPortletClassIdentifier()
	 */
	public String GetPortletClassIdentifier()
	{
		return m_strPortletClassIdentifier;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return IntrinsicPortletWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
	}

	/**
	 * Load the portlet class identifier from provider info property bag of web
	 * service object.
	 *
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		SetPortletClassIdentifier(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_CLASSID, GetPortletClassIdentifier()));
	}

	/**
	 * Valdiates that the specified portlet model and view exist and have been loaded by
	 * dynamic discovery.
	 *
	 * @return int
	 */
	private int ValidatePortletClassIdentifier()
	{
		// Verify that the portlet class identifier is valid.
		IModel portletModel = ASManager.INSTANCE.GetModel(m_strPortletClassIdentifier);
		IView portletView = ASManager.INSTANCE.GetView(m_strPortletClassIdentifier);

		// If the model or view cannot be retrieved using the portlet class identifier, then
		// it must be invalid.  Controls are optional so we don't check to see if the control exists.
		if ((null == portletModel) || (null == portletView))
		{
			String strErrorMsg = XPResourceManager.FormatMessage(m_asOwner.GetString(1104, "ptmsgs_portaladminmsgs"), m_strPortletClassIdentifier);
			UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, strErrorMsg, strErrorMsg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			return RepostControl.PAGE_STATUS_INVALID;
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Save the portlet class identifier.
	 *
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		SetPortletClassIdentifier(WSModelHelper.GetFormElementString(_htFormData, IntrinsicPortletWSSettingsPluginView.HTMLINPUT_PORTLET_CLASS_IDENTIFIER, m_strPortletClassIdentifier));

		return ValidatePortletClassIdentifier();
	}

	/**
	 * Set the portlet class identifier
	 *
	 * @param strPortletClassIdentifier Portlet class identifier
	 */
	public void SetPortletClassIdentifier(String strPortletClassIdentifier)
	{
		m_strPortletClassIdentifier = strPortletClassIdentifier;
	}
}

