package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Section for setting portlet class identifier.
 *
 * @author josephc
 */
public class IntrinsicPortletWSSettingsPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.IntrinsicPortletWSSettingsPluginView");

	/** Class name for IntrinsicPortletWSSettingsPluginView */
	public static final String STR_MVC_CLASS_NAME = "IntrinsicPortletWSSettingsPlugin";

	/** Logger for IntrinsicPortletWSSettingsPluginView */
	/** Flag for debug logging */
	/** Flag for error logging */
	/** Flag for warning logging */
	/** Flag for info logging */
	/** Flag for fatal error logging */
	/** Input for portlet class identifier */
	public static final String HTMLINPUT_PORTLET_CLASS_IDENTIFIER = "in_tx_PortletClassIdentifier";

	/**
	 * The name of our validation function. This must be added by the Page to
	 * the page level validation function. See WSPluginDP for details.
	 */
	public static final String VALIDATION_FUNCTION_NAME = "IsValidIntrinsicPortletWSSettings";

	/**
	 * Localized String: Unable to display the HTML for
	 * IntrinsicPortletWSSettingsPluginView (Display).
	 */

	
	/** Our parent Activity space. */
	private AActivitySpace m_asParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IntrinsicPortletWSSettingsPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			IIntrinsicPortletWSSettingsPluginModelRO iModelRO = (IIntrinsicPortletWSSettingsPluginModelRO) m_model;

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1107, "ptmsgs_portaladminmsgs")));

			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);

			// 1st row ends
			// 2nd row begins
			WSViewHelper.AddSimpleEditBox(myTable, 5,
				m_asOwner.GetString(1106, "ptmsgs_portaladminmsgs"), null,
				iModelRO.GetPortletClassIdentifier(),
				HTMLINPUT_PORTLET_CLASS_IDENTIFIER);

			// last row (spacer row)
			WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FIVE);
		}
		catch (Exception e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1105,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asParent = parent;
	}
}

