package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This model is used to store whether the intrinsic web service contains Profile data.
 *
 * @author jennifersu
 */
public class IntrinsicProfilePluginModel extends EditorHelperModel
	implements IIntrinsicProfilePluginModelRO, IWSSubModel
{
	/** Class name for IntrinsicProfilePluginModel */
	public static final String STR_MVC_CLASS_NAME = "IntrinsicProfilePlugin";

	/** The Web Service object being edited by our parent Web Service editor */
	IPTWebService m_ptWebService = null;
	
	boolean m_bIsUserProfile = false;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IntrinsicProfilePluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		int nSupportsPersonalization = m_ptWebService.GetSupportsPersonalization();

		if (!m_bIsUserProfile)
		{
			nSupportsPersonalization &= ~PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE;
		}
		else
		{
			nSupportsPersonalization |= PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE;
		}

		m_ptWebService.SetSupportsPersonalization(nSupportsPersonalization);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String,
	 *      String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;
		// TODO CR not used, commenting out.
		// int nPersonalization = m_ptWebService.GetSupportsPersonalization();
		if (0 != (ptWebService.GetSupportsPersonalization() & PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE))
		{
			m_bIsUserProfile = true;
		}
//
//		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
//
//		SetHelpURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_I_GADGET_HELP_URL, m_strHelpURL));
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
//		SetHelpURL(WSModelHelper.GetFormElementString(_htFormData, IntrinsicHelpSpacePluginView.HTMLINPUT_HELP_SPACE, m_strHelpURL));
//
		m_bIsUserProfile = WSModelHelper.GetFormCheckboxBool(_htFormData, IntrinsicProfilePluginView.HTMLINPUT_PROFILE);
		
		return RepostControl.PAGE_STATUS_VALID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IIntrinsicProfilePluginModelRO#ContainsProfileData()
	 */
	public boolean ContainsProfileData() {
		return m_bIsUserProfile;
	}
	
	/**
	 * 
	 *
	 * @param nSupportsPersonalization 
	 * @param strPrefsSpace 
	 * @param nPortletPersonalizationRole 
	 *
	 * @return 
	 */
	private int UpdatePersonalizationFlag(int nSupportsPersonalization, int nPortletPersonalizationRole)
	{
		if (!m_bIsUserProfile)
		{
			nSupportsPersonalization &= ~nPortletPersonalizationRole;
		}
		else
		{
			nSupportsPersonalization |= nPortletPersonalizationRole;
		}

		return nSupportsPersonalization;
	}


}
