package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This plugin view is used to configure intrinsic portlets to be User Profile.
 *
 * @author jennifersu
 */
public class IntrinsicProfilePluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.IntrinsicProfilePluginView");

	/** Class name for IntrinsicProfilePluginView */
	public static final String STR_MVC_CLASS_NAME = "IntrinsicProfilePlugin";

	public static final String HTMLINPUT_PROFILE = "in_cb_Profile";

	/** Our parent Activity space. */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IntrinsicProfilePluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(2701, "ptmsgs_portaladminmsgs")));

			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);

			// 1st row ends
			// 2nd row begins

			boolean bIsUserProfile = ((IIntrinsicProfilePluginModelRO)m_model).ContainsProfileData();
			WSViewHelper.AddSimpleCheckbox(myTable, 4, m_asOwner.GetString(2702, "ptmsgs_portaladminmsgs"), HTMLINPUT_PROFILE, "1", bIsUserProfile, null);
			
			//TODO: OBSOLETE string 1102
			
			// last row (spacer row)
			WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);
		}
		catch (HTMLException e)
		{
			log.Error(e, STR_MVC_CLASS_NAME +
				"::Display The following error occured when trying to display the HTML: " +
				e.getMessage());
			
			throw new XPException(m_asOwner.GetString(1101,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = new HTMLScript("text/javaScript");

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}
