package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This plugin view is used to show user, community, and admin preference spaces. 
 * The model will determine what type of preference should be shown.
 *
 * @author josephc
 */
public class IntrinsicUserPrefsPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.IntrinsicUserPrefsPluginView");

	/** Class name for IntrinsicUserPrefsPluginView */
	public static final String STR_MVC_CLASS_NAME = "IntrinsicUserPrefsPluginView";

	/** Logger for IntrinsicUserPrefsPluginView */
	/** Flag for debug logging */
	/** Flag for error logging */
	/** Flag for warning logging */
	/** Flag for info logging */
	/** Flag for fatal error logging */
	/** Input for user portlet preferences space */
	public static final String HTMLINPUT_USER_PREFS_SPACE = "in_tx_UserPrefsSpace";

	/** Input for community portlet preferences space */
	public static final String HTMLINPUT_COMMUNITY_PREFS_SPACE = "in_tx_CommunityPrefsSpace";

	/** Input for admin portlet preferences space */
	public static final String HTMLINPUT_ADMIN_PREFS_SPACE = "in_tx_AdminPrefsSpace";

	/** Input for admin portlet template preferences space */
	public static final String HTMLINPUT_TEMPLT_ADMIN_PREFS_SPACE = "in_tx_TemplAdminPrefsSpace";

	
	/** Our parent Activity space. */
	private AActivitySpace m_asParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IntrinsicUserPrefsPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			switch (((IIntrinsicUserPrefsPluginModelRO) m_model).GetPrefMode())
			{
			case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:

				result.AddInnerHTMLElement(super.GetHeaderView(
						m_asOwner.GetString(1115, "ptmsgs_portaladminmsgs")));
				myTable = GetDisplayAsTable();
				result.AddInnerHTMLElement(myTable);

				break;

			case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:

				result.AddInnerHTMLElement(super.GetHeaderView(
						m_asOwner.GetString(1113, "ptmsgs_portaladminmsgs")));
				myTable = GetDisplayAsTable();
				result.AddInnerHTMLElement(myTable);

				break;

			case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:

				result.AddInnerHTMLElement(super.GetHeaderView(
						m_asOwner.GetString(1114, "ptmsgs_portaladminmsgs")));
				myTable = GetDisplayAsTable();
				result.AddInnerHTMLElement(myTable);

				break;
			}
		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1110,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * This method is called by Display() to display the HTML for entering the activity space
	 * of the portlet preferences.
	 *
	 * @return HTML for portlet preferences.
	 *
	 * @throws XPException Throws exception if HTML could not be generated.
	 */
	public HTMLTable GetDisplayAsTable()
	{
		HTMLTable myTable;

		try
		{
			myTable = WSViewHelper.MakeTable();

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);

			// 1st row ends
			// 2nd row 
			String strDefault	    = ((IIntrinsicUserPrefsPluginModelRO) m_model).GetPrefsSpace();
			String strTempltDefault = ((IIntrinsicUserPrefsPluginModelRO) m_model).GetTemplatePrefsSpace();

			switch (((IIntrinsicUserPrefsPluginModelRO) m_model).GetPrefMode())
			{
			case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:

				WSViewHelper.AddSimpleEditBox(myTable, 4,
					m_asOwner.GetString(1109, "ptmsgs_portaladminmsgs"), null,
					strDefault, HTMLINPUT_COMMUNITY_PREFS_SPACE);

				break;

			case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:

				WSViewHelper.AddSimpleEditBox(myTable, 4,
					m_asOwner.GetString(1112, "ptmsgs_portaladminmsgs"), null,
					strDefault, HTMLINPUT_USER_PREFS_SPACE);

				break;

			case IntrinsicUserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:

				WSViewHelper.AddSimpleEditBox(myTable, 4,
					m_asOwner.GetString(1108, "ptmsgs_portaladminmsgs"), null,
					strDefault, HTMLINPUT_ADMIN_PREFS_SPACE);

				WSViewHelper.AddSimpleEditBox(myTable, 4,
					m_asOwner.GetString(1111, "ptmsgs_portaladminmsgs"), null,
					strTempltDefault, HTMLINPUT_TEMPLT_ADMIN_PREFS_SPACE);

				break;
			}

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, CommonHTMLStrings.FOUR);
			
		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1110,
					"ptmsgs_portaladminmsgs"), e);
		}

		return myTable;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asParent = parent;
	}
}

