package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author Jennifer Sun
 *
 */
public class MWSSettingsPluginModel extends EditorHelperModel
	implements IMWSSettingsPluginModelRO, IWSSubModel
{
	public static final String STR_MVC_CLASS_NAME = "MWSSettingsPlugin";

	/**
	 * This mask is used by our view to send time data to us in units that we
	 * support.
	 */
	public static final int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES |
		PTDurationCombo.DISPLAYSECONDS;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * We might get the Remote Server Base URL from
	 * our parent model if it is a WebService Model. It is stored here.
	 */
	private String m_strBaseURL = "";

	/**
	 * The location of the Migration URL for this Web Service.
	 */
	private String m_strMigrationURL		  = "";

	/**
	 * Timeout information.
	 */
	protected PTDuration m_ptdSOAPTimeout;

	public MWSSettingsPluginModel()
	{
		super();
		m_ptdSOAPTimeout = new PTDuration(30000, NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MWSSettingsPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PTC_HTTPMWS_MWSURL, m_strMigrationURL);
		WSModelHelper.PBWrite(ptProviderInfo,
			AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
			m_ptdSOAPTimeout.GetMilliseconds());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
		m_strBaseURL = strRemoteServerBaseURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.IAdminPrefsPluginModelRO#GetBaseURL()
	 */
	public String GetBaseURL()
	{
		return m_strBaseURL;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * The location of the Migration URL for this Web Service.
	 * @returns String
	 */
	public String GetMigrationURL()
	{
		return m_strMigrationURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return MWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		SetMigrationURL(WSModelHelper.PBReadString(ptProviderInfo,
				AExtensibilityConstants.PTC_HTTPMWS_MWSURL, m_strMigrationURL));
		m_ptdSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(
					ptProviderInfo,
					AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
					m_ptdSOAPTimeout.GetMilliseconds()), NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		
		SetMigrationURL(WSModelHelper.GetFormElementString(_htFormData,
				MWSSettingsPluginView.HTMLINPUT_MIGRATION_URL, GetMigrationURL()));

		m_ptdSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				MWSSettingsPluginView.HTMLINPUT_TIMEOUT_DURATION,
				MWSSettingsPluginView.HTMLSELECT_TIMEOUT_UNITS, m_ptdSOAPTimeout);


		int nValid = RepostControl.PAGE_STATUS_VALID;


		if ((null == m_strBaseURL) || (m_strBaseURL.length() <= 0))
		{
			nValid = WSModelHelper.ValidateIsURLString(m_strMigrationURL, m_asOwner, m_asOwner.GetString(2829, "ptmsgs_portaladminmsgs"), nValid);
		}
		else
		{
			nValid = WSModelHelper.ValidateNonEmptyString(m_strMigrationURL, m_asOwner, m_asOwner.GetString(2830, "ptmsgs_portaladminmsgs"), nValid);
		}

		nValid = WSModelHelper.ValidateDurationRange(m_ptdSOAPTimeout,
				m_asOwner, m_asOwner.GetString(1929, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 90);

		return nValid;
	}


	/**
	 * The location of the Synchronization URL for this Web Service.
	 */
	public void SetMigrationURL(String strMigrationURL)
	{
		m_strMigrationURL = XPStringUtility.Trim(strMigrationURL);
	}
	
	/**
	 * Returns timeout setting.
	 *
	 * @return PTDuration
	 */
	public PTDuration GetDuration()
	{
		return m_ptdSOAPTimeout;
	}
	
}

