package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Mike Jahr
 *
 */
public class PWSSettingsPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.PWSSettingsPluginView");

	public static final String STR_MVC_CLASS_NAME = "PWSSettingsPluginView";

	public static final String HTMLINPUT_SYNC_URL		  = "in_tx_SyncURL";
	public static final String HTMLINPUT_TIMEOUT_DURATION = "in_tx_Timeout";
	public static final String HTMLSELECT_TIMEOUT_UNITS = "in_se_TimeoutUnits";

	/**
	 * The name of our validation function. This must be added by the Page to the
	 * page level validation function. See WSPluginDP for details.
	 */
	public static final String VALIDATION_FUNCTION_NAME = "IsValidPWSSettings";


	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PWSSettingsPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1123, "ptmsgs_portaladminmsgs")));

			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, "5");

			// 1st row ends
			// 2nd row begins
			String strBaseURL = ((IPWSSettingsPluginModelRO) m_model).GetBaseURL();
			String strDefault = ((IPWSSettingsPluginModelRO) m_model).GetSyncURL();

			WSViewHelper.AddSimpleEditBox(myTable, 5,
				m_asOwner.GetString(1124, "ptmsgs_portaladminmsgs"),
				strBaseURL, strDefault, HTMLINPUT_SYNC_URL);

			//Spacer Row
			WSViewHelper.AddEmptyRow(myTable, "5");


			//////// Portal Timeout
			PTDuration ptdDefault = ((IPWSSettingsPluginModelRO) m_model).GetDuration();
			WSViewHelper.AddSimpleDurationCombo(myTable, 5,
				m_asOwner.GetString(1125, "ptmsgs_portaladminmsgs"),
				HTMLINPUT_TIMEOUT_DURATION, HTMLSELECT_TIMEOUT_UNITS, ptdDefault, m_asOwner);

			// 6th row (spacer row)
			WSViewHelper.AddEmptyRow(myTable, "5");
		}
		catch (Exception e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1122,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result  = new HTMLScript("text/javaScript");
		XPStringBuilder sb = new XPStringBuilder(300);

		try
		{
			sb.Append("\n" + "function " + VALIDATION_FUNCTION_NAME + "()\n");
			sb.Append("{\n");

			WebServiceModel mParent = (WebServiceModel) m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);

			if (WebServiceModel.WSMODE_PWS == mParent.GetWSMode())
			{
				sb.Append(WSViewHelper.ValidateNumericInputJS(
						WSPluginDP.HTMLFORM_NAME,
						PWSSettingsPluginView.HTMLINPUT_TIMEOUT_DURATION,
						m_asOwner.GetString(1126, "ptmsgs_portaladminmsgs")));
			}

			sb.Append(" 	return true;\n");
			sb.Append("}\n\n");

			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he.getMessage());
		}

		return result;
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

