/**
 * Created on Nov 26, 2002
 * by adolfoc
 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.server.impl.core.common.*;

/**
 * @author adolfoc
 *
 */
public class PrefsListPluginModel extends GrowableListModel
	implements IPrefsListPluginModelRO, IWSSubModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.PrefsListPluginModel");

	public static final String STR_MVC_CLASS_NAME = "PrefsListPlugin";

	/**
	 * These values specify whether this model is used to set community
	 * preferences or user preferences. The call to SetPrefMode can be used
	 * to set this when the model is initialized. GetPrefMode can be used to
	 * get which mode this model is in.
	 */
	public static final int PLPM_PREFMODE_USERPREFS		 = 0;

	public static final int PLPM_PREFMODE_COMMUNITYPREFS = 1;

	public static final int PLPM_PREFMODE_SESSIONPREFS = 2;
	
	/**
	 * Every Growable list used within an editor must have a unique ID. It just
	 * so happens that it is easy to accidentally collide (since the unique ID's
	 * are set to 0 and 1 a lot). I'm going to give myself an offset, so that I
	 * am less likely to collide with someone else's unique ID). It doesn't really
	 * matter what this number is, as long as no one else chooses the same one for
	 * another ExpList.
	 */
	private static final int m_nUniqueIDOffset = 666;

	/** NOT Localized String: This string must be blank! */
	public final String _PrefsListMainTitle = "";

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;
	private int m_nPrefMode		 = 0;

	/**
	 * WSMode setting. We use this to determine which checkboxes to display
	 * and store.
	 */
	private int m_nWSMode;

	public PrefsListPluginModel()
	{	
		super();
		m_nWSMode = WebServiceModel.WSMODE_NONE;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PrefsListPluginModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)
	 */
	public void DeleteRowsOnRepost(XPHashtable _htFormData)
	{
		super.DeleteRowsOnRepost(_htFormData);

		String[] arList = GetListValues();

		if ((null == arList) || (0 >= arList.length))
		{
			// Add an extra, empty string for the sake of aesthetics... Any empty 
			// items will be ignored when we store.
			String[] arBlank = { "" };
			AddRowsToList(arBlank);
		}
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		String[] aGrowableArrayValues = GetListValues();

		XPArrayList aPrefsList = new XPArrayList();

		// Preference values will be encoded using this XP String Builder. Hopefully pref value
		// names are under 100 characters.
		XPStringBuilder sEncodedPrefValue;
		
		// Turn this into an Object array so that we can store it.			
		for (int nIndex = 0; nIndex < aGrowableArrayValues.length; nIndex++)
		{
			String strNewValue = aGrowableArrayValues[nIndex];

			if (0 < strNewValue.trim().length())
			{
				// AGC- Warning... We're doing a trim here. I think it is valid, but
				// it is worth noting.
				// JD- Let's also percent-U encode the preference name here.
				sEncodedPrefValue = new XPStringBuilder(strNewValue.length() + 10);
				CharsetConverter.WSTR2PercentU(strNewValue.trim(), sEncodedPrefValue);
				aPrefsList.Add(sEncodedPrefValue.toString());
			}

			
				log.Debug("Prefslist array value: " + aGrowableArrayValues[nIndex]);
			
		}

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		switch (m_nPrefMode)
		{
		case PLPM_PREFMODE_USERPREFS:
			

			// AGC- Do not un-set the locale string from the list of User prefs. But ONLY IN SWS MODE
			// ONLY SWS MODE!!! In SWS Mode the AdvSettingsPluginView handles the existance of the
			// strLocale pref based on a checkbox.
			WebServiceModel mParent = (WebServiceModel)m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
			if (WebServiceModel.WSMODE_SWS == mParent.GetWSMode())
			{
				boolean bStrLocaleWasSet = false;
				XPArrayList xpalOldPrefs = null;
				try {
					xpalOldPrefs = WSModelHelper.ObjectArrayToXPArray(ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS));
				} catch (Exception e)
				{
					//AGC- This likely means that this has never been set in the propertybag.
					// That's fine.
				}
				
				if (null != xpalOldPrefs)
				{
					if (xpalOldPrefs.Contains(AExtensibilityConstants.PTC_STRLOCALE))
					{
						bStrLocaleWasSet = true;
					}
				}
				
				// If the checkbox set strLocale - then don't remove strLocale. If the
				// user added strLocale in by hand, however, we will always add it (notice that
				// when we draw the prefs list in SWS mode, we don't add strLocale). This means
				// that next time the user opens the Editor, strLocale will not show up in our list,
				// but the checkbox will be set. This is weird behavior, but better than the alternatives.				
				if ((bStrLocaleWasSet) && (!aPrefsList.Contains(AExtensibilityConstants.PTC_STRLOCALE)))
				{
					aPrefsList.Add(AExtensibilityConstants.PTC_STRLOCALE);	
				}

			} 


			ptProviderInfo.Write(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS,
				aPrefsList.ToArray());

			break;

		case PLPM_PREFMODE_COMMUNITYPREFS:
			ptProviderInfo.Write(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_COMMUNITYPREFS,
				aPrefsList.ToArray());

			break;
			
		case PLPM_PREFMODE_SESSIONPREFS:
			ptProviderInfo.Write(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SESSIONPREFS,
				aPrefsList.ToArray());

			break;

		}
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
		m_nWSMode = nNewWSMode;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * This method checks whether this model is used to set community
	 * preferences or user preferences. SetPrefMode can be used
	 * to set this when the model is initialized. GetPrefMode can be used to
	 * get which mode this model is in.
	 */
	public int GetPrefMode()
	{
		return m_nPrefMode;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * Returns our current WS display mode from the WebServiceModel.WSMODE enumeration.
	 * @returns int
	 */
	public int GetWSMode()
	{
		return m_nWSMode;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		String strPrefListAddLabel  = "";
		String strPrefListMainTitle = _PrefsListMainTitle;

		switch (m_nPrefMode)
		{
		case PLPM_PREFMODE_USERPREFS:

			strPrefListAddLabel = m_asOwner.GetString(1119,
					"ptmsgs_portaladminmsgs");

			strPrefListMainTitle = m_asOwner.GetString(1116,
					"ptmsgs_portaladminmsgs");

			break;

		case PLPM_PREFMODE_COMMUNITYPREFS:

			strPrefListAddLabel = m_asOwner.GetString(1120,
					"ptmsgs_portaladminmsgs");

			strPrefListMainTitle = m_asOwner.GetString(1117,
					"ptmsgs_portaladminmsgs");

			break;

		case PLPM_PREFMODE_SESSIONPREFS:

			strPrefListAddLabel = m_asOwner.GetString(2798,
					"ptmsgs_portaladminmsgs");

			strPrefListMainTitle = m_asOwner.GetString(2799,
					"ptmsgs_portaladminmsgs");

			break;
		}

		InitializeGrowableList(strPrefListMainTitle,
			strPrefListMainTitle, //m_asOwner.GetString(1118, "ptmsgs_portaladminmsgs") would make user and community the same, difference is appreciated by iecontrol (otherwise it'll rely on the 666 id or the order of user and community)
			PTImageType.ICON_PREFS, strPrefListAddLabel,
			m_nPrefMode + m_nUniqueIDOffset);

		SetDefaultValue("");

		SetDeleteIcon(PTImageType.ACTION_DELETE);

		// Get our state from the ptObject.
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();
		Object[] aPrefsList;

		switch (m_nPrefMode)
		{
		case PLPM_PREFMODE_USERPREFS:
			aPrefsList = ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_USERPREFS);
			
			// AGC- Do not show the locale string in the list of User prefs. But ONLY IN SWS MODE
			// ONLY SWS MODE!!! In SWS Mode the AdvSettingsPluginView handles the existance of the
			// strLocale pref based on a checkbox.
			WebServiceModel mParent = (WebServiceModel)m_asOwner.GetModel(WebServiceModel.STR_MVC_CLASS_NAME);
			if (WebServiceModel.WSMODE_SWS == mParent.GetWSMode())
			{
				XPArrayList xpalPrefsList = WSModelHelper.ObjectArrayToXPArray(aPrefsList);
				
				if ((null != xpalPrefsList) && (xpalPrefsList.GetSize() > 0))
				{
					int nLocaleIndex = xpalPrefsList.IndexOf(AExtensibilityConstants.PTC_STRLOCALE);
					if ((nLocaleIndex >= 0) && (nLocaleIndex < xpalPrefsList.GetSize()))
					{
						xpalPrefsList.RemoveAt(nLocaleIndex);
					} 
					
				}
				aPrefsList = xpalPrefsList.ToArray();
			}

			break;

		case PLPM_PREFMODE_COMMUNITYPREFS:
			aPrefsList = ptProviderInfo.ReadAsObject1DArray(AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_COMMUNITYPREFS);

			break;

		case PLPM_PREFMODE_SESSIONPREFS:default:
			aPrefsList = ptProviderInfo.ReadAsObject1DArray(PlumtreeExtensibility.PT_PROPBAG_HTTPGADGET_SESSIONPREFS);

			break;
		}

		if ((null != aPrefsList) && (aPrefsList.length > 0))
		{
			String[] astrPrefsList = new String[aPrefsList.length];
			XPStringBuilder xpsbDecodedPrefName;

			for (int nIndex = 0; nIndex < aPrefsList.length; nIndex++)
			{
				//CSP decode pref name
				String strPrefName = XPConvert.ToString(aPrefsList[nIndex]);
				xpsbDecodedPrefName = new XPStringBuilder(strPrefName.length() + 10);
				CharsetConverter.PercentUtoBSTR(strPrefName, xpsbDecodedPrefName);
				astrPrefsList[nIndex] = xpsbDecodedPrefName.toString();
			}

			AddRowsToList(astrPrefsList);
		}
		

		// Add an extra, empty string for the sake of aesthetics... Any empty 
		// items will be ignored when we store.
		String[] arBlank = { "" };
		AddRowsToList(arBlank);
	}

	/**
	 * This method specifies whether this model is used to set community
	 * preferences or user preferences. SetPrefMode can be used
	 * to set this when the model is initialized. GetPrefMode can be used to
	 * get which mode this model is in.
	 */
	public void SetPrefMode(int nPrefMode)
	{
		m_nPrefMode = nPrefMode;
	}
}

