package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * 
 * @author rozhang
 */
public class RemotePageletPickerPluginModel extends EditorHelperModel implements IWSSubModel 
{
	private static OpenLogger log = OpenLogService.GetLogger(OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		RemotePageletPickerPluginModel.class);
	
	public static final String STR_MVC_CLASS_NAME = "RemotePageletPicker";

	public final static String INPUTNAME_SELECTEDLIB 	 = "in_hi_selpageletlib";
	public final static String INPUTNAME_SELECTEDPAGELET = "in_hi_selpagelet";
	
	protected IPTWebService	m_webService = null;
	
	protected boolean		m_ensembleServerValid = true; 
	
	protected EnsemblePageletRestData[] m_pagelets = null;
	
	protected XPHashtable 	m_libCollection = new XPHashtable();
	protected XPHashtable	m_pageletData	= new XPHashtable();
	protected String[]		m_libNames		= null;
	// store portlet community preferences names, used by PageletPAramsMapPluginModel
	protected String[]		m_pageletParamNames = null;
	protected String[]		m_pageletParamDescriptions = null;
	
	protected String		m_selectedLibraryName = null;
	protected String		m_selectedPageletName = null;
	protected String		m_selectedPageletDesc = null;
	
	protected int			m_selectedLibIndex = -1;
	protected String		m_selectedPageletId = "";
	
	/**
	 * Loads stored data and retrieves list of pagelets from ensemble
	 * This method is called once editor is started  
	 * 
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel(com.plumtree.server.IPTWebService)
	 */
	public void InitWSModel(IPTWebService ptWebService) 
	{
		// this method is called in all webservice editors, not just remote pagelets, don't do anything unless
		// we are in a remote pagelet webservice editor
		if ( !RemPageletWSWebServiceEditorAS.STR_MVC_CLASS_NAME.equals( m_asOwner.GetName() ) ) {
			return;
		}
		
		m_webService = ptWebService;

		// first load the stored library and pagelet name
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
		m_selectedLibraryName = WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY, "");
		m_selectedPageletName =  WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_NAME, "");
		
		// now get the list of pagelets from ensemble rest api
		IPTSession session = (IPTSession)m_asOwner.GetUserSession();
		EnsembleRestAPIService service = new EnsembleRestAPIService();
		EnsemblePageletRestData[] pagelets = null;
		try {
			pagelets = service.GetAllPageletsFromRest(session);

			if ( pagelets == null ) {
				HandleUIError( m_asOwner.GetString(3237, ResourceConstants.PORTALADMINMSGS) );
				m_ensembleServerValid = false;
				return;
			}
			
		} catch (XPException e) {
			if ( e instanceof RestConnectFailedException) {
				// handle when ensemble remote server is not available
				log.Error(e, "Error connecting to Ensemble REST service.");
				HandleUIError( m_asOwner.GetString(3237, ResourceConstants.PORTALADMINMSGS) );
			} else {
				log.Error(e, "Error parsing REST Response from Ensemble.");
				HandleUIError( m_asOwner.GetString(3283, ResourceConstants.PORTALADMINMSGS) );
			}
			m_ensembleServerValid = false;
			return;
		}
		m_pagelets = pagelets;
		
		// need to extract pagelets by library - use an arraylist for each library and add all libraries to a hashtable
		XPHashtable libCollection = new XPHashtable();
		
		for ( int i = 0; i < pagelets.length; i++ ) 
		{
			EnsemblePageletRestData pagelet = pagelets[i];
			String libName = pagelet.libraryName;
			// for the stored pagelet, gets its id and description - used by the view
			if ( pagelet.name.equals(m_selectedPageletName)) {
				m_selectedPageletId = pagelet.id+"";
				m_selectedPageletDesc = pagelet.description;
			}
			
			// keep a map of pagelet ids to pagelet names (need to display pagelet name)
			m_pageletData.PutElement(pagelet.id+"", pagelet);
			 
			if ( !libCollection.ContainsKey(libName) ) 
			{
				// new library, add a new arraylist to put pagelets in
				XPArrayList newLib = new XPArrayList();
				newLib.Add(pagelet);
				libCollection.PutElement(libName, newLib);
			} 
			else 
			{
				// library already exists, add to existing arraylist 
				((XPArrayList) libCollection.GetElement(libName)).Add(pagelet);
			}
		}
		
		m_libCollection = libCollection;
		
		// make sure we got at least one library, should really never happen
		if ( m_libCollection.GetSize() < 1 ) {
			throw new XPIllegalStateException("No pagelet libraries found!");
		}
		
		// set the index of selected library
		String[] libNames = GetPageletLibraries();
		if ( "".equals(m_selectedLibraryName) || m_selectedLibraryName == null ) {
			// select the first library if none is saved
			m_selectedLibIndex = 0;
			RefreshSelectedPageletLibraryName();
		} else {
			for ( int i = 0; i < libNames.length; i++ ) {
				if ( libNames[i].equals(m_selectedLibraryName) ) {
					m_selectedLibIndex = i;
					break;
				}
			}
		} 
	}
	
	/**
	 * Save reposted page data to model
	 * Called on every page reload and before switching pages 
	 * 
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData) 
	{
		// this method is called in all webservice editors, not just remote pagelets, don't do anything unless
		// we are in a remote pagelet webservice editor
		if ( !RemPageletWSWebServiceEditorAS.STR_MVC_CLASS_NAME.equals( m_asOwner.GetName() ) ) {
			return EditorRepostControl.PAGE_STATUS_VALID;
		}
		
		if ( !m_ensembleServerValid ) {
			String strError = m_asOwner.GetString(3237, ResourceConstants.PORTALADMINMSGS);
			HandleUIError(strError);
			return EditorRepostControl.PAGE_STATUS_INVALID;
		}
		
		boolean newLibrarySelected = false;
		int valid = EditorRepostControl.PAGE_STATUS_VALID;
		
		// get the selected library from the form repost
		if ( _htFormData.ContainsKey(INPUTNAME_SELECTEDLIB) ) {
			String libIndex = ((String[])_htFormData.GetElement(INPUTNAME_SELECTEDLIB))[0];
			// invalid library
			if ( "".equals(libIndex) || libIndex == null ) {
				// should never get here
				m_selectedLibIndex = -1;
			} else {
				int newLibrary = XPConvert.ToInteger( libIndex );
				if ( m_selectedLibIndex != newLibrary ) {
					// we got a new library, clear the selected pagelet
					ClearSelectedPagelet();
					m_selectedLibIndex = newLibrary;
					newLibrarySelected = true;
				}
				// sets the library name
				this.RefreshSelectedPageletLibraryName();
			}
		} else {
			throw new XPIllegalStateException("Missing form element missing from page! Hidden input: "+INPUTNAME_SELECTEDLIB+" not found.");
		}
		// SET PAGELET
		// if new library was set, don't bother setting new portlet, we are changing library so pagelet is cleared
		if ( !newLibrarySelected ) 
		{ 
			if ( !_htFormData.ContainsKey(INPUTNAME_SELECTEDPAGELET) ) {
				throw new XPIllegalStateException("Missing form element missing from page! Hidden input: "+INPUTNAME_SELECTEDPAGELET+" not found.");
			}
			
			m_selectedPageletId = ((String[])_htFormData.GetElement(INPUTNAME_SELECTEDPAGELET))[0];
			
			// if it is a change page action, validate that a valid pagelet has been selected
			String repostMode = ((String[])_htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF))[0];
			// make sure we got a pagelet selected before allowing user to switch page, but don't peform check when just
			// reloading page for changing libraries
			if ( repostMode.equals(RepostControl.POSTTOSELF_ACTION_GOTOPAGE+"") || repostMode.equals(RepostControl.POSTTOSELF_ACTION_FINISH+"") ) 
			{
				String errorString = m_asOwner.GetString(3238, ResourceConstants.PORTALADMINMSGS);;
				valid = ModelHelper.ValidateInteger(m_selectedPageletId, m_asOwner, errorString, valid);
				
				if ( valid == RepostControl.PAGE_STATUS_VALID ) {
					// store the selected pagelet name in the model
					EnsemblePageletRestData pagelet = (EnsemblePageletRestData)m_pageletData.GetElement(m_selectedPageletId);
					m_selectedPageletName 			= pagelet.name;
					m_pageletParamNames 			= pagelet.prefsData.GetParameterNames();
					m_pageletParamDescriptions  	= pagelet.prefsData.GetParameterDescriptions();
				}
			}
		} 
		return valid;
	}

	/**
	 * Store the library name and pagelet name in the webservice webservice property bag 
	 * 
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore() 
	{
		// don't save any data if the ensemble service is not configured properly
		if ( m_ensembleServerValid )
		{
			IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_webService.GetProviderInfo();
			
			WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_LIBRARY, m_selectedLibraryName);
			WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PAGELET_NAME, m_selectedPageletName);
		}
	}
	
	/**
	 * Sets the name of the selected library
	 */
	public void RefreshSelectedPageletLibraryName()
	{
		// not initialized, invalid ensemble server
		if ( m_libNames == null ) {
			return;
		}
		m_selectedLibraryName = m_libNames[m_selectedLibIndex];
	}
	
	public EnsemblePageletRestData[] GetPagelets()
	{
		return m_pagelets;
	}
	
	public XPArrayList GetPageletsInCurrentLibrary() 
	{
		XPArrayList pagelets = (XPArrayList)m_libCollection.GetElement(m_selectedLibraryName);
		if ( pagelets == null ) {
			return new XPArrayList();
		}
		return pagelets;
	}
	
	public String GetSelectedLibraryName()
	{
		return m_selectedLibraryName;
	}
	
	public int GetSelectedLibraryIndex()
	{
		return m_selectedLibIndex;
	}
	
	public String GetSelectedPageletIndex()
	{
		return m_selectedPageletId;
	}
	
	public String GetSelectedPageletName()
	{
		return m_selectedPageletName;
	}
	
	public String GetSelectedPageletDescription()
	{
		return m_selectedPageletDesc;
	}
	
	public String[] GetPageletParameterNames()
	{
		return m_pageletParamNames;
	}
	
	public String[] GetPageletParameterDescriptions()
	{
		return m_pageletParamDescriptions;
	}
	
	protected String ClearSelectedPagelet()
	{
		String oldPageletId 	= m_selectedPageletId;
		
		m_selectedPageletName 	= "";
		m_selectedPageletId 	= "";
		m_selectedPageletDesc	= "";
		
		m_pageletParamNames		= null;
		m_pageletParamDescriptions = null;
		
		return oldPageletId;
	}

	
	/**
	 * @return
	 */
	public String[] GetPageletLibraries()
	{
		if ( m_libCollection == null ) {
			return new String[] {};
		}
		
		String[] returnVal = null;
		if ( m_libNames == null)
		{
			returnVal = new String[m_libCollection.GetSize()];
			IXPEnumerator names = m_libCollection.GetKeys();
			int count = 0;
			while ( names.MoveNext() ) {
				returnVal[count] = (String)names.GetCurrent();
				count++;
			}
			m_libNames = returnVal;
		} else {
			returnVal = m_libNames;
		}
		return returnVal;
	}
	
	/**
	 * 
	 * @param errorMessage
	 */
	public void HandleUIError(String errorMessage)
	{
		UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, errorMessage, errorMessage);
		UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(java.lang.String, java.lang.String, java.lang.String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID, String strRemoteServerName, String strRemoteServerBaseURL) 
	{
		// This won't happen since remote servers don't change for remote pagelet webservices
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode) 
	{
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction() 
	{
		return null;
	}
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#Create()
	 */
	public Object Create() 
	{
		return new RemotePageletPickerPluginModel();
	}

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#GetName()
	 */
	public String GetName() 
	{
		return STR_MVC_CLASS_NAME;
	}
}
