/**
 * Created on Oct 29, 2002
 *
 * To change this generated comment edit the template variable "filecomment":

 * To enable and disable the creation of file comments go to

 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author adolfoc
 *
 */
public class SWSSettingsPluginModel extends EditorHelperModel
	implements ISWSSettingsPluginModelRO, IWSSubModel
{
	/** This object's name */
	public static final String STR_MVC_CLASS_NAME = "SWSSettings";

	/**
	 * This mask is used by our view to send time data to us in units that we
	 * support.
	 */
	public static final int NMASK_SUPPORTED_UNITS = PTDurationCombo.DISPLAYMINUTES |
		PTDurationCombo.DISPLAYSECONDS;

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * We might get the Remote Server Base URL from
	 * our parent model if it is a WebService Model. It is stored here.
	 */
	private String m_strBaseURL = "";

	/** Logging object and booleans */
	/** URL to this Web Service (To be combined with the BaseURL from the Remote Server)
	 * (RemoteServerPluginView) */
	private String m_strSearchURL = "";

	/**
	 * Timeout information.
	 */
	protected PTDuration m_ptdSOAPTimeout;
	protected PTDuration m_ptdGatewayTimeout;
	
	public SWSSettingsPluginModel()
	{
		super();
		m_ptdSOAPTimeout = new PTDuration(5000, NMASK_SUPPORTED_UNITS);
		m_ptdGatewayTimeout = new PTDuration(20000, NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SWSSettingsPluginModel();
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) m_ptWebService.GetProviderInfo();

		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PT_PROPBAG_FORMAT, AExtensibilityConstants.PT_PROPBAG_FORMAT_HTTPGADGET_INIT);
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSWS_SEARCHURL, GetSearchURL());
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT, m_ptdSOAPTimeout.GetMilliseconds());
		WSModelHelper.PBWrite(ptProviderInfo, AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT, m_ptdGatewayTimeout.GetMilliseconds());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
		m_strBaseURL = strRemoteServerBaseURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ISWSSettingsPluginModelRO#GetBaseURL()
	 */
	public String GetBaseURL()
	{
		return m_strBaseURL;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * Returns the SWS Search URL
	 *
	 * @return String
	 */
	public String GetSearchURL()
	{
		return m_strSearchURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return SWSSettingsPluginView.VALIDATION_FUNCTION_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;

		IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
		SetSearchURL(WSModelHelper.PBReadString(ptProviderInfo, AExtensibilityConstants.PTC_HTTPSWS_SEARCHURL, GetSearchURL()));
		
		
		m_ptdSOAPTimeout = new PTDuration(WSModelHelper.PBReadInt(
					ptProviderInfo,
					AExtensibilityConstants.PTC_HTTPSOAP_TIMEOUT,
					m_ptdSOAPTimeout.GetMilliseconds()), NMASK_SUPPORTED_UNITS);

		m_ptdGatewayTimeout = new PTDuration(WSModelHelper.PBReadInt(
					ptProviderInfo,
					AExtensibilityConstants.PTC_HTTPGADGET_GATEWAYTIMEOUT,
					m_ptdGatewayTimeout.GetMilliseconds()), NMASK_SUPPORTED_UNITS);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		
		SetSearchURL(WSModelHelper.GetFormElementString(_htFormData, SWSSettingsPluginView.HTMLINPUT_SEARCH_URL, GetSearchURL()));


		m_ptdSOAPTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				SWSSettingsPluginView.HTMLINPUT_TIMEOUT_SOAPDURATION,
				SWSSettingsPluginView.HTMLSELECT_TIMEOUT_SOAPUNITS, m_ptdSOAPTimeout);

		m_ptdGatewayTimeout = WSModelHelper.GetFormElementDuration(_htFormData,
				SWSSettingsPluginView.HTMLINPUT_TIMEOUT_GATEWAYDURATION,
				SWSSettingsPluginView.HTMLSELECT_TIMEOUT_GATEWAYUNITS, m_ptdGatewayTimeout);



		int nValid = RepostControl.PAGE_STATUS_VALID;


		if ((null == m_strBaseURL) || (m_strBaseURL.length() <= 0))
		{
			nValid = WSModelHelper.ValidateIsURLString(m_strSearchURL, m_asOwner, m_asOwner.GetString(1935, "ptmsgs_portaladminmsgs"), nValid);
		}
		else
		{
			nValid = WSModelHelper.ValidateNonEmptyString(m_strSearchURL, m_asOwner, m_asOwner.GetString(1152, "ptmsgs_portaladminmsgs"), nValid);
		}

		nValid = WSModelHelper.ValidateDurationRange(m_ptdSOAPTimeout,
				m_asOwner, m_asOwner.GetString(1936, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 90);


		nValid = WSModelHelper.ValidateDurationRange(m_ptdGatewayTimeout,
				m_asOwner, m_asOwner.GetString(1937, "ptmsgs_portaladminmsgs"), nValid, 1000,
				1000 * 60 * 90);

		return nValid;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ISWSSettingsPluginModelRO#GetGatewayDuration()
	 */
	public PTDuration GetGatewayDuration() {
		return m_ptdGatewayTimeout;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ISWSSettingsPluginModelRO#GetSOAPDuration()
	 */
	public PTDuration GetSOAPDuration() {
		return m_ptdSOAPTimeout;
	}

	/**
	 * Sets the SWS Search URL
	 *
	 * @param strWebServiceURL The m_strWebServiceURL to set
	 */
	public void SetSearchURL(String strWebServiceURL)
	{
		this.m_strSearchURL = strWebServiceURL;
	}
}

