/**
 * Created on Oct 30, 2002
 *
 * To change this generated comment edit the template variable "filecomment":

 * To enable and disable the creation of file comments go to

 */
package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author adolfoc
 */
public class SelectDevicesPluginModel extends EditorHelperModel
	implements ISelectDevicesPluginModelRO, IWSSubModel
{
	public static final String STR_MVC_CLASS_NAME = "SelectDevicesPlugin";

	/**
	 * The Web Service object being edited by our parent Web Service editor
	 */
	IPTWebService m_ptWebService = null;

	/**
	 * URL to the BaseURL from the Remote Server
	 */
	private String m_strBaseURL = "";

	private XPArrayList m_xpalAvailUIUniqueIDs = null;

	/**
	 * The array of selected Devices (by UniqueID)
	 */
	private XPArrayList m_xpalSelectedDevices;
	private XPHashtable m_xphAvailUIDescriptions = null;
	private XPHashtable m_xphAvailUINames		 = null;

	/**
	 * The array and hash tables that contain the available UserInterface data.
	 * These three members are initialized by the LazyInitAvailableUIs function.
	 */
	private boolean m_bAvailUIsInitialized = false;

	public SelectDevicesPluginModel()
	{
		super();
		m_xpalSelectedDevices = new XPArrayList();;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectDevicesPluginModel();
	}

	/**
	 * Returns whether or not a particular device is selected for this WebService.
	 */
	public boolean DeviceChecked(String strUnique)
	{
		return m_xpalSelectedDevices.Contains(strUnique);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskBeforeWSStore()
	 */
	public void DoTaskBeforeWSStore()
	{
		m_ptWebService.SetUserInterfaces(m_xpalSelectedDevices.ToArray());
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnRemoteServerUpdate(String, String, String)
	 */
	public void DoTaskOnRemoteServerUpdate(String strRemoteServerID,
		String strRemoteServerName, String strRemoteServerBaseURL)
	{
		m_strBaseURL = strRemoteServerBaseURL;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#DoTaskOnWSModeUpdate(int)
	 */
	public void DoTaskOnWSModeUpdate(int nNewWSMode)
	{
	}

	/**
	 * Returns an ArrayList of all of the available userinterface objectids.
	 */
	public XPArrayList GetAvailableUIs()
	{
		LazyInitAvailableUIs();

		return m_xpalAvailUIUniqueIDs;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.plugins.ISelectDevicesPluginModelRO#GetBaseURL()
	 */
	public String GetBaseURL()
	{
		return m_strBaseURL;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the Description of the interface with a particular Object ID (use GetAvailableUIs to
	 * get a list of valid objectids).
	 */
	public String GetUIDescription(String strUnique)
	{
		LazyInitAvailableUIs();

		return (String) m_xphAvailUIDescriptions.GetElement(strUnique);
	}

	/**
	 * Returns the Name of the interface with a particular Object ID (use GetAvailableUIs to
	 * get a list of valid objectids).
	 */
	public String GetUIName(String strUnique)
	{
		LazyInitAvailableUIs();

		return (String) m_xphAvailUINames.GetElement(strUnique);
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#GetValidationFunction()
	 */
	public String GetValidationFunction()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.admin.editors.webservice.IWSSubModel#InitWSModel()
	 */
	public void InitWSModel(IPTWebService ptWebService)
	{
		m_ptWebService = ptWebService;
		m_xpalSelectedDevices.Clear();

		Object[] arDevices = (Object[]) ptWebService.GetUserInterfaces();

		if (null != arDevices)
		{
			for (int nIndex = 0; nIndex < arDevices.length; nIndex++)
			{
				m_xpalSelectedDevices.Add(arDevices[nIndex]);
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		LazyInitAvailableUIs();
		m_xpalSelectedDevices.Clear();
						
		String[] data = (String[]) _htFormData.GetElement(SelectDevicesPluginView.HTTP_DEVICE_PREFIX);
		if (data != null)
		{
			for (int nIndex = 0; nIndex < data.length; nIndex++)
			{
				if ((null != data[nIndex]) && (0 < data[nIndex].length()))
				{
					m_xpalSelectedDevices.Add(data[nIndex]);
				}
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	// Helper Functions

	/**
	 * Initializes the member variables that contain the available userinterface info.
	 */
	private void LazyInitAvailableUIs()
	{
		if (m_bAvailUIsInitialized)
		{
			return;
		}

		IPTSession ptSession = ((WebServiceModel) ((WebServiceEditorAS) m_asOwner).GetModel(WebServiceModel.STR_MVC_CLASS_NAME)).GetPTSession();

		//Future Feature: Should use ObjectManagerQueryResultWrapper here- will perform better.		
		IPTObjectManager ptOMUserInterfaces = ptSession.GetUserInterfaces();
		IPTQueryResult ptQRUserInterfaces   = ptOMUserInterfaces.SimpleQuery(-1,
				PT_PROPIDS.PT_PROPID_NAME);

		int nNumUIs = 0;

		if (null != ptQRUserInterfaces)
		{
			nNumUIs = ptQRUserInterfaces.RowCount();
		}

		// Initalize our members
		m_xpalAvailUIUniqueIDs		 = new XPArrayList();
		m_xphAvailUINames			 = new XPHashtable();
		m_xphAvailUIDescriptions     = new XPHashtable();

		// Now fill our members with da data.
		for (int nIndex = 0; nIndex < nNumUIs; nIndex++)
		{
			String strUniqueID = ptQRUserInterfaces.ItemAsString(nIndex,
					PT_PROPIDS.PT_PROPID_USERINTERFACE_UNIQUEID);
			m_xpalAvailUIUniqueIDs.Add(strUniqueID);
			m_xphAvailUINames.PutElement(strUniqueID,
				ptQRUserInterfaces.ItemAsString(nIndex,
					PT_PROPIDS.PT_PROPID_NAME));
			m_xphAvailUIDescriptions.PutElement(strUniqueID,
				ptQRUserInterfaces.ItemAsString(nIndex,
					PT_PROPIDS.PT_PROPID_DESCRIPTION));
		}

		m_bAvailUIsInitialized = true;
	}
}

