package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 */
public class SelectDevicesPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.SelectDevicesPluginView");

	
	public static final String STR_MVC_CLASS_NAME = "SelectDevicesPluginView";

	
	/**
	 * The Prefix to the QueryString argument name to be used to pass around the selected devices.
	 */
	public static final String HTTP_DEVICE_PREFIX    = "in_cb_Device";

	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectDevicesPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1144, "ptmsgs_portaladminmsgs")));
						
			myTable = WSViewHelper.AddTable(result);

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, "5");

			// 1st row ends
			// 2nd - Xth rows begin
			XPArrayList xpalUniqueIDs = ((ISelectDevicesPluginModelRO) m_model).GetAvailableUIs();

			if (0 == xpalUniqueIDs.GetSize())
			{
				myRow = WSViewHelper.AddRow(myTable);

				// Left Margin
				WSViewHelper.AddLeftMargin(myRow, 5);
				
				// "Empty" Label
				WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.TWO, m_asOwner.GetString(1145, "ptmsgs_portaladminmsgs"));
				
				// Right Margin
				WSViewHelper.AddRightMargin(myRow, 5);
			}

			for (int nIndex = 0; nIndex < xpalUniqueIDs.GetSize(); nIndex++)
			{
				// Check Boxe(s)
				String strUniqueID    = (String) xpalUniqueIDs.GetElement(nIndex);
				String strHTTP		  = HTTP_DEVICE_PREFIX;
				String strUI		  = ((ISelectDevicesPluginModelRO) m_model).GetUIName(strUniqueID);
				String strDescription = ((ISelectDevicesPluginModelRO) m_model).GetUIDescription(strUniqueID);
				AddSimpleDeviceCheckBox(myTable, strHTTP, strUniqueID, strUI,
					strDescription);

			}

			// Xth + 1 row
			WSViewHelper.AddEmptyRow(myTable, "5");

		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1143,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = new HTMLScript("text/javaScript");

		return result;
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}

	// Helper Function:
	private void AddSimpleDeviceCheckBox(HTMLTable myTable, String strHTTP,
		String strUniqueID, String strUI, String strDescription)

	{
		HTMLTableRow myRow = WSViewHelper.AddRow(myTable);
		HTMLTableCell myCell;
		HTMLSpan mySpan;


		// Margin
		WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
		

		//// Checkbox, in a separate cell.
		myCell = WSViewHelper.AddCell(myRow, CommonHTMLStrings.ONE);
		mySpan	    = WSViewHelper.AddSpanToCell(myCell);
		mySpan.AddInnerHTMLElement(WSViewHelper.MakeSimpleCheckbox("", strHTTP, strUniqueID,
			((ISelectDevicesPluginModelRO) m_model).DeviceChecked(strUniqueID), ""));

		//// Label.
		myCell = WSViewHelper.AddLabelCell(myRow, CommonHTMLStrings.ONE, strUI);
		myCell.SetNoWrap(false);
		mySpan = WSViewHelper.AddSpanToCell(myCell);
		mySpan.AddInnerHTMLElement(new HTMLBr());
		mySpan.AddInnerHTMLEncodedString(strDescription);

		//// Description, underneath name cell.
		
		
		// Margin
		WSViewHelper.AddEmptyCell(myRow, CommonHTMLStrings.ONE);
	}
}

