package com.plumtree.portalpages.admin.editors.webservice.plugins;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.webservice.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author adolfoc
 *
 * This plugin view is used to show both User and Community Preferences. It will
 * get the label that describes whether it is User or Community from its model.
 */
public class UserPrefsPluginView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.webservice.plugins.UserPrefsPluginView");

	
	public static final String STR_MVC_CLASS_NAME = "UserPrefsPluginView";

	// HTML Object names.
	public static final String HTMLINPUT_USER_PREFS_URL		    = "in_tx_UserPrefsURL";
	public static final String HTMLINPUT_COMMUNITY_PREFS_URL    = "in_tx_CommunityPrefsURL";
	public static final String HTMLINPUT_ADMIN_PREFS_URL	    = "in_tx_AdminPrefsURL";
	public static final String HTMLINPUT_TEMPLT_ADMIN_PREFS_URL = "in_tx_TemplAdminPrefsURL";

	/**
	 * Our parent Activity space.
	 */
	private AActivitySpace m_asasParent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserPrefsPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;

		try
		{
			switch (((IUserPrefsPluginModelRO) m_model).GetPrefMode())
			{
			case UserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:
			case UserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:
			case UserPrefsPluginModel.UPPM_PREFMODE_SESSIONPREFS:
				
				break;

			case UserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:

				result.AddInnerHTMLElement(super.GetHeaderView(
						m_asOwner.GetString(1174, "ptmsgs_portaladminmsgs")));
				myTable = GetDisplayAsTable();
				result.AddInnerHTMLElement(myTable);

				break;
			}
		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1171,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = new HTMLScript("text/javaScript");

		return result;
	}

	public HTMLTable GetDisplayAsTable()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;


		try
		{
			myTable = WSViewHelper.MakeTable();

			// 1st row begins (Top Margin)
			WSViewHelper.AddEmptyRow(myTable, "5");

			// 1st row ends
			// 2nd row 
			String strBaseURL	    = ((IUserPrefsPluginModelRO) m_model).GetBaseURL();
			String strDefault	    = ((IUserPrefsPluginModelRO) m_model).GetPrefsURL();
			String strTempltDefault = ((IUserPrefsPluginModelRO) m_model).GetTemplatePrefsURL();

			switch (((IUserPrefsPluginModelRO) m_model).GetPrefMode())
			{
			case UserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:

				WSViewHelper.AddSimpleEditBox(myTable, 5,
					m_asOwner.GetString(1176, "ptmsgs_portaladminmsgs"),
					strBaseURL, strDefault, HTMLINPUT_COMMUNITY_PREFS_URL);
			
				// 3rd row (spacer row)
				WSViewHelper.AddEmptyRow(myTable, "5");
				break;

			case UserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:

				WSViewHelper.AddSimpleEditBox(myTable, 5,
					m_asOwner.GetString(1175, "ptmsgs_portaladminmsgs"),
					strBaseURL, strDefault, HTMLINPUT_USER_PREFS_URL);


				// 3rd row (spacer row)
				WSViewHelper.AddEmptyRow(myTable, "5");
				break;

			case UserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:

				WSViewHelper.AddSimpleEditBox(myTable, 5,
					m_asOwner.GetString(1177, "ptmsgs_portaladminmsgs"),
					strBaseURL, strDefault, HTMLINPUT_ADMIN_PREFS_URL);


				WSViewHelper.AddEmptyRow(myTable, "5");
				
				WSViewHelper.AddSimpleEditBox(myTable, 5,
					m_asOwner.GetString(1178, "ptmsgs_portaladminmsgs"),
					strBaseURL, strTempltDefault,
					HTMLINPUT_TEMPLT_ADMIN_PREFS_URL);

				// 3rd row (spacer row)
				WSViewHelper.AddEmptyRow(myTable, "5");
				break;
				
			case UserPrefsPluginModel.UPPM_PREFMODE_SESSIONPREFS: default:

				//do nothing here
				break;

			}

			switch (((IUserPrefsPluginModelRO) m_model).GetPrefMode())
			{
			case UserPrefsPluginModel.UPPM_PREFMODE_COMMUNITYPREFS:
			case UserPrefsPluginModel.UPPM_PREFMODE_USERPREFS:
			case UserPrefsPluginModel.UPPM_PREFMODE_SESSIONPREFS:

				// 4th row begins (Only for User, Session and Community Views)
				myRow = WSViewHelper.AddRow(myTable);

				// Left Margin
				WSViewHelper.AddLeftMargin(myRow, 5);

				// Write in instructions for the preference list.
				WSViewHelper.AddTextCell(myRow, CommonHTMLStrings.TWO, m_asOwner.GetString(1179, "ptmsgs_portaladminmsgs")); 

				// Right Margin
				WSViewHelper.AddRightMargin(myRow, 5);

				break;

			case UserPrefsPluginModel.UPPM_PREFMODE_ADMINPREFS:default:
				break;
			}
		}
		catch (HTMLException e)
		{
			
				log.Error(e, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1171,
					"ptmsgs_portaladminmsgs"), e);
		}

		return myTable;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
		m_asasParent = parent;
	}
}

