package com.plumtree.portalpages.admin.editors.webservice.userinfotree;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * @author adolfoc
 *
 * To change this generated comment edit the template variable "typecomment":
 * Window>Preferences>Java>Templates.
 * To enable and disable the creation of type comments go to
 * Window>Preferences>Java>Code Generation.
 */
public class UserInfoRefreshTreeControl extends RefreshTreeControl {
	/** name of the refresh tree control */
	public static final String STR_MVC_CLASS_NAME = "UserInfoRefreshTree";

	
	/** A separator character used when encoding UserInfo arguments. **/
	private static String USERINFO_SEPARATORCHAR = ",";
	
	/** An encoding character used to encode/decode UserInfos **/
	private static String USERINFO_ESCAPECHAR = "!";
	
	/** A Query String argument name - used for setting the selected USerInfos. */
	public static final String SELECTED_USERINFOS = "SelectUserInfo";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserInfoRefreshTreeControl();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments) {
		Redirect rResult = super.CheckActionSecurityAndExecute(arguments);

		String[] sValues;

		// Object ids to select
		sValues = (String[]) arguments.GetElement(SELECTED_USERINFOS);

		if (sValues != null)
		{
			((UserInfoTreeModel)m_asModel).SetUserInfosToSelect(StringToUserInfos(sValues[0]));
		}

		// Now load the bugger.
		((UserInfoTreeModel) m_asModel).LoadUserInfo();
		
		return rResult;
		
	}


	/**
	 * Used for transferring Userinfo's via QueryString argument. Encodes an
	 * array of user info strings into a string usable as a QueryString
	 * argument.
	 * 
	 * @param arsUserInfos
	 * @return String
	 */
	public static String UserInfosToString(String[] arsUserInfos)
	{
		String strResult = "";
		for (int nIndex = 0; nIndex < arsUserInfos.length; nIndex++)
		{
			if (0 != nIndex)
			{
				strResult += USERINFO_SEPARATORCHAR;
			}
			strResult += EscapeUserInfo(arsUserInfos[nIndex]);
		}
		
		return strResult;
	}
	
	/**
	 * User for transferring Userinfo's via Query String. Decodes a string of
	 * userinfo's separated by tokens into an array of Userinfo's. Avoids
	 * mistaken tokens by using an escape character.
	 * 
	 * @param strUserInfoData
	 * @return XPArrayList
	 */
	public static XPArrayList StringToUserInfos(String strUserInfoData)
	{
		XPStringTokenizer xpstUnEscape = new XPStringTokenizer(strUserInfoData, USERINFO_SEPARATORCHAR);
		
		XPArrayList xpalResult		 = new XPArrayList();		

		while(xpstUnEscape.HasMoreTokens())
		{
			String strCurrentUserInfo = xpstUnEscape.GetNextToken();
			
			// AGC- if the end of strCurrentUserInfo is the escape char, then
			// we should remove the escape char and add the next token. We must continue
			// doing this until we find an un-escaped token.
			while (0 == USERINFO_ESCAPECHAR.compareTo(strCurrentUserInfo.substring(strCurrentUserInfo.length() - USERINFO_ESCAPECHAR.length())))
			{	
				// Remove the escape char and add back the original character (removed by the tokenizer).			
				strCurrentUserInfo = strCurrentUserInfo.substring(0, strCurrentUserInfo.length() - USERINFO_ESCAPECHAR.length()) + USERINFO_SEPARATORCHAR;
				
				// Could always be the last item in the string. Must check for more tokens.
				if (xpstUnEscape.HasMoreTokens())
				{
					// There's another token. Tack them together. 
					strCurrentUserInfo = strCurrentUserInfo + xpstUnEscape.GetNextToken();
				} 
			}
			
			// AGC- We've finally regenerated the original userinfo. Add it to 
			// the results.
			xpalResult.Add(strCurrentUserInfo);
		}

		return xpalResult;
 
	}
	
	/**
	 * Escapes a single userinfo string to avoid collision with the separator
	 * character used in StringToUserInfos and UserInfosToString.
	 * 
	 * @param strIn
	 * @return String
	 */
	private static String EscapeUserInfo(String strIn)
	{
		String strReplacement = USERINFO_ESCAPECHAR + USERINFO_SEPARATORCHAR;
		String strResult = GeneralHelpers.Replace(strIn, USERINFO_SEPARATORCHAR, strReplacement);
		return strResult;
	}
	

	public static String UserInfoToStringJS(String strUnique, String strFormPrefix)
	{
		String strReplacement = USERINFO_ESCAPECHAR + USERINFO_SEPARATORCHAR;
		
		XPStringBuilder xpsbResult = new XPStringBuilder(400);
		
		xpsbResult.Append("function UserInfoArgFromExpList").Append(strUnique).Append("()\n");
		xpsbResult.Append("{\n");
		
		xpsbResult.Append("  var frm = document.").Append(AFormDP.HTMLFORM_NAME).Append(";\n"); 
		xpsbResult.Append("  var len = frm.elements.length;\n"); 
		
		xpsbResult.Append("  var i = 0;\n");
		xpsbResult.Append("  var sItemPrefix = '").Append(strFormPrefix).Append(strUnique).Append("';\n");
		xpsbResult.Append("  var result = '';\n");
		  
		xpsbResult.Append("  for(i=0 ; i<len ; i++)\n"); 
		xpsbResult.Append("  {\n");
		xpsbResult.Append("    if (frm.elements[i].name.substr(0, sItemPrefix.length) == sItemPrefix)\n"); 
		xpsbResult.Append("    {\n");
		xpsbResult.Append("      var current = frm.elements[i].value\n");
		xpsbResult.Append("      current = current.replace('").Append(USERINFO_SEPARATORCHAR).Append("', '").Append(strReplacement).Append("');\n");
		
		xpsbResult.Append("      if (0 != result.length)\n");
		xpsbResult.Append("      {\n");
		xpsbResult.Append("         result = result + ',' + current;\n");
		xpsbResult.Append("      } else {\n");
		xpsbResult.Append("         result = current;\n");
		xpsbResult.Append("      }\n");
		xpsbResult.Append("    } \n");
		xpsbResult.Append("  }\n");
		
		xpsbResult.Append("  result = '&SelectUserInfo=' + result;\n");
		xpsbResult.Append("  return result;\n");		
		xpsbResult.Append("}\n");
		
		return xpsbResult.ToString();
	}
	
	public static String UserInfoToStringJSFunc(String strUnique)
	{
		return "UserInfoArgFromExpList" + strUnique + "()";
	}
	
}


