package com.plumtree.portalpages.admin.editors.xui;


// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the Display Page class for the XUI page.
 *
 * @author Julie Fournier
 */
public class XUIDP extends EditorDP
{
	/**
	 * Class Name for the Activity Space.
	 */
	private static final String STR_MVC_CLASS_NAME = "XUI";

	/**
	 * ID of the XUI page printed out by this DP.
	 */
	private int m_nXUIPageID;
	
	/**
	 * ID of the XUI service within the Editor (support for multiple XUI services)
	 */
	private int m_nXUIIndex;
	
	/**
	 * Registered model name (support for multiple XUI services that need different model names)
	 */
	private String m_strModelName;

	/**
	 * Default Constructor.
	 *
	 * @param _nXUIPageID ID of the XUI page printed out by this DP.
	 */
	public XUIDP(int _nXUIPageID)
	{
		m_nXUIIndex = 0;
		m_nXUIPageID = _nXUIPageID;
		m_strModelName = XUIHelperModel.STR_MVC_CLASS_NAME;
	}
	
	/**
	 * This constructor should be used to when multiple XUI
	 * services can exist within a single editor.
	 * The pagename will be in the format of 'XUI{XUIIndex}_{PageID}'.
	 * @param _nXUIIndex
	 * @param _nXUIPageID
	 */
	public XUIDP(int _nXUIIndex, int _nXUIPageID)
	{
		m_nXUIIndex = _nXUIIndex;
		m_nXUIPageID = _nXUIPageID;
		m_strModelName = XUIHelperModel.STR_MVC_CLASS_NAME + m_nXUIIndex;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		String sPageTitle;
		// Don't need to worry about XUI service index here, since the model is
		// for a given service.
		sPageTitle = ((IXUIHelperModelRO) m_asOwner.GetModel(m_strModelName)).GetPageTitle(m_nXUIPageID);

		return (sPageTitle);
	}

	/**
	 * Get the page ID
	 * @return
	 */
	public int GetPageID()
	{
		return m_nXUIPageID;
	}

	/**
	 * Returns the registered page name.
	 * If it's the 0th XUI service, the name is 'XUI{PageID}'.
	 * If it's not the 0th service, the name is 'XUI{XUIIndex}_{PageID}'.
	 *
	 * @return String
	 */
	public String GetName()
	{
		if (m_nXUIIndex == 0)
		{
			return STR_MVC_CLASS_NAME + m_nXUIPageID;
		}
		else
		{
			return STR_MVC_CLASS_NAME + m_nXUIIndex + "_" + m_nXUIPageID;
		}
	}

	/**
	 * Returns the HTML for the XUI page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		//JF- Add the Section for this XUI page.
		// The view name only contains the XUIIndex.  The view dynamically
		// shows page data for a given XUI service.
		if (m_nXUIIndex == 0)
		{
			views.AddInnerHTMLElement(((XUIView) m_asOwner.GetView(
					XUIView.STR_MVC_CLASS_NAME)).Display(m_nXUIPageID));
		}
		else
		{
			views.AddInnerHTMLElement(((XUIView) m_asOwner.GetView(
					XUIView.STR_MVC_CLASS_NAME + m_nXUIIndex)).Display(m_nXUIPageID));
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}
}

