package com.plumtree.portalpages.admin.editors.xui;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the Section class for the XUI page.
 *
 * @author Julie Fournier
 */
public class XUIView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.editors.xui.XUIView");

	/**
	 * Class Name for the Activity Space.
	 */
	public static final String STR_MVC_CLASS_NAME = "XUI";

	/**
	 * Input name: hidden input for the XUI page ID */
	public static final String HTMLHIDDEN_XUI_PAGEID = "in_hi_XUIPageID";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new XUIView();
	}

	/**
	 * This method is not used here. Use Display(int _nXUIPageID) instead.
	 *
	 * @return null
	 */
	public HTMLElement Display()
	{
		// not used
		
			log.Error("XUIView::Display Do NOT use this method. Use Display(int _nXUIPageID) instead.");
		

		return null;
	}

	/**
	 * Returns the HTML for the page identified by the ID in argument.
	 *
	 * @param _nXUIPageID
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display(int _nXUIPageID)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableCell myCell;
		HTMLTableRow myRow;
		HTMLInput myInput;

		IXUIHelperModelRO myModel = (IXUIHelperModelRO) m_model;

		try
		{
			// JF- Section header
			result.AddInnerHTMLElement(super.GetHeaderView(myModel.GetPageTitle(
						_nXUIPageID)));

			result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());

			// JF- Table with instructions
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.AddInnerHTMLString(myModel.GetPageInstructions(_nXUIPageID));

			// JF- Content table
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// JF- Get the HTML from the remote server and print it out.
			myCell.AddInnerHTMLString(myModel.GetHTMLForXUIPage(_nXUIPageID));

			// JF- Add the page ID as a hidden input.
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_XUI_PAGEID, "");
			myInput.SetValue(XPConvert.ToString(_nXUIPageID));
			myCell.AddInnerHTMLElement(myInput);
		}
		catch (Exception e)
		{
			
				log.Error(e, "XUIView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(1198,
					"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

