package com.plumtree.portalpages.admin.httpmemorydebugging;

import com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;


/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the HTTPMemoryDebug AS.
 * 
 * @author Julie Fournier
 */
public class HTTPMemoryDebugAS extends PlumtreeAS
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "MemoryDebug";

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		// DCA - call super's to check for change in navigational scheme
		super.CheckBasicAccess(strPage, strControl, bSameSpace);
		// JF- Only Sys Admins can access this page
		return PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession) GetUserSession());
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new HTTPMemoryDebugAS();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the name of the repost control class.
	 * E.g.: PropRepostControl.GetName()
	 *
	 * @see com.plumtree.xpshared.form.IRepostAS#GetRepostControlName()
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		// This method is not really implemented, because this is a sample
		// form that will not be able to be submitted.
		return HTTPMemoryDebugRepostControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();

		// Model
		RegisterModel(HTTPMemoryDebugModel.STR_MVC_CLASS_NAME);

		IModel myModel = GetModel(HTTPMemoryDebugModel.STR_MVC_CLASS_NAME);

		// Display Page
		HTTPMemoryDebugDP myPage = new HTTPMemoryDebugDP();

		// set multipart encoding so that file uploads work correctly.
		myPage.SetMultiPartEncoding(true);
		
		myPage.SetAddMainForm(true);
		RegisterPage(myPage);
		
		VarPackContentDP myPopUpPage = new VarPackContentDP();
		RegisterPage(myPopUpPage);
		
		// View
		RegisterView(HTTPMemoryDebugView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(VarPackContentView.STR_MVC_CLASS_NAME, myModel);

		// Repost Controls
		RegisterControl(HTTPMemoryDebugRepostControl.STR_MVC_CLASS_NAME, myModel);
	}
}

