package com.plumtree.portalpages.admin.httpmemorydebugging;

import com.plumtree.openfoundation.io.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.varpacks.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.helper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This is the Model class for the HTTPMemoryDebug AS. 
 * It replements the reload Var Pack feature.
 * 
 * @author Julie Fournier
 */
public class HTTPMemoryDebugModel implements IRepostModel, IVarPackModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.httpmemorydebugging.HTTPMemoryDebugModel");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "HTTPMemoryDebug";
	
	/** Associated  Activity Space */
	private AActivitySpace m_asOwner;
	
	/** ID of the var pack to reload */
	private String m_sReloadVarPackID;
	
	/** ID of the var pack to view */
	private String m_sViewContentVarPackID;
	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.varpack.IVarPackModelRO#GetCurrentVarPackID()
	 */
	public String GetCurrentVarPackID()
	{
		return m_sViewContentVarPackID;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.varpack.IVarPackModelRO#GetAllowVarPackReload()
	 */
	public boolean GetAllowVarPackReload()
	{
		return true;
	}

	/**
	 * Method reloading the var pack.
	 * 
	 */
	public void ReloadVarPack()
	{
		if ((null != m_sReloadVarPackID) && !("").equals(m_sReloadVarPackID))	
		{
			// JF- Get the VarPack
			IVarPack myVarPack = m_asOwner.GetApplication().GetVarPackManager().GetVariablePackage(m_sReloadVarPackID);
			
			// JF- Make sure we can reload it
			if ((null != myVarPack) && myVarPack.CanReloadVarPackFromUI())
			{
				myVarPack.ReloadVarPack();
			}
			else
			{
				
					log.Error("HTTPMemoryDebugModel::ReloadVarPack Couldn't reload Var Pack with key: " + m_sReloadVarPackID);
				
			}
			
			// JF- We are done. We reset the VarPack ID.
			m_sReloadVarPackID = null;
		}
	}
	
	/**
	 * Method to clear the AS cache.
	 * 
	 */
	public void ClearCache()
	{
		ASCache myCache = (ASCache) m_asOwner.GetSubSession().GetAttribute(ASConstants.SANDBOXASCACHE);
		myCache.ClearCache();
	}
	
	/**
	 * Method to reload custom.
	 * 
	 */
	public void ReloadDynamicLoads(IXPRequest request)
	{
	    try
	    {	        
	        String strRemoteFile = request.GetRemoteFilePath();
	        
	        XPFile remoteFile = new XPFile(strRemoteFile);
	        String strFileName = remoteFile.GetName();
	        remoteFile = null;
	        
	        String strDynamicLoadsPath = AppWarmUp.GetSettingValueAsString(
	            AppWarmUp.KEY_PATH_PORTAL_DYNAMIC_LOADS);
	        
	        XPFile replaceFile = new XPFile(strDynamicLoadsPath + strFileName);
	        if (replaceFile.Exists())
	        {
	            replaceFile.Delete();
	        }
	        replaceFile = null;
	        
	        // we need to check this otherwise we lose our file!
	        
	        request.Save(strDynamicLoadsPath);
	    }
	    catch (Exception ex)
	    {
	        log.Error(ex, "Error saving file.");
	    }
		// Bug#44025
		// Commented out because refactoring broke the build.
//		AppWarmUp.LoadDynamicLoads();
	}
	
	/**
	 * Method to clear unused memory.
	 * 
	 */
	public void ClearMemory()
	{
		XPSystem.GarbageCollect();
	}
	
	/**
	 * Method to clear unused memory and caches.
	 * 
	 */
	public void ClearMemoryAndCaches()
	{
		// Clear the my pages cache
		try
		{
			((IPTSession) m_asOwner.GetUserSession()).GetMyPages().FlushMandatoryGadgetsCache();
			((IPTCommunityManager)((IPTSession) m_asOwner.GetUserSession()).GetCommunities()).FlushMandatoryTabsCache();
		}
		catch (Exception e)
		{
			// Do nothing if cache clearing fails.
		}

		// Clear all the other C++ caches (PTCache caches, etc.)
		try
		{
			((IPTSession) m_asOwner.GetUserSession()).GetCommunities().ClearData( -19760313 );  // Pass in secret cache clearing key
		}
		catch (Exception e)
		{
			// Do nothing if cache clearing fails
		}

		// Garbage collect AFTER having cleared the caches
		ClearMemory();
	}
	
	/**
	 * Method reloading the current viewed var pack.
	 * 
	 */
	public void ReloadCurrentViewedVarPack()
	{
		m_sReloadVarPackID = m_sViewContentVarPackID;
		ReloadVarPack();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new HTTPMemoryDebugModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#Finish()
	 */
	public void Finish()
	{
	
	}	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = (AActivitySpace) parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String, XPHashtable)
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		String[] data;
		
		if (_sPageName.equals(HTTPMemoryDebugDP.STR_MVC_CLASS_NAME))
		{
			data = (String[]) _htFormData.GetElement(HTTPMemoryDebugView.HTMLHIDDEN_RELOAD_VARPACK_ID);
	
			if ((null != data) && !(0 == data.length))
			{
				m_sReloadVarPackID = data[0];
			}
		}
		
		if (_sPageName.equals(VarPackContentDP.STR_MVC_CLASS_NAME))
		{
			data = (String[]) _htFormData.GetElement(ViewVarPackControl.HTMLHIDDEN_VIEW_VARPACK_ID);

			if ((null != data) && !(0 == data.length))
			{
				m_sViewContentVarPackID = data[0];
			}
		}
		
		return RepostControl.PAGE_STATUS_VALID;
	}
	
	public int ClearAdaptiveTagCache()
	{
		Object oMap = m_asOwner.GetApplication().GetCachingManager().GetEntry(TagState.CACHE_LIB+"."+TagState.CACHE_MAPENTRY_NAME);
		if ( oMap != null) {
			XPHashtable cacheMap = (XPHashtable)oMap;
			cacheMap.Clear();
		}
		return RepostControl.PAGE_STATUS_VALID;
	}
}

