package com.plumtree.portalpages.admin.migrationhistory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * Model for the migration history of a single PTObject.
 *
 * @author arvinds
 */
public class MigrationHistoryModel extends EditorModel
	implements IMigrationHistoryModel, IMigrationHistoryModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.migrationhistory.MigrationHistoryModel");

	
	public static final String STR_MVC_CLASS_NAME = "MigrationHistory";
	private XPArrayList m_arrList;
	private int m_nCurrentMigrationStatus;
	private boolean m_bApprovedForMigration;
	
	public MigrationHistoryModel()
	{
		super();
		m_arrList = new XPArrayList();
	}
	
	/**
	 * Modifies the object name on repost.
	 *
	 */
	public void ActionOnRepost()
	{
	}

	//////////////////////////////////////////////////
	//					EditorModel methods
	/////////////////////////////////////////////////    

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		String[] asClassID  = (String[]) _htFormData.GetElement(ObjEditorModel.EDITOR_QS_INT_CLASS_ID);
		String[] asObjectID = (String[]) _htFormData.GetElement(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID);

		if ((null == asClassID) || (null == asObjectID) ||
				(0 == asClassID.length) || (0 == asObjectID.length) ||
				(null == asClassID[0]) || (null == asObjectID[0]))
		{
			
				log.Error("could not find classID/objectID in query string.");
			

			return false;
		}

		int nObjectID = XPConvert.ToInteger(asObjectID[0]);
		int nClassID  = XPConvert.ToInteger(asClassID[0]);

		IPTMigrationManager ptMM = (IPTMigrationManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
				false);

		m_nCurrentMigrationStatus = ptMM.QueryMigrationStatus(nClassID,
				nObjectID);

		IPTQueryResult ptQRHistory = ptMM.QueryMigrationHistory(nClassID,
				nObjectID);

		int nCount = ptQRHistory.RowCount();

		for (int i = 0; i < nCount; i++)
		{
			String strMigrationComment		    = ptQRHistory.ItemAsString(i,
					PT_PROPIDS.PT_PROPID_MIGRATION_COMMENT);
			XPDateTime xpdtMigration		    = ptQRHistory.ItemAsXPDateTime(i,
					PT_PROPIDS.PT_PROPID_MIGRATION_DATE);
			String strMigrationSourcePortalUUID = ptQRHistory.ItemAsString(i,
					PT_PROPIDS.PT_PROPID_MIGRATION_SOURCEPORTALUUID);

			MigrationHistoryItem mhi = new MigrationHistoryItem(xpdtMigration,
					strMigrationComment, strMigrationSourcePortalUUID, m_asOwner);
			m_arrList.Add(mhi);
		}

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationHistoryModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCurrentMigrationStatus()
	{
		return m_nCurrentMigrationStatus;
	}

	/**
	 * 
	 *
	 * @param _nIndex 
	 *
	 * @return 
	 */
	public MigrationHistoryItem GetHistoryItem(int _nIndex)
	{
		return (MigrationHistoryItem) m_arrList.GetElement(_nIndex);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumHistoryItems()
	{
		return m_arrList.GetSize();
	}

	/**
	 * Retrieves the flag indicating whether or not we are being
	 * hosted by another activity space, or our own.
	 */
	public boolean IsStandalone()
	{
		return true;
	}

	/**
	 * Retrieves the flag indicating whether or not to display
	 * the approval checkbox (currently only for full sysadmins)
	 */
	public boolean ShouldDisplayApproval()
	{
		return PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession)m_asOwner.GetUserSession());
	}
	
	/**
	 * Sets the flag indicating this object has been approved for migration
	 */
	public void SetApprovedForMigration(boolean bApproved)
	{
		m_bApprovedForMigration = bApproved;
	}
	
	/**
	 * Retrieves the flag indicating whether the checkbox has
	 * been checked in this editor session.
	 */
	public boolean IsMigrationCheckboxChecked()
	{
		return m_bApprovedForMigration;
	}

	/**
	 * Helper method to Store the migration status on the object.
	 *
	 */	
	public void StoreMigrationStatus(int nClassID, int nObjectID)
	{
	}
			
	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		return EditorRepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
	}
}

