package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.objmgr.popups.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * @author Don Hayler
 *
 * This handles setting folders to delete in order to determine
 * whether or not to offer ABO delete as a choice.
 */
public class CheckDeleteControl implements IControl
{
	/** object name */
	public static final String STR_MVC_CLASS_NAME = "CheckDelete";

	/** Control argument names */
	public static final String DELETEFOLDERS = "DeleteFolders";

	
	public static final String OBJECTIDPAIRS = "ObjectIDPairs";

	/** internal data */
	private AActivitySpace m_asOwner;
	private IObjMgrDeleteRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		Redirect result = new Redirect();
		result.SetLinkGetCachedSpace(m_asOwner);

		boolean bFolders = false;
		String[] sValues = (String[]) arguments.GetElement(DELETEFOLDERS);

		if (sValues != null)
		{
			bFolders = XPConvert.ToBoolean(sValues[0]);
		}

		m_asModel.SetFoldersForDeleteCheck(bFolders);

		sValues = (String[]) arguments.GetElement(OBJECTIDPAIRS);

		if (sValues != null)
		{
			int[] nObjectIDPairs = GeneralHelpers.ConvertToInts(sValues[0]);
			m_asModel.SetObjectsForDeleteCheck(nObjectIDPairs);
		}

		result.SetDisplayPage(ObjMgrDeleteWarningsDP.STR_MVC_CLASS_NAME);

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CheckDeleteControl();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (IObjMgrDeleteRO) model;
		m_asOwner     = space;
	}
}

