package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author Don Hayler
 */
public interface IObjMgrModelRO extends IModelRO
{
	/**
	 * This method returns whether or not there are any job IDs to display.
	 *
	 * @return boolean true implies there are job ids to display.
	 */
	public boolean ABOJobsToDisplay();

	/**
	 * This method checks if any users or groups came from an auth source other
	 * than plumtree.  This assumes that any objects to check were set on the
	 * model earlier in the request (as they will be deleted between requests).
	 *
	 * @return true implies objects did come from an outside auth source
	 */
	public boolean CheckAuthSourceForDelete();

	/**
	 * This method checks whether or not the user is trying to delete any page templates.
	 *
	 * @return true implies page templates are being deleted
	 */
	public boolean CheckPageTemplatesForDelete();

	/**
	 * This method checks whether or not the user is trying to delete any folders.
	 *
	 * @return true implies folders are being deleted
	 */
	public boolean CheckFoldersForDelete();

	/**
	 * This method returns the job names for the supplied ABO job IDs.
	 *
	 * @param int[] the ABO job IDs to get the names for.
	 * @return String[] an array of job names for folder deletions.
	 */
	public String[] GetABOJobNames(int[] nABOJobIDs);

	/**
	 * This method returns the job IDs for the last ABO deletes, and then clears
	 * them.
	 *
	 * @return int[] an array of job IDs for folder deletions.
	 */
	public int[] GetABOJobIDs();

	/**
	 * This method returns the folder where the ABO jobs were created.
	 *
	 * @return String the folder name where the ABO jobs were created.
	 */
	public String GetABOJobFolderName();

	/**
	 * This method returns the community object ID associated with the folder.
	 *
	 * @param int the community folder ID to check.  -1 means check current folder
	 * 
	 * @return int the ID of the community object, -1 if error
	 */
	public int GetCommunityID(int nFolderID);

	/**
	 * This method returns the folder ID that we were previously at.
	 * This is used to return from places like the subportal manager.
	 * 
	 * @return int the previous folder ID.
	 */
	public int GetPreviousFolderID();

	/**
	 * This method is used to determine whether to display the 'expand all'
	 * button or the 'collapse all' button.
	 * 
	 * @return boolean true implies all object expanded button has
	 * been clicked.
	 */
	public boolean GetAreAllObjectsExpanded();

	/**
	 * This method returns whether or not the current folder is a community.
	 *
	 * @return boolean true implies is a community
	 */
	public boolean GetCurrentFolderIsCommunity();

	/**
	 * This method returns whether or not the current folder is a subportal.
	 *
	 * @return boolean true implies is a subportal
	 */
	public boolean GetCurrentFolderIsSubportal();

	/**
	 * This method returns an int array of the currently expanded object types.
	 *
	 * @return int[] the expanded object types.
	 */
	public int[] GetExpandedObjectTypesArray();

	/**
	 * This method returns the string of currently expanded object types
	 * suitable for using in an URL.
	 *
	 * @return String the expanded object types.
	 */
	public String GetExpandedObjectTypesString();

	/**
	 * This method returns the space ID of the folder select tree.
	 *
	 * @return String the space ID of the folder select tree
	 */
	public String GetFolderTreeID();

	/**
	 * This method checks whether or not the current page has any objects that
	 * will be displayed for the requested classID.
	 *
	 * @param int nClassID the class ID to check for
	 */
	public boolean GetHasDisplayedObjects(int nClassID);

	/**
	 * This method returns a 2d query result with folder level, id, and name.
	 * 
	 * @return IASQueryResult
	 */
	public IASQueryResult GetBreadCrumbPath();
	
	/**
	 * @see com.plumtree.portalpages.admin.objmgr.ObjMgrModel#HasAccessToCreateMenu() 
	 */
	public boolean HasAccessToCreateMenu();
}
