package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This implements the admin directory for sub-folders
 */
public class ObjMgrDP extends PlumtreeDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objmgr.ObjMgrDP");

	/** MVC component name */
	public static final String STR_MVC_CLASS_NAME = "ObjMgr";

	/** prefix for object type div */
	public static final String OBJECT_ID_PREFIX = "Object";

	/** Javascript function name for the onload function */
	public static final String JAVASCRIPT_ONLOAD = "adminOnload";

	/** Javascript function name for the onload function */
	public static final int MAX_TYPES = 5;

	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		return "";
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		return m_asOwner.GetString(1219, "ptmsgs_portaladminmsgs");
	}

	/**
	 * helper display method for PlumtreeDP
	 *
	 * Fill in the body argument with HTML to display in the page.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		ObjectView objectView = (ObjectView) m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME);
		objectView.SetObjectViewHelper(new ObjMgrViewHelper());

		ObjMgrModel asModel = (ObjMgrModel) m_asOwner.GetModel(ObjMgrModel.STR_MVC_CLASS_NAME);

		try
		{
			result.AddInnerHTMLElement(m_asOwner.GetView(
					ObjMgrSearchView.STR_MVC_CLASS_NAME).Display());
			result.AddInnerHTMLElement(m_asOwner.GetView(
					ObjMgrBreadCrumbView.STR_MVC_CLASS_NAME).Display());
			result.AddInnerHTMLElement(m_asOwner.GetView(
					ObjMgrHeaderView.STR_MVC_CLASS_NAME).Display());
			result.AddInnerHTMLElement(m_asOwner.GetView(
					FolderView.STR_MVC_CLASS_NAME).Display());

			// Indent the object section by 15 pixels
			HTMLTable objectTable = new HTMLTable();
			result.AddInnerHTMLElement(objectTable);
			objectTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			objectTable.SetBorder(CommonHTMLStrings.ZERO);
			objectTable.SetCellPadding(CommonHTMLStrings.ZERO);
			objectTable.SetCellSpacing("15");

			HTMLTableRow objectRow = new HTMLTableRow();
			objectTable.AddInnerHTMLElement(objectRow);

			HTMLTableCell objectCell = new HTMLTableCell();
			objectRow.AddInnerHTMLElement(objectCell);
			objectCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			objectCell.SetVAlign(CommonHTMLStrings.TOP);

			// Sort the objects first then display them (see bug 27380)
			DisplayObjects(asModel, objectView, objectCell);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Unable to build HTML for admin directory. ");
			
		}

		return result;
	}

	/**
	 * This is a helper method that all classes that inherit from AFormDP can override
	 * if they like.  The method provides a hook into the head so that DP's can add javascript.
	 * Simply override and return and HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();

		//		scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjMgrSearchView.STR_MVC_CLASS_NAME).DisplayJavascript());
		scripts.AddInnerHTMLElement(m_asOwner.GetView(
				ObjMgrHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());
		scripts.AddInnerHTMLElement(m_asOwner.GetView(
				ObjectView.STR_MVC_CLASS_NAME).DisplayJavascript());

		int nCurrentlyOpeningObjectType = -1;
		ObjMgrModel asModel = (ObjMgrModel) m_asOwner.GetModel(ObjMgrModel.STR_MVC_CLASS_NAME);
		if (asModel != null)
		{
			nCurrentlyOpeningObjectType = asModel.GetCurrentlyOpeningObjectType();
		}

		// We don't want to scroll if nothing has been opened.
		if (nCurrentlyOpeningObjectType != -1)
		{
			String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
			
			XPStringBuilder sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JAVASCRIPT_ONLOAD).Append("() {\n");
				sb.Append(strJSUtilVersionPrefix+"PTCommonUtil.scrollDivIntoView(document.getElementById('")
				.Append(OBJECT_ID_PREFIX).Append(nCurrentlyOpeningObjectType).Append("'), document.body);\n");
	
			sb.Append("}\n");
	
			sb.Append("window.onload = ").Append(JAVASCRIPT_ONLOAD).Append(";\n");

			HTMLScript onloadScript = new HTMLScript("text/javaScript");
	
			try
			{
				onloadScript.AddInnerHTMLString(sb.ToString());
				scripts.AddInnerHTMLElement(onloadScript);
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "DisplayJavascriptFromChild couldn't add javascript for the scroll function to the HTMLScript element.");
				
			}
		}

		return scripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#InsertJavascriptBeforeFormSubmit()
	 * 
	 * Helper method to insert custom javascript in the form submit
	 * method right before the form is submitted.
	 */
	public void InsertJavascriptBeforeFormSubmit(XPStringBuilder sb)
	{
		// This code automatically checks if there are a large number of selected items
		// and converts the submit to a post if there are.  Otherwise, the GET string
		// can be too long and cause an error.

		// If there are too many expanded object types or displayed users, we set the
		// form submission mode to POST already, so this check is unneccesary.
		if (!GetRepostTypeIsPost())
		{
			// If there are too many selected objects, the checkboxes
			// will make the GET string too long.  We have to check for this at
			// runtime.		
			sb.Append("    if (").Append(ObjMgrHeaderView.JAVASCRIPT_GET_NUM_OBJECTS_SELECTED)
			.Append("() > ").Append(ObjMgrHeaderView.MAX_SELECTED_ITEMS).Append(") {\n");
			sb.Append("      document.").Append(HTMLFORM_NAME).Append(".method='POST';\n");
			sb.Append("    }\n");
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetRepostTypeIsPost()
	 */
	protected boolean GetRepostTypeIsPost()
	{
		ObjMgrModel model = (ObjMgrModel) m_asOwner.GetModel(ObjMgrModel.STR_MVC_CLASS_NAME);

		if ((null != model) && (model.GetExpandedObjectTypesArray().length > MAX_TYPES))
		{
			// If there are too many expanded object types, the pagination inputs
			// will make the GET string too long.
			// Use POST submission
			return true;
		}

		if ((null != model) &&
			(model.GetRoughDisplayedObjectCount(PT_CLASSIDS.PT_USER_ID) > ObjMgrModel.MAX_DISPLAYED_USERS))
		{
			// If there are too many displayed users, the user hidden inputs
			// will make the GET string too long.
			// Use POST submission
			return true;
		}	

		// Use GET submission
		return false;
	}
	

	/**
	 * Sort the objects in _asModel alphabetically by banner title then display them
	 * in the given HTMLTableCell _objectCell. See bug 27380.
	 * 
	 * @param _asModel ObjMgrModel containing some objects (groups, users, invitations etc)
	 * @param _objectView ObjectView
	 * @param _objectCell HTMLTableCell to display objects in.
	 */
	private void DisplayObjects(ObjMgrModel _asModel, 
	        ObjectView _objectView, 
	        HTMLTableCell _objectCell)
	{
		XPHashtable myHashtable = new XPHashtable();
		// iterate over gropus in _asModel and put them in a hastable whose keys
		// are the banner title ans whose values are the objectIDs and HTML contents
		while (_asModel.MoveNext())
		{
		    String objID = XPConvert.ToString(OBJECT_ID_PREFIX + _asModel.GetObjectType());
		    String key = _asModel.GetObjectBannerTitle();
		    Object[] value = new Object[2];
		    value[0] = objID;
		    value[1] = _objectView.Display();
		    myHashtable.PutElement(key, value);
		}
		if (!myHashtable.IsEmpty())
		{
			// Create an array of Strings made up of object banner titles
		    IXPEnumerator myEnum = myHashtable.GetKeys();
			String[] keyArray = new String[myHashtable.GetSize()];
			int i = 0;
			while (myEnum.MoveNext())
			{
			    keyArray[i] = (String)myEnum.GetCurrent();
			    i++;
			}
			// sort the banner titles
			XPArray.Sort(keyArray);
			// display each object in the sorted order.
			for (i = 0; i < keyArray.length; i++)
			{
			    String key = keyArray[i];
			    Object[] value 	 = (Object[])myHashtable.GetElement(key);
			    String objID 	 = (String)value[0];
			    HTMLElement html = (HTMLElement)value[1];
			    HTMLDiv myDiv = new HTMLDiv();
			    myDiv.SetID(objID);
				_objectCell.AddInnerHTMLElement(myDiv);
				_objectCell.AddInnerHTMLElement(html);			    
			}
		}
	}
}

