package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This class displays the folders for the object manager.
 */
public class ObjMgrFolderViewHelper implements IFolderViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objmgr.ObjMgrFolderViewHelper");

	/** Form input name for the checkbox */
	public static final String QS_CHECKBOX = "in_cb_Folder";

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayFolder(int, HTMLTableCell, IFolderModelRO, AActivitySpace)
	 */
	public int DisplayFolder(int nFolderIndex, HTMLTableCell tableCell,
		IFolderModelRO model, AActivitySpace asOwner)
	{
		try
		{
			// get the folder query
			IASQueryResult qrFolders = model.GetFolderQueryResult();
			int nTotalFolderCount    = qrFolders.GetCount();

			// get name, folder ID, and folder URL from query
			String strName = (String) qrFolders.GetFields(nFolderIndex,
					PT_PROPIDS.PT_PROPID_NAME);
			strName = GeneralHelpers.TruncateLongString(strName,
				ObjMgrAS.MAX_DISPLAYED_NAME_LENGTH, false);

			int nFolderID = XPConvert.ToInteger(qrFolders.GetFields(nFolderIndex,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String strFolderID = XPConvert.ToString(nFolderID);

			int nFolderType = XPConvert.ToInteger(qrFolders.GetFields(nFolderIndex,
					PT_PROPIDS.PT_PROPID_FOLDER_FOLDERTYPE));

			HTMLAnchor topAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			topAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER + "(" +
				strFolderID + "); return false;");
			topAnchor.AddInnerHTMLEncodedString(strName);

			if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER)
			{
				topAnchor.SetTitle(asOwner.GetString(1221, "ptmsgs_portaladminmsgs"));
			}
			else if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_REGULARFOLDER)
			{
				topAnchor.SetTitle(asOwner.GetString(1220, "ptmsgs_portaladminmsgs"));
			}
			else
			{
				// Everything else is a sub-portal.  The type will be the ID of the sub-portal object,
				// therefore we can't just check against PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_DEFAULTSUBPORTALFOLDER.
				topAnchor.SetTitle(asOwner.GetString(1222, "ptmsgs_portaladminmsgs"));
			}

			// use list item construct
			UIListItem itemConstruct = new UIListItem(topAnchor, asOwner);

			if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER)
			{
				itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_COMMUNITY,
					asOwner.GetString(1397, "ptmsgs_portaladminmsgs"));
			}
			else if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_REGULARFOLDER)
			{
				itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER,
					asOwner.GetString(76, "ptmsgs_portaladminmsgs"));
			}
			else
			{
				// Everything else is a sub-portal.  The type will be the ID of the sub-portal object,
				// therefore we can't just check against PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_DEFAULTSUBPORTALFOLDER.
				itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_SUBPORTAL,
					asOwner.GetString(1891, "ptmsgs_portaladminmsgs"));
			}

			itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			itemConstruct.SetCellHeight("20");

			// check if there's a checkbox item
			if (model.GetShowCheckbox())
			{
				itemConstruct.EnableCheckbox
				(QS_CHECKBOX, strFolderID,
					asOwner.GetString(1223, "ptmsgs_portaladminmsgs"),
					model.GetIsFolderSelected(nFolderID));
				
				if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER)
				{
					itemConstruct.GetSelectionInput().SetOnClick(ObjMgrHeaderView.JAVASCRIPT_COMMUNITY_SELECTED 
						+ "(this, 1); return true;");
				}
			}

			nFolderIndex++;

			// folder level in hierarchy
			int nTopFolderLevel = model.GetCurrentFolderLevel();

			int nStartIndexRef  = nFolderIndex;
			int nNumSubSubFoldersToDisplay = model.GetNumSubSubFoldersToDisplay();
			HTMLAnchor myAnchor;

			// Set the max number of links displayed greater than what we need, because
			// we will handle the '...'s.  (+ 1 for the ellipses)
			itemConstruct.SetMaxNumSubLinksDisplayed(nNumSubSubFoldersToDisplay + 1);

			// While we still have more results in the query and
			// we are down one level.
			while ((nFolderIndex < nTotalFolderCount) &&
					((nTopFolderLevel + 2) == XPConvert.ToInteger(qrFolders.GetFields(
						nFolderIndex, PT_PROPIDS.PT_PROPID_FOLDER_LEVEL))))
			{
				// if there are too many subsubfolders to display, skip over them
				if (nFolderIndex < (nStartIndexRef +
						nNumSubSubFoldersToDisplay))
				{
					// get sub-subfolder ids
					strFolderID     = XPConvert.ToString(qrFolders.GetFields(
								nFolderIndex, PT_PROPIDS.PT_PROPID_OBJECTID));

					// folder name
					strName     = (String) qrFolders.GetFields(nFolderIndex,
							PT_PROPIDS.PT_PROPID_NAME);
					strName = GeneralHelpers.TruncateLongString(strName,
						ObjMgrAS.MAX_DISPLAYED_NAME_LENGTH, false);

					//construct sub-subfolder URL
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER +
						"(" + strFolderID + "); return false;");
					myAnchor.AddInnerHTMLEncodedString(strName);

					itemConstruct.AddSubLink(myAnchor, false, false);
				}
				else if (nFolderIndex == (nStartIndexRef + nNumSubSubFoldersToDisplay))
				{
					// Only do this once.

					// add ... to the end of the list
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(topAnchor.GetOnClick());

					// Add ellipses
					myAnchor.AddInnerHTMLString(asOwner.GetString(2353, "ptmsgs_portaladminmsgs"));
					itemConstruct.AddSubLink(myAnchor, false, false);
				}

				//increment to the next folder
				nFolderIndex++;
			}

			// convert the construct to table and display the main item
			try
			{
				HTMLTable folderTable = itemConstruct.GetItemAsTable();
				tableCell.AddInnerHTMLElement(folderTable);
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "Couldn't add folder to HTML.");
				
			}
		}
		catch (Exception e)
		{
			
				log.Error("Couldn't retrieve folder at " + nFolderIndex);
			
		}

		return nFolderIndex;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID, IFolderModelRO _model, AActivitySpace _space)
	{
		_anchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
		_anchor.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_OPEN_FOLDER + "(" +
			_nFolderID + "); return false;");
	}

}

