package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.createfolder.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * @author Don Hayler
 *
 * This control handles the Obj Mgr specific repost work.
 */
public class ObjMgrRepostControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objmgr.ObjMgrRepostControl");

	/** Name of this control */
	public static final String STR_MVC_CLASS_NAME = "ObjMgrRepost";

	/** Mandatory Form inputs */
	public static final String HTML_INPUT_FOLDER_ID  = "in_hi_FolderID";
	public static final String HTML_INPUT_OBJECT_IDS = "in_hi_ObjectIDs";

	/** Optional Form inputs */
	/** Expand object types inputs */
	public static final String HTML_INPUT_EXPAND_OBJECT_ID = "in_hi_ExpandObjectIDs"; // an int
	public static final String HTML_INPUT_EXPAND_BOOLEAN = "in_hi_Expand"; // boolean true = expand, false = collapse

	/** Repost Actions */
	public final static int POSTTOSELF_ACTION_CREATE_FOLDER 		= 50;
	public final static int POSTTOSELF_ACTION_MOVE		    	= 51;
	public final static int POSTTOSELF_ACTION_COPY		    	= 52;
	public final static int POSTTOSELF_ACTION_EDIT		    	= 53;
	public final static int POSTTOSELF_ACTION_DELETE	    		= 54;
	public final static int POSTTOSELF_ACTION_DELETE_LATER  		= 55;
	public final static int POSTTOSELF_ACTION_RUN_ONCE	    	= 56;
	public final static int POSTTOSELF_ACTION_MIGRATE	    	= 57;
	public final static int POSTTOSELF_ACTION_ENABLE	    		= 58;
	public final static int POSTTOSELF_ACTION_EXPAND_OBJECT_TYPE  = 59;
	public final static int POSTTOSELF_ACTION_EXPAND_ALL_OBJECTS  = 60;
	public final static int POSTTOSELF_ACTION_COLLAPSE_ALL_OBJECTS = 61;

	/** ObjMgr Model */
	ObjMgrModel m_asObjMgrModel;

	/**
	 * This ovverrides the implementation from RepostControl for certain actions
	 * @return Redirect
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String sDataKey;
		String[] aDataValue;

		// Needed for Create Folder
		sDataKey	   = CreateFolderDP.QS_PARENT_FOLDER;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Info("CREATE FOLDER PARENT");

			int nFolderID = XPConvert.ToInteger(aDataValue[0]);
			m_asObjMgrModel.SetObjMgrSettings(nFolderID, new int[0]);

			return null;
		}

		return super.CheckActionSecurityAndExecute(arguments);
	}


	/**
	 * This method gets the selected folders from the form data
	 *
	 * @return int[] an array of Folder IDs
	 */
	public static int[] GetSelectedFolders(XPHashtable htFormData)
	{
		String[] sDataValue = (String[]) htFormData.GetElement(ObjMgrFolderViewHelper.QS_CHECKBOX);

		if (sDataValue != null)
		{
			int[] result     = new int[sDataValue.length];
			int nErrorsFound = 0;

			for (int i = 0; i < sDataValue.length; i++)
			{
				try
				{
					result[i] = XPConvert.ToInteger(sDataValue[i]);
				}
				catch (Exception e)
				{
					
						log.Error("Unable to convert selected folder to int: " +
							sDataValue[i]);
					

					result[i] = -1;
					nErrorsFound++;
				}
			}

			// Resize array if there were errors
			if (nErrorsFound > 0)
			{
				int[] temp = new int[sDataValue.length - nErrorsFound];
				int nIndex = 0;

				for (int i = 0; i < result.length; i++)
				{
					if ((result[i] != -1) && (nIndex < temp.length))
					{
						temp[nIndex] = result[i];
						nIndex++;
					}
				}

				result = temp;
			}

			return result;
		}

		return new int[0];
	}

	/**
	 * This method gets the selected objects (not folders) from the form data
	 *
	 * @return Object[][] a (2 x n) array of class ID / Object ID pairs
	 */
	public static Object[][] GetSelectedObjects(IObjMgrModelRO asObjMgrModel,
		XPHashtable htFormData)
	{
		int[] nExpandedObjectTypes = asObjMgrModel.GetExpandedObjectTypesArray();

		String[] sDataKeys  = new String[nExpandedObjectTypes.length];
		String[] sDataValue;
		Object nError	    = new Integer(-1);
		Object[][] result;

		// Calculate the size of the array needed
		int nSize = 0;

		for (int i = 0; i < nExpandedObjectTypes.length; i++)
		{
			sDataKeys[i]     = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX +
				nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
			sDataValue		 = (String[]) htFormData.GetElement(sDataKeys[i]);

			if (sDataValue != null)
			{
				nSize += sDataValue.length;
			}
		}

		result = new Object[2][nSize];

		if (nSize > 0)
		{
			// populate the array
			int nIndex		 = 0;
			int nErrorsFound = 0;

			for (int i = 0; i < nExpandedObjectTypes.length; i++)
			{
				sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);

				if (sDataValue != null)
				{
					for (int j = 0; j < sDataValue.length; j++)
					{
						if (nIndex < nSize)
						{
							try
							{
								result[0][nIndex]     = new Integer(nExpandedObjectTypes[i]);
								result[1][nIndex]     = new Integer(XPConvert.ToInteger(sDataValue[j]));
							}
							catch (Exception e)
							{
								
									log.Error("Unable to convert selected object to int: " +
										sDataValue[j]);
								

								result[0][nIndex]     = nError;
								result[1][nIndex]     = nError;
								nErrorsFound++;
							}

							nIndex++;
						}
					}
				}
			}

			// Resize array if there were errors
			if (nErrorsFound > 0)
			{
				Object[][] temp = new Object[2][nSize - nErrorsFound];
				nIndex = 0;

				for (int i = 0; i < result.length; i++)
				{
					if ((!result[0][i].equals(nError)) &&
							(nIndex < temp.length))
					{
						temp[0][nIndex]     = result[0][i];
						temp[1][nIndex]     = result[1][i];
						nIndex++;
					}
				}

				result = temp;
			}
		}

		return result;
	}

	/**
	 * This method gets the selected objects (not folders) from the form data
	 *
	 * @return XPHashtable of Integer class IDs to int[] of Object IDs
	 */
	public static XPHashtable GetSelectedObjectsMap(IObjMgrModelRO asObjMgrModel,
		XPHashtable htFormData)
	{
		XPHashtable result = new XPHashtable();

		int[] nExpandedObjectTypes = asObjMgrModel.GetExpandedObjectTypesArray();

		String[] sDataKeys  = new String[nExpandedObjectTypes.length];
		String[] sDataValue;

		int[] temp;
		int nErrorsFound;

		for (int i = 0; i < nExpandedObjectTypes.length; i++)
		{
			sDataKeys[i]     = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX +
				nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
			sDataValue		 = (String[]) htFormData.GetElement(sDataKeys[i]);

			if ((sDataValue != null) && (sDataValue.length > 0))
			{
				temp			 = new int[sDataValue.length];
				nErrorsFound     = 0;

				for (int j = 0; j < sDataValue.length; j++)
				{
					try
					{
						temp[j] = XPConvert.ToInteger(sDataValue[j]);
					}
					catch (Exception e)
					{
						
							log.Error("Unable to convert selected object to int: " +
								sDataValue[j]);
						

						temp[j] = -1;
						nErrorsFound++;
					}
				}

				if (nErrorsFound > 0)
				{
					int[] resize     = new int[temp.length - nErrorsFound];
					int nResizeIndex = 0;

					for (int k = 0; k < temp.length; k++)
					{
						if ((temp[k] != -1) && (nResizeIndex < temp.length))
						{
							resize[nResizeIndex] = temp[i];
							nResizeIndex++;
						}
					}

					temp = resize;
				}

				result.PutElement(new Integer(nExpandedObjectTypes[i]), temp);
			}
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjMgrRepostControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the class with the associated model and activity space.
	 *
	 * @param model
	 * @param space
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		super.Init(model, space);

		try
		{
			m_asObjMgrModel = (ObjMgrModel) model;
		}
		catch (Exception e)
		{
			
				log.Error(e, "Init Unable to cast the Object " + model +
					" to ObjMgrModel. The following exception occured.");
			

			// JF- No need to extract, this is an unexpected error.
			throw new XPException("Unable to cast the Object " + model +
				" to ObjMgrModel.", e);
		}

		m_asOwner = space;
	}

	/**
	 * Given the repost action mode, calls the associated method in the model.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		int nTargetFolderID;
		String[] sValues;
		String sComment;
		boolean bRequires302Redirect = false;
		boolean bClearFormDataAfterAction = false;


		switch (_nAction)
		{
		case POSTTOSELF_ACTION_EXPAND_OBJECT_TYPE:
			ExpandObject();

			break;

		case POSTTOSELF_ACTION_EXPAND_ALL_OBJECTS:
			m_asObjMgrModel.ExpandAllObjects(true);

			break;

		case POSTTOSELF_ACTION_COLLAPSE_ALL_OBJECTS:
			m_asObjMgrModel.ExpandAllObjects(false);

			break;

		case POSTTOSELF_ACTION_EDIT:

			int[] nFolders = ObjMgrRepostControl.GetSelectedFolders(m_htFormData);

			if (nFolders.length > 0)
			{
				// Get the first non-community folder
				int nFirstIndex = m_asObjMgrModel.GetFirstFolderIndex(nFolders);
				if (nFirstIndex >= 0)
				{
					// set redirect to folder editor
					Redirect myRedirect = new Redirect();
					myRedirect.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME,
						m_asOwner);
					myRedirect.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
					myRedirect.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID,
						PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
					myRedirect.AddControlArgument(IPTOpenerConstants.STR_QS_OBJECTID,
						nFolders[nFirstIndex]);

					SetRedirect(myRedirect);
				}
			}

			bClearFormDataAfterAction = true;

			break;

		case POSTTOSELF_ACTION_MOVE:
			nTargetFolderID = m_asObjMgrModel.GetFolderIDFromTree();

			if (nTargetFolderID != -1)
			{
				m_asObjMgrModel.MoveFolders(nTargetFolderID,
					ObjMgrRepostControl.GetSelectedFolders(m_htFormData));
				m_asObjMgrModel.MoveObjectsBetweenFolders(nTargetFolderID,
					ObjMgrRepostControl.GetSelectedObjects(m_asObjMgrModel,
					m_htFormData));

				bRequires302Redirect = true;
				bClearFormDataAfterAction = true;
			}

			break;

		case POSTTOSELF_ACTION_COPY:
			nTargetFolderID = m_asObjMgrModel.GetFolderIDFromTree();

			if (nTargetFolderID != -1)
			{
				m_asObjMgrModel.CopyFolders(nTargetFolderID,
					ObjMgrRepostControl.GetSelectedFolders(m_htFormData));
				m_asObjMgrModel.CopyObjectsBetweenFolders(nTargetFolderID,
					ObjMgrRepostControl.GetSelectedObjectsMap(m_asObjMgrModel,
						m_htFormData));

				bRequires302Redirect = true;
				bClearFormDataAfterAction = true;
			}

			break;

		case POSTTOSELF_ACTION_DELETE:
			m_asObjMgrModel.DeleteFolders(ObjMgrRepostControl.GetSelectedFolders(
					m_htFormData));
			m_asObjMgrModel.DeleteObjects(ObjMgrRepostControl.GetSelectedObjectsMap(
					m_asObjMgrModel, m_htFormData), false);

			bRequires302Redirect = true;
			bClearFormDataAfterAction = true;

			break;

		case POSTTOSELF_ACTION_DELETE_LATER:
			XPHashtable xpmSelectedObjects = ObjMgrRepostControl.GetSelectedObjectsMap(
				m_asObjMgrModel, m_htFormData);

			// Do ABO Deletes
			m_asObjMgrModel.ABODeleteFolders(ObjMgrRepostControl.GetSelectedFolders(
					m_htFormData));
			m_asObjMgrModel.ABODeletePageTemplates(xpmSelectedObjects);

			// Do normal deletes (true means skip page templates)
			m_asObjMgrModel.DeleteObjects(xpmSelectedObjects, true);

			bRequires302Redirect = true;
			bClearFormDataAfterAction = true;

			break;

		case POSTTOSELF_ACTION_MIGRATE:
			sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);

			if (sValues != null)
			{
				sComment = sValues[0];
			}
			else
			{
				sComment = "";
			}

			m_asObjMgrModel.MigrateFolders(ObjMgrRepostControl.GetSelectedFolders(
					m_htFormData), sComment);
			m_asObjMgrModel.MigrateObjects(ObjMgrRepostControl.GetSelectedObjectsMap(
					m_asObjMgrModel, m_htFormData), sComment);

			bRequires302Redirect = true;
			bClearFormDataAfterAction = true;

			break;

		case POSTTOSELF_ACTION_ENABLE:
			sComment = "";

			boolean bEnable;
			sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_ENABLE);

			if (sValues != null)
			{
				if (!(sValues[0].equals("null")))
				{
					try
					{
						bEnable = XPConvert.ToBoolean(sValues[0]);
					}
					catch (Exception e)
					{
						
							log.Error("Unable to parse boolean enable/disable value: " +
								sValues[0]);
						

						break;
					}
				}
				else
				{
					break;
				}
			}
			else
			{
				
					log.Error("Unable to locate boolean enable/disable value.");
				

				break;
			}

			if (!bEnable)
			{
				sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);

				if (sValues != null)
				{
					sComment = sValues[0];
				}
			}

			m_asObjMgrModel.EnableObjects(ObjMgrRepostControl.GetSelectedObjectsMap(
					m_asObjMgrModel, m_htFormData), sComment, bEnable);

			bRequires302Redirect = true;
			bClearFormDataAfterAction = true;

			break;

		case POSTTOSELF_ACTION_RUN_ONCE:
			StaticPTObjectHelpers.RunJobsOnce((int[]) ObjMgrRepostControl.GetSelectedObjectsMap(
					m_asObjMgrModel, m_htFormData).GetElement(new Integer(
						PT_CLASSIDS.PT_JOB_ID)), m_asOwner);

			bRequires302Redirect = true;
			bClearFormDataAfterAction = true;

			break;

		case POSTTOSELF_ACTION_CREATE_FOLDER:

			String sName = null;
			sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERNAME);

			if (sValues == null)
			{
				
					log.Error("Could not get folder name.");
				
			}
			else
			{
				sName = sValues[0];
			}

			String sDesc = null;
			sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERDESCRIPTION);

			if (sValues == null)
			{
				
					log.Error("Could not get folder description.");
				
			}
			else
			{
				sDesc = sValues[0];
			}

			m_asObjMgrModel.CreateFolder(sName, sDesc);

			Redirect repostURL = new Redirect();
			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);
			break;

		default:
			super.PerformAction(_nAction);

			break;
		}

		if (bRequires302Redirect)
		{
			Redirect safeRedirect = new Redirect();
			safeRedirect.SetLinkGetCachedSpace(m_asOwner);
			safeRedirect.SetIsHTTPRedirect(true);
			safeRedirect.SetControl(ObjMgrSettingsControl.STR_MVC_CLASS_NAME);
			safeRedirect.AddControlArgument(ObjMgrSettingsControl.FOLDER_ID,
				m_asObjMgrModel.GetCurrentFolderID());
			safeRedirect.AddControlArgument(ObjMgrSettingsControl.OBJECT_IDS,
				m_asObjMgrModel.GetExpandedObjectTypesString());
			SetRedirect(safeRedirect);
		}

		if (bClearFormDataAfterAction)
		{
			m_asObjMgrModel.ClearAllSelectedObjects();
		}
	}

	/**
	 * Save Object Manager settings
	 */
	protected void SaveCurrentPage()
	{
		// Set basic settings
		String[] sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_FOLDER_ID);

		if (sValues == null)
		{
			
				log.Info("could not find folder ID in form data.");
			

			super.SaveCurrentPage();
			return;
		}

		int nFolderID = XPConvert.ToInteger(sValues[0]);

		int[] nExpandedObjectTypes;
		sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_OBJECT_IDS);

		if (sValues != null)
		{
			nExpandedObjectTypes = GeneralHelpers.ConvertToInts(sValues[0]);
		}
		else
		{
			nExpandedObjectTypes = new int[0];
		}

		m_asObjMgrModel.SetObjMgrSettings(nFolderID, nExpandedObjectTypes);

		// Set selected object IDs
		int[] nSelectedObjectIDs;

		for (int i = 0; i < nExpandedObjectTypes.length; i++)
		{
			sValues = (String[]) m_htFormData.GetElement(ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX +
					nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX);

			if ((sValues != null) && (sValues.length > 0))
			{
				nSelectedObjectIDs = new int[sValues.length];

				for (int j = 0; j < sValues.length; j++)
				{
					try
					{
						nSelectedObjectIDs[j] = XPConvert.ToInteger(sValues[j]);
					}
					catch (Exception e)
					{
						
							log.Error("Unable to convert selected item to int: " +
								sValues[i]);
						

						nSelectedObjectIDs[j] = -1;
					}
				}

				m_asObjMgrModel.SetSelectedObjects(
					nExpandedObjectTypes[i], nSelectedObjectIDs);
			}
		}

		super.SaveCurrentPage();
	}

	/////////////////
	// Helper methods
	/////////////////

	/**
	 * This method handles the expand object type action
	 */
	private void ExpandObject()
	{
		String[] sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_EXPAND_OBJECT_ID);

		if (sValues == null)
		{
			
				log.Error("could not find class ID to expand in form data.");
			

			return;
		}

		int nClassID = XPConvert.ToInteger(sValues[0]);

		sValues = (String[]) m_htFormData.GetElement(HTML_INPUT_EXPAND_BOOLEAN);

		if (sValues == null)
		{
			
				log.Error("could not find expand value in query string.");
			

			return;
		}

		boolean bExpand = XPConvert.ToBoolean(sValues[0]);

		m_asObjMgrModel.ExpandObjectType(nClassID, bExpand);
	}
}

