package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 * This implements the admin directory for the root folder.
 */
public class ObjMgrRootDP extends PlumtreeDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objmgr.ObjMgrRootDP");

	
	public static final String STR_MVC_CLASS_NAME = "ObjMgrRoot";

	
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		return "";
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		return m_asOwner.GetString(1266, "ptmsgs_portaladminmsgs");
	}

	/**
	 * helper display method for PlumtreeDP
	 *
	 * Fill in the body argument with HTML to display in the page.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			result.AddInnerHTMLElement(m_asOwner.GetView(
					ObjMgrSearchView.STR_MVC_CLASS_NAME).Display());

			result.AddInnerHTMLElement(new HTMLBr());

			result.AddInnerHTMLElement(m_asOwner.GetView(
					ObjMgrHeaderView.STR_MVC_CLASS_NAME).Display());
			result.AddInnerHTMLElement(m_asOwner.GetView(
					FolderView.STR_MVC_CLASS_NAME).Display());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Unable to build HTML for admin directory. ");
			
		}

		return result;
	}

	/**
	 * This is a helper method that all classes that inherit from AFormDP can override
	 * if they like.  The method provides a hook into the head so that DP's can add javascript.
	 * Simply override and return and HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();

		//		scripts.AddInnerHTMLElement(m_asOwner.GetView(ObjMgrSearchView.STR_MVC_CLASS_NAME).DisplayJavascript());
		scripts.AddInnerHTMLElement(m_asOwner.GetView(
				ObjMgrHeaderView.STR_MVC_CLASS_NAME).DisplayJavascript());

		return scripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetRepostTypeIsPost()
	 */
	protected boolean GetRepostTypeIsPost()
	{
		// GET submission
		return false;
	}
}

