package com.plumtree.portalpages.admin.objmgr;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * @author Don Hayler
 *
 * This method sets the basic variables for the object manager:
 * folder ID and the list of object types to expand
 */
public class ObjMgrSettingsControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objmgr.ObjMgrSettingsControl");

	/** Name of this control */
	public static final String STR_MVC_CLASS_NAME = "ObjMgrSettings";

	/** Query string parameters */
	public static final String FOLDER_ID  = "FolderID";

	
	public static final String OBJECT_IDS = "ObjectIDs";
	private ObjMgrModel m_asModel;

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#execute(XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String[] sValues = (String[]) arguments.GetElement(FOLDER_ID);

		if (sValues == null)
		{
			
				log.Error("could not find folder ID in query string.");
			

			return null;
		}

		int nFolderID;

		try
		{
			nFolderID = XPConvert.ToInteger(sValues[0]);
		}
		catch (Exception e)
		{
			
				log.Error(e, "Unable to parse folder ID: " + sValues[0]);
			

			return null;
		}

		int[] nExpandedObjectTypes;
		sValues = (String[]) arguments.GetElement(OBJECT_IDS);

		if (sValues != null)
		{
			nExpandedObjectTypes = GeneralHelpers.ConvertToInts(sValues[0]);
		}
		else
		{
			nExpandedObjectTypes = new int[0];
		}

		m_asModel.SetObjMgrSettings(nFolderID, nExpandedObjectTypes);

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjMgrSettingsControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel = (ObjMgrModel) model;
	}
}

