package com.plumtree.portalpages.admin.objmgr.popups;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Don Hayler
 *
 */
public class ObjMgrABOLinksView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objmgr.popups.ObjMgrABOLinksView");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "ObjMgrABOLinks";

	/** HTML Object names */
	public static final String HTMLBUTTON_CLOSE = "in_bu_Close";

	/** javascript function names */
	public static final String JAVASCRIPT_OPEN_JOB = "OpenJob";

	
	/** mvc objects */
	AActivitySpace m_asOwner;
	IObjMgrModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjMgrABOLinksView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = new HTMLElementCollection();
		HTMLSpan mySpan;
		HTMLTable myTable;
		HTMLInput myInput;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			// Links
			mySpan = new HTMLSpan();
			result.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

			// Message stating where the ABO jobs were created.
			mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage
				(m_asOwner.GetString(2557, ResourceConstants.PORTALADMINMSGS),
				m_asModel.GetABOJobFolderName()));

			int[] nJobIDs = m_asModel.GetABOJobIDs();
			String[] nJobNames = m_asModel.GetABOJobNames(nJobIDs);

			for (int i = 0; i < nJobIDs.length; i++)
			{
				if (nJobIDs[i] != -1)
				{
					mySpan.AddInnerHTMLElement(new HTMLBr());
	                mySpan.AddInnerHTMLElement(ConstructStaticHelpers.GetJavascriptAnchor
	                    (XPHttpUtility.HtmlEncode(nJobNames[i]),
	                    JAVASCRIPT_OPEN_JOB + "(" + nJobIDs[i] + ")"));
				}
			}

			// Add buttons
			result.AddInnerHTMLElement(new HTMLComment(
					"Begin: Footer buttons table"));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetBorder("0");
			myTable.SetWidth("100%");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("10");

			// 1st Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// Close button
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("window.close(); return false;");

			result.AddInnerHTMLElement(new HTMLComment(
					"End: Footer buttons table"));
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Unable to create warnings.");
			

			result = new HTMLGenericElement(m_asOwner.GetString(1209,
						"ptmsgs_portaladminmsgs"));
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		ASURL myURL = new ASURL(m_asOwner);
		myURL.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME, m_asOwner);
		myURL.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
		myURL.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID,
			PT_CLASSIDS.PT_JOB_ID);

		// This must be last so we can append the object ID
		myURL.AddControlArgument(IPTOpenerConstants.STR_QS_OBJECTID);

		// JavaScript to open the create folder popup
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb  = new XPStringBuilder(200);

		sb.Append("\n").Append("function ").Append(JAVASCRIPT_OPEN_JOB)
		.Append("(nID)\n").Append("{\n").Append("  window.open('")
		.Append(myURL.GetURLAsString()).Append("' + nID, '_jobpopup', '');\n")
		.Append("}\n");

		try
		{
			// Add script
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Unable to create javascript.");
			

			return null;
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_asModel     = (IObjMgrModelRO) model;
	}

	/** logger */
}

