package com.plumtree.portalpages.admin.objsearch;

import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * @author Matt Fryer
 *
 *	This is the "Search Again" view of the admin search searchbox. Advanced Search link goes in here
 *  when we get to that.
 */
public class AdminFollowupSearchView implements IView
{
	/** object name */
	public static final String STR_MVC_CLASS_NAME = "AdminFollowupSearchView";
	
	/** form name **/
	public static final String FORM_NAME = "searchform";

	public static final String SEPARATOR = "&nbsp;|&nbsp;&nbsp;&nbsp;";
	
	/** localized strings */
	protected AActivitySpace m_asOwner;

        protected ISearchResultModelRO _model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdminFollowupSearchView();
	}

	/**
	 * Returns an icon and link for advanced search. The link includes a control argument that will
	 * restrict the search to the admin hierarchy and another which will cause the results to be displayed
	 * with checkboxes and a toolbar.
	 * 
	 * @param m_asOwner
	 * @return
	 */
	public static HTMLElement GetAdvancedAdminSearchLink(AActivitySpace m_asOwner)
	{
		// Advanced Search Link
		ASURL url = new ASURL(m_asOwner);
		url.SetLinkCreateNewSpace(AdvancedSearchAS.STR_MVC_CLASS_NAME, m_asOwner);
		url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			com.plumtree.uiinfrastructure.editor.EditorStartControl.EDITOR_START_FLAG_MISC);
			
		//Setting this to 1 will cause the adv search page to come up with the top level
		// admin folder selected in the folder view.
		url.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
								SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S,1);
		
		// We want advanced search results to come up in admin mode.
		url.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, SearchPageModeHelper.ADMIN_MODE);

                // Start off with all admin types checked, but not collab or content.
                // Need to list all the searchable admin types here.. sort of a pain
                String objtypeKey = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
                  SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S;
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGETTEMPLATE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_USER_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_USERGROUP_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_AUTHSOURCE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_ADMIN_FOLDER_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_FILTER_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_SAVEDSEARCH_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_DATASOURCE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_DOCUMENTTYPE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_CRAWLER_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_INVITATION_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_FEDERATEDPORTAL_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGETCONTENTSERVER_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITYTEMPLATE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_GADGETBUNDLE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PAGETEMPLATE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_JOB_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PAGE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_SUBPORTAL_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_WEBSERVICE_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_EXTOPERATION_ID));
                url.AddControlArgument(objtypeKey, XPConvert.ToString(PT_CLASSIDS.PT_PROFILESOURCE_ID));

		HTMLImg icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED, 
															   true, m_asOwner).GetHTMLElement();
		icon.SetAlign("absmiddle");
		icon.SetBorder("0");
		url.AddInnerHTMLElement(icon);
		url.AddInnerHTMLString("   ");
		url.AddInnerHTMLString(m_asOwner.GetString(815, "ptmsgs_portalbrowsingmsgs"));		

		HTMLElementCollection coll = new HTMLElementCollection();
		coll.AddInnerHTMLString(SEPARATOR);
		coll.AddInnerHTMLElement(url.GetURLAsHTMLElement());
		return coll;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
          // If the last search failed..
          if (null != _model.GetError())
          {
            // Usually this is null. Sometimes it is an un-internationalized error message.
            return _model.GetError().GetComment();
          }

                int adminFolderID = 1;

                // Try to figure out what folder we are in
                int[] folderIDs = _model.GetAdminFolderRestrictions();
                if ((null != folderIDs) && (1 == folderIDs.length)) {
                        adminFolderID = folderIDs[0];
                }

		HTMLElement form = AdminSearchForm.GetObjectSearchForm(m_asOwner,
			
		// Give the form a unique name

		/* name= */ FORM_NAME, 
		// When form is submitted, results appear on page SampleResultsDP of the current space

		/* targetSpace= */ AdminSearchAS.STR_MVC_CLASS_NAME, // null, 
		/* targetSpaceID= */ m_asOwner.GetSpaceID(), //  null, 
		/* targetPage= */ AdminSearchDP.STR_MVC_CLASS_NAME, // null, 
		// Display a prompt

		/* prompt= */ m_asOwner.GetString(2538, "ptmsgs_portaladminmsgs"), 
		// Restrict to this folder

		/* currentAdminFolder= */ adminFolderID, 
		// No object type restriction; type is selectable from a pulldown

		/* objectClassIDs= */ null, 
		// Not needed if you've implemented your own view of search results

		/* makeEditLinks= */ true,
		/* return complete form= */ true,
		/* overrideEnclosingForm */ false,
		/* additionalElements */GetAdvancedAdminSearchLink(m_asOwner),
		/* validate alert */ true);
		


		return form;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		// by default, return nothing
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
                _model = (ISearchResultModelRO) model;
	}
}

