package com.plumtree.portalpages.admin.objsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.IPTSession;
import com.plumtree.uiinfrastructure.constants.AccessStyles;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author Matt Fryer
 *
 */
public class AdminSearchDP extends PlumtreeDP
{
	public static final String STR_MVC_CLASS_NAME = "AdminSearchResult";
	public static final String HTML_FORM_NAME = "mainform";
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		return "";
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		return m_asOwner.GetString(2550,"ptmsgs_portaladminmsgs");
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection group = new HTMLElementCollection();

		try
		{
			// Enclose all views in a single table cell.
			HTMLTable table = new HTMLTable();
			group.AddInnerHTMLElement(table);

			table.SetWidth("100%");
			table.SetCellSpacing("0");
			table.SetCellPadding("0");

			HTMLTableRow row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);

			HTMLTableCell cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);

			HTMLElement viewElement;
			
			// "Search again:"
			viewElement = m_asOwner.GetView(AdminFollowupSearchView.STR_MVC_CLASS_NAME).Display();
			
			if (null != viewElement)
			{
				cell.AddInnerHTMLElement(viewElement);
			}
								
			OrganizationView orgView = (OrganizationView) m_asOwner.GetView(OrganizationView.STR_MVC_CLASS_NAME);

			HTMLForm orgForm = new HTMLForm(OrganizationView.REORGANIZATION_FORM_NAME);
	  		orgForm.SetMethod("get");
	  		orgForm.SetName(OrganizationView.REORGANIZATION_FORM_NAME);

	  		orgView.addTargetsToOrganizationForm(orgForm);

			cell.AddInnerHTMLElement(orgForm);

			// "Search Results"
			viewElement = m_asOwner.GetView(SearchBannerView.STR_MVC_CLASS_NAME).Display();

			if (null != viewElement)
			{
				orgForm.AddInnerHTMLElement(viewElement);
			}

			// "Organize by:"
			viewElement = m_asOwner.GetView(OrganizationView.STR_MVC_CLASS_NAME)
				.Display();

			if (null != viewElement)
			{
				orgForm.AddInnerHTMLElement(viewElement);
				orgForm.AddInnerHTMLElement(makeSpacer("1"));
			}

			// "42 results searching for 'kumquat'"
			viewElement = m_asOwner.GetView(SearchSummaryView.STR_MVC_CLASS_NAME)
				.Display();

			if (null != viewElement)
			{
				orgForm.AddInnerHTMLElement(viewElement);
			}

			HTMLElement resultElement = m_asOwner.GetView(GroupedResultsView.STR_MVC_CLASS_NAME).Display();


			// Bug fix 10269455 - SEARCH RESULTS PAGE(EDIT MODE), TOP LEVEL CHECKBOX FUNCTIONALITY NOT FINE
			// Checking to see if adaptive layout mode is enabled in this subportal, if so we will run
			// the delayedJavascript function that writes the DoToggleAll function to the page after the
			// page has mostly rendered
		    IPTSession currentSession = (IPTSession) m_asOwner.GetUserSession();
			if (currentSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetLayoutEnabled())
			{
				orgForm.AddInnerHTMLElement(DisplayDelayedJavaScriptFromChild());
			}
			
			HTMLForm moveForm = new HTMLForm(HTML_FORM_NAME);
			moveForm.SetMethod("post");
			moveForm.SetName(HTML_FORM_NAME);
			cell.AddInnerHTMLElement(moveForm);
			ToolbarView tbv = (ToolbarView)m_asOwner.GetView(ToolbarView.STR_MVC_CLASS_NAME);
			tbv.addTargetsToActionBarForm(moveForm);

			tbv.SetFormName(HTML_FORM_NAME);
			moveForm.AddInnerHTMLElement(tbv.Display());
			
			if (null != resultElement)
			{
				moveForm.AddInnerHTMLElement(resultElement);
			}

			// Pagination footer
			viewElement = m_asOwner.GetView(SearchFooterView.STR_MVC_CLASS_NAME)
				.Display();

			if (null != viewElement)
			{
				moveForm.AddInnerHTMLElement(makeSpacer("1"));
				moveForm.AddInnerHTMLElement(viewElement);
			}
		}
		catch (HTMLException he)
		{
			group.AddInnerHTMLElement(new HTMLGenericElement(he.getMessage()));
		}

		return group;
	}

	/**
	 *  Helper method to make a spacer table
	 */
	private HTMLTable makeSpacer(String height)

	{
		HTMLTable table = new HTMLTable();

		HTMLTableRow row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);

		HTMLImg spacer = null;

		try
		{
			spacer = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
					true, m_asOwner).GetHTMLElement();
		}
		catch (Exception e)
		{
			throw XPException.GetInstance(e);
		}

		if (null == spacer)
		{
			throw new HTMLException();
		}

		cell.AddInnerHTMLElement(spacer);
		spacer.SetWidth("1");
		spacer.SetHeight(height);
		spacer.SetAlign("absmiddle");
		spacer.SetBorder("0");
		spacer.SetAlt("");

		return table;
	}

	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection c = new HTMLScriptCollection();

		HTMLScript s = m_asOwner.GetView(GroupedResultsView.STR_MVC_CLASS_NAME).DisplayJavascript();
		if(null != s) 
		{ 
			c.AddInnerHTMLElement(s);
		}
		
		ToolbarView tbv = (ToolbarView)m_asOwner.GetView(ToolbarView.STR_MVC_CLASS_NAME);
		tbv.SetFormName(HTML_FORM_NAME);
		s = tbv.DisplayJavascript();
		
		if(null != s) 
		{ 
			c.AddInnerHTMLElement(s);
		}
		return c;
	}
	
	protected HTMLScriptCollection DisplayDelayedJavaScriptFromChild()
	{
		HTMLScriptCollection c = new HTMLScriptCollection();
	  	   
	  	   GroupedResultsView groupResultsViewObj = (GroupedResultsView) m_asOwner.GetView(GroupedResultsView.STR_MVC_CLASS_NAME);
	  	   GroupedResultsViewHelper grvHelper = (GroupedResultsViewHelper) groupResultsViewObj.GetHelper();

	  	   HTMLScript s = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
	  		   XPStringBuilder sb = new XPStringBuilder(200);
	  		   sb.Append("function DoToggleAll(group)\n");
	  		   sb.Append("{\n");			
	  		   sb.Append("    var fElem = document.mainform;\n");
	  		   sb.Append("    var feLen = fElem.elements.length;\n");
	  		   sb.Append("    var checkVal = false;\n");
	  		   sb.Append("    for (var i = 0; i < feLen; i++) {\n");
	  		   sb.Append("        if (fElem.elements[i].name == '" + GroupedResultsViewHelper.IN_CB_MASTER + "' && fElem.elements[i].value == group) {\n");
	  		   sb.Append("            checkVal = fElem.elements[i].checked;\n");
	  		   sb.Append("        }\n");
	  		   sb.Append("    }\n");
	  		   sb.Append("    for (var i = 0; i < feLen; i++) {\n");
	  		   sb.Append(grvHelper.GetCheckBoxScriptBuilder().ToString());
	  		   sb.Append("    }\n");
	  		   sb.Append("    return true;\n"); 
	  		   sb.Append("}\n"); 
	  		   s.AddInnerHTMLString(sb.ToString());
		
			c.AddInnerHTMLElement(s);
		return c;
	}
	
    /**
	* @see com.plumtree.uiinfrastructure.form.AFormDP#GetRepostTypeIsPost()
	*/
   protected boolean GetRepostTypeIsPost()
   {
	   // POST submission
	   return true;
   }
}

