package com.plumtree.portalpages.admin.objsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.objcommon.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author Matt Fryer
 *
 * This implements the Administrative Search Model, mostly delegating to an AdminModelHelper. 
 */
public class AdminSearchModel implements IRepostModel, IObjMgrDeleteRO, IAdminSearchModelRO
{
	public static final String STR_MVC_CLASS_NAME = "AdminSearch";

	private AActivitySpace m_asOwner = null;

	private AdminModelHelper m_helper = null;
	
	private ISearchResultModelRO m_searchModel = null;

	public AdminSearchModel()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
		m_helper.CleanupTempData();
	}
	
	public boolean GetHasDisplayedObjects(int classID)
	{
		return ((SearchResultModel)m_searchModel).GetHasDisplayedObjects(classID);
	}
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
 	*/	
	public void CleanupAllData()
	{
	}

	/**
	 * This method copies folders to a new folder.
	 *
	 * @param int nTargetFolderID the ID of the folder to copy the folders to.
	 * @param int[] nFolders an array of folder IDs.
	 */
	public void CopyFolders(int nTargetFolderID, int[] nFolders)
	{
		m_helper.CopyFolders(nTargetFolderID,nFolders);
	}

	/**
	 * This method copies objects between folders.
	 *
	 * @param int nFolderID the ID of the folder to copy the objects to.
	 * @param XPHashtable a map of Integer Class IDs to int[] arrays of object IDs.
	 */
	public void CopyObjectsBetweenFolders(int nFolderID, XPHashtable xpmObjects, int nCurrentFolderID)
	{
		m_helper.CopyObjectsBetweenFolders(nFolderID, xpmObjects, nCurrentFolderID);

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdminSearchModel();
	}

	/**
	 * This method deletes folders.
	 *
	 * @param int[] the folder IDs to delete
	 */
	public void DeleteFolders(int[] nFolders)
	{
		m_helper.DeleteFolders(nFolders);
	}
	
	/**
	 * @param cards
	 * @param folders
	 */
	public void DeleteCards(int[] cards, int[] folders)
	{
		m_helper.DeleteCards(cards,folders);
	}

	/**
	 *
	 */
	public void DeleteDocumentFolders(int[] documentFolders)
	{
		m_helper.DeleteDocumentFolders(documentFolders);
	}

	/**
	 * @param nPageTemplates
	 */
	public void ABODeletePageTemplates(int[] nPageTemplates)
	{
		m_helper.ABODeletePageTemplates(nPageTemplates);

	}

	/**
	 * This method deletes objects.
	 *
	 * @param XPHashtable a map of Integer Class IDs to int[] arrays of object IDs.
	 */
	public void DeleteObjects(XPHashtable xpmObjects, boolean bABODeleteObjects)
	{
		m_helper.DeleteObjects(xpmObjects, bABODeleteObjects);
	}

	/**
	 * This method enables and disables users and web services.
	 */
	public void EnableObjects(XPHashtable xpmObjects, String sComment, boolean bEnable)
	{
		m_helper.EnableObjects(xpmObjects, sComment, bEnable);
	}


	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#Finish()
	 */
	public void Finish()
	{
	}

	/**
	 * TODO: MOve some version of this to the helper.
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetCommunityID()
	 */
	public int GetCommunityID(int nFolderID)
	{
		return m_helper.GetCommunityID(nFolderID,1);

	}

	/**
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetCurrentFolderIsCommunity()
	 */
	public boolean GetFolderIsCommunity(IPTAdminFolder folder)
	{
		return m_helper.GetFolderIsCommunity(folder);
	}

	/**
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetCurrentFolderIsSubportal()
	 */
	public boolean GetFolderIsSubportal(IPTAdminFolder folder)
	{
		return m_helper.GetFolderIsSubportal(folder);
	}

	/**
	 * This method gets the selected folder from the tree sub space.
	 *
	 * @return int the folder ID (-1 implies error)
	 */
	public int GetFolderIDFromTree(String subspaceKey)
	{
		return m_helper.GetFolderIDFromTree(subspaceKey);
	}
	/**
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrModelRO#GetFolderTreeID()
	 */
	public String GetFolderTreeID()
	{
		return m_helper.GetFolderTreeID();
	}
	
	/**
	 * @return
	 */
	public int GetRootFolderID()
	{
		return 1;
	}
	
	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}

	/**
	 * @return
	 */
	public String GetAllObjectTypesString()
	{
		return m_helper.GetAllObjectTypesString();
	}

	/**
	 * @return
	 */
	public int[] GetAllObjectTypesArray()
	{
		return m_helper.GetAllObjectTypesArray();
	}

	/**
	 * Get the SpaceID of the parent Activity Space
	 *
	 * @return int m_asOwner.GetSpaceID();
	 */
	public String GetSpaceID()
	{
		return m_asOwner.GetSpaceID();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner			  = parent;
		m_helper 	= new AdminModelHelper();
		m_helper.Init(parent);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.objsearch.IAdminSearchModelRO#SetSearchModel(com.plumtree.portaluiinfrastructure.search.ISearchResultModelRO)
	 */
	public void SetSearchModel(ISearchResultModelRO model)
	{
		m_searchModel = model;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.objsearch.IAdminSearchModelRO#GetSearchModel()
	 */
	public ISearchResultModelRO GetSearchModel()
	{
		return m_searchModel;
	}
	/**
	 * This method adds folders into the migration queue.
	 */
	public void MigrateFolders(int[] nFolderIDs, String sComment)
	{
		m_helper.MigrateFolders(nFolderIDs, sComment);
	}

	/**
	 * This method adds objects into the migration queue.
	 */
	public void MigrateObjects(XPHashtable xpmObjects, String sComment)
	{
		m_helper.MigrateObjects(xpmObjects, sComment);
	}
	/**
	 * This method adds objects into the migration queue.
	 */
	public void MigrateObjects(int nClassID, int[] nObjects, String sComment)
	{
		m_helper.MigrateObjects(nClassID, nObjects, sComment);
	}
	/**
	 * This method moves folders to a new folder.
	 *
	 * @param int nTargetFolderID the ID of the folder to move the folders to.
	 * @param int[] nFolders an array of folder IDs.
	 */
	public void MoveFolders(int nTargetFolderID, int[] nFolders)
	{
		m_helper.MoveFolders(nTargetFolderID, nFolders);
	}
	
	/**
	 * @param fromFolder
	 * @param cardId
	 * @param toFolder
	 */
	public void MoveCards(int fromFolder, int cardId, int toFolder)	
	{
		m_helper.MoveCards(fromFolder, cardId, toFolder);
	}

	/**
	 * @param foldersToMove
	 * @param targetFolder
	 */
	public void MoveDocumentFolders(int[] foldersToMove,int targetFolder)
	{
		m_helper.MoveDocumentFolders(foldersToMove,targetFolder);
	}
	
	/**
	 * @param cardIds
	 * @param toFolder
	 */
	public void CopyCards(int[] cardIds, int toFolder)
	{
		m_helper.CopyCards(cardIds, toFolder);
	}

	/**
	 * @param folderIDs
	 * @param toFolder
	 */
	public void CopyDocumentFolders(int[] folderIDs, int toFolder)
	{
		m_helper.CopyDocumentFolders(folderIDs, toFolder);
	}

	/**
	 * This method moves objects between folders.
	 *
	 * @param int nFolderID the ID of the folder to move the objects to.
	 * @param Object[][] nObjects an (2 x n) array of class IDs / Object IDs
	 */
	public void MoveObjectsBetweenFolders(int nFolderID, Object[][] nObjects, Object[][] nFolders)
	{
		m_helper.MoveObjectsBetweenFolders(nFolderID, nObjects, nFolders);


	}
	
	/**
	 * @param nObjects
	 * @param nFolders
	 * @param nFolderID
	 */
	protected void DoMove(Object[][] nObjects, Object[][] nFolders, int nFolderID)
	{
		m_helper.DoMove(nObjects, nFolders, nFolderID);
	}

	/////////////////////////////////
	// Write methods for IRepostModel
	/////////////////////////////////

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String, XPHashtable)
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * This method sets the selected items in a Class ID
	 *
	 * @param int nClassID the class ID of the selected items
	 * @param int[] nSelectedObjectIDs the selected object IDs
	 */
	public void SetSelectedObjects(int nClassID, int[] nSelectedObjectIDs)
	{
		m_helper.SetSelectedObjects(nClassID, nSelectedObjectIDs);
	}

	/**
	 * 
	 *
	 * @param nFolderID 
	 *
	 * @return 
	 */
	protected boolean CheckIsCommunityFolder(int nFolderID)
	{
		return m_helper.CheckIsCommunityFolder(nFolderID);
	}


	/**
	 * This method creates a job to delete folders using Asynchronous
	 * Browser Operations (ABO).
	 *
	 * @param int[] the folder IDs to delete
	 */
	public void ABODeleteFolders(int[] nFolders)
	{
		m_helper.ABODeleteFolders(nFolders);
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrDeleteRO#CheckAuthSourceForDelete()
	 */
	public boolean CheckAuthSourceForDelete() 
	{ 
		return m_helper.CheckAuthSourceForDelete(-1);
	}
	
	/**
	 * This method checks whether or not the user is trying to delete any page templates.
	 *
	 * @return true implies page templates are being deleted
	 */
	public boolean CheckPageTemplatesForDelete() 
	{ 		
		return m_helper.CheckPageTemplatesForDelete();
	}
	/**
	 * This method checks whether or not the user is trying to delete any folders.
	 *
	 * @return true implies folders are being deleted
	 */
	public boolean CheckFoldersForDelete() 
	{ 
		return m_helper.CheckFoldersForDelete(); 
	}
	
	/**
	 * This method is used to set the list of folder IDs (temporary)
	 * to be checked for delete.
	 *
	 * @param int[] of object class id / object id pairs.
	 */
	public void SetObjectsForDeleteCheck(int[] nObjectIDPairs)
	{
		m_helper.SetObjectsForDeleteCheck(nObjectIDPairs);
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrDeleteRO#SetFoldersForDeleteCheck(boolean)
	 */
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.objmgr.IObjMgrDeleteRO#SetFoldersForDeleteCheck(boolean)
	 */
	public void SetFoldersForDeleteCheck(boolean tf)
	{
		m_helper.SetFoldersForDeleteCheck(tf);
	}
	
	/**
	 * @param folderID
	 * @return
	 */
	public String GetAdminFolderPath(int folderID)
	{
		return m_helper.GetAdminFolderPath(folderID);
	}
	
	/**
	 * @param key
	 */
	public void RefreshResults(String key)
	{
		m_helper.RefreshResults(key);
	}

}

