package com.plumtree.portalpages.admin.objsearch;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author MatthewF
 *
 * This control handles the Admin Search specific repost work. TODO: Note that code here is mostly from
 * ObjMgrRepostControl and that these should be consolidated.
 */
public class AdminSearchRepostControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.objsearch.AdminSearchRepostControl");

	/** Name of this control */
	public static final String STR_MVC_CLASS_NAME = "AdminSearchRepost";
	
	/** Mandatory Form inputs */
	public static final String HTML_INPUT_FOLDER_ID  = "in_hi_FolderID";
	public static final String HTML_INPUT_OBJECT_IDS = "in_hi_ObjectIDs";
	public static final String CURRENT_KEY_INPUT = "in_hi_currKey";

	/** Optional Form inputs */
	/** Expand object types inputs */
	public static final String HTML_INPUT_EXPAND_OBJECT_ID = "in_hi_ExpandObjectIDs"; // an int
	public static final String HTML_INPUT_EXPAND_BOOLEAN = "in_hi_Expand"; // boolean true = expand, false = collapse

	/** Repost Actions */
	public final static int POSTTOSELF_ACTION_MOVE		    	= 51;
	public final static int POSTTOSELF_ACTION_COPY		    	= 52;
	public final static int POSTTOSELF_ACTION_DELETE	    	= 54;
	public final static int POSTTOSELF_ACTION_DELETE_LATER  	= 55;
	public final static int POSTTOSELF_ACTION_MIGRATE	    	= 57;
	public final static int POSTTOSELF_ACTION_ENABLE	    	= 58;
	public final static int POSTTOSELF_ACTION_RUN_ONCE	    	= 56;
	public final static int POSTTOSELF_ACTION_MOVE_DOCITEMS	    = 61;
	public final static int POSTTOSELF_ACTION_COPY_DOCITEMS	    = 62;
	
	protected AdminSearchModel m_asAdminSearchModel;

	/**
	 * This ovverrides the implementation from RepostControl for certain actions
	 * @return Redirect
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		return super.CheckActionSecurityAndExecute(arguments);
	}


	/**
	 * This method gets the selected folders from the form data
	 *
	 * @return int[] an array of Folder IDs
	 */
	public static int[] GetSelectedFolders(XPHashtable htFormData, String key)
	{
		String[] sDataValue = (String[]) htFormData.GetElement(key);

		if (sDataValue != null)
		{
			int[] result     = new int[sDataValue.length];
			int nErrorsFound = 0;

			for (int i = 0; i < sDataValue.length; i++)
			{
				try
				{
					result[i] = XPConvert.ToInteger(sDataValue[i]);
				}
				catch (Exception e)
				{
					
						log.Error("Unable to convert selected folder to int: " +
							sDataValue[i]);
					

					result[i] = -1;
					nErrorsFound++;
				}
			}

			// Resize array if there were errors
			if (nErrorsFound > 0)
			{
				int[] temp = new int[sDataValue.length - nErrorsFound];
				int nIndex = 0;

				for (int i = 0; i < result.length; i++)
				{
					if ((result[i] != -1) && (nIndex < temp.length))
					{
						temp[nIndex] = result[i];
						nIndex++;
					}
				}

				result = temp;
			}

			return result;
		}

		return new int[0];
	}


	/**
	 * This method gets the selected objects (not folders) from the form data
	 *
	 * @return Object[][] a (2 x n) array of class ID / Object ID pairs
	 */
	public static Object[][] GetSelectedObjects(XPHashtable htFormData, boolean returnObjectIDS)
	{
		ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
		int[] arAllClassIDs = ptClassTypeDescManager.GetOrderedListOfClassIDs("en");


		String[] sDataKeys  = new String[arAllClassIDs.length];
		String[] sDataValue;
		Object nError	    = new Integer(-1);
		Object[][] result;

		// Calculate the size of the array needed
		int nSize = 0;

		for (int i = 0; i < arAllClassIDs.length; i++)
		{
			sDataKeys[i]     = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX +
			arAllClassIDs[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
			sDataValue		 = (String[]) htFormData.GetElement(sDataKeys[i]);

			if (sDataValue != null)
			{
				nSize += sDataValue.length;
			}
		}

		result = new Object[2][nSize];

		if (nSize > 0)
		{
			// populate the array
			int nIndex		 = 0;
			int nErrorsFound = 0;

			for (int i = 0; i < arAllClassIDs.length; i++)
			{
				sDataValue = (String[]) htFormData.GetElement(sDataKeys[i]);

				if (sDataValue != null)
				{
					for (int j = 0; j < sDataValue.length; j++)
					{
						if (nIndex < nSize)
						{
							try
							{
								int idValue;
								int separator = sDataValue[j].indexOf(",");
								if(returnObjectIDS)
								{
									idValue = XPConvert.ToInteger(sDataValue[j].substring(0, separator));
								}
								else
								{
									idValue = XPConvert.ToInteger(sDataValue[j].substring(separator + 1));
								}
								result[0][nIndex]     = new Integer(arAllClassIDs[i]);
								result[1][nIndex]     = new Integer(idValue);
							}
							catch (Exception e)
							{
								
									log.Error("Unable to convert selected object to int: " +
										sDataValue[j]);
								

								result[0][nIndex]     = nError;
								result[1][nIndex]     = nError;
								nErrorsFound++;
							}

							nIndex++;
						}
					}
				}
			}

			// Resize array if there were errors
			if (nErrorsFound > 0)
			{
				Object[][] temp = new Object[2][nSize - nErrorsFound];
				nIndex = 0;

				for (int i = 0; i < result.length; i++)
				{
					if ((!result[0][i].equals(nError)) &&
							(nIndex < temp.length))
					{
						temp[0][nIndex]     = result[0][i];
						temp[1][nIndex]     = result[1][i];
						nIndex++;
					}
				}

				result = temp;
			}
		}

		return result;
	}

	public static int[] GetSelectedCards(XPHashtable htFormData, boolean returnFolders)
	{
		String[] cardVals = (String[])htFormData.GetElement(GroupedResultsViewHelper.DOC_INPUT);
		if(cardVals == null || cardVals.length == 0)
			return new int[0];
		int[] retval = new int[cardVals.length];
		for(int i = 0; i < cardVals.length; i++)
		{
			String val = cardVals[i];
			int separator = val.indexOf(",");
			if(! returnFolders)
			{
				retval[i] = XPConvert.ToInteger(val.substring(0, separator));
			}
			else
			{
				retval[i] = XPConvert.ToInteger(val.substring(separator + 1));
			}
		}
		return retval;
	}
	/**
	 * This method gets the selected objects (not folders) from the form data
	 *
	 * @return XPHashtable of Integer class IDs to int[] of Object IDs
	 */
	public static XPHashtable GetSelectedObjectsMap(XPHashtable htFormData, boolean returnObjectIDS)
	{
		XPHashtable result = new XPHashtable();
		ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
		int[] nExpandedObjectTypes = ptClassTypeDescManager.GetOrderedListOfClassIDs("en");

		String[] sDataKeys  = new String[nExpandedObjectTypes.length];
		String[] sDataValue;

		int[] temp;
		int nErrorsFound;

		for (int i = 0; i < nExpandedObjectTypes.length; i++)
		{
			sDataKeys[i]     = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX +
				nExpandedObjectTypes[i] + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_SUFFIX;
			sDataValue		 = (String[]) htFormData.GetElement(sDataKeys[i]);

			if ((sDataValue != null) && (sDataValue.length > 0))
			{
				temp			 = new int[sDataValue.length];
				nErrorsFound     = 0;

				for (int j = 0; j < sDataValue.length; j++)
				{
					try
					{
						int idValue;
						int separator = sDataValue[j].indexOf(",");
						if(returnObjectIDS)
						{
							idValue = XPConvert.ToInteger(sDataValue[j].substring(0, separator));
						}
						else
						{
							idValue = XPConvert.ToInteger(sDataValue[j].substring(separator + 1));
						}
						temp[j] =idValue;
					}
					catch (Exception e)
					{
						
							log.Error("Unable to convert selected object to int: " +
								sDataValue[j]);
						

						temp[j] = -1;
						nErrorsFound++;
					}
				}

				if (nErrorsFound > 0)
				{
					int[] resize     = new int[temp.length - nErrorsFound];
					int nResizeIndex = 0;

					for (int k = 0; k < temp.length; k++)
					{
						if ((temp[k] != -1) && (nResizeIndex < temp.length))
						{
							resize[nResizeIndex] = temp[i];
							nResizeIndex++;
						}
					}

					temp = resize;
				}

				result.PutElement(new Integer(nExpandedObjectTypes[i]), temp);
			}
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdminSearchRepostControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the class with the associated model and activity space.
	 *
	 * @param model
	 * @param space
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		super.Init(model, space);
		
		m_asAdminSearchModel = (AdminSearchModel) model;

		m_asOwner = space;
	}

	/**
	 * Given the repost action mode, calls the associated method in the model.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		int nTargetFolderID;
		String[] sValues;
		String sComment;
		boolean bRequires302Redirect = false;
		int[] foldersarray = null;
		int[] docFolders = AdminSearchRepostControl.GetSelectedFolders(m_htFormData, GroupedResultsViewHelper.DOC_FOLDER_INPUT);
		int[] cards = AdminSearchRepostControl.GetSelectedCards(m_htFormData, false);
		int[] folders = AdminSearchRepostControl.GetSelectedCards(m_htFormData, true);

		switch (_nAction)
		{
			case POSTTOSELF_ACTION_MOVE_DOCITEMS:
				String[] foldersTomove = (String[])m_htFormData.GetElement(GroupedResultsViewHelper.DOC_FOLDER_INPUT);
				String[] docsTomove = (String[])m_htFormData.GetElement(GroupedResultsViewHelper.DOC_INPUT);
				nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ToolbarView.FOLDER_TREE_SUB_SPACE_KEY);

				// first, check that no cards are in multiple folders before committing any changes
				boolean haveDocInMultipleFolders = false;
				if(docsTomove != null && docsTomove.length > 0)
				{
					for(int i = 0; i < docsTomove.length; i++)
					{
						int separator = docsTomove[i].indexOf(",");
						int folderId = XPConvert.ToInteger(docsTomove[i].substring(separator + 1));
						if (GroupedResultsViewHelper.MULTIFOLDER_CODE == folderId) {
							haveDocInMultipleFolders = true;
							break;
						}
					}
					if (haveDocInMultipleFolders) {
						SetPageStatus(RepostControl.PAGE_STATUS_INVALID);
						UIError err = new UIError(UIErrorLevel.FRIENDLY,
									  UIErrorScope.CURRENT_USER,
									  m_asOwner.GetString(1863, "ptmsgs_portalbrowsingmsgs"),
									  m_asOwner.GetString(1863, "ptmsgs_portalbrowsingmsgs"));
						UIErrorHandler.RaiseError(err, m_asOwner.GetSubSession(),
									  m_asOwner.GetApplication());
						bRequires302Redirect = true;
					}
				}
		
				if((! haveDocInMultipleFolders) && foldersTomove != null && foldersTomove.length > 0)
				{
					int[] folderIDS = new int[foldersTomove.length];
					for(int i = 0; i < foldersTomove.length; i++)
					{
						folderIDS[i] = XPConvert.ToInteger(foldersTomove[i]);
					}
					m_asAdminSearchModel.MoveDocumentFolders(folderIDS,nTargetFolderID);
					bRequires302Redirect = true;

				}
				if((! haveDocInMultipleFolders) && docsTomove != null && docsTomove.length > 0)
				{
					for(int i = 0; i < docsTomove.length; i++)
					{
						int separator = docsTomove[i].indexOf(",");
						int docId = XPConvert.ToInteger(docsTomove[i].substring(0, separator));
						int folderId = XPConvert.ToInteger(docsTomove[i].substring(separator + 1));
						m_asAdminSearchModel.MoveCards(folderId,docId,nTargetFolderID);
					}
					bRequires302Redirect = true;
				}
				break;
				
			case POSTTOSELF_ACTION_COPY_DOCITEMS:
			
				String[] foldersToCopy = (String[])m_htFormData.GetElement(GroupedResultsViewHelper.DOC_FOLDER_INPUT);
				String[] docsToCopy = (String[])m_htFormData.GetElement(GroupedResultsViewHelper.DOC_INPUT);
				nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ToolbarView.FOLDER_TREE_SUB_SPACE_COPY_KEY);
				if(foldersToCopy != null && foldersToCopy.length > 0)
				{
					int[] folderIDS = new int[foldersToCopy.length];
					for(int i = 0; i < foldersToCopy.length; i++)
					{
						folderIDS[i] = XPConvert.ToInteger(foldersToCopy[i]);
					}
					m_asAdminSearchModel.CopyDocumentFolders(folderIDS,nTargetFolderID);
					bRequires302Redirect = true;

				}
				if(docsToCopy != null && docsToCopy.length > 0)
				{
					int[] docIDs = new int[docsToCopy.length];
					for(int i = 0; i < docsToCopy.length; i++)
					{
						int separator = docsToCopy[i].indexOf(",");
						int docId = XPConvert.ToInteger(docsToCopy[i].substring(0, separator));
						docIDs[i] = docId;
					}
					m_asAdminSearchModel.CopyCards(docIDs,nTargetFolderID);
					bRequires302Redirect = true;
				}
				break;
			case POSTTOSELF_ACTION_MOVE:
				nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ObjMgrAS.FOLDER_TREE_SUB_SPACE_KEY);
	
				if (nTargetFolderID != -1)
				{
					foldersarray = AdminSearchRepostControl.GetSelectedFolders(m_htFormData, ObjMgrFolderViewHelper.QS_CHECKBOX);
					
						log.Debug("Hit Move with folders: ");
						for(int i = 0; i < foldersarray.length; i++)
							log.Debug("id(" + i + ") = " + foldersarray[i]);
					
					m_asAdminSearchModel.MoveFolders(nTargetFolderID, foldersarray);
					m_asAdminSearchModel.MoveObjectsBetweenFolders(nTargetFolderID,
						AdminSearchRepostControl.GetSelectedObjects(m_htFormData, true), AdminSearchRepostControl.GetSelectedObjects(m_htFormData, false));
					m_asAdminSearchModel.RefreshResults(GetCurrentKey());
					bRequires302Redirect = true;
				}
					
				break;

			case POSTTOSELF_ACTION_COPY:
				nTargetFolderID = m_asAdminSearchModel.GetFolderIDFromTree(ObjMgrAS.FOLDER_TREE_SUB_SPACE_KEY);
	
				if (nTargetFolderID != -1)
				{
					
						log.Debug("Hit Copy");
					
	
					m_asAdminSearchModel.CopyFolders(nTargetFolderID,
						AdminSearchRepostControl.GetSelectedFolders(m_htFormData, ObjMgrFolderViewHelper.QS_CHECKBOX));
					m_asAdminSearchModel.CopyObjectsBetweenFolders(nTargetFolderID,
						AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData, true), -1);
					m_asAdminSearchModel.RefreshResults(GetCurrentKey());
					bRequires302Redirect = true;
				}
	
				break;

			case POSTTOSELF_ACTION_DELETE:
				foldersarray = AdminSearchRepostControl.GetSelectedFolders(m_htFormData, ObjMgrFolderViewHelper.QS_CHECKBOX);
	
				
					log.Debug("Hit Delete with folders: ");
					for(int i = 0; i < foldersarray.length; i++)
						log.Debug("id(" + i + ") = " + foldersarray[i]);
				
				m_asAdminSearchModel.DeleteFolders(foldersarray);
				XPHashtable objects =  AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData, true);
				m_asAdminSearchModel.DeleteObjects(objects, false);
				
				m_asAdminSearchModel.DeleteDocumentFolders(docFolders);
				
				m_asAdminSearchModel.DeleteCards(cards, folders);

				m_asAdminSearchModel.RefreshResults(GetCurrentKey());
				bRequires302Redirect = true;
	
				break;

			case POSTTOSELF_ACTION_DELETE_LATER:
				m_asAdminSearchModel.ABODeleteFolders(AdminSearchRepostControl.GetSelectedFolders(
						m_htFormData, ObjMgrFolderViewHelper.QS_CHECKBOX));
				m_asAdminSearchModel.DeleteObjects(AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData, true), true);
				m_asAdminSearchModel.RefreshResults(GetCurrentKey());
				bRequires302Redirect = true;
	
				break;
				
			case POSTTOSELF_ACTION_RUN_ONCE:
				StaticPTObjectHelpers.RunJobsOnce((int[]) GetSelectedObjectsMap(m_htFormData, true).GetElement(new Integer(PT_CLASSIDS.PT_JOB_ID)), m_asOwner);

				bRequires302Redirect = true;

				break;

			case POSTTOSELF_ACTION_MIGRATE:
				sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);
	
				if (sValues != null)
				{
					sComment = sValues[0];
				}
				else
				{
					sComment = "";
				}
				m_asAdminSearchModel.MigrateObjects(XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGFOLDER_ID), docFolders, sComment);
				
				m_asAdminSearchModel.MigrateObjects(XPConvert.ToInteger(PT_CLASSIDS.PT_CATALOGCARD_ID), cards, sComment);
				
				m_asAdminSearchModel.MigrateFolders(AdminSearchRepostControl.GetSelectedFolders(
						m_htFormData, ObjMgrFolderViewHelper.QS_CHECKBOX), sComment);
						
				m_asAdminSearchModel.MigrateObjects(AdminSearchRepostControl.GetSelectedObjectsMap(m_htFormData, true), sComment);
				
				bRequires302Redirect = true;
				break;
				
			case POSTTOSELF_ACTION_ENABLE:
				sComment = "";

				boolean bEnable;
				sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_ENABLE);

				if (sValues != null)
				{
					try
					{
						bEnable = XPConvert.ToBoolean(sValues[0]);
					}
					catch (Exception e)
					{
						
							log.Error("Unable to parse boolean enable/disable value: " +
								sValues[0]);
						

						break;
					}
				}
				else
				{
					
						log.Error("Unable to locate boolean enable/disable value.");
					

					break;
				}

				if (!bEnable)
				{
					sValues = (String[]) m_htFormData.GetElement(ObjMgrHeaderView.HTML_INPUT_COMMENT);

					if (sValues != null)
					{
						sComment = sValues[0];
					}
				}

				m_asAdminSearchModel.EnableObjects(
						GetSelectedObjectsMap(m_htFormData, true), sComment, bEnable);

				bRequires302Redirect = true;

				break;

			default:
				super.PerformAction(_nAction);
				break;
		}
		if (bRequires302Redirect)
		{
			Redirect safeRedirect = new Redirect();
			safeRedirect.SetLinkGetCachedSpace(m_asOwner);
			safeRedirect.SetIsHTTPRedirect(true);
			safeRedirect.SetDisplayPage(GetDP());

			SetRedirect(safeRedirect);
		}

	}
		
	protected String GetDP()
	{
		String retval = AdminSearchDP.STR_MVC_CLASS_NAME;
		if(m_htFormData != null || m_htFormData.GetElement(ASConstants.PAGE_INPUT) != null)
		{
			String[] vals = (String[])m_htFormData.GetElement(ASConstants.PAGE_INPUT);
			if(vals != null && vals.length > 0)
				retval = vals[0];
		}
			return retval;	
	}
	
	public String GetCurrentKey()
	{
		String[] vals = (String[])m_htFormData.GetElement(CURRENT_KEY_INPUT);
		if (vals != null)
		{
			return vals[0];
		}
		else
		{
			return "";
		}		
	}
}

