package com.plumtree.portalpages.admin.ptutilities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * @author SudhaS
 */
public class PlumtreeUtilitiesModel implements IPlumtreeUtilitiesModel,
	IPlumtreeUtilitiesModelRO
{
	public static final String STR_MVC_CLASS_NAME = "PlumtreeUtilities";

	private AActivitySpace m_asOwner;
	private XPArrayList m_SettingItems;

	public PlumtreeUtilitiesModel()
	{
		m_SettingItems = new XPArrayList();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PlumtreeUtilitiesModel();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpagessample.PlumtreeUtilities.IPlumtreeUtilitiesModelRO#getString()
	 */
	public int GetNumSettingItems()
	{
		return m_SettingItems.GetSize();
	}

	/**
	 * 
	 *
	 * @param _nIndex 
	 *
	 * @return 
	 */
	public String GetSettingItemName(int _nIndex)
	{
		return ((SettingItem) m_SettingItems.GetElement(_nIndex)).m_strName;
	}

	/**
	 * 
	 *
	 * @param _nIndex 
	 *
	 * @return 
	 */
	public String GetSettingItemURL(int _nIndex)
	{
		return ((SettingItem) m_SettingItems.GetElement(_nIndex)).m_strURL;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.ptutilities.IPlumtreeUtilitiesModelRO#GetActivityRightRestriction(int)
	 */
	public int GetActivityRightRestriction(int _nIndex)
	{
		return ((SettingItem) m_SettingItems.GetElement(_nIndex)).m_intActivityRight;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.admin.ptutilities.IPlumtreeUtilitiesModelRO#IsPluggableAdmin(int)
	 */
	public boolean IsPluggableAdmin(int _nIndex)
	{
		return ((SettingItem) m_SettingItems.GetElement(_nIndex)).m_bIsPluggableAdmin;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IModel#Init(IActivitySpace)
	 */
	public void Init(AActivitySpace _asOwner)
	{
		m_asOwner		 = _asOwner;

		final IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		final IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());

		final Object[] oaSettings = (Object[]) application.GetCachingManager().GetEntry("DisplayPlumtreeUtilities");

		final String strLang = XPConvert.ToString( PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE, _asOwner) );

		for (int i = 0; i < oaSettings.length; i++)
		{
			IPlumtreeUtilities objPlumtreeUtilities = (IPlumtreeUtilities) oaSettings[i];
			//this is not a pluggable admin utility menu item
			m_SettingItems.Add(new SettingItem(objPlumtreeUtilities.GetLinkText(
						strLang), GetLinkFromPortalSetting(objPlumtreeUtilities), 
						objPlumtreeUtilities.GetActivityRightRestriction(), false));
		}

		// Pluggable Admin Setting Pages
		IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
		IPTQueryResult ptQueryResult = ptSessionInfo.GetCurrentUserCachedPluggablePages();

		for (int i = 0; i < ptQueryResult.RowCount(); i++)
		{
			int nPersonalization = ptQueryResult.ItemAsInt(i,
					PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION);

			//JD - Get the bit for admin personalization.
			int nUserPersonalization = nPersonalization &
				PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_ADMIN;

			//JD- Flag to keep track of whether Return URI was set correctly
			boolean bReturnURISet = false;

			//JD- Compare the bitmasked number to the right value
			if (nUserPersonalization == PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_ADMIN)
			{
				//JD- This web service has admin personalization.
				String strName = ptQueryResult.ItemAsString(i,
						PT_PROPIDS.PT_PROPID_NAME);

				int nObjectID = ptQueryResult.ItemAsInt(i,
						PT_PROPIDS.PT_PROPID_OBJECTID);

				String strURL = GatewayHelpers.ConstructPrefPageLink(m_asOwner,
						nObjectID, 0, 0, GatewayHelpers.ADMINPLUGPAGE | GatewayHelpers.REDIRECTGUEST,
						PT_CLASSIDS.PT_WEBSERVICE_ID);
						
				//this is a pluggable admin menu item;  set the activity right to no activity right -mgs 9/2/03
				m_SettingItems.Add(new SettingItem(strName, strURL, PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE, true));

				//JD- Add return URI.
				if (!bReturnURISet)
				{
					ASURL url	    = new ASURL(m_asOwner);
					boolean bSetURL = url.SetLinkGetCachedSpace(m_asOwner);

					if (bSetURL)
					{
						HttpUtils.SetReturnURI(url.GetURLAsString(),
							m_asOwner.GetSubSession());
						bReturnURISet = true;
					}
				}
			}
		}
	}

	/**
	 * 
	 *
	 * @param _ptUtility 
	 *
	 * @return 
	 */
	private String GetLinkFromPortalSetting(IPlumtreeUtilities _ptUtility)
	{
		ASURL asURL			 = new ASURL(m_asOwner);
		String strUtilityURL = null;

		// The space
		asURL.SetLinkCreateNewSpace(_ptUtility.GetASName(), m_asOwner);

		// The control
		String strControl = _ptUtility.GetASControlName();

		if (strControl != null)
		{
			asURL.SetControl(strControl);
		}

		// The display page
		String strDP = _ptUtility.GetASDPName();

		if (strDP != null)
		{
			asURL.SetDisplayPage(strDP);
		}

		// The query string
		String strQueryString = _ptUtility.GetASQueryString();

		if (strQueryString != null)
		{
			strUtilityURL = asURL.GetURLAsString() + strQueryString;
		}
		else
		{
			strUtilityURL = asURL.GetURLAsString();
		}

		return strUtilityURL;
	}

	/**
	 * 
	 *
	 * @author SudhaS
	 */
	private static class SettingItem
	{
		
		public String m_strName;

		
		public String m_strURL;
		
		public int m_intActivityRight;
		
		public boolean m_bIsPluggableAdmin;

		/**
		 * Creates a new SettingItem object.
		 *
		 * @param _strName 
		 * @param _strURL 
		 */
		public SettingItem(String _strName, String _strURL, int _intActivityRight, boolean _bIsPluggableAdmin)
		{
			m_strName     		= _strName;
			m_strURL	  		= _strURL;
			m_intActivityRight 	= _intActivityRight;
			m_bIsPluggableAdmin = _bIsPluggableAdmin;
		}
	}
}

