package com.plumtree.portalpages.admin.ptutilities.activitysecurity;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Main Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author SudhaS
 */

// ***CHANGE_HERE*** Change the name of the class.
// ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
//       when you are done.
public class MainActivityRightsEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.activitysecurity.MainActivityRightsEditorAS");

	// ***CHANGE_HERE*** Set the class name.
	// ***COMMENT_1*** All the AS in Plumtree need to have a unique name.

	
	public static final String STR_MVC_CLASS_NAME = "MainActivityRightsEditor";

	
	public static final String strStorageActivityRightsList = "ActivityRightsList";

	private static final String sClassName = "com.plumtree.portalpages.admin.ptutilities.activitysecurity.MainActivityRightsEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MainActivityRightsEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		// ***CHANGE_HERE*** Return the main title of the Editor.
		return (GetString(1350, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	
	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		// ***CHANGE_HERE*** Replace MainRepostControl below with your RepostControl.
		return (MainActivityRightsRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		// ***CHANGE_HERE*** Replace MainModel below with your Model.
		m_strModelName = MainActivityRightsModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(MainActivityRightsModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		// ***CHANGE_HERE*** Register each DP of your AS.
		RegisterPage(new MainActivityRightsDP());

		// Register Controls
		// ***CHANGE_HERE*** Register each Control of your AS.
		RegisterControl(MainActivityRightsRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		// Set default page
		// ***CHANGE_HERE*** Replace MainDP below with the default DP.
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(MainActivityRightsDP.STR_MVC_CLASS_NAME);

		// Sets left nav menu
		// ***CHANGE_HERE*** Set the left nav menu using StartNewSubMenu and AddLinkToSubMenu.
		// ***COMMENT_1*** If you don't want any left nav menu just remove the lines below.
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1351,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			MainActivityRightsDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
		// ***CHANGE_HERE GROWABLELIST*** Register the Section, the Model 
		//      and the Control used by the growable array.
		RegisterModel(MainActivityRightsListModel.STR_MVC_CLASS_NAME,
			strStorageActivityRightsList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myActivityRightsListModel = GetModel(strStorageActivityRightsList);
		RegisterView(MainActivityRightsListView.STR_MVC_CLASS_NAME,
			strStorageActivityRightsList, myActivityRightsListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strStorageActivityRightsList, myActivityRightsListModel);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				
				tm.SetGeneratingClass( sClassName );
				

				int iTitleId = 75;
				int iTipId = 76;
				int iSecondaryTipId = 77;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}									
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}
	
	/**
	 * Set the help page for this editor. 
	 *
	 * @param page 
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);
	
		String sPageName = page.GetName();
	
		if (MainActivityRightsDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_ActivityManager_MainSettings");
		}	}
}

