package com.plumtree.portalpages.admin.ptutilities.activitysecurity;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This class keeps an up-to-date state of all the settings.
 *
 * It contains the set and get methods for those settings.
 *
 * It contains the start, save and finish methods.
 *
 * This class is used by the Section MainView (to get the
 * latest value of the settings to display) and by the
 * Control MainRepostControl (to perform the repost actions).
 *
 * @author SudhaS
 */

public class MainActivityRightsModel extends EditorModel
	implements IMainActivityRightsModelRO
{
	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "MainActivityRights";

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		MainActivityRightsListModel activityRightsList = (MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList);

		activityRightsList.InitializeActivityRightsList(m_asOwner.GetString(
				1357, "ptmsgs_portaladminmsgs"),
			
		m_asOwner.GetString(1358, "ptmsgs_portaladminmsgs"),
			PTImageType.ACTION_ADD,
			
		m_asOwner.GetString(1359, "ptmsgs_portaladminmsgs"), 1);

		activityRightsList.SetRowIcon(PTImageType.ICON_FOLDER_OPEN);

		IPTSessionInfo ptSessionInfo	  = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo();
		IPTQueryResult ptqrActivityRights = ptSessionInfo.QueryActivityRights();

		Object[][] oRows = new Object[ptqrActivityRights.RowCount()][MainActivityRightsListModel.EXPLIST_COL_MAX];

		for (int i = 0; i < ptqrActivityRights.RowCount(); i++)
		{
			oRows[i][MainActivityRightsListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(activityRightsList.m_nNextIndex);
			activityRightsList.m_nNextIndex++;
			oRows[i][MainActivityRightsListModel.EXPLIST_COL_ID]			  = new Integer (ptqrActivityRights.ItemAsInt(i,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			oRows[i][MainActivityRightsListModel.EXPLIST_COL_NAME]			  = ptqrActivityRights.ItemAsString(i,
					PT_PROPIDS.PT_PROPID_NAME);
			oRows[i][MainActivityRightsListModel.EXPLIST_COL_DESCRIPTION]     = ptqrActivityRights.ItemAsString(i,
					PT_PROPIDS.PT_PROPID_DESCRIPTION);
			oRows[i][MainActivityRightsListModel.EXPLIST_COL_URI]			  = ptqrActivityRights.ItemAsString(i,
					PT_PROPIDS.PT_PROPID_ACTIVITY_URI);

		}

		activityRightsList.SetDefaultObjects(oRows);

		activityRightsList.SetEmptyListMessages(m_asOwner.GetString(1360,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(1361, "ptmsgs_portaladminmsgs"));

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MainActivityRightsModel();
	}

	/**
	* This method will be called when you come back to the main Editor from a sub Editor.
	*
	*/
	public void DoTaskOnComeBackFromSubEditor()
	{
		((MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList)).DoTaskOnComeBackFromSubEditor();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		//Done for deletion purposes - first delete all rights, and then add the ones that still remain in the GrowableArray
		int[] aRowsToDelete = ((MainActivityRightsListModel) m_asOwner.GetModel(MainActivityRightsEditorAS.strStorageActivityRightsList)).GetRowsToDelete();

		if (aRowsToDelete != null)
		{
			RemoveGroups(aRowsToDelete);
		}

		//RemoveAllGroups();
		//AddRemainingGroups();
	}

	/**
	 * 
	 *
	 * @param nActivityID 
	 *
	 * @return 
	 */
	public Object[] GetGroups(int nActivityID)
	{
		IPTSession ptSession			   = (IPTSession) m_asOwner.GetUserSession();
		IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
				false);

		IPTQueryResult ptqrGroups = ptActivityGroups.QueryAllGroups(nActivityID);
		Object[] groups			  = new Object[ptqrGroups.RowCount()];

		for (int i = 0; i < ptqrGroups.RowCount(); i++)
		{
			int nGroupID = ptqrGroups.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
			groups[i] = new Integer(nGroupID);
		}

		return groups;
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param _aRowsToDelete 
	 */
	public void RemoveGroups(int[] _aRowsToDelete)
	{
		IPTSession ptSession			   = (IPTSession) m_asOwner.GetUserSession();
		IPTActivityGroups ptActivityGroups = (IPTActivityGroups) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACTIVITY_SECURITY_MANAGER,
				false);

		for (int i = 0; i < _aRowsToDelete.length; i++)
		{
			//ptActivityGroups.RevokeRightFromGroups(_aRowsToDelete[i], GetGroups(_aRowsToDelete[i]));
			((IPTListManager) ptActivityGroups.GetInterfaces("IPTListManager")).DeleteItem(_aRowsToDelete[i]);
		}
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}
}

