package com.plumtree.portalpages.admin.ptutilities.automationserver;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register all the Model, Views, Display Pages,  and
 * Controls created for the Main Editor. This class can also be used to get
 * any of those objects back with  the class name.
 *
 * @author SudhaS
 */
public class AutomationServerEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.automationserver.AutomationServerEditorAS");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "AutomationServerEditor";

	/** Unique name for the automation server list control */
	public static final String strStorageAutomationServerList = "AutomationServerList";

	/** Fully qualified class name */
	private static final String sClassName = "com.plumtree.portalpages.admin.ptutilities.automationserver.AutomationServerEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AutomationServerEditorAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(1435, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (AutomationServerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = AutomationServerModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(AutomationServerModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new AutomationServerDP());
		RegisterPage(new AutomationServerPopUpDP());
		RegisterPage(new JobHistoriesDP());

		//Register the classes from the joblogs package
		RegisterModel(JobLogModel.STR_MVC_CLASS_NAME);

		IModel myJobLogModel = GetModel(JobLogModel.STR_MVC_CLASS_NAME);
		RegisterView(HistoryView.STR_MVC_CLASS_NAME, myJobLogModel);
		RegisterControl(JobLogRepostControl.STR_MVC_CLASS_NAME, myJobLogModel);

		// Job Log Download Page -- this needs to be registered after
		// the Job Log Model.
		RegisterPage(new JobLogDownloadDP());

		//Popup view
		RegisterView(AutomationServerPopUpView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(AutomationServerRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		// Set default page
		SetCurrentPage(AutomationServerDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "Utility Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1436,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			AutomationServerDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			JobHistoriesDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
		// Register AutomationServerList 
		RegisterModel(AutomationServerListModel.STR_MVC_CLASS_NAME,
			strStorageAutomationServerList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myAutomationServerListModel = GetModel(strStorageAutomationServerList);
		RegisterView(AutomationServerListView.STR_MVC_CLASS_NAME,
			strStorageAutomationServerList, myAutomationServerListModel);

		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strStorageAutomationServerList, myAutomationServerListModel);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				
				tm.SetGeneratingClass( sClassName );
				

				int iTitleId = 78;
				int iTipId = 79;
				int iSecondaryTipId = 80;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}									
								
				
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}
	
	/**
	  * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	  *
	  * @param IDisplayPage the current Display Page
	  */

	 public void SetCurrentPage(IDisplayPage page)
	 {
		 
		  super.SetCurrentPage( page );
		  String sPageName = page.GetName();
		  if(AutomationServerDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_AutomationServerManager_MainSettings" );                           
		  } else if(JobHistoriesDP.STR_MVC_CLASS_NAME.equals( sPageName ))  
		  {
			this.SetHelpTopic( "PT_AutomationServerManager_JobHistories" );    
		  }




	 }
}

