package com.plumtree.portalpages.admin.ptutilities.automationserver;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.admin.ptutilities.customactivity.*;
import com.plumtree.portalpages.admin.ptutilities.jobfolders.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Growable Array.
 * The Growable Array is a list of input texts.
 * On add, a new input text populated with the default value
 * will be added at the bottom of the list.
 *
 * @author SudhaS
 */
public class AutomationServerListModel extends ExpListModel
	implements IAutomationServerListModelRO
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "AutomationServerList";

	
	public static final String SERVER_NAME = "serverName";

	/**
	 * Number total of columns
	 */
	public static final int EXPLIST_COL_MAX = 5;

	/**
	 * This column contains the Object Class IDs.
	 */
	public static final int EXPLIST_COL_NAME = 1;

	/**
	 * This column contains the Object IDs.
	 */
	public static final int EXPLIST_COL_NETADDR = 2;

	/**
	 * This is the String that we doisplay in the list.
	 * E.g.: Object name or folder path.
	 */
	public static final int EXPLIST_COL_STATUS = 3;

	
	public static final int EXPLIST_COL_LASTUPDATE = 4;

	/**
	 * Second column: the value of the input text. */
	public static final int EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT = 1;

	/**
	 * Icon to display on each row, just before the input text. */
	protected PTImageType m_imgRowIcon;

	/**
	 * This is used on add to populate the input
	 * text of the newly added row.
	 */
	protected String m_sDefaultValue = "";
	private String[] m_aRowsToDelete;

	/**
	 * Adds one row at the bottom of the list and
	 * sets the following values:
	 * First column: m_nNextIndex
	 * Second column: m_sDefaultValue
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		boolean bCanAddNewRow = true;

		// JF- Before we add a new row at the end of the list, we check 
		// if you don't already have a "new row" in the list.
		// The user doesn't need to have more than one empty row (or row with the default value).
		// JF- Check the array see if we have the default value in it.
		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			if (m_sDefaultValue.equals(m_saData.GetItem(i,
							EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT)))
			{
				// JF- We already have a new row no need to add one more.
				bCanAddNewRow = false;

				break;
			}
		}

		if (bCanAddNewRow)
		{
			AddRowsToList(new String[] { m_sDefaultValue });
		}
	}

	/**
	 * Adds an array of new rows to the list.
	 *
	 * @param _aData
	 */
	public void AddRowsToList(String[] _aData)
	{
		Object[] oRow;

		for (int i = 0; i < _aData.length; i++)
		{
			oRow									   = new Object[EXPLIST_COL_MAX];
			oRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
			m_nNextIndex++;
			oRow[EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = _aData[i];
			super.GetItems().AddRow(oRow);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AutomationServerListModel();
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 */
	public void DeleteRowsOnRepost(XPHashtable _htFormData)
	{
		int[] aRowsToDelete;

		if (!m_bIsReadOnly)
		{
			String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);

			// JF- We get back the list of index of rows to delete.
			if (_htFormData.ContainsKey(sDataKey))
			{
				aRowsToDelete = GetArrayOfObjToDelete(_htFormData);

				// JF- We can only delete rows if the array is not empty
				if (m_saData.GetCount() > 0)
				{
					m_aRowsToDelete = new String[aRowsToDelete.length];

					for (int i = 0; i < aRowsToDelete.length; i++)
					{
						m_aRowsToDelete[i] = (String) m_saData.GetItem(aRowsToDelete[i],
								EXPLIST_COL_NAME);
					}

					m_saData.RemoveRows(aRowsToDelete);
				}
			}
		}
	}

	/**
	 * 
	 */
	public void DoTaskOnComeBackFromPopUp()
	{

	}

	/*
	public void AddPropertyToSubSpace()
	{
	    m_asOwner.SetSubSpaceKey(CustomActivityEditorAS.STR_MVC_CLASS_NAME + m_nSubSpaceIndex);
	    m_nSubSpaceIndex ++;
	}*/

	/**
	 * This method will be called when you come back to the main Editor from a sub Editor.
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		//AddPropertyToArray();	
		JobFoldersEditorAS myJobFoldersEditorAS;
		JobFoldersModel myJobFoldersModel;

		String strSubEditorASName = JobFoldersEditorAS.STR_MVC_CLASS_NAME;

		if (m_asOwner.GetSubSpaceExists(strSubEditorASName))
		{
			myJobFoldersEditorAS     = (JobFoldersEditorAS) m_asOwner.GetSubSpace(strSubEditorASName);
			myJobFoldersModel		 = (JobFoldersModel) myJobFoldersEditorAS.GetModel(myJobFoldersEditorAS.m_strModelName);

			String strServerName     = myJobFoldersModel.GetServerName();

			String strNewSubSpaceKey = strSubEditorASName + strServerName;
			m_asOwner.ChangeSubSpaceKey(strSubEditorASName, strNewSubSpaceKey);

			//m_asOwner.DeleteSubSpace(sEditorASName);
		}
	}

	/**
	 * Return the ASURL object going to the Property Editor as a sub Editor.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor.
	 * If we are going to a new sub Editor, the key can be null and
	 * we will just pass in the default key. If we are going back to an
	 * existing sub Editor, it should be the sub Editor key.
	 * @return ASURL
	 */
	public ASURL GetASURLToProperty(String _sSubSpaceKey)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = CustomActivityEditorAS.STR_MVC_CLASS_NAME;
		}

		// ***CHANGE_HERE*** If you don't have a class ID, just pass in null for the 2 last arguments.
		// JF- The helper method below will return the right URL. We don't need to figure out 
		// if it's a cahed sub Editor or no.
		ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(CustomActivityEditorAS.STR_MVC_CLASS_NAME,
				_sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE,
				ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));

		return myPopUpURL;
	}

	/**
	 * Returns the array of sub spaces.
	 * This method is used by the Section to know the list of
	 * Properties to display.
	 *
	 * @return XPArrayList
	 */

	/*
	public Object GetSubEditorAtIndex(int index)
	{
	    XPArrayList alSubModels = new XPArrayList();

	    // JF- The sub spaces array in the Activity Space is used to store all kind
	    // of sub spaces. Not only our Property Editors. That's why we need to look for our Editors.

	    for (int i = 0; i <= m_nSubSpaceIndex; i ++)
	    {
	        if (m_asOwner.GetSubSpaceExists(CustomActivityEditorAS.STR_MVC_CLASS_NAME + i))
	        {
	            alSubModels.Add(m_asOwner.GetSubSpace(CustomActivityEditorAS.STR_MVC_CLASS_NAME + i));
	        }
	    }
	    if ((index > alSubModels.GetSize()) || (alSubModels.GetSize() == 0)) return null;
	    return (alSubModels.GetElement(index));
	}*/

	/**
	 * All sub Editors are cvreated with the same default key.
	 * This method takes care of changing the key to a real key (unique)
	 * when we are sure the Editor has been created and not canceled.
	 *
	 * This method is called by DoTaskOnComeBackFromSubEditor.
	 */

	/*
	public void AddPropertyToArray()
	{
	    // JF- When we create the sub Editor, we pass in a default key because the user might
	    // cancel the sub Editor, so at that time we don't know for sure if the sub Editor will be created or no.
	    // However when the user clicks on finish, we know that the Property Editor has been created and
	    // we can add it to the list. We do so by changing the key to something unique.

	    m_asOwner.ChangeSubSpaceKey(CustomActivityEditorAS.STR_MVC_CLASS_NAME, CustomActivityEditorAS.STR_MVC_CLASS_NAME + m_nSubSpaceIndex);

	    m_nSubSpaceIndex ++;



	}*/

	/**
	 * Returns the URL to edit the object.
	 *
	 * @param _nClassID
	 * @param _nObjectID
	 * @param _sEditorASName
	 *
	 * @return ASURL URL to the Editor
	 */
	public ASURL GetEditObjectURL(String _strServerName)
	{
		ASURL myURL = new ASURL(m_asOwner);

		// JF- For any Object in the list, the sub space key will be 
		// this Model name with the object class id and the object id.
		String strSubEditorKey = STR_MVC_CLASS_NAME + _strServerName;

		if (m_asOwner.GetSubSpaceExists(strSubEditorKey))
		{
			JobFoldersEditorAS mySubEditor = (JobFoldersEditorAS) m_asOwner.GetSubSpace(strSubEditorKey);
			myURL.SetLinkGetCachedSpace(mySubEditor);
		}
		else
		{
			String sEditorASName = JobFoldersEditorAS.STR_MVC_CLASS_NAME;

			myURL.SetLinkCreateNewSpace(sEditorASName, m_asOwner);
			myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			myURL.SetSubSpaceKey(XPHttpUtility.HtmlEncode(strSubEditorKey));

			//myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(_nClassID));
			//myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID, XPConvert.ToString(_nObjectID));
			myURL.AddControlArgument(SERVER_NAME, _strServerName);
		}

		return myURL;
	}

	/**
	 * This method should ge used by the client to
	 * get back the array of values at the end of
	 * the Editor and store them.
	 *
	 * @return String[]
	 */
	public String[] GetListValues()
	{
		String[] aListValues = new String[m_saData.GetCount()];

		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			aListValues[i] = (String) m_saData.GetItem(i,
					EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		}

		return aListValues;
	}

	// ***CHANGE_HERE*** This key is used to create and retrieve sub Editors. 
	//private int m_nSubSpaceIndex = 0;

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the icon to display on each row before the
	 * input text.
	 * If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgRowIcon;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String[] GetRowsToDelete()
	{
		return m_aRowsToDelete;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeAutomationServerList(String _sSectionTitle,
		String _sSectionSubTitle1, String _sSectionSubTitle2,
		String _sSectionSubTitle3, PTImageType _imgAddIcon, String _sAddLabel,
		int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[3][5];

		/*
		arrExpListColInfo[0][EXPLIST_COLUMN_ID] = new Integer(EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE] = "";
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH] = "30";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT] = Boolean.FALSE;
		*/
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle1;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "60%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "2";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle2;
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "20%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		arrExpListColInfo[2][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		arrExpListColInfo[2][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle3;
		arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH]		    = "20%";
		arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_NAME,
				EXPLIST_COL_NETADDR, EXPLIST_COL_STATUS, EXPLIST_COL_LASTUPDATE
			};

		// JF- Sort array
		// The growable array will always be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_SORTEDARRAY_PROPID_INDEX;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true);
	}

	/**
	* Add the array passed in argument to the list.
	* The array should be created using the EXPLIST_COL
	* constants defined in this class.
	*
	* @param _arrRows Array of rows to add.
	*/
	public void SetDefaultObjects(Object[][] _arrRows)
	{
		super.GetItems().AddRows(_arrRows);
	}

	/**
	 * Sets a new default value.
	 * By default this is an empty string.
	 * This value is used on add to populate the input
	 * text of the newly added row.
	 *
	 * @param _sDefaultValue New value
	 */
	public void SetDefaultValue(String _sDefaultValue)
	{
		m_sDefaultValue = _sDefaultValue;
	}

	/**
	 * Sets the icon to display on each row before the
	 * input text.
	 * By default, no icon is displayed.
	 *
	 * @param _imgRowIcon
	 */
	public void SetRowIcon(PTImageType _imgRowIcon)
	{
		m_imgRowIcon = _imgRowIcon;
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		String sDataKey     = GetUniqueString(AutomationServerListView.HTMLINPUT_ITEM) +
			_nRowIndex;
		String[] aDataValue;

		// JF- For each input text posted by the form, we get the value back 
		// and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex,
					EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT, aDataValue[0]);
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
}

