package com.plumtree.portalpages.admin.ptutilities.automationserver;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.server.*;

/**
 * This is the implementation of the Expandable List
 * framework for the Growable Array.
 * Is constains the HTML to display the Growable Array.
 * It gets the data to display from GrowableListModel.
 *
 * @author SudhaS
 */
public class AutomationServerListView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.automationserver.AutomationServerListView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "AutomationServerList";

	/**
	 * Class name for the activity space */
	public static final String HTMLINPUT_ITEM		    = "in_tx_Item";

	
	public static final String HTMLHIDDEN_PROPEDITORKEY = "in_hi_PropEditorKey";

	/** Job Server javascript opener function */
	public static final String JAVASCRIPT_EDITOBJECT = "EditObject";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AutomationServerListView();
	}

	/**
	 * Returns Java Script for goToPage function.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = null;
		myScript = new HTMLScript("text/javaScript");

		// The URL to open the pop-up
		ASURL myPopUp = new ASURL(m_asOwner);
		myPopUp.SetLinkGetCachedSpace(m_asOwner);

		myPopUp.SetDisplayPage(AutomationServerPopUpDP.STR_MVC_CLASS_NAME);

		// ***CHANGE_HERE*** Add the following 2 lines only if you need to have an "on open pop-up" action
		//      The code to execute when the pop-up gets opened should go in Misc2RepostControl under "case POSTTOSELF_ACTION_OPEN_POPUP"
		myPopUp.SetControl(AutomationServerRepostControl.STR_MVC_CLASS_NAME);

		//myPopUp.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF, XPConvert.ToString(Misc2RepostControl.POSTTOSELF_ACTION_OPEN_POPUP));
		try
		{
			XPStringBuilder sb;
			sb = new XPStringBuilder(300);

			// JavaScript to sort by column	
			sb.Append("function " +
				((IExpListModelRO) m_model).GetUniqueString("SortBy") +
				"(varColumnID)\n");
			sb.Append("{\n");
			sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
				((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_COLUMNID) +
				".value= varColumnID;\n");
			sb.Append("  postToSelf(" +
				((IExpListModelRO) m_model).GetUniqueInt(
					ExpListControl.POSTTOSELF_ACTION_SORTBYCOLUMN) + ");\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(300);

			// JavaScript to sort by column	
			sb.Append("function " +
				((IExpListModelRO) m_model).GetUniqueString("DeleteRows") +
				"()\n");
			sb.Append("{\n");
			sb.Append("  if(0 != " +
				((IExpListModelRO) m_model).GetUniqueString("CountCheckedRows") +
				"()) \n");
			sb.Append("  {\n");
			sb.Append("    postToSelf(" +
				((IExpListModelRO) m_model).GetUniqueInt(
					ExpListControl.POSTTOSELF_ACTION_DELETE) + ");\n");
			sb.Append("  }\n");
			sb.Append("  else\n");
			sb.Append("  {\n");

			sb.Append("    alert('" +
				m_asOwner.GetString(60, "ptmsgs_infrastructure") + "');\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(300);

			// JavaScript to return the number of checked rows.
			sb.Append("function " +
				((IExpListModelRO) m_model).GetUniqueString("CountCheckedRows") +
				"()\n");
			sb.Append("{ \n");
			sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME +
				"; \n");
			sb.Append("  var len = frm.elements.length; \n");
			sb.Append("  var nValue = frm." +
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALL) + ".checked; \n");
			sb.Append("  var i = 0; \n");
			sb.Append("  var nTotal = 0; \n");
			sb.Append("  \n");
			sb.Append("  for(i=0 ; i<len ; i++) \n");
			sb.Append("  { \n");
			sb.Append("    if (frm.elements[i].name == '" +
				((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW) +
				"') \n");
			sb.Append("    { \n");
			sb.Append("       if (frm.elements[i].checked) \n");
			sb.Append("       { \n");
			sb.Append("          nTotal++; \n");
			sb.Append("       } \n");
			sb.Append("    } \n");
			sb.Append("  } \n");
			sb.Append("  return (nTotal);\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(300);

			// JavaScript to check all the rows
			sb.Append("function " +
				((IExpListModelRO) m_model).GetUniqueString("CheckRows") +
				"()\n");
			sb.Append("{ \n");
			sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME +
				"; \n");
			sb.Append("  var len = frm.elements.length; \n");
			sb.Append("  var nValue = frm." +
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALL) + ".checked; \n");
			sb.Append("  var i = 0; \n");
			sb.Append("  \n");
			sb.Append("  for(i=0 ; i<len ; i++) \n");
			sb.Append("  { \n");
			sb.Append("    if (frm.elements[i].name == '" +
				((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW) +
				"') \n");
			sb.Append("    { \n");
			sb.Append("       frm.elements[i].checked = nValue;\n");
			sb.Append("    } \n");
			sb.Append("  } \n");
			sb.Append("}\n");

			// Open Pop Up function
			sb.Append("function OpenPopUp()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(myPopUp.GetURLAsString())
			.Append("', '_blank3', 'location=no,menubar=no,height=180,width=400');\n");
			sb.Append("}\n");

			sb.Append("function EditProperty(varSubSpaceURL,varSubSpaceKey)\n");
			sb.Append("{\n");
			sb.Append(
				"    window.open(varSubSpaceURL, 'PopUpEditMode' + varSubSpaceKey, 'location=no,menubar=no, scrollbars=yes, height=400,width=800');\n");
			sb.Append("}\n");

			// Edit object
			//sb = new XPStringBuilder( 200 );
			sb.Append(" function " +
				((IAutomationServerListModelRO) m_model).GetUniqueString(
					JAVASCRIPT_EDITOBJECT) + "(varURL,varIndex)");
			sb.Append(" {");
			sb.Append(
				"    window.open(varURL,'PopUpEditMode' + varIndex,'location=no,menubar=no, scrollbars=yes, height=600,width=800');\n");
			sb.Append(" }");

			sb.Append("function RemoveProperty(varSubSpaceKey)\n");
			sb.Append("{\n");
			sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
				HTMLHIDDEN_PROPEDITORKEY + ".value= varSubSpaceKey;\n");
			sb.Append("  postToSelf(" +
				AutomationServerRepostControl.POSTTOSELF_ACTION_REMOVEPROPERTY +
				");\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			if (((IExpListModelRO) m_model).GetEnableMoveRowActions())
			{
				sb = new XPStringBuilder(300);

				// JavaScript to sort by column			
				sb.Append("function " +
					((IExpListModelRO) m_model).GetUniqueString("MoveRow") +
					"(varMoveAction, varRowIndex)\n");
				sb.Append("{\n");
				sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
					((IExpListModelRO) m_model).GetUniqueString(
						HTMLHIDDEN_ROWINDEX) + ".value= varRowIndex;\n");
				sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
					((IExpListModelRO) m_model).GetUniqueString(
						HTMLHIDDEN_MOVEACTION) + ".value= varMoveAction;\n");
				sb.Append("  postToSelf('" +
					((IExpListModelRO) m_model).GetUniqueInt(
						ExpListControl.POSTTOSELF_ACTION_MOVEROW) + "');\n");
				sb.Append("}\n");

				myScript.AddInnerHTMLString(sb.ToString());
			}

			String sEmptyListAlert = ((IExpListModelRO) m_model).GetAlertMessageForEmptyList();

			if (null != sEmptyListAlert)
			{
				sb = new XPStringBuilder(300);

				// JavaScript to check if the list is not empty	
				// JF- Note that this method is not called anywhere in the framework. 
				// It has to be registered as a validation function inside the Editor
				sb.Append("function " +
					((IExpListModelRO) m_model).GetUniqueString(
						"CheckEmptyList") + "()\n");
				sb.Append("{\n");
				sb.Append("  \n");

				if (0 == ((IExpListModelRO) m_model).GetReadOnlyItems()
						.GetCount())
				{
					sb.Append("  alert(\"" + sEmptyListAlert + "\"); \n");
					sb.Append("  return false;\n");
				}
				else
				{
					sb.Append("  return true;\n");
				}

				sb.Append("}\n");

				myScript.AddInnerHTMLString(sb.ToString());
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "ExpListView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(53,
					"ptmsgs_infrastructure"), e); //_ui_DisplayJSError
		}

		return myScript;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		try
		{
			HTMLElementCollection result = new HTMLElementCollection();
			HTMLTableCell myCell;

			myCell = new HTMLTableCell();
			result.AddInnerHTMLElement(myCell);

			//myCell.SetWidth("100%");
			myCell.SetHeight("30");
			myCell.SetWidth("20");
			
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myCell.SetNoWrap(true);
			myCell.SetVAlign("middle");
			//myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// row icon
			PTImageType imgRowIcon = ((IAutomationServerListModelRO) m_model).GetRowIcon();

			if (null != imgRowIcon)
			{
				
				myCell.AddInnerHTMLElement(GetHTMLForIcon(imgRowIcon));
				//myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			}

			String strServerName = (String) _saData.GetItem(_nRowIndex,
					AutomationServerListModel.EXPLIST_COL_NAME);

			//String strServerAddr = (String) _saData.GetItem(_nRowIndex, AutomationServerListModel.EXPLIST_COL_NETADDR);
			int nServerStatus		   = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					AutomationServerListModel.EXPLIST_COL_STATUS));

			XPDateFormat xpDateFormat = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
																	   /* use portal server time zone */ false);
			XPDateTime dtServerLastUpdate = (XPDateTime) _saData.GetItem(_nRowIndex,
										  AutomationServerListModel.EXPLIST_COL_LASTUPDATE);
			String strServerLastUpdate = xpDateFormat.Format(dtServerLastUpdate);

			// input text
			myCell = new HTMLTableCell();
			result.AddInnerHTMLElement(myCell);
			myCell.SetWidth("60%");
			myCell.SetHeight("30");
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

			myCell.AddInnerHTMLString(SPACE);

			//myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode( (String)oRightName ));
			//myCell.AddInnerHTMLString("<br>");
			//myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode( (String)oRightDesc ));
			ASURL myURL = ((IAutomationServerListModelRO) m_model).GetEditObjectURL(strServerName);

			// mj: replaced the following line with a blank constructur and SetOnClick()
			// HTMLAnchor myAnchor = new HTMLAnchor(
			HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.SetOnClick(
					((IAutomationServerListModelRO) m_model).GetUniqueString(
						"EditObject") + "('" + myURL.GetURLAsString() + "','" +
					_nRowIndex + "'); return false;");
			myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strServerName));
			myCell.AddInnerHTMLElement(myAnchor);
			
			//myCell.AddInnerHTMLString(strServerName);
			myCell = new HTMLTableCell();
			result.AddInnerHTMLElement(myCell);
			myCell.SetWidth("20%");
			myCell.SetHeight("30");
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

			if (nServerStatus == PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_ONLINE)
			{
				myCell.AddInnerHTMLString(m_asOwner.GetString(1442,
						"ptmsgs_portaladminmsgs"));
			}
			else if (nServerStatus == PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_OFFLINE)
			{
				myCell.AddInnerHTMLString(m_asOwner.GetString(1443,
						"ptmsgs_portaladminmsgs"));
			}
			else
			{
				//MES- Unknown status.  We won't explicitly check for 
				//  PT_JOBSERVERSTATUS.PT_JOBSERVERSTATUS_UNKNOWN, since even
				//  if it's some other status, we still want to display Unknown
				myCell.AddInnerHTMLString(m_asOwner.GetString(3198,
						"ptmsgs_portaladminmsgs"));
			}

			myCell = new HTMLTableCell();
			result.AddInnerHTMLElement(myCell);
			myCell.SetWidth("20%");
			myCell.SetHeight("30");
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myCell.AddInnerHTMLString(strServerLastUpdate);

			return result;
		}
		catch (HTMLException e)
		{
			
				log.Error("AutomationServerListView::" + e.getMessage());
			
		}
		catch (Exception e)
		{
			
				log.Error("AutomationServerListView::" + e.getMessage());
			
		}

		return null;
	}

	/***/
	/**
	 */
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the space below the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		return null;
	}

	/**
	 * Returns the HTML for the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLForActionBar()
	{
		try
		{
			HTMLTable myTable;
			HTMLTableRow myRow;
			HTMLTableCell myCell;

			myTable = new HTMLTable();
			myTable.SetBorder("0");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("0");

			// 1st Row begin (there is only one row)
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			// Empty Cell
			myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());

			// Add icon cell
			myRow.AddInnerHTMLElement(GetHTMLForAddAction());

			// Empty Cell
			myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());

			// JF- No need to display the delete icon, if the list is empty.
			if (0 != ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
			{
				// Delete icon cell
				myRow.AddInnerHTMLElement(GetHTMLForDeleteAction());
			}

			// Add Extra HTML to the action bar (like a "create" button)
			AddHTMLToActionBar(myRow);

			// Last Empty Cell
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetHeight("25");
			myCell.AddInnerHTMLString(SPACE);

			// 1st Row ends
			return myTable;
		}
		catch (HTMLException e)
		{
			
				log.Error("AutomationServerListView::" + e.getMessage());
			
		}
		catch (Exception e)
		{
			
				log.Error("AutomationServerListView::" + e.getMessage());
			
		}

		return null;
	}

	/**
	 * Returns the HTML for the add cell in the action bar.
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
		try
		{
			HTMLTableCell myCell;
			PTConstruct myConstruct;
			HTMLImg myImage, myAddIcon;
			HTMLAnchor myAnchor;
			HTMLSpan mySpan;

			myCell = new HTMLTableCell();
			myCell.SetHeight("25");
			myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
			myCell.SetNoWrap(true);
			myCell.AddInnerHTMLString(SPACE);

			// Add icon
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD,
					true, this.m_asOwner);
			myAddIcon		    = (HTMLImg) myConstruct.GetHTMLElement();
			myAddIcon.SetAlt("");
			myAddIcon.SetAlign("absmiddle");

			// Add icon
			myConstruct     = UIConstructFactory.GetConstruct(((IExpListModelRO) m_model).GetAddIcon(),
					true, this.m_asOwner);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt("");
			myImage.SetAlign("absmiddle");

			//myAnchor = new HTMLAnchor("postToSelf('"	// 	: removed 'Javascript:' from function name
			//	+ ((IExpListModelRO)m_model).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD) + "');");
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.SetOnClick("OpenPopUp(); return false;");

			myAnchor.AddInnerHTMLElement(myAddIcon);
			myAnchor.AddInnerHTMLElement(myImage);
			mySpan = new HTMLSpan();
			myAnchor.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

			// Add label
			mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLElement(myAnchor);
			myCell.AddInnerHTMLString(SPACE);

			return myCell;
		}
		catch (HTMLException e)
		{
			
				log.Error("AutomationServerListView::" + e.getMessage());
			
		}
		catch (Exception e)
		{
			
				log.Error("AutomationServerListView::" + e.getMessage());
			
		}

		return null;
	}

	/**
	 * Helper method to get the HTML for the icon.
	 * (Each row has an icon before the input text.)
	 *
	 * @return HTMLImg
	 * @throws Exception
	 */
	protected HTMLImg GetHTMLForIcon(PTImageType _imgRowIcon)

	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct     = UIConstructFactory.GetConstruct(_imgRowIcon, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		return (myImage);
	}
}

