package com.plumtree.portalpages.admin.ptutilities.automationserver;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This class keeps an up-to-date state of all the settings.
 *
 * It contains the set and get methods for those settings.
 *
 * It contains the start, save and finish methods.
 *
 * This class is used by the Section MainView (to get the
 * latest value of the settings to display) and by the
 * Control MainRepostControl (to perform the repost actions).
 *
 * @author SudhaS
 */

public class AutomationServerModel extends EditorModel
	implements IAutomationServerModelRO
{
	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "AutomationServer";

	protected String m_strServerName    = "";
	protected String m_strServerNetAddr = "";
	protected XPDateTime m_dtDeleteDate = null;
	protected XPDateTime m_dtFromDate   = null;
	protected XPDateTime m_dtToDate     = null;
	protected boolean m_bFromPopUp	    = false;

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(
						PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}
		
		InitializeAutomationServerList();

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AutomationServerModel();
	}

	/**
	 * Executes when the user returns from the automation server popup
	 */
	public void DoTaskOnComeBackFromPopUp()
	{
		int nServerLookupIndex   = -1;
		IPTSession ptSession     = (IPTSession) m_asOwner.GetUserSession();
		IPTScheduler ptScheduler = ptSession.GetScheduler();

		AutomationServerListModel AutomationServerList = (AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList);

		ptScheduler.RegisterJobServer(m_strServerName, m_strServerNetAddr);

		IPTQueryResult ptqrAutomationServer = ptScheduler.QueryJobServerStatus(
				"*");

		for (int i = 0; i < ptqrAutomationServer.RowCount(); i++)
		{
			//String strTempServerName = (String) ptqrAutomationServer.Item(i, PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
			if (XPStringUtility.CompareIgnoreCase(m_strServerName,
						ptqrAutomationServer.ItemAsString(i, PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME)) == 0)
			{
				nServerLookupIndex = i;

				break;
			}
		}

		Object[] oRow = new Object[AutomationServerListModel.EXPLIST_COL_MAX];

		if (nServerLookupIndex != -1)
		{
			oRow[AutomationServerListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(AutomationServerList.m_nNextIndex);
			AutomationServerList.m_nNextIndex++;
			oRow[AutomationServerListModel.EXPLIST_COL_NAME]		   = ptqrAutomationServer.ItemAsString(nServerLookupIndex,
					PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
			oRow[AutomationServerListModel.EXPLIST_COL_NETADDR]		   = ptqrAutomationServer.ItemAsString(nServerLookupIndex,
					PT_PROPIDS.PT_PROPID_JOBSERVER_NETADDRESS);
			oRow[AutomationServerListModel.EXPLIST_COL_STATUS]		   = new Integer(ptqrAutomationServer.ItemAsInt(nServerLookupIndex, PT_PROPIDS.PT_PROPID_JOBSERVER_STATUS));
			oRow[AutomationServerListModel.EXPLIST_COL_LASTUPDATE]     = ptqrAutomationServer.ItemAsXPDateTime(nServerLookupIndex,
					PT_PROPIDS.PT_PROPID_JOBSERVER_LASTUPDATE);
			AutomationServerList.GetItems().AddRow(oRow);
		}
	}

	/**

	* This method will be called when you come back to the main Editor from a sub Editor.
	*
	*/
	public void DoTaskOnComeBackFromSubEditor()
	{
		((AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList)).DoTaskOnComeBackFromSubEditor();
	}

	/**
	 * Null implementation of parent function
	 */
	public void DoTaskOnDeleteFromDate()
	{
	}

	/**
	 * 
	 */
	public void DoTaskOnShowNewDates()
	{
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		String[] aRowsToDelete = ((AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList)).GetRowsToDelete();

		if (aRowsToDelete != null)
		{
			IPTSession ptSession     = (IPTSession) m_asOwner.GetUserSession();
			IPTScheduler ptScheduler = ptSession.GetScheduler();

			for (int i = 0; i < aRowsToDelete.length; i++)
			{
				ptScheduler.UnregisterJobServer(aRowsToDelete[i]);
			}
		}
	}

	//TODO:SS Get Date as it appears from calendar
	public String GetFromDateAsString()
	{
    XPDateFormat df = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
                                                     /* use portal server time zone */ false);
		return df.Format(m_dtFromDate);
	}

	// ***CHANGE_HERE*** Update the class name below.

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetToDateAsString()
	{
    XPDateFormat df = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
                                                     /* use portal server time zone */ false);
		return df.Format(m_dtToDate);
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public int SaveAutomationServer(XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int n_PageStatus = RepostControl.PAGE_STATUS_VALID;

		String[] data;

		data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NAME);

		if (data != null)
		{
			m_strServerName = data[0];
		}

		if (data == null)
		{
			data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NETADDR);
		}

		if (data != null)
		{
			m_strServerNetAddr = data[0];
		}

		if (_sPageName.equals(JobHistoriesDP.STR_MVC_CLASS_NAME))
		{
			n_PageStatus = ((JobLogModel) m_asOwner.GetModel(JobLogModel.STR_MVC_CLASS_NAME)).SavePage(_sPageName, _htFormData);
		}

		return n_PageStatus;
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public int SavePopUp(XPHashtable _htFormData)
	{
		String[] data;
		IPTSession ptSession     = (IPTSession) m_asOwner.GetUserSession();
		IPTScheduler ptScheduler = ptSession.GetScheduler();

		data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NAME);

		if (data != null)
		{
			m_strServerName = data[0];
		}

		data = (String[]) _htFormData.GetElement(AutomationServerDP.HTMLHIDDEN_POPUP_NETADDR);

		if (data != null)
		{
			m_strServerNetAddr = data[0];
		}

		ptScheduler.RegisterJobServer(m_strServerName, m_strServerNetAddr);

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @param _bComingFromPopup 
	 */
	public void SetFromPopup(boolean _bComingFromPopup)
	{
		m_bFromPopUp = _bComingFromPopup;
	}

	/**
	 * 
	 */
	protected void InitializeAutomationServerList()
	{
		AutomationServerListModel AutomationServerList = (AutomationServerListModel) m_asOwner.GetModel(AutomationServerEditorAS.strStorageAutomationServerList);

		AutomationServerList.InitializeAutomationServerList(m_asOwner.GetString(
				1444, "ptmsgs_portaladminmsgs"),
			
		m_asOwner.GetString(1445, "ptmsgs_portaladminmsgs"),
			
		m_asOwner.GetString(1446, "ptmsgs_portaladminmsgs"),
			
		m_asOwner.GetString(1447, "ptmsgs_portaladminmsgs"),
			PTImageType.ICON_AUTOMATION_SERVER,
			
		m_asOwner.GetString(1448, "ptmsgs_portaladminmsgs"), 1);

		//     Use the method below to set the icon to display on each row before the input text.
		//     (By default there will be no icon.)
		//AutomationServerList.SetRowIcon(PTImageType.ICON_FOLDER_OPEN);
		AutomationServerList.SetRowIcon(PTImageType.ICON_AUTOMATION_SERVER);

		IPTSession ptSession     = (IPTSession) m_asOwner.GetUserSession();
		IPTScheduler ptScheduler = ptSession.GetScheduler();

		IPTQueryResult ptqrAutomationServer = ptScheduler.QueryJobServerStatus(
				"*");

		Object[][] oRows = new Object[ptqrAutomationServer.RowCount()][AutomationServerListModel.EXPLIST_COL_MAX];

		for (int i = 0; i < ptqrAutomationServer.RowCount(); i++)
		{
			oRows[i][AutomationServerListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(AutomationServerList.m_nNextIndex);
			AutomationServerList.m_nNextIndex++;
			oRows[i][AutomationServerListModel.EXPLIST_COL_NAME]		   = ptqrAutomationServer.ItemAsString(i, PT_PROPIDS.PT_PROPID_JOBSERVER_SERVERNAME);
			oRows[i][AutomationServerListModel.EXPLIST_COL_NETADDR]		   = ptqrAutomationServer.ItemAsString(i, PT_PROPIDS.PT_PROPID_JOBSERVER_NETADDRESS);
			oRows[i][AutomationServerListModel.EXPLIST_COL_STATUS]		   = new Integer(ptqrAutomationServer.ItemAsInt(i, PT_PROPIDS.PT_PROPID_JOBSERVER_STATUS));
			oRows[i][AutomationServerListModel.EXPLIST_COL_LASTUPDATE]     = ptqrAutomationServer.ItemAsXPDateTime(i, PT_PROPIDS.PT_PROPID_JOBSERVER_LASTUPDATE);

			//AutomationServerList.AddPropertyToSubSpace();
			//AutomationServerList.AddPropertyToArray();
		}

		//for (int i = 0; i < 3; i++) {
		AutomationServerList.SetDefaultObjects(oRows);

		AutomationServerList.SetEmptyListMessages(m_asOwner.GetString(1449,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(1450, "ptmsgs_portaladminmsgs"));
	}
}

