package com.plumtree.portalpages.admin.ptutilities.automationserver;

// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class displays the Job History page in the Automation Server editor
 *
 * @author JohnH
 */
public class JobHistoriesDP extends EditorDP {
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.automationserver.JobHistoriesDP");

	/***/
	/**
	 */
	public static final String STR_MVC_CLASS_NAME = "JobHistories";

	/**
	 * Displays some HTML after the body tag and before the form tag.
	 * For example this is used by pages using a DHTML calendar to display the div tag.
	 * The function is optional.  If it exists, it will be called by the framework, and
	 * the resulting HTMLElement will be added in the right place.
	 *
	 * @return HTMLElement
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm() 
	{
		//Display the DIV tag required for the Date picker control
		IJobLogModelRO ptROModel = (IJobLogModelRO) m_asOwner.GetModel(JobLogModel.STR_MVC_CLASS_NAME);

		return ptROModel.GetDatePickerControlManager().GetPagePreFormContent();
	}

	/**
	 * Returns the HTML that is placed in the HEAD section of this HTML page.
	 *
	 * @return HTMLElementCollection
	 */
	public HTMLElementCollection DisplayHTMLinHEAD() {
		HTMLElementCollection retVal = new HTMLElementCollection();

		IJobLogModelRO ptROModel = (IJobLogModelRO) m_asOwner.GetModel(JobLogModel.STR_MVC_CLASS_NAME);
		JSDatePickerMgr ptDatePickerMgr = ptROModel.GetDatePickerControlManager();
		retVal.AddInnerHTMLElement(ptDatePickerMgr.GetJSIncludes());

		return retVal;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return (m_asOwner.GetString(1457, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() {
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1658, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		try {
			result.AddInnerHTMLElement(super.PageDisplay());

			HTMLElementCollection views = new HTMLElementCollection();

			views.AddInnerHTMLElement(
				(m_asOwner
					.GetView(HistoryView.STR_MVC_CLASS_NAME))
					.Display());

			//Add menu bar construct here, along with job list
			result.AddInnerHTMLElement(CreateLeftNavBar(views));
		} catch (HTMLException e) {
			log.Error(e, "JobHistoriesDP.");
		}

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(HistoryView.STR_MVC_CLASS_NAME)
				.DisplayJavascript());

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) +
			"opennewwindow.js");

		myScripts.AddInnerHTMLElement(script);

		return myScripts;
	}
}

