package com.plumtree.portalpages.admin.ptutilities.condition;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author DustinA
 *
 */
public class RulesListModel extends SelectPTObjectModel implements IRulesListModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
			"com.plumtree.portalpages.admin.ptutilities.condition.RulesListModel");
	
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "RulesListModel";
	
	/**
	 * Name of Row */
	public static final int EXPLIST_OBJECTID 		= 1;
	/**
	 * Name of Row */
	public static final int EXPLIST_NAME 			= 2;
	/**
	 * Name of Row */
	public static final int EXPLIST_DESCRIPTION 	= 3;
	/**
	 * Action of Row */
	public static final int EXPLIST_ACTIONNAME		= 4;
	/**
	 * Action of Row */
	public static final int EXPLIST_ACTIONVALUE		= 5;
	
	public static final int RULES_PAGINATION_SIZE	= 15;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RulesListModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _arrObjectClassIDs Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeRulesList(String _sSectionTitle,
 			PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs, Object[][] arrExpListColInfo, int _nListKey)
	{
		m_arrObjectClassIDs = _arrObjectClassIDs;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}
		
	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX,
				EXPLIST_OBJECTID,
				EXPLIST_NAME, 
				EXPLIST_DESCRIPTION, 
				EXPLIST_ACTIONNAME,
				EXPLIST_ACTIONVALUE
			};

		// JF- Sort array
		// The growable array will always be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		// DCA - kind of a hack to determine which list is being initialized
		if (SubportalRulesManagerModel.FOLDER_RULES_LIST_KEY == m_nListKey) {
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_NAME;
		} else {
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_SORTEDARRAY_PROPID_INDEX;
		}
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true);
	}
	
	/**
	 * This method will be called when you come back to the main Editor from a sub Editor.
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		String sEditorASName;
		EditorAS myEditorAS;
		ObjEditorModel myObjEditorModel;
		Object[] oNewRow;
		int nClassID, nObjectID;

		// JF- Check if they are any newly created objects
		for (int i = 0; i < m_arrCreateNewInfo.length; i++)
		{
			sEditorASName = (String) m_arrCreateNewInfo[i][CREATE_NEW_COL_ASNAME];

			if (m_asOwner.GetSubSpaceExists(sEditorASName))
			{
				myEditorAS			 = (EditorAS) m_asOwner.GetSubSpace(sEditorASName);
				myObjEditorModel     = (ObjEditorModel) myEditorAS.GetModel(myEditorAS.m_strModelName);

				oNewRow										  = new Object[6];
				oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
				m_nNextIndex++;
				oNewRow[EXPLIST_OBJECTID]		= new Integer(myObjEditorModel.GetObjectID());
				oNewRow[EXPLIST_NAME] 			= myObjEditorModel.GetObjectName();
				oNewRow[EXPLIST_DESCRIPTION] 	= myObjEditorModel.GetObjectDescription();

				int nRuleAction =  ((IPTExpression) myObjEditorModel.GetObject()).GetActionValue();
				IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).
					GetExpressions();
				oNewRow[EXPLIST_ACTIONNAME] 	= ptExpressionManager.GetActionValueName(ActionTypeEnum.SUBPORTAL, nRuleAction);
				oNewRow[EXPLIST_ACTIONVALUE] 	= new Integer(nRuleAction);

				super.GetItems().AddRow(oNewRow);
				SubportalRulesManagerModel spRuleModel = (SubportalRulesManagerModel) 
					m_asOwner.GetModel(SubportalRulesManagerModel.STR_MVC_CLASS_NAME);
				spRuleModel.AddNewlyCreatedObject(new int[] {myObjEditorModel.GetObjectID(), nRuleAction} );
				
				m_asOwner.DeleteSubSpace(sEditorASName);
			}
		}

		// JF- Go through all the existing sub spaces and update the Object name.
		for (int i = 0; i < m_saData.GetCount(); i ++)
		{
			nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
			nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_OBJECTID));
			if (m_asOwner.GetSubSpaceExists(STR_MVC_CLASS_NAME + nClassID + nObjectID))
			{
				try
				{
					EditorAS mySpace = (EditorAS) m_asOwner.GetSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
					myObjEditorModel = (ObjEditorModel) mySpace.GetModel(mySpace.m_strModelName);
					int nRuleAction =  ((IPTExpression) myObjEditorModel.GetObject()).GetActionValue();
					IPTExpressionManager ptExpressionManager = (IPTExpressionManager) ((IPTSession) m_asOwner.GetUserSession()).
						GetExpressions();

					m_saData.SetItem(i, EXPLIST_NAME, myObjEditorModel.GetObjectName());
					m_saData.SetItem(i, EXPLIST_DESCRIPTION, myObjEditorModel.GetObjectDescription());
					m_saData.SetItem(i, EXPLIST_ACTIONNAME, ptExpressionManager.GetActionValueName(ActionTypeEnum.SUBPORTAL, nRuleAction));
					m_saData.SetItem(i, EXPLIST_ACTIONVALUE, new Integer(nRuleAction));
				}
				catch (Exception e)
				{
					log.Warn("Could not retrieve the sub Space with key: " + STR_MVC_CLASS_NAME + nClassID + nObjectID);
				}
			}
			
			nClassID = PT_CLASSIDS.PT_SUBPORTAL_ID;
			nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_ACTIONVALUE));
			if (m_asOwner.GetSubSpaceExists(STR_MVC_CLASS_NAME + nClassID + nObjectID))
			{
				try
				{
					EditorAS mySpace = (EditorAS) m_asOwner.GetSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
					myObjEditorModel = (ObjEditorModel) mySpace.GetModel(mySpace.m_strModelName);
					m_saData.SetItem(i, EXPLIST_ACTIONNAME, myObjEditorModel.GetObjectName());
					
					m_asOwner.DeleteSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
				}
				catch (Exception e)
				{
					log.Warn("Could not retrieve the sub Space with key: " + STR_MVC_CLASS_NAME + nClassID + nObjectID);
				}
			}
			
			nClassID = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
			nObjectID = XPConvert.ToInteger(m_saData.GetItem(i, EXPLIST_OBJECTID));
			if (m_asOwner.GetSubSpaceExists(STR_MVC_CLASS_NAME + nClassID + nObjectID))
			{
				try
				{
					EditorAS mySpace = (EditorAS) m_asOwner.GetSubSpace(STR_MVC_CLASS_NAME + nClassID + nObjectID);
					myObjEditorModel = (ObjEditorModel) mySpace.GetModel(mySpace.m_strModelName);
					m_saData.SetItem(i, EXPLIST_NAME, myObjEditorModel.GetObjectName());
				}
				catch (Exception e)
				{
					log.Warn("Could not retrieve the sub Space with key: " + STR_MVC_CLASS_NAME + nClassID + nObjectID);
				}
			}
		}

	}
	
	/**
	 * Returns the icon to display on each row before the
	 * input text.
	 * If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgDefaultRowIcon;
	}
	
	/**
	 *
	 * @param _bEnableMoveRowActions
	 */
	public void SetEnableMoveRowActions(boolean _bEnableMoveRowActions)
	{
		super.SetEnableMoveRowActions(_bEnableMoveRowActions);
		// change back to span 1 column
		m_arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN] = "1";
	}
	
	/**
	 * Returns the URL to edit the object.
	 *
	 * @param _nClassID
	 * @param _nObjectID
	 * @param _sEditorASName
	 *
	 * @return ASURL URL to the Editor
	 */
	public ASURL GetEditObjectURL(int _nClassID, int _nObjectID, String sEditorASName)
	{
		ASURL myURL = new ASURL(m_asOwner);

		// JF- For any Object in the list, the sub space key will be 
		// this Model name with the object class id and the object id.
		String sSubEditorKey = STR_MVC_CLASS_NAME + _nClassID + _nObjectID;

		if (m_asOwner.GetSubSpaceExists(sSubEditorKey))
		{
			EditorAS mySubEditor = (EditorAS) m_asOwner.GetSubSpace(sSubEditorKey);
			myURL.SetLinkGetCachedSpace(mySubEditor);
		}
		else
		{
			
			myURL.SetLinkCreateNewSpace(sEditorASName, m_asOwner);
			myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			myURL.SetSubSpaceKey(sSubEditorKey);
			myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(_nClassID));
			myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
				XPConvert.ToString(_nObjectID));
		}

		return myURL;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.form.pagination.IPaginationModelRO#GetPaginationSize()
	 */	
	public int GetPaginationSize()
	{
		return RULES_PAGINATION_SIZE;
	}

}

