package com.plumtree.portalpages.admin.ptutilities.condition;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.adminfolder.*;
import com.plumtree.portalpages.admin.editors.condition.*;
import com.plumtree.portalpages.admin.editors.subportal.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author DustinA
 */
public class RulesListView extends SelectPTObjectView
{
	
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "RulesListView";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RulesListView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// do not show rank if we're on the folder rules page
		if (m_asOwner.GetCurrentPage().GetName() != SubportalRulesManagerFolderDP.STR_MVC_CLASS_NAME) {
			result.AddInnerHTMLElement(GetHTMLForRankColumn(_saData, _nRowIndex));
		}
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
		result.AddInnerHTMLElement(GetHTMLForActionColumn(_saData, _nRowIndex));
		// only show arrows if we're on the subportal rules page
		if (m_asOwner.GetCurrentPage().GetName() == SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME) {
			result.AddInnerHTMLElement(GetHTMLForMoveRowActions(_nRowIndex));
		}
		
		return result;
	}
	
	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForRankColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetAlign(CommonHTMLStrings.CENTER);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		myCell.AddInnerHTMLString(XPConvert.ToString(_nRowIndex+1));

		return myCell;
	}
			
	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForNameColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		
		Object objID = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_OBJECTID);
		Object objName = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_NAME);
		Object objDescription = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_DESCRIPTION);
		
		// only show name as editable if we're on the subportal rules page
		if (m_asOwner.GetCurrentPage().GetName() != SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME) {
			int nClassID;
			String strASName;
			if (m_asOwner.GetCurrentPage().GetName() == SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME) {
				nClassID = PT_CLASSIDS.PT_EXPRESSION_ID;
				strASName = RuleEditorAS.STR_MVC_CLASS_NAME;
			} else {
				nClassID = PT_CLASSIDS.PT_ADMIN_FOLDER_ID;
				strASName = AdminFolderEditorAS.STR_MVC_CLASS_NAME;
			}
			ASURL asEditURL = ((IRulesListModelRO) m_model).GetEditObjectURL(nClassID, 
				XPConvert.ToInteger(objID), strASName);
					
			HTMLAnchor myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
			myAnchor.SetOnClick(((IRulesListModelRO) m_model).GetUniqueString("EditObject") +
				"('" + asEditURL.GetURLAsString() + "'," + _nRowIndex + ")");
			myAnchor.AddInnerHTMLEncodedString(XPConvert.ToString(objName));
			myCell.AddInnerHTMLElement(myAnchor);
		} else {
			myCell.AddInnerHTMLEncodedString(XPConvert.ToString(objName));
		}
		
		myCell.AddInnerHTMLElement(new HTMLBr());
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLEncodedString((String) objDescription);
		return myCell;
	}
	
	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForActionColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLTableCell myCell;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		Object objActionID = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_ACTIONVALUE);
		Object objActionName = _saData.GetItem(_nRowIndex, RulesListModel.EXPLIST_ACTIONNAME);
		
		// only show action as editable if we're on the subportal rules page
		if (m_asOwner.GetCurrentPage().GetName() != SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME) {
		    if (null == objActionName) {
		        myCell.AddInnerHTMLString(m_asOwner.GetString(2853, "ptmsgs_portaladminmsgs"));
		    } else {
				ASURL asEditURL = ((IRulesListModelRO) m_model).GetEditObjectURL(PT_CLASSIDS.PT_SUBPORTAL_ID, 
					XPConvert.ToInteger(objActionID), SubPortalAS.STR_MVC_CLASS_NAME);
				
				HTMLAnchor myAnchor = new HTMLAnchor(CommonHTMLStrings.POUND_SYMBOL);
				myAnchor.SetOnClick(((IRulesListModelRO) m_model).GetUniqueString("EditObject") +
					"('" + asEditURL.GetURLAsString() + "'," + _nRowIndex + ")");
				myAnchor.AddInnerHTMLEncodedString(XPConvert.ToString(objActionName));
				myCell.AddInnerHTMLElement(myAnchor);
		    }
		} else {
			myCell.AddInnerHTMLEncodedString(XPConvert.ToString(objActionName));
		}

		return myCell;
	}
	
	/**
	 * Returns the HTML for the checkbox on row _nRowIndex.
	 *
	 * @param _nRowIndex
	 * @return HTMLTableCell
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)
	{
		HTMLTableCell myCell;
		HTMLInput myInput;

		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetAlign("center");
		myCell.SetVAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		// checkbox
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				((IRulesListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DELROW),
				((IRulesListModelRO) m_model).GetDeleteIconAlt());
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetValue(XPConvert.ToString(_nRowIndex));
		myCell.AddInnerHTMLElement(myInput);

		return (myCell);
	}

}

