package com.plumtree.portalpages.admin.ptutilities.condition;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 *
 *
 */
public class SubportalRulesManagerAS extends EditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.condition.SubportalRulesManagerAS");

	public static final String STR_MVC_CLASS_NAME = "SubportalRulesManagerAS";
	
	public static final String SUBPORTAL_RULES_LIST = "SubportalRulesList";
	public static final String GUEST_RULES_LIST = "GuestRulesList";
	public static final String FOLDER_RULES_LIST = "FolderRulesList";

	private static final String sClassName = "com.plumtree.portalpages.admin.editors.condition.SubportalRulesManagerAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SubportalRulesManagerAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 */
	public String GetEditorTitle()
	{
		return GetString(2863, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}


	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SubportalRulesManagerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
	    super.SetCurrentPage( page );

	    String sPageName = page.GetName();

	    if( SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
	    {
	        this.SetHelpTopic( "PT_SubportalRulesManager_SubportalRules" );
	    } 
	    else if( SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME.equals( sPageName ))
	    {
	        this.SetHelpTopic( "PT_SubportalRulesManager_GuestLoginRules" );
	    } 
	    else if( SubportalRulesManagerFolderDP.STR_MVC_CLASS_NAME.equals( sPageName ))
	    {
	        this.SetHelpTopic( "PT_SubportalRulesManager_FolderRules" );
	    }
	}


	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = SubportalRulesManagerModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Main DP
		SubportalRulesManagerMainDP smMainDP = new SubportalRulesManagerMainDP();
		// Register DisplayPages
		RegisterPage(smMainDP);
		
		// Guest Rules DP
		SubportalRulesManagerGuestDP smGuestDP = new SubportalRulesManagerGuestDP();
		// Register DisplayPages
		RegisterPage(smGuestDP);
		
		// Folder Rules DP
		SubportalRulesManagerFolderDP smFolderDP = new SubportalRulesManagerFolderDP();
		// Register DisplayPages
		RegisterPage(smFolderDP);

		// Register Subportal Rules Expandable List
		RegisterModel(RulesListModel.STR_MVC_CLASS_NAME, SUBPORTAL_RULES_LIST);
		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel rulesListModel = GetModel(SUBPORTAL_RULES_LIST);
		RegisterView(RulesListView.STR_MVC_CLASS_NAME, SUBPORTAL_RULES_LIST, rulesListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, SUBPORTAL_RULES_LIST, rulesListModel);
		
		// Register Guest Rules Expandable List
		RegisterModel(RulesListModel.STR_MVC_CLASS_NAME, GUEST_RULES_LIST);
		// Get back the Model we just registered because we need it to register the Section and the Control
		rulesListModel = GetModel(GUEST_RULES_LIST);
		RegisterView(RulesListView.STR_MVC_CLASS_NAME, GUEST_RULES_LIST, rulesListModel);
		
		// Register Folder Rules Expandable List
		RegisterModel(RulesListModel.STR_MVC_CLASS_NAME, FOLDER_RULES_LIST);
		// Get back the Model we just registered because we need it to register the Section and the Control
		rulesListModel = GetModel(FOLDER_RULES_LIST);
		RegisterView(RulesListView.STR_MVC_CLASS_NAME, FOLDER_RULES_LIST, rulesListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, FOLDER_RULES_LIST, rulesListModel);

		// Register Controls
		RegisterControl(SubportalRulesManagerRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Default page
		SetCurrentPage(SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(2864, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubportalRulesManagerMainDP.STR_MVC_CLASS_NAME);	
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubportalRulesManagerGuestDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SubportalRulesManagerFolderDP.STR_MVC_CLASS_NAME);

	}
}

