package com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 * Credential Vault Manager Utility.  
 * Allows admins to manage lockboxes.
 *  
 */
public class CredentialVaultManagerAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager.CredentialVaultManagerAS");

	public static final String STR_MVC_CLASS_NAME = "CredentialVaultManager";
	
	public static final String strLockboxList = "LockboxList";

	private static final String sClassName = "com.plumtree.portalpages.admin.ptutilities.credentialvault.CredentialVaultManagerAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CredentialVaultManagerAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		// Credential Vault Manager
		return (GetString(2900, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	
	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (CredentialVaultManagerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo().CheckCurrentUserIsAdmin())
		{
			return false;
		}

		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = CredentialVaultManagerModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(CredentialVaultManagerModel.STR_MVC_CLASS_NAME);

		RegisterPage(new CredentialVaultManagerMainDP());

		RegisterControl(CredentialVaultManagerRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		SetCurrentPage(CredentialVaultManagerMainDP.STR_MVC_CLASS_NAME);

		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1351,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CredentialVaultManagerMainDP.STR_MVC_CLASS_NAME);

		RegisterModel(LockboxListModel.STR_MVC_CLASS_NAME, strLockboxList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myLockboxListModel = GetModel(strLockboxList);
		RegisterView(LockboxListView.STR_MVC_CLASS_NAME,
			strLockboxList, myLockboxListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strLockboxList, myLockboxListModel);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				
				tm.SetGeneratingClass( sClassName );
				

				int iTitleId = 151;
				int iTipId = 152;
				int iSecondaryTipId = 153;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}									
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}
	
	/**
	 * Set the help page for this editor. 
	 *
	 * @param page 
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);
	
		String sPageName = page.GetName();
	
		if (CredentialVaultManagerMainDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_CredentialVaultManager");
		}	
	}
}

