package com.plumtree.portalpages.admin.ptutilities.credentialvaultmanager;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.lockbox.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * 
 * @author jennifersu
 *
 * Helper model that manages the expandable list of Lockboxes.
 */
public class LockboxListModel extends ExpListModel
	implements ILockboxListModelRO
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "LockboxList";

	public static final String LOCKBOX_ROW = "lockboxRow";
	
	/**
	 * Number total of columns
	 */
	public static final int EXPLIST_COL_MAX = 4;

	/**
	 * This column contains the Object Class IDs.
	 */
	public static final int EXPLIST_COL_ID = 1;

	/**
	 * This column contains the Object IDs.
	 */
	public static final int EXPLIST_COL_NAME = 2;

	/**
	 * This is the String that we doisplay in the list.
	 * E.g.: Object name or folder path.
	 */
	public static final int EXPLIST_COL_DESCRIPTION = 3;
	
	/**
	 * Second column: the value of the input text. */
	public static final int EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT = 1;

	/**
	 * Icon to display on each row, just before the input text. */
	protected PTImageType m_imgRowIcon;

	/**
	 * This is used on add to populate the input
	 * text of the newly added row.
	 */
	protected String m_sDefaultValue = "";
	
	/**
	 * array of row IDs that need to be deleted
	 */
	public int[] m_aRowsToDelete = null;

	/**
	 * Adds one row at the bottom of the list and
	 * sets the following values:
	 * First column: m_nNextIndex
	 * Second column: m_sDefaultValue
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		boolean bCanAddNewRow = true;

		// JF- Before we add a new row at the end of the list, we check 
		// if you don't already have a "new row" in the list.
		// The user doesn't need to have more than one empty row (or row with the default value).
		// JF- Check the array see if we have the default value in it.
		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			if (m_sDefaultValue.equals(m_saData.GetItem(i,
							EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT)))
			{
				// JF- We already have a new row no need to add one more.
				bCanAddNewRow = false;

				break;
			}
		}

		if (bCanAddNewRow)
		{
			AddRowsToList(new String[] { m_sDefaultValue });
		}
	}

	/**
	 * Adds an array of new rows to the list.
	 *
	 * @param _aData
	 */
	public void AddRowsToList(String[] _aData)
	{
		Object[] oRow;

		for (int i = 0; i < _aData.length; i++)
		{
			oRow									   = new Object[EXPLIST_COL_MAX];
			oRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
			m_nNextIndex++;
			oRow[EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT] = _aData[i];
			super.GetItems().AddRow(oRow);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LockboxListModel();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public void DeleteRowsOnRepost(XPHashtable _htFormData)
	{
		int[] aRowsToDelete;

		if (!m_bIsReadOnly)
		{
			String sDataKey = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);

			// JF- We get back the list of index of rows to delete.
			if (_htFormData.ContainsKey(sDataKey))
			{
				aRowsToDelete = GetArrayOfObjToDelete(_htFormData);

				// JF- We can only delete rows if the array is not empty
				if (m_saData.GetCount() > 0)
				{
					m_aRowsToDelete = new int[aRowsToDelete.length];

					for (int i = 0; i < aRowsToDelete.length; i++)
					{
						m_aRowsToDelete[i] = XPConvert.ToInteger(m_saData.GetItem(aRowsToDelete[i],
								EXPLIST_COL_ID));
					}

					m_saData.RemoveRows(aRowsToDelete);
				}
			}
		}
	}


	/**
	 * This method will be called when you come back to the main Editor from a sub Editor.
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		LockboxEditorAS myLockboxEditorAS;
		LockboxEditorModel myLockboxEditorModel;
		Object[] oNewRow;
		int nLockboxID;

		String strSubEditorASName = LockboxEditorAS.STR_MVC_CLASS_NAME;


		if (m_asOwner.GetSubSpaceExists(strSubEditorASName))
		{
			myLockboxEditorAS = (LockboxEditorAS) m_asOwner.GetSubSpace(strSubEditorASName);
			myLockboxEditorModel = (LockboxEditorModel) myLockboxEditorAS.GetModel(myLockboxEditorAS.m_strModelName);
			if (myLockboxEditorModel.IsNewLockbox()) {
				oNewRow										  = new Object[EXPLIST_COL_MAX];
				oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
				m_nNextIndex++;
				nLockboxID							 = myLockboxEditorModel.GetObjectID();
				oNewRow[EXPLIST_COL_ID]				 = new Integer(nLockboxID);
				oNewRow[EXPLIST_COL_NAME]			 = myLockboxEditorModel.GetObjectName();
				oNewRow[EXPLIST_COL_DESCRIPTION]     = myLockboxEditorModel.GetObjectDescription();

				super.GetItems().AddRow(oNewRow);
				
			} else {
				int nRow = myLockboxEditorModel.GetRow();
				
				super.GetItems().SetItem(nRow, EXPLIST_COL_NAME, myLockboxEditorModel.GetObjectName());
				super.GetItems().SetItem(nRow, EXPLIST_COL_DESCRIPTION, myLockboxEditorModel.GetObjectDescription());
			
			}

			m_asOwner.DeleteSubSpace(strSubEditorASName);

			myLockboxEditorModel.ResetInputs();
		}
	}

	/**
	 * Return the ASURL object going to the Lockbox Editor as a sub Editor.
	 *
	 * @param _sSubSpaceKey Key for the sub Editor.
	 * If we are going to a new sub Editor, the key can be null and
	 * we will just pass in the default key. If we are going back to an
	 * existing sub Editor, it should be the sub Editor key.
	 * @return ASURL
	 */
	public ASURL GetASURLToLockbox(String _sSubSpaceKey)
	{
		if (null == _sSubSpaceKey)
		{
			_sSubSpaceKey = LockboxEditorAS.STR_MVC_CLASS_NAME;
		}

		// JF- The helper method below will return the right URL. We don't need to figure out 
		// if it's a cahed sub Editor or no.
		ASURL myPopUpURL = ((EditorAS) m_asOwner).GoToSubEditor(LockboxEditorAS.STR_MVC_CLASS_NAME,
				_sSubSpaceKey, EditorStartControl.EDITOR_START_FLAG_CREATE,
				ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_PROFILESECTION_ID));

		return myPopUpURL;
	}

	/**
	 * Returns the URL to edit the object.
	 *
	 * @param _nClassID
	 * @param _nObjectID
	 * @param _sEditorASName
	 *
	 * @return ASURL URL to the Editor
	 */
	public ASURL GetEditObjectURL(int _nObjectID, String _strObjectName,
		String _strObjectDesc, int _nRow)
	{
		ASURL myURL = new ASURL(m_asOwner);

		String sEditorASName = LockboxEditorAS.STR_MVC_CLASS_NAME;

		myURL.SetLinkCreateNewSpace(sEditorASName, m_asOwner);
		myURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		myURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
		myURL.SetSubSpaceKey(sEditorASName);

		myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID, XPConvert.ToString(PT_CLASSIDS.PT_PROFILESECTION_ID));
		myURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID, XPConvert.ToString(_nObjectID));
		myURL.AddControlArgument(LOCKBOX_ROW, _nRow);

		return myURL;
	}

	/**
	 * This method should ge used by the client to
	 * get back the array of values at the end of
	 * the Editor and store them.
	 *
	 * @return String[]
	 */
	public String[] GetListValues()
	{
		String[] aListValues = new String[m_saData.GetCount()];

		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			aListValues[i] = (String) m_saData.GetItem(i,
					EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		}

		return aListValues;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the icon to display on each row before the
	 * input text.
	 * If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgRowIcon;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int[] GetRowsToDelete()
	{
		return m_aRowsToDelete;
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeLockboxList(String _sSectionTitle,
		String _sSectionSubTitle, PTImageType _imgAddIcon, String _sAddLabel,
		int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[1][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "2";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_ID,
				EXPLIST_COL_NAME, EXPLIST_COL_DESCRIPTION
			};

		// JF- Sort array
		// The growable array will always be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_NAME;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true);
	}

	/**
	* Add the array passed in argument to the list.
	* The array should be created using the EXPLIST_COL
	* constants defined in this class.
	*
	* @param _arrRows Array of rows to add.
	*/
	public void SetDefaultObjects(Object[][] _arrRows)
	{
		super.GetItems().AddRows(_arrRows);
	}

	/**
	 * Sets a new default value.
	 * By default this is an empty string.
	 * This value is used on add to populate the input
	 * text of the newly added row.
	 *
	 * @param _sDefaultValue New value
	 */
	public void SetDefaultValue(String _sDefaultValue)
	{
		m_sDefaultValue = _sDefaultValue;
	}

	/**
	 * Sets the icon to display on each row before the
	 * input text.
	 * By default, no icon is displayed.
	 *
	 * @param _imgRowIcon
	 */
	public void SetRowIcon(PTImageType _imgRowIcon)
	{
		m_imgRowIcon = _imgRowIcon;
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		String sDataKey     = GetUniqueString(LockboxListView.HTMLINPUT_ITEM) +
			_nRowIndex;
		String[] aDataValue;

		// JF- For each input text posted by the form, we get the value back 
		// and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex,
					EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT, aDataValue[0]);
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
}

