package com.plumtree.portalpages.admin.ptutilities.diagnostic;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * This interface describes the components
 * required for a Diagnostic Page in the
 * Server Diagnostic Editor.
 */
public interface IDiagnosticPage
{
	/**
	 * Get an instance of the Display Page for
	 * this Diagnostic Page.
	 * 
	 * This page will be registered automatically.
	 * 
	 * @return EditorDP an instance of the Display
	 * Page for this Diagnostic Page.
	 */
	public abstract EditorDP GetDiagnosticPage();

	/**
	 * Get the name of the EditorHelperRepostControl
	 * to execute when this page is displayed.
	 * 
	 * This control needs to be registered manually
	 * in the IDiagnosticPage.Init() method.
	 * 
	 * @return String The MVC name for the EditorHelperRepostControl
	 * to call for this page.  May be null.
	 */
	public abstract String GetHelperRepostControlName();

	/**
	 * This method should register any necessary
	 * Models, Views, or extra DisplayPages.
	 * 
	 * I.E. _asOwner.RegisterView(), etc...
	 * 
	 * This should not register the main Display Page.
	 * The main Display Page should be returned by
	 * the GetDiagnosticPage() method and will be
	 * registered automatically.
	 */
	public abstract void Init(AActivitySpace _asOwner);

	/**
	 * This method is called every time the user switches
	 * to this particular page.  This method should initialize
	 * or refresh the data on the page.
	 * 
	 * Initializing the data should not be done in the Model.Init()
	 * method, as this is called when entering the page, and running
	 * all tests at once takes too long.
	 */
	public abstract void RunDiagnosticTest(AActivitySpace _asOwner);

	/**
	 * 
	 * @return String The Help Topic for this Diagnostic Page.
	 * Null means to use the generic help page.
	 */
	public abstract String GetHelpTopic();

	/**
	 * This method tells the diagnostic page framework
	 * whether or not to display a tip.
	 * 
	 * @return True implies display a tip.
	 */
	public abstract boolean HasTip();

	/**
	 * 
	 * @return int The tip title ID.  -1 means
	 * no tip.
	 */
	public abstract int GetTipTitleID();

	/**
	 * 
	 * @return int The tip ID.  -1 means
	 * no tip.
	 */
	public abstract int GetTipID();

	/**
	 * 
	 * @return int The secondary tip ID.  -1 means
	 * no tip.
	 */
	public abstract int GetSecondaryTipID();
}
