package com.plumtree.portalpages.admin.ptutilities.diagnostic.adaptivelayouts;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.pages.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This model initializes the Server List with the
 * Remote Hosts.
 * 
 * @author DustinA
 */
public class AdaptiveLayoutsModel implements IModel, IModelRO
{
	private static final String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.adaptivelayouts.AdaptiveLayoutsModel";

	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		sClassName);

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "AdaptiveLayouts";

	// Server types - for SERVER_TYPE column
	public static final int SERVER_TYPE_REMOTE = 0;

	// Used to get the host name part of an url
	public static final String PROTOCOL_SEPARATOR = "://";

	// portlet timeouts for testing the remote hosts.
	public static final int INITIAL_TIMEOUT = 5000;
	public static final int REPEAT_TIMEOUT = 15000;

	protected AActivitySpace m_asOwner;

	protected boolean m_bNeedRefresh = false;

	protected XPHashtable m_htInitialPortletStatus = new XPHashtable();

	/**
	 * This method returns the model to it's original state
	 * before any tests have been run / lists initialized.
	 */
	public void ResetModel()
	{
		m_bNeedRefresh = false;
		m_htInitialPortletStatus = new XPHashtable();
	}

	/**
	 * Helper method to start the Server List.
	 */
	public void StartServerList()
	{
		SortedMetaDataListModel model = (SortedMetaDataListModel)
			m_asOwner.GetModel(AdaptiveLayoutsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		model.InitializeMetaDataList(
			// List Title -- "Remote Hosts"
			m_asOwner.GetString(3100, ResourceConstants.PORTALADMINMSGS),
			new String[] {
				// Server Icon -- "Type"
				m_asOwner.GetString(3090, ResourceConstants.PORTALADMINMSGS),
				// Server Name
				m_asOwner.GetString(3091, ResourceConstants.PORTALADMINMSGS),
				// Status
				m_asOwner.GetString(3092, ResourceConstants.PORTALADMINMSGS),
			},
			// Width -- we use percents for the small columns because otherwise
			// the column header breaks to a new line when the sort icon is added.
			new String[] {
				// Server Type
				"10%",
				// Server Name
				null,
				// Status
				"10%",
			},
			// Sortable
			new Boolean[] {
				// Server Type
				Boolean.TRUE,
				// Server Name
				Boolean.TRUE,
				// Status
				Boolean.TRUE,
			},
			// default sort column -- sort by type
			1,
			// Number of total columns (Visible + Data)
			ServerStatusListView.NUM_COLS,
			// list key
			1);

		PopulateServerList();
	}

	/**
	 * Helper method to populate the Server List.
	 */
	public void PopulateServerList()
	{
		SortedMetaDataListModel model = (SortedMetaDataListModel)
			m_asOwner.GetModel(AdaptiveLayoutsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		// Pre populate the list (By default the list will be empty.).
		model.AddRowsToList(GetAdaptiveLayouts());
	}

	/**
	 * Helper method to generate the data for the Adaptive Layouts.
	 * @return Object[][] The Remote Host data.
	 */
	protected Object[][] GetAdaptiveLayouts()
	{
		Object[] oData = null;
		XPArrayList results = new XPArrayList();
		XPArrayList arLayouts = Layouts.GetAllLayouts();
		
		for (int j=0; j<arLayouts.GetSize(); j++) {
			Layouts layout = (Layouts) arLayouts.GetElement(j);
			IPTQueryResult adaptiveLayouts = LayoutService.getChooserInstance().GetAvailableWebServices(layout, m_asOwner);
	
			for(int i=0; i<adaptiveLayouts.RowCount(); i++)
			{
				oData = new Object[ServerStatusListView.NUM_COLS];
				
				String strLayoutName = adaptiveLayouts.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
				int nLayoutId = adaptiveLayouts.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				String strLayoutDesc = adaptiveLayouts.ItemAsString(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
				
				// This method checks the layout status and fills out the relevant
				// parts of the data array for each portlet.
				// I.E. ServerStatusListView.SERVER_STATUS, SERVER_STATUS_MSG, & SERVER_STATUS_ERROR
				SetLayoutStatus(nLayoutId, oData);
	
				// Visible columns
				oData[ServerStatusListView.SERVER_TYPE] = XPConvert.ToString(SERVER_TYPE_REMOTE);
				oData[ServerStatusListView.SERVER_NAME] = strLayoutName;
	
				// SERVER_STATUS already filled out.
	
				// Data only columns
				oData[ServerStatusListView.SERVER_ICON] = PTImageType.ICON_LAYOUT;
				oData[ServerStatusListView.SERVER_ANCHOR] = GetWebServiceAnchor(strLayoutName, nLayoutId);
				oData[ServerStatusListView.SERVER_DESCRIPTION] = strLayoutDesc;
	
				// SERVER_STATUS_MSG and SERVER_STATUS_ERROR already filled out.
				
				results.Add(oData);
			}
		}

		Object[][] retVal = new Object[ServerStatusListView.NUM_COLS][results.GetSize()];
		for(int i=0; i<results.GetSize(); i++)
		{
			Object[] data = (Object[]) results.GetElement(i);
			for (int j=0; j<data.length; j++) {
				retVal[j][i] = data[j];
			}
		}
		
		return retVal;
	}

	private void SetLayoutStatus(int nLayoutId, Object[] data) {
		Object[][] objArrMarkup;
		try
		{
			objArrMarkup = LayoutService.getManagerInstance().GetLayout(nLayoutId, m_asOwner, true);
		} catch (Exception e)
		{
			if( e instanceof PTException )
			{
				// TODO: This switch statement shouldn't be necessary, but
				// some kinds of portlets throw exceptions (gadget_runtime_error)
				// and some use the error reporting array below.
				switch ( ((PTException) e).GetErrorCode() )
				{
					case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
					{
						// Portlet timed out, might just be slow
						data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_RED);
						// "Timeout"
						data[ServerStatusListView.SERVER_STATUS_MSG] =
							m_asOwner.GetString(3104, ResourceConstants.PORTALADMINMSGS);

						break;
					}

					case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
					{
						// Portlet had a runtime error
						// This could be because the machine is down
						data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_RED);

						break;
					}

					case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
					{
						// Portlet had an HTTP error
						// This could be because the machine is down
						data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_RED);

						break;
					}

					case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
					{
						// We display disabled WebServices for info purposes.
						data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
						// "Disabled"
						data[ServerStatusListView.SERVER_STATUS_MSG] =
							m_asOwner.GetString(3105, ResourceConstants.PORTALADMINMSGS);
						break;
					}

					default:
					{
						// Inconclusive
						data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
					}
				}
			} else
			{
				// Inconclusive
				data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
			}

			objArrMarkup = null;
		}

		if (objArrMarkup != null)
		{
			if (objArrMarkup.length == PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_NUM_COLS)
			{
				if (!GatewayUtils.IsErrorContentArray(objArrMarkup))
				{
					data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_GREEN);
				} else {
					int iErrorCode = GatewayUtils.GetErrorCode(objArrMarkup);

					// TODO: Do we need to check this?
					// if the response was received, need to make room in the array for response status, header, body
//					boolean bResponseReceived = GatewayUtils.ResponseReceivedForErrors(objArrMarkup);

					switch (iErrorCode)
					{
						case PT_RESULTCODES.PT_E_GADGET_TIMEOUT:
						{
							// Portlet timed out, might just be slow
							data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
							// "Timeout"
							data[ServerStatusListView.SERVER_STATUS_MSG] =
								m_asOwner.GetString(3104, ResourceConstants.PORTALADMINMSGS);

							break;
						}

						case PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR:
						{
							// Portlet had a runtime error
							// This could be because the machine is down
							data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_RED);

							String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
							if (strStatus != null)
							{
								// "HTTP {0} error"
								data[ServerStatusListView.SERVER_STATUS_MSG] =
									XPResourceManager.FormatMessage(
										m_asOwner.GetString(3106, ResourceConstants.PORTALADMINMSGS),
										strStatus);
							}

							String strError = GatewayUtils.GetErrorMessage(objArrMarkup);
							if (null != strError)
							{
								data[ServerStatusListView.SERVER_STATUS_ERROR] = strError;
							}

							break;
						}

						case PT_RESULTCODES.PT_E_GADGET_HTTP_ERROR_CODE:
						{
							// Portlet had an http error
							// This could be because the machine is down
							data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_RED);

							String strStatus = GatewayUtils.GetResponseStatus(objArrMarkup);
							if (strStatus != null)
							{
								// "HTTP {0} error"
								data[ServerStatusListView.SERVER_STATUS_MSG] =
									XPResourceManager.FormatMessage(
										m_asOwner.GetString(3106, ResourceConstants.PORTALADMINMSGS),
										strStatus); 
							}

							String strError = GatewayUtils.GetErrorMessage(objArrMarkup);
							if (null != strError)
							{
								data[ServerStatusListView.SERVER_STATUS_ERROR] = strError;
							}

							break;
						}

						case PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED:
						{
							// We display disabled WebServices for info purposes.
							data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
							// "Disabled"
							data[ServerStatusListView.SERVER_STATUS_MSG] =
								m_asOwner.GetString(3105, ResourceConstants.PORTALADMINMSGS);
							break;
						}

						default:
						{
							// Inconclusive
							data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
							break;
						}
					}
				}
			} else {
				// Nothing in the markup
				// TODO: what does this mean?
				data[ServerStatusListView.SERVER_STATUS] = XPConvert.ToString(ServerStatusListView.STATUS_YELLOW);
			}
		}
	}
	
	/**
	 * Helper method that creates an HTML Anchor to a pop-up
	 * page viewing remote host details.
	 * 
	 * @param _strName The name of the server.
	 * @return HTMLAnchor The HTML Anchor.
	 */
	protected HTMLAnchor GetWebServiceAnchor(String _strName, int _nWebServiceID)
	{
		String strWebServiceURL = PTOpenerLinks.GetOpenerURLOpenObjID
			(PT_CLASSIDS.PT_WEBSERVICE_ID, _nWebServiceID,
			IPTOpenerConstants.OPENER_MODE_EDIT, m_asOwner);
		
		HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("window.open('" + strWebServiceURL +
			"','PopUpAdaptiveLayout','location=no,menubar=no, scrollbars=yes, height=600,width=800'); return false;");
		myAnchor.AddInnerHTMLEncodedString(_strName);
		myAnchor.SetTitle(_strName);

		return myAnchor;
	}

	/**
	 * This method returns whether or not the results page needs refreshing
	 * because a host had connection problems.
	 * 
	 * @return True implies that the results page needs to be refreshed.
	 */
	public boolean GetNeedsRefresh()
	{
		return m_bNeedRefresh;
	}

	/**
	 * This method sets whether or not the results page needs refreshing
	 * because a host had connection problems.
	 * 
	 * @param _bNeedsRefresh True implies that the results page needs to
	 * be refreshed.
	 */
	public void SetNeedsRefresh(boolean _bNeedsRefresh)
	{
		m_bNeedRefresh = _bNeedsRefresh;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AdaptiveLayoutsModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}