package com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads;

import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This page handles displaying the status of the various
 * dynamic loads in the portal.
 * 
 * @author DonH
 */
public class DynamicLoadsDP extends EditorDP
{
	public static final String STR_MVC_CLASS_NAME = "CustomObjectsDiagnostic";

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()
	 */
	public String GetLeftNavString()
	{
		// "Dynamic Loads"
		return m_asOwner.GetString(3072, ResourceConstants.PORTALADMINMSGS);
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		// Summary of the dynamically loaded UI objects currently loaded in the Portal.
		// The Custom Objects section only contains custom objects, not standard objects that come with the Portal.
		// The Dynamic Loads section contains both custom and standard objects.
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(3073, ResourceConstants.PORTALADMINMSGS),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for this Page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(m_asOwner.GetView(DynamicLoadsView.STR_MVC_CLASS_NAME).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// Display JavaScript for the PEIView
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
		DynamicLoadsView.STR_MVC_CLASS_NAME).DisplayJavascript());

		return myScripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}