package com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.pei;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This View displays a list of the currently loaded PEIs.
 * 
 * @author DonH
 */
public class PEIView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.diagnostic.dynamicloads.pei.PEIView");

	public static final String STR_MVC_CLASS_NAME = "PEI";

	protected AActivitySpace m_asOwner = null;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		return GetHTMLForApplicationSection(m_asOwner, true);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * Helper method to return the HTML for the Application section.
	 * 
	 * This is also used in the HTTPMemoryDebug page.
	 * 
	 * @return HTMLElement
	 */
	public static HTMLElement GetHTMLForApplicationSection(AActivitySpace _asOwner, boolean _bOnlyDisplayPEIs) 
	{
		HTMLElement myResult = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLB myBold;

		myTable = new HTMLTable();
		myResult.AddInnerHTMLElement(myTable);
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		myRow.AddInnerHTMLElement(myCell);
		myBold = new HTMLB();
		myCell.AddInnerHTMLElement(myBold);
		myBold.AddInnerHTMLString(_asOwner.GetString(1969, "ptmsgs_portaladminmsgs"));

		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		myRow.AddInnerHTMLElement(myCell);
		myBold = new HTMLB();
		myCell.AddInnerHTMLElement(myBold);
		myBold.AddInnerHTMLString(_asOwner.GetString(1970, "ptmsgs_portaladminmsgs"));
	
		myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		myRow.AddInnerHTMLElement(myCell);
		myBold = new HTMLB();
		myCell.AddInnerHTMLElement(myBold);
		myBold.AddInnerHTMLString(_asOwner.GetString(1971, "ptmsgs_portaladminmsgs"));

		CachingManager cache = _asOwner.GetApplication().GetCachingManager();
		IXPEnumerator cKeys = cache.GetKeys();
		int nIndex = 0;
		int nDisplayIndex = 1;
		String sKey = null;
		Object oVal = null;

		while (cKeys.MoveNext())
		{
			try
			{
				sKey = (String) cKeys.GetCurrent();

				if ((XPStringUtility.EndsWith(sKey, "Actions")) ||
					(!_bOnlyDisplayPEIs))
				{
					oVal = cache.GetEntry(sKey);

					myRow = new HTMLTableRow();
					myTable.AddInnerHTMLElement(myRow);

					myCell = new HTMLTableCell();
					myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myRow.AddInnerHTMLElement(myCell);
					myCell.AddInnerHTMLString(XPConvert.ToString(nDisplayIndex));

					myCell = new HTMLTableCell();
					myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myRow.AddInnerHTMLElement(myCell);
					myCell.AddInnerHTMLEncodedString(sKey);

					myCell = new HTMLTableCell();
					myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myRow.AddInnerHTMLElement(myCell);

					if (XPStringUtility.EndsWith(sKey, "Actions"))
					{
						Object[] arrPEIs = (Object[]) oVal;

						if (0 != arrPEIs.length)
						{
							for (int k = 0; k < arrPEIs.length; k ++)
							{
								myCell.AddInnerHTMLEncodedString(XPConvert.ToString(arrPEIs[k]));
								myCell.AddInnerHTMLElement(new HTMLBr());
							}
						}
						else
						{
							myCell.AddInnerHTMLEncodedString(_asOwner.GetString(2677, "ptmsgs_portaladminmsgs"));
						}

						nDisplayIndex++;
					}
					else
					{
						myCell.AddInnerHTMLEncodedString(XPConvert.ToString(oVal));

						if (!_bOnlyDisplayPEIs)
						{
							nDisplayIndex++;
						}
					}
				}
			}
			catch (Exception e)
			{
				log.Error(e, "Unexpected exception when displaying application item " + sKey);
			}

			nIndex ++;
		}

		return myResult;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner = parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PEIView();
	}
}