package com.plumtree.portalpages.admin.ptutilities.diagnostic.pages;

import com.plumtree.portalpages.admin.ptutilities.diagnostic.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.adaptivelayouts.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata.*;

/**
 * This page displays the status of remote hosts
 * that supply the portal with content
 * (i.e. Portlet WebServices).
 * 
 * @author DustinA
 */
public class AdaptiveLayoutsPage implements IDiagnosticPage
{
	public static final String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "AdaptiveLayoutsList";

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetDiagnosticPage()
	 */
	public EditorDP GetDiagnosticPage()
	{
		return new AdaptiveLayoutsListDP();
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelperRepostControlName()
	 */
	public String GetHelperRepostControlName()
	{
		return STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace _asOwner)
	{
		// The base model for the Diagnostic Page
		_asOwner.RegisterModel(AdaptiveLayoutsModel.STR_MVC_CLASS_NAME);

		// Register the View, Control, and the Model used by the multi column array.		
		_asOwner.RegisterModel(SortedMetaDataListModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myListModel = _asOwner.GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
		_asOwner.RegisterView(RefreshServerStatusListView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
		_asOwner.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#RunDiagnosticTest(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void RunDiagnosticTest(AActivitySpace _asOwner)
	{
		AdaptiveLayoutsModel model = (AdaptiveLayoutsModel)
			_asOwner.GetModel(AdaptiveLayoutsModel.STR_MVC_CLASS_NAME);

		// Reset to good state
		model.ResetModel();

		model.StartServerList();
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelpTopic()
	 */
	public String GetHelpTopic()
	{
		return "PT_Diagnostic_AdaptiveLayouts";
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#HasTip()
	 */
	public boolean HasTip()
	{
		// This diagnostic page does not have a tip.
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipTitleID()
	 */
	public int GetTipTitleID()
	{
		return 0;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipID()
	 */
	public int GetTipID()
	{
		return 0;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetSecondaryTipID()
	 */
	public int GetSecondaryTipID()
	{
		return 0;
	}
}