package com.plumtree.portalpages.admin.ptutilities.diagnostic.pages;

import com.plumtree.portalpages.admin.ptutilities.diagnostic.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist.*;
import com.plumtree.portalpages.admin.serversettings.search.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata.*;

/**
 * This page displays the status of related servers,
 * such as the Search, Automation, and Collabortion
 * Servers.
 * 
 * @author DonH
 */
public class RelatedServersPage implements IDiagnosticPage
{
	public static final String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "RelatedServerList";

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetDiagnosticPage()
	 */
	public EditorDP GetDiagnosticPage()
	{
		return new RelatedServersListDP();
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelperRepostControlName()
	 */
	public String GetHelperRepostControlName()
	{
		return STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace _asOwner)
	{
		// The base model for the Diagnostic Page
		_asOwner.RegisterModel(RelatedServersModel.STR_MVC_CLASS_NAME);

		// In case this model is used by another diagnostic page
		if (!_asOwner.GetModelExists(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME))
		{
			// Register the model used to access the search servers
			_asOwner.RegisterModel(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME);
		}

		SearchServerSettingsEditorModel searchModel = (SearchServerSettingsEditorModel)
			_asOwner.GetModel(SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME);

		// This normally gets called by the editor framework in
		// CheckEditorAccessAndStart(), but since we are using this
		// model outside of the editor framework, we need to call
		// this manually.
		searchModel.InitializePropertyValues();

		// Register the View, Control, and the Model used by the multi column array.		
		_asOwner.RegisterModel(SortedMetaDataListModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myListModel = _asOwner.GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
		_asOwner.RegisterView(RefreshServerStatusListView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
		_asOwner.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#RunDiagnosticTest(AActivitySpace)
	 */
	public void RunDiagnosticTest(AActivitySpace _asOwner)
	{
		RelatedServersModel model = (RelatedServersModel)
			_asOwner.GetModel(RelatedServersModel.STR_MVC_CLASS_NAME);

		model.StartServerList();
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetHelpTopic()
	 */
	public String GetHelpTopic()
	{
		return "PT_Diagnostic_RelatedServers";
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#HasTip()
	 */
	public boolean HasTip()
	{
		// This diagnostic page does not have a tip.
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipTitleID()
	 */
	public int GetTipTitleID()
	{
		return 0;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetTipID()
	 */
	public int GetTipID()
	{
		return 0;
	}

	/**
	 * @see com.plumtree.portalpages.admin.ptutilities.diagnostic.IDiagnosticPage#GetSecondaryTipID()
	 */
	public int GetSecondaryTipID()
	{
		return 0;
	}
}