package com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers;

import com.plumtree.portalpages.admin.ptutilities.diagnostic.pages.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This page displays the status of related servers,
 * such as the Search, Automation, and Collabortion
 * Servers.
 * 
 * @author DonH
 */
public class RelatedServersListDP extends EditorDP
{
	public static final String STR_MVC_CLASS_NAME = "RelatedServerDiagnostic";

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()
	 */
	public String GetLeftNavString()
	{
		// "Related Servers"
		return m_asOwner.GetString(3088, ResourceConstants.PORTALADMINMSGS);
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		// This page allows you to view and reload the tag libraries for this portal machine.
		// "The current status of Related Servers.  " +
		// "Server status is not updated when sorting.  " +
		// "To update server status, click the Refresh button."
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(3089, ResourceConstants.PORTALADMINMSGS),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for this Page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(m_asOwner.GetView(
			RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// Display JavaScript for the search & auto servers list
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
			RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).DisplayJavascript());

		return myScripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PartialContentDisplay()
	 */
	public HTMLElement PartialContentDisplay()
	{
		return m_asOwner.GetView(RelatedServersPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}