package com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.pages.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This page displays status information for all remote
 * hosts that the Portal gets content from.
 * 
 * @author DonH
 */
public class RemoteHostsListDP extends EditorDP
{
	public static final String STR_MVC_CLASS_NAME = "RemoteHostDiagnostic";

	public static final String JAVASCRIPT_REFRESH = "refresh";
	public static final String REFRESH_ID = "refresharea";

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()
	 */
	public String GetLeftNavString()
	{
		// "Remote Hosts"
		return m_asOwner.GetString(3100, ResourceConstants.PORTALADMINMSGS);
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		// This page allows you to view and reload the tag libraries for this portal machine.
		// "The current status of the Remote Hosts (i.e. Any host that serves a portlet).  " +
		// "Host status is not updated when sorting.  " +
		// "To update host status, click the Refresh button."
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(3101, ResourceConstants.PORTALADMINMSGS),
			this.m_asOwner);
	}

	/**
	 * Returns the HTML for this Page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLDiv refreshDiv = new HTMLDiv();
		refreshDiv.SetID(REFRESH_ID);

		refreshDiv.AddInnerHTMLElement(m_asOwner.GetView(
			RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(refreshDiv));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// Display JavaScript for the remote hosts list
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
			RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).DisplayJavascript());

		RemoteHostsModel model = (RemoteHostsModel) m_asOwner.GetModel(RemoteHostsModel.STR_MVC_CLASS_NAME);

		if (model.GetNeedsRefresh())
		{
			HTMLScript inplaceRefreshScript = new HTMLScript("text/javaScript");
	
			XPStringBuilder sb = new XPStringBuilder(100);
	
			sb.Append("function ").Append(JAVASCRIPT_REFRESH).Append("() {\n");
			sb.Append("  ").Append(InPlaceRefreshHelper.GetJSSendPOSTOnAFormDP(m_asOwner.GetCurrentNormalizedBaseURL(),
				REFRESH_ID, RepostControl.POSTTOSELF_ACTION_IN_PLACE_REFRESH)).Append("\n");
			sb.Append("}\n");
			sb.Append("\n");
			sb.Append("document.PCC.RegisterForWindowEvent(\"onload\", \"")
				.Append(JAVASCRIPT_REFRESH).Append("();\");\n");
	
			inplaceRefreshScript.AddInnerHTMLString(sb.ToString());
	
			myScripts.AddInnerHTMLElement(inplaceRefreshScript);
		}

		return myScripts;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PartialContentDisplay()
	 */
	public HTMLElement PartialContentDisplay()
	{
		// Since we're refreshing, we know we need to generate the host list again.
		RemoteHostsModel model = (RemoteHostsModel) m_asOwner.GetModel(RemoteHostsModel.STR_MVC_CLASS_NAME);

		EditorModel diagPageModel = (EditorModel) m_asOwner.GetModel(DiagnosticPageModel.STR_MVC_CLASS_NAME);

		if (diagPageModel.GetCurrentRepostAction() ==
			RepostControl.POSTTOSELF_ACTION_IN_PLACE_REFRESH)
		{
			// Only refresh the server list if we're requesting
			// an in-place refresh of this page.
			model.StartServerList();
		}

		// reset so we don't keep refreshing.  Only do it once.
		model.SetNeedsRefresh(false);

		return m_asOwner.GetView(
			RemoteHostsPage.STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST).Display();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}