package com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.hostservices;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.relatedservers.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This view displays links to the content or collaboration
 * server diagnostic pages, if the currently displayed remote
 * host is a content or collaboration server host.
 * 
 * @author DonH
 */
public class ContentCollabLinksView implements IView
{
	private static final String sClassName = "com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.hostservices.ContentCollabLinksView";

	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_UI_INFRASTRUCTURE),
		sClassName);

	/**  Name of the view */
	public static final String STR_MVC_CLASS_NAME = "ContentCollabLinks";

	protected HostServicesAS m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// The name of the remote host we are currently displaying.
		String strRemoteHost = m_asOwner.GetHostServicesRemoteHostName();

		String strCollabBaseURL = RemoteHostsModel.GetServerBaseURL(RelatedServersModel.GetCollabServerUUIDFilter(), m_asOwner);

		if (null != strCollabBaseURL)
		{
			String strCollabName = RemoteHostsModel.GetHostName(strCollabBaseURL);

			if (0 == XPStringUtility.Compare(strRemoteHost, strCollabName))
			{
				HTMLElement diagLink = new HTMLElementCollection();
				// "Collaboration Server Diagnostic Page:"
				diagLink.AddInnerHTMLString(m_asOwner.GetString(3112, ResourceConstants.PORTALADMINMSGS));
				diagLink.AddInnerHTMLElement(RelatedServersModel.GetCollabServerAnchor(strCollabName, strCollabBaseURL));

				diagLink = GetSubHeaderNoHelp(diagLink);

				if (null != diagLink)
				{
					result.AddInnerHTMLElement(diagLink);
					result.AddInnerHTMLElement(new HTMLBr());
				}
			}
		}

		String strContentBaseURL = RemoteHostsModel.GetServerBaseURL(RelatedServersModel.GetContentServerUUIDFilter(), m_asOwner);

		if (null != strContentBaseURL)
		{
			String strContentName = RemoteHostsModel.GetHostName(strContentBaseURL);

			if (0 == XPStringUtility.Compare(strRemoteHost, strContentName))
			{
				HTMLElement diagLink = new HTMLElementCollection();
				// "Content Server Diagnostic Page:"
				diagLink.AddInnerHTMLString(m_asOwner.GetString(3113, ResourceConstants.PORTALADMINMSGS));
				diagLink.AddInnerHTMLElement(RelatedServersModel.GetContentServerAnchor(strContentName, strContentBaseURL));

				diagLink = GetSubHeaderNoHelp(diagLink);

				if (null != diagLink)
				{
					result.AddInnerHTMLElement(diagLink);
					result.AddInnerHTMLElement(new HTMLBr());
				}
			}
		}

		return result;
	}

	public static HTMLElement GetSubHeaderNoHelp(HTMLElement _element)
	{
		//	Get the banner, set the title
		PTBannerType myType   = PTBannerType.DIRECTORY_CONTENT;
		PTConstruct construct;

		HTMLElement result;

		try
		{
			construct = UIConstructFactory.GetConstruct(myType);

			//	Set the title on the construct.
			//	ReplaceNestedElementsWithHTMLString() takes an ElementName, and a string.
			//	It finds the element within the construct having the specified ElementName,
			//	and sets the inner html of this element to be the specified element
			construct.ReplaceNestedElementsWithElement(myType.TITLE_ELEMENT_NAME,
				_element);

			result = construct.GetHTMLElement();
		}
		catch (Exception e)
		{
			log.Error(e, "Unable to create subheader.");

			return null;
		}

		return result;
	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(com.plumtree.uiinfrastructure.activityspace.IModelRO, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModelRO _model, AActivitySpace _parent)
	{
		m_asOwner = (HostServicesAS) _parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ContentCollabLinksView();
	}
}