package com.plumtree.portalpages.admin.ptutilities.diagnostic.remotehosts.hostservices;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalpages.admin.ptutilities.diagnostic.serverstatuslist.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.multicolumnlist.sortedmetadata.*;

/**
 * Displays a list of all the portlet web services associated
 * with a given host machine.
 * 
 * @author DonH
 */
public class HostServicesAS extends EditorAS
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "HostServices";

	/** Storage name for the multi column list classes */
	public static final String STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST = "HostServicesList";

	/**
	 * Registers all the classes of the Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = HostServicesModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		// Main Host Services Popup Page
		IDisplayPage popup = new HostServicesPopupDP();
		RegisterPage(popup);

		RegisterView(ContentCollabLinksView.STR_MVC_CLASS_NAME, null);

		// Register the View, Control, and the Model used by the multi column array.		
		RegisterModel(SortedMetaDataListModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myListModel = GetModel(STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST);
		RegisterView(ServerStatusListView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_MULTI_COLUMN_LIST, myListModel);

		HostServicesModel myMainModel = (HostServicesModel)
			GetModel(HostServicesModel.STR_MVC_CLASS_NAME);

		// We have to initialize the list after all list MVC components
		// have been registered.
		myMainModel.StartWebServiceList();

		// Set up the editor framework

		//Sets left nav menu
		// BEGIN Sub menu "Web Services for {0}"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(
			XPResourceManager.FormatMessage(
				GetString(3114, ResourceConstants.PORTALADMINMSGS),
				GetHostServicesRemoteHostName()));

		// Add the link for the main Display Page to the left nav menu
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, popup.GetName());
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String, java.lang.String, boolean)
	 */
	public boolean CheckBasicAccess(
		String strPage,
		String strControl,
		boolean bSameSpace)
	{
		if (!PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession()))
		{
			return false;
		}

		// Check for right to access administration
		return ((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()
	 */
	public String GetEditorTitle()
	{
		// "Web Services for {0}"
		return XPResourceManager.FormatMessage(
			GetString(3114, ResourceConstants.PORTALADMINMSGS),
			GetHostServicesRemoteHostName());
	}

	/**
	 * This helper method gets the name of the
	 * remote host that this page is displaying
	 * the webservices from.
	 * 
	 * @return String The remote host name, possible
	 * including port number.
	 */
	public String GetHostServicesRemoteHostName()
	{
		// Note: we pass in the remote host name as the sub space key.  This is
		// not exactly standard behavior, but it's easy to code.  This means
		// we cannot reuse subspaces, because their subspace key will not get
		// updated.
		return GetSubSpaceKey();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetRepostControlName()
	 */
	public String GetRepostControlName()
	{
		return (ExpListControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new HostServicesAS();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}