package com.plumtree.portalpages.admin.ptutilities.jobfolders;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.ptutilities.automationserver.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author SudhaS
 */
public class JobFoldersModel extends EditorModel implements IJobFoldersModelRO
{
	
	public static final String STR_MVC_CLASS_NAME = "JobFoldersModel";
	protected String m_sSetting1;
	protected String m_sSetting2;
	protected String m_strDescription = "";
	protected String m_strServerName  = "";
	protected String m_strURI   = "";
	protected int m_nActivityID = -1;

	/**
	 * Code executed when the Editor is starting.
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		String[] data;
		
		if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckForActivityRight(
						PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		data = (String[]) _htFormData.GetElement(AutomationServerListModel.SERVER_NAME);

		if (data != null)
		{
			m_strServerName = data[0];
		}

		StartJobFoldersList();
		StartGetFolderJobs();

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobFoldersModel();
	}

	/**
	 * 
	 */
	public void Finish()
	{
		PTGrowableSortedArrayWrapper aJobFoldersObjectValues = ((JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME)).GetItems();

		//IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
		//IPTScheduler ptScheduler = ptSession.GetScheduler();
		//IPTQueryResult ptqrJobHistoriesByFolder;
		IPTSession ptSession     = (IPTSession) m_asOwner.GetUserSession();
		IPTScheduler ptScheduler = ptSession.GetScheduler();

		for (int i = 0; i < aJobFoldersObjectValues.GetCount(); i++)
		{
			int n_FolderID = XPConvert.ToInteger(aJobFoldersObjectValues.GetItem(i,
					JobFoldersListModel.EXPLIST_COL_OBJECTID));

			ptScheduler.AssignJobFolder(m_strServerName, n_FolderID);
		}

		int[] aRowsToDelete = ((JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME)).GetRowsToDelete();

		if (aRowsToDelete != null)
		{
			for (int i = 0; i < aRowsToDelete.length; i++)
			{
				ptScheduler.UnassignJobFolder(m_strServerName, aRowsToDelete[i]);
			}
		}

		//ResetInputs();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetActivityDescription()
	{
		return m_strDescription;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetActivityID()
	{
		return m_nActivityID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetActivityURI()
	{
		return m_strURI;
	}

	/** Localized String: Users */
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetServerName()
	{
		return m_strServerName;
	}

	/**
	 * 
	 */
	public void ResetInputs()
	{
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public int SaveMainPage(XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		String[] data;

		data = (String[]) _htFormData.GetElement(AutomationServerListModel.SERVER_NAME);

		if (data != null)
		{
			m_strServerName = data[0];
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 */
	public void StartGetFolderJobs()
	{
		JobFoldersListModel myJobFoldersObjectModel = (JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME);

		myJobFoldersObjectModel.SetEnableMoveRowActions(false);

		//IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
		//IPTScheduler ptScheduler = ptSession.GetScheduler();
		//IPTQueryResult ptqrJobHistoriesByFolder;
		IPTSession ptSession     = (IPTSession) m_asOwner.GetUserSession();
		IPTScheduler ptScheduler = ptSession.GetScheduler();
		IPTAdminCatalog ptCatalog = ptSession.GetAdminCatalog();

		IPTQueryResult ptqrJobFolders = ptScheduler.QueryJobAssignmentsByServer(m_strServerName);
		
		/* get the indices of folder ids that this user can access */
		XPArrayList indices = new XPArrayList(ptqrJobFolders.RowCount());
		for (int i = 0; i < ptqrJobFolders.RowCount(); i++)
		{
			int id = ptqrJobFolders.ItemAsInt(i, PT_PROPIDS.PT_PROPID_FOLDERID);
			if (ptCatalog.IsAdminFolderAccessible(id, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				indices.Add(new Integer(i));
			}
		}

		/* now create rows for each folder */
		Object[][] oRows = new Object[indices.GetSize()][SelectPTObjectModel.EXPLIST_COL_MAX];
		for (int i=0; i<indices.GetSize(); i++)
		{
			int queryIdx = XPConvert.ToInteger(indices.GetElement(i));
			
			oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(myJobFoldersObjectModel.m_nNextIndex);
			myJobFoldersObjectModel.m_nNextIndex++;
			oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	= new Integer(PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
			oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]  = new Integer(ptqrJobFolders.ItemAsInt(queryIdx, PT_PROPIDS.PT_PROPID_FOLDERID));
			oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING]	= ptqrJobFolders.ItemAsString(queryIdx,PT_PROPIDS.PT_PROPID_NAME);
		}

		myJobFoldersObjectModel.SetDefaultObjects(oRows);
	}

	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	public void StartJobFoldersList()
	{
		JobFoldersListModel myJobFoldersObjectModel = (JobFoldersListModel) m_asOwner.GetModel(JobFoldersListModel.STR_MVC_CLASS_NAME);

		// ***CHANGE_HERE SELECTPTOBJECT*** Initialize the Select PTObject list.
		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		myJobFoldersObjectModel.InitializeSelectPTObject(m_strServerName,
			
		m_asOwner.GetString(1507, "ptmsgs_portaladminmsgs"),
			PTImageType.ICON_FOLDER,
			
		m_asOwner.GetString(1508, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_ADMIN_FOLDER_ID }, 2);
			
		myJobFoldersObjectModel.SetTreeTitle(m_asOwner.GetString(2102, "ptmsgs_portaladminmsgs"));
		myJobFoldersObjectModel.SetTreeSubTitle(m_asOwner.GetString(2102, "ptmsgs_portaladminmsgs"));
		myJobFoldersObjectModel.SetTreeLeafType(TreeConstants.N_COMPOSITESELECT);

		// ***CHANGE_HERE SELECTPTOBJECT*** Optional setting
		//     Use the method bellow to set the icon to display on each row.
		//     (By default there will be no icon.)
		myJobFoldersObjectModel.SetDefaultRowIcon(PTImageType.ICON_JOB);

		myJobFoldersObjectModel.SetEmptyListMessages(m_asOwner.GetString(1509,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(1510, "ptmsgs_portaladminmsgs"));

		// JF- The 2 lines below are only needed if you are going to enable the move row actions

		/*
		if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE) {
		    oRows = new Object[1][mySelectPTObjectModel.EXPLIST_COL_MAX];
		    oRows[0][mySelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer( mySelectPTObjectModel.m_nNextIndex );
		    mySelectPTObjectModel.m_nNextIndex ++;
		    oRows[0][mySelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_USERGROUP_ID);
		    oRows[0][mySelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(PT_INTRINSICS.PT_USERGROUP_EVERYONE);
		    oRows[0][mySelectPTObjectModel.EXPLIST_COL_STRING] = new String("Everyone");
		} else if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT) {
		*/

		//}
	}
}

