package com.plumtree.portalpages.admin.ptutilities.localizedstrings;

import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author Don Hayler
 *
 * Models encapsulate the data in the MVC framework.  Views have access to the read
 * only model interface and should only read data from it.  Controls get and set data,
 * and therefore use the base IModel interface.
 *
 * Models should encapsulate the data handling of the AActivitySpace.  Temporary UI
 * data that you want to store for each user should go here.  As an MVC component,
 * Models are subject to the strict separation between data, logic, and presentation.
 *
 * It is a requirement that Models not reference HTMLElements or HTMLConstructs.
 * Models can return text Strings for display in HTML, but they are not allowed to use
 * HTML themselves.
 *
 * It is also a requirement that Models not return server structures to Views.  For
 * instance, rather than returning an IPTQueryResult to a Section, the model should
 * provide accessor methods to it.  Views can use server constants such as
 * PT_PROPIDS.PT_PROPID_NAME.
 *
 * Obviously, there should be a good way to refer to models without having to
 * manually type in a text string.  There should be some sort of package identifier
 * used to get these.
 */
public interface ILocalizedStringsModel extends IModel
{
	/**
	 * Set method for LocalizedStrings data
	 */
	public void SetData(Object[][] arrLocalizedStrings);

	/**
	 * 
	 *
	 * @param arrLangs 
	 */
	public void SetLangs(String[] arrLangs);

	/**
	 * 
	 *
	 * @param sMessage 
	 */
	public void SetUploadMessage(String sMessage);
}

