package com.plumtree.portalpages.admin.ptutilities.localizedstrings;

import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author MichaelS
 */
public class LocalizedStringsAS extends PTEditorAS
{
	/** AS name */
	public static final String STR_MVC_CLASS_NAME = "LocalizedStrings";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LocalizedStringsAS();
	}

	/**
	 * Returns the Editor main title.
	 * It will get printed out in EditorHeaderView.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return GetString(1511, "ptmsgs_portaladminmsgs");
	}

	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	* Returns the name of the repost control class.
	* E.g.: PropRepostControl.GetName()
	*
	* @return String
	*/
	public String GetRepostControlName()
	{
		return LocalizedStringsControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		m_strModelName = LocalizedStringsModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(LocalizedStringsModel.STR_MVC_CLASS_NAME);

		// LocalizedStrings Display Page
		LocalizedStringsDP myPage = new LocalizedStringsDP();
		RegisterPage(myPage);

		//MES- Set multipart encoding so that file uploads work correctly
		myPage.SetMultiPartEncoding(true);

		// LocalizedStringsDownload Display Page
		LocalizedStringsDownloadDP myDownloadPage = new LocalizedStringsDownloadDP();
		RegisterPage(myDownloadPage);

		// LocalizedStrings Control
		RegisterControl(LocalizedStringsControl.STR_MVC_CLASS_NAME, myModel);

		// LocalizedStrings Views
		RegisterView(LocalizedStringsView.STR_MVC_CLASS_NAME, myModel);
		
		// Set default page
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(LocalizedStringsDP.STR_MVC_CLASS_NAME);

		// Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1535,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, LocalizedStringsDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"

	}
	
	
	/**
	* @see com.plumtree.uiinfrastructure.activityspace.
	* AActivitySpace#SetCurrentPage()
	*
	* @param IDisplayPage the current Display Page
	*/
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage( page );

		String sPageName = page.GetName();
    
		if( LocalizedStringsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_LocalizationManager" );
		}
	}
}

