package com.plumtree.portalpages.admin.ptutilities.localizedstrings;

import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Display Pages aggregate Views and put them into an HTMLPage. They are owned
 * by Activity Spaces and represent a view into an MVC framework. Display Pages
 * are allowed to get and set data on the Models, if necessary. Display Pages
 * are viewed as an extension of Activity Spaces, and therefore are not subject
 * to the strict data/logic/presentation separation that MVC components are.
 *
 * @author Don Hayler 
 */
public class LocalizedStringsDP extends EditorDP {
	
	public static final String STR_MVC_CLASS_NAME = "LocalizedStrings";

	/**
	 * MES- See
	 * com.plumtree.uiinfrastructure.editor.EditorDP.GetLeftNavString
	 * @return 
	 */
	public String GetLeftNavString() {
		return m_asOwner.GetString(1515, "ptmsgs_portaladminmsgs");
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1654, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	/**
	 * Localized String: Import and export localized strings
	 * @return 
	 */

	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#PageDisplay()
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		//MES- Add the LocalizedStringsView
		views.AddInnerHTMLElement(
			m_asOwner
				.GetView(LocalizedStringsView.STR_MVC_CLASS_NAME)
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) +
			"opennewwindow.js");

		myScripts.AddInnerHTMLElement(script);
		
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(LocalizedStringsView.STR_MVC_CLASS_NAME).DisplayJavascript());

		return myScripts;
	}

}

