package com.plumtree.portalpages.admin.ptutilities.localizedstrings;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.xml.dom.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author MichaelS
 *
 * MES- This display page returns the complete set of localized strings for a Portal.
 * It returns the strings as XML, rather than HTML, for easy processing by the user (e.g.
 * the user may send the XML file to a translation service.)  Note that this page returns
 * NO HTML, it ONLY returns XML.
 */
public class LocalizedStringsDownloadDP implements IDisplayPage
{
	
	public static final String STR_MVC_CLASS_NAME = "LocalizedStringsDownload";

	/*MES- The following variables define elements in the XML we will return */

	
	public static final String LOC_XML_ROOT_NODE     = "localizationtable";

	
	public static final String LOC_XML_LANGS_NODE    = "languages";

	
	public static final String LOC_XML_SEGMENTS_NODE = "segments";

	
	public static final String LOC_XML_COUNT_ATT    = "count";

	
	public static final String LOC_XML_LANG_NODE    = "language";

	
	public static final String LOC_XML_SEGMENT_NODE = "segment";

	
	public static final String LOC_XML_CLASSID_ATT  = "classid";

	
	public static final String LOC_XML_ITEMID_ATT   = "itemid";

	
	public static final String LOC_XML_STRINGID_ATT = "stringid";

	
	public static final String LOC_XML_SOURCE_NODE = "source";

	
	public static final String LOC_XML_TARGET_NODE = "target";

	
	public static final String LOC_XML_LANG_ATT = "language";
	protected AActivitySpace m_asOwner;

	/**
	 * Construct the HTMLPage for Display.
	 *
	 * @param IWebData The HTMLPage for display to the browser should be set on this object.
	 */
	public void Display(IWebData webData)
	{
		//MES- Get the data from the model
		ILocalizedStringsModelRO model = (ILocalizedStringsModelRO) m_asOwner.GetModel(LocalizedStringsModel.STR_MVC_CLASS_NAME);

		Object objData    = model.GetData();
		String[] arrLangs = model.GetLangs();

		//MES- Convert the data to XML and put into the output
		webData.SetData(ConvertDataToXML(arrLangs, objData));

		//MES- Tell the browser that we're returning XML.
		//MES- TODO: Are these strings available in a centralized place?
		webData.SetHeader("Content-Type", "text/xml; charset=UTF-8");
		webData.SetHeader( "Content-Disposition", "attachment; filename=LocalizedStrings.xml;");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetParent()
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}

	/**
	 * MES- ConvertDataToXML takes in an array of languages and a
	 * 2D array of localized strings (as returned by the IPTStringLocalizationManager
	 * interface), and turns it into an XML string, encoded as UTF8.
	 *
	 * @param arrLangs is a 1D String array of the languages we support
	 * @param objData is a 2D Object array (or null) containing the localized
	 * strings
	 * @return a byte[] containing the relevant XML encoded as UTF8.
	 */
	private byte[] ConvertDataToXML(String[] arrLangs, Object objData)
	{
		//MES- Make a new document
		XPDocument docXML = new XPDocument();

		//MES- Add a root node, from which we'll hang other nodes
		XPElement elemRoot = docXML.CreateElement(LOC_XML_ROOT_NODE);
		docXML.AppendChild(elemRoot);

		//MES- Add two nodes to root- one for our list of languages, and
		//	one for the list of localized strings.  The list of languages
		//	is a convenience to the code that needs to parse this XML- 
		//	it doesn't have to look through all of the string localizations
		//	to get the complete list of supported languages
		XPElement elemLangs   = docXML.CreateElement(LOC_XML_LANGS_NODE);
		XPElement elemStrings = docXML.CreateElement(LOC_XML_SEGMENTS_NODE);
		elemRoot.AppendChild(elemLangs);
		elemRoot.AppendChild(elemStrings);

		//MES- Add the count of languages, for convenience
		elemLangs.SetAttribute(LOC_XML_COUNT_ATT,
			XPConvert.ToString(arrLangs.length));

		//MES- Add all of the languages 
		for (int iLangIndex = 0; iLangIndex < arrLangs.length; iLangIndex++)
		{
			XPElement elemLang = docXML.CreateElement(LOC_XML_LANG_NODE);
			elemLangs.AppendChild(elemLang);

			XPText textLang = docXML.CreateTextNode(arrLangs[iLangIndex]);
			elemLang.AppendChild(textLang);
		}

		//MES- Is there any data?
		if (null != objData)
		{
			Object[][] arrData = (Object[][]) objData;
			int iNumCols	   = arrData.length;
			int iNumRows	   = arrData[0].length;

			//MES- Add the count of strings, for convenience
			elemStrings.SetAttribute(LOC_XML_COUNT_ATT, XPConvert.ToString(iNumRows));

			//MES- Add each string
			for (int iRowIndex = 0; iRowIndex < iNumRows; ++iRowIndex)
			{
				//MES- Make a node for the string, and add the identifying info
				XPElement elemString = docXML.CreateElement(LOC_XML_SEGMENT_NODE);
				elemStrings.AppendChild(elemString);
				elemString.SetAttribute(LOC_XML_CLASSID_ATT,
					XPConvert.ToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_CLASSID][iRowIndex]));
				elemString.SetAttribute(LOC_XML_ITEMID_ATT,
					XPConvert.ToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_ITEMID][iRowIndex]));
				elemString.SetAttribute(LOC_XML_STRINGID_ATT,
					XPConvert.ToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_STRINGID][iRowIndex]));

				//MES- Add a child node for the "source" or primary translation
				XPElement elemSourceString = docXML.CreateElement(LOC_XML_SOURCE_NODE);
				elemString.AppendChild(elemSourceString);

				// TODO CR: Do we need ObToString? Also I removed the .toString() after the arrData array access, since it seems this is redundant.
				String sLang = ObToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_SOURCE_LANG][iRowIndex]);
				elemSourceString.SetAttribute(LOC_XML_LANG_ATT, sLang);

				String sValue			 = ObToString(arrData[PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_SOURCE_STRING][iRowIndex]);
				XPText textPrimaryString = docXML.CreateTextNode(sValue);
				elemSourceString.AppendChild(textPrimaryString);

				//MES- Add a node for each possible localization
				for (int iColIndex = PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_TARGET_STRING_START;
						iColIndex < iNumCols; ++iColIndex)
				{
					XPElement elemLocalization = docXML.CreateElement(LOC_XML_TARGET_NODE);
					elemString.AppendChild(elemLocalization);
					elemLocalization.SetAttribute(LOC_XML_LANG_ATT,
						arrLangs[iColIndex -
						PT_SERIALIZED_LOCALIZED_STRINGS_COLS.PT_SLS_TARGET_STRING_START]);

					//MES- The value is "" if it's not translated to that language,
					//	or the string in that language if it is translated.
					String sLocalizedString = ObToString(arrData[iColIndex][iRowIndex]);

					XPText textString = docXML.CreateTextNode(sLocalizedString);
					elemLocalization.AppendChild(textString);
				}
			}
		}
		else
		{
			elemStrings.SetAttribute("count", "0");
		}

		return XPBuilder.GetDocumentAsByteArray(docXML, "UTF-8");
	}

	/**
	 * MES- ObToString is an internal helper function that converts an
	 * Object to a String.  It just calls toString, except in the case
	 * of NULL objects, where it returns the blank string
	 *
	 * @param ob the object to be converted to a string
	 * @return the object converted to a String, or the blank string for
	 * null objects
	 */
	private String ObToString(Object ob)
	{
		if (null == ob)
		{
			return "";
		}
		else
		{
			return ob.toString();
		}
	}
}

