package com.plumtree.portalpages.admin.ptutilities.localizedstrings;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * @author MichaelS
 */
public class LocalizedStringsModel extends EditorModel
	implements ILocalizedStringsModelRO,
		ILocalizedStringsModel //, IRepostModel
{
	
	public static final String STR_MVC_CLASS_NAME = "LocalizedStrings";

	
	public IPTSession m_ptSession;
	private String m_sLastUploadMessage			  = "";
	private String[] m_arrLangsToLocalizeTo		  = null;
	private Object[][] m_arrLocalizedStringsArray = null;
	private boolean m_bDataUploaded = false;

	/**
	 * Implements some actions to perform on start.
	 * Use the Editor Type if needed.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		//MES- Nothing to do here
		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LocalizedStringsModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		//MES- If data was uploaded, save it
		if (m_bDataUploaded && (null != m_arrLocalizedStringsArray) &&
				(null != m_arrLangsToLocalizeTo))
		{
			IPTStringLocalizationManager mgr = (IPTStringLocalizationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_STRING_LOCALIZATION_MANAGER,
					false);
			mgr.SetLocalizedStrings(m_arrLangsToLocalizeTo,
				m_arrLocalizedStringsArray);
		}
	}

	/**
	 * Read Only methods from ILocalizedStringsModelRO
	 */
	/**
	 * @see ILocalizedStringsModelRO#getData()
	 */
	public Object[][] GetData()
	{
		// Methods like this are where you return data to your Section to be displayed.
		//MES- Cache the data if we haven't already
		if (null == m_arrLocalizedStringsArray)
		{
			IPTStringLocalizationManager mgr = (IPTStringLocalizationManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_STRING_LOCALIZATION_MANAGER,
					false);
			m_arrLangsToLocalizeTo		   = m_asOwner.GetResourceManager()
				.GetSupportedLanguages();
			m_arrLocalizedStringsArray     = (Object[][]) mgr.GetLocalizedStrings(m_arrLangsToLocalizeTo);
		}

		return m_arrLocalizedStringsArray;
	}

	/**
	 * @see ILocalizedStringsModelRO#getLangs()
	 */
	public String[] GetLangs()
	{
		//MES- Cache the langs and data by calling getData
		GetData();

		//MES- And return the langs
		return m_arrLangsToLocalizeTo;
	}

	/**
	 * MES- GetLastUploadMessage returns a string describing the last upload,
	 * or the zero length string if there has been no upload
	 *
	 * @param none
	 * @return void
	 */
	public String GetLastUploadMessage()
	{
		return m_sLastUploadMessage;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	//MES- Stuff for IRepostModel

	/**
	 * Inits the Model with the Activity Space.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		m_ptSession = (IPTSession) parent.GetUserSession();
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		//MES- We don't have pages, so we don't do anything
		return LocalizedStringsControl.PAGE_STATUS_VALID;
	}

	/**
	 * Write methods for LocalizedStrings Model from ILocalizedStringsModel
	 */
	/**
	 * MES- setData sets the array of localized strings
	 *
	 * @param arrLocalizedStrings is a 2D array of localized strings, as
	 * required by IPTStringLocalizationManager::SetLocalizedStrings
	 * @return void
	 */
	public void SetData(Object[][] arrLocalizedStrings)
	{
		// Methods like this are how your Controls perform actions on your Models.
		m_arrLocalizedStringsArray     = arrLocalizedStrings;
		m_bDataUploaded				   = true;
	}

	/**
	 * MES- setLangs sets the array of languages associated with m_arrLocalized
	 *    StringsArray.  Each column in m_arrLocalizedStringsArray is represented by an
	 *     item in arrLangs.
	 *
	 * @param arrLangs is a 1D array of language identifiers (e.g. "en" or "en-us".)
	 * @return void
	 */
	public void SetLangs(String[] arrLangs)
	{
		m_arrLangsToLocalizeTo     = arrLangs;
		m_bDataUploaded			   = true;
	}

	/**
	 * MES- SetUploadMessage sets a message that describes the most recent upload- success or failure
	 *
	 * @param sMessage is the message
	 * @return void
	 */
	public void SetUploadMessage(String sMessage)
	{
		m_sLastUploadMessage = sMessage;
	}

	/**
	 * @see ILocalizedStringsModelRO#userCanLocalize()
	 */
	public boolean UserCanLocalize()
	{
		//MES- Try to get the Localization Manager.  If we can get it, we can localize, but
		//	if we can't get it (presumably for security reasons), then we can't localize
		try
		{
			m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_STRING_LOCALIZATION_MANAGER,
				false);

			//MES- If we got here, we're cool
			return true;
		}
		catch (Exception e)
		{
			//MES- If we got here, we're NOT cool
			return false;
		}
	}
}

