package com.plumtree.portalpages.admin.ptutilities.migrationutility;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 */
public class MigrationResultPopupView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationResultPopupView");

	public static final String STR_MVC_CLASS_NAME = "MigrationResultPopup";

	/**
	 * Activity Space
	 */
	private MigrationUtilityAS m_asOwner;
	
	/**
	 * Model
	 */
	private IModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activiMigrationResultPopupViewt#Create()
	 */
	public Object Create()
	{
		return new MigrationResultPopupView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result  = new HTMLElementCollection();
		HTMLTable myMainTable;
		HTMLTableRow myMainTableRow;
		HTMLTableCell myMainTableCell;
		HTMLSpan mySpan;

		try
		{
			// Main table
			myMainTable = new HTMLTable();
			result.AddInnerHTMLElement(myMainTable);
			myMainTable.SetWidth("100%");
			myMainTable.SetHeight("100%");
			myMainTable.SetBorder("0");
			myMainTable.SetCellPadding("0");
			myMainTable.SetCellSpacing("0");

			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);
			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetColSpan("3");
			myMainTableCell.SetHeight("10%");
			myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// 1st Row: Status display
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("15");

			myMainTableCell = new HTMLTableCell();
			myMainTableCell.SetVAlign("bottom");
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			mySpan = new HTMLSpan();
			myMainTableCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(2747, "ptmsgs_portaladminmsgs") + GetStatusString());
			
			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("15");

			// 2nd Row: Close button
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("15");

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetAlign("right");
			mySpan = new HTMLSpan();
			myMainTableCell.AddInnerHTMLElement(mySpan);
			HTMLInput cancelButton = new HTMLInput(HTMLInputTypes.BUTTON_TYPE, m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
			cancelButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			cancelButton.SetValue(m_asOwner.GetString(1210, "ptmsgs_portaladminmsgs"));
			cancelButton.SetOnClick("window.close();");
			mySpan.AddInnerHTMLElement(cancelButton);
			
			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("15");

			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);
			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetColSpan("3");
			myMainTableCell.SetHeight("20%");
			myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		}
		catch (Exception e)
		{	
			log.Error(e, "Display The following error occured when trying to display the HTML: " + e.getMessage());
			throw new XPException(m_asOwner.GetString(24, "ptmsgs_portalcommonmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (IModelRO) model;
		m_asOwner     = (MigrationUtilityAS) parent;
	}
	
	/**
	 * Gets the status of the migration and returns the corresponding string.
	 * @return String
	 */
	public String GetStatusString()
	{
		String strStatus = "";
		int intStatus = ((IMigrationUtilityModelRO)m_model).GetMigrationStatus();
		
		switch (intStatus)
		{
			case PTMigrationTask.DONE : strStatus = m_asOwner.GetString(2748, "ptmsgs_portaladminmsgs"); break;
			case PTMigrationTask.CANCEL : strStatus = m_asOwner.GetString(2749, "ptmsgs_portaladminmsgs"); break;
			case PTMigrationTask.FAILED : strStatus = m_asOwner.GetString(2750, "ptmsgs_portaladminmsgs"); break;
		}
		
		return strStatus;
	}
}

