package com.plumtree.portalpages.admin.ptutilities.migrationutility;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.xui.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author jennifersu
 */
public class MigrationUtilityAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationUtilityAS");

	public static final String STR_MVC_CLASS_NAME = "MigrationUtility";

	private static final String sClassName = "com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationUtilityAS";
	
	public static final String strStorageRepostControl = "MigrationRepostControl";
	
	/**
	 * Export mode
	 */
	public static final int MODE_EXPORT = 0;
	
	/**
	 * Import mode
	 */
	public static final int MODE_IMPORT = 1;

	/** 
	 * Array of XUI pages (needed to set the help) 
	 */
	private XPArrayList m_alXUIPages;
	
	/**
	 * Migration Mode (export or import)
	 */
	protected int m_intMode;
	
	/**
	 * Menu ID for "Utility Settings" submenu
	 */
	private int m_intSettingsMenuID;
	
	/**
	 * Menu ID for "Resources" submenu
	 */
	private int m_intResourcesMenuID;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationUtilityAS();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()
	 */
	public String GetEditorTitle()
	{
		return GetString(2771, "ptmsgs_portaladminmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#GetRepostControlName()
	 */
	public String GetRepostControlName()
	{
		return strStorageRepostControl;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!PlumtreeHelpers.CheckCurrentUserIsAdmin((IPTSession)GetUserSession()))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		IModel myModel;
		
		if (m_intMode == MODE_IMPORT)
		{
			m_strModelName = MigrationUtilityImportModel.STR_MVC_CLASS_NAME;
			super.Init();
			myModel = GetModel(m_strModelName);

			RegisterControl(MigrationImportRepostControl.STR_MVC_CLASS_NAME, strStorageRepostControl, myModel);

			// Register Main Page
			RegisterPage(new MigrationImportMainDP());
			RegisterView(ImportSettingsView.STR_MVC_CLASS_NAME, myModel);

			// Register Load Package
			RegisterModel(MigrationLoadPackageModel.STR_MVC_CLASS_NAME, MigrationLoadPackageModel.strStorageLoadPackage);
			RegisterView(MigrationLoadPackageView.STR_MVC_CLASS_NAME, GetModel(MigrationLoadPackageModel.strStorageLoadPackage));

			// Register Dependency List
			RegisterModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME);
			MigrationDependencyListModel listModel = (MigrationDependencyListModel)GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME);
			RegisterView(MigrationDependencyListView.STR_MVC_CLASS_NAME, listModel);
			RegisterControl(MigrationDependencyListRepostControl.STR_MVC_CLASS_NAME, listModel);
			RegisterPage(new MigrationDependenciesDP());
		
			// Register SelectForImport
			RegisterModel(MigrationSelectForImportModel.STR_MVC_CLASS_NAME,
				MigrationUtilityImportAS.strStorageSelectForImport);
			IModel mySelectForImportModel = GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
			MigrationImportPortalResourcesDP portalResourcesDP = new MigrationImportPortalResourcesDP();
			RegisterPage(portalResourcesDP);
			RegisterView(MigrationSelectForImportView.STR_MVC_CLASS_NAME,
				MigrationUtilityImportAS.strStorageSelectForImport, mySelectForImportModel);
			RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
				MigrationUtilityImportAS.strStorageSelectForImport, mySelectForImportModel);
		}
		else
		{
			m_strModelName = MigrationUtilityExportModel.STR_MVC_CLASS_NAME;
			super.Init();
			myModel = GetModel(m_strModelName);

			RegisterControl(MigrationExportRepostControl.STR_MVC_CLASS_NAME, strStorageRepostControl, myModel);

			// Register Main Page
			RegisterPage(new MigrationExportMainDP());
			RegisterView(MigrationGeneralInfoView.STR_MVC_CLASS_NAME,
				MigrationGeneralInfoView.STR_MVC_CLASS_NAME, myModel);

            // Register export settings on the select resource view
            RegisterView(ExportSettingsView.STR_MVC_CLASS_NAME,
                         ExportSettingsView.STR_MVC_CLASS_NAME,
                         myModel);

			// Register Add Existing Package Resources
			RegisterModel(MigrationLoadPackageModel.STR_MVC_CLASS_NAME, MigrationLoadPackageModel.strStorageLoadPackage);
			MigrationAddExistingPackageDP uploadDP = new MigrationAddExistingPackageDP();
			RegisterPage(uploadDP);
			RegisterView(MigrationLoadPackageView.STR_MVC_CLASS_NAME, GetModel(MigrationLoadPackageModel.strStorageLoadPackage));

			// Register SelectForExport
			RegisterModel(MigrationSelectForExportModel.STR_MVC_CLASS_NAME,
				MigrationUtilityExportAS.strStorageSelectForExport);
			IModel mySelectForExportModel = GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
			MigrationExportPortalResourcesDP portalResourcesDP = new MigrationExportPortalResourcesDP();
			RegisterPage(portalResourcesDP);
			RegisterView(MigrationSelectForExportView.STR_MVC_CLASS_NAME,
				MigrationUtilityExportAS.strStorageSelectForExport, mySelectForExportModel);
			RegisterControl(MigrationSelectForExportRepostControl.STR_MVC_CLASS_NAME,
				MigrationUtilityExportAS.strStorageSelectForExport, mySelectForExportModel);

		}
		
		// Register StatusPopup
		RegisterPage(new MigrationStatusPopupDP());
		RegisterView(MigrationStatusPopupView.STR_MVC_CLASS_NAME, myModel);
		RegisterPage(new MigrationResultPopupDP());
		RegisterView(MigrationResultPopupView.STR_MVC_CLASS_NAME, myModel);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);
		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
							
				int iTitleId = 111;
				int iTipId = 112;
				int iSecondaryTipId = 113;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{					
					e = new HTMLGenericElement( sSecondary );
					tm.SetSecondarTip( e );
				}
			}
			catch (Exception ex)
			{
					log.Error(ex, "Couldn't generate tip.");	
			}
		}
		
		if (m_intMode == MODE_IMPORT)
		{
			SetCurrentPage(MigrationImportMainDP.STR_MVC_CLASS_NAME);			
		}
		else
		{
			SetCurrentPage(MigrationExportPortalResourcesDP.STR_MVC_CLASS_NAME);
		}
	}
	
	/**
	 * Registers XUI classes. Also sets the left navigation menu.
	 *
	 * @param _nPageCount Number of XUI pages.
	 */
	public void InitXUIClasses(XPHashtable _htPageCounts, int _intNumServices)
	{
		// If we have at least one XUI Service, we need to register XUIView
		// All pages in one Service will use the same View. The display method of the View
		// takes in the page ID to know what page to display.
		if (_intNumServices > 0)
		{
			for (int indService = 0; indService < _intNumServices; indService++)
			{
				if (indService == 0)
				{
					RegisterView(XUIView.STR_MVC_CLASS_NAME, XUIView.STR_MVC_CLASS_NAME, GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indService));
				}
				else
				{
					RegisterView(XUIView.STR_MVC_CLASS_NAME, XUIView.STR_MVC_CLASS_NAME + indService, GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indService));
				}
			}
		}

		// Start to build the left nav menu - first the main menu
		
		boolean mandatory=(EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel)GetModel(m_strModelName)).GetEditorType());

		// BEGIN Sub menu "Edit Utility Settings"
		m_intSettingsMenuID = m_mEditorMenu.StartNewSubMenu(GetString(478, "ptmsgs_portalbrowsingmsgs"));
		// Package Settings
		if (m_intMode == MODE_IMPORT)
		{
			m_mEditorMenu.AddLinkToSubMenu(m_intSettingsMenuID, MigrationImportMainDP.STR_MVC_CLASS_NAME);
			m_mEditorMenu.AddLinkToSubMenu(0, MigrationDependenciesDP.STR_MVC_CLASS_NAME);
			m_mEditorMenu.HideLink(true, MigrationDependenciesDP.STR_MVC_CLASS_NAME);

			// BEGIN Sub menu "Resources"
			m_intResourcesMenuID = m_mEditorMenu.StartNewSubMenu(GetString(2772, "ptmsgs_portaladminmsgs"));
			m_mEditorMenu.AddLinkToSubMenu(m_intResourcesMenuID, MigrationImportPortalResourcesDP.STR_MVC_CLASS_NAME);			
			m_mEditorMenu.HideSubMenu(true, m_intResourcesMenuID);
			
			// register a new XUIDP for each XUI page.
			m_alXUIPages = new XPArrayList();
			for (int indService = 0; indService < _intNumServices; indService++)
			{
				int nPages = XPConvert.ToInteger(_htPageCounts.GetElement(new Integer(indService)));
				for (int indPage = 1; indPage <= nPages; indPage++)
				{
					XUIDP myXuiPage = new XUIDP(indService, indPage);
					RegisterPage(myXuiPage, myXuiPage.GetName());
	
					// Add the page to the left nav menu
					m_mEditorMenu.AddLinkToSubMenu(m_intResourcesMenuID, myXuiPage.GetName());
	
					// Add the XUI Javascript validation function for each XUI DP.
					myXuiPage.AddToValidationFunction("ValidateThisPageOnTheClient");
				
					m_alXUIPages.Add(myXuiPage);
				}
			}
		}
		else
		{
			m_mEditorMenu.AddLinkToSubMenu(m_intSettingsMenuID, MigrationExportMainDP.STR_MVC_CLASS_NAME);

			// BEGIN Sub menu "Resources"
			m_intResourcesMenuID = m_mEditorMenu.StartNewSubMenu(GetString(2772, "ptmsgs_portaladminmsgs"));
			m_mEditorMenu.AddLinkToSubMenu(m_intResourcesMenuID, MigrationAddExistingPackageDP.STR_MVC_CLASS_NAME);			
			m_mEditorMenu.AddLinkToSubMenu(m_intResourcesMenuID, MigrationExportPortalResourcesDP.STR_MVC_CLASS_NAME);			
			
			// register a new XUIDP for each XUI page.
			m_alXUIPages = new XPArrayList();
			for (int indService = 0; indService < _intNumServices; indService++)
			{
				int nPages = XPConvert.ToInteger(_htPageCounts.GetElement(new Integer(indService)));
				for (int indPage = 1; indPage <= nPages; indPage++)
				{
					XUIDP myXuiPage = new XUIDP(indService, indPage);
					RegisterPage(myXuiPage, myXuiPage.GetName());
		
					// Add the page to the left nav menu
					m_mEditorMenu.AddLinkToSubMenu(m_intResourcesMenuID, myXuiPage.GetName());
		
					// Add the XUI Javascript validation function for each XUI DP.
					myXuiPage.AddToValidationFunction("ValidateThisPageOnTheClient");
					
					m_alXUIPages.Add(myXuiPage);
				}
			}
		}

	}


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage( page );
		
		String sPageName = page.GetName();

		if (sPageName.indexOf("XUI", 0) == 0)
		{
			XUIHelperModel myXUIHelperModel;
			int indUnderscoreIndex = sPageName.indexOf("_");
			if (indUnderscoreIndex > 0)
			{
				String strService = sPageName.substring(sPageName.indexOf("XUI") + 3, indUnderscoreIndex);
				myXUIHelperModel = (XUIHelperModel) GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + strService);
			}
			else
			{
				myXUIHelperModel = (XUIHelperModel) GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + 0);
			}
				
			XUIDP myXuiPage;
				
			for (int i = 0; i < m_alXUIPages.GetSize(); i ++)
			{
				myXuiPage = (XUIDP) m_alXUIPages.GetElement(i);
					
				if (myXuiPage.GetName().equals(sPageName))
				{
					SetHelpTopic(myXUIHelperModel.GetHelpFileName(myXuiPage.GetPageID()));
				}
			}
		}
	}
	
	/**
	 * Get "Utility Settings" submenu ID
	 * @return
	 */
	public int GetSettingsSubMenuID()
	{
		return m_intSettingsMenuID;
	}
	
	/**
	 * Get "Resources" submenu ID
	 * @return
	 */
	public int GetResourcesSubMenuID()
	{
		return m_intResourcesMenuID;
	}
}

