package com.plumtree.portalpages.admin.ptutilities.migrationutility;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.areyousure.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 */
public abstract class MigrationUtilityRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.MigrationRepostControl");

	public static final String STR_MVC_CLASS_NAME = "MigrationRepostControl";

	/**
	 * Migration-specific repost actions
	 */
	public final static int POSTTOSELF_ACTION_MIGRATION_START = 10;
	public final static int POSTTOSELF_ACTION_MIGRATION_POLL = 11;
	public final static int POSTTOSELF_ACTION_MIGRATION_CANCEL = 12;
	public final static int POSTTOSELF_ACTION_MIGRATION_DOUPLOAD = 13;
	public final static int POSTTOSELF_ACTION_REDIRECT_ON_POPUP = 14;
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public abstract Object Create();

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Sets the editor to perform the Are You Sure popup.
	 * Takes in an XPArrayList of AYSMessages.
	 */
	protected abstract void PerformAYSPopup();

	/**
	 * Dynamically add javascript to the current DisplayPage.
	 * 1. Open the StatusPopup window
	 * 2. Redirect the main window to m_model.GetRedirectAfterFinish().
	 */
	public void PerformMigrationPopup()
	{
		try
		{
			HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			XPStringBuilder sb;

			// Construct the ASURL for the popup
			ASURL statusPopup = new ASURL(m_asOwner);
			statusPopup.SetLinkGetCachedSpace(m_asOwner);
			statusPopup.SetDisplayPage(MigrationStatusPopupDP.STR_MVC_CLASS_NAME);
			statusPopup.SetControl(((MigrationUtilityAS)m_asOwner).GetRepostControlName());
			statusPopup.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF, POSTTOSELF_ACTION_MIGRATION_START);

			// Javascript: Open the popup
			sb = new XPStringBuilder(200);
			sb.Append("window.open('")
			.Append(statusPopup.GetURLAsString()).Append("', 'Status', 'scrollbar=yes,resizable=yes,location=no,menubar=no,height=350,width=400');\n");

			// Add the javascript to the <HEAD> of the current page.
			myScript.AddInnerHTMLString(sb.ToString());
			
			EditorDP currPage = (EditorDP) m_asOwner.GetCurrentPage(); 
			currPage.AddScriptToHead(myScript);
		}
		catch (Exception e)
		{			
			log.Error(e, "Unknown error attempting to open StatusPopup. e: " + e.getMessage());			
		}
	}

    private boolean HasUIErrors()
    {
        IXPEnumerator enumer = UIErrorHandler.GetErrors(
            m_asOwner.GetSubSession(),
            m_asOwner.GetApplication(),
            m_asOwner,
            true,
            UIErrorHandler.GetDisplayAdminErrors(m_asOwner));
        boolean rval = enumer.MoveNext();
        return rval;
    }

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param int
	 */
	protected void PerformAction(int _nAction)
	{
		// Editor repost actions (Finish, Cancel, Change Page, etc.)
		super.PerformAction(_nAction);
		
		// Migration repost actions
		switch (_nAction)
		{
			case POSTTOSELF_ACTION_FINISH:

				if (PAGE_STATUS_VALID == m_nPageStatus)
				{
					if (!HasUIErrors())
					{
						PerformAYSPopup();						
					}
					SetRedirect(null);
				}

				break;

			case POSTTOSELF_ACTION_REDIRECT_ON_POPUP:
				// This gets called when the status window first pops up.
				// This redirects the main window out of the utility.
				SetRedirect(m_model.GetRedirectAfterFinish());
				break;

			case POSTTOSELF_ACTION_MIGRATION_POLL:
				// Poll the status of the migration task 
				Redirect pollRedirect = PollStatus();
				// Display the page if migration is still in progress.
				// Otherwise, redirect to results page.
				SetRedirect(pollRedirect);
				break;
				
			case POSTTOSELF_ACTION_MIGRATION_CANCEL:
				// Cancel the migration task
				((MigrationUtilityModel)m_model).CancelMigration();
				// Redirect to the results page.
				Redirect cancelRedirect = new Redirect();
				cancelRedirect.SetLinkGetCachedSpace(m_asOwner);
				cancelRedirect.SetDisplayPage(MigrationResultPopupDP.STR_MVC_CLASS_NAME);
				cancelRedirect.SetControl(((MigrationUtilityAS)m_asOwner).GetRepostControlName());

				SetRedirect(cancelRedirect);
				break;
				
			case POSTTOSELF_ACTION_MIGRATION_DOUPLOAD:
				// Save page is called before we get here - it may error that the package is not
				// up-to-date (or that the folder's not selected). It shouldn't do that.
				UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(), m_asOwner.GetApplication());
				MigrationUtilityModel mainModel = (MigrationUtilityModel)m_model;
				mainModel.DoLoadPackage(m_htFormData);

				break;

			case AreYouSureControl.POSTTOSELF_ACTION_REDIRECT_AFTER_OK:
				PerformMigrationPopup();

				break;
		}

	}
	
	/**
	 * Polls for the status of the currently running migration task.  Depending on the status,
	 * return an appropriate redirect.
	 * 
	 * @return Redirect
	 */
	public abstract Redirect PollStatus();
}

