package com.plumtree.portalpages.admin.ptutilities.migrationutility;


import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;

/**
 * This class is what calls the actual server migration code.
 * It runs in a separate thread to prevent UI timeouts.
 * 
 * @author jennifersu
 *
 */
public class PTMigrationTask implements IXPRunnable {

	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.PTMigrationTask");

	// Status values for Migration tasks
	public static final int CREATED = 0;
	public static final int INPROGRESS = 1;
	public static final int DONE = 2;
	public static final int FAILED = 3;
	public static final int CANCEL = 4;

	// Current status
	protected int m_intStatus;
	protected IPTMigrationManager m_MigrationManager;

	
	/**
	 * Sets status to CREATED.
	 *
	 */
	public PTMigrationTask(IPTMigrationManager _MigrationManager)
	{
		log.Info("Migration Task created.");

		m_MigrationManager = _MigrationManager;

		m_intStatus = CREATED;
	}

	/**
	 * Performs the actual migration.
	 */
	public void run() 
	{
	}

	/**
	 * Gets the current status of the migration task
	 * @return int
	 */
	public int GetStatus()
	{
		return m_intStatus;
	}

	/**
	 * Sets the status for the migration task to CANCEL
	 *
	 */
	public void Cancel()
	{		
		m_intStatus = CANCEL;

		log.Info("Cancelling migration task.");
	}

    // mel: Fix for 46247, When a user exports objects from Collab or Publisher, no feedback is given that this was done. At least provide the UUID of the zip file in the final migration status.
    /**
     * @return XPArrayList of String each of which represents the return value from an MWS ExportPackage call with info about the MWS. If no MWS's are present or none responded, returns an empty list.
     */
    public XPArrayList GetMWSMessages()
    {
        return new XPArrayList();
    }
}

