package com.plumtree.portalpages.admin.ptutilities.migrationutility.exp;

import com.plumtree.server.*;

import com.plumtree.openfoundation.util.*;


/**
 * 
 * @author jennifersu
 *
 */
public class DependencyBundle
{
	/**
	 * The IPTMigrationElement that this is a dependency
	 * bundle for
	 */
	protected IPTMigrationElement m_ptME;
	
	/**
	 * XPArrayList of all dependent IPTMigrationElements
	 */
	protected XPArrayList m_xparDependencies;
	
	/**
	 * XPHashtable of dependents.
	 * Key=UUID; Value=IPTMigrationElement
	 */
	protected XPHashtable m_xphtUUIDs;
	
	/**
	 * Object ID of this IPTMigrationElement
	 */
	protected int m_nObjectID;
		
	/**
	 * 
	 * @param ptME
	 * @param nObjectID
	 */
	public DependencyBundle(IPTMigrationElement ptME, int nObjectID)
	{
		m_ptME = ptME;
		m_xparDependencies = new XPArrayList();
		m_xphtUUIDs = new XPHashtable();
		m_nObjectID = nObjectID;
	}
		
	/**
	 * Get the IPTMigrationELement that this
	 * bundle depends on
	 * @return IPTMigrationElement
	 */
	public IPTMigrationElement GetMainObject()
	{
		return m_ptME;
	}
		
	/**
	 * Get the array list of dependent objects
	 * (IPTMigrationElements)
	 * @return XPArrayList
	 */
	public XPArrayList GetDependentObjects()
	{
		return m_xparDependencies;
	}
	
	/**
	 * Get the object ID of the main
	 * IPTMigrationElement
	 * @return int
	 */
	public int GetMainObjectID()
	{
		return m_nObjectID;	
	}
		
	/**
	 * Adds an IPTMigrationElement as a dependent
	 * on the main object.
	 * @param ptME
	 */
	public void AddDependentObject(IPTMigrationElement ptME)
	{
		m_xparDependencies.Add(ptME);
		String strUUID = ptME.GetUUID();
		m_xphtUUIDs.PutElement(strUUID, ptME);
	}
	
	/**
	 * Looks up the UUID to see if it is a dependent
	 * in this bundle.
	 * @param strUUID
	 * @return boolean
	 */
	public boolean DependencyExistsInBundle(String strUUID)
	{
		IPTMigrationElement ptME = (IPTMigrationElement)m_xphtUUIDs.GetElement(strUUID);
		
		if (null == ptME)
		{
			return false;
		}
		else
		{
			return true;
		}
	}
}