package com.plumtree.portalpages.admin.ptutilities.migrationutility.exp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Represent global export settings like export parent folders
 * on the migration export resources page.
 */
public class ExportSettingsView extends EditorView
{
    private static OpenLogger log = OpenLogService.GetLogger(
        OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
        "com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.ExportSettingsView");

    public static final String STR_MVC_CLASS_NAME = "ExportSettingsView";

    public static final String HTMLCHECKBOX_EXPORT_PARENT_FOLDERS = "in_cb_ExportParentFolders";

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create()
    {
        return new ExportSettingsView();
    }

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
     */
    public HTMLElement Display()
    {
        HTMLElementCollection result = new HTMLElementCollection();
        HTMLTable myTable;

        try
        {
            IMigrationUtilityExportModelRO modelRO = (IMigrationUtilityExportModelRO) m_model;
            result.AddInnerHTMLElement(super.GetHeaderView(
                m_asOwner.GetString(3183, "ptmsgs_portaladminmsgs")
            ));

            myTable = ViewHelper.AddTable(result);
            myTable.SetBorder("0");

            // 1st row (Top Margin)
            ViewHelper.AddEmptyRow(myTable, "3");

            // 2nd row
            DrawCheckBox(myTable, HTMLCHECKBOX_EXPORT_PARENT_FOLDERS, "1",
                         m_asOwner.GetString(3184, ResourceConstants.PORTALADMINMSGS),
                         modelRO.IsExportParentFoldersEnabled());

            // last row (spacer row)
            ViewHelper.AddEmptyRow(myTable, "3");
        }
        catch (HTMLException e)
        {
            log.Error(e, STR_MVC_CLASS_NAME +
                         "::Display The following error occured when trying to display the HTML: " +
                         e.GetMessage());

            throw new XPException(STR_MVC_CLASS_NAME + "::Display() Unknown error when trying to display HTML. ", e);
        }

        return result;
    }

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
    public HTMLScript DisplayJavascript()
    {
        HTMLScript result = new HTMLScript("text/javaScript");
        return result;
    }

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
    public String GetName()
    {
        return STR_MVC_CLASS_NAME;
    }

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
     */
    public void Init(IModelRO model, AActivitySpace parent)
    {
        super.Init(model, parent);
    }

    // Helper Function:
    private void DrawCheckBox(HTMLTable myTable, String strHTMLID,
                              String strValue, String strUI, boolean bChecked)
    {
        ViewHelper.AddSimpleCheckbox(myTable, 3, strUI, strHTMLID, strValue, bChecked, "");
    }
}
