package com.plumtree.portalpages.admin.ptutilities.migrationutility.exp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.*;
import com.plumtree.portalpages.common.areyousure.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.filedownload.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 */
public class MigrationExportRepostControl extends MigrationUtilityRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.MigrationExportRepostControl");

	public static final String STR_MVC_CLASS_NAME = "MigrationExportRepostControl";

    // Session key for the MWS messages (return value from ExportPackage + info about the MWS)
    public static final String MWS_MESSAGES_SESSION_KEY = "MWS_MESSAGES_SESSION_KEY";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationExportRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Sets the editor to perform the Are You Sure popup.
	 * Takes in an XPArrayList of AYSMessages.
	 */
	protected void PerformAYSPopup()
	{
		try
		{
			// Put the AYSMessages in a common Session space - so the popup can reach them.
			MigrationUtilityExportModel mainModel = (MigrationUtilityExportModel)m_asOwner.GetModel(MigrationUtilityExportModel.STR_MVC_CLASS_NAME);
			XPArrayList xpalAYSMessages = mainModel.GetAYSMessages();
			m_asOwner.GetSubSession().SetAttribute(MigrationUtilityExportModel.AYS_SESSION_KEY,
				xpalAYSMessages);

			// Set up the AYS popup
			HTMLScript myScript = new HTMLScript("text/javaScript");
			XPStringBuilder sb;

			ASURL asurlPopup = new ASURL(m_asOwner);

			asurlPopup.SetLinkCreateNewSpace(AreYouSureAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			asurlPopup.SetSubSpaceKey(MigrationUtilityExportAS.SUBSPACEKEY_AYS);
			asurlPopup.SetDisplayPage(AYSPopupDP.STR_MVC_CLASS_NAME);
			asurlPopup.SetControl(AreYouSureControl.STR_MVC_CLASS_NAME);
			asurlPopup.AddControlArgument(AreYouSureControl._QS_AYS_SESSION_KEY,
				MigrationUtilityExportModel.AYS_SESSION_KEY);

			sb = new XPStringBuilder(200);
			sb.Append("window.open('")
			.Append(asurlPopup.GetURLAsString()).Append("', 'Confirm', 'scrollbar=yes,location=no,menubar=no,height=350,width=400');\n");

			myScript.AddInnerHTMLString(sb.ToString());
			((EditorDP) ((EditorAS) m_asOwner).GetCurrentPage()).AddScriptToHead(myScript);

			// AGC - we want to just repost here. Our new script will redirect us after download is
			// complete.
			SetRedirect(null);
		}
		catch (Exception e)
		{			
			log.Error(e, "Unknown error attempting to open AYSPopup. e: " + e.getMessage());
		}
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param int
	 */
	protected void PerformAction(int _nAction)
	{
		// Editor repost actions (Finish, Cancel, Change Page, etc.)
		super.PerformAction(_nAction);
		
		// You need to call the PerformRepostAction on the select ptobject control
		((ExpListControl) m_asOwner.GetControl(MigrationUtilityExportAS.strStorageSelectForExport)).PerformRepostAction(_nAction,
			m_htFormData);

		// Migration repost actions
		switch (_nAction)
		{
			case POSTTOSELF_ACTION_MIGRATION_START:
				// Start the migration thread 
				((MigrationUtilityExportModel)m_model).StartExport();
				
				// Construct the redirect to the status polling page.
				Redirect startRedirect = new Redirect();
				startRedirect.SetLinkGetCachedSpace(m_asOwner);
				startRedirect.SetDisplayPage(MigrationStatusPopupDP.STR_MVC_CLASS_NAME);
				startRedirect.SetControl(((MigrationUtilityAS)m_asOwner).GetRepostControlName());
				startRedirect.AddControlArgument(RepostControl.HTMLINPUT_POSTTOSELF, MigrationExportRepostControl.POSTTOSELF_ACTION_MIGRATION_POLL);

				// Go to the status polling page
				SetRedirect(startRedirect);		
				break;

		}
	}
	
	/**
	 * Polls for the status of the currently running migration task.  Depending on the status,
	 * return an appropriate redirect.
	 * 
	 * @return Redirect
	 */
	public Redirect PollStatus()
	{
		MigrationUtilityExportModel myModel = (MigrationUtilityExportModel)m_model;
		
		// Begin polling
		if (myModel.GetMigrationStatus() != PTMigrationTask.DONE)
		{
			if (myModel.GetMigrationStatus() != PTMigrationTask.FAILED)
			{	
				// It's not DONE and it's not FAILED, so it must still be in progress.
				// Return a null Redirect so the status page displays.	
				log.Info("Export task in progress.");
				return null;
			}
			else
			{
				// Handle failure and return a redirect to the result page.
				log.Error("Export task failed.");

				Redirect pollPage = new Redirect();
				pollPage.SetLinkGetCachedSpace(m_asOwner);
				pollPage.SetDisplayPage(MigrationResultPopupDP.STR_MVC_CLASS_NAME);
				pollPage.SetControl(((MigrationUtilityAS)m_asOwner).GetRepostControlName());
				
				return pollPage;
			}
		}
		else
		{
			// Success! Return a redirect to the result page.
			log.Info("Export task successful!");

            // Store the MWS messages on the session for later retrieval by MigrationDownloadFilePopupDP
            XPArrayList mwsMessages = myModel.GetMWSMessages();
            m_asOwner.GetSubSession().SetAttribute(MWS_MESSAGES_SESSION_KEY, mwsMessages);

			// Construct the redirect to the result page
			Redirect downloadPage = new Redirect();
	
			downloadPage.SetLinkCreateNewSpace(MigrationFileDownloadAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			downloadPage.SetDisplayPage(MigrationDownloadFilePopupDP.STR_MVC_CLASS_NAME);
			downloadPage.SetControl(FileDownloadControl.STR_MVC_CLASS_NAME);
			downloadPage.AddControlArgument(FileDownloadControl._QS_FD_CONTENT_TYPE,
				"application/octet-stream");
			downloadPage.AddControlArgument(FileDownloadControl._QS_FD_SESSION_KEY,
				MigrationUtilityExportModel.EXPORT_FILE_SESSION_KEY);
			
			return downloadPage;
		}
	}
}

