package com.plumtree.portalpages.admin.ptutilities.migrationutility.exp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 */
public class MigrationSelectForExportView extends SelectPTObjectView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.MigrationSelectForExportView");

	/** 
	 * Class name for the activity space 
	 */
	public static final String STR_MVC_CLASS_NAME = "MigrationSelectForExportView";

	/**
	 * HTML for dropdown filter
	 */
	public static final String HTMLINPUT_FILTER = "in_se_filter";

    /**
     * HTML dropdown value for default, none selected.
     */
    public static final String HTML_FILTER_NONE_SELECTED_VALUE = "0";

	/**
	 * HTML dropdown value for filtering on admin objects.
	 */
	public static final String HTML_FILTER_ADMIN_OBJ_VALUE = "1";
	
	/**
	 * HTML dropdown value for filtering on directory objects.
	 */
	public static final String HTML_FILTER_DIRECTORY_VALUE = "2";

	/**
	 * HTML dropdown value for filtering on global maps.
	 */
	public static final String HTML_FILTER_GLOBAL_VALUE = "3";

	/**
	 * HTML Object names */
	public static final String HTMLINPUT_ADMIN_TREEASID = "in_hi_AdminTreeSpaceID";

	/**
	 * HTML Object names */
	public static final String HTMLINPUT_DIR_TREEASID = "in_hi_DirTreeSpaceID";

	/**
	 * HTML Object names */
	public static final String HTMLINPUT_GLOBAL_TREEASID = "in_hi_GlobalTreeSpaceID";

	/**
	 * HTML Object name: Check all folder contents checkbox */
	public static final String HTMLCHECKBOX_CHECKALLFOLDERS = "in_cb_CheckAllFolders";

	/**
	 * HTML Object name: Check all dependencies checkbox */
	public static final String HTMLCHECKBOX_CHECKALLDEPENDENCIES = "in_cb_CheckAllDependencies";

	/**
	 * HTML Object name: Add Folder Contents checkbox */
	public static final String HTMLCHECKBOX_FOLDERCONTENTS   = "in_cb_FolderContents";

	/**
	 * HTML Object name: Add Dependencies checkbox */
	public static final String HTMLCHECKBOX_DEPENDENCIES   = "in_cb_Dependencies";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationSelectForExportView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForCheckBox(int)
	 */
	protected HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)

	{
		HTMLTableCell myCell = new HTMLTableCell();
		MigrationSelectForExportModel myModel = (MigrationSelectForExportModel)m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
		PTGrowableSortedArrayWrapper saData = myModel.GetItems();   
		int nClassID = XPConvert.ToInteger(saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_CLASSID));
		if (nClassID != PT_CLASSIDS.PT_GUESTLOGIN_ID)
		{
		   	myCell = super.GetHTMLForCheckBox(_nRowIndex);
			myCell.SetVAlign("top");
		}
		
		return myCell;
	}

	/**
	 * Returns the HTML for the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 */
	protected HTMLTable GetHTMLForActionBar()
	{
		try
		{
			HTMLTable myTable;
			HTMLTableRow myRow;
			HTMLTableCell myCell;

			myTable = new HTMLTable();
			myTable.SetBorder("0");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("0");

			// 1st Row begin (there is only one row)
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			// Empty Cell
			myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());

			// Filter dropdown

			// MigrationSelectForExportModel listModel = (MigrationSelectForExportModel)m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
				
			myCell = new HTMLTableCell();
			myCell.SetHeight("25");
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
	
			HTMLSelect myFilter = new HTMLSelect(HTMLINPUT_FILTER, "");
			myFilter.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(myFilter);

            // Select Resources...
            HTMLOption selectOption = new HTMLOption(HTML_FILTER_NONE_SELECTED_VALUE);
            selectOption.AddInnerHTMLString(m_asOwner.GetString(3154, "ptmsgs_portaladminmsgs"));
            myFilter.AddInnerHTMLElement(selectOption );

			HTMLOption adminOption = new HTMLOption(HTML_FILTER_ADMIN_OBJ_VALUE);
			adminOption.AddInnerHTMLString(m_asOwner.GetString(2787, "ptmsgs_portaladminmsgs"));
			myFilter.AddInnerHTMLElement(adminOption);
				
			HTMLOption dirOption = new HTMLOption(HTML_FILTER_DIRECTORY_VALUE);
			dirOption.AddInnerHTMLString(m_asOwner.GetString(2788, "ptmsgs_portaladminmsgs"));
			myFilter.AddInnerHTMLElement(dirOption);
				
			HTMLOption globalOption = new HTMLOption(HTML_FILTER_GLOBAL_VALUE);
			globalOption.AddInnerHTMLString(m_asOwner.GetString(2789, "ptmsgs_portaladminmsgs"));
			myFilter.AddInnerHTMLElement(globalOption);

            // Javascript to open the add object tree for the various resource types
            myFilter.SetOnChange("OpenAddObjectTree" + "(document." + AFormDP.HTMLFORM_NAME + "." +
                                HTMLINPUT_FILTER + ".options[document." + AFormDP.HTMLFORM_NAME + "." +
                                HTMLINPUT_FILTER + ".selectedIndex].value); return false;");

            // Invisible elements to support the Select Resoruces dropdown
			myRow.AddInnerHTMLElement(GetHTMLForAddAction());

			AddHTMLToActionBar(myRow);
	
			// No need to display the delete icon, if the list is empty.
			if (0 != ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
			{
				// Delete icon cell
				myRow.AddInnerHTMLElement(GetHTMLForDeleteAction());
			}

			// Last Empty Cell
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetHeight("25");
			myCell.AddInnerHTMLString(SPACE);
	
			// 1st Row ends
			return myTable;
		}
		catch (HTMLException e)
		{
				
				log.Error(e, STR_MVC_CLASS_NAME + "::" + e.GetMessage());
				
		}
		catch (Exception e)
		{
				
				log.Error(e, STR_MVC_CLASS_NAME + "::" + e.getMessage());
				
		}
	
		return null;
	}

	/**
	 * Returns the HTML for the sub header.
	 *
	 * @return HTMLTableRow
	 */
	protected HTMLTableRow GetHTMLForSubHeader()
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;
		HTMLInput myInput;
		HTMLImg myImage;
		PTConstruct myConstruct;

		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

		// Row 1 - Cell 1 - checkbox
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("20");
		myCell.SetAlign("center");
		myCell.SetVAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

		// checkbox
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALL),
				((IExpListModelRO) m_model).GetAddIconAlt());
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(
				"CheckRows") + "();");
		myCell.AddInnerHTMLElement(myInput);

		// Row 1 - Name Col
		Object[][] oArrExpListColInfo = ((IExpListModelRO) m_model).GetArrExpListColInfo();
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth((String) oArrExpListColInfo[0][ExpListModel.EXPLIST_COLUMN_WIDTH]);
		myCell.SetColSpan((String) oArrExpListColInfo[0][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
//		myCell.SetHeight("20");
		myCell.SetNoWrap(((IExpListModelRO) m_model).GetWrapColumnHeaders());
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myCell.AddInnerHTMLString(SPACE);
		// JF- We build the link to reverse the sort
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf('" +
			((IExpListModelRO) m_model).GetUniqueInt(
				ExpListControl.POSTTOSELF_ACTION_REVERSESORT) +
			"'); return false;");
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[0][ExpListModel.EXPLIST_COLUMN_TITLE]);
		// JF- We figure out the sort direction to know which arrow to display
		if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IExpListModelRO) m_model).GetMainColumnSortDirection())
		{
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
					true, this.m_asOwner);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

			myImage.SetAlt(m_asOwner.GetString(55,
					ResourceConstants.INFRASTRUCTURE));
			myImage.SetAlign("absmiddle");
			myAnchor.AddInnerHTMLElement(myImage);
		}
		else
		{
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
					true, this.m_asOwner);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt(m_asOwner.GetString(54,
					ResourceConstants.INFRASTRUCTURE));
			myImage.SetAlign("absmiddle");
			myAnchor.AddInnerHTMLElement(myImage);
		}

		// Row 1 - Submitted By Col
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth((String) oArrExpListColInfo[1][ExpListModel.EXPLIST_COLUMN_WIDTH]);
		myCell.SetColSpan((String) oArrExpListColInfo[1][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
//		myCell.SetHeight("20");
		myCell.SetNoWrap(((IExpListModelRO) m_model).GetWrapColumnHeaders());
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		myCell.SetAlign("center");
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString((String) oArrExpListColInfo[1][ExpListModel.EXPLIST_COLUMN_TITLE]);

		// Row 1 - Folder Contents Col
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth((String) oArrExpListColInfo[2][ExpListModel.EXPLIST_COLUMN_WIDTH]);
		myCell.SetColSpan((String) oArrExpListColInfo[2][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
//		myCell.SetHeight("20");
		myCell.SetNoWrap(false);
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetAlign("center");
		myCell.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLString((String) oArrExpListColInfo[2][ExpListModel.EXPLIST_COLUMN_TITLE]);
        myCell.AddInnerHTMLString("<br>");
		// checkbox
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALLFOLDERS),
				((IExpListModelRO) m_model).GetAddIconAlt());
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(
				"CheckAllFolderRows") + "();");
		myCell.AddInnerHTMLElement(myInput);

		// Row 1 - Dependencies Col
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth((String) oArrExpListColInfo[3][ExpListModel.EXPLIST_COLUMN_WIDTH]);
		myCell.SetColSpan((String) oArrExpListColInfo[3][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
        myCell.AddInnerHTMLString((String) oArrExpListColInfo[3][ExpListModel.EXPLIST_COLUMN_TITLE]);
//		myCell.SetHeight("20");
		myCell.SetNoWrap(false);
		myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
        myCell.SetAlign("center");
		myCell.AddInnerHTMLString(SPACE);
        myCell.AddInnerHTMLString("<br>");
		// checkbox
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALLDEPENDENCIES),
				((IExpListModelRO) m_model).GetAddIconAlt());
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString(
				"CheckAllDependencyRows") + "();");
		myCell.AddInnerHTMLElement(myInput);

		return myRow;
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_CLASSID));
		if (nClassID != PT_CLASSIDS.PT_GUESTLOGIN_ID)
		{
			result.AddInnerHTMLElement(GetHTMLForIconColumn(_saData, _nRowIndex));
			result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
			result.AddInnerHTMLElement(GetHTMLForSubmittedByColumn(_saData, _nRowIndex));
			result.AddInnerHTMLElement(GetHTMLForFolderContents(_saData, _nRowIndex));
			result.AddInnerHTMLElement(GetHTMLForDependencies(_saData, _nRowIndex));			
		}

		return result;
	}

	/**
	 * 
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForIconColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
        String languageID
            = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(
                PersonalSettingNames.LANGUAGE, m_asOwner);
        return com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationSelectForImportView.GetHTMLForIconColumn(
            _saData,
            _nRowIndex,
            MigrationSelectForExportModel.EXPLIST_COL_CLASSID,
            languageID
        );
	}

	/**
	 * Returns the HTML for the checkbox on row _nRowIndex.
	 *
	 * @param _nRowIndex
	 * @return HTMLTableCell
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForFolderContents(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		
		int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
					SelectPTObjectModel.EXPLIST_COL_CLASSID));
		boolean bFolderContents = XPConvert.ToBoolean(_saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_FOLDER_CONTENTS));
		
		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetWidth(MigrationSelectForExportModel.CONTENTS_COLUMN_WIDTH);
		myCell.SetAlign("center");
		myCell.SetVAlign("middle");
		myCell.SetNoWrap(true);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		if (nClassID == PT_CLASSIDS.PT_ADMIN_FOLDER_ID || nClassID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
		{
			// checkbox
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_FOLDERCONTENTS),
					m_asOwner.GetString(2790, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myInput.SetValue(XPConvert.ToString(_nRowIndex));
			myInput.SetChecked(bFolderContents);
			myCell.AddInnerHTMLElement(myInput);

		}
		else
		{
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}
		
		return myCell;
	}

	/**
	 * Returns the HTML for the checkbox on row _nRowIndex.
	 *
	 * @param _nRowIndex
	 * @return HTMLTableCell
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForDependencies(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		boolean bDependencies = XPConvert.ToBoolean(_saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_DEPENDENCIES));
		
		HTMLTableCell myCell;
		
		myCell = new HTMLTableCell();
		myCell.SetHeight("30");
		myCell.SetWidth(MigrationSelectForExportModel.DEPENDENCIES_COLUMN_WIDTH);
		myCell.SetAlign("center");
		myCell.SetVAlign("middle");
		myCell.SetNoWrap(true);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		// checkbox
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DEPENDENCIES),
				m_asOwner.GetString(2791, "ptmsgs_portaladminmsgs"));
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetValue(XPConvert.ToString(_nRowIndex));
		myInput.SetChecked(bDependencies);
		
		myCell.AddInnerHTMLElement(myInput);
		
		return myCell;
	}

	/**
	 * 
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForNameColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLBr myBr;

		myCell = new HTMLTableCell(); // Note, we are not calling our super.
		myCell.SetWidth(MigrationSelectForExportModel.NAME_COLUMN_WIDTH);
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(false);

		mySpan = new HTMLSpan();
		mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLElement(mySpan);

		try
		{
			// Object Name
			Object oPTObjectName = _saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_STRING);
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLEncodedString((String) oPTObjectName);

			// Try to add an Object Description		
			Object oPTObjectDesc = _saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_DESCRIPTION);

			if (null != oPTObjectDesc)
			{
				// Add a break;
				myBr = new HTMLBr();
				mySpan.AddInnerHTMLElement(myBr);

				// Add the Description.
				mySpan.AddInnerHTMLString(SPACE);
				mySpan.AddInnerHTMLEncodedString(XPConvert.ToString(oPTObjectDesc));
			}
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetHTMLForNameColumn: Unknown Error e: " + e.getMessage());
		}

		return myCell;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.SelectPTObjectView#GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO,
	 *      int)
	 */
	protected HTMLTableCell GetHTMLForSubmittedByColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell(); // Note, we are not calling our super.
		myCell.SetWidth(MigrationSelectForExportModel.SUBMITTED_BY_COLUMN_WIDTH);
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(false);
		myCell.SetAlign("center");

		mySpan = new HTMLSpan();
		mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLElement(mySpan);

		try
		{
			// Submitted By Name
			String strSubmittedBy = XPConvert.ToString(_saData.GetItem(_nRowIndex, MigrationSelectForExportModel.EXPLIST_COL_SUBMITTED_BY));
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLEncodedString(strSubmittedBy);
			mySpan.AddInnerHTMLString(SPACE);

		}
		catch (Exception e)
		{
			log.Error(e, "MigrationSelectForExportView::GetHTMLForNameColumn: Unknown Error e: " + e.getMessage());
		}

		return myCell;
	}
	
	/**
	 * Helper method to get the HTML for the icon.
	 * (Each row has an icon before the input text.)
	 *
	 * @return HTMLImg
	 * @throws Exception
	 */
	protected HTMLImg GetHTMLForIcon(PTImageType _imgRowIcon)
		throws Exception
	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct = UIConstructFactory.GetConstruct(_imgRowIcon, true, this.m_asOwner);
		myImage = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		return (myImage);
	}


	/**
	 * Helper method to add a BR tag to another element.
	 */
	protected void AddLineBreaks(HTMLElement myElement, int nNumBreaks)
	{
		for (int nIndex = 0; nIndex < nNumBreaks; nIndex++)
		{
			HTMLBr myBr = new HTMLBr();
			myElement.AddInnerHTMLElement(myBr);
		}
	}
	
	/**
	 * Add HTML to the action bar for the Add Approved button.
	 *
	 * @param _myRow Action bar row object.
	 */
	protected void AddHTMLToActionBar(HTMLTableRow _myRow)
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage, myAddIcon;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		_myRow.AddInnerHTMLElement(myCell);
		
		// Add icon
		myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_ADD, true, this.m_asOwner);
		myAddIcon = (HTMLImg) myConstruct.GetHTMLElement();
		myAddIcon.SetAlt("");
		myAddIcon.SetAlign("absmiddle");

		// Add icon
		myConstruct = UIConstructFactory.GetConstruct(((ISelectPTObjectModelRO) m_model).GetAddIcon(), true, this.m_asOwner);
		myImage = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = GetAnchorForAddApprovedAction();
		myAnchor.AddInnerHTMLString(SPACE);
		myAnchor.AddInnerHTMLElement(myAddIcon);
		myAnchor.AddInnerHTMLElement(myImage);
		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(m_asOwner.GetString(2759, "ptmsgs_portaladminmsgs"));
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
	}

	/**
	 * Helper method to return the add action link.
	 *
	 * @return HTMLAnchor
	 */
	protected HTMLAnchor GetAnchorForAddApprovedAction()

	{
		HTMLAnchor myAnchor;

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("postToSelf(" + MigrationSelectForExportRepostControl.POSTTOSELF_ACTION_ADD_APPROVED + ");return false;");

		return myAnchor;
	}
	
	/**
	 * Helper method to return the add action link.
	 *
	 * @return HTMLAnchor
	 */
	protected HTMLAnchor GetAnchorForAddAction()

	{
		HTMLAnchor myAnchor;

		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick("OpenAddObjectTree" + "(document." + AFormDP.HTMLFORM_NAME + "." +
			HTMLINPUT_FILTER + ".options[document." + AFormDP.HTMLFORM_NAME + "." +
			HTMLINPUT_FILTER + ".selectedIndex].value); return false;");

		return myAnchor;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		String strSelectedItems = ((ISelectPTObjectModelRO) m_model).GetSelectedItems();
		ASURL adminObjTree = GetAdminObjTreeURL(strSelectedItems);
		ASURL directoryTree = GetDirectoryTreeURL(strSelectedItems);
		ASURL globalTree = GetGlobalObjTreeURL(strSelectedItems);

		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		ASURL myOldTree = new ASURL(m_asOwner);
		myOldTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
		myOldTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
		myOldTree.IsSubSpace();
		if (strSelectedItems.length() < 100)
		{
			myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				strSelectedItems);
		} else
		{
			// This list can be quite long for users, so we need to pass
			// it by reference.
			myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				strSelectedItems, m_asOwner);	
		}

		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		ASURL myOldGlobalTree = new ASURL(m_asOwner);
		myOldGlobalTree.SetLinkCreateNewSpace(GlobalObjsTreeAS.STR_MVC_CLASS_NAME,
			m_asOwner);
		myOldTree.SetControl(RefreshTreeControl.STR_MVC_CLASS_NAME);
		myOldTree.IsSubSpace();
		if (strSelectedItems.length() < 100)
		{
			myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				strSelectedItems);
		} else
		{
			// This list can be quite long for users, so we need to pass
			// it by reference.
			myOldTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				strSelectedItems, m_asOwner);	
		}

		XPStringBuilder sb;

		try
		{
			// Open Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function OpenAddObjectTree(filterType)\n");
			sb.Append("{\n");
			sb.Append("  var myInput;\n");
			sb.Append("  if (filterType == " + HTML_FILTER_ADMIN_OBJ_VALUE + ") {\n");
			sb.Append("    myInput = document." + AFormDP.HTMLFORM_NAME + "." +
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_ADMIN_TREEASID) + "\n");
			sb.Append("    if (myInput.value == '') {\n");
			sb.Append("      window.open('").Append(adminObjTree.GetURLAsString())
			.Append("', '_SelectPTObjectTree', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("    } else {\n");
			sb.Append("      window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_SelectPTObjectTree', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("    }\n");
			sb.Append("  } else if (filterType == " + HTML_FILTER_DIRECTORY_VALUE + ") {\n");
			sb.Append("    myInput = document." + AFormDP.HTMLFORM_NAME + "." +
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_DIR_TREEASID) + "\n");
			sb.Append("    if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(directoryTree.GetURLAsString())
			.Append("', '_SelectPTObjectTree', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("    } else {\n");
            /**
			sb.Append("      window.open('").Append(myOldTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_SelectPTObjectTree', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
            */
            // mel: Fix for 45899, Opening the knowledge directory resources after global resources have been added causes "Error displaying frames"
            // This fix is incorrect but works. We're recreating the tree each time its opened.
            // There's a side-effect from ASURL construction above. Note that
            // the admin/dir trees have the same "myOldTree" and their is a distinct "myOldGlobalTree".
            // This all has something to do with myInput.value.
            // TODO Repair this properly so it reuses the directory tree.
            sb.Append("    window.open('").Append(directoryTree.GetURLAsString())
                .Append("', '_SelectPTObjectTree', '")
                .Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("    }\n");
			sb.Append("  } else if (filterType == " + HTML_FILTER_GLOBAL_VALUE + ") {\n");
			sb.Append("    myInput = document." + AFormDP.HTMLFORM_NAME + "." +
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_GLOBAL_TREEASID) + "\n");
			sb.Append("    if (myInput.value == '') {\n");
			sb.Append("    window.open('").Append(globalTree.GetURLAsString())
			.Append("', '_SelectPTObjectTree', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("    } else {\n");
			sb.Append("      window.open('").Append(myOldGlobalTree.GetURLAsString())
			.Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
			.Append(", '_SelectPTObjectTree', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("    }\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(300);

			// JavaScript to check all the rows
			sb.Append("function " +
				((IExpListModelRO) m_model).GetUniqueString("CheckAllFolderRows") +
				"()\n");
			sb.Append("{ \n");
			sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME +
				"; \n");
			sb.Append("  var len = frm.elements.length; \n");
			sb.Append("  var nValue = frm." +
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALLFOLDERS) + ".checked; \n");
			sb.Append("  var i = 0; \n");
			sb.Append("  \n");
			sb.Append("  for(i=0 ; i<len ; i++) \n");
			sb.Append("  { \n");
			sb.Append("    if (frm.elements[i].name == '" +
				((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_FOLDERCONTENTS)+
				"') \n");
			sb.Append("    { \n");
			sb.Append("       frm.elements[i].checked = nValue;\n");
			sb.Append("    } \n");
			sb.Append("  } \n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(300);

			// JavaScript to check all the rows
			sb.Append("function " +
				((IExpListModelRO) m_model).GetUniqueString("CheckAllDependencyRows") +
				"()\n");
			sb.Append("{ \n");
			sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME +
				"; \n");
			sb.Append("  var len = frm.elements.length; \n");
			sb.Append("  var nValue = frm." +
				((IExpListModelRO) m_model).GetUniqueString(
					HTMLCHECKBOX_CHECKALLDEPENDENCIES) + ".checked; \n");
			sb.Append("  var i = 0; \n");
			sb.Append("  \n");
			sb.Append("  for(i=0 ; i<len ; i++) \n");
			sb.Append("  { \n");
			sb.Append("    if (frm.elements[i].name == '" +
				((IExpListModelRO) m_model).GetUniqueString(HTMLCHECKBOX_DEPENDENCIES)+
				"') \n");
			sb.Append("    { \n");
			sb.Append("       frm.elements[i].checked = nValue;\n");
			sb.Append("    } \n");
			sb.Append("  } \n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME + "::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.GetMessage());
			
		}

		return myScript;
	}
	
	/**
	 * Get Tree URL for admin objects
	 * @param _strSelectedItems
	 * @return
	 */
	private ASURL GetAdminObjTreeURL(String _strSelectedItems)
	{
		// The URL to open a new tree
		ASURL myNewTree = new ASURL(m_asOwner);

		myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		myNewTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(
				MigrationSelectForExportModel.SUBSPACE_KEY_ADMINTREE));
		myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		myNewTree.AddControlArgument(StartTreeControl.ROOT_ID,
			XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
		myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
			((ISelectPTObjectModelRO) m_model).GetTreeMultiSelect());
		myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetTreeLeafType()));
		myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_ADMIN_TREEASID));
		myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				"OnReturnFromTree"));
		myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			((MigrationSelectForExportModel) m_model).GetAdminObjectClassIDs());
		myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL,
			XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetAccessLevel()));

		if (_strSelectedItems.length() < 100)
		{
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				_strSelectedItems);
		} else
		{
			// This list can be quite long for users, so we need to pass
			// it by reference.
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
			_strSelectedItems, m_asOwner);	
		}

		myNewTree.AddControlArgument(StartTreeControl.TITLE,
				m_asOwner.GetString(2792, "ptmsgs_portaladminmsgs"));

		myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE,
				m_asOwner.GetString(2793, "ptmsgs_portaladminmsgs"));
		
		int nCommunityMode = AObjectTreeModel.ALLCOMMUNITIES;
		myNewTree.AddControlArgument(StartTreeControl.COMMUNITY_MODE,
				nCommunityMode);			
		
		return myNewTree;
	}

	/**
	 * Get Tree URL for directory objects
	 * @param _strSelectedItems
	 * @return
	 */
	private ASURL GetDirectoryTreeURL(String _strSelectedItems)
	{
		// The URL to open a new tree
		ASURL myNewTree = new ASURL(m_asOwner);

		myNewTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		myNewTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(
				MigrationSelectForExportModel.SUBSPACE_KEY_DIRTREE));
		myNewTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		myNewTree.AddControlArgument(StartTreeControl.ROOT_ID,
			XPConvert.ToString(PT_INTRINSICS.PT_FOLDER_ROOTFOLDER));
		myNewTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
			((ISelectPTObjectModelRO) m_model).GetTreeMultiSelect());
		myNewTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetTreeLeafType()));
		myNewTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewTree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_DIR_TREEASID));
		myNewTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				"OnReturnFromTree"));
		myNewTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			((MigrationSelectForExportModel) m_model).GetDirectoryClassIDs());
		myNewTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL,
			XPConvert.ToString(((ISelectPTObjectModelRO) m_model).GetAccessLevel()));

		if (_strSelectedItems.length() < 100)
		{
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				_strSelectedItems);
		} else
		{
			// This list can be quite long for users, so we need to pass
			// it by reference.
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
			_strSelectedItems, m_asOwner);	
		}

		myNewTree.AddControlArgument(StartTreeControl.TITLE,
				m_asOwner.GetString(2794, "ptmsgs_portaladminmsgs"));

		myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE,
				m_asOwner.GetString(2795, "ptmsgs_portaladminmsgs"));
		
		int nDirectoryMode = DirectoryTreeModel.EDIT_MODE;
		myNewTree.AddControlArgument(StartTreeControl.DIRECTORY_MODE,
				nDirectoryMode);			
		
		return myNewTree;
	}
	
	/**
	 * Get Tree URL for global objects
	 * @param _strSelectedItems
	 * @return
	 */
	private ASURL GetGlobalObjTreeURL(String _strSelectedItems)
	{
		// The URL to open a new tree
		ASURL myNewTree = new ASURL(m_asOwner);

		// Tree creation and binding
		myNewTree.SetLinkCreateNewSpace(GlobalObjsTreeAS.STR_MVC_CLASS_NAME,
			m_asOwner);
		myNewTree.SetSubSpaceKey(((ISelectPTObjectModelRO) m_model).GetUniqueString(
			MigrationSelectForExportModel.SUBSPACE_KEY_GLOBALTREE));
		myNewTree.SetControl(GlobalObjsStartTreeControl.STR_MVC_CLASS_NAME);

		// Tree configuration
		myNewTree.AddControlArgument(AStartTreeControl.MULTI_SELECT, XPConvert.ToString(true));
		myNewTree.AddControlArgument(AStartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		myNewTree.AddControlArgument(AStartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_FORM_SPACE_ID,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				HTMLINPUT_GLOBAL_TREEASID));
		myNewTree.AddControlArgument(AStartTreeControl.PARENT_SUBMIT_CALL,
			((ISelectPTObjectModelRO) m_model).GetUniqueString(
				"OnReturnFromTree"));
		myNewTree.AddControlArgument(AStartTreeControl.CLASS_IDS_TO_DISPLAY,
			((ISelectPTObjectModelRO) m_model).GetObjectClassIDs());
		myNewTree.AddControlArgument(AStartTreeControl.SHOW_ROOT, XPConvert.ToString(false));

		if (_strSelectedItems.length() < 100)
		{
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
				_strSelectedItems);
		} else
		{
			// This list can be quite long for users, so we need to pass
			// it by reference.
			myNewTree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,
			_strSelectedItems, m_asOwner);	
		}

		myNewTree.AddControlArgument(AStartTreeControl.TITLE,
			m_asOwner.GetString(2796, "ptmsgs_portaladminmsgs"));
			
		// set the subtitle display string

		myNewTree.AddControlArgument(AStartTreeControl.ACTIONSUBTITLE, m_asOwner.GetString(2797, "ptmsgs_portaladminmsgs"));	
			
		return myNewTree;
	}
	
	/**
	 * Returns the HTML for the invisible add cell in the action bar.
     * This supports the drop down list of "Select Resources..." choices
	 *
	 * @return HTMLTableCell
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
        HTMLTableCell myCell = new HTMLTableCell();

		// hidden input with the tree space ID
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				((ISelectPTObjectModelRO) m_model).GetUniqueString(
					HTMLINPUT_ADMIN_TREEASID), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((MigrationSelectForExportModel) m_model).GetAdminTreeSpaceID());

		// hidden input with the tree space ID
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				((ISelectPTObjectModelRO) m_model).GetUniqueString(
					HTMLINPUT_DIR_TREEASID), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((MigrationSelectForExportModel) m_model).GetDirectoryTreeSpaceID());

		// hidden input with the tree space ID
		myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				((ISelectPTObjectModelRO) m_model).GetUniqueString(
					HTMLINPUT_GLOBAL_TREEASID), "");
		myCell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((MigrationSelectForExportModel) m_model).GetGlobalTreeSpaceID());

		return myCell;
	}
}

