package com.plumtree.portalpages.admin.ptutilities.migrationutility.exp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.xui.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.*;
import com.plumtree.portalpages.common.areyousure.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tempfile.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.uiinfrastructure.constants.*;

/**
 * 
 * @author jennifersu
 *
 */
public class MigrationUtilityExportModel extends MigrationUtilityModel implements IMigrationUtilityExportModelRO
{
	
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.exp.MigrationUtilityExportModel");

	public static final String STR_MVC_CLASS_NAME = "MigrationUtilityExportModel";
	
	/**
	 * The number of minutes we want our temp file to stick around.
	 */
	private static int TEMPFILE_MINUTES = 60;


    /**
     * The maximum characters in the package name prior to the extension. (".pte" will be appended).
     */
    private static final int MAX_PACKAGE_NAME_LENGTH = 60;

	/**
	 * The name of the session key into which we will be storing the filename to our export package.
	 */
	public static final String EXPORT_FILE_SESSION_KEY = "fdDownloadExportFile";

	/**
	 * The name of the session key into which we will be storing confirmation messages that the 
	 * AreYouSure popup can access and display.
	 */
	public static final String AYS_SESSION_KEY = "aysExportMessages";

	/**
	 * Migration Package name
	 */
	private String m_strPackageName;
	
	/**
	 * Package description
	 */
	private String m_strPackageDescription;

	/**
	 * Package publisher
	 */
	private String m_strPublisherName;

    /**
     * Export parent folders as objects if true, as references if false
     */
    private static final boolean ExportParentFoldersDefault = false;
    private boolean exportParentFolders = ExportParentFoldersDefault;

	/**
	 * Inits member variables
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		
		m_strPackageName = "";
		m_strPackageDescription = "";
		m_strPublisherName = "";
        exportParentFolders = ExportParentFoldersDefault;
	}

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		MigrationSelectForExportModel mySelectForExportModel = (MigrationSelectForExportModel) m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
		mySelectForExportModel.InitSFE(m_ptSession);

        StartXUIServicesSafely(XUIHelperMethods.XUI_MIGRATION_EXPORT_SERVICEID);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationUtilityExportModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()
	 */
	public void DoTaskBeforeStore()
	{
		super.DoTaskBeforeStore();

		try
		{
			for (int indService = 0; indService < m_alMWSIDs.GetSize(); indService++)
			{			
				// mj: save xui pbag
				XUIHelperModel myXUIModel = (XUIHelperModel) m_asOwner.GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indService);
				IXPPropertyBag pbXUISettings = myXUIModel.GetFinalXUISettings();
				m_htPropBags.PutElement(m_alMWSIDs.GetElement(indService), pbXUISettings);
			}
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Providers"), STR_MVC_CLASS_NAME + "::DoTaskBeforeStore", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(2, "ptmsgs_provUIMWS"));
		}
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		MigrationSelectForExportModel listModel = (MigrationSelectForExportModel) m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
		PTGrowableSortedArrayWrapper ptgsarItems = listModel.GetItems();

		if (m_alMWSIDs.GetSize() == 0)
		{
			if (ptgsarItems.GetCount() == 0)
			{
				String strError = m_asOwner.GetString(2775, "ptmsgs_portaladminmsgs");
				XPException e = new XPException(strError);
				GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "MigrationUtilityExportModel::Finish", 
					e, true, UIErrorLevel.FRIENDLY, strError);        	
			}			
		}

		DoTaskBeforeStore();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		if (_sPageName.equals(MigrationExportMainDP.STR_MVC_CLASS_NAME))
		{
			m_strPackageName = ModelHelper.GetFormElementString(_htFormData, MigrationGeneralInfoView.HTMLINPUT_PACKAGE_NAME, "");
			m_strPackageDescription = ModelHelper.GetFormElementString(_htFormData, MigrationGeneralInfoView.HTMLINPUT_PACKAGE_DESCRIPTION, "");
			m_strPublisherName = ModelHelper.GetFormElementString(_htFormData, MigrationGeneralInfoView.HTMLINPUT_PUBLISHER_NAME, "");
		}
		
		// Save select for export
		if (_sPageName.equals(MigrationExportPortalResourcesDP.STR_MVC_CLASS_NAME))
		{
            exportParentFolders = ModelHelper.GetFormCheckboxBool(_htFormData, ExportSettingsView.HTMLCHECKBOX_EXPORT_PARENT_FOLDERS);
			nPageStatus = ((MigrationSelectForExportModel) m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport)).SaveSection(_htFormData);
		}

		nPageStatus = super.SavePage(_sPageName, _htFormData);

		return nPageStatus;
	}
	
	/**
	 * Creates a new PTMigrationTask and spawns the new thread.
	 * 
	 */
	public void StartExport()
	{
		log.Info("Starting new migration task.");
		
		// Need to reset migration manager in case it's in Import mode
		// from loading existing packages
		ResetMigrationManager();
		
		// Temporarily write to this location
		String strExportFile = TempFile.CreateTempFile("odexport",
				FixPackageNameForFile(m_strPackageName), ".pte", TEMPFILE_MINUTES);

		// Initialize migration manager
		m_ptMigrationManager.InitializeForExport(strExportFile);
		
		// Set the export file path as the location for download in the session (to be used by
		// FileDownloadAS later).
		ISessionManager subSessionMgr = m_asOwner.GetSubSession();
		subSessionMgr.SetAttribute(EXPORT_FILE_SESSION_KEY, strExportFile);

		// Create a new PTMigrationTask and spawn new thread.
		MigrationSelectForExportModel listModel = (MigrationSelectForExportModel)m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
		PTGrowableSortedArrayWrapper listItems = listModel.GetItems();
        m_objMigrationTask = new PTExportMigrationTask(m_ptMigrationManager, m_ptSession, listItems, m_strPackageName, m_strPackageDescription, m_strPublisherName, exportParentFolders);
		((PTExportMigrationTask)m_objMigrationTask).SetMWSPropBags(m_htPropBags);
		XPThread migrationThread = new XPThread(m_objMigrationTask);
		migrationThread.SetBackground(true);
		migrationThread.Start();
	}
	
	/**
	 * Perform action when user Adds Exisiting Package
	 * (load resources into list)
	 */
	public void DoLoadPackage(XPHashtable _htFormData)
	{
		super.DoLoadPackage(_htFormData);
		MigrationSelectForExportModel listModel = (MigrationSelectForExportModel)m_asOwner.GetModel(MigrationUtilityExportAS.strStorageSelectForExport);
		listModel.LoadResources();
	}

	/**
	 * Clean up package name so that it will be a valid 
	 * file name.
	 * @param strIn
	 * @return String
	 */
	private String FixPackageNameForFile(String strIn)
	{
		String strDefault = "exportpackage";
		
		if (null == strIn)
		{
			return strDefault;
		}
		
		String strOut = GeneralHelpers.TruncateLongString(strIn, MAX_PACKAGE_NAME_LENGTH, false);
		strOut = strOut.trim();
		strOut = GeneralHelpers.Replace(strOut, ".", "");		
		strOut = GeneralHelpers.Replace(strOut, "\t", ""); 
		strOut = GeneralHelpers.Replace(strOut, "\r", "");
		strOut = GeneralHelpers.Replace(strOut, "\n", "");
		strOut = GeneralHelpers.Replace(strOut, "?", "");
		strOut = GeneralHelpers.Replace(strOut, "*", "");
		strOut = GeneralHelpers.Replace(strOut, "\\", "");
		strOut = GeneralHelpers.Replace(strOut, "/", "");
		strOut = GeneralHelpers.Replace(strOut, ":", "");
		strOut = GeneralHelpers.Replace(strOut, "\"", "");
		strOut = GeneralHelpers.Replace(strOut, "<", "");
		strOut = GeneralHelpers.Replace(strOut, ">", "");
		strOut = GeneralHelpers.Replace(strOut, "|", "");
		
		if (strOut.length() <= 0)
		{
			return strDefault;
		}
		
		return strOut;
			
	}
	
	/**
	 * Returns package name
	 */
	public String GetPackageName()
	{
		return m_strPackageName;
	}
	
	/**
	 * Returns package description
	 */
	public String GetPackageDescription()
	{
		return m_strPackageDescription;
	}
	
	/**
	 * Returns package publisher name
	 */
	public String GetPublisher()
	{
		return m_strPublisherName;
	}

    /**
     * When exporting dependencies, should the parent folders
     * and their dependencies also be exported?
     *
     * @return true to export parent folder dependencies as
     * objects and pull in their dependencies as well,
     * false to only add references in the dependency map
     */
    public boolean IsExportParentFoldersEnabled()
    {
        return exportParentFolders;
    }

    /**
	 * Get list of confirmation messages to 
	 * display in the AreYouSure popup
	 * @return
	 */
	public XPArrayList GetAYSMessages()
	{
		XPArrayList xpalMessages = new XPArrayList();
		String strMessage;
		strMessage = m_asOwner.GetString(3168, ResourceConstants.PORTALADMINMSGS);
        AYSMessage aysMessage = new AYSMessage(strMessage, AYSMessage.AYSTYPE_TOPLEVEL);
		xpalMessages.Add(aysMessage);
		return xpalMessages;
	}

    // mel: Fix for 46247, When a user exports objects from Collab or Publisher, no feedback is given that this was done. At least provide the UUID of the zip file in the final migration status.
    /**
     * @return XPArrayList of String each of which represents the return value from an MWS ExportPackage call with info about the MWS. If no MWS's are present or none responded, returns an empty list.
     */
    public XPArrayList GetMWSMessages()
    {
        if(m_objMigrationTask == null || m_objMigrationTask.GetMWSMessages() == null)
        {
            return new XPArrayList();
        }
        return m_objMigrationTask.GetMWSMessages();
    }
}
