package com.plumtree.portalpages.admin.ptutilities.migrationutility.imp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlelements.*;

public class ImportSettingsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.ImportSettingsView");

	public static final String STR_MVC_CLASS_NAME = "ImportSettingsView";

	public static final String HTMLCHECKBOX_IMPORT_ACLS	= "in_cb_ImportACLs";
	public static final String HTMLCHECKBOX_OVERWRITE_RS = "in_cb_OverwriteRS";
	public static final String HTMLCHECKBOX_REMEMBER_DEPENDENCY_SETTINGS = "in_cb_RememberDependencySettings";
	public static final String HTMLCHECKBOX_CREATE_NEW_OBJECTS = "in_cb_CreateNewObjs";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ImportSettingsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLInput myInput;

		try
		{
			IMigrationUtilityImportModelRO modelRO = (IMigrationUtilityImportModelRO) m_model;
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(2760, "ptmsgs_portaladminmsgs")));

			myTable = ViewHelper.AddTable(result);
			myTable.SetBorder("0");

			// 1st row (Top Margin)
			ViewHelper.AddEmptyRow(myTable, "3");

			// 2nd row
			DrawCheckBox(myTable, HTMLCHECKBOX_IMPORT_ACLS, "1",
				m_asOwner.GetString(2761, "ptmsgs_portaladminmsgs"),
				modelRO.GetImportACLs());

			// 3rd row
			DrawCheckBox(myTable, HTMLCHECKBOX_OVERWRITE_RS, "1",
				m_asOwner.GetString(2762, "ptmsgs_portaladminmsgs"),
				modelRO.GetOverwriteRemoteServers());

			// 4th row
			DrawCheckBox(myTable, HTMLCHECKBOX_REMEMBER_DEPENDENCY_SETTINGS, "1",
				m_asOwner.GetString(2763, "ptmsgs_portaladminmsgs"),
				modelRO.GetRememberDependencySettings());

			// 5th row
			DrawCheckBox(myTable, HTMLCHECKBOX_CREATE_NEW_OBJECTS, "1",
				m_asOwner.GetString(2764, "ptmsgs_portaladminmsgs"),
				modelRO.GetCreateNewObjectInstances());

			// last row (spacer row)
			ViewHelper.AddEmptyRow(myTable, "3");
		}
		catch (HTMLException e)
		{			
			log.Error(e, STR_MVC_CLASS_NAME +
				"::Display The following error occured when trying to display the HTML: " +
				e.GetMessage());
			
			throw new XPException(STR_MVC_CLASS_NAME + "::Display() Unknown error when trying to display HTML. ", e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = new HTMLScript("text/javaScript");
		return result;
	}

	/**
	* @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		super.Init(model, parent);
	}

	// Helper Function:
	private void DrawCheckBox(HTMLTable myTable, String strHTMLID,
		String strValue, String strUI, boolean bChecked)
	{
		ViewHelper.AddSimpleCheckbox(myTable, 3, strUI, strHTMLID, strValue, bChecked, "");
	}
}

