package com.plumtree.portalpages.admin.ptutilities.migrationutility.imp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

public class MigrationDependencyListView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationDependencyListView");

	public static final String STR_MVC_CLASS_NAME = "MigrationDependencyList";

	/**
	 * Hidden input to store the tree space ID of the dependency tree
	 */
	public static final String HTMLINPUT_DEPENDENCYTREEASID = "in_hi_DependencyTreeSpaceID";
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationDependencyListView();
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex Row index
	 *
	 * @return HTML for row
	 *
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Get cell containing dependency name
		result.AddInnerHTMLElement(GetHTMLForIconColumn(_saData, _nRowIndex));
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		// Get cell containing replacement name
		result.AddInnerHTMLElement(GetHTMLForReplacementColumn(_saData, _nRowIndex));

		// Get cell containing edit button
		result.AddInnerHTMLElement(GetHTMLForEdit(_saData, _nRowIndex));

		return result;
	}

	/**
	 * Returns null because rows are read-only in browse-mode.
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Table cell for action
	 *
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForRowAction(int _nRowIndex)
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * HTML for column containing unresolved dependency
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForNameColumn(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{		
		HTMLTableCell myCell = new HTMLTableCell(); // Note, we are not calling our super.
		myCell.SetWidth("45%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(false);

		HTMLSpan mySpan = new HTMLSpan();
		mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLElement(mySpan);

		try
		{
			MigrationDependencyListModel listModel = (MigrationDependencyListModel)m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME);
			// Object Name
			String strObjectName = XPConvert.ToString(_saData.GetItem(_nRowIndex, MigrationDependencyListModel.EXPLIST_COL_NAME));
			
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLEncodedString(XPConvert.ToString(strObjectName));
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.LIST_SUBHEAD);
			myCell.AddInnerHTMLElement(mySpan);			
			mySpan.AddInnerHTMLElement(new HTMLP());
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(2766, "ptmsgs_portaladminmsgs"));
			mySpan.AddInnerHTMLElement(new HTMLBr());
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);			
			
			CPTMigrationDependency cptmd = listModel.GetUnresolvedDependency(_nRowIndex);
			XPHashtable xphtDependents = cptmd.GetAllResolvableObjects();
			IXPEnumerator enumKeys = xphtDependents.GetKeys();
			while (enumKeys.MoveNext())
			{
				IPTMigrationElement ptME = (IPTMigrationElement)(xphtDependents.GetElement(enumKeys.GetCurrent()));
				mySpan.AddInnerHTMLString(SPACE);
				mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				mySpan.AddInnerHTMLString(ptME.GetName());
				mySpan.AddInnerHTMLElement(new HTMLBr());
			}
			mySpan.AddInnerHTMLElement(new HTMLP());
			
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetHTMLForNameColumn: Unknown Error e: " + e.getMessage());
		}

		return myCell;
	}
	
	/**
	 * 
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForIconColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell(); // Note, we are not calling our super.
		myCell.SetWidth("20");
		myCell.SetVAlign("top");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(false);

		mySpan = new HTMLSpan();
		mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.AddInnerHTMLString(SPACE);

		try
		{
			ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
			String strLangID = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE, m_asOwner);

			HTMLImg myImage;
			
			int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex,
						MigrationDependencyListModel.EXPLIST_COL_CLASSID));

			if (nClassID == PT_CLASSIDS.PT_PROFILESECTION_ID)
			{
				PTConstruct myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_LOCKBOX, true,
						this.m_asOwner);
				myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			}
			else
			{
				// Icon & Class descriptor
				myImage = ptClassTypeDescManager.GetDefaultIconForClassType(nClassID, strLangID);				
			}
			
			mySpan.AddInnerHTMLElement(myImage);
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetHTMLForIconColumn: Unknown Error e: " + e.getMessage());
		}

		return myCell;
	}

	/**
	 * HTML for column containing replacement
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForReplacementColumn(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{		
		HTMLTableCell myCell = new HTMLTableCell(); // Note, we are not calling our super.
		myCell.SetWidth("45%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(false);
		myCell.SetVAlign("top");

		HTMLSpan mySpan = new HTMLSpan();
		mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLElement(mySpan);

		try
		{
			// Object Name
			Object oPTObjectName = _saData.GetItem(_nRowIndex, MigrationDependencyListModel.EXPLIST_COL_NEW_NAME);			
			if (null == oPTObjectName)
			{
				mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				mySpan.AddInnerHTMLString(m_asOwner.GetString(2767, "ptmsgs_portaladminmsgs"));
			}
			else
			{
				mySpan.AddInnerHTMLString(SPACE);	
				mySpan.AddInnerHTMLEncodedString(XPConvert.ToString(oPTObjectName));
			}
	
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetHTMLForReplacementColumn: Unknown Error e: " + e.getMessage());
		}

		return myCell;
	}
	
	/**
	 * Returns HTML for edit button
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return HTML table cell for edit button
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForEdit(IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
		
		// Display the appropriate Edit or Browse icon
		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetNoWrap(true);
		myCell.SetWidth("5");
		myCell.SetVAlign("top");

		PTConstruct construct		 = null;
		HTMLAnchor myAnchor			 = null;
		PTButtonType myType = PTButtonType.EDIT;

		try
		{
			int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, MigrationDependencyListModel.EXPLIST_COL_CLASSID));
	
			// hidden input with the tree space ID
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_DEPENDENCYTREEASID + _nRowIndex, "");
			myInput.SetValue("");
			
			myCell.AddInnerHTMLElement(myInput);

			//	Get the construct, do update the strings.
			construct = UIConstructFactory.GetConstruct(myType, true, this.m_asOwner);
			construct.ReplaceNestedElementsWithHTMLString(myType.TITLE_ELEMENT_NAME, "");
			myAnchor = (HTMLAnchor) construct.GetNestedElement(myType.ANCHOR_ELEMENT_NAME);

			myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
			
			myAnchor.SetOnClick(((IMigrationDependencyListModelRO) m_model).GetUniqueString(
					"PosttoSelfOpenTree") + "(" + _nRowIndex + "); return false;");
			ConstructFactory.SetAltOnButtonImages( construct, m_asOwner.GetString(2768, "ptmsgs_portaladminmsgs"));
			ConstructFactory.SetTitleOnButtonImages( construct, m_asOwner.GetString(2768, "ptmsgs_portaladminmsgs"));			
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), STR_MVC_CLASS_NAME + "::GetHTMLForEdit", e, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(199, "ptmsgs_portalinfrastructure"));
		}

		myCell.AddInnerHTMLElement(construct.GetHTMLElement());

		return myCell;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		XPStringBuilder sb;

		try
		{
			// On return from Tree function
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((IMigrationDependencyListModelRO) m_model).GetUniqueString(
					"OnReturnFromDependencyTree") + "()");
			sb.Append(" {\n");
			sb.Append(" 	postToSelf('" +	MigrationDependencyListRepostControl.POSTTOSELF_ACTION_EDIT_DEPENDENCY + "');");
			sb.Append(" }\n");

			myScript.AddInnerHTMLString(sb.ToString());

			// post to self to open tree
			sb = new XPStringBuilder(200);
			sb.Append(" function " +
				((IMigrationDependencyListModelRO) m_model).GetUniqueString(
					"PosttoSelfOpenTree") + "(varRowIndex)");
			sb.Append(" {\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(((IExpListModelRO) m_model).GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
			sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("('" +	MigrationDependencyListRepostControl.POSTTOSELF_ACTION_OPEN_DEPENDENCY_TREE + "');\n");
			sb.Append(" }\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{	
			log.Error(he, STR_MVC_CLASS_NAME + "::DisplayJavascript The following error occured when trying to display the JavaScript: " + he.GetMessage());			
		}

		return myScript;
	}
}

