package com.plumtree.portalpages.admin.ptutilities.migrationutility.imp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 */
public class MigrationSelectForImportView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationSelectForImportView");

	/** 
	 * Class name for the activity space 
	 */
	public static final String STR_MVC_CLASS_NAME = "MigrationSelectForImportView";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationSelectForImportView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForCheckBox(int)
	 */
	protected HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)

	{
		HTMLTableCell myCell = new HTMLTableCell();
		MigrationSelectForImportModel myModel = (MigrationSelectForImportModel)m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
		PTGrowableSortedArrayWrapper saData = myModel.GetItems();   
		int nClassID = XPConvert.ToInteger(saData.GetItem(_nRowIndex, MigrationSelectForImportModel.EXPLIST_COL_CLASSID));
		if (nClassID != PT_CLASSIDS.PT_GUESTLOGIN_ID)
		{
		   	myCell = super.GetHTMLForCheckBox(_nRowIndex);
			myCell.SetVAlign("top");
		}
		
		return myCell;
	}

	/**
	 * 
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForNameColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLBr myBr;

		myCell = new HTMLTableCell(); // Note, we are not calling our super.
		myCell.SetWidth("100%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(false);

		mySpan = new HTMLSpan();
		mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.AddInnerHTMLElement(mySpan);

		try
		{
			// Object Name
			Object oPTObjectName = _saData.GetItem(_nRowIndex, MigrationSelectForImportModel.EXPLIST_COL_NAME);
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLEncodedString((String) oPTObjectName);

			// Try to add an Object Description		
			Object oPTObjectDesc = _saData.GetItem(_nRowIndex, MigrationSelectForImportModel.EXPLIST_COL_DESCRIPTION);

			if (null != oPTObjectDesc)
			{
				// Add a break;
				myBr = new HTMLBr();
				mySpan.AddInnerHTMLElement(myBr);

				// Add the Description.
				mySpan.AddInnerHTMLString(SPACE);
				mySpan.AddInnerHTMLEncodedString(XPConvert.ToString(oPTObjectDesc));
			}
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::GetHTMLForNameColumn: Unknown Error e: " + e.getMessage());
		}

		return myCell;
	}

    // mel: TODO Refactor this into a separate class shared by MigrationSelectForExportView and MigrationSelectForImportView
    public static HTMLTableCell GetHTMLForIconColumn(
        IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex, int viewIconColumnID, String languageID)
    {
        HTMLTableCell myCell;
        HTMLSpan mySpan;

        myCell = new HTMLTableCell(); // Note, we are not calling our super.
        myCell.SetWidth("20");
        myCell.SetVAlign("top");
        myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.SetNoWrap(false);

        mySpan = new HTMLSpan();
        mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
        myCell.AddInnerHTMLElement(mySpan);

        try
        {
            HTMLImg myImage;
            int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, viewIconColumnID));

            if (nClassID == PT_CLASSIDS.PT_ACTIVITY_ID)
            {
                myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_ACTIVITY_RIGHT_CUSTOM).GetHTMLElement();
            }
            else if (nClassID == PT_CLASSIDS.PT_SITEMAPFOLDER_ID)
            {
                myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER).GetHTMLElement();
            }
            else if (nClassID == PT_CLASSIDS.PT_EXPRESSION_ID)
            {
                myImage = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SUBPORTAL_RULE).GetHTMLElement();
            }
            else
            {
                // Icon & Class descriptor
                ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
                myImage = ptClassTypeDescManager.GetDefaultIconForClassType(nClassID, languageID);

                // mel: Fix for 43881, use a different icon for catalog folders. TODO Create a PTImageType for this image.
                if (nClassID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
                {
                    HTMLImg substituteImage = new HTMLImg("portal/public/img/icon_folder_contents.gif", myImage.GetAlt());
                    myImage = substituteImage;
                }
            }
            mySpan.AddInnerHTMLElement(myImage);
        }
        catch (Exception e)
        {
            log.Error(e, STR_MVC_CLASS_NAME + "::GetHTMLForIconColumn: Unknown Error e: " + e.getMessage());
        }

        return myCell;
    }

	/**
	 * 
	 * @param _saData
	 * @param _nRowIndex
	 * @return
	 */
	protected HTMLTableCell GetHTMLForIconColumn(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)
	{
        String languageID
            = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(
            PersonalSettingNames.LANGUAGE, m_asOwner);
        return MigrationSelectForImportView.GetHTMLForIconColumn(
            _saData,
            _nRowIndex,
            MigrationSelectForImportModel.EXPLIST_COL_CLASSID,
            languageID
            );
	}

	/**
	 * Helper method to add a BR tag to another element.
	 */
	protected void AddLineBreaks(HTMLElement myElement, int nNumBreaks)
	{
		for (int nIndex = 0; nIndex < nNumBreaks; nIndex++)
		{
			HTMLBr myBr = new HTMLBr();
			myElement.AddInnerHTMLElement(myBr);
		}
	}
	
	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		return myScript;
	}

  /**
	* Returns the HTML for the row _nRowIndex.
	* Each row contains just an icon and input text.
	*
	* @param _saData
	* @param _nRowIndex
	*
	* @return HTMLElement
	*/
   public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
	   int _nRowIndex)
   {
	   HTMLElementCollection result = new HTMLElementCollection();
	   int nClassID = XPConvert.ToInteger(_saData.GetItem(_nRowIndex, MigrationSelectForImportModel.EXPLIST_COL_CLASSID));
	   if (nClassID != PT_CLASSIDS.PT_GUESTLOGIN_ID)
	   {
		   result.AddInnerHTMLElement(GetHTMLForIconColumn(_saData, _nRowIndex));
		   result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));
	   }
	   return result;
   }

}

