package com.plumtree.portalpages.admin.ptutilities.migrationutility.imp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.xui.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.*;
import com.plumtree.portalpages.common.areyousure.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;

/**
 * 
 * @author jennifersu
 *
 */
public class MigrationUtilityImportModel extends MigrationUtilityModel implements IMigrationUtilityImportModelRO
{
	
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.MigrationUtilityImportModel");

	public static final String STR_MVC_CLASS_NAME = "MigrationUtilityImportModel";
	
	/**
	 * The name of the session key into which we will be storing confirmation messages that the 
	 * AreYouSure popup can access and display.
	 */
	public static final String AYS_SESSION_KEY = "aysImportMessages";

	/**
	 * Import ACLs setting
	 */
	private boolean m_bImportACLs;
	
	/**
	 * Overwrite Remote Servers setting
	 */
	private boolean m_bOverwriteRemoteServers;
	
	/**
	 * Remember Dependency Settings setting
	 */
	private boolean m_bRememberDependencySettings;
	
	/**
	 * Create New Object Instances setting
	 */
	private boolean m_bCreateNewObjectInstances;

	/**
	 * Inits member variables
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		m_ptSession = (IPTSession) m_asOwner.GetUserSession();
		m_bImportACLs = true;
		m_bOverwriteRemoteServers = false;
		m_bRememberDependencySettings = true;
		m_bCreateNewObjectInstances = false;
	}

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		((MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME)).InitializeDependencies();
		MigrationSelectForImportModel mySelectForImportModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
		mySelectForImportModel.InitSFE(m_ptSession);

        StartXUIServicesSafely(XUIHelperMethods.XUI_MIGRATION_IMPORT_SERVICEID);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MigrationUtilityImportModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskBeforeStore()
	 */
	public void DoTaskBeforeStore()
	{
		super.DoTaskBeforeStore();

		try
		{
			for (int indService = 0; indService < m_alMWSIDs.GetSize(); indService++)
			{			
				// mj: save xui pbag
				XUIHelperModel myXUIModel = (XUIHelperModel) m_asOwner.GetModel(XUIHelperModel.STR_MVC_CLASS_NAME + indService);
				IXPPropertyBag pbXUISettings = myXUIModel.GetFinalXUISettings();
				m_htPropBags.PutElement(m_alMWSIDs.GetElement(indService), pbXUISettings);
			}
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Providers"), STR_MVC_CLASS_NAME + "::DoTaskBeforeStore", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(2, "ptmsgs_provUIMWS"));
		}
	}

    // mel: Fix for 45506, previously unable to import collab only resources
    public boolean HasObjectsForMigration()
    {
        boolean rval = false;

        MigrationSelectForImportModel listModel = (MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
        PTGrowableSortedArrayWrapper ptgsarItems = listModel.GetItems();

        if(ptgsarItems.GetCount() > 0)
        {
            rval = true;
        }
        else
        {
            rval = super.HasObjectsForMigration();
        }

        return rval;
    }

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		MigrationLoadPackageModel loadModel = (MigrationLoadPackageModel)m_asOwner.GetModel(MigrationLoadPackageModel.strStorageLoadPackage);
		if (!loadModel.IsPackageLoaded())
		{
			String strError = m_asOwner.GetString(3131, "ptmsgs_portaladminmsgs");
			XPException e = new XPException(strError);
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "MigrationUtilityImportModel::Finish ", 
				e, true, UIErrorLevel.FRIENDLY, strError);			
		}
		
		if(!HasObjectsForMigration())
		{
			String strError = m_asOwner.GetString(2780, "ptmsgs_portaladminmsgs");
			XPException e = new XPException(strError);
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "MigrationUtilityImportModel::Finish ", 
				e, true, UIErrorLevel.FRIENDLY, strError);        	
		}
		
		MigrationDependencyListModel depModel = (MigrationDependencyListModel)m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME);
		if (depModel.UnresolvedDependenciesExist())
		{		
			String strError = m_asOwner.GetString(2781, "ptmsgs_portaladminmsgs");
			XPException e = new XPException(strError);
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "MigrationUtilityImportModel::Finish ", 
				e, true, UIErrorLevel.FRIENDLY, strError);        	
		}
		
		if (m_bRememberDependencySettings)
		{
			PTGrowableSortedArrayWrapper ptgsarDeps =  depModel.GetItems();
			String strPortalUUID = m_ptMigrationManager.GetPackageSourcePortalUUID();
			for (int indDep = 0; indDep < ptgsarDeps.GetCount(); indDep++)
			{
				String strOldUUID = XPConvert.ToString(ptgsarDeps.GetItem(indDep, MigrationDependencyListModel.EXPLIST_COL_UUID));
				String strNewUUID = XPConvert.ToString(ptgsarDeps.GetItem(indDep, MigrationDependencyListModel.EXPLIST_COL_NEW_UUID));
				m_ptMigrationManager.StoreMappingInProfile(strPortalUUID, strOldUUID, strNewUUID);
			}
		}

		DoTaskBeforeStore();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;

		if (_sPageName.equals(MigrationImportMainDP.STR_MVC_CLASS_NAME))
		{
			m_bCreateNewObjectInstances = ModelHelper.GetFormCheckboxBool(_htFormData, ImportSettingsView.HTMLCHECKBOX_CREATE_NEW_OBJECTS);
			m_bImportACLs = ModelHelper.GetFormCheckboxBool(_htFormData, ImportSettingsView.HTMLCHECKBOX_IMPORT_ACLS);
			m_bOverwriteRemoteServers = ModelHelper.GetFormCheckboxBool(_htFormData, ImportSettingsView.HTMLCHECKBOX_OVERWRITE_RS);
			m_bRememberDependencySettings = ModelHelper.GetFormCheckboxBool(_htFormData, ImportSettingsView.HTMLCHECKBOX_REMEMBER_DEPENDENCY_SETTINGS);			
			if(!HasObjectsForMigration())
			{
				nPageStatus = RepostControl.PAGE_STATUS_INVALID;
                String errorMessage = m_asOwner.GetString(3176, ResourceConstants.PORTALADMINMSGS);
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null,
					errorMessage,
                    errorMessage);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
		}
		
		// Save select for import
		if (_sPageName.equals(MigrationDependenciesDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = ((MigrationDependencyListModel) m_asOwner.GetModel(MigrationDependencyListModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
		}

		// Save select for import
		if (_sPageName.equals(MigrationImportPortalResourcesDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = ((MigrationSelectForImportModel) m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport)).SaveSection(_htFormData);
		}

		nPageStatus = super.SavePage(_sPageName, _htFormData);

		return nPageStatus;
	}
	
	/**
	 * Creates a new PTMigrationTask and spawns the new thread.
	 * 
	 * @return  
	 */
	public void StartImport()
	{
		log.Info("Starting new migration task.");
		
		// Initialize migration manager
		m_ptMigrationManager.InitializeForImport("");
		
		// Load IPTMigrationElements by classID into XPArrayList[] for migration.
		XPArrayList[] objsToMigrate = PrepareObjectsForPackage();
		
		// Create a new PTMigrationTask and spawn new thread.
		m_objMigrationTask = new PTImportMigrationTask(m_ptMigrationManager, 
								objsToMigrate, 
								m_bCreateNewObjectInstances, 
								m_bImportACLs, 
								m_bOverwriteRemoteServers, 
								m_bRememberDependencySettings);
		XPThread migrationThread = new XPThread(m_objMigrationTask);
		migrationThread.SetBackground(true);
		migrationThread.Start();
	}
	
	/**
	 * Perform action when user Loads Package
	 * (load resources into list)
	 */
	public void DoLoadPackage(XPHashtable _htFormData)
	{
		super.DoLoadPackage(_htFormData);
		MigrationSelectForImportModel listModel = (MigrationSelectForImportModel)m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
		listModel.LoadResources();
	}
	
	/**
	 * Gets the Import ACLs setting
	 * @return boolean
	 */
	public boolean GetImportACLs()
	{
		return m_bImportACLs;
	}
	
	/**
	 * Gets the Remember Dependency Settings settings
	 * @return boolean
	 */
	public boolean GetRememberDependencySettings()
	{
		return m_bRememberDependencySettings;
	}
	
	/**
	 * Gets the Overwrite Remote Servers settings
	 * @return boolean
	 */
	public boolean GetOverwriteRemoteServers()
	{
		return m_bOverwriteRemoteServers;
	}
	
	/**
	 * Gets the Create New Object Instances settings
	 * @return boolean
	 */
	public boolean GetCreateNewObjectInstances()
	{
		return m_bCreateNewObjectInstances;
	}

	/**
	 * array of XPArrayLists containing IPTMigrationElements to
	 * migrate, indexed by classID.
	 */
	private XPArrayList[] PrepareObjectsForPackage()
	{
		MigrationSelectForImportModel listModel = (MigrationSelectForImportModel)m_asOwner.GetModel(MigrationUtilityImportAS.strStorageSelectForImport);
		return listModel.GetObjectsToMigrate();
	}

	/**
	 * Get list of confirmation messages to 
	 * display in the AreYouSure popup
	 * @return
	 */
	public XPArrayList GetAYSMessages()
	{
		XPArrayList xpalMessages = new XPArrayList();
		String strMessage;
		strMessage = m_asOwner.GetString(3169, ResourceConstants.PORTALADMINMSGS);
        AYSMessage aysMessage = new AYSMessage(strMessage, AYSMessage.AYSTYPE_TOPLEVEL);
		xpalMessages.Add(aysMessage);
		return xpalMessages;
	}
}

