package com.plumtree.portalpages.admin.ptutilities.migrationutility.imp;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.ptutilities.migrationutility.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;

/**
 * This class is what calls the actual server migration code.
 * It runs in a separate thread to prevent UI timeouts.
 * 
 * @author jennifersu
 *
 */
public class PTImportMigrationTask extends PTMigrationTask {

	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.migrationutility.imp.PTImportMigrationTask");

	/**
	 * array of XPArrayLists containing IPTMigrationElements to
	 * migrate, indexed by classID.
	 */
	private XPArrayList[] m_xparObjsToMigrate;
	
	/**
	 * Import ACLs setting
	 */
	private boolean m_bImportACLs;
	
	/**
	 * Overwrite Remote Servers setting
	 */
	private boolean m_bOverwriteRemoteServers;
	
	/**
	 * Remember Dependency Settings setting
	 */
	private boolean m_bRememberDependencySettings;
	
	/**
	 * Create New Object Instances setting
	 */
	private boolean m_bCreateNewObjectInstances;
	
	/**
	 * Sets status to CREATED.
	 * Initializes array of objects to migrate
	 */
	public PTImportMigrationTask(IPTMigrationManager _MigrationManager, XPArrayList[] _xparObjsToMigrate, boolean _bCreateNewObjectInstances, boolean _bImportACLs, boolean _bOverwriteRemoteServers, boolean _bRememberDependencySettings)
	{
		super(_MigrationManager);
		
		m_xparObjsToMigrate = _xparObjsToMigrate;
		m_bImportACLs = _bImportACLs;
		m_bOverwriteRemoteServers = _bOverwriteRemoteServers;
		m_bRememberDependencySettings = _bRememberDependencySettings;
		m_bCreateNewObjectInstances = _bCreateNewObjectInstances;
	}

	/**
	 * Performs the actual migration.
	 */
	public void run() 
	{
		m_intStatus = INPROGRESS;
		log.Info("Migration Task in progress.");

		try
		{
			m_MigrationManager.PerformImport(m_xparObjsToMigrate, m_bCreateNewObjectInstances, m_bImportACLs, m_bOverwriteRemoteServers, m_bRememberDependencySettings);
			if (m_intStatus == CANCEL)
			{
				log.Info("Migration Task cancelled.");
				return;
			}

			m_MigrationManager.ImportMigrationWebServices();
			
			// End the import
			m_MigrationManager.EndImport();
				
			m_intStatus = DONE;
			log.Info("Migration Task completed.");
		}
		catch (Exception e)
		{
			m_intStatus = FAILED;
			log.Error(e, "PTImportMigrationTask::run Unknown error importing package.");
		}
	}


    // mel: Fix for 45685, the Cancel button does not kill the import task
    public void Cancel()
    {
        // No need to synchronize since m_MigrationManager is assigned in ctor
        if(m_MigrationManager != null)
        {
            // CancelImport is synchronized
            m_MigrationManager.CancelImport();
        }
        super.Cancel();
    }
}
