package com.plumtree.portalpages.admin.ptutilities.objectlockmanager;


// Framework Imports
import com.plumtree.openfoundation.util.XPConvert;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.ClassTypeDescManager;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.IPTClassTypeDesc;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTConfigHelper;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.PersonalSettingsHelper;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Main Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author John Hogan
 */
public class ObjectLockManagerAS extends PTEditorAS
{
	// All the AS in Plumtree need to have a unique name.

	/** The unique identifier for this activity space */
	public static final String STR_MVC_CLASS_NAME = "ObjectLockManager";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectLockManagerAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(1534, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	// Strings to localize.

	/** Localized String: Main Editor */

	/** Localized String: General Settings */

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (ObjectLockManagerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = ObjectLockManagerModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();
        
        String strLanguage = null;
        
        try {
            strLanguage = XPConvert.ToString(PersonalSettingsHelper.GetPersonalSettingValue
                (PersonalSettingsHelper.LANGUAGE, this));
        } catch (Exception e) {}

		IModel myModel = GetModel(ObjectLockManagerModel.STR_MVC_CLASS_NAME);
        ClassTypeDescManager ptClassTypeDescManager = PTConfigHelper.GetPTClassTypeDescrManager();
        IPTClassTypeDesc[] allClassTypes = ptClassTypeDescManager.GetLockManagerClassTypes(strLanguage);
        
        int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1535, "ptmsgs_portaladminmsgs"));
        LockManagerObjectDP tmpLMO = null, firstObject = null;
        
        for (int i = 0; i < allClassTypes.length; i++) {
            tmpLMO = new LockManagerObjectDP(allClassTypes[i]);
            if (firstObject == null) {
                firstObject = tmpLMO;
            }
            RegisterPage(tmpLMO);
            m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, tmpLMO.GetName());
        }

		// Register Views
		RegisterView(ObjectLockManagerView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(ObjectLockManagerRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		// Set default page
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(firstObject.GetName());
		// END Sub menu "General Settings"
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 * Sets the help links for the object locks utility
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page) {
		super.SetCurrentPage(page);

		// set the help for all pages to this url -mgs
		this.SetHelpTopic("PT_ItemLocks");
	}
}

