package com.plumtree.portalpages.admin.ptutilities.objectlockmanager;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section represents a section of the main page
 * of the Misc Editor.
 * This Section is printed out by Misc2DP.
 *
 * @author John Hogan
 */
public class ObjectLockManagerView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.objectlockmanager.ObjectLockManagerView");

	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "ObjectLockManagerView";

	// HTML Object names.
	/** Locked checkbox */
	public static final String HTMLCHECKBOX_LOCKED = "in_cb_Unlock";
	
	/** Check All checkbox */
	public static final String HTMLCHECKBOX_CHECKALL = "in_cb_CheckAll";
	
	/** Javascript function for checking all objects */
	public static final String JAVASCRIPT_CHECKALL = "CheckAllObjects";
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectLockManagerView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;
		PTConstruct myConstruct;
		HTMLImg myImage;

		try
		{
			//SS - Upon entering the view, initialize the model with the locked objects for this
			//particular class
			((ObjectLockManagerModel) m_asOwner.GetModel(ObjectLockManagerModel.STR_MVC_CLASS_NAME)).SetLocks();
			
			result.AddInnerHTMLElement(new HTMLComment("Begin: Display ObjectLockManagerView"));

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						1552, "ptmsgs_portaladminmsgs")));

			//Now add a banner HTML construct
			//	Now we get a banner construct, and add a button to the extendable cell of the banner.
			PTConstruct construct		  = null;
			PTConstruct myButtonConstruct = null;
			PTBannerType myType			  = PTBannerType.OBJECT_ACTION_BAR;

			construct					  = UIConstructFactory.GetConstruct(myType,
					true, this.m_asOwner);

			try
			{
				//	Get a button construct
				PTButtonType myButtonType = PTButtonType.UNLOCK_OBJ_ACTIONBAR;
				myButtonConstruct = UIConstructFactory.GetConstruct(myButtonType,
						true, this.m_asOwner);
						
				myButtonConstruct.ReplaceNestedElementsWithHTMLString(myButtonType.TITLE_ELEMENT_NAME,
				
					
				m_asOwner.GetString(1554, "ptmsgs_portaladminmsgs"));
				
				ConstructFactory.SetTitleOnButtonImages( myButtonConstruct, 
										m_asOwner.GetString(1554, "ptmsgs_portaladminmsgs") );
				
				//myButtonConstruct.
				myButtonConstruct.GetHTMLElement().SetOnClick("postToSelf(" +
					ObjectLockManagerRepostControl.POSTTOSELF_ACTION_UNLOCK +
					"); return false;");

				//	Add the button's HTMLElement to the extendable cell of the banner.
				construct.AddElementToNestedElement(myType.EXTENDABLE_CELL_ELEMENT_NAME,
					myButtonConstruct.GetHTMLElement());
			}
			catch (Exception e)
			{
				// TODO CR DLH: Why do we ignore this?
			}

			result.AddInnerHTMLElement(construct.GetHTMLElement());

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding(CommonHTMLStrings.TWO);
			myTable.SetCellSpacing(CommonHTMLStrings.TWO);

			// 1st Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

			//first cell
			myCell = new HTMLTableCell();
			myCell.SetAlign(CommonHTMLStrings.CENTER);
			myCell.SetVAlign(CommonHTMLStrings.MIDDLE);
			myCell.SetWidth("20");
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_CHECKALL,
					m_asOwner.GetString(1552, "ptmsgs_portaladminmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			myInput.SetOnClick(JAVASCRIPT_CHECKALL + "(); return true;");
			myCell.AddInnerHTMLElement(myInput);

			//second cell
			myCell = new HTMLTableCell();
			myCell.SetHeight("20");
			myRow.AddInnerHTMLElement(myCell);
			//mySpan = new HTMLSpan();
			//myCell.AddInnerHTMLElement(mySpan);
			//mySpan.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			//mySpan.AddInnerHTMLString(m_asOwner.GetString(1555,
			//		"ptmsgs_portaladminmsgs"));
					
			HTMLAnchor myAnchor;
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.AddInnerHTMLString(m_asOwner.GetString(1555,
					"ptmsgs_portaladminmsgs"));

			//if (PT_PROPIDS.PT_PROPID_NAME == ((IObjectLockManagerModelRO) m_model).GetSortColumn())
			//{
				if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IObjectLockManagerModelRO) m_model).GetSortDirection())
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
							true, this.m_asOwner);
					
					myAnchor.SetOnClick("postToSelf(" +
						ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
											"); return false;");
											
					
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1562,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}
				else
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
							true, this.m_asOwner);
							
					myAnchor.SetOnClick("postToSelf(" +
											ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
																"); return false;");
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1563,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}

				
			//}
			myCell.AddInnerHTMLElement(myAnchor);

			//third cell
			myCell = new HTMLTableCell();
			myCell.SetHeight("20");
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			
			
			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.AddInnerHTMLString(m_asOwner.GetString(1557,
					"ptmsgs_portaladminmsgs"));


			

			//if (((IObjectLockManagerModelRO) m_model).GetSortColumn() == PT_PROPIDS.PT_PROPID_OBJLOCK_FROMMACHINENAME)
			//{
				if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IObjectLockManagerModelRO) m_model).GetSortDirection())
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
							true, this.m_asOwner);
							
					myAnchor.SetOnClick("postToSelf(" +
											ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
																"); return false;");
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1562,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}
				else
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
							true, this.m_asOwner);
					myAnchor.SetOnClick("postToSelf(" +
											ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
																"); return false;");
																
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1563,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}

			myCell.AddInnerHTMLElement(myAnchor);
			//}

			//fourth cell
			myCell = new HTMLTableCell();
			myCell.SetHeight("20");
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
						myAnchor.AddInnerHTMLString(m_asOwner.GetString(1558,
								"ptmsgs_portaladminmsgs"));

			//if (((IObjectLockManagerModelRO) m_model).GetSortColumn() == PT_PROPIDS.PT_PROPID_OBJLOCK_ACQUIREDAT)
			//{
				if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IObjectLockManagerModelRO) m_model).GetSortDirection())
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
							true, this.m_asOwner);
					
					myAnchor.SetOnClick("postToSelf(" +
								ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
								"); return false;");			
					
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1562,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}
				else
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
							true, this.m_asOwner);
					myAnchor.SetOnClick("postToSelf(" +
													ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
													"); return false;");
													
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1563,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}

			myCell.AddInnerHTMLElement(myAnchor);
			//}

			//fifth cell
			myCell = new HTMLTableCell();
			myCell.SetHeight("20");
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
						myAnchor.AddInnerHTMLString(m_asOwner.GetString(1559,
								"ptmsgs_portaladminmsgs"));

			//if (((IObjectLockManagerModelRO) m_model).GetSortColumn() == PT_PROPIDS.PT_PROPID_OBJLOCK_LOCKINGUSERID)
			//{
				if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IObjectLockManagerModelRO) m_model).GetSortDirection())
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
							true, this.m_asOwner);
					
					myAnchor.SetOnClick("postToSelf(" +
													ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
													"); return false;");	
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1562,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}
				else
				{
					myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
							true, this.m_asOwner);
							
					myAnchor.SetOnClick("postToSelf(" +
										ObjectLockManagerRepostControl.POSTTOSELF_ACTION_SORT +
										"); return false;");
																		
					myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

					myImage.SetAlt(m_asOwner.GetString(1563,
							"ptmsgs_portaladminmsgs"));
					myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
					myImage.SetBorder(CommonHTMLStrings.ZERO);
					myAnchor.AddInnerHTMLElement(myImage);
				}

			myCell.AddInnerHTMLElement(myAnchor);
			//}

			// Add the other rows
			HTMLElementCollection myRows = null;	
			myRows = GetLockTable(((IObjectLockManagerModelRO) m_model).GetLockedItemsFromHashtable(((IObjectLockManagerModelRO) m_model).GetClassID()));

			if (null != myRows)
			{
				myTable.AddInnerHTMLElement(myRows);
			}

			result.AddInnerHTMLElement(new HTMLComment("End: Display ObjectLockManagerView"));
		}
		catch (Exception e)
		{
			GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "ObjectLockManagerView::Display", e, false, UIErrorLevel.SERIOUS, m_asOwner.GetString(1560, "ptmsgs_portaladminmsgs"));
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		XPStringBuilder sb;
		sb = new XPStringBuilder(300);

		try
		{
			// JavaScript to check all the rows
			// JavaScript to check all the rows
			sb.Append("function " + JAVASCRIPT_CHECKALL +
				"()\n");
			sb.Append("{ \n");
			sb.Append("  var frm = document." + AFormDP.HTMLFORM_NAME +
				"; \n");
			sb.Append("  var len = frm.elements.length; \n");
			sb.Append("  var nValue = frm." +
				HTMLCHECKBOX_CHECKALL + ".checked; \n");
			sb.Append("  var i = 0; \n");
			sb.Append("  \n");
			sb.Append("  for(i=0 ; i<len ; i++) \n");
			sb.Append("  { \n");
			sb.Append("    if (frm.elements[i].name == '" +
				HTMLCHECKBOX_LOCKED +
				"') \n");
			sb.Append("    { \n");
			sb.Append("       if (frm.elements[i].disabled == false)\n");
			sb.Append("           frm.elements[i].checked = nValue;\n");
			sb.Append("    } \n");
			sb.Append("  } \n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			//javascript to check individual items
			sb = new XPStringBuilder(200);
			sb.Append("function CheckItem(strItemName)\n");
			sb.Append("{ \n");
			sb.Append("  var frm = document." + EditorDP.HTMLFORM_NAME +
				"; \n");
			sb.Append("  frm.elements[strItemName].value = 1;\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "ObjectLockManagerView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 *
	 * @author johnh
	 *
	 * Utility function to generate a table for locked items.
	 */
	public HTMLElementCollection GetLockTable(PTSortedArrayWrapper arrLocks)
	{
		HTMLElementCollection result = null;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		if (null != arrLocks)
		{
			int intRowCount = arrLocks.GetCount();

			if (0 != intRowCount)
			{
				result = new HTMLElementCollection();
			}

			try
			{
				for (int k = 0; k < intRowCount; k++)
				{
					//row begin
					myRow = new HTMLTableRow();
					result.AddInnerHTMLElement(myRow);

					if ((k % 2) == 1)
					{
						myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
					}
					else
					{
						myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
					}

					//first cell
					myCell = new HTMLTableCell();
					myCell.SetAlign("center");
					myCell.SetVAlign("middle");
					myCell.SetWidth("20");
					myCell.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
					myRow.AddInnerHTMLElement(myCell);

					myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLCHECKBOX_LOCKED,
							m_asOwner.GetString(1553, "ptmsgs_portaladminmsgs"));
					myInput.SetValue(XPConvert.ToString(k));
					myCell.AddInnerHTMLElement(myInput);

					//second cell
					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetHeight("20");
					myCell.SetWidth("100%");
					myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan = new HTMLSpan();
					mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan.AddInnerHTMLEncodedString((String) arrLocks.GetItem(k,
							PT_PROPIDS.PT_PROPID_NAME));
					myCell.AddInnerHTMLElement(mySpan);

					//third cell
					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetHeight("20");
					myCell.SetWidth("100%");
					myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan = new HTMLSpan();
					mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan.AddInnerHTMLString((String) arrLocks.GetItem(k,
							PT_PROPIDS.PT_PROPID_OBJLOCK_FROMMACHINENAME));
					myCell.AddInnerHTMLElement(mySpan);

					//fourth cell
					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetHeight("20");
					myCell.SetWidth("100%");
					myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan = new HTMLSpan();
					mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);

					XPDateTime dtAcquired = (XPDateTime) arrLocks.GetItem(k,
							PT_PROPIDS.PT_PROPID_OBJLOCK_ACQUIREDAT);

					XPDateFormat dtFmt = PTPersonalSettingsHelper.GetPersonalDateTimeFormat(m_asOwner,
																			  /* use portal server time zone */ false);
					mySpan.AddInnerHTMLString(dtFmt.Format(dtAcquired));
					myCell.AddInnerHTMLElement(mySpan);

					//fifth cell
					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetHeight("20");
					myCell.SetWidth("100%");
					myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan = new HTMLSpan();
					mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
					mySpan.AddInnerHTMLString((String) arrLocks.GetItem(k,
							PT_PROPIDS.PT_PROPID_OBJLOCK_LOCKINGUSERID));
					myCell.AddInnerHTMLElement(mySpan);

					//Row End
				}
			}
			catch (Exception e)
			{
				
					log.Error(e, "ObjectLockManagerView::GetLockTable The following error occured when trying to display the HTML: " +
						e.getMessage());
				

				throw new XPException(m_asOwner.GetString(1561,
						"ptmsgs_portaladminmsgs"), e);
			}
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}


