package com.plumtree.portalpages.admin.ptutilities.settings;

import com.plumtree.openfoundation.internationalization.XPResourceManager;
import com.plumtree.portalpages.admin.ptutilities.IPlumtreeUtilities;
import com.plumtree.portalpages.browsing.directory.DirAS;
import com.plumtree.portalpages.browsing.directory.DirConstants;
import com.plumtree.portalpages.common.folder.OpenSubFolderControl;
import com.plumtree.server.PT_ACTIVITY_RIGHTS;
import com.plumtree.server.PT_INTRINSICS;
import com.plumtree.uiinfrastructure.application.varpacks.AppConstants;
import com.plumtree.uiinfrastructure.web.ApplicationManager;
import com.plumtree.uiinfrastructure.web.IApplication;

/*
 * A PTUtility item which lets users within groups with 'Access Unclassifed Document'
 * ActivityRight go to edit mode within the unclassifed documents. This lets users to
 * modify unclassified documents even if they dont have edit rights on the knowledge
 * directory. However, they would need a way to access the PTUtilies.
 */

/**
 * @author ShivaB
 *
 */
public class AccessUnclassifiedDocumentsPlumtreeUtilities implements IPlumtreeUtilities
{

	/* Only group with access to unclassified documents should be able
	 * to view this utility in the PTUtility drop-down menu.
	 */
	public int GetActivityRightRestriction() {
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UNCLASSIFIED_FOLDER;
	}

	/* Returns the control to open a folder.
	 *
	 */
	public String GetASControlName() {
		return OpenSubFolderControl.STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 *
	 */
	public String GetASDPName() {
		return null;
	}

	/*
	 * @return the Directory ActivitySpace
	 */
	public String GetASName() {
		return DirAS.STR_MVC_CLASS_NAME;
	}

	/* This adds the parameters to the OpenSubFolderControl
	 * DirMode -> Edit mode, subFolderID -> unclassified documents
	 */
	public String GetASQueryString() {
		String strQuery = "&" + DirConstants.QS_DIRECTORY_MODE + "=" +
			DirConstants.EDIT_MODE + "&subfolderID=" + PT_INTRINSICS.PT_FOLDER_UNCLASSIFIEDCARDS;
		return strQuery;
	}

	/* This is the text that gets displayed in the dropdown menu of the
	 * PTUtility
	 */
	public String GetLinkText(String _strLangID) {
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
		return (rm.GetString(2703, "ptmsgs_portaladminmsgs", _strLangID));
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#IsStandardPortalOption()
	 */
	public boolean IsStandardPortalOption() {
		return true;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#IsViewable()
	 */
	public boolean IsViewable() {
		return true;
	}

}
