package com.plumtree.portalpages.admin.ptutilities.userlockmanager;

// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.pagination.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the Misc Settings page of the Misc Editor.
 *
 * @author Julie Fournier
 */
public class MainDP extends EditorDP {
	
	public static final String STR_MVC_CLASS_NAME = "UserLockManagerMainDP";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return (m_asOwner.GetString(1586, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1656, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for that Page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay() 
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		result.AddInnerHTMLElement(ExpListView.GetHiddenInputsForPagination());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(UserLockManagerAS.strStorageUserLockList))
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(
			m_asOwner
				.GetView(UserLockManagerAS.strStorageUserLockList)
				.DisplayJavascript());
				
		HTMLScript myScript = null;
		myScript = new HTMLScript("text/javaScript");
		myScript.AddInnerHTMLString(PaginationControl.CreatePaginationJavascript(m_asOwner));
		myScripts.AddInnerHTMLElement(myScript);

		return myScripts;
	}
}

