package com.plumtree.portalpages.admin.ptutilities.userlockmanager;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * 
 * @author JenniferSu
 *
 * Expandable list implementation for the Release User Lock utility.
 * */
public class UserLockListModel extends ExpListModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.ptutilities.userlockmanager.UserLockListModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "UserLockList";
	
	/**
	 * Number total of columns
	 */
	public static final int EXPLIST_COL_MAX = 5;

	/**
	 * This column contains the User Object ID
	 */
	public static final int EXPLIST_COL_USERID = 1;

	/**
	 * This column contains the Name.
	 */
	public static final int EXPLIST_COL_NAME = 2;

    /**
     * This column contains the sort order. Rows will be sorted by user name
     */
    public static final int EXPLIST_SORT_ORDER = 1;

	/**
	 * This column contains the Reason for Lock.
	 */
	public static final int EXPLIST_COL_LOGINNAME = 3;

	/**
	 * This column contains the Date Locked.
	 */
	public static final int EXPLIST_COL_DATELOCKED = 4;

	/**
	 * Filter reason string for admin disabled.
	 */
	public static final String FILTER_ADMIN_DISABLED = "An administrator manually locked this account.";
	
	/**
	 * Filter reason string for agent disabled.
	 */
	public static final String FILTER_AGENT_DISABLED = "This user has been locked by a User Synchronization Job.";
	
	/**
	 * Filter reason string for too many bad login attempts.
	 */
	public static final String FILTER_BAD_LOGIN = "This user has had too many bad logon attempts.";
	
	/**
	 * Filter reason string for retrieving all.
	 */
	public static final String FILTER_ALL = "";

	/**
	 * This is used on add to populate the input
	 * text of the newly added row.
	 */
	protected String m_sDefaultValue = "";
	private int[] m_arrObjectsToDelete;
	private String m_sCurrentFilter = "";
    
    private XPHashtable m_opItems;

	/**
	 * Adds one row at the bottom of the list
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserLockListModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Initialize and load the expandable list.
	 *
	 */
	public void InitializeUserLockList()
	{
		InitializeExpandableList(m_asOwner.GetString(1591, "ptmsgs_portaladminmsgs"),		
			m_asOwner.GetString(1594, "ptmsgs_portaladminmsgs"),			
			m_asOwner.GetString(2658, "ptmsgs_portaladminmsgs"),			
			m_asOwner.GetString(1596, "ptmsgs_portaladminmsgs"),
			null,			
			null, 1);

        m_opItems = new XPHashtable();
		Load(FILTER_ALL);
		
		SetEmptyListMessages(m_asOwner.GetString(2653, "ptmsgs_portaladminmsgs"), "");
		
		EnablePagination(UserLockManagerAS.strStorageUserLockList);
	}
	
	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeExpandableList(String _sSectionTitle,
		String _sSectionSubTitle1, String _sSectionSubTitle2,
		String _sSectionSubTitle3, PTImageType _imgAddIcon, String _sAddLabel,
		int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[3][5];

		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_USERID);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle1;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "0%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_NAME);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle1;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "33%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_LOGINNAME);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle2;
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "33%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		arrExpListColInfo[2][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_DATELOCKED);
		arrExpListColInfo[2][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle3;
		arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH]		    = "33%";
		arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_USERID, EXPLIST_COL_NAME,
				EXPLIST_COL_LOGINNAME, EXPLIST_COL_DATELOCKED
			};

		// JF- Sort array
		// The growable array will always be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_SORT_ORDER;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true);
	}

	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
    
    //OKAN::WHY IS THIS USED AGAIN?
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex, XPHashtable _htFormData) {
		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		// Save the items to be unlocked
		m_arrObjectsToDelete = GetArrayOfObjToDelete(_htFormData);
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * ROB: Make the available for other models.
	 *
	 * @param _htFormData
	 * @return int[]
	 */
	public int[] GetArrayOfObjToDelete(XPHashtable _htFormData)
	{
		String sDataKey     = GetUniqueString(ExpListView.HTMLCHECKBOX_DELROW);
		String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
		int[] aRowsToDelete = null;
	
		if ( (null != aDataValue) && (aDataValue.length > 0) )
		{
			aRowsToDelete = new int[aDataValue.length];
	
			for (int i = 0; i < aDataValue.length; i++)
			{
				try
				{
					aRowsToDelete[i] = XPConvert.ToInteger(aDataValue[i]);
				}
				catch (Exception e)
				{
					
						log.Error("UserLockManagerModel::GetArrayOfObjToDelete Unbale to retrieve users to unlock.");
					
				}
			}
		}

		return aRowsToDelete;
	}

	/**
	* Add the array passed in argument to the list.
	* The array should be created using the EXPLIST_COL
	* constants defined in this class.
	*
	* @param _arrRows Array of rows to add.
	*/
	public void SetDefaultObjects(Object[][] _arrRows)
	{
		super.GetItems().AddRows(_arrRows);
	}
	
	/**
	 * This function unlocks users that have been checked in the UI
	 */
    public void UnlockUsers() {
        try {
            //int intRowIndex;
            if (null != m_arrObjectsToDelete) {
                for (int i = 0; i < m_arrObjectsToDelete.length; i++) {
                    m_opItems.PutElement(GetReadOnlyItems().GetItem(m_arrObjectsToDelete[i], UserLockListModel.EXPLIST_COL_USERID), new Integer(1));
                }
                GetItems().RemoveRows(m_arrObjectsToDelete);
                m_arrObjectsToDelete = null;
            }
        } catch (Exception exc) {
            log.Error(exc, "UserLockManagerModel::UnlockObject Unable to unlock the user.");
            UIError myError = new UIError(UIErrorLevel.SERIOUS,
                UIErrorScope.CURRENT_USER, null,
                m_asOwner.GetString(1590,"ptmsgs_portaladminmsgs"), "");
            UIErrorHandler.RaiseError(myError,
                m_asOwner.GetSubSession(),
                m_asOwner.GetApplication());
        }
    }

	private void UnlockOneUser(int userID)
	{
		IPTUser ptUser;
		IPTServerContext mySC = null;
		IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();
		try {
        	ptUser = (IPTUser) ptSession.GetUsers().Open(userID, true);
        	ptUser.SetLockedStatus(false);
			mySC = (IPTServerContext)ptUser;
			mySC.Store();
			mySC.UnlockObject();
		} catch (Exception exc) {
			log.Error(exc, "UserLockManagerModel::Error occured during unlock user within Finish");
            throw new XPException(m_asOwner.GetString(1536, "ptmsgs_portaladminmsgs"), exc);
		}
	}
	
    /**
     * Gets the array of checked rows and delete  them from the list.
     *
     * @param _htFormData
     */
    public void DeleteRowsOnRepost(XPHashtable _htFormData) {
        // we are already getting the selected user list from m_deletedItems, which is calculated in GetArrayOfObjToDelete
        // so ignore this _htFormData
        if (null != m_arrObjectsToDelete) {
            for (int i = 0; i < m_arrObjectsToDelete.length; i++) {
                m_opItems.PutElement(GetReadOnlyItems().GetItem(m_arrObjectsToDelete[i], UserLockListModel.EXPLIST_COL_USERID), new Integer(2));
            }
        }
        GetItems().RemoveRows(m_arrObjectsToDelete);
        m_arrObjectsToDelete = null;
    }
    

    private void DeleteOneUser(int userID) {
        try {
            IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();
            IPTObjectManager objMgr = ptSession.GetObjectManagers(PT_CLASSIDS.PT_USER_ID);
            objMgr.Delete(userID);
        } catch (Exception exc) {
            log.Error(exc, "UserLockManagerModel::Error occured during delete user within Finish");
            throw new XPException(m_asOwner.GetString(1536, "ptmsgs_portaladminmsgs"), exc);
        }
    }
    
    public void Finish() {
        IXPEnumerator eKeys = m_opItems.GetKeys();
        int userID = -1;
        int opMode = -1;
        
        while (eKeys.MoveNext()) {
            opMode = XPConvert.ToInteger(m_opItems.GetElement(eKeys.GetCurrent()));
            userID = (XPConvert.ToInteger(eKeys.GetCurrent()));
            if (opMode == 1) {
                UnlockOneUser(userID);
            } else if (opMode == 2) {
                DeleteOneUser(userID);
            }
        }
        m_opItems.Clear();
    }
    
	/**
	 * Load the expandable list with locked users
	 * @param filter
	 */
	public void Load(String filter)
	{
		IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();

		IPTUserManager ptUserMan;
		ptUserMan = (IPTUserManager)ptSession.GetUsers();
		ASQueryResultWrapper ptqrUserLock = new ASQueryResultWrapper(ptUserMan.GetLockedAccounts(filter, 0, -1));
		m_saData.ClearArray();
		
        XPArrayList objectRows = new XPArrayList();
        
        Object userID = null;
        Object[] columns = null;

		for (int i = 0; i < ptqrUserLock.GetCount(); i++)
		{
            userID = ptqrUserLock.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID); 
            if (m_opItems.GetElement(userID) != null) {
                continue;
            }
            columns = new Object[UserLockListModel.EXPLIST_COL_MAX];
            columns[UserLockListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(m_nNextIndex);
			m_nNextIndex++;
			columns[UserLockListModel.EXPLIST_COL_USERID]		   = userID;
            columns[UserLockListModel.EXPLIST_COL_NAME]		   = ptqrUserLock.GetFields(i, PT_PROPIDS.PT_PROPID_NAME);
            columns[UserLockListModel.EXPLIST_COL_LOGINNAME]		   = ptqrUserLock.GetFields(i, PT_PROPIDS.PT_PROPID_USER_LOGINNAME);
            columns[UserLockListModel.EXPLIST_COL_DATELOCKED]     = ptqrUserLock.GetFields(i, PT_PROPIDS.PT_PROPID_CREATED);
            objectRows.Add(columns);
            
		}
        
        Object[][] allRows = new Object[objectRows.GetSize()][];
        for (int i = 0; i < objectRows.GetSize(); i++) {
            allRows[i] = (Object[])(objectRows.GetElement(i));
        }
		m_saData.AddRows(allRows);
		m_sCurrentFilter = filter;
	}
	
	/**
	 * Get the reason that the list is currently filtering on.
	 * @return
	 */
	public String GetCurrentFilter()
	{
		return m_sCurrentFilter;
	}
}

