package com.plumtree.portalpages.admin.ptutilities.userlockmanager;


// Framework Imports
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * Activity Space for Release User Locks utility.
 * @author JenniferSu
 *
 */
public class UserLockManagerAS extends PTEditorAS
{
	public static final String STR_MVC_CLASS_NAME = "UserLockManager";

	public static final String strStorageUserLockList = "UserLockList";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserLockManagerAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(1587, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (UserLockManagerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = UserLockManagerModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(UserLockManagerModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new MainDP());

		// Register Controls
		RegisterControl(UserLockManagerRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register UserLockList 
		RegisterModel(UserLockListModel.STR_MVC_CLASS_NAME,
			strStorageUserLockList);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myUserLockListModel = GetModel(strStorageUserLockList);
		RegisterView(UserLockListView.STR_MVC_CLASS_NAME,
			strStorageUserLockList, myUserLockListModel);

		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strStorageUserLockList, myUserLockListModel);

		// Set default page
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		// Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1535,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 * Sets the help links for the user locks utility
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page) {
		super.SetCurrentPage(page);

		// set the help for all pages to this url -mgs
		this.SetHelpTopic("PT_UserLocks");
	}
}

