package com.plumtree.portalpages.admin.ptutilities.userlockmanager;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class keeps an up-to-date state of all the settings.
 *
 * It contains the set and get methods for those settings.
 *
 * It contains the start, save and finish methods.
 *
 *
 * @author JohnH
 * @author JenniferSu
 */
public class UserLockManagerModel extends EditorModel
{
	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "UserLockManagerModel";

	public UserLockManagerModel()
	{
		super();
	}

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		//Check for administration rights
		IPTSession session = (IPTSession) m_asOwner.GetUserSession();

		if (!PlumtreeHelpers.CheckCurrentUserIsAdmin(session))
		{
			return false;
		}

		((UserLockListModel)m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).InitializeUserLockList();

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserLockManagerModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish() {
        ((UserLockListModel)m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Finish();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the Model with the IPTSession.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		((UserLockListModel)m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).SaveSection(_htFormData);
		
		return RepostControl.PAGE_STATUS_VALID;
	}
}

