package com.plumtree.portalpages.admin.ptutilities.userlockmanager;


// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * This class contains the additional repost actions.
 * The ones specific to the Misc Editor (other than
 * "change page", "finish" and "cancel" actions).
 *
 * @author JohnH
 * @author JenniferSu
 */
public class UserLockManagerRepostControl extends EditorRepostControl
{
	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME    = "UserLockManagerRepost";

	/** The unlock action */
	public final static int POSTTOSELF_ACTION_UNLOCK = 10;

	/** The sort action */
	public final static int POSTTOSELF_ACTION_SORT = 20;

	/** The filtering action */
	public final static int POSTTOSELF_ACTION_FILTER = 30;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserLockManagerRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param int
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		((ExpListControl) m_asOwner.GetControl(UserLockManagerAS.strStorageUserLockList)).PerformRepostAction(_nAction, m_htFormData);

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_UNLOCK:
			((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).UnlockUsers();

			break;

		case POSTTOSELF_ACTION_FILTER:
			String filter = ((String[])m_htFormData.GetElement("in_se_filter"))[0];
			if (filter.equals(UserLockListView.HTML_FILTER_ALL_VALUE))
				((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_ALL);
			else if (filter.equals(UserLockListView.HTML_FILTER_ADMIN_VALUE))
				((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_ADMIN_DISABLED);
			else if (filter.equals(UserLockListView.HTML_FILTER_AGENT_VALUE))
				((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_AGENT_DISABLED);
			else if (filter.equals(UserLockListView.HTML_FILTER_BADLOGIN_VALUE))
				((UserLockListModel) m_asOwner.GetModel(UserLockManagerAS.strStorageUserLockList)).Load(UserLockListModel.FILTER_BAD_LOGIN);

			break;
		}
	}
}

