package com.plumtree.portalpages.admin.sendinvitation;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.datepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.xpshared.jsutil.*;

/**
 * @author DustinA
 *
 */
public class InvCodesListModel extends ExpListModel
	implements IInvCodeListModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.sendinvitation.InvCodesListModel");

	
	public static final String STR_MVC_CLASS_NAME = "InvCodesListModel";

	
	public static final int INVEXPLIST_COL_MAX	    = 4;

	
	public static final int INVEXPLIST_COL_NAME     = 0;

	
	public static final int INVEXPLIST_COL_NUMOFINV = 1;

	
	public static final int INVEXPLIST_COL_EXPR = 2;

	
	public static final int INVEXPLIST_COL_CODE = 3;
	
	// used as a control argument name
	public static final String CONTROLARGUMENT_OBJECTID = "in_hi_objectid";

	/**
	 * Default initial size for the sorted array.
	 */
	public static final int INVEXPLIST_DEFAULT_INITIAL_SIZE = 50;
	
	protected IPTInvitation m_objInv;
	protected String m_strInvName;
	protected int m_nInvNoi							 = 1;	// DCA - default number of invitations

	/**
	 * Icon to display on each row, just before the input text. */
	protected PTImageType m_imgRowIcon;
	protected String m_strCurrentInvCode				    = "Invalid";
	protected boolean m_bInvObj							    = false;

	protected int m_nInvitationID = -1;
	private Object m_Session;

	/** DateTime date picker manager */
	private JSDatePickerMgr m_ptJSDatePickerMgr;

	/** Page Manager object */
	private PageMgr m_ptPageMgr;

	/**
	 * Creates a new Invitation Code
	 *
	 */
	public void AddRows()
	{
		Object[] objInvitationCode;
		int iNumInvites;
		XPDateTime dtExprDate;
		IASQueryResult qrInvCodes = new ASQueryResultWrapper(m_objInv.QueryInvitationCodes());
		XPDateTime xpNow			  = new XPDateTime();

		for (int i = 0; i < qrInvCodes.GetCount(); i++)
		{
			iNumInvites     = XPConvert.ToInteger(qrInvCodes.GetFields(i,
					PT_PROPIDS.PT_PROPID_INVITATION_NUMINVITES));
			dtExprDate	    = (XPDateTime) qrInvCodes.GetFields(i,
					PT_PROPIDS.PT_PROPID_INVITATION_EXPIRATIONDATE);

			if ((iNumInvites > 0) && xpNow.Before(dtExprDate))
			{
				objInvitationCode							   = new Object[INVEXPLIST_COL_MAX];
				objInvitationCode[INVEXPLIST_COL_NAME]		   = qrInvCodes.GetFields(i,
						PT_PROPIDS.PT_PROPID_NAME);
				objInvitationCode[INVEXPLIST_COL_NUMOFINV]     = new Integer(iNumInvites);
				objInvitationCode[INVEXPLIST_COL_EXPR]		   = dtExprDate;
				objInvitationCode[INVEXPLIST_COL_CODE]		   = qrInvCodes.GetFields(i,
						PT_PROPIDS.PT_PROPID_INVITATION_INVITATIONCODE);
				super.GetItems().AddRow(objInvitationCode);
			}
		}
	}

	/**
	 * Will be called each time the add action is performed.
	 * Should take care of adding the row(s) to the list.
	 * Use the GetItems() method to get the list.
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		// DCA - not used
	}

	/**
	 * Will be called each time the add action is performed.
	 * Should take care of adding the row(s) to the list.
	 * Use the GetItems() method to get the list.
	 *
	 * @param _htFormData Form data
	 */
	public String AddRowsOnRepost(XPHashtable _htFormData,
		int _nDummy /* DCA - dummy param so as not same as parent's */)
	{
		//XPArrayList arrayOfStatusAndErrorMessage = new XPArrayList(2);
		XPStringBuilder sb;

		XPDateTime _dInvExpr = null;
		String[] data		 = (String[]) _htFormData.GetElement(NewLinkPopUpView.HTMLINPUT_NAME);

		if ((0 != data.length) && (null != data[0]))
		{
			m_strInvName = data[0];

			
				log.Debug("InvCodesListModel::AddRowsOnRepost InvName value: " +
					m_strInvName);
			
		}
		else
		{
			
				log.Warn("InvCodesListModel::AddRowsOnRepost InvName was not in Query String.");
			
		}

		data = (String[]) _htFormData.GetElement(NewLinkPopUpView.HTMLINPUT_NOI);

		if ((0 != data.length) && (null != data[0]))
		{
			try
			{
				m_nInvNoi = XPConvert.ToInteger(data[0]);
			}
			catch (Exception e)
			{
				
					log.Error("InvCodesListModel::AddRowsOnRepost could not parse Number of Invites " +
						data[0]);
				

				m_nInvNoi = -1;
			}

			
				log.Debug("InvCodesListModel::AddRowsOnRepost InvNoi value: " +
					m_nInvNoi);
			
		}
		else
		{
			
				log.Warn("InvCodesListModel::AddRowsOnRepost InvNoi was not in Query String.");
			
		}

		JSDatePicker ptJSDatePicker = (JSDatePicker) m_ptJSDatePickerMgr.GetComponent("DP_One");
		
		String strValue = ptJSDatePicker.GetSelectedDateAsString();
		
		if ( (null != strValue) && (!(strValue.equals(""))))
		{
			try
			{
				_dInvExpr = ptJSDatePicker.GetDateAsDateTime();
			}
			catch (XPException e)
			{
				
					log.Error("InvCodesListModel::AddRowsOnRepost could not parse date " +
						strValue);
				

				_dInvExpr = null;
			}

			
				log.Debug("InvCodesListModel::AddRowsOnRepost InvExpr value: " +
					strValue);
			
		}
		else
		{
			
				log.Warn("InvCodesListModel::AddRowsOnRepost InvExpr was not in Query String.");
			
		}

		XPDateTime now = new XPDateTime();

		if (_dInvExpr != null && _dInvExpr.Before(now))
		{
			//arrayOfStatusAndErrorMessage.Insert(0, Boolean.FALSE);
			sb = new XPStringBuilder(200);
			sb.Append(m_asOwner.GetString(1293, "ptmsgs_portaladminmsgs"));
			sb.Append(CommonHTMLStrings.SPACE);
			sb.Append(m_asOwner.GetString(1289, "ptmsgs_portaladminmsgs"));

			//arrayOfStatusAndErrorMessage.Insert(1, sb.ToString());

			//return arrayOfStatusAndErrorMessage;
			return sb.ToString();
		}

		if (_dInvExpr != null && CreateNewInvLink(m_strInvName, m_nInvNoi, _dInvExpr))
		{
			super.GetItems().ClearArray();
			AddRows();
			//arrayOfStatusAndErrorMessage.Insert(0, Boolean.TRUE);
			//arrayOfStatusAndErrorMessage.Insert(1, "");

			m_strInvName = m_asOwner.GetString(1308, "ptmsgs_portaladminmsgs");
			m_nInvNoi = 1;
			
			//return arrayOfStatusAndErrorMessage;
			return null;
		}
		else
		{
			//arrayOfStatusAndErrorMessage.Insert(0, Boolean.FALSE);
			sb = new XPStringBuilder(200);
			sb.Append(m_asOwner.GetString(1295, "ptmsgs_portaladminmsgs"));
			sb.Append(CommonHTMLStrings.SPACE);
			sb.Append(m_asOwner.GetString(1289, "ptmsgs_portaladminmsgs"));

			//arrayOfStatusAndErrorMessage.Insert(1, sb.ToString());

			//return arrayOfStatusAndErrorMessage;
			return sb.ToString();
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new InvCodesListModel();
	}

	/**
	 * Creates a new Invitation Code
	 *
	 * @param _strInvName
	 * @param _nInvNoi
	 * @param _dInvExpr
	 */
	public boolean CreateNewInvLink(String _strInvName, int _nInvNoi,
		XPDateTime _dInvExpr)
	{
		try
		{
			m_objInv.CreateNewInvitationCode(_strInvName, _dInvExpr, _nInvNoi);
		}
		catch (Exception e)
		{
			
				XPDateFormat dateFormat = XPDateFormat.GetDateInstance(XPDateFormat.MEDIUM);
				// Done -> TODO: We should use XPDateFormat for string printing but maybe it's ok for debugging.
				log.Error("InvCodesListModel::CreateNewInvLink Could not create code using " +
					_strInvName + ", " + _nInvNoi + ", " +
					dateFormat.Format(_dInvExpr));
			

			return false;
		}

		return true;
	}

	/**
	 * Returns the Status of the Invitation Object.
	 *
	 * @return boolean
	 */
	public boolean GetInvObjectStatus()
	{
		return m_bInvObj;
	}

	/**
	 * Gets the invitation ID to the invitation wanted
	 *
	 */
	public String GetInvitationCode()
	{
		if (m_strCurrentInvCode == "Invalid")
		{
			
				log.Warn("InvCodesListModel::GetInvitationCode Invitation Code was not Set.");
			
		}

		return m_strCurrentInvCode;
	}

	/**
	 * Gets the invitation ID to the invitation wanted
	 *
	 */
	public int GetInvitationID()
	{
		return m_nInvitationID;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the icon to display on each row before the
	 * input text.
	 * If the value is null, no icon is displayed.
	 *
	 * @return PTImageType
	 */
	public PTImageType GetRowIcon()
	{
		return m_imgRowIcon;
	}

	/**
	 * Inits the Model with the IPTSession.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner     = parent;
		// JF- Get the Session object from the associated AS.
		m_Session = (IPTSession) m_asOwner.GetUserSession();
		
		m_strInvName = m_asOwner.GetString(1308, "ptmsgs_portaladminmsgs");
		
		InitializeDatePickerMgrs();

		ADatePickerComponent ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
		ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME,  m_ptPageMgr, "DP_One");
		m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);

	}

	/**
	 * This function initializes the manager objects (Page and datetime) for the date pickers
	 */
	public void InitializeDatePickerMgrs()
	{
		XPLocale m_Locale = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner);
		XPTimeZone m_Timezone = PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner);
		
		// Deal with the page manager
		String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
		m_ptPageMgr     = new PageMgr(m_asOwner.GetAccessStyle(), m_Locale, m_Timezone, strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		// Deal with the date/time-picker
		JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		m_ptJSDatePickerMgr = new JSDatePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(), m_ptPageMgr);
		m_ptPageMgr.RegisterComponentMgr(m_ptJSDatePickerMgr);

	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitInvitationExpList(String _sSectionTitle,
		String _sSectionSubTitle1, String _sSectionSubTitle2,
		String _sSectionSubTitle3, PTImageType _imgAddIcon, String _sAddLabel,
		int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[3][6];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(INVEXPLIST_COL_NAME);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle1;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "30%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;
		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(INVEXPLIST_COL_NUMOFINV);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle2;
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "35%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;
		arrExpListColInfo[2][EXPLIST_COLUMN_ID]			    = new Integer(INVEXPLIST_COL_EXPR);
		arrExpListColInfo[2][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle3;
		arrExpListColInfo[2][EXPLIST_COLUMN_WIDTH]		    = "35%";
		arrExpListColInfo[2][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[2][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		try
		{
			IPTObjectManager omInv = ((IPTSession) m_Session).GetInvitations();
			m_objInv	  = (IPTInvitation) omInv.Open(m_nInvitationID, false);
			m_bInvObj     = true;
		}
		catch (Exception e)
		{
			
				log.Error("InvCodesListModel::InitInvitationExpList Unable to get Invitation Object w/ ID: " +
					m_nInvitationID);
			
		}

		if (m_bInvObj)
		{
			super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
				_imgAddIcon, _sAddLabel, _nListKey);
			super.DisableCheckBoxes();
			AddRows();

			super.SetEmptyListMessages(m_asOwner.GetString(1288,
					"ptmsgs_portaladminmsgs"), " ");
		}
	}

	/**
	 * Will be called when this class is initalized.
	 * Should take care of initializing _saData (calling Initialize).
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// DCA- Column mapping
		int[] arrColumns = new int[]
			{
				INVEXPLIST_COL_NAME, INVEXPLIST_COL_NUMOFINV,
				INVEXPLIST_COL_EXPR, INVEXPLIST_COL_CODE
			};

		// DCA- Sort array
		// The growable array will always be sorted by the String column (the one displayed).
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = INVEXPLIST_COL_NAME;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// DCA- We don't initalize the list itself (null bellow)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true,
			INVEXPLIST_DEFAULT_INITIAL_SIZE);
	}

	/**
	 * Saves the data when a repost occurs.
	 * Editors using this framework need to call that method from
	 * the savePage method of the main Model.
	 *
	 * @param _htFormData
	 *
	 * @return int Status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		m_ptPageMgr.StoreAllUserInput(_htFormData);

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Sets the invitation ID to the invitation wanted
	 *
	 * @param _invCode
	 */
	public void SetInvitationCode(String _invCode)
	{
		m_strCurrentInvCode = _invCode;
	}

	/**
	 * Sets the invitation ID to the invitation wanted
	 *
	 * @param __nInvitationID
	 */
	public void SetInvitationID(int _nInvitationID)
	{
		m_nInvitationID = _nInvitationID;
	}

	/**
	 * Sets the icon to display on each row before the
	 * input text.
	 * By default, no icon is displayed.
	 *
	 * @param _imgRowIcon
	 */
	public void SetRowIcon(PTImageType _imgRowIcon)
	{
		m_imgRowIcon = _imgRowIcon;
	}

	/**
	 * Will be called each ime there is a repost to save
	 * the data on the list.
	 * Should contain the code to update the data on the
	 * row _nRowIndex.Use the SetItem method to update _saData and
	 * use _htFormData to retrieve the posted data.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 * @param _htFormData
	 * @param _nListKey
	 *
	 * @return int
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * Returns the m_nInvNoi as a String.
	 * @return String
	 */
	public String GetNumberOfInvitations() {
		return XPConvert.ToString(m_nInvNoi);
	}

	/**
	 * Returns the m_strInvName.
	 * @return String
	 */
	public String GetInvitationCodeName() {
		return m_strInvName;
	}

	/**
	 * Get the Date picker control manager
	 *
	 * @return JSDatePickerMgr
	 */
	public JSDatePickerMgr GetDatePickerControlManager()
	{
		return m_ptJSDatePickerMgr;
	}

}

