package com.plumtree.portalpages.admin.sendinvitation;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author dustina
 *
 */
public class InvCodesListView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.sendinvitation.InvCodesListView");


	public static final String STR_MVC_CLASS_NAME = "InvCodesListView";
	/** invite argument processed by CreateAccountControl and Invite control; make sure they match */
	public static final String CONTROLARGUMENT_INVCODE = "in_hi_invcode";


	public static final String JS_CREATE_POPUP = "createPopUp";
	protected AActivitySpace m_asOwner;
	protected HTMLImg m_imgInvitation;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new InvCodesListView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			if (((IInvCodeListModelRO) m_model).GetInvObjectStatus())
			{
				myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				myTable.SetBorder(CommonHTMLStrings.ZERO);
				myTable.SetAlign(CommonHTMLStrings.CENTER);
				myTable.SetCellPadding(CommonHTMLStrings.ZERO);
				myTable.SetCellSpacing("15");

				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.AddInnerHTMLElement(super.Display());
			}
			else
			{
				myTable = new HTMLTable();
				result.AddInnerHTMLElement(myTable);
				myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				myTable.SetBorder(CommonHTMLStrings.ZERO);
				myTable.SetAlign(CommonHTMLStrings.CENTER);
				myTable.SetCellPadding(CommonHTMLStrings.ZERO);
				myTable.SetCellSpacing("15");

				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);

				myCell.AddInnerHTMLString(m_asOwner.GetString(1297,
						"ptmsgs_portaladminmsgs"));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "InvCodesListView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(52,
					"ptmsgs_infrastructure"), e); //m_asOwner.GetString(14, "ptmsgs_portaladminmsgs")
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		// The URL to open the pop-up
		ASURL myPopUp = new ASURL(m_asOwner);
		myPopUp.SetLinkGetCachedSpace(m_asOwner);
		myPopUp.SetDisplayPage(NewLinkPopUpDP.STR_MVC_CLASS_NAME);

		myPopUp.SetControl(SendInvitationRepostControl.STR_MVC_CLASS_NAME);

		XPStringBuilder sb;

		try
		{
			// Open Pop Up function
			sb = new XPStringBuilder(200);
			sb.Append("function " + JS_CREATE_POPUP + "()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(myPopUp.GetURLAsString())
			.Append("', '_blank3', 'location=no,menubar=no,width=535,height=270');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "InvCodesListView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * Will be called for each row.
	 * Should return the HTML for row _nRowIndex.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTableCell myCell;
		HTMLAnchor myAnchor;

		// The URL to open the pop-up
		Object myObject = _saData.GetItem(_nRowIndex,
				InvCodesListModel.INVEXPLIST_COL_CODE);

		ASURL myHref = new ASURL(m_asOwner);
		myHref.SetLinkGetCachedSpace(m_asOwner);
		myHref.SetDisplayPage(CodePopUpDP.STR_MVC_CLASS_NAME);
		myHref.SetControl(InvCodesListControl.STR_MVC_CLASS_NAME);
		myHref.AddControlArgument(CONTROLARGUMENT_INVCODE, XPConvert.ToString(myObject));

		myCell = new HTMLTableCell();
		result.AddInnerHTMLElement(myCell);
		myCell.SetWidth("40%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
		myAnchor.SetOnClick("window.open('" + myHref.GetURLAsString() +
			"', '_blank3', 'location=no,menubar=no,width=460,height=220'); return false;");
		myObject = _saData.GetItem(_nRowIndex,
				InvCodesListModel.INVEXPLIST_COL_NAME);

		if (m_imgInvitation != null)
		{
			myAnchor.AddInnerHTMLElement(m_imgInvitation);
		}

		myAnchor.AddInnerHTMLString(XPHttpUtility.HtmlEncode( XPConvert.ToString(myObject) ));

		//}
		// add # of Invitation
		myCell = new HTMLTableCell();
		result.AddInnerHTMLElement(myCell);
		myCell.SetWidth("30%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myObject = _saData.GetItem(_nRowIndex,
				InvCodesListModel.INVEXPLIST_COL_NUMOFINV);
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString(XPConvert.ToString(myObject));

		// add Expiration Date
		myCell = new HTMLTableCell();
		result.AddInnerHTMLElement(myCell);
		myCell.SetWidth("30%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		myCell.SetNoWrap(true);
		myObject = _saData.GetItem(_nRowIndex,
				InvCodesListModel.INVEXPLIST_COL_EXPR);
		PageMgr m_PageMgr = ((IInvCodeListModelRO) m_model).GetDatePickerControlManager().GetPageMgr();
		XPDateFormat dateParser =
			XPDateFormat.GetDateInstance(XPDateFormat.MEDIUM, m_PageMgr.GetLocale(), m_PageMgr.GetTimeZone());
		String strEprDate = dateParser.Format((XPDateTime) myObject);
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLString(strEprDate);

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the Section with the read-only Model and the Activity Space.
	 *
	 * @param model
	 * @param parent
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model = model;

		try
		{
			m_asOwner = parent;
		}
		catch (Exception e)
		{
			
				log.Error(e, "InvCodesListView::Init Unable to cast the Object " +
					parent +
					" to AActivitySpace. The following exception occured: " +
					e.getMessage());
			

			// DCA - No need to extract, this is an unexpected error.
			throw new XPException("Unable to cast the Object " + parent +
				" to AActivitySpace.", e);
		}

		try
		{
			m_imgInvitation = GetIcon(PTImageType.ICON_INVITATION);
		}
		catch (Exception e)
		{
			m_imgInvitation = null;
		}
	}

	/**
	 * Returns the HTML for the space below the Action bar.
	 * (The one with the add and delete icons).
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLBelowActionBar()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		myTable = new HTMLTable();
		myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		//Spacer Row begin
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("5");

		//Spacer Row ends
		// 1st Row begin (there is only one row)
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

		myCell.AddInnerHTMLString(m_asOwner.GetString(1296,
				"ptmsgs_portaladminmsgs"));
		myCell.AddInnerHTMLElement(new HTMLBr());

		//Spacer Row begin
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetHeight("5");

		//Spacer Row ends
		return myTable;
	}

	/**
	 * Returns the HTML for the Action bar.
	 * (The one with the add icons).
	 * copied from JulieF's ExpListView but got rid of the delete Action cause invitation
	 * instances can't be deleted.
	 *
	 * @return HTMLTable
	 * @throws Exception
	 */
	protected HTMLTable GetHTMLForActionBar()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		myTable = new HTMLTable();
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing("0");

		// 1st Row begin (there is only one row)
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

		// Add icon cell
		myRow.AddInnerHTMLElement(GetHTMLForAddAction());

		// Empty Cell
		myRow.AddInnerHTMLElement(GetHTMLForEmptyCellInActionBar());

		// Add Extra HTML to the action bar (like a "create" button)
		AddHTMLToActionBar(myRow);

		// Last Empty Cell
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myCell.SetHeight("25");
		myCell.AddInnerHTMLString(SPACE);

		// 1st Row ends
		return myTable;
	}

	/**
	 * Returns the HTML for the add cell in the action bar.
	 *
	 * @return HTMLTableCell
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForAddAction()
	{
		HTMLTableCell myCell;
		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLAnchor myAnchor;
		HTMLSpan mySpan;

		myCell = new HTMLTableCell();
		myCell.SetHeight("25");
		myCell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
		myCell.SetNoWrap(true);
		myCell.AddInnerHTMLString(SPACE);

		// Add icon
		myConstruct     = UIConstructFactory.GetConstruct( ((IExpListModelRO) m_model).GetAddIcon(),
				true, this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		myAnchor = ConstructStaticHelpers.GetJavascriptAnchor("", JS_CREATE_POPUP + "()");	// mj: removed 'Javascript:' from function name
		myAnchor.AddInnerHTMLElement(myImage);
		if (m_imgInvitation != null)
		{
			myAnchor.AddInnerHTMLElement(m_imgInvitation);
		}

		mySpan = new HTMLSpan();
		myAnchor.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

		// Add label
		mySpan.AddInnerHTMLString(((IExpListModelRO) m_model).GetAddLabel());
		mySpan.AddInnerHTMLString(SPACE);
		mySpan.AddInnerHTMLString(SPACE);
		myCell.AddInnerHTMLElement(myAnchor);
		myCell.AddInnerHTMLString(SPACE);

		return myCell;
	}

	/**
	 * Returns the HTML for the sub header.
	 *
	 * @return HTMLTableRow
	 * @throws Exception
	 */
	protected HTMLTableRow GetHTMLForSubHeader()
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;
		HTMLImg myImage;
		PTConstruct myConstruct;

		myRow = new HTMLTableRow();
		myRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

		Object[][] oArrExpListColInfo = ((IExpListModelRO) m_model).GetArrExpListColInfo();
		int nColumnID;

		for (int i = 0; i < oArrExpListColInfo.length; i++)
		{
			// Row 1
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_WIDTH]);
			myCell.SetColSpan((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_COLSPAN]);
			myCell.SetHeight("20");
			myCell.SetNoWrap(true);
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			myCell.AddInnerHTMLString(SPACE);

			if (XPConvert.ToBoolean(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ENABLESORT]))
			{
				nColumnID = XPConvert.ToInteger(oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID]);

				if (nColumnID == ((IExpListModelRO) m_model).GetMainColumnSort())
				{
					// mj: replaced the following line with a blank constructur and SetOnClick()
					// myAnchor = new HTMLAnchor("postToSelf('" +
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick("postToSelf('" +
							((IExpListModelRO) m_model).GetUniqueInt(
								ExpListControl.POSTTOSELF_ACTION_REVERSESORT) +
							"'); return false;");
					myCell.AddInnerHTMLElement(myAnchor);
					myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);

					if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == ((IExpListModelRO) m_model).GetMainColumnSortDirection())
					{
						myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
								true, this.m_asOwner);
						myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

						myImage.SetAlt(m_asOwner.GetString(55,
								"ptmsgs_infrastructure")); //_ui_DescendingIconAlt
						myImage.SetAlign("absmiddle");
						myAnchor.AddInnerHTMLElement(myImage);
					}
					else
					{
						myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_ASCEND,
								true, this.m_asOwner);
						myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

						myImage.SetAlt(m_asOwner.GetString(54,
								"ptmsgs_infrastructure")); //_ui_AscendingIconAlt
						myImage.SetAlign("absmiddle");
						myAnchor.AddInnerHTMLElement(myImage);
					}
				}
				else
				{
					// mj: replaced the following line with a blank constructur and SetOnClick()
					// myAnchor = new HTMLAnchor(
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(
							((IExpListModelRO) m_model).GetUniqueString(
								"SortBy") + "('" +
							oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_ID] +
							"'); return false;");
					myCell.AddInnerHTMLElement(myAnchor);
					myAnchor.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
				}
			}
			else
			{
				myCell.AddInnerHTMLString((String) oArrExpListColInfo[i][ExpListModel.EXPLIST_COLUMN_TITLE]);
			}
		}

		return myRow;
	}

	/**
	 * Helper method to get the HTML for the icon.
	 * (Each row has an icon before the input text.)
	 *
	 * @return HTMLImg
	 * @throws Exception
	 */
	protected HTMLImg GetIcon(PTImageType _imgRowIcon)

	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct     = UIConstructFactory.GetConstruct(_imgRowIcon, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetAlign("absmiddle");

		return (myImage);
	}
	
	/** 
	 * We ned to overwrite this method because because SendInvitationAS extends 
	 * from PlumtreeAS and not EditorAS.  However, we are still using EditorView
	 * to display headers, and that requires our activity space to be extended 
	 * from EditorAS.  Instead, we will circumvent that dependency.
	 *
	 * @param _sHeaderTitle Title you want to display in the header.
	 * 
	 * @return HTMLTable
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLElement GetHeaderView(String _sHeaderTitle)
	{
		return GetHeaderViewHelper(m_asOwner, _sHeaderTitle);
	}
}

