package com.plumtree.portalpages.admin.serversettings.auditmanager;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class implements the Activity Space for the Audit Manager utility.  It
 * incorporates the display pages from the Audit Query Central editor as well.
 * 
 * @author ErickS
 */

public class AuditManagerEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.auditmanager.AuditManagerEditorAS");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "AuditManagerEditor";


	private static final String sClassName = "com.plumtree.portalpages.admin.serversettings.auditmanager.AuditManagerEditorAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AuditManagerEditorAS();
	}

	
	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(1614, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (AuditManagerRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
     * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
     *
	 * @param IDisplayPage the current Display Page
	 */
     public void SetCurrentPage(IDisplayPage page)
     {

        super.SetCurrentPage( page );

        String sPageName = page.GetName();

        if( AuditManagerDP.STR_MVC_CLASS_NAME.equals( sPageName ))
        {
			this.SetHelpTopic( "PT_AuditManager_MainSettings" );                           
		}
        else if( AuditQueryCentralDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
            this.SetHelpTopic( "PT_AuditManager_CreateAuditQuery" );
        }
        else if( AuditQueryResultDP.STR_MVC_CLASS_NAME.equals( sPageName ))
        {
            this.SetHelpTopic( "PT_AuditManager_RunQuery" );
        }
     }

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = AuditManagerModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(AuditManagerModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new AuditManagerDP());
		
		// Register Controls
		RegisterControl(AuditManagerRepostControl.STR_MVC_CLASS_NAME, myModel);

		//Register AuditManagerView
		RegisterView(MessageTypesView.STR_MVC_CLASS_NAME, myModel);

		//Register ArchivingAgentView
		RegisterView(ArchivingAgentView.STR_MVC_CLASS_NAME, myModel);

		//Register MessageDeleteView
		RegisterView(MessageDeleteView.STR_MVC_CLASS_NAME, myModel);

		//********** Audit Query Central registration ************
		// Register DisplayPages
		RegisterPage(new AuditQueryCentralDP());
		RegisterPage(new AuditQueryResultDP());

		//Register SearchCriteria Section
		RegisterView(SearchCriteriaView.STR_MVC_CLASS_NAME, myModel);

		//Register TimesDates Section
		RegisterView(TimesDatesView.STR_MVC_CLASS_NAME, myModel);

		//Register DisplayPrefs Section
		RegisterView(DisplayPrefsView.STR_MVC_CLASS_NAME, myModel);

		//Register AuditQueryResult Section
		RegisterView(AuditQueryResultView.STR_MVC_CLASS_NAME, myModel);
		
		
		// Set default page
		SetCurrentPage(AuditManagerDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1615,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			AuditManagerDP.STR_MVC_CLASS_NAME);

		//************ Audit Query Central pages **************
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			AuditQueryCentralDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			AuditQueryResultDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
		//Sets left nav menu
		
		
		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				
				
				int iTitleId = 96;
				int iTipId = 97;
				int iSecondaryTipId = 98;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}

								

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
		 
		 		
		
	}
}

