package com.plumtree.portalpages.admin.serversettings.auditmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.datepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.jsutil.*;

/**
 * This class implements the model for the Audit Manager, which includes Audit
 * Query Central
 * 
 * @author ErickS
 */

public class AuditManagerModel extends EditorModel
	implements IAuditManagerModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.auditmanager.AuditManagerModel");

	public static final String STR_DELETION_DATE_PICKER_UNIQUE_ID = "DeletionDP";
	public static final String STR_START_DATE_PICKER_UNIQUE_ID = "StartDP";
	public static final String STR_END_DATE_PICKER_UNIQUE_ID = "EndDP";

	public static final int N_DATE_PICKER_PAGE_TYPE_MESSAGES = 0;
	public static final int N_DATE_PICKER_PAGE_TYPE_QUERY = 1;

	/** The unique identifier for this class */
	public static final String STR_MVC_CLASS_NAME = "AuditManager";

	
	public static final int intMaxQueryFilters = 7;

	
	public static final int intAllMessageTypes = PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE |
		PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT | PT_AUDIT_TYPES.PT_AUDIT_LOGIN |
		PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE |
		PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION |
		PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE;

	private IPTAuditManager m_AuditManager;

	// Data members
	private IPTSession m_Session;
	private String m_strArchivePath;
	private int m_intDaysInDB;
	private int m_intDaysInFiles;
	private int m_intDeleteAction;
	private int m_intDeleteMessageTypeValue;
	private int m_intMessageTypeValue;
	private int m_intQueryMessageTypeValue;
	private JSDatePickerMgr m_ptDatePickerMgr_MessagesPg;
	private PageMgr m_ptPageMgr_MessagesPg;

	//*********** Audit Query Central specific members ***********
	private String m_strItemName;
	private String m_strServerName;
	private String m_strUserName;
	private String m_strWordInMessage;
	private int m_intItemNameApproximateType;
	private int m_intItemType;
	private int m_intQueryCount;
	private int m_intResultsPerPage;
	private int m_intServerNameApproximateType;
	private int m_intSkipMessages;
	private int m_intSortType;
	private int m_intUserNameApproximateType;
	private JSDateTimePickerMgr m_dateTimePickerMgr_QueryPg;
	private PageMgr m_ptPageMgr_QueryPg;

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		// Get the AuditManager
		m_AuditManager = (IPTAuditManager) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_AUDITMANAGER,
				false);

		// Set the initial state
		SetMessageTypeValue(m_AuditManager.GetAuditingState());
		SetArchivePath(m_AuditManager.GetArchivePath());
		SetDaysInDB(m_AuditManager.GetDaysInDB());
		SetDaysInFiles(m_AuditManager.GetDaysInArchive());
		SetDeleteMessageTypeValue(intAllMessageTypes);
		SetDeleteAction(MessageDeleteView.intUnchecked);

		//*********** Audit Query Central initialization *************
		SetItemType(SearchCriteriaView.iAllItemType);
		SetItemName("");
		SetItemNameApproximateType(SearchCriteriaView.iApproximateValue);
		SetUserName("");
		SetUserNameApproximateType(SearchCriteriaView.iApproximateValue);
		SetServerName("");
		SetServerNameApproximateType(SearchCriteriaView.iApproximateValue);
		SetWordInMessage("");
		SetQueryMessageTypeValue(intAllMessageTypes);
		SetSortType(DisplayPrefsView.iNewestFirst);
		SetResultsPerPage(10);
		SetSkipMessages(0);
		SetQueryCount(0);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AuditManagerModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		// Store the message type value
		m_AuditManager.TurnOnGlobalAuditing(m_intMessageTypeValue);
		m_AuditManager.SetArchivePath(m_strArchivePath);
		m_AuditManager.SetDaysInDB(m_intDaysInDB);
		m_AuditManager.SetDaysInArchive(m_intDaysInFiles);

		// Check to see if the delete checkbox is checked
		if(m_intDeleteAction == MessageDeleteView.intChecked)
		{
			// Delete action is checked, go ahead and delete old messages
			XPDateTime myDateTime = GetDateFromDatePicker(N_DATE_PICKER_PAGE_TYPE_MESSAGES, STR_DELETION_DATE_PICKER_UNIQUE_ID);

			if (null != myDateTime)
			{
				m_AuditManager.DiscardOldAuditMsgs(m_intDeleteMessageTypeValue,
						myDateTime,
						myDateTime);
			}
		}
	}

	//*************** Audit Query Central helper methods ****************
	/**
	 * 
	 *
	 * @return 
	 */
	public PTSortedArrayWrapper GetAuditMessages()
	{
		PTSortedArrayWrapper myArray = null;
		int intMessagesCount		 = 0;

		// build the query filter
		Object[] oProperties = new Object[intMaxQueryFilters];
		Object[] oOperators  = new Object[intMaxQueryFilters];
		Object[] oOperands   = new Object[intMaxQueryFilters];
		int iFilterIndex     = 0;

		// Item Type
		if (m_intItemType != SearchCriteriaView.iAllItemType)
		{
			oProperties[iFilterIndex]     = new Integer(PT_PROPIDS.PT_PROPID_CLASSID);
			oOperators[iFilterIndex]	  = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			oOperands[iFilterIndex]		  = new Integer(m_intItemType);
			iFilterIndex++;
		}

		// Item Name
		if (!m_strItemName.equals(""))
		{
			oProperties[iFilterIndex] = new Integer(PT_PROPIDS.PT_PROPID_AUDIT_OBJECTNAME);

			if (SearchCriteriaView.iApproximateValue == m_intItemNameApproximateType)
			{
				oOperators[iFilterIndex] = new Integer(PT_FILTEROPS.PT_FILTEROP_CONTAINS);
			}
			else
			{
				oOperators[iFilterIndex] = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			}

			oOperands[iFilterIndex] = m_strItemName;
			iFilterIndex++;
		}

		// User Name
		if (!m_strUserName.equals(""))
		{
			oProperties[iFilterIndex] = new Integer(PT_PROPIDS.PT_PROPID_AUDIT_USERNAME);

			if (SearchCriteriaView.iApproximateValue == m_intUserNameApproximateType)
			{
				oOperators[iFilterIndex] = new Integer(PT_FILTEROPS.PT_FILTEROP_CONTAINS);
			}
			else
			{
				oOperators[iFilterIndex] = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			}

			oOperands[iFilterIndex] = m_strUserName;
			iFilterIndex++;
		}

		// Server Name
		if (!m_strServerName.equals(""))
		{
			oProperties[iFilterIndex] = new Integer(PT_PROPIDS.PT_PROPID_AUDIT_SERVERNAME);

			if (SearchCriteriaView.iApproximateValue == m_intServerNameApproximateType)
			{
				oOperators[iFilterIndex] = new Integer(PT_FILTEROPS.PT_FILTEROP_CONTAINS);
			}
			else
			{
				oOperators[iFilterIndex] = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			}

			oOperands[iFilterIndex] = m_strServerName;
			iFilterIndex++;
		}

		// Word in Message
		if (!m_strWordInMessage.equals(""))
		{
			oProperties[iFilterIndex]     = new Integer(PT_PROPIDS.PT_PROPID_AUDIT_MSGCONTENT);
			oOperators[iFilterIndex]	  = new Integer(PT_FILTEROPS.PT_FILTEROP_CONTAINS);
			oOperands[iFilterIndex]		  = m_strWordInMessage;
			iFilterIndex++;
		}

		// Start date
		XPDateTime xpdtStartDate = GetDateTimeFromDateTimePicker(N_DATE_PICKER_PAGE_TYPE_QUERY, STR_START_DATE_PICKER_UNIQUE_ID);
		
		if (null != xpdtStartDate)
		{
			oProperties[iFilterIndex]     = new Integer(PT_PROPIDS.PT_PROPID_AUDIT_MSGTIME);
			oOperators[iFilterIndex]	  = new Integer(PT_FILTEROPS.PT_FILTEROP_GTE);
			oOperands[iFilterIndex]		  = xpdtStartDate;
			iFilterIndex++;
		}


		// End date
		XPDateTime xpdtEndDate = GetDateTimeFromDateTimePicker(N_DATE_PICKER_PAGE_TYPE_QUERY, STR_END_DATE_PICKER_UNIQUE_ID);
		
		if (null != xpdtEndDate)
		{
			oProperties[iFilterIndex]     = new Integer(PT_PROPIDS.PT_PROPID_AUDIT_MSGTIME);
			oOperators[iFilterIndex]	  = new Integer(PT_FILTEROPS.PT_FILTEROP_LTE);
			oOperands[iFilterIndex]		  = xpdtEndDate;
			iFilterIndex++;
		}


		Object[][] oFilters = new Object[3][iFilterIndex];

		// put everything into oFilters
		for (int i = 0; i < iFilterIndex; i++)
		{
			oFilters[0][i]     = oProperties[i];
			oFilters[1][i]     = oOperators[i];
			oFilters[2][i]     = oOperands[i];
		}

		ASQueryResultWrapper ptqrAuditMessages = new ASQueryResultWrapper(m_AuditManager.QueryAuditMsgs(
					PT_PROPIDS.PT_PROPID_ALL,
					(intAllMessageTypes == m_intQueryMessageTypeValue) ? (-1)
																  : m_intQueryMessageTypeValue,
					m_intSkipMessages, m_intResultsPerPage + 1, oFilters,
					m_intSortType));
		intMessagesCount = ptqrAuditMessages.GetCount();
		SetQueryCount(intMessagesCount);

		if (intMessagesCount >= (m_intResultsPerPage + 1))
		{
			intMessagesCount = m_intResultsPerPage;
		}

		if (intMessagesCount > 0)
		{
			myArray = new PTSortedArrayWrapper();

			int[] arrIndexes = new int[]
				{
					PT_PROPIDS.PT_PROPID_CLASSID,
					PT_PROPIDS.PT_PROPID_AUDIT_CLASSNAME,
					PT_PROPIDS.PT_PROPID_OBJECTID,
					PT_PROPIDS.PT_PROPID_AUDIT_OBJECTNAME,
					PT_PROPIDS.PT_PROPID_AUDIT_USERID,
					PT_PROPIDS.PT_PROPID_AUDIT_USERNAME,
					PT_PROPIDS.PT_PROPID_AUDIT_SERVERNAME,
					PT_PROPIDS.PT_PROPID_AUDIT_MSGTYPE,
					PT_PROPIDS.PT_PROPID_AUDIT_MSGTIME,
					PT_PROPIDS.PT_PROPID_AUDIT_MSGCONTENT
				};
			Object[][] arrData = new Object[10][intMessagesCount];
			int[][] arrSort    = new int[1][2];
			arrSort[0][0]	   = PT_PROPIDS.PT_PROPID_AUDIT_MSGTIME;

			if (DisplayPrefsView.iOldestFirst == m_intSortType)
			{
				arrSort[0][1] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
			}
			else
			{
				arrSort[0][1] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
			}

			for (int i = 0; i < intMessagesCount; i++)
			{
				arrData[0][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_CLASSID);
				arrData[1][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_CLASSNAME);
				arrData[2][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_OBJECTID);
				arrData[3][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_OBJECTNAME);
				arrData[4][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_USERID);
				arrData[5][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_USERNAME);
				arrData[6][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_SERVERNAME);
				arrData[7][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_MSGTYPE);
				arrData[8][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_MSGTIME);
				arrData[9][i]     = ptqrAuditMessages.GetFields(i,
						PT_PROPIDS.PT_PROPID_AUDIT_MSGCONTENT);						
			}

			myArray.Initialize(arrIndexes, arrData, arrSort, false);
		}

		return myArray;
	}

	/**
	 * Returns the date-picker control manager.
	 *
	 * @return The date-picker control manager.
	 */
	public JSDatePickerMgr GetDatePickerControlManager(int _nPageType)
	{
		if (_nPageType == N_DATE_PICKER_PAGE_TYPE_MESSAGES)
		{
			return m_ptDatePickerMgr_MessagesPg;	
		}
		else if (_nPageType == N_DATE_PICKER_PAGE_TYPE_QUERY)
		{
			return m_dateTimePickerMgr_QueryPg;
		}
		else
		{
			return null;
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetItemName()
	{
		return m_strItemName;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetItemNameApproximateType()
	{
		return m_intItemNameApproximateType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetItemType()
	{
		return m_intItemType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetMessageTypeValue()
	{
		return m_intMessageTypeValue;
	}
	
	/**
	 * 
	 *
	 * @return 
	 */
	public int GetQueryMessageTypeValue()
	{
		return m_intQueryMessageTypeValue;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetQueryCount()
	{
		return m_intQueryCount;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetResultsPerPage()
	{
		return m_intResultsPerPage;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetServerName()
	{
		return m_strServerName;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetServerNameApproximateType()
	{
		return m_intServerNameApproximateType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetSkipMessages()
	{
		return m_intSkipMessages;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetSortType()
	{
		return m_intSortType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetUserName()
	{
		return m_strUserName;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetUserNameApproximateType()
	{
		return m_intUserNameApproximateType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetWordInMessage()
	{
		return m_strWordInMessage;
	}
	//************* End Audit Query Central helper methods **************

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetArchivePath()
	{
		return m_strArchivePath;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetDaysInDB()
	{
		return m_intDaysInDB;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetDaysInFiles()
	{
		return m_intDaysInFiles;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetDeleteAction()
	{
		return m_intDeleteAction;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetDeleteMessageTypeValue()
	{
		return m_intDeleteMessageTypeValue;
	}

	/**
	 * 
	 *
	 * @param parent 
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);

		// JF- Get the Session object from the associated AS.
		m_Session = (IPTSession) parent.GetUserSession();

		// open the audit manager
		m_AuditManager = (IPTAuditManager) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_AUDITMANAGER,
				false);

		// Message date-picker...
		String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(parent.GetIsSecuredSpace());
		m_ptPageMgr_MessagesPg = new PageMgr(m_asOwner.GetAccessStyle(), PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner), PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner), strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
		
		JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
		JSDatePickerVersionMgr ptDatePickerVersionMgr = new JSDatePickerVersionMgr();
		
		m_ptDatePickerMgr_MessagesPg = new JSDatePickerMgr(ptJSRegistry, ptDatePickerVersionMgr, m_ptPageMgr_MessagesPg);
		m_ptPageMgr_MessagesPg.RegisterComponentMgr(m_ptDatePickerMgr_MessagesPg);

		ADatePickerComponent ptDatePicker = (ADatePickerComponent) m_ptPageMgr_MessagesPg.AddPageControl("DatePicker");
		XPDateTime defaultDateTime = new XPDateTime();
		ptDatePicker.Init(EditorDP.HTMLFORM_NAME, defaultDateTime, m_ptPageMgr_MessagesPg, STR_DELETION_DATE_PICKER_UNIQUE_ID);
		m_ptDatePickerMgr_MessagesPg.RegisterComponent(ptDatePicker);

		// Query date/time-pickers...
		m_ptPageMgr_QueryPg = new PageMgr(m_asOwner.GetAccessStyle(), PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner), PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner), strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		m_dateTimePickerMgr_QueryPg = new JSDateTimePickerMgr(ptJSRegistry, ptDatePickerVersionMgr, m_ptPageMgr_QueryPg);
		m_ptPageMgr_QueryPg.RegisterComponentMgr(m_dateTimePickerMgr_QueryPg);

		ADatePickerComponent dateTimePicker1 = (ADatePickerComponent) m_ptPageMgr_MessagesPg.AddPageControl("DateTimePicker");
		dateTimePicker1.Init(EditorDP.HTMLFORM_NAME, m_ptPageMgr_MessagesPg, STR_START_DATE_PICKER_UNIQUE_ID);
		m_dateTimePickerMgr_QueryPg.RegisterComponent(dateTimePicker1);
		
		ADatePickerComponent dateTimePicker2 = (ADatePickerComponent) m_ptPageMgr_MessagesPg.AddPageControl("DateTimePicker");
		dateTimePicker2.Init(EditorDP.HTMLFORM_NAME, m_ptPageMgr_MessagesPg, STR_END_DATE_PICKER_UNIQUE_ID);
		m_dateTimePickerMgr_QueryPg.RegisterComponent(dateTimePicker2);
	}

	//************* Audit Query Central Repost methods ***************
	/**
	 * 
	 */
	public void RepostQueryResultPageOnNext()
	{
		m_intSkipMessages += m_intResultsPerPage;
	}

	/**
	 * 
	 */
	public void RepostQueryResultPageOnPrevious()
	{
		m_intSkipMessages -= m_intResultsPerPage;
	}
	//************* End Audit Query Central Repost methods ***************

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(AuditManagerDP.STR_MVC_CLASS_NAME))
		{
			String[] data;

			// Process the message types
			int iMessageTypeValue = 0;

			// ITEM CHANGE
			data = (String[]) _htFormData.GetElement(MessageTypesView.HTMLCHECKBOX_ITEM_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage ItemChange checkbox value was not in Query String.");
				
			}

			// ITEM DELETION
			data = (String[]) _htFormData.GetElement(MessageTypesView.HTMLCHECKBOX_ITEM_DELETION);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage ItemDeletion checkbox value was not in Query String.");
				
			}

			// LOCKED ACCOUNT
			data = (String[]) _htFormData.GetElement(MessageTypesView.HTMLCHECKBOX_LOCKED_ACCOUNT);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage LockedAccount checkbox value was not in Query String.");
				
			}

			// SECURITY CHANGE
			data = (String[]) _htFormData.GetElement(MessageTypesView.HTMLCHECKBOX_SECURITY_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage SecurityChange checkbox value was not in Query String.");
				
			}

			// USER LOGIN
			data = (String[]) _htFormData.GetElement(MessageTypesView.HTMLCHECKBOX_USER_LOGIN);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_LOGIN;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage UserLogin checkbox value was not in Query String.");
				
			}

			// GLOBAL SYSTEM CHANGE
			data = (String[]) _htFormData.GetElement(MessageTypesView.HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage GlobalSystemChange checkbox value was not in Query String.");
				
			}

			SetMessageTypeValue(iMessageTypeValue);

			// NETWORK PATH OF ARCHIVE FILES
			data = (String[]) _htFormData.GetElement(ArchivingAgentView.HTMLINPUT_ARCHIVE_PATH);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					String strArchiveFilePath = data[0];
					SetArchivePath(strArchiveFilePath);

					
						log.Debug("AuditManagerModel::SavePage Network path of archive files: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditManagerModel::SavePage An error occured when trying to save the network path of archive files. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage Network path of archive files was not in Query String.");
				
			}
			
			// DAYS IN DB
			data = (String[]) _htFormData.GetElement(ArchivingAgentView.HTMLINPUT_DAYSINDB);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int nDaysInDB = XPConvert.ToInteger(data[0]);
					SetDaysInDB(nDaysInDB);

					
						log.Debug("AuditManagerModel::SavePage New days in DB: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditManagerModel::SavePage An error occured when trying to save the days in DB. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage DaysInDB was not in Query String.");
				
			}

			// DAYS IN FILES
			data = (String[]) _htFormData.GetElement(ArchivingAgentView.HTMLINPUT_DAYSINFILES);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int nDaysInFiles = XPConvert.ToInteger(data[0]);
					SetDaysInFiles(nDaysInFiles);

					
						log.Debug("AuditManagerModel::SavePage New days in Files: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditManagerModel::SavePage An error occured when trying to save the days in Files. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage DaysInFiles was not in Query String.");
				
			}

			// DELETE DATE
			m_ptPageMgr_MessagesPg.StoreAllUserInput(_htFormData); // JAO -- This is the only page control and will store the date.

			// Process the delete message types
			iMessageTypeValue     = 0;

			// DELETE ITEM CHANGE
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_ITEM_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage ItemChange checkbox value was not in Query String.");
				
			}

			// DELETE ITEM DELETION
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_ITEM_DELETION);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage ItemDeletion checkbox value was not in Query String.");
				
			}

			// DELETE LOCKED ACCOUNT
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_LOCKED_ACCOUNT);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage LockedAccount checkbox value was not in Query String.");
				
			}

			// DELETE SECURITY CHANGE
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_SECURITY_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage SecurityChange checkbox value was not in Query String.");
				
			}

			// DELETE USER LOGIN
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_USER_LOGIN);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_LOGIN;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage UserLogin checkbox value was not in Query String.");
				
			}

			// DELETE GLOBAL SYSTEM CHANGE
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE;
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage GlobalSystemChange checkbox value was not in Query String.");
				
			}

			SetDeleteMessageTypeValue(iMessageTypeValue);

			// DELETE ACTION
			data = (String[]) _htFormData.GetElement(MessageDeleteView.HTMLCHECKBOX_DELETEACTION);

			if ((null != data) && !(0 == data.length))
			{
				SetDeleteAction(MessageDeleteView.intChecked);
			}
			else
			{
				
					log.Warn("AuditManagerModel::SavePage DeleteAction checkbox value was not in Query String.");
				
			}
		}
		
		if (_sPageName.equals(AuditQueryCentralDP.STR_MVC_CLASS_NAME))
		{
			String[] data;

			// ITEM TYPE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLSELECT_ITEM_TYPE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int nItemType = XPConvert.ToInteger(data[0]);
					SetItemType(nItemType);

					
						log.Debug("AuditQueryCentralModel::SavePage New item type: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the item type. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ApprovalItemType was not in Query String.");
				
			}

			// ITEM NAME
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLINPUT_ITEM_NAME);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					SetItemName(data[0]);

					
						log.Debug("AuditQueryCentralModel::SavePage New item name: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the item name. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ItemName was not in Query String.");
				
			}

			// ITEM NAME APPROXIMATE TYPE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLSELECT_ITEM_NAME_APPROXIMATE_TYPE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int iItemNameApproximateType = XPConvert.ToInteger(data[0]);
					SetItemNameApproximateType(iItemNameApproximateType);

					
						log.Debug("AuditQueryCentralModel::SavePage New item name approx type: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the item name approx type. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ItemNameApproximateType was not in Query String.");
				
			}

			// USER NAME
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLINPUT_USER_NAME);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					SetUserName(data[0]);

					
						log.Debug("AuditQueryCentralModel::SavePage New user name: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the user name. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage UserName was not in Query String.");
				
			}

			// USER NAME APPROXIMATE TYPE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLSELECT_USER_NAME_APPROXIMATE_TYPE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int iUserNameApproximateType = XPConvert.ToInteger(data[0]);
					SetUserNameApproximateType(iUserNameApproximateType);

					
						log.Debug("AuditQueryCentralModel::SavePage New user name approx type: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the user name approx type. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage UserNameApproximateType was not in Query String.");
				
			}

			// SERVER NAME
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLINPUT_SERVER_NAME);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					SetServerName(data[0]);

					
						log.Debug("AuditQueryCentralModel::SavePage New server name: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the server name. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ServerName was not in Query String.");
				
			}

			// SERVER NAME APPROXIMATE TYPE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLSELECT_SERVER_NAME_APPROXIMATE_TYPE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int iServerNameApproximateType = XPConvert.ToInteger(data[0]);
					SetServerNameApproximateType(iServerNameApproximateType);

					
						log.Debug("AuditQueryCentralModel::SavePage New server name approx type: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the server name approx type. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ServerNameApproximateType was not in Query String.");
				
			}

			// WORD IN MESSAGE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLINPUT_WORD_IN_MESSAGE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					SetWordInMessage(data[0]);

					
						log.Debug("AuditQueryCentralModel::SavePage New word in message: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save word in message. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage WordInMessage was not in Query String.");
				
			}

			int iMessageTypeValue = 0;

			// ITEM CHANGE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLCHECKBOX_ITEM_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE;
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ItemChange checkbox value was not in Query String.");
				
			}

			// ITEM DELETION
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLCHECKBOX_ITEM_DELETION);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION;
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ItemDeletion checkbox value was not in Query String.");
				
			}

			// LOCKED ACCOUNT
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLCHECKBOX_LOCKED_ACCOUNT);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT;
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage LockedAccount checkbox value was not in Query String.");
				
			}

			// SECURITY CHANGE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLCHECKBOX_SECURITY_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE;
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage SecurityChange checkbox value was not in Query String.");
				
			}

			// USER LOGIN
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLCHECKBOX_USER_LOGIN);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_LOGIN;
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage UserLogin checkbox value was not in Query String.");
				
			}

			// GLOBAL SYSTEM CHANGE
			data = (String[]) _htFormData.GetElement(SearchCriteriaView.HTMLCHECKBOX_GLOBAL_SYSTEM_CHANGE);

			if ((null != data) && !(0 == data.length))
			{
				iMessageTypeValue = iMessageTypeValue |
					PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE;
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage GlobalSystemChange checkbox value was not in Query String.");
				
			}

			SetQueryMessageTypeValue(iMessageTypeValue);

			// START AND END DATE
			m_ptPageMgr_QueryPg.StoreAllUserInput(_htFormData); // JAO -- This is the only page control and will store the date.

			// SORT TYPE
			data = (String[]) _htFormData.GetElement(DisplayPrefsView.HTMLRADIO_SORTTYPE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int nSortType = XPConvert.ToInteger(data[0]);
					SetSortType(nSortType);

					
						log.Debug("AuditQueryCentralModel::SavePage New sort type: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the sort type. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage SortType was not in Query String.");
				
			}

			// RESULTS PER PAGE
			data = (String[]) _htFormData.GetElement(DisplayPrefsView.HTMLINPUT_RESULTSPERPAGE);

			if ((null != data) && !(0 == data.length))
			{
				try
				{
					int nResultsPerPage = XPConvert.ToInteger(data[0]);
					SetResultsPerPage(nResultsPerPage);

					
						log.Debug("AuditQueryCentralModel::SavePage New results per page: " +
							data[0]);
					
				}
				catch (Exception e)
				{
					
						log.Error("AuditQueryCentralModel::SavePage An error occured when trying to save the results per page. Exception: " +
							e);
					
				}
			}
			else
			{
				
					log.Warn("AuditQueryCentralModel::SavePage ResultsPerPage was not in Query String.");
				
			}

			// When we're coming from the editor, always set the SkipMessages to 0;
			SetSkipMessages(0);
			SetQueryCount(0);
		}


		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @param strArchivePath 
	 */
	public void SetArchivePath(String strArchivePath)
	{
		m_strArchivePath = strArchivePath;

		
			log.Debug("AuditManagerModel::SetArchivePath New archive path: " +
				m_strArchivePath);
		
	}

	/**
	 * 
	 *
	 * @param iDaysInDB 
	 */
	public void SetDaysInDB(int iDaysInDB)
	{
		m_intDaysInDB = iDaysInDB;

		
			log.Debug("AuditManagerModel::SetDaysInDB New days in DB: " +
				m_intDaysInDB);
		
	}

	/**
	 * 
	 *
	 * @param iDaysInFiles 
	 */
	public void SetDaysInFiles(int iDaysInFiles)
	{
		m_intDaysInFiles = iDaysInFiles;

		
			log.Debug("AuditManagerModel::SetDaysInFiles New days in Files: " +
				m_intDaysInFiles);
		
	}

	/**
	 * 
	 *
	 * @param iDeleteAction 
	 */
	public void SetDeleteAction(int iDeleteAction)
	{
		m_intDeleteAction = iDeleteAction;

		
			log.Debug("AuditManagerModel::SetDeleteAction New delete action: " +
				m_intDeleteAction);
		
	}

	/**
	 * 
	 *
	 * @param iDeleteMessageTypeValue 
	 */
	public void SetDeleteMessageTypeValue(int iDeleteMessageTypeValue)
	{
		m_intDeleteMessageTypeValue = iDeleteMessageTypeValue;

		
			log.Debug("AuditManagerModel::SetDeleteMessageTypeValue New delete message type value: " +
				m_intDeleteMessageTypeValue);
		
	}

	/**
	 * 
	 *
	 * @param iMessageTypeValue 
	 */
	public void SetMessageTypeValue(int iMessageTypeValue)
	{
		m_intMessageTypeValue = iMessageTypeValue;

		
			log.Debug("AuditManagerModel::SetMessageTypeValue New message type value: " +
				m_intMessageTypeValue);
		
	}
	
	/**
	 * 
	 *
	 * @param iQueryMessageTypeValue 
	 */
	public void SetQueryMessageTypeValue(int iQueryMessageTypeValue)
	{
		m_intQueryMessageTypeValue = iQueryMessageTypeValue;

		
			log.Debug("AuditManagerModel::SetQueryMessageTypeValue New message type value: " +
				m_intQueryMessageTypeValue);
		
	}

	//*************** Audit Query Central Set methods *****************

	/**
	 * 
	 *
	 * @param strItemName 
	 */
	public void SetItemName(String strItemName)
	{
		m_strItemName = strItemName;

		
			log.Debug("AuditQueryCentralModel::SetItemName New item name: " +
				m_strItemName);
		
	}

	/**
	 * 
	 *
	 * @param iItemNameApproximateType 
	 */
	public void SetItemNameApproximateType(int iItemNameApproximateType)
	{
		m_intItemNameApproximateType = iItemNameApproximateType;

		
			log.Debug("AuditQueryCentralModel::SetItemNameApproximateType New item name approximate value: " +
				iItemNameApproximateType);
		
	}

	/**
	 * 
	 *
	 * @param iItemType 
	 */
	public void SetItemType(int iItemType)
	{
		m_intItemType = iItemType;

		
			log.Debug("AuditQueryCentralModel::SetItemType New item type: " +
				m_intItemType);
		
	}

	/**
	 * 
	 *
	 * @param iQueryCount 
	 */
	public void SetQueryCount(int iQueryCount)
	{
		m_intQueryCount = iQueryCount;

		
			log.Debug("AuditQueryCentralModel::SetQueryCount New query count: " +
				m_intQueryCount);
		
	}

	/**
	 * 
	 *
	 * @param iResultsPerPage 
	 */
	public void SetResultsPerPage(int iResultsPerPage)
	{
		m_intResultsPerPage = iResultsPerPage;

		
			log.Debug("AuditQueryCentralModel::SetResultsPerPage New results per page: " +
				m_intResultsPerPage);
		
	}

	/**
	 * 
	 *
	 * @param strServerName 
	 */
	public void SetServerName(String strServerName)
	{
		m_strServerName = strServerName;

		
			log.Debug("AuditQueryCentralModel::SetServerName New server name: " +
				m_strServerName);
		
	}

	/**
	 * 
	 *
	 * @param iServerNameApproximateType 
	 */
	public void SetServerNameApproximateType(int iServerNameApproximateType)
	{
		m_intServerNameApproximateType = iServerNameApproximateType;

		
			log.Debug("AuditQueryCentralModel::SetServerNameApproximateType New server name approximate value: " +
				iServerNameApproximateType);
		
	}

	/**
	 * 
	 *
	 * @param iSkipMessages 
	 */
	public void SetSkipMessages(int iSkipMessages)
	{
		m_intSkipMessages = iSkipMessages;

		
			log.Debug("AuditQueryCentralModel::SetSkipMessages New skip messages: " +
				m_intSkipMessages);
		
	}

	/**
	 * 
	 *
	 * @param iSortType 
	 */
	public void SetSortType(int iSortType)
	{
		m_intSortType = iSortType;

		
			log.Debug("AuditQueryCentralModel::SetSortType New sort type: " +
				m_intSortType);
		
	}

	/**
	 * 
	 *
	 * @param strUserName 
	 */
	public void SetUserName(String strUserName)
	{
		m_strUserName = strUserName;

		
			log.Debug("AuditQueryCentralModel::SetUserName New user name: " +
				m_strUserName);
		
	}

	/**
	 * 
	 *
	 * @param iUserNameApproximateType 
	 */
	public void SetUserNameApproximateType(int iUserNameApproximateType)
	{
		m_intUserNameApproximateType = iUserNameApproximateType;

		
			log.Debug("AuditQueryCentralModel::SetUserNameApproximateType New user name approximate value: " +
				iUserNameApproximateType);
		
	}

	/**
	 * 
	 *
	 * @param strWordInMessage 
	 */
	public void SetWordInMessage(String strWordInMessage)
	{
		m_strWordInMessage = strWordInMessage;

		
			log.Debug("AuditQueryCentralModel::SetWordInMessage New word in message: " +
				m_strWordInMessage);
		
	}

	private XPDateTime GetDateFromDatePicker(int _nPageType, String _strUniqueInstanceID)
	{
		JSDatePicker ptJSDatePicker = null;
		if (_nPageType == N_DATE_PICKER_PAGE_TYPE_MESSAGES)
		{
			ptJSDatePicker = (JSDatePicker) m_ptDatePickerMgr_MessagesPg.GetComponent(_strUniqueInstanceID);	
		}
		else if (_nPageType == N_DATE_PICKER_PAGE_TYPE_QUERY)
		{
			ptJSDatePicker = (JSDatePicker) m_dateTimePickerMgr_QueryPg.GetComponent(_strUniqueInstanceID);
		}
		else
		{
			return null;
		}
		
		return ptJSDatePicker.GetDateAsDateTime();
	}

	private XPDateTime GetDateTimeFromDateTimePicker(int _nPageType, String _strUniqueInstanceID)
	{
		JSDateTimePicker ptJSDateTimePicker = null;
		if (_nPageType == N_DATE_PICKER_PAGE_TYPE_MESSAGES)
		{
			ptJSDateTimePicker = (JSDateTimePicker) m_ptDatePickerMgr_MessagesPg.GetComponent(_strUniqueInstanceID);	
		}
		else if (_nPageType == N_DATE_PICKER_PAGE_TYPE_QUERY)
		{
			ptJSDateTimePicker = (JSDateTimePicker) m_dateTimePickerMgr_QueryPg.GetComponent(_strUniqueInstanceID);
		}
		else
		{
			return null;
		}
		
		return ptJSDateTimePicker.GetDateTimeAsDateTime();
	}
	
	
	/**
	 * Returns the Message Type String given the ID.
	 * 
	 * @param _nMessageTypeID Message Type as ID.
	 * @return Message Type as String.
	 */
	public String GetMessageTypeAsString(int _nMessageTypeID)
	{
		switch (_nMessageTypeID)
		{
			case PT_AUDIT_TYPES.PT_AUDIT_OBJECT_CHANGE:
				return m_asOwner.GetString(1421, "ptmsgs_portaladminmsgs");
			case PT_AUDIT_TYPES.PT_AUDIT_GLOBAL_CHANGE:
				return m_asOwner.GetString(1426, "ptmsgs_portaladminmsgs");
			case PT_AUDIT_TYPES.PT_AUDIT_SECURITY_CHANGE:
				return m_asOwner.GetString(1425, "ptmsgs_portaladminmsgs");
			case PT_AUDIT_TYPES.PT_AUDIT_LOGIN:
				return m_asOwner.GetString(1423, "ptmsgs_portaladminmsgs");
			case PT_AUDIT_TYPES.PT_AUDIT_OBJECT_DELETION:
				return m_asOwner.GetString(1422, "ptmsgs_portaladminmsgs");
			case PT_AUDIT_TYPES.PT_AUDIT_LOCKED_ACCOUNT:
				return m_asOwner.GetString(1424, "ptmsgs_portaladminmsgs");
		}
		
		return m_asOwner.GetString(2699, "ptmsgs_portaladminmsgs");
	}
}
















