package com.plumtree.portalpages.admin.serversettings.auditmanager;

// Framework Imports
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the Expandable List page of the List Editor.
 *
 * @author Julie Fournier
 */

// ***CHANGE_HERE*** Change the name of the class.
// ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
//       when you are done.
public class AuditQueryCentralDP extends EditorDP {
	// ***CHANGE_HERE*** Set the class name.
	// COMMENT1- All the DPs in your AS need to have a unique name.

	
	public static final String STR_MVC_CLASS_NAME = "AuditQueryCentral";

	/**
	 * Displays some HTML after the body tag and before the form tag.
	 * For example this is used by pages using a DHTML calendar to display the div tag.
	 * The function is optional.  If it exists, it will be called by the framework, and
	 * the resulting HTMLElement will be added in the right place.
	 *
	 * @return HTMLElement
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm()
	{
		IAuditManagerModelRO ptROModel = (IAuditManagerModelRO) m_asOwner.GetModel(AuditManagerModel.STR_MVC_CLASS_NAME);
		return ptROModel.GetDatePickerControlManager(AuditManagerModel.N_DATE_PICKER_PAGE_TYPE_QUERY).GetPagePreFormContent();
	}

	/**
	 * Returns the HTML that is placed in the HEAD section of this HTML page.
	 *
	 * @return HTMLElement
	 */
	public HTMLElementCollection DisplayHTMLinHEAD()
	{
		IAuditManagerModelRO ptROModel = (IAuditManagerModelRO) m_asOwner.GetModel(AuditManagerModel.STR_MVC_CLASS_NAME);
		return ptROModel.GetDatePickerControlManager(AuditManagerModel.N_DATE_PICKER_PAGE_TYPE_MESSAGES).GetJSIncludes();
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		// ***CHANGE_HERE*** Returns the String to display on the left navigation menu, 
		//       linking to that page.
		// ***COMMENT_1*** That String will also be printed out in the page header, so
		//     even if you don't use the left nav menu, it should still return something.
		return (m_asOwner.GetString(1362, "ptmsgs_portaladminmsgs"));
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1645, "ptmsgs_portaladminmsgs"),
			this.m_asOwner);
	}

	// Strings to localize.
	// ***CHANGE_HERE*** List of the Strings that need to be localized.
	// ***COMMENT_1*** The names should all start with "_ui_".
	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for that Page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// ***CHANGE_HERE PLUG-IN ONLY*** For each Section you want to display on that page, 
		//       copy the line below and replace ListView with your Section name.
		// ***CHANGE_HERE GROWABLELIST*** Display the list.
		//views.AddInnerHTMLElement(((EditorView)
		//	m_asOwner.GetView(AuditQueryCentralEditorAS.m_strStorageGrowableList)).Display());
		// ***CHANGE_HERE SELECTPTOBJECT*** Display the list.
		//views.AddInnerHTMLElement(((EditorView)
		//	m_asOwner.GetView(AuditManagerEditorAS.m_strStorageSelectPTObject)).Display());
		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(SearchCriteriaView.STR_MVC_CLASS_NAME))
				.Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		// ***CHANGE_HERE*** If you have more than one Section, 
		//      you might want to insert an empty table between your Views:
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(
			((EditorView) m_asOwner.GetView(TimesDatesView.STR_MVC_CLASS_NAME))
				.Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(
			((EditorView) m_asOwner
				.GetView(DisplayPrefsView.STR_MVC_CLASS_NAME))
				.Display());

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		// ***CHANGE_HERE GROWABLELIST*** Display JavaScripts for the Growable Array.
		//myScripts.AddInnerHTMLElement(m_asOwner.GetView(AuditQueryCentralEditorAS.m_strStorageGrowableList).DisplayJavascript());
		// ***CHANGE_HERE SELECTPTOBJECT*** Display JavaScripts for the Select PTObject list.
		//myScripts.AddInnerHTMLElement(m_asOwner.GetView(AuditManagerEditorAS.m_strStorageSelectPTObject).DisplayJavascript());
		return myScripts;
	}
}

