package com.plumtree.portalpages.admin.serversettings.general;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class displays the UI for the password management settings.
 */
public class PasswordRulesView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.general.PasswordView");

	public static final String STR_MVC_CLASS_NAME = "PasswordRulesView";

	@Override
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;

		try
		{
			// Password Management
			result.AddInnerHTMLElement(super.GetHeaderView(
				m_asOwner.GetString(3247, ResourceConstants.PORTALADMINMSGS)));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");


			// Password Length Error
			String strLengthError = null;
			if (((ISetServerSettingsModelRO) this.m_model).HasPasswordLengthError())
			{
				strLengthError = XPResourceManager.FormatMessage(m_asOwner.GetString(3258,
					ResourceConstants.PORTALADMINMSGS), SetServerSettingsModel.MIN_PASSWORD_LENGTH,
					SetServerSettingsModel.MAX_PASSWORD_LENGTH);
			}

			// Password Length Rows
			// No description
			CreateEditorItem(myTable, m_asOwner.GetString(3248, ResourceConstants.PORTALADMINMSGS),
				false, SetServerSettingsRepostControl.PARAM_PASSWORD_LENGTH,
				XPConvert.ToString(((ISetServerSettingsModelRO) this.m_model).GetPasswordLength()),
				false, null, strLengthError);


			// Passwords Require a Number Rows
			// No description, no errors
			// Beginning of row
			CreateEditorItem(myTable, m_asOwner.GetString(3249, ResourceConstants.PORTALADMINMSGS),
				true, SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_NUMBERS, null,
				((ISetServerSettingsModelRO) this.m_model).GetPasswordIncludeNumbers(), null, null);


			// Passwords Require Casing Rows
			// No description, no errors
			// Beginning of row
			CreateEditorItem(myTable, m_asOwner.GetString(3250, ResourceConstants.PORTALADMINMSGS),
				true, SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_CASING, null,
				((ISetServerSettingsModelRO) this.m_model).GetPasswordIncludeCasing(), null, null);


			// Passwords Require Punctuation Rows
			// No description (TODO: Do we need one?), no errors
			// Beginning of row
			CreateEditorItem(myTable, m_asOwner.GetString(3251, ResourceConstants.PORTALADMINMSGS),
				true, SetServerSettingsRepostControl.PARAM_PASSWORD_INCLUDE_PUNCTUATION, null,
				((ISetServerSettingsModelRO) this.m_model).GetPasswordIncludePunctuation(), null, null);


			// Passwords Cannot Include the User ID Rows
			// No description, no errors
			// Beginning of row
			CreateEditorItem(myTable, m_asOwner.GetString(3252, ResourceConstants.PORTALADMINMSGS),
				true, SetServerSettingsRepostControl.PARAM_PASSWORD_NO_USER_IDS, null,
				((ISetServerSettingsModelRO) this.m_model).GetPasswordNoUserIDs(), null, null);


			// Password Reuse History Error
			String strReuseError = null;
			if (((ISetServerSettingsModelRO) this.m_model).HasPasswordReuseHistoryError())
			{
				strReuseError = XPResourceManager.FormatMessage(m_asOwner.GetString(3259,
					ResourceConstants.PORTALADMINMSGS), 0, SetServerSettingsModel.MAXIMUM_PASSWORD_HISTORY);
			}

			// Password Reuse History Rows
			CreateEditorItem(myTable, m_asOwner.GetString(3253, ResourceConstants.PORTALADMINMSGS),
				false, SetServerSettingsRepostControl.PARAM_PASSWORD_REUSE_HISTORY,
				XPConvert.ToString(((ISetServerSettingsModelRO) this.m_model).GetPasswordReuseHistory()),
				false, m_asOwner.GetString(3254, ResourceConstants.PORTALADMINMSGS), strReuseError);


			// Password expiration Error
			String strExpirationError = null;
			if (((ISetServerSettingsModelRO) this.m_model).HasPasswordExpirationError())
			{
				strExpirationError = XPResourceManager.FormatMessage(m_asOwner.GetString(3260,
					ResourceConstants.PORTALADMINMSGS), 0);
			}

			// Password expiration Rows
			CreateEditorItem(myTable, m_asOwner.GetString(3255, ResourceConstants.PORTALADMINMSGS),
				false, SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION,
				XPConvert.ToString(((ISetServerSettingsModelRO) this.m_model).GetPasswordExpiration()),
				false, m_asOwner.GetString(3256, ResourceConstants.PORTALADMINMSGS), strExpirationError);


			// Password expiration warning Error
			String strExpirationWarningError = null;
			if (((ISetServerSettingsModelRO) this.m_model).HasPasswordExpirationWarningError())
			{
				strExpirationWarningError = m_asOwner.GetString(3265, ResourceConstants.PORTALADMINMSGS);
			}

			// Password expiration warning Rows
			CreateEditorItem(myTable, m_asOwner.GetString(3267, ResourceConstants.PORTALADMINMSGS),
				false, SetServerSettingsRepostControl.PARAM_PASSWORD_EXPIRATION_WARNING,
				XPConvert.ToString(((ISetServerSettingsModelRO) this.m_model).GetPasswordExpirationWarning()),
				false, m_asOwner.GetString(3266, ResourceConstants.PORTALADMINMSGS), strExpirationWarningError);


			result.AddInnerHTMLString("\n" );
			
			HTMLComment myComment = new HTMLComment( "End: Display PasswordView" );
			result.AddInnerHTMLElement( myComment );
			
			result.AddInnerHTMLString("\n");
			
		}
		catch (Exception e)
		{
			log.Error(e, "PasswordView::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(1321,
				"ptmsgs_portaladminmsgs"), e);
		}

		return result;
	}

	/**
	 * This helper method creates a item in the settings editor and adds it to
	 * the specified table.  It can create a description, error, and the main
	 * item (either text input or checkbox).
	 * 
	 * @param _table the table to add the item rows to.
	 * @param _strLabel The label for the item.
	 * @param _bIsCheckbox Whether the item is a checkbox or text input
	 * @param _strInputName The name of the input
	 * @param _strInputValue The value of the input (if it's text)
	 * @param _bCheckboxValue The value of the input (if it's a checkbox)
	 * @param _strDescription The optional description of the item (null for no description)
	 * @param _strError The optional error text for the item (null for no error)
	 */
	public void CreateEditorItem(HTMLTable _table, String _strLabel, boolean _bIsCheckbox,
		String _strInputName, String _strInputValue, boolean _bCheckboxValue,
		String _strDescription, String _strError)
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLInput myInput;


		// beginning of error row
		if (_strError != null)
		{
			myRow = new HTMLTableRow();
			_table.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetColSpan(CommonHTMLStrings.TWO);	
			myCell.SetHeight(CommonHTMLStrings.THREE);
			
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
			// Row Error
			mySpan.AddInnerHTMLString(_strError);
		}
		// End of error row

		// beginning of main row
		myRow = new HTMLTableRow();
		_table.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		myCell.SetWidth( "50%");
		
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

		// Row Item Label
		mySpan.AddInnerHTMLString(_strLabel);
		
		if (_strDescription != null)
		{
			myCell.AddInnerHTMLElement(new HTMLBr());
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			// Row description
			mySpan.AddInnerHTMLString(_strDescription);

		}

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetNoWrap(true);
		myCell.SetAlign(CommonHTMLStrings.LEFT);
		myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

		if (_bIsCheckbox)
		{
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE,
				_strInputName, _strInputName);

			myInput.SetValue(XPConvert.ToString(true));

			if (_bCheckboxValue)
			{
				myInput.SetChecked(_bCheckboxValue);
			}
		} else
		{
			myInput = new HTMLInput(HTMLInputTypes.TEXT_TYPE,
				_strInputName, _strInputName);

			myInput.SetValue(_strInputValue);			
		}

		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myCell.AddInnerHTMLElement(myInput);

		// End of row
	}

	@Override
	public Object Create() {
		return new PasswordRulesView();
	}

	@Override
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}
}