package com.plumtree.portalpages.admin.serversettings.general;

import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Various portal config server settings from the PTSERVERCONFIG db table.
 */
public class SetServerSettingsAS extends PTEditorAS
{
	public static final String STR_MVC_CLASS_NAME = "SetServerSettingsAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetServerSettingsAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return GetString(1346, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SetServerSettingsRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = SetServerSettingsModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(SetServerSettingsModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new UserSettingsDP());

		RegisterPage(new PortalURLsDP());

		RegisterPage(new GeneralSettingsDP());
		
		// Register Views
		RegisterView(NewUserCreationView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(AccountLockingView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(NumericAuthenticationView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(PasswordRulesView.STR_MVC_CLASS_NAME, myModel);
		/* JHQ bug 25352: Doc Team says to remove this view because it is not
		 * accurate.  I will not delete the class, since we may change our mind
		 * in the future.  For now I'll just comment this out. */
//		RegisterView(DefaultLanguageSettingsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(UpdateLoginTokenKeyView.STR_MVC_CLASS_NAME, myModel);

		RegisterView(DebuggingModeView.STR_MVC_CLASS_NAME, myModel);

		RegisterView(PortalURLsView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(SetServerSettingsRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		// Set default page
		SetCurrentPage(UserSettingsDP.STR_MVC_CLASS_NAME);


		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(3264,
					"ptmsgs_portaladminmsgs"));

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			UserSettingsDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PortalURLsDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			GeneralSettingsDP.STR_MVC_CLASS_NAME);
	}
	
	/**
	  * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	  *
	  * @param IDisplayPage the current Display Page
	  */
	 public void SetCurrentPage(IDisplayPage page)
	 {
		  super.SetCurrentPage( page );
		  String sPageName = page.GetName();
		  if(UserSettingsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic("PT_PortalServerManager_UserSettings");                           
		  }
		  else if( PortalURLsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic("PT_PortalServerManager_PortalURLs");
		  }
		  else if( GeneralSettingsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic("PT_PortalServerManager_GeneralSettings");
		  }
	 }
}