package com.plumtree.portalpages.admin.serversettings.globalaclsyncmap;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.ptmulticolumnlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Main Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author JohnH
 */
public class GlobalACLSyncMapAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapAS");

	// All the AS in Plumtree need to have a unique name.

	
	public static final String STR_MVC_CLASS_NAME				   = "GlobalACLSyncMap";

	
	public static final String STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN = "GlobalACLSyncMapDomainList";

	
	public static final String STR_MVC_STORAGE_NAME_GROUP_PLUG_IN = "GlobalACLSyncMapGroupList";

	private static final String sClassName = "com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GlobalACLSyncMapAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (GetString(1473, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	
	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (GlobalACLSyncMapRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = GlobalACLSyncMapModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(GlobalACLSyncMapModel.STR_MVC_CLASS_NAME);

		//Register the model, view and control for the domain map list
		RegisterModel(GlobalACLSyncMapListModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myMultiColumnListModel = GetModel(STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN);
		RegisterView(GlobalACLSyncMapListView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN, myMultiColumnListModel);
		RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN, myMultiColumnListModel);

		//Register the model, view and control for the group map list
		RegisterModel(GlobalACLSyncMapListModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_GROUP_PLUG_IN);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myGroupListModel = GetModel(STR_MVC_STORAGE_NAME_GROUP_PLUG_IN);
		RegisterView(GlobalACLSyncMapListView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_GROUP_PLUG_IN, myGroupListModel);
		RegisterControl(PTMultiColumnListRepostControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_GROUP_PLUG_IN, myGroupListModel);

		// Register DisplayPages
		RegisterPage(new MainDP());
		RegisterPage(new GroupMapDP());

		// Register Views
		// Register Controls
		RegisterControl(GlobalACLSyncMapRepostControl.STR_MVC_CLASS_NAME,
			myModel);

		// Register Migration History Plugin
		RegisterModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME);
		RegisterView(MigrationHistoryView.STR_MVC_CLASS_NAME,
			GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME));
		RegisterPage(new MigrationHistoryPluginDP());

		// Set default page
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		// Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1474,
					"ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, GroupMapDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				

				int iTitleId = 84;
				int iTipId = 85;
				int iSecondaryTipId = 86;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}											
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}
	
	/**
	  * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	  *
	  * @param IDisplayPage the current Display Page
	  */

	 public void SetCurrentPage(IDisplayPage page)
	 {
		 
		  super.SetCurrentPage( page );
		  String sPageName = page.GetName();
		  if(MainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_GlobalACLSyncMap_PrefixDomainMap" );                           
		  }
		
		  else if( GroupMapDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_GlobalACLSyncMap_PortalExternalGroupMap" );
		  } else  if( MigrationHistoryPluginDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		  {
				this.SetHelpTopic( "PT_MigrationHistoryandStatus" );                           
		  }



	 }
}

