package com.plumtree.portalpages.admin.serversettings.globalaclsyncmap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.ptmulticolumnlist.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * 
 * @author jennifersu
 *
 * Custom MultiColumnListModel for the Global ACL Sync Map.
 * Has a Select PT Object Tree but displays certain properties about
 * the selected objects rather than the name itself. (Domain mapping displays
 * auth source prefix; Group mapping displays mappingauthname).  Also,
 * can edit both columns of the list.
 */
public class GlobalACLSyncMapListModel extends PTMultiColumnListModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapListModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "GlobalACLSyncMapListModel";
	
	/**
	 * List displays domain mappings.
	 */
	public static final int ACL_MAP_TYPE_DOMAIN = 0;
	
	/**
	 * List displays group mappings.
	 */
	public static final int ACL_MAP_TYPE_GROUP = 1;
	
	/**
	 * The type of mapping that the current list displays.
	 */
	private int m_nACLMapType;
	
	/**
	 * The column index that is currently being edited.
	 * Need this since both columns of a given row is editable.
	 */
	private int m_intEditColumn;

	/**
	 * 
	 *
	 */
	public GlobalACLSyncMapListModel()
	{
		super();
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GlobalACLSyncMapListModel();
	}
	
	/**
	 * Set the type of mapping that this list contains.
	 * Use constants.
	 * @param _nMapType
	 */
	public void SetMapType(int _nMapType)
	{
		m_nACLMapType = _nMapType;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Overrides PTMultiColumnListModel since
	 * we don't want the tree to pre-select anything.
	 *
	 * This is the format used by the tree.
	 *
	 * @return String
	 */
	public String GetSelectedItems()
	{
		String sSelectedItems = "";

		return sSelectedItems;
	}
	
	/**
	 * Initializes the expandable list.  Overrides PTMultiColumnListModel
	 * since we want both columns to be editable.
	 *
	 * @param _sSectionTitle  - Main title of the view.
	 * @param _sFirstColSubTitle - The subtitle for the selected Plumtree
	 * Object, if appropriate.  If _bIncludePTSelect is FALSE, this shoudl be
	 * set to null.
	 * @param _sSectionSubTitle - An array of subtitles for non-plumtree object
	 * columns
	 * @param _imgAddIcon - Icon for the add action.
	 * @param _sAddLabel - Text to display next to the add icon.
	 * @param _arrObjectClassIDs - The Class ID of the objects displayed on the
	 * list.  This should be null if _bIncludePTSelect is FALSE.
	 * @param _nListKey - In case you have multiple Expandable Lists on the same
	 * DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializePTMultiColumnList(String _sSectionTitle,
		String _sFirstColSubTitle, String[] _sSectionSubTitle,
		PTImageType _imgAddIcon, String _sAddLabel, int[] _arrObjectClassIDs,
		int _nListKey)
	{
		int intNumColumns;

		if (m_bIncludePTSelect)
		{
			intNumColumns = m_intNumColumns + 1;
		}
		else
		{
			intNumColumns = m_intNumColumns;
		}

		//Set the width based on the number of columns
		int intColWidth    = 100 / (intNumColumns);
		XPStringBuilder sb = new XPStringBuilder(5);
		sb.Append(intColWidth).Append("%");

		Object[][] arrExpListColInfo = new Object[intNumColumns][5];

		if (m_bIncludePTSelect)
		{
			//First initialize the name column
			arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_STRING +
					m_intPTObjectPosition);
			arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_TITLE]		    = _sFirstColSubTitle;
			arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_WIDTH]		    = sb.ToString();
			arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_COLSPAN]	    = "2";
			arrExpListColInfo[m_intPTObjectPosition][EXPLIST_COLUMN_ENABLESORT]     = Boolean.TRUE;
		}

		//now initialize the subsequent columns
		int intColumnID;
		int intColIndex;

		for (int i = 0; i < m_intNumColumns; i++)
		{
			if (i < m_intPTObjectPosition)
			{
				intColIndex     = i;
				intColumnID     = i + 1;
			}
			else
			{
				intColIndex     = i + 1;
				intColumnID     = i + 4;
			}

			arrExpListColInfo[intColIndex][EXPLIST_COLUMN_ID]			  = new Integer(intColumnID);
			arrExpListColInfo[intColIndex][EXPLIST_COLUMN_TITLE]		  = _sSectionSubTitle[i];
			arrExpListColInfo[intColIndex][EXPLIST_COLUMN_WIDTH]		  = sb.ToString();
			arrExpListColInfo[intColIndex][EXPLIST_COLUMN_COLSPAN]		  = "2";
			arrExpListColInfo[intColIndex][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;
		}

		m_arrObjectClassIDs = _arrObjectClassIDs;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * Calls the appropriate AddRowOnRepost helper method,
	 * depending on what type of list this is.
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		if (m_nACLMapType == ACL_MAP_TYPE_DOMAIN)
		{
			AddDomainRowsOnRepost(_htFormData);
		}
		else if (m_nACLMapType == ACL_MAP_TYPE_GROUP)
		{
			AddGroupRowsOnRepost(_htFormData);
		}
	}

	/**
	 * For domain mappings, look up the selected auth source's prefix.
	 * The row that gets added displays the prefix string, NOT the auth
	 * source name.
	 * 
	 * @param _htFormData Form data
	 */
	private void AddDomainRowsOnRepost(XPHashtable _htFormData)
	{	
		if (m_bIncludePTSelect)
		{
			//Validate that the proposed position of the selected Plumtree
			//object is not greater than the number of other columns
			if (m_intPTObjectPosition > m_intNumColumns)
			{
				m_intPTObjectPosition = 0;
			}

			TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(
						SUBSPACE_KEY_SELECTTREE));

			if (null != asTree)
			{
				ITreeModelRO myTree    = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList mySelected = myTree.GetSelectedItems();
				Object[] oNewRow;
				int nClassID;

				//First, save the data so we can re-populate the non-tree items
				XPHashtable[] arrHashtables = new XPHashtable[m_intNumColumns +
					3];

				for (int i = 0; i < (m_intNumColumns + 3); i++)
				{
					arrHashtables[i] = new XPHashtable();
				}

				for (int i = 0; i < m_saData.GetCount(); i++)
				{
					for (int j = 1; j < (m_intNumColumns + 4); j++) //skip the index column
					{
						arrHashtables[j - 1].PutElement(m_saData.GetItem(i,
								EXPLIST_COL_STRING + m_intPTObjectPosition),
							m_saData.GetItem(i, j));
					}
				}

				// Look up prefix strings for the selected auth sources.
				IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();
				IPTObjectManager authManager = ptSession.GetAuthSources();
				PTObjectManagerQueryWrapper authQW = new PTObjectManagerQueryWrapper(authManager);
				Object[][] objQueryFilter;
				String strAuthName = "";
				String strPrefix = "";
				for (int i = 0; i < mySelected.GetSize(); i++)
				{
					oNewRow										  = new Object[m_intNumColumns + 4];
					oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
					m_nNextIndex++;
					nClassID												  = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
					oNewRow[EXPLIST_COL_CLASSID + m_intPTObjectPosition]	  = new Integer(nClassID);
					oNewRow[EXPLIST_COL_OBJECTID + m_intPTObjectPosition]     = new Integer(-12345); //bogus object id since we're not really storing objects here
					
					// get prefix
					strAuthName = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
					objQueryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_NAME,
					 PT_FILTEROPS.PT_FILTEROP_EQ, strAuthName);
					authQW.Query(-1, -1, null, objQueryFilter);
					if (authQW.GetCount() > 0)
					{
						strPrefix = XPConvert.ToString(authQW.GetFields(0, PT_PROPIDS.PT_PROPID_AUTHSOURCE_PREFIXSTRING));
						if (null == strPrefix)
						{
							int nAuthID = XPConvert.ToInteger(authQW.GetFields(0, PT_PROPIDS.PT_PROPID_OBJECTID));
							if (1 == nAuthID)
							{
								strPrefix = "Plumtree";
							}
						}
					}
					else
					{
						
							log.Error("GlobalACLSyncMapListModel::AddDomainRowOnRepost	An error occurred when trying to add a row to the domain map list.");
						
					}

					oNewRow[EXPLIST_COL_STRING + m_intPTObjectPosition] = strPrefix;

					//Add the other empty columns
					// TODO CR not used, commenting out.
					//String strValue;
					int intColIndex;

					for (int j = 0; j < m_intNumColumns; j++)
					{
						if (j < m_intPTObjectPosition)
						{
							intColIndex = j + 1;
						}
						else
						{
							intColIndex = j + 4;
						}

						oNewRow[intColIndex] = "";
					}

					super.GetItems().AddRow(oNewRow);
				}
			}
		}
		else
		{
			String[][] arrDefault = new String[m_intNumColumns][1];

			for (int i = 0; i < m_intNumColumns; i++)
			{
				arrDefault[i][0] = m_arrDefaultValue[i];
			}

			AddRowsToList(arrDefault);
		}
	}

	/**
	 * For group mappings, look up the group's mappingauthname instead
	 * of the group object name, since we don't want to display any prefixes
	 * in the UI.
	 *
	 * @param _htFormData Form data
	 */
	private void AddGroupRowsOnRepost(XPHashtable _htFormData)
	{
		if (m_bIncludePTSelect)
		{
			//Validate that the proposed position of the selected Plumtree
			//object is not greater than the number of other columns
			if (m_intPTObjectPosition > m_intNumColumns)
			{
				m_intPTObjectPosition = 0;
			}

			TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(
						SUBSPACE_KEY_SELECTTREE));

			if (null != asTree)
			{
				ITreeModelRO myTree    = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList mySelected = myTree.GetSelectedItems();
				Object[] oNewRow;
				int nClassID;

				//First, save the data so we can re-populate the non-tree items
				XPHashtable[] arrHashtables = new XPHashtable[m_intNumColumns +
					3];

				for (int i = 0; i < (m_intNumColumns + 3); i++)
				{
					arrHashtables[i] = new XPHashtable();
				}

				for (int i = 0; i < m_saData.GetCount(); i++)
				{
					for (int j = 1; j < (m_intNumColumns + 4); j++) //skip the index column
					{
						arrHashtables[j - 1].PutElement(m_saData.GetItem(i,
								EXPLIST_COL_STRING + m_intPTObjectPosition),
							m_saData.GetItem(i, j));
					}
				}

				// Look up the selected groups' mappingauthnames
				IPTSession ptSession = (IPTSession)m_asOwner.GetUserSession();
				IPTObjectManager groupManager = ptSession.GetUserGroups();
				PTObjectManagerQueryWrapper groupQW = new PTObjectManagerQueryWrapper(groupManager);
				Object[][] objQueryFilter;
				String strGroupName = "";
				String strMappingAuthName = "";
				for (int i = 0; i < mySelected.GetSize(); i++)
				{
					oNewRow										  = new Object[m_intNumColumns + 4];
					oNewRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
					m_nNextIndex++;
					nClassID												  = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
					oNewRow[EXPLIST_COL_CLASSID + m_intPTObjectPosition]	  = new Integer(nClassID);
					oNewRow[EXPLIST_COL_OBJECTID + m_intPTObjectPosition]     = new Integer(-12345); // bogus objectid since we're not really storing objects
					
					// get mappingauthname
					strGroupName = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
					objQueryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_NAME,
					 PT_FILTEROPS.PT_FILTEROP_EQ, strGroupName);
					groupQW.Query(-1, -1, null, objQueryFilter);
					if (groupQW.GetCount() > 0)
					{
						strMappingAuthName = XPConvert.ToString(groupQW.GetFields(0, PT_PROPIDS.PT_PROPID_USERGROUP_SIMPLENAME));
					}
					else
					{
						
							log.Error("GlobalACLSyncMapListModel::AddGroupRowOnRepost	An error occurred when trying to add a row to the group map list.");
						
					}

					oNewRow[EXPLIST_COL_STRING + m_intPTObjectPosition] = strMappingAuthName;

					//Add the other empty columns
					// TODO CR not used, commenting out.
					//String strValue;
					int intColIndex;

					for (int j = 0; j < m_intNumColumns; j++)
					{
						if (j < m_intPTObjectPosition)
						{
							intColIndex = j + 1;
						}
						else
						{
							intColIndex = j + 4;
						}

						oNewRow[intColIndex] = "";
					}

					super.GetItems().AddRow(oNewRow);
				}
			}
		}
		else
		{
			String[][] arrDefault = new String[m_intNumColumns][1];

			for (int i = 0; i < m_intNumColumns; i++)
			{
				arrDefault[i][0] = m_arrDefaultValue[i];
			}

			AddRowsToList(arrDefault);
		}
	}

	/**
	 * Saves the data for columns other than the plumtree object select column
	 * on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append(PTMultiColumnListView.HTMLINPUT_ITEM);

		int intIndex;

		for (int i = 0; i <= m_intNumColumns; i++)
		{
			if (i < m_intPTObjectPosition)
			{
				intIndex = i + 1;
			}
			else
			{
				intIndex = i + 3;
			}

			String sDataKey     = GetUniqueString(sb.Append(intIndex).ToString()) +
				_nRowIndex;
			String[] aDataValue;

			// JF- For each input text posted by the form, we get the value back
			// and set the new value in the array.
			if (_htFormData.ContainsKey(sDataKey))
			{
				aDataValue = (String[]) _htFormData.GetElement(sDataKey);

				if ((null != aDataValue) && !(0 == aDataValue.length))
				{
					_saData.SetItem(_nRowIndex, intIndex, aDataValue[0]);
				}
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Returns the column currently being edited.
	 * @return int
	 */
	public int GetEditColumn()
	{
		return m_intEditColumn;
	}

	/**
	 * Sets the column currently being edited.
	 * @param editColumn The column to set
	 */
	public void SetEditColumn(int editColumn)
	{
		m_intEditColumn = editColumn;
	}

	/**
	 * Action for modifying a row
	 *
	 * @param _htFormData 
	 */
	public void ModifyRow(XPHashtable _htFormData)
	{
		String[] data = (String[]) _htFormData.GetElement(PTMultiColumnListView.HTMLHIDDEN_EDITROW);

		if (null != data)
		{
			this.SetEditRow(XPConvert.ToInteger(data[0]));
		}

		data = (String[]) _htFormData.GetElement(GlobalACLSyncMapListView.HTMLHIDDEN_EDITCOL);

		if (null != data)
		{
			this.SetEditColumn(XPConvert.ToInteger(data[0]));
		}
	}

}

