package com.plumtree.portalpages.admin.serversettings.globalaclsyncmap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.ptmulticolumnlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 *
 * Custom MultiColumnListModel for the Global ACL Sync Map.
 * Has a Select PT Object Tree but displays certain properties about
 * the selected objects rather than the name itself. (Domain mapping displays
 * auth source prefix; Group mapping displays mappingauthname).  Also,
 * can edit both columns of the list.
 */
public class GlobalACLSyncMapListView extends PTMultiColumnListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapListView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "GlobalACLSyncMapListView";

	/** Javascript funtion name */
	public static final String JAVASCRIPT_SETEDITROWCOL = "SetEditRowColumn";

	/** Hidden element for the edit column */
	public static final String HTMLHIDDEN_EDITCOL = "in_hi_EditColumn";

	/**
	 * 
	 *
	 */
	public GlobalACLSyncMapListView()
	{
		super();
	}
	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GlobalACLSyncMapListView();
	}

	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains 2 editable columns.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTableCell myCell;
		HTMLInput myInput;
		PTButtonType myType;
		PTConstruct construct		 = null;
		HTMLAnchor myAnchor			 = null;
		String strItem;

		boolean bEditMode = false;
		int intEditCol = -1;
		int intColWidth;
		int intNumColumns;
		int intInputSize;

		if (((IPTMultiColumnListModelRO) m_model).GetIncludePTSelect())
		{
			intNumColumns = ((IPTMultiColumnListModelRO) m_model).GetNumColumns() + 1;
		}
		else
		{
			intNumColumns = ((IPTMultiColumnListModelRO) m_model).GetNumColumns();
		}

		intColWidth = 100 / intNumColumns;

		XPStringBuilder sbColPercent = new XPStringBuilder(5);
		sbColPercent.Append(intColWidth).Append("%");

		XPStringBuilder sbFieldName = new XPStringBuilder(100);
		sbFieldName.Append(HTMLINPUT_ITEM);

		int intStartPosition;
		intStartPosition = ((IPTMultiColumnListModelRO) m_model).GetPTObjectPosition();

		int intIndex;
		String strElementName;

		// Get the row AND column indices for the field that is being edited.
		if (_nRowIndex == ((IPTMultiColumnListModelRO) m_model).GetEditRow())
		{
			bEditMode = true;
			intEditCol = ((GlobalACLSyncMapListModel)m_model).GetEditColumn();
		}
		else
		{
			bEditMode = false;
		}

		for (int i = 0; i < intNumColumns; i++)
		{
			if (i < intStartPosition)
			{
				intIndex = i + 1;
			}
			else
			{
				intIndex = i + 3;
			}

			// 1st column: portal object string (auth source prefix or group mappingauthname)
			if ((i == intStartPosition) &&
					((IPTMultiColumnListModelRO) m_model).GetIncludePTSelect())
			{
				sbFieldName.Append(intIndex);
				myCell = new HTMLTableCell();
				myCell.SetWidth(sbColPercent.ToString());
				myCell.SetHeight("30");
				myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
				myCell.SetNoWrap(true);
				strElementName = ((IPTMultiColumnListModelRO) m_model).GetUniqueString(sbFieldName.ToString()) +
					_nRowIndex;

				// if in edit mode, display value in a text field
				if (bEditMode && intEditCol == i)
				{
					myInput = new HTMLInput(HTMLInputTypes.TEXT, strElementName, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

					strItem = (String) _saData.GetItem(_nRowIndex, intIndex);

					if (null == strItem 
						|| strItem.startsWith(CommonHTMLStrings.SPACE)) // a hack to avoid using default value for input box 
					{
						myInput.SetValue("");
					}
					else
					{
						myInput.SetValue((String) _saData.GetItem(_nRowIndex,
							intIndex));
					}
					
					switch (intNumColumns)
					{
						case 2:
							intInputSize = 70;
							break;
						case 3:
							intInputSize = 50;
							break;
						case 4:
							intInputSize = 30;
							break;
						case 5:
							intInputSize = 20;
							break;
						default:
							intInputSize = 25;
					}
							
					myInput.SetSize(intInputSize);
				}
				else
				{
					strItem = (String) _saData.GetItem(_nRowIndex, intIndex);

					if (null == strItem)
					{
						myCell.AddInnerHTMLString("");
					}
					else
					{
						// HTMLEncode all other values.
						myCell.AddInnerHTMLEncodedString(strItem);
					}
				}

				result.AddInnerHTMLElement(myCell);

				// Display the appropriate Edit or Browse icon
				myCell = new HTMLTableCell();
				result.AddInnerHTMLElement(myCell);
				myCell.SetHeight("20");
				myCell.SetNoWrap(true);

				if (bEditMode && intEditCol == i)
				{
					myType = PTButtonType.BROWSE;
				}
				else
				{
					myType = PTButtonType.EDIT;
				}

				construct     = null;
				myAnchor	  = null;
				try
				{
					//	Get the construct, do update the strings.
					construct = UIConstructFactory.GetConstruct(myType, true,
							this.m_asOwner);
					construct.ReplaceNestedElementsWithHTMLString(myType.TITLE_ELEMENT_NAME,
						"");
					myAnchor = (HTMLAnchor) construct.GetNestedElement(myType.ANCHOR_ELEMENT_NAME);

					//Implement the on click action to edit the field
					myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);

					if (bEditMode && intEditCol == i)
					{
						myAnchor.SetOnClick(JAVASCRIPT_SETEDITROWCOL +
							"('-1', '-1'); return false;");

						ConstructFactory.SetAltOnButtonImages( construct,m_asOwner.GetString(201,
						"ptmsgs_portalinfrastructure") );
						ConstructFactory.SetTitleOnButtonImages( construct,m_asOwner.GetString(201,
						"ptmsgs_portalinfrastructure") );
				
				
					}
					else
					{
						myAnchor.SetOnClick(JAVASCRIPT_SETEDITROWCOL +
							"('" + _nRowIndex + "','" + i + "'); return false;");

						ConstructFactory.SetAltOnButtonImages( construct,m_asOwner.GetString(200,
						"ptmsgs_portalinfrastructure") );
						ConstructFactory.SetTitleOnButtonImages( construct,m_asOwner.GetString(200,
						"ptmsgs_portalinfrastructure") );						
					}
				}
				catch (Exception e)
				{
					PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::GetHTMLForRow", e, false, UIErrorLevel.SERIOUS, 
						m_asOwner.GetString(199, "ptmsgs_portalinfrastructure"));
				}

				myCell.AddInnerHTMLElement(construct.GetHTMLElement());

			}
			else // 2nd column: external string (Domain or external group)
			{
				sbFieldName.Append(intIndex);
				myCell = new HTMLTableCell();
				myCell.SetWidth(sbColPercent.ToString());
				myCell.SetHeight("30");
				myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
				myCell.SetNoWrap(true);
				strElementName = ((IPTMultiColumnListModelRO) m_model).GetUniqueString(sbFieldName.ToString()) +
					_nRowIndex;

				// Edit mode
				if (bEditMode && intEditCol == i)
				{
					myInput = new HTMLInput(HTMLInputTypes.TEXT, strElementName, "");
					myCell.AddInnerHTMLElement(myInput);
					myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

					strItem = (String) _saData.GetItem(_nRowIndex, intIndex);

					if (null == strItem 
						|| strItem.startsWith(CommonHTMLStrings.SPACE)) // a hack to avoid using default value for input box 
					{
						myInput.SetValue("");
					}
					else
					{
						myInput.SetValue((String) _saData.GetItem(_nRowIndex,
							intIndex));
					}
					
					switch (intNumColumns)
					{
						case 2:
							intInputSize = 70;
							break;
						case 3:
							intInputSize = 50;
							break;
						case 4:
							intInputSize = 30;
							break;
						case 5:
							intInputSize = 20;
							break;
						default:
							intInputSize = 25;
					}
							
					myInput.SetSize(intInputSize);
				}
				else
				{
					strItem = (String) _saData.GetItem(_nRowIndex, intIndex);

					if (null == strItem)
					{
						myCell.AddInnerHTMLString("");
					}
					else
					{
						// HTMLEncode all other values.
						myCell.AddInnerHTMLEncodedString(strItem);
					}
				}

				result.AddInnerHTMLElement(myCell);

				// Edit or Browse icon
				myCell = new HTMLTableCell();
				result.AddInnerHTMLElement(myCell);
				myCell.SetHeight("20");
				myCell.SetNoWrap(true);

				if (bEditMode && intEditCol == i)
				{
					myType = PTButtonType.BROWSE;
				}
				else
				{
					myType = PTButtonType.EDIT;
				}

				construct     = null;
				myAnchor	  = null;

				try
				{
					//	Get the construct, do update the strings.
					construct = UIConstructFactory.GetConstruct(myType, true,
							this.m_asOwner);
					construct.ReplaceNestedElementsWithHTMLString(myType.TITLE_ELEMENT_NAME,
						"");
					myAnchor = (HTMLAnchor) construct.GetNestedElement(myType.ANCHOR_ELEMENT_NAME);

					//Implement the on click action to edit the field
					myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);

					if (bEditMode && intEditCol == i)
					{
						myAnchor.SetOnClick(JAVASCRIPT_SETEDITROWCOL +
							"('-1', '-1'); return false;");

						ConstructFactory.SetAltOnButtonImages( construct,m_asOwner.GetString(201,
						"ptmsgs_portalinfrastructure") );
						ConstructFactory.SetTitleOnButtonImages( construct,m_asOwner.GetString(201,
						"ptmsgs_portalinfrastructure") );
				
				
					}
					else
					{
						myAnchor.SetOnClick(JAVASCRIPT_SETEDITROWCOL +
							"('" + _nRowIndex + "','" + i + "'); return false;");

						ConstructFactory.SetAltOnButtonImages( construct,m_asOwner.GetString(200,
						"ptmsgs_portalinfrastructure") );
						ConstructFactory.SetTitleOnButtonImages( construct,m_asOwner.GetString(200,
						"ptmsgs_portalinfrastructure") );						
					}
				}
				catch (Exception e)
				{
					PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::GetHTMLForRow", e, false, UIErrorLevel.SERIOUS, 
						m_asOwner.GetString(199, "ptmsgs_portalinfrastructure"));
				}

				myCell.AddInnerHTMLElement(construct.GetHTMLElement());
			}
		}

		if (((IPTMultiColumnListModelRO) m_model).GetEnableMoveRowActions())
		{
			result.AddInnerHTMLElement(super.GetHTMLForMoveRowActions(
					_nRowIndex));
		}

		return result;
	}

	/**
	 * Returns the HTML for the Section.  Overrides
	 * PTMultiColumnListView since we need a hidden input
	 * for which column is being edited.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLInput myInput;

		try
		{
			result.AddInnerHTMLElement(super.Display());
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_EDITCOL, HTMLHIDDEN_EDITCOL);
			myInput.SetValue(XPConvert.ToString(((GlobalACLSyncMapListModel)m_model).GetEditColumn()));
			result.AddInnerHTMLElement(myInput);
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "PTMultiColumnListView::Display", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(52, "ptmsgs_infrastructure"));
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 * Overrides PTMultiColumnListView since we need to set the index of the column
	 * being edited.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();

		try
		{
			// Set the edit field function
			XPStringBuilder sb = new XPStringBuilder(200);
			sb.Append("function " + JAVASCRIPT_SETEDITROWCOL + "(strEditRow, strEditColumn)\n");
			sb.Append("{\n");
			sb.Append("    document." + AFormDP.HTMLFORM_NAME + ".elements['" +
				HTMLHIDDEN_EDITCOL + "'].value = strEditColumn;\n");
			sb.Append("    " + JAVASCRIPT_SETEDITROW + "(strEditRow);");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_UI_Infrastructure"), "GlobalACLSyncMapListView::DisplayJavascript", he, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(101, "ptmsgs_infrastructure"));
		}

		return myScript;
	}
}


