package com.plumtree.portalpages.admin.serversettings.globalaclsyncmap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class keeps an up-to-date state of all the settings.
 *
 * It contains the set and get methods for those settings.
 *
 * It contains the start, save and finish methods.
 *
 * This class is used by the Section class (to get the latest value of the settings
 * to display) and by the Repost Control class (to perform the repost actions).
 *
 * @author JohnH
 * @author JenniferSu
 */
public class GlobalACLSyncMapModel extends EditorModel
	implements IGlobalACLSyncMapModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.globalaclsyncmap.GlobalACLSyncMapModel");

	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "GlobalACLSyncMapModel";

	//Constants
	/** Number of columns in the multicolumn list */
	public static final int MAPLIST_NUMCOLUMNS		 = 1;

	/** The position of the plumtree object in the multicolumn list */
	public static final int MAPLIST_PTOBJECTPOSITION = 0; //Zero-based list position for the PT object column 

	/** Server object: Plumtree Session */
	private IPTSession m_Session;

	//Member variables
	private Object[][] m_arrDomainMapInfo; //This is a 2 dim array 0,0=auth source name, 1,0=mapped domain names
	private Object[][] m_arrGroupMapInfo; //This is a 2 dim array 0,0=group name, 1,0=mapped external group

	public GlobalACLSyncMapModel()
	{
		super();
	}

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		if (!m_Session.GetSessionInfo().CheckForActivityRight(
						PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}
		
		if (!m_Session.GetSessionInfo().CheckCurrentUserIsAdmin()) return false;
		
		StartDomainMapList();
		StartGroupMapList();
		StartMigrationHistory();

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GlobalACLSyncMapModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		//m_arrDomainMapInfo
		//This is a 2 dim array 0,0=auth source Prefix, 1,0=mapped string
		try
		{
			if ((null != m_arrDomainMapInfo) && 
				(null != m_arrDomainMapInfo[0]))
			{
				IPTACLSyncMap mySyncMap = (IPTACLSyncMap) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
						false);

				//First, delete the existing entries in the map
				mySyncMap.ClearMappings(PT_ACLSYNC_MAPPINGTYPES.PT_ACLSYNCMAPPING_DOMAIN);

				for (int i = 0; i < m_arrDomainMapInfo[0].length; i++)
				{
					String strPrefix = XPConvert.ToString(m_arrDomainMapInfo[0][i]);
					// special case for Plumtree intrinsic auth source
					if (strPrefix.equals("Plumtree"))
					{
						strPrefix = "";
					}
					Object[] arrFields =null;
					String domain = (String) m_arrDomainMapInfo[1][i];
					if(!(domain==null || domain.trim().length()==0 || domain.startsWith(CommonHTMLStrings.SPACE)))
						arrFields = ParseFields(domain);

					if (null != arrFields)
					{
						for (int j = 0; j < arrFields.length; j++)
						{
							String strNewDomain = (String) arrFields[j];
							IPTQueryResult qr = mySyncMap.QueryMappingsForItem(PT_ACLSYNC_ITEMTYPES.PT_ACLSYNCITEM_AUTHSOURCECATEGORY, strPrefix);
							boolean bExists = false;
							for (int k = 0; k < qr.RowCount(); k++)
							{
								String strCompare = qr.ItemAsString(k, PT_PROPIDS.PT_PROPID_ACLSYNC_FROMSTRING);
								if (strCompare.equals(strNewDomain))
								{
									bExists = true;
								}
							}
							if (!bExists)
							{
								mySyncMap.AddMapping(PT_ACLSYNC_MAPPINGTYPES.PT_ACLSYNCMAPPING_DOMAIN,
									strNewDomain, strPrefix);
							}
						}
					}
				}
			}

			// Set the migration status to approved if the checkbox was checked
			((IMigrationHistoryModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).StoreMigrationStatus(PT_CLASSIDS.PT_GLOBALOBJECT_ID, PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP);
		}
		catch (Exception e)
		{
			log.Error(e, "GlobalACLSyncMapModel::Finish Unable to set the ACL sync map domain information.");

			throw new XPException(m_asOwner.GetString(1487,
				"ptmsgs_portaladminmsgs"), e);
		}

		//m_arrGroupMapInfo
		//This is a 2 dim array 0,0=group ID, 1,0=mapped external group name
		try
		{
			if ((null != m_arrGroupMapInfo) && (null != m_arrGroupMapInfo[0]))
			{
				IPTACLSyncMap mySyncMap = (IPTACLSyncMap) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
						false);

				//First, delete the existing entries in the map
				mySyncMap.ClearMappings(PT_ACLSYNC_MAPPINGTYPES.PT_ACLSYNCMAPPING_GROUP);

				for (int i = 0; i < m_arrGroupMapInfo[0].length; i++)
				{
					String strPTGroup = XPConvert.ToString(m_arrGroupMapInfo[0][i]);
					Object[] arrFields=null;						
					String group = (String) m_arrGroupMapInfo[1][i];
					if(!(group==null || group.trim().length()==0 || group.startsWith(CommonHTMLStrings.SPACE)))
						arrFields = ParseFields(group);
					
					if (null != arrFields)
					{
						for (int j = 0; j < arrFields.length; j++)
						{
							String strExternalGroup = (String) arrFields[j];

							//Add the mapping
							mySyncMap.AddMapping(PT_ACLSYNC_MAPPINGTYPES.PT_ACLSYNCMAPPING_GROUP,
								strExternalGroup, strPTGroup);

							log.Debug("GlobalACLSyncMapModel::Finish Adding group map from \'" + strPTGroup + 
								"\' (internal) to \'" + strExternalGroup + "\' (external).");
						}
					}
				}
			}
		}
		catch (Exception e)
		{
			log.Error(e, "GlobalACLSyncMapModel::Finish Unable to set the ACL sync map group information.");

			throw new XPException(m_asOwner.GetString(1497, "ptmsgs_portaladminmsgs"), e);
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	// END ***************** helper methods *****************

	/**
	 * Inits the Model with the IPTSession.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);

		// JF- Get the Session object from the associated AS.
		m_Session = (IPTSession) parent.GetUserSession();
	}

	// BEGIN ***************** helper methods *****************

	/**
	 * Parses the string of mapped fields and returns a two dimensional array
	 * in the format expected by the Plumtree server
	 *
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnStartEditor(XPHashtable)
	 */
	public Object[] ParseFields(String strMappedFields)
	{
		Object[] myArray			  = null;
		int intTokenIndex			  = 0;
		XPStringTokenizer myTokenizer = new XPStringTokenizer(strMappedFields, ",");
		myArray						  = new Object[myTokenizer.GetTokenCount()];

		for (XPStringTokenizer i = myTokenizer; i.HasMoreTokens();)
		{
			String strToken = XPStringUtility.Trim(i.GetNextToken());
			myArray[intTokenIndex] = strToken;
			intTokenIndex++;
		}

		return myArray;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = GlobalACLSyncMapRepostControl.PAGE_STATUS_VALID;

		// Save the pages
		if (_sPageName.equals(MainDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = SaveMainPage(_htFormData);
		}

		if (_sPageName.equals(GroupMapDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus = SaveGroupPage(_htFormData);
		}

		if (_sPageName.equals(MigrationHistoryPluginDP.STR_MVC_CLASS_NAME))
		{
			nPageStatus		= ((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).SaveSection(_htFormData);
		}
			
		return nPageStatus;
	}

	/**
	 * This method initializes the expandable list used as the basis for
	 * the domain ACL Sync map
	 */
	public void StartDomainMapList()
	{
		GlobalACLSyncMapListModel myListModel = (GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN);
		myListModel.SetMapType(GlobalACLSyncMapListModel.ACL_MAP_TYPE_DOMAIN);

		myListModel.SetNumColumns(MAPLIST_NUMCOLUMNS);
		myListModel.SetIncludePTSelect(true);
		myListModel.SetPTObjectPosition(MAPLIST_PTOBJECTPOSITION);

		String[] arrMapSubTitles = new String[MAPLIST_NUMCOLUMNS];

		//Domain Name
		arrMapSubTitles[0] = m_asOwner.GetString(1482, "ptmsgs_portaladminmsgs");
		
		myListModel.InitializePTMultiColumnList(m_asOwner.GetString(1480, "ptmsgs_portaladminmsgs"),	
			m_asOwner.GetString(1481, "ptmsgs_portaladminmsgs"), 
			arrMapSubTitles,
			PTImageType.ICON_AUTH_SOURCE,	
			m_asOwner.GetString(2689, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_AUTHSOURCE_ID }, 
			1);

		// Use the method below to set the value to populate a newly created input text.
		// (By default it will be a null array, so it MUST be initialized.
		//Login form page
		String[] arrMapDefaults = new String[MAPLIST_NUMCOLUMNS];

		arrMapDefaults[0] = "";		
		myListModel.SetDefaultValue(arrMapDefaults);
		myListModel.SetTreeSubTitle(m_asOwner.GetString(2144, "ptmsgs_portaladminmsgs"));
		myListModel.SetTreeTitle(m_asOwner.GetString(2145, "ptmsgs_portaladminmsgs"));
		myListModel.SetTreeMultiSelect(true);

		//Set the message and instructions to display when the list is empty.
		myListModel.SetEmptyListMessages(m_asOwner.GetString(1484, "ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(1485, "ptmsgs_portaladminmsgs"));

		//Get the name value pairs from the model in edit mode,
		//and populate them in here
		try
		{
			// Get all the auth source prefixes that are mapped
			IPTACLSyncMap ptSyncMap = (IPTACLSyncMap) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
					false);
			ASQueryResultWrapper ptqrCategories = new ASQueryResultWrapper(ptSyncMap.QueryMappedItems(
						PT_ACLSYNC_ITEMTYPES.PT_ACLSYNCITEM_AUTHSOURCECATEGORY));
			XPArrayList xpList = ASQueryResultWrapper.ConvertToArrayList(ptqrCategories, PT_PROPIDS.PT_PROPID_ACLSYNC_TOSTRING);

			// Populate the expandable list
			Object[][] oRows     = new Object[xpList.GetSize()][MAPLIST_NUMCOLUMNS + 4];
			for (int i = 0; i < xpList.GetSize(); i++)
			{
				XPArrayList lstDomains			 = new XPArrayList();
				String strCategory = (String) xpList.GetElement(i);
				ASQueryResultWrapper ptqrDomains = new ASQueryResultWrapper(ptSyncMap.QueryMappingsForItem(
							PT_ACLSYNC_ITEMTYPES.PT_ACLSYNCITEM_AUTHSOURCECATEGORY,
							strCategory));

				for (int j = 0; j < ptqrDomains.GetCount(); j++)
				{
					lstDomains.Add(ptqrDomains.GetFields(j,
							PT_PROPIDS.PT_PROPID_ACLSYNC_FROMSTRING));
				}

				// Set the class ID
				oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_CLASSID + MAPLIST_PTOBJECTPOSITION]
					= new Integer(PT_CLASSIDS.PT_AUTHSOURCE_ID);

				// Set the Object ID.  Bogus value since we don't care about the actual object.
				oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_OBJECTID +	MAPLIST_PTOBJECTPOSITION]
					= new Integer(-12345);

				if (null != strCategory && strCategory.equals("_PT_"))
				{
					// Set the Object name
					oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_STRING + MAPLIST_PTOBJECTPOSITION] 
						= "Plumtree";
				}
				else
				{
					// Set the Object name
					oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_STRING + MAPLIST_PTOBJECTPOSITION] 
						= strCategory;
				}

				// Set the elements
				XPStringBuilder sbMappedItems = new XPStringBuilder(100);
				for (int j = 0; j < lstDomains.GetSize(); j++)
				{
					sbMappedItems.Append(lstDomains.GetElement(j));

					if (j < (lstDomains.GetSize() - 1))
					{
						sbMappedItems.Append(",");
					}
				}

				if (1 == MAPLIST_PTOBJECTPOSITION)
				{
					oRows[i][1] = sbMappedItems.ToString();
				}
				else
				{
					oRows[i][4] = sbMappedItems.ToString();
				}
			}

			myListModel.SetDefaultObjects(oRows);

		}
		catch (Exception e)
		{
			log.Error(e, "GlobalACLSyncMapModel::StartDomainMapList	An error occurred when trying populate the ACL Sync map select list.");

			throw new XPException(m_asOwner.GetString(1489, "ptmsgs_portaladminmsgs"), e);
		}
	}

	/**
	 * This method initializes the expandable list used as the basis for
	 * the group ACL Sync map
	 */
	public void StartGroupMapList()
	{
		GlobalACLSyncMapListModel myListModel = (GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_GROUP_PLUG_IN);
		myListModel.SetMapType(GlobalACLSyncMapListModel.ACL_MAP_TYPE_GROUP);
		
		myListModel.SetNumColumns(MAPLIST_NUMCOLUMNS);
		myListModel.SetIncludePTSelect(true);
		myListModel.SetPTObjectPosition(MAPLIST_PTOBJECTPOSITION);

		String[] arrMapSubTitles = new String[MAPLIST_NUMCOLUMNS];
		//External Group Name
		arrMapSubTitles[0] = m_asOwner.GetString(2691, "ptmsgs_portaladminmsgs");

		myListModel.InitializePTMultiColumnList(m_asOwner.GetString(1490, "ptmsgs_portaladminmsgs"),		
			m_asOwner.GetString(2690, "ptmsgs_portaladminmsgs"), 
			arrMapSubTitles,
			PTImageType.ICON_GROUP,
			m_asOwner.GetString(2689, "ptmsgs_portaladminmsgs"),
			new int[] { PT_CLASSIDS.PT_USERGROUP_ID }, 
			2);

		// Use the method below to set the value to populate a newly created input text.
		// (By default it will be a null array, so it MUST be initialized.
		String[] arrMapDefaults = new String[MAPLIST_NUMCOLUMNS];
		arrMapDefaults[0] = "";
		myListModel.SetDefaultValue(arrMapDefaults);
		myListModel.SetTreeMultiSelect(true);
		myListModel.SetTreeSubTitle(m_asOwner.GetString(2146, "ptmsgs_portaladminmsgs"));
		myListModel.SetTreeTitle(m_asOwner.GetString(2147, "ptmsgs_portaladminmsgs"));
		
		//Set the message and instructions to display when the list is empty.
		myListModel.SetEmptyListMessages(m_asOwner.GetString(1494,
				"ptmsgs_portaladminmsgs"),
			m_asOwner.GetString(1495, "ptmsgs_portaladminmsgs"));

		//Get the name value pairs from the model in edit mode,
		//and populate them in here
		try
		{
			// Get all the group mappings from the ACL Sync Map
			IPTACLSyncMap ptSyncMap = (IPTACLSyncMap) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP,
					false);
			ASQueryResultWrapper ptqrGroups = new ASQueryResultWrapper(ptSyncMap.QueryMappedItems(
						PT_ACLSYNC_ITEMTYPES.PT_ACLSYNCITEM_USERGROUP));
			XPArrayList xpList =
			ASQueryResultWrapper.ConvertToArrayList(ptqrGroups, PT_PROPIDS.PT_PROPID_ACLSYNC_TOSTRING);

			Object[][] oRows     = new Object[xpList.GetSize()][MAPLIST_NUMCOLUMNS + 4];

			for (int i = 0; i < xpList.GetSize(); i++)
			{
				XPArrayList lstExternalGroups     = new XPArrayList();
				String strPTGroup				  = (String) xpList.GetElement(i);
				ASQueryResultWrapper ptqrPTGroups = new ASQueryResultWrapper(ptSyncMap.QueryMappingsForItem(
							PT_ACLSYNC_ITEMTYPES.PT_ACLSYNCITEM_USERGROUP,
							strPTGroup));

				for (int j = 0; j < ptqrPTGroups.GetCount(); j++)
				{
					lstExternalGroups.Add(ptqrPTGroups.GetFields(j,
							PT_PROPIDS.PT_PROPID_ACLSYNC_FROMSTRING));
				}

				// Set the class ID
				oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_CLASSID + 
				MAPLIST_PTOBJECTPOSITION] = new Integer(PT_CLASSIDS.PT_USERGROUP_ID);

				// Set the Object ID.  Bogus ID since we don't really care about the object
				oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_OBJECTID +
				MAPLIST_PTOBJECTPOSITION] = new Integer(-12345);

				// Set the Object name
				oRows[i][GlobalACLSyncMapListModel.EXPLIST_COL_STRING +
				MAPLIST_PTOBJECTPOSITION] = strPTGroup;

				// Set the elements
				XPStringBuilder sbMappedItems = new XPStringBuilder(100);
				for (int j = 0; j < lstExternalGroups.GetSize(); j++)
				{
					sbMappedItems.Append(lstExternalGroups.GetElement(j));

					if (j < (lstExternalGroups.GetSize() - 1))
					{
						sbMappedItems.Append(",");
					}
				}

				if (1 == MAPLIST_PTOBJECTPOSITION)
				{
					oRows[i][1] = sbMappedItems.ToString();
				}
				else
				{
					oRows[i][4] = sbMappedItems.ToString();
				}
			}

			// Then add the array to the list
			myListModel.SetDefaultObjects(oRows);
		}
		catch (Exception e)
		{
			log.Error(e, "GlobalACLSyncMapModel::StartGroupMapList	An error occurred when trying populate the ACL Sync map group list.");

			throw new XPException(m_asOwner.GetString(1498,
				"ptmsgs_portaladminmsgs"), e);
		}
	}

	/**
	 * Helper method to start the migration history page.
	 */
	public void StartMigrationHistory()
	{
		((MigrationHistoryPluginModel) m_asOwner.GetModel(MigrationHistoryPluginModel.STR_MVC_CLASS_NAME)).InitializeHistory(PT_CLASSIDS.PT_GLOBALOBJECT_ID,
			PT_GLOBALOBJECTS.PT_GLOBAL_ACLSYNCMAP);
	}

	/**
	 * Saves the data on the group page.
	 *
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	private int SaveGroupPage(XPHashtable _htFormData)
	{
		try
		{
			//First, save the existing section to the activity space
			((GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_GROUP_PLUG_IN)).SaveSection(_htFormData);

			//Now retrieve the non Plumtree select elements
			Object[][] arrMappingInfo = ((GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_GROUP_PLUG_IN)).GetListValues();

			//m_arrDomainMapInfo
			PTGrowableSortedArrayWrapper arrItems;
			arrItems = ((GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_GROUP_PLUG_IN)).GetItems();

			int intNumItems = arrItems.GetCount();
			m_arrGroupMapInfo = new Object[2][intNumItems];

			if (intNumItems > 0)
			{
				for (int i = 0; i < intNumItems; i++)
				{
					m_arrGroupMapInfo[0][i]     = arrItems.GetItem(i,
							GlobalACLSyncMapListModel.EXPLIST_COL_STRING +
							MAPLIST_PTOBJECTPOSITION);
					String group=(String) arrMappingInfo[0][i];
					m_arrGroupMapInfo[1][i] = group;
				}
			}
		}
		catch (Exception e)
		{
			log.Error(e, "GlobalACLSyncMapModel::SaveGroupPage " +
				m_asOwner.GetString(1496, "ptmsgs_portaladminmsgs"));

			throw new XPException(m_asOwner.GetString(1496,
					"ptmsgs_portaladminmsgs"), e);
		}

		return GlobalACLSyncMapRepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Saves the data on the main page.
	 *
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	private int SaveMainPage(XPHashtable _htFormData)
	{
		try
		{
			//First, save the existing section to the activity space
			((GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN)).SaveSection(_htFormData);

			//Now retrieve the non Plumtree select elements
			Object[][] arrMappingInfo = ((GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN)).GetListValues();

			//m_arrDomainMapInfo
			PTGrowableSortedArrayWrapper arrItems;
			arrItems = ((GlobalACLSyncMapListModel) m_asOwner.GetModel(GlobalACLSyncMapAS.STR_MVC_STORAGE_NAME_DOMAIN_PLUG_IN)).GetItems();

			int intNumItems = arrItems.GetCount();
			m_arrDomainMapInfo = new Object[2][intNumItems];

			if (intNumItems > 0)
			{
				for (int i = 0; i < intNumItems; i++)
				{
					m_arrDomainMapInfo[0][i]     = arrItems.GetItem(i,
							GlobalACLSyncMapListModel.EXPLIST_COL_STRING +
							MAPLIST_PTOBJECTPOSITION);
					String domain=(String) arrMappingInfo[0][i];
					m_arrDomainMapInfo[1][i] = domain;
				}
			}
		}
		catch (Exception e)
		{
			log.Error(e, "GlobalACLSyncMapModel::SaveMainPage " +
				m_asOwner.GetString(1486, "ptmsgs_portaladminmsgs"));

			throw new XPException(m_asOwner.GetString(1486, "ptmsgs_portaladminmsgs"), e);
		}

		return GlobalACLSyncMapRepostControl.PAGE_STATUS_VALID;
	}

	// END ***************** repost action methods *****************
}