package com.plumtree.portalpages.admin.serversettings.objectpropertymap;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Activity space for object properties map
 *
 * @author josephc
 */
public class ObjPropMapEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.objectpropertymap.ObjPropMapEditorAS");

	/** Class name for ObjPropMapEditorAS */
	public static final String STR_MVC_CLASS_NAME = "ObjPropMapEditor";

	/** Plugin for object properties map  */
	public static final String strStorageObjPropMapPlugin = "StorageObjPropMapPlugin";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjPropMapEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return GetString(542, "ptmsgs_portaladminmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Document Type Map Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (ObjPropMapRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = ObjPropMapModel.STR_MVC_CLASS_NAME;

		// Warning: m_myModel must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(ObjPropMapModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new ObjPropMapDP());

		// Register Controls
		RegisterControl(ObjPropMapRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register Plugin
		RegisterModel(ObjPropMapPluginModel.STR_MVC_CLASS_NAME, strStorageObjPropMapPlugin);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myObjPropPluginModel = GetModel(strStorageObjPropMapPlugin);
		RegisterView(ObjPropMapPluginView.STR_MVC_CLASS_NAME, strStorageObjPropMapPlugin, myObjPropPluginModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strStorageObjPropMapPlugin, myObjPropPluginModel);

		// Set default page
		SetCurrentPage(ObjPropMapDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(321, "ptmsgs_portaladminmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, ObjPropMapDP.STR_MVC_CLASS_NAME);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				int iTitleId = 87;
				int iTipId = 88;
				int iSecondaryTipId = 89;

				tm.SetTipTitle(this.GetString(iTitleId, "ptmsgs_tips"));

				HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId, "ptmsgs_tips"));

				tm.SetTip(e);

				String sSecondary = this.GetString(iSecondaryTipId, "ptmsgs_tips");

				if (!("none_do_not_translate".equals(sSecondary)))
				{
					e = new HTMLGenericElement(sSecondary);

					tm.SetSecondarTip(e);
				}
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}

		//	Got the tips model
	}

	/**
	 * Set the help page for this editor. 
	 *
	 * @param page 
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);
		
		String sPageName = page.GetName();
		
		if (ObjPropMapDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_GlobalObjectPropertyMap_ObjectPropertyMap");
		}
	}
}

