package com.plumtree.portalpages.admin.serversettings.objectpropertymap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * Model for object properties map
 *
 * @author josephc
 */
public class ObjPropMapModel extends EditorModel implements IObjPropMapModelRO
{
	/** Class name for ObjPropMapModel */
	public static final String STR_MVC_CLASS_NAME = "ObjPropMap";

	/** IPTSession */
	protected IPTSession m_ptSession;

	/**
	 * Modifies the object name on repost.
	 */
	public void ActionOnRepost()
	{
		// Code to perform on repost.
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#CheckEditorAccessAndStart(XPHashtable)
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		if (!m_ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(429, "ptmsgs_portalinfrastructure"), null);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());
		
			return false;
		}
			
		if (!m_ptSession.GetSessionInfo().CheckCurrentUserIsAdmin())
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(431, "ptmsgs_portalinfrastructure"), null);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			return false;
		}

		// Init common pages
		StartObjPropMap();

		// Perform Editor specific tasks
		DoTaskOnStartEditor(_htFormData);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjPropMapModel();
	}

	/**
	 * This method contains the code to store the object property mappings.
	 */
	public void Finish()
	{
		ObjPropMapPluginModel opModel = (ObjPropMapPluginModel) m_asOwner.GetModel(ObjPropMapEditorAS.strStorageObjPropMapPlugin);
		opModel.StorePropertyMappings();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the Model with the Activity Space.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner     = parent;

		// JF- Get the Session object from the associated AS.
		m_ptSession = (IPTSession) parent.GetUserSession();
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(ObjPropMapDP.STR_MVC_CLASS_NAME))
		{
			SaveMainPage(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
		// Code to save the page.
	}

	/**
	 * Initialize object properties map
	 */
	protected void StartObjPropMap()
	{
		ObjPropMapPluginModel opModel = (ObjPropMapPluginModel) m_asOwner.GetModel(ObjPropMapEditorAS.strStorageObjPropMapPlugin);

		opModel.InitializeObjectPropertiesMap(m_ptSession, m_asOwner.GetString(548, "ptmsgs_portaladminmsgs"), 1);
	}
}

