package com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List for object properties map.
 *
 * @author josephc
 */
public class ObjPropMapPluginView extends ExpListView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.objectpropertymap.plugin.ObjPropMapPluginView");

	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "ObjPropMapPlugin";

	/** JavaScript function to open property tree. */
	private static final String JAVASCRIPT_PROPERTYTREE_OPEN = "propertyTreeOpen";

	/** JavaScript function to get property tree value. */
	private static final String JAVASCRIPT_PROPERTYTREE_GETVALUE = "propertyTreeGetValue";

	/** List row height */
	private static final String LIST_ROW_HEIGHT = "30";
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjPropMapPluginView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		IObjPropMapPluginModelRO iOPModel = (IObjPropMapPluginModelRO) m_model;

		// The URL to open a pick tree as a subspace.  We want to use the same pick tree each time.
		ASURL asURLPropertyTree = GetPropertyTreeURL();

		HTMLScript result  = super.DisplayJavascript();
		XPStringBuilder sb;

		try
		{
			// Open property tree
			sb = new XPStringBuilder(200);
			sb.Append("function ")
			.Append(iOPModel.GetUniqueString(JAVASCRIPT_PROPERTYTREE_OPEN))
			.Append("(varRowIndex, varSelectedItems)\n");
			sb.Append("{\n");
			sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".")
			.Append(iOPModel.GetUniqueString(HTMLHIDDEN_ROWINDEX)).Append(".value = varRowIndex;\n");
			sb.Append("  window.open('").Append(asURLPropertyTree.GetURLAsString());
			sb.Append("&").Append(StartTreeControl.SELECTED_ITEMS).Append("=' + varSelectedItems");
			sb.Append(
				", 'PropertyTreeWindow', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());

			// On return from property tree
			sb = new XPStringBuilder(200);
			sb.Append("function ")
			.Append(iOPModel.GetUniqueString(JAVASCRIPT_PROPERTYTREE_GETVALUE))
			.Append("()\n");
			sb.Append("{\n");
			sb.Append("  postToSelf('")
			.Append(iOPModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_ADD))
			.Append("');\n");
			sb.Append("}\n");
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element: " +
					he.getMessage());
			
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#GetHTMLForRow(IPTGrowableSortedArrayWrapperRO, int)
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Get cell containing class icon
		result.AddInnerHTMLElement(GetHTMLForIcon(_saData, _nRowIndex));

		// Get cell containing class name
		result.AddInnerHTMLElement(GetHTMLForName(_saData, _nRowIndex));

		// Get cell containing mapped properties
		result.AddInnerHTMLElement(GetHTMLForMappedProperties(_nRowIndex));

		// Get cell containing edit button
		result.AddInnerHTMLElement(GetHTMLForEdit(_nRowIndex));

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Return cell that contains anchor for editing mappings.
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return HTMLTableCell
	 *
	 * @throws Exception
	 */
	protected HTMLTableCell GetHTMLForEdit(int _nRowIndex)

	{
		IObjPropMapPluginModelRO iOPModel = (IObjPropMapPluginModelRO) m_model;

		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetHeight(LIST_ROW_HEIGHT);
		myCell.SetNoWrap(true);

		XPStringBuilder sb = new XPStringBuilder(100);

		sb.Append(iOPModel.GetUniqueString(JAVASCRIPT_PROPERTYTREE_OPEN));
		sb.Append("(").Append(_nRowIndex).Append(", '");
		sb.Append(iOPModel.GetSelectedItems(_nRowIndex));
		sb.Append("'); return false;");

		HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		myAnchor.SetOnClick(sb.ToString());

		HTMLImg myEditImage = GetImageForEditIcon();

		myAnchor.AddInnerHTMLElement(myEditImage);

		myCell.AddInnerHTMLElement(myAnchor);

		return myCell;
	}

	/**
	 * Returns cell for mapped properties
	 *
	 * @param _nRowIndex Row index
	 *
	 * @return HTMLTableCell
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForMappedProperties(int _nRowIndex)

	{
		IObjPropMapPluginModelRO iOPModel = (IObjPropMapPluginModelRO) m_model;

		HTMLTableCell myCell;
		myCell = new HTMLTableCell();
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetWidth("75%");
		myCell.SetHeight(LIST_ROW_HEIGHT);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		HTMLElementCollection result = new HTMLElementCollection();

		String[][] arPropertyInfo = iOPModel.GetPropertyInfo(_nRowIndex);

		for (int i = 0; i < arPropertyInfo.length; i++)
		{
			if (0 != i)
			{
				result.AddInnerHTMLString(", ");
			}

			result.AddInnerHTMLString(XPHttpUtility.HtmlEncode(arPropertyInfo[i][ObjPropMapPluginModel.PROPERTY_INFO_NAME]));
		}

		myCell.AddInnerHTMLElement(result);

		return myCell;
	}

	/**
	 * Returns cell for icon
	 *
	 * @param _saData Data
	 * @param _nRowIndex Row index
	 *
	 * @return HTMLTableCell
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForIcon(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		IObjPropMapPluginModelRO iOPModel = (IObjPropMapPluginModelRO) m_model;

		HTMLTableCell myCell;
		HTMLImg myClassIcon;
	
		myCell = new HTMLTableCell();
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetHeight(LIST_ROW_HEIGHT);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		myClassIcon = iOPModel.GetClassIcon(_nRowIndex);
		myCell.AddInnerHTMLElement(myClassIcon);

		return myCell;
	}

	/**
	 * Returns cell for name
	 *
	 * @param _saData Data
	 * @param _nRowIndex Row index
	 *
	 * @return HTMLTableCell
	 *
	 * @throws HTMLException
	 */
	protected HTMLTableCell GetHTMLForName(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		HTMLTableCell myCell;
		
		myCell = new HTMLTableCell();
		myCell.SetVAlign(CommonHTMLStrings.TOP);
		myCell.SetWidth("25%");
		myCell.SetHeight(LIST_ROW_HEIGHT);
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		// Get current row's name and propertyID
		String strName = (String) _saData.GetItem(_nRowIndex, ObjPropMapPluginModel.EXPLIST_COL_CLASS_NAME);

		myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strName));

		return myCell;
	}

	/**
	 * Returns image for edit icon
	 *
	 * @return Image for edit icon
	 *
	 * @throws Exception
	 */
	protected HTMLImg GetImageForEditIcon()

	{
		HTMLImg myImage;
		PTConstruct myConstruct;

		myConstruct     = UIConstructFactory.GetConstruct(PTImageType.ACTION_EDIT, true,
				this.m_asOwner);
		myImage		    = (HTMLImg) myConstruct.GetHTMLElement();

		myImage.SetAlt(m_asOwner.GetString(537, "ptmsgs_portaladminmsgs"));
		myImage.SetWidth("25");
		myImage.SetHeight("25");
		myImage.SetBorder(CommonHTMLStrings.ZERO);
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);

		return myImage;
	}

	/**
	 * Returns URL for property tree
	 *
	 * @return URL for property tree
	 */
	private ASURL GetPropertyTreeURL()
	{
		IObjPropMapPluginModelRO iOPModel = (IObjPropMapPluginModelRO) m_model;

		// The URL to open a new tree to select multi-valued properties
		ASURL asURLPropertyTree = new ASURL(m_asOwner);

		asURLPropertyTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);

		asURLPropertyTree.SetSubSpaceKey(iOPModel.GetUniqueString(
				ObjPropMapPluginModel.SUBSPACE_KEY_PROPERTYTREE));
		asURLPropertyTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		asURLPropertyTree.AddControlArgument(StartTreeControl.ROOT_ID,
			XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
		asURLPropertyTree.AddControlArgument(StartTreeControl.MULTI_SELECT,
			XPConvert.ToString(true));
		asURLPropertyTree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(TreeConstants.N_LEAFSELECT));
		asURLPropertyTree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		asURLPropertyTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		asURLPropertyTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			iOPModel.GetUniqueString(JAVASCRIPT_PROPERTYTREE_GETVALUE));
		asURLPropertyTree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
			XPConvert.ToString(PT_CLASSIDS.PT_PROPERTY_ID));

		asURLPropertyTree.AddControlArgument(StartTreeControl.TITLE,
			m_asOwner.GetString(538, "ptmsgs_portaladminmsgs"));

		asURLPropertyTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
			m_asOwner.GetString(539, "ptmsgs_portaladminmsgs"));
			
		asURLPropertyTree.AddControlArgument(AStartTreeControl.ALLOW_EMPTY_SUBMISSION,
			XPConvert.ToString(true));
					
		return asURLPropertyTree;
	}
}

