package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author MatthewF
 */
public class BannerFieldAliasView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.search.BannerFieldAliasView");

	
	public static final String STR_MVC_CLASS_NAME = "BannerFieldAliasView";

	public static final String DEL_ALL_CB = "in_cb_uber";
	
	public static final String IN_CB_NAME = "in_cb_row_";
	
	public static final String IN_SE_NAME = "in_se_typeSelector_";
	
	public static final String IN_WEIGHT_INPUT = "in_tx_weightInput_";
	
	public static final String IN_PERCENT_INPUT = "in_tx_percentInput_";
	
	public static final String IN_HI_NUM_FIELDS = "in_hi_numFields";

	private SearchServerTuningEditorModel _model;

	PropertyValue[] _props = null;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new BannerFieldAliasView();
	}

	/**
	 * Returns Java Script for editBB function.
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script;

		try
		{
			_model = (SearchServerTuningEditorModel) m_model;

			char cLocalDecimalSeperator = _model.GetLocalizedDecimalSeperator();
			XPStringBuilder sb = new XPStringBuilder(400);
			script = new HTMLScript("text/javaScript");
			
			sb.Append("\n\nfunction DoToggleAllCBs() {\n");
			sb.Append("    var fElem = document.mainform;\n");
			sb.Append("    var feLen = fElem.elements.length;\n");
			sb.Append("    var checkVal = false;\n");
			sb.Append("    for (var i = 0; i < feLen; i++) {\n");
			sb.Append("        if (fElem.elements[i].name == '" + DEL_ALL_CB + "') {\n");
			sb.Append("            checkVal = fElem.elements[i].checked;\n");
			sb.Append("        }\n");
			sb.Append("    }\n");
			sb.Append("    for (var i = 0; i < feLen; i++) {\n");
			sb.Append("        if (fElem.elements[i].name.indexOf('" + IN_CB_NAME + "') != -1) {\n");
			sb.Append("             fElem.elements[i].checked = checkVal;\n");
			sb.Append("        }\n");
			sb.Append("    }\n");
			sb.Append("    return true;\n"); 
			sb.Append("}\n"); 
			sb.Append("\n\nfunction maxCreated() {\n");
			sb.Append("    alert('" + m_asOwner.GetString(143,"ptmsgs_portalcommonmsgs") + "');\n");
			sb.Append("}\n"); 
			
			sb.Append("\n\nfunction IntsOnly(inputName) {\n");
			sb.Append("   UpdatePercentages();\n");
			sb.Append("	  return false;\n");
			sb.Append("}\n");
			
			sb.Append("\n\nvar percents = null;\n");
			
			sb.Append("\n\nvar weights = null;\n");
			
			sb.Append("\n\nfunction UpdatePercentages() {\n");
			sb.Append("  if(percents == null || weights == null) {\n");
			sb.Append("    percents = new Array();\n");
			sb.Append("    weights = new Array();\n");
			sb.Append("    var aSpanPercents = document.getElementsByTagName('span');\n");
			sb.Append("    var fSpansLen = aSpanPercents.length;\n");
			sb.Append("    for (var i = 0; i < fSpansLen; i++) {\n");
			sb.Append("        if (aSpanPercents[i].id != null &&  aSpanPercents[i].id.indexOf('" + IN_PERCENT_INPUT + "') != -1) {\n");
			sb.Append("            percents.push(aSpanPercents[i]);\n");
			sb.Append("        }\n");
			sb.Append("    }\n");

			sb.Append("    var aInputWeights = document.getElementsByTagName('input');\n");
			sb.Append("    var fInpLen = aInputWeights.length;\n");
			sb.Append("    for (var j = 0; j < fInpLen; j++) {\n");
			sb.Append("        if (aInputWeights[j].name != null &&  aInputWeights[j].name.indexOf('" + IN_WEIGHT_INPUT + "') != -1) {\n");
			sb.Append("            weights.push(aInputWeights[j]);\n");
			sb.Append("        }\n");
			sb.Append("    }\n");

			sb.Append("  }\n");
			sb.Append("  var total = 0.0;\n");
			sb.Append("  for (var i = 0; i < weights.length; i++) {\n");
			sb.Append("      try {\n");	
			sb.Append("        total += parseFloat(weights[i].value.replace('" + cLocalDecimalSeperator + "','.'));\n");
			sb.Append("      } catch(b) {\n");
			sb.Append("      }\n");
			sb.Append("  }\n");	
			sb.Append("  for (var i = 0; i < percents.length; i++) {\n");
			sb.Append("      try {\n");	
			sb.Append("        var pct = ((parseFloat(weights[i].value.replace('" + cLocalDecimalSeperator + "','.')) / total) * 100.0 + 0.005) + '';\n");
			sb.Append("        pct = pct.replace('.','" + cLocalDecimalSeperator + "');\n");
			sb.Append("        if(pct.indexOf('" + cLocalDecimalSeperator + "') != -1);\n");
			sb.Append("            pct = pct.substring(0,pct.indexOf('" + cLocalDecimalSeperator + "') + 3);\n");
			sb.Append("        percents[i].innerHTML = Pad(pct) + '';\n");
			sb.Append("      } catch(b) {\n");
			sb.Append("        percents[i].innerHTML = Pad('0');\n");
			sb.Append("      }\n");
			sb.Append("  }\n");					
			sb.Append("}\n");
			sb.Append("\n\nfunction Pad(val) {\n");
			sb.Append("      var retval = '';\n");
			sb.Append("      var backPad = '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';\n");
			sb.Append("      for(var i = val.length; i <= 12; i++)\n");
			sb.Append("      	retval += '&nbsp;'; \n");
			sb.Append("      retval += val;\n");
			sb.Append("      return retval + backPad;\n");
			sb.Append("}\n");
			script.AddInnerHTMLString(sb.ToString());

		}
		catch (Exception e)
		{
			
				log.Error(e, "BannerFieldAliasView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					e.getMessage());
			

			throw XPException.GetInstance(e);
		}

		return script;
	}

	/**
	 * 
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
	public static class PropertyValue
	{
		int objID;
		int typeID;
		String name;
	}
	
	protected void CreateAliasTable(HTMLElement container)
	{
		_model = (SearchServerTuningEditorModel) m_model;
		SearchServerTuningEditorModel.AliasElement[] els = (SearchServerTuningEditorModel.AliasElement[])_model.GetCurrentAliasElements();
		
		HTMLTableRow row;
		HTMLTableCell cell;

		if(els.length == 0)
		{
			return;
		}
		HTMLInput numEls = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, IN_HI_NUM_FIELDS, "", "");
		numEls.SetValue(XPConvert.ToString(els.length));
		
		for(int i = 0; i < els.length; i++)
		{
		    // Make sure that decimals are all localized.
		    els[i].weightVal = _model.LocalizeFloat(els[i].weightVal);
		    els[i].percentage = _model.LocalizeFloat(els[i].percentage);
		    
			row = new HTMLTableRow();
			if ((i % 2) == 0)
			{
				row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			}
			else
			{
				row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
			}

			container.AddInnerHTMLElement(row);
			cell = new HTMLTableCell();
			
			if(i == 0)
				cell.AddInnerHTMLElement(numEls);
				
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			cell.SetWidth("25");
			cell.SetAlign("center");
			cell.SetVAlign("middle");
			row.AddInnerHTMLElement(cell);
			cell.AddInnerHTMLElement(GetCheckbox(els[i], i)); 
			
			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			cell.SetWidth("20");
			cell.SetAlign("left");
			cell.SetVAlign("middle");
			cell.SetNoWrap(true);
			row.AddInnerHTMLElement(cell);
			cell.AddInnerHTMLElement(GetSelect(els[i], i));

			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			cell.SetWidth("30");
			cell.SetAlign("right");
			cell.SetVAlign("middle");
			row.AddInnerHTMLElement(cell);
			cell.AddInnerHTMLElement(GetPercentageLabel(els[i], i));
				
			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			cell.SetWidth("20");
			cell.SetAlign("left");
			cell.SetVAlign("middle");
			row.AddInnerHTMLElement(cell);
		    cell.AddInnerHTMLElement(GetWeightInput(els[i], i));
		    

		}
	}
	

	public String LookUpNameForPropertyID(int id)
	{
		for(int i = 0; i < _props.length; i++)
		{
			if(_props[i].objID == id)
				return _props[i].name;
		}
		return "Unknown";
	}
	/**
	 * 
	 *
	 * @return 
	 */
	public PropertyValue[] GetPropertiesVisibleToCurrentUser()
	{
		if(_props != null)
			return _props; 
		IASQueryResult _propertyList = null;
		if (null == _propertyList)
		{
			int nFields = PT_PROPIDS.PT_PROPID_OBJECTID |
				PT_PROPIDS.PT_PROPID_NAME |
				PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;

			PTObjectManagerQueryWrapper PropMgr = new PTObjectManagerQueryWrapper(((IPTSession)m_asOwner.GetUserSession()).GetProperties());

			Object[][] ptqf = new Object[3][3];
			ptqf[0][0]     = new Integer(PT_PROPIDS.PT_PROPID_PROP_SEARCHABLE);
			ptqf[1][0]     = new Integer(PT_FILTEROPS.PT_FILTEROP_GT);
			ptqf[2][0]     = new Integer(0);
			ptqf[0][1]     = new Integer(PT_PROPIDS.PT_PROPID_ACCESSLEVEL);
			ptqf[1][1]     = new Integer(PT_FILTEROPS.PT_FILTEROP_GTE);
			ptqf[2][1]     = new Integer(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
			ptqf[0][2]     = new Integer(PT_PROPIDS.PT_PROPID_PROP_VALUETYPE);
			ptqf[1][2]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			ptqf[2][2]     = new Integer(PT_PROPERTY_TYPES.PT_PROPTYPE_STRING);

			PropMgr.Query(nFields, -1, null, ptqf);
			_propertyList = (IASQueryResult) PropMgr;
		}
		int count = _propertyList.GetCount();
		PropertyValue[] retval = new PropertyValue[count];
		for (int i = 0; i < count; i++)
		{
			// Hide the OBJECTIMAGEUUID (property 7) from the user
			PropertyValue v = new PropertyValue();
			int ObjID = XPConvert.ToInteger(_propertyList.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
			v.objID = ObjID;
			if (7 != ObjID) {
		  		String name = XPConvert.ToString(_propertyList.GetFields(i, PT_PROPIDS.PT_PROPID_NAME));
				int type = XPConvert.ToInteger(_propertyList.GetFields(i, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
				v.name = name;
				v.typeID = type;				
			}
			else
			{
				v.objID = -1;
				v.name = null;
				v.typeID = -1;
			}
			retval[i] = v;
		}

		_props = retval;
		return _props;
	}
	
	protected HTMLElement GetSelect(SearchServerTuningEditorModel.AliasElement element, int number)
	{
		HTMLSelect select = new HTMLSelect(IN_SE_NAME + number, IN_SE_NAME + number);
		select.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
		for(int i = 0; i < _props.length; i++)
		{
			if(_props[i].objID == -1)
				continue;
			if(IsIDMandatory(_props[i].objID))
				continue;
			HTMLOption opt = new HTMLOption(XPConvert.ToString(_props[i].objID));
			opt.AddInnerHTMLString(XPHttpUtility.HtmlEncode(_props[i].name));
			if(_props[i].objID == element.propID)
				opt.SetSelected(true);
			opt.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
			select.AddInnerHTMLElement(opt);			
		}
		return select;
	}
	
	protected HTMLElement GetMandatoryLabel(SearchServerTuningEditorModel.AliasElement element, int number)
	{
		HTMLSpan span = new HTMLSpan();
		
		span.SetStyleClass(PTStyleClass.FORM_TEXTBOX_TEXT);
		for(int i = 0; i < _props.length; i++)
		{
			if(_props[i].objID == element.propID)
			{
				span.AddInnerHTMLString("<nobr>" + XPHttpUtility.HtmlEncode(_props[i].name) + "</nobr>");
				return span;
			}
		}
		span.AddInnerHTMLString("Unknown Property");
		return span;
	}
	
	protected HTMLElement GetWeightInput(SearchServerTuningEditorModel.AliasElement element, int number)
	{
		HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT_TYPE, IN_WEIGHT_INPUT + number, "", "");
		input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		input.SetValue(element.weightVal);
		input.SetSize(6);
		input.SetMaxLength(6);
		input.SetAlign("right");
		input.SetOnKeyUp("IntsOnly('" + IN_WEIGHT_INPUT + number + "');");
		return input;
	}
	
	protected HTMLElement GetPercentageLabel(SearchServerTuningEditorModel.AliasElement element, int number)
	{
		HTMLSpan span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		span.SetID(IN_PERCENT_INPUT + number);
		span.AddInnerHTMLString(PadToEight(element.percentage));
		return span;
	}
	
	protected String PadToEight(String val)
	{
		String retval = "";
		String backPad = "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
		for(int i = val.length(); i <= 12; i++)
			retval += "&nbsp;";
		retval += val;
		return retval + backPad;
	}
	
	protected HTMLElement GetCheckbox(SearchServerTuningEditorModel.AliasElement element, int number)
	{
		HTMLInput input = new HTMLInput(HTMLInputTypes.CHECKBOX_TYPE, IN_CB_NAME, "", "");
		input.SetValue(XPConvert.ToString(number));
		input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		input.SetDisabled(IsIDMandatory(element.propID));
		return input;
	}
	
	protected boolean IsIDMandatory(int propertyID)
	{
          /*
		return (PT_INTRINSICS.PT_PROPERTY_OBJECTNAME == propertyID ||
				PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY == propertyID ||
				PT_INTRINSICS.PT_PROPERTY_TEXTCONTENT == propertyID);
          */
		// Bug 31410: don't enforce mandatory banner fields
		return false;
	}
	
	public HTMLElement Display()
	{
		try
		{
			_model = (SearchServerTuningEditorModel) m_model;
			GetPropertiesVisibleToCurrentUser();

			HTMLElementCollection result = new HTMLElementCollection();

			HTMLTable table = new HTMLTable();
			table.SetWidth("100%");
			table.SetBorder("0");
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			result.AddInnerHTMLElement(table);
			  
			HTMLTableRow row = new HTMLTableRow();
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
			table.AddInnerHTMLElement(row);
			  
			HTMLTableCell cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("100%");
			cell.SetHeight("20");
			cell.SetVAlign("middle");
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			HTMLSpan span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			span.AddInnerHTMLString(m_asOwner.GetString(2571, "ptmsgs_portaladminmsgs"));
			cell.AddInnerHTMLElement(span);
 

			table = new HTMLTable();
			table.SetWidth("100%");
			table.SetBorder("0");
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			result.AddInnerHTMLElement(table);
			              
			row = new HTMLTableRow();
			row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
			table.AddInnerHTMLElement(row);
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("25");
			cell.SetVAlign("middle");
			cell.SetAlign("absmiddle");

			cell.SetNoWrap(true);
			cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
			 
			HTMLImg newImg = SearchUIUtility.GetImage(m_asOwner,PTImageType.ACTION_NEW,"Add Field","6","25");
			newImg.SetAlign("absmiddle");
			HTMLImg docImg = SearchUIUtility.GetImage(m_asOwner,PTImageType.ICON_DOCUMENT,"","15","20");
			docImg.SetAlign("absmiddle");
			HTMLImg docImg2 = SearchUIUtility.GetImage(m_asOwner,PTImageType.ICON_DOCUMENT,"","15","20");
			docImg2.SetAlign("absmiddle");
			HTMLImg delImg = SearchUIUtility.GetImage(m_asOwner,PTImageType.ACTION_DELETE,m_asOwner.GetString(2450, ResourceConstants.PORTALADMINMSGS),"25","25");
			delImg.SetAlign("absmiddle");
			HTMLImg sp1Img = SearchUIUtility.GetImage(m_asOwner,PTImageType.SPACER,"","1","1");
			HTMLImg sp2Img = SearchUIUtility.GetImage(m_asOwner,PTImageType.SPACER,"","1","1");

			HTMLAnchor a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

			a.SetOnClick("postToSelf(" + SearchServerTuningEditorRepostControl.POSTTOSELF_ACTION_ADD_FIELD + "); return false;");

			cell.AddInnerHTMLElement(a);
			a.AddInnerHTMLString("&nbsp;");
			a.AddInnerHTMLElement(newImg);
			a.AddInnerHTMLElement(docImg);
			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
			span.AddInnerHTMLString(m_asOwner.GetString(2564, "ptmsgs_portaladminmsgs"));
			a.AddInnerHTMLElement(span);
			a.AddInnerHTMLString("&nbsp;&nbsp;");
					
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("25");
			cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
			cell.AddInnerHTMLElement(sp1Img);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("25");
			cell.SetNoWrap(true);
			cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
			
			a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			a.SetOnClick("postToSelf(" + SearchServerTuningEditorRepostControl.POSTTOSELF_ACTION_DEL_FIELD + "); return false;");

			cell.AddInnerHTMLElement(a);
			a.AddInnerHTMLElement(delImg);
			
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("25");
			cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
			cell.AddInnerHTMLElement(sp2Img);
			
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
			cell.SetHeight("25");
			cell.SetWidth("100%");
			cell.SetAlign("right");
			
			a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			a.SetOnClick("postToSelf(" + SearchServerTuningEditorRepostControl.POSTTOSELF_ACTION_FIELD_DEFAULTS + "); return false;");
			cell.AddInnerHTMLElement(a);
			a.AddInnerHTMLElement(docImg2);
			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
			span.AddInnerHTMLString(m_asOwner.GetString(2563, "ptmsgs_portaladminmsgs"));
			a.AddInnerHTMLElement(span);
			//a.AddInnerHTMLString("&nbsp;&nbsp;");

			HTMLElement spacer = SearchUIUtility.makeSpacer(m_asOwner, "5");
			result.AddInnerHTMLElement(spacer);
			
			// Now create the real table
			table = new HTMLTable();
			result.AddInnerHTMLElement(table);
			table.SetBorder("0");
			table.SetCellSpacing("2");
			table.SetCellPadding("2");
			table.SetWidth("100%");

			// Table header
			row = new HTMLTableRow();
			row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
			table.AddInnerHTMLElement(row);

			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			cell.SetWidth("25");
			cell.SetAlign("center");
			cell.SetVAlign("middle");
			HTMLInput cb = new HTMLInput(HTMLInputTypes.CHECKBOX,DEL_ALL_CB,DEL_ALL_CB,"");
			cb.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			cb.SetOnClick("DoToggleAllCBs();");
			cell.AddInnerHTMLElement(cb);
			row.AddInnerHTMLElement(cell);

			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			cell.SetHeight("25");
			//cell.SetWidth("30%");
			cell.AddInnerHTMLString(m_asOwner.GetString(2572, "ptmsgs_portaladminmsgs"));

			row.AddInnerHTMLElement(cell);
			
			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			cell.SetHeight("25");
			cell.AddInnerHTMLString("<nobr>" + m_asOwner.GetString(2580, "ptmsgs_portaladminmsgs") + "</nobr>");
			row.AddInnerHTMLElement(cell);
		
			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			cell.SetHeight("25");
			cell.SetWidth("100%");
			cell.AddInnerHTMLString(m_asOwner.GetString(2573, "ptmsgs_portaladminmsgs"));
			row.AddInnerHTMLElement(cell);

			CreateAliasTable(table);

			return result;
		}
		catch (Exception e)
		{
			
				log.Error("Exception in BannerFieldAliasView.Display: " + e.getMessage());
			

			throw XPException.GetInstance(e);
		}
	}

}

