package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
/**
 * Allow selection of additional class ids for display in IndexingStatusView.
 *
 * @author MatthewF
 */
public class IndexingStatusPopUpView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.search.IndexingStatusPopUpView");


	public static final String STR_MVC_CLASS_NAME = "IndexingStatusPopUp";

	// HTML Object names.
	public static final String HTMLBUTTON_OK = "in_bu_ok";
	public static final String HTMLBUTTON_CANCEL = "in_bu_cancel";
	public static final String SELECT_NAME  = "in_se_AddCategorySelect";
	public static final String EMPTY = "";
	public static final String CHECKBOX_ADD_ALL = "in_cb_addAllUnused";

	private static final String PORTAL_ADMIN_MSGS = ResourceConstants.PORTALADMINMSGS;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IndexingStatusPopUpView();
	}

	/**
	 * Display html for the search status info.
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;

		try
		{

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding(CommonHTMLStrings.FIVE);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);

			SearchServerSettingsEditorModel m = (SearchServerSettingsEditorModel)GetModel();
			/*<tr class="objectHeaderBg" >
			  <td valign="center" colspan="2" ><span class="objectHeader" >Search Server */
			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myCell.SetColSpan(CommonHTMLStrings.TWO);
			myRow.AddInnerHTMLElement(myCell);
			HTMLSpan span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			span.AddInnerHTMLString(m_asOwner.GetString(2521, PORTAL_ADMIN_MSGS));
			myCell.AddInnerHTMLElement(span);

			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.OBJECT_SUBHEAD);
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myCell.AddInnerHTMLString(m_asOwner.GetString(2522, PORTAL_ADMIN_MSGS));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			HTMLSelect select = new HTMLSelect(SELECT_NAME, EMPTY);
			select.SetStyleClass(PTStyleClass.FORM_SELECT_TEXT);
			myCell.AddInnerHTMLElement(select);
			XPArrayList unused = m.GetUndisplayedNamesAndTypes();
			IXPEnumerator xpEnumerator = unused.GetEnumerator();
			while(xpEnumerator.MoveNext())
			{
				SearchServerSettingsEditorModel.IndexingCount ic = (SearchServerSettingsEditorModel.IndexingCount)xpEnumerator.GetCurrent();
				HTMLOption option = new HTMLOption(ic.GetClassName());
				option.AddInnerHTMLString(ic.GetClassName());
				option.SetValue(XPConvert.ToString(ic.GetClassId()));
				select.AddInnerHTMLElement(option);
			}
			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.OBJECT_SUBHEAD);
			myRow.AddInnerHTMLElement(myCell);
			myCell.AddInnerHTMLString(m_asOwner.GetString(2523, PORTAL_ADMIN_MSGS));
			myCell.SetAlign(CommonHTMLStrings.RIGHT);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,CHECKBOX_ADD_ALL, EMPTY, EMPTY);
			myCell.AddInnerHTMLElement(myInput);

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetHeight("20");
			myCell.AddInnerHTMLString(" ");
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.BUTTON,HTMLBUTTON_OK,EMPTY,EMPTY);
			//myInput.AddInnerHTMLString(HTMLBUTTON_OK);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myInput.SetValue(m_asOwner.GetString(2524, PORTAL_ADMIN_MSGS));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("DoPostToSelf(" +
				SearchServerSettingsEditorRepostControl.POSTTOSELF_ACTION_IS_ADD_TYPE +
				"); return false;");
			myCell.AddInnerHTMLElement(myInput);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myInput = new HTMLInput(HTMLInputTypes.BUTTON,HTMLBUTTON_CANCEL,EMPTY,EMPTY);
			//myInput.AddInnerHTMLString(HTMLBUTTON_CANCEL);
			myCell.SetAlign(CommonHTMLStrings.LEFT);
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetValue(m_asOwner.GetString(2525, PORTAL_ADMIN_MSGS));
			myInput.SetOnClick("window.close(); return false; ");

			myCell.AddInnerHTMLElement(myInput);

		}
		catch (Exception e)
		{
			//e.printStackTrace();
			
				log.Error(e, "SearchServerSettingsPopUpView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			


			throw new XPException(m_asOwner.GetString(174,
					ResourceConstants.PORTALCOMMONMSGS), e);
		}

		return result;
	}
	 // Display()

	/**
	 *
	 *
	 * @return
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 *
	 * @return
	 */
	protected ISearchServerSettingsEditorModelRO GetModel()
	{
		return (ISearchServerSettingsEditorModelRO) m_model;
	}
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;
			// Open Pop Up function
		sb = new XPStringBuilder(200);
		sb.Append("function DoPostToSelf(code)\n");
		sb.Append("{\n");
		//sb.Append("   postToSelf(code);");
		sb.Append("   if(window.opener != null && window.opener.mainform != null) {\n");
		sb.Append("       window.opener.mainform.in_hi_PostToSelf.value= code;\n");
		sb.Append("       if(window.mainform." + CHECKBOX_ADD_ALL + ".checked) window.opener.mainform." + CHECKBOX_ADD_ALL + ".value = 'true';\n");
		sb.Append("       window.opener.mainform." + SELECT_NAME + ".value = window.mainform." + SELECT_NAME + ".value;\n");
		sb.Append("       window.opener.mainform.submit();\n");
		sb.Append("       window.close();\n");
		sb.Append("   }\n");
		sb.Append("}\n");
		sb.Append("function CheckBoxValue()\n");
		sb.Append("{\n");
		sb.Append("       if(window.mainform." + CHECKBOX_ADD_ALL + ".checked) \n");
		sb.Append("            window.opener.mainform." + CHECKBOX_ADD_ALL + ".value = 'true';\n");
		sb.Append("       else\n");
		sb.Append("            window.opener.mainform." + CHECKBOX_ADD_ALL + ".value = 'false';\n");
		sb.Append("}\n");

		myScript.AddInnerHTMLString(sb.ToString());
		return myScript;
	}
}

