package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.PT_RESULTCODES;
import com.plumtree.server.PortalObjectsFactory;
import com.plumtree.server.marshalers.PTException;

/**
 * Helper class which yanks information out of the PropertyBag
 * returned by a search server status request.
 */
public class SearchClusterStatusInfo
{
	
    /* Individual-server-related values */
    
	public String connectStatus = "ERROR";
    public String pbagString ;
	public boolean isValid = false;


    
    /* Cluster-related values */
    
    public String clusterHome;
    public String clusterDocsetTID;
    public String lastSubittedTID;
    public String clusterSearchState;    
    public String clusterIndexState;
    public String clusterLexiconTID;
    public String numberOfNodes;
    public String numberOfPartitions;
    public String mbFree;
    public String mbUsed;
    public String[] errors;
    public NodeInfo[] nodes;


	/**
     * @param lastSubittedTID The lastSubittedTID to set.
     */
    public void setLastSubittedTID(String lastSubittedTID) {
        this.lastSubittedTID = lastSubittedTID;
    }



    /**
     * @return Returns the clusterIndexState.
     */
    public String getClusterIndexState() {
        return this.clusterIndexState;
    }



    /**
     * @return Returns the clusterSearchState.
     */
    public String getClusterSearchState() {
        return this.clusterSearchState;
    }



    /**
     * @return Returns the errors.
     */
    public String[] getErrors() {
        return this.errors;
    }




    /**
     * @return Returns the mbFree(in Megs).
     */
    public String getFreeMem() {
        return this.mbFree;
    }



    /**
     * @return Returns the mbUsed(in Megs).
     */
    public String getUsedMem() {
        return this.mbUsed;
    }



    /**
     * @return Returns the nodes.
     */
    public NodeInfo[] getNodes() {
        return this.nodes;
    }



    /**
     * @return Returns the clusterDocsetTID.
     */
    public String getClusterDocsetTID() {
        return this.clusterDocsetTID;
    }



    /**
     * @return Returns the clusterHome.
     */
    public String getClusterHome() {
        return this.clusterHome;
    }



    /**
     * @return Returns the clusterLexiconTID.
     */
    public String getClusterLexiconTID() {
        return this.clusterLexiconTID;
    }



    /**
     * @return Returns the clusterSearchState.
     */
    public String getClusterState() {
        return this.clusterSearchState;
    }



    /**
     * @return Returns the connectStatus.
     */
    public String getConnectStatus() {
        return this.connectStatus;
    }



    /**
     * @return Returns the isValid.
     */
    public boolean valid() {
        return this.isValid;
    }



    /**
     * @return Returns the mbUsed.
     */
    public String getKbUsed() {
        return this.mbUsed;
    }



    /**
     * @return Returns the lastSubittedTID.
     */
    public String getLastSubittedTID() {
        return this.lastSubittedTID;
    }



    /**
     * @return Returns the numberOfNodes.
     */
    public String getNumberOfNodes() {
        return this.numberOfNodes;
    }



    /**
     * @return Returns the numberOfPartitions.
     */
    public String getNumberOfPartitions() {
        return this.numberOfPartitions;
    }



    /**
     * @return Returns the pbagString.
     */
    public String getPbagString() {
        return this.pbagString;
    }



    /**
	 * Construct a SearchServerStatusInfo from a named subbag of a search
	 * status propertybag. <p>
	 * When all is well, connectStatus == "OK".
	 * When there is no search server running, connectStatus contains
	 * "Error: (0x80044301) Unable to connect to search server: Winsock error code 10061"
	 * @param pBag PropertyBag result of SearchRequest.RetrieveStatus()
	 */
	public SearchClusterStatusInfo(IXPPropertyBag pBag)
	{
		IXPPropertyBag subBag = pBag.ReadAsIXPPropertyBag("CLUSTERSTATUS");

		if (subBag == null)
		{
			isValid = false;

			return;
		}

		isValid			  = true;
		connectStatus     = subBag.ReadAsString("CONNECTSTATUS");
        if(!connectStatus.equalsIgnoreCase("OK")){
            throw new PTException(connectStatus, PT_RESULTCODES.PT_E_SEARCH_FAIL);
        }
        clusterHome = subBag.ReadAsString("CLUSTER_HOME");
        clusterDocsetTID = subBag.ReadAsString("CLUSTER_DOCSET_TID_STRING");
//        lastSubittedTID = subBag.ReadAsString("LAST_TRANSACTION_ID");
        clusterSearchState = subBag.ReadAsString("CLUSTER_SEARCH_STATE_STRING");
        clusterIndexState = subBag.ReadAsString("CLUSTER_INDEX_STATE_STRING");
        clusterLexiconTID = subBag.ReadAsString("CLUSTER_LEXICON_TID_STRING");
        numberOfNodes = subBag.ReadAsString("NUMBER_OF_NODES");
        numberOfPartitions = subBag.ReadAsString("NUMBER_OF_PARTITIONS");
        mbFree = subBag.ReadAsString("MB_FREE");
        mbUsed = subBag.ReadAsString("MB_USED");
        
        Object[] errorsObj = subBag.ReadAsObject1DArray("ERRORS");
        errors = new String[errorsObj.length];
        for(int count = 0; count < errorsObj.length ; count++){
            errors[count] = (String)errorsObj[count];
        }

        Object[] nodeBags = subBag.ReadAsObject1DArray("NODES");
        nodes = new NodeInfo[nodeBags.length];
        for(int count = 0; count < nodeBags.length ; count++){
            nodes[count] = new NodeInfo((IXPPropertyBag)nodeBags[count]);
        }

	}
}
 // class SearchServerStatusInfo

