package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author OlegS
 */
public class SearchServerSettingsEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.search.SearchServerSettingsEditorAS");

	
	public static final String STR_MVC_CLASS_NAME = "SearchServerSettingsEditor";
	private static final String sClassName = "com.plumtree.portalpages.admin.serversettings.search.SearchServerSettingsEditorAS";
		// True if we've checked for the indexing status file config option.
	private static boolean _isInitialized = false;
		// Tagname to put in ptconfig.xml to turn indexing status on.
	private static String SPECIAL_VAL_NAME = "IndexingStatus";
		// True if we are showing indexing status page
	private static boolean _showIndexingStatus = false;
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SearchServerSettingsEditorAS();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{

		return (GetString(152, "ptmsgs_portalcommonmsgs"));
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	public String GetRepostControlName()
	{
		return (SearchServerSettingsEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		boolean bInAdminGroup = PlumtreeHelpers.CheckCurrentUserIsAdmin
			((IPTSession) GetUserSession());

		if (!bInAdminGroup)
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * 
	 */
	public void Init()
	{
		if(! _isInitialized)
			loadConfig();
		m_strModelName = SearchServerSettingsEditorModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(m_strModelName);

		RegisterPage(new SearchServerSettingsEditorDP());
		RegisterPage(new SearchServerSettingsPopUpDP());

		RegisterView(SearchServerSettingsEditorView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SearchServerSettingsPopUpView.STR_MVC_CLASS_NAME, myModel);

		RegisterControl(SearchServerSettingsEditorRepostControl.STR_MVC_CLASS_NAME,
			myModel);
		SetCurrentPage(SearchServerSettingsEditorDP.STR_MVC_CLASS_NAME);

		// Set left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(153,
					"ptmsgs_portalcommonmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			SearchServerSettingsEditorDP.STR_MVC_CLASS_NAME);

		if(_showIndexingStatus)
		{			
			RegisterPage(new IndexingStatusDP());
			RegisterPage(new IndexingStatusPopUpDP());
			RegisterView(IndexingStatusView.STR_MVC_CLASS_NAME, myModel);
			RegisterView(IndexingStatusPopUpView.STR_MVC_CLASS_NAME, myModel);

			m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
				IndexingStatusDP.STR_MVC_CLASS_NAME);
		}
		
		// END Sub menu "General Settings"
		

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				
				
				int iTitleId = 132;
				int iTipId = 133;
				int iSecondaryTipId = 134;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}

								

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
		 
		 		
	}

  /**
   * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
   *
   * @param IDisplayPage the current Display Page
   */
  public void SetCurrentPage(IDisplayPage page) {

    super.SetCurrentPage( page );

    String sPageName = page.GetName();

    if (SearchServerSettingsEditorDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SearchServerManager_MainSettings" );                           
    } else if (IndexingStatusDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SearchServerManager_IndexingStatus" );
    } else if (SearchServerSettingsPopUpDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      this.SetHelpTopic( "PT_SearchServerStatus" );
    }
  }

  private static void loadConfig()
  {
	_isInitialized = true;

	try
	{
	  IApplication application = ApplicationManager.GetInstance()
		.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());

	  PTConfigVarPack vpPTConfig = (PTConfigVarPack) application.GetVarPackManager()
		.GetVariablePackage(PTConfigVarPack.VARPACK_ID);  

	  try {

		  String categoryName=
		  vpPTConfig.GetConfigValueAsString("Search",
							SPECIAL_VAL_NAME,
							"value"); 
		  if (categoryName != null && ! categoryName.trim().equals("")) {
			  _showIndexingStatus = true;
		  }
	  }
	  catch (Exception e)
			  {
				
					log.Error(e, "Trouble parsing Indexing Status flag.");
					
			  }

	}
	catch (Exception e)
	{
	
		  log.Error(e, "Trouble parsing Indexing Status info: " +
			 e.getMessage());
		
	}
  }

}

