package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Section class to display search server status in a popup window. Typically
 * there is one search server used as the "query host" and "index host",
 * and the view will show uptime and other information from that server,
 * or an error message if we fail to connect.<p>
 * Less typically, there will be separate servers configured for query,
 * index, and failover host, and this view shows status info for each
 * server in that case.
 *
 * @author OlegS
 */
public class SearchServerSettingsPopUpView extends EditorView
{
    private static final String SEARCH_MSG_BUNDLE = "ptmsgs_searchAdminUI";
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.searchcluster.SearchServerSettingsPopUpView");

	
	public static final String STR_MVC_CLASS_NAME = "SearchServerSettingsPopUp";

	// HTML Object names.

	
	public static final String HTMLBUTTON_CLOSE = "in_bu_close";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SearchServerSettingsPopUpView();
	}

	/**
	 * Display html for the search status info.
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display SearchServerSettingsPopUpView");
			result.AddInnerHTMLElement(myComment);
			
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			//DisplayEmptyRow(result,myTable);

			ISearchServerSettingsEditorModelRO m = GetModel();

			AddSearchServerStatusHTML(result, myTable, m, m_asOwner);

			// Close button
			//DisplayEmptyRow(result,myTable);
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.CENTER);
			myCell.SetColSpan("2");
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
			myCell.AddInnerHTMLElement(myInput);


			myInput.SetValue(m_asOwner.GetString(173, "ptmsgs_portalcommonmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick("window.close();");	// mj: removed 'Javascript:' from function name
			myComment = new HTMLComment( "End: Display SearchServerSettingsPopUpView");
			result.AddInnerHTMLElement(myComment);
		}
		catch (Exception e)
		{
			//e.printStackTrace();
			
				log.Error(e, "SearchServerSettingsPopUpView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			


			throw new XPException(m_asOwner.GetString(174,
					"ptmsgs_portalcommonmsgs"), e);
		}

		return result;
	}
	 // Display()

	public static void AddSearchServerStatusHTML(HTMLElementCollection _result,
		HTMLTable _currentTable, ISearchServerSettingsEditorModelRO _model,
		AActivitySpace _asOwner)
	{
		IXPPropertyBag statusBag = _model.GetStatusPropertyBag();
        SearchServerStatusInfo statusInfo;
        statusInfo = new SearchServerStatusInfo(statusBag, "INDEXSTATUS");
        DisplayStatus(_result, _currentTable, _asOwner.GetString(799, "ptmsgs_portalcommonmsgs"), _model.GetIndexingHost(),
                _model.GetIndexingPort(), statusInfo, _asOwner);
        
        IXPPropertyBag clusterStatusBag = _model.GetClusterStatusPropertyBag();
        SearchClusterStatusInfo clusterStatusInfo;
        clusterStatusInfo = new SearchClusterStatusInfo(clusterStatusBag);
        clusterStatusInfo.setLastSubittedTID(_model.getLastSubmittedSearchTransactioID());
        DisplayClusterStatus(_result, _currentTable,
                             _asOwner.GetString(1, SEARCH_MSG_BUNDLE), 
                              clusterStatusInfo, _asOwner);
        
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	protected ISearchServerSettingsEditorModelRO GetModel()
	{
		return (ISearchServerSettingsEditorModelRO) m_model;
	}

	/**
	 * 
	 *
	 * @param result 
	 * @param myTable 
	 *
	 * @throws HTMLException 
	 */
	protected void DisplayEmptyRow(HTMLElementCollection result, HTMLTable myTable)

	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan("2");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}

	/**
	 * Display a single property bag's worth of status info. This method
	 * is called separately for query, indexing, and failover hosts.
	 */
	protected static void DisplayStatus(HTMLElementCollection result,
		HTMLTable myTable, String title, String host, String port,
		SearchServerStatusInfo statusInfo, AActivitySpace _asOwner)

	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLComment myComment = new HTMLComment( "Begin: DisplayStatus SearchServerSettingsPopUpView");
		result.AddInnerHTMLElement(myComment);

		// will be null for failover host typically
		if ((host == null) || (host.length() == 0))
		{
			return;
		}

		// Will be null for indexing host and failover host typically
		if (statusInfo == null)
		{
			return;
		}

		myComment = new HTMLComment( "pbag = " + statusInfo.pbagString );
		result.AddInnerHTMLElement(myComment);

		// header
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		//myCell.SetHeight("20");
		myCell.SetVAlign("center");
		myCell.SetColSpan("2");
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
		mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(title)); // could be null

		// Initialize the style class
		PTStyleClass styleListItem = flipRowStyle(null);


		DisplayStatusEntry(result, myTable,
			_asOwner.GetString(179, "ptmsgs_portalcommonmsgs"), host, styleListItem);
		// Flip the style class
		styleListItem = flipRowStyle(styleListItem);


		DisplayStatusEntry(result, myTable,
			_asOwner.GetString(180, "ptmsgs_portalcommonmsgs"), port, styleListItem);
		// Flip the style class
		styleListItem = flipRowStyle(styleListItem);

		if (statusInfo.connectStatus.equals("OK"))
		{

			DisplayStatusEntry(result, myTable,
				_asOwner.GetString(182, "ptmsgs_portalcommonmsgs"),
				statusInfo.uptime, styleListItem);
			// Flip the style class
			styleListItem = flipRowStyle(styleListItem);

			DisplayStatusEntry(result, myTable,
				_asOwner.GetString(181, "ptmsgs_portalcommonmsgs"),
				statusInfo.indexDir, styleListItem);
			// Flip the style class
			styleListItem = flipRowStyle(styleListItem);


//			DisplayStatusEntry(result, myTable,
//				_asOwner.GetString(183, "ptmsgs_portalcommonmsgs"),
//				statusInfo.numSearchableItems, styleListItem);
//			// Flip the style class
//			styleListItem = flipRowStyle(styleListItem);
//
//			DisplayStatusEntry(result, myTable,
//				_asOwner.GetString(184, "ptmsgs_portalcommonmsgs"),
//				statusInfo.numDeletedItems, styleListItem);
//			// Flip the style class
//			styleListItem = flipRowStyle(styleListItem);
//
//			// If no snapshot is in progress, display nothing
//			DisplayStatusEntry(result, myTable,
//				_asOwner.GetString(185, "ptmsgs_portalcommonmsgs"),
//				(statusInfo.snapshotActive
//				? _asOwner.GetString(186, "ptmsgs_portalcommonmsgs") : null), styleListItem);
//			// Flip the style class
//			styleListItem = flipRowStyle(styleListItem);

			if (null != statusInfo.errorMessages) {
				int numErrors = statusInfo.errorMessages.length;
				String[] msgsPlusHelp = new String[numErrors + 2];
				for (int j = 0; j < numErrors; j++) {
					msgsPlusHelp[j] = statusInfo.errorMessages[j];
				}
				msgsPlusHelp[numErrors] = "";
				msgsPlusHelp[numErrors+1] = _asOwner.GetString(770, "ptmsgs_portalcommonmsgs");

				DisplayMultiLineStatusEntry(result, myTable,
					_asOwner.GetString(769, "ptmsgs_portalcommonmsgs"),
					msgsPlusHelp, PTStyleClass.ALERT_BG,PTStyleClass.ALERT_ERROR_DESCRIPTION);
				// Flip the style class
				styleListItem = flipRowStyle(styleListItem);
			}
		}
		else
		{
			// Could not connect to the server at this host and port
			// When there is no search server running, the connectStatus
			// string contains
			// Error: (0x80044301) Unable to connect to search server: Winsock error code 10061
			// !!! Need to find out what happens if server is present but hung
			DisplayStatusEntry(result, myTable,
				_asOwner.GetString(187, "ptmsgs_portalcommonmsgs"),
				_asOwner.GetString(188, "ptmsgs_portalcommonmsgs") + " " +
				_asOwner.GetString(189, "ptmsgs_portalcommonmsgs"), styleListItem);
			// Flip the style class
			styleListItem = flipRowStyle(styleListItem);
		}

		//DisplayStatusEntry(result,myTable,"TODO","add more info");
		myComment = new HTMLComment( "End: DisplayStatus SearchServerSettingsPopUpView");
		result.AddInnerHTMLElement(myComment);
	}
	 // DisplayStatus

    /**
     * Display a single property bag's worth of status info. This method is
     * called separately for query, indexing, and failover hosts.
     */
    protected static void DisplayClusterStatus(HTMLElementCollection result,
            HTMLTable myTable, String title,
            SearchClusterStatusInfo statusInfo, AActivitySpace _asOwner) {
        HTMLTableRow myRow;
        HTMLTableCell myCell;
        HTMLSpan mySpan;
        HTMLComment myComment = new HTMLComment(
                "Begin: DisplayStatus SearchServerSettingsPopUpView");
        result.AddInnerHTMLElement(myComment);
        // Will be null for indexing host and failover host typically
        if (statusInfo == null) {
            return;
        }
        myComment = new HTMLComment("pbag = " + statusInfo.pbagString);
        result.AddInnerHTMLElement(myComment);
        // header
        myRow = new HTMLTableRow();
        myTable.AddInnerHTMLElement(myRow);
        myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
        myCell = new HTMLTableCell();
        myRow.AddInnerHTMLElement(myCell);
        // myCell.SetHeight("20");
        myCell.SetVAlign("center");
        myCell.SetColSpan("2");
        mySpan = new HTMLSpan();
        myCell.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
        mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(title)); // could be
        // null
        // Initialize the style class
        PTStyleClass styleListItem = flipRowStyle(null);
        if (statusInfo.connectStatus.equals("OK")) {
            DisplayMultiLineStatusEntry(result, myTable, _asOwner.GetString(18,
                    SEARCH_MSG_BUNDLE), statusInfo.getErrors(),
                    PTStyleClass.ALERT_BG,PTStyleClass.ALERT_ERROR_DESCRIPTION);
            
            DisplayStatusEntry(result, myTable, _asOwner.GetString(2,
                    SEARCH_MSG_BUNDLE), statusInfo.getClusterHome(),
                    styleListItem);
            // Flip the style class
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(3,
                    SEARCH_MSG_BUNDLE), statusInfo.getClusterSearchState(),
                    styleListItem);
            // Flip the style class
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(19,
                    SEARCH_MSG_BUNDLE), statusInfo.getClusterIndexState(),
                    styleListItem);
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(4,
                    SEARCH_MSG_BUNDLE), statusInfo.getNumberOfPartitions(),
                    styleListItem);
            // Flip the style class
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(5,
                    SEARCH_MSG_BUNDLE), statusInfo.getNumberOfNodes(),
                    styleListItem);
            // Flip the style class
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(6,
                    SEARCH_MSG_BUNDLE), statusInfo.getClusterDocsetTID(),
                    styleListItem);
            // Flip the style class
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(7,
                    SEARCH_MSG_BUNDLE), statusInfo.getClusterLexiconTID(),
                    styleListItem);
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(21,
                    SEARCH_MSG_BUNDLE), statusInfo.getLastSubittedTID(),
                    styleListItem);
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(8,
                    SEARCH_MSG_BUNDLE), statusInfo.getFreeMem(),
                    styleListItem);
            styleListItem = flipRowStyle(styleListItem);
            DisplayStatusEntry(result, myTable, _asOwner.GetString(9,
                    SEARCH_MSG_BUNDLE), statusInfo.getUsedMem(),
                    styleListItem);
            

            
           NodeInfo[] nodes = statusInfo.getNodes();
           String[] nodesDesc = new String[nodes.length];

           String partitionLabel =  _asOwner.GetString(13,SEARCH_MSG_BUNDLE);
           String stateLabel =  _asOwner.GetString(15,SEARCH_MSG_BUNDLE);
           //building cluster node desciptions in form 
           //  nodename@(host:port) Partition-partitionnumber, State-"state"
           for(int count = 0; count < nodes.length;count++){
              
               nodesDesc[count] = nodes[count].getName()+"@("+
                          nodes[count].getAddress()+":"+nodes[count].getPort()+") " +
                          partitionLabel + "-" + nodes[count].getPartition()+
                          ", " + stateLabel + "-" + "\"" + nodes[count].getSearchState()+ "\"" ;
               
           }
           DisplayMultiLineStatusEntry(result, myTable, _asOwner.GetString(20,
                   SEARCH_MSG_BUNDLE), nodesDesc,
                   PTStyleClass.OBJECT_SUBHEAD,PTStyleClass.OBJECT_TEXT); 
        } else {
            // Could not connect to the server at this host and port
            // When there is no search server running, the connectStatus
            // string contains
            // Error: (0x80044301) Unable to connect to search server: Winsock
            // error code 10061
            // !!! Need to find out what happens if server is present but hung
            DisplayStatusEntry(result, myTable, _asOwner.GetString(187,
                    "ptmsgs_portalcommonmsgs"), _asOwner.GetString(188,
                    "ptmsgs_portalcommonmsgs")
                    + " " + _asOwner.GetString(189, "ptmsgs_portalcommonmsgs"),
                    styleListItem);
            // Flip the style class
            styleListItem = flipRowStyle(styleListItem);
        }
        // DisplayStatusEntry(result,myTable,"TODO","add more info");
        myComment = new HTMLComment(
                "End: DisplayStatus SearchServerSettingsPopUpView");
        result.AddInnerHTMLElement(myComment);
    }

    // DisplayStatus

	/**
     * 
     * 
     * @param result
     * @param myTable
     * @param name
     * @param value
     * 
     * @throws HTMLException
     */
	protected static void DisplayStatusEntry(HTMLElementCollection result,
		HTMLTable myTable, String name, String value, PTStyleClass _styleListItem)

	{
		if (value == null)
		{
			return;
		}

		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(_styleListItem);
		myCell = new HTMLTableCell();
		myCell.SetNoWrap(true);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBHEAD);
		mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(name));
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(value));
	}

	protected static void DisplayMultiLineStatusEntry(HTMLElementCollection result, HTMLTable myTable,
		String name, String[] values, PTStyleClass _styleListItem, PTStyleClass _styleItemText)

	{
		if ((values == null) || (0 == values.length))
		{
			return;
		}

		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(_styleListItem);
		myCell = new HTMLTableCell();
		myCell.SetNoWrap(true);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBHEAD);
		mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(name));
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(_styleItemText);
		for (int j = 0; j < values.length; j++) {
			myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(values[j]));
			myCell.AddInnerHTMLElement(new HTMLBr());
		}
	}

	/**
	 * 
	 */
	protected static PTStyleClass flipRowStyle(PTStyleClass _styleListItem)
	{
		PTStyleClass result = ((_styleListItem == null) || (_styleListItem == PTStyleClass.LIST_ITEM_ONE_BG)) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG;

		return result;
	}


}

