package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openfoundation.util.*;

/**
 * Helper class which yanks information out of the PropertyBag
 * returned by a search server status request.
 */
public class SearchServerStatusInfo
{
	
	public String connectStatus = "ERROR";

	
	public String currentDir;

	
	public String indexDir;

	
	public String numDeletedItems;

	
	public String numSearchableItems;

	
	public String pbagString; // for debugging

	
	public String uptime;

	
	public boolean isValid = false;

	
	public boolean snapshotActive = false;


	public String[] errorMessages = null;

	/**
	 * Construct a SearchServerStatusInfo from a named subbag of a search
	 * status propertybag. <p>
	 * When all is well, connectStatus == "OK".
	 * When there is no search server running, connectStatus contains
	 * "Error: (0x80044301) Unable to connect to search server: Winsock error code 10061"
	 * @param pBag PropertyBag result of SearchRequest.RetrieveStatus()
	 * @param subBagName Name of subbag to use, can be
	 * "QUERYSTATUS", "INDEXSTATUS", or "FAILOVERSTATUS"
	 */
	public SearchServerStatusInfo(IXPPropertyBag pBag, String subBagName)
	{
		IXPPropertyBag subBag = pBag.ReadAsIXPPropertyBag(subBagName);

		if (subBag == null)
		{
			isValid = false;

			return;
		}

		isValid			  = true;
		connectStatus     = subBag.ReadAsString("CONNECTSTATUS");
		indexDir		  = subBag.ReadAsString("CURRENTDIRECTORY");
		uptime			  = subBag.ReadAsString("UPTIME");

		// Wrapper interfaces cannot convert null property bag entries
		// to primitive int type, so we must check before access
		if (subBag.ReadAsObject("SNAPSHOTACTIVE") != null) {
		    snapshotActive = (1 == subBag.ReadAsInt("SNAPSHOTACTIVE"));
		}

		if (subBag.ReadAsObject("TOTALLIVEDOCS") != null) {
		    numSearchableItems = XPConvert.ToString(subBag.ReadAsInt("TOTALLIVEDOCS"));
		}
		if (subBag.ReadAsObject("TOTALDEADDOCS") != null) {
		    numDeletedItems = XPConvert.ToString(subBag.ReadAsInt("TOTALDEADDOCS"));
		}

		int numErrors = 0;
		if (subBag.ReadAsObject("TOTALERRORS") != null) {
			numErrors = subBag.ReadAsInt("TOTALERRORS");
		}
		if (numErrors > 0) {
			IXPPropertyBag errorMessageBag = subBag.ReadAsIXPPropertyBag("ERRORS");
			if (null != errorMessageBag) {
				errorMessages = new String[numErrors];
				for (int j = 1; j <= numErrors; j++) {
					errorMessages[j-1] = "";
					String oneMessage = errorMessageBag.ReadAsString("MSG_ID_" + j);
					if (null != oneMessage) {
						errorMessages[j-1] = oneMessage;
					}
				}
			}
		}

		pbagString = pBag.SaveToXML(0);
	}
}
 // class SearchServerStatusInfo

