package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author MatthewF
 */
public class SearchServerTuningEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN),
		"com.plumtree.portalpages.admin.serversettings.search.SearchServerTuningEditorAS");

	
	public static final String STR_MVC_CLASS_NAME = "SearchServerTuningEditor";
	
	private static final String sClassName = "com.plumtree.portalpages.admin.serversettings.search.SearchServerTuningEditorAS";
		
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SearchServerTuningEditorAS();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		return (GetString(2574, "ptmsgs_portaladminmsgs"));
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	public String GetRepostControlName()
	{
		return (SearchServerTuningEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		IPTSession ptSession = (IPTSession)GetUserSession();

		boolean hasRight = ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SEARCH_SERVER_TUNING);
		if(!hasRight)
		{
			return false;
		}	

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * 
	 */
	public void Init()
	{
		m_strModelName = SearchServerTuningEditorModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(m_strModelName);

		RegisterPage(new BestBetsListDP());
		RegisterPage(new ThesaurusSettingsDP());
		RegisterPage(new BannerFieldAliasDP());

		RegisterView(BestBetsListView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ThesaurusSettingsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(BannerFieldAliasView.STR_MVC_CLASS_NAME, myModel);
		
		RegisterControl(SearchServerTuningEditorRepostControl.STR_MVC_CLASS_NAME,
			myModel);
		SetCurrentPage(BestBetsListDP.STR_MVC_CLASS_NAME);

		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(153,
					"ptmsgs_portalcommonmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			BestBetsListDP.STR_MVC_CLASS_NAME);

		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			BannerFieldAliasDP.STR_MVC_CLASS_NAME);
			
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			ThesaurusSettingsDP.STR_MVC_CLASS_NAME);

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				
				//TODO: Get help topic and tips for Tuning rather than Manager
				int iTitleId = 135;
				int iTipId = 136;
				int iSecondaryTipId = 137;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
	}

  /**
   * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
   *
   * @param IDisplayPage the current Display Page
   */
  public void SetCurrentPage(IDisplayPage page) {

    super.SetCurrentPage( page );

    String sPageName = page.GetName();

    if (BestBetsListDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
      	this.SetHelpTopic( "PT_SearchResultsManager_BestBets" );
    } else if (ThesaurusSettingsDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
		this.SetHelpTopic( "PT_SearchResultsManager_ThesaurusandSpellCorrection" );
    } else if (BannerFieldAliasDP.STR_MVC_CLASS_NAME.equals(sPageName)) {
		this.SetHelpTopic( "PT_SearchResultsManager_BannerFields" );
    }
  }
}

