package com.plumtree.portalpages.admin.serversettings.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * @author MatthewF
 */
public class SearchServerTuningEditorRepostControl extends EditorRepostControl
{	
	public static final String STR_MVC_CLASS_NAME = "SearchServerTuningEditorRepost";
	
	public final static int POSTTOSELF_ACTION_MISC		 = 10;
	
	public final static int POSTTOSELF_ACTION_BB_DELETE = 21;
	
	public static final int POSTTOSELF_ACTION_ADD_FIELD = 81;
	
	public static final int POSTTOSELF_ACTION_DEL_FIELD = 91;
	
	public static final int POSTTOSELF_ACTION_FIELD_DEFAULTS = 101;
	
	public final static int POSTTOSELF_ACTION_BB_PAGINATE = 111;

	public final static int POSTTOSELF_ACTION_BB_SEARCH = 112;

	public final static int POSTTOSELF_ACTION_BB_SHOWALL = 113;

	public static final String HTMLINPUT_ADD				  = "in_bu_add";
	
	public static final String HTMLINPUT_DELETE				  = "in_bu_delete";
	
	public static final String HTMLINPUT_SEARCH_TEXT		  = "in_tx_search";

	public static final String HTMLINPUT_SELECTED_ITEM		  = "in_cb_selected";
	
	public static final String HTMLINPUT_IS_SELECTED_ITEM     = "in_cb_is_selected";
	
	public static final String HTMLINPUT_HIDDEN_SELECTED_ITEM = "in_hi_selected";

	public static final String HTMLINPUT_FIRST_BEST_BET_TO_SHOW = "in_hi_first_bb";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SearchServerTuningEditorRepostControl();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param _nAction 
	 */
	protected void PerformAction(int _nAction)
	{
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
		if(! (PlumtreeHelpers.CheckCurrentUserIsAdmin(ptSession) ||
		      ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_SEARCH_SERVER_TUNING)))
		{
			return;
		}	
		super.PerformAction(_nAction);

		switch (_nAction)
		{
		    case POSTTOSELF_ACTION_APPLY_CHANGES:
					((SearchServerTuningEditorModel) m_model).DoApplyChanges(m_htFormData);
      			break;

			case POSTTOSELF_ACTION_MISC:
				((SearchServerTuningEditorModel) m_model).ActionOnRepost();
	
				break;

			case POSTTOSELF_ACTION_BB_DELETE:
	
				if (m_htFormData.ContainsKey(HTMLINPUT_SELECTED_ITEM))
				{
					String[] itemDel = (String[]) m_htFormData.GetElement(HTMLINPUT_SELECTED_ITEM);
					if(itemDel.length > 0)
					{
						int[] idsToDelete = new int[itemDel.length];
						for (int j = 0; j < itemDel.length; j++)
						{
							idsToDelete[j] = -1;
		
							try
							{
								idsToDelete[j] = XPConvert.ToInteger(itemDel[j]);
							}
							catch (Exception e)
							{
								throw XPException.GetInstance(e);
							}
						}
						((SearchServerTuningEditorModel) m_model).DeleteBestBets(idsToDelete);
					}
				}
	
				break;
			case POSTTOSELF_ACTION_BB_PAGINATE:
				String[] itemPag = (String[]) m_htFormData.GetElement(HTMLINPUT_FIRST_BEST_BET_TO_SHOW);
				
				int nBestBetIndex = 1;

				try
				{
					nBestBetIndex = XPConvert.ToInteger(itemPag[0]);
				}
				catch (Exception e)
				{
					throw XPException.GetInstance(e);
				}

				if (nBestBetIndex >= 1)
				{
					((SearchServerTuningEditorModel) m_model).PaginateBestBets(nBestBetIndex, ((SearchServerTuningEditorModel) m_model).GetNumBestBetsAskedFor());
				}

				break;
				
			case POSTTOSELF_ACTION_BB_SEARCH:
				String[] itemSearch = (String[]) m_htFormData.GetElement(HTMLINPUT_SEARCH_TEXT);
				

				if (itemSearch != null && itemSearch[0] != null && itemSearch[0].length() > 0)
				{
					((SearchServerTuningEditorModel) m_model).SearchBestBets(itemSearch[0]);
				}

				break;

			case POSTTOSELF_ACTION_BB_SHOWALL:
				((SearchServerTuningEditorModel) m_model).ShowAllBestBets();
				break;
				
			case POSTTOSELF_ACTION_ADD_FIELD:
				((SearchServerTuningEditorModel) m_model).AddAliasTerm(m_htFormData);
				break;
				
			case POSTTOSELF_ACTION_DEL_FIELD:
				String[] cbVals = (String[])m_htFormData.GetElement(BannerFieldAliasView.IN_CB_NAME);
				if(cbVals != null && cbVals.length > 0)
				{
					if(((SearchServerTuningEditorModel) m_model).OkToDeleteThisManyAliasTerms(cbVals.length))
					{
						int[] indices = new int[cbVals.length];
						for(int i = 0; i < cbVals.length; i++)
						{
							indices[i] = XPConvert.ToInteger(cbVals[i]);
						}
						((SearchServerTuningEditorModel) m_model).DeleteTheseAliasTerms(indices, m_htFormData);
					}
					else
					{
						RaiseError(m_asOwner.GetString(2566, "ptmsgs_portaladminmsgs"));
					}
				}
				break;
				
			case POSTTOSELF_ACTION_FIELD_DEFAULTS:
				((SearchServerTuningEditorModel) m_model).RestoreDefaultFieldAlias();
				break;
				
			default:
				break;
		}
	}
	protected void RaiseError(String message)
	{
		UIError err = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER,message,"");
		err.SetActivitySpace(m_asOwner.GetName());
		err.SetDisplayOnSeparatePage(false);
		err.SetClearWithActivitySpaceChange(true);
		err.SetImmediateClear(true);
		
		UIErrorHandler.RaiseError(err,m_asOwner.GetSubSession(), m_asOwner.GetApplication());

	}

}

