package com.plumtree.portalpages.ajax;

import com.plumtree.openfoundation.util.XPStringBuilder;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;

/**
 * This class returns the results of an AJAX call.
 * The response is JSON, not HTML.
 * 
 * @author MattC
 */
public class AjaxView implements IView
{
	public static final String STR_MVC_CLASS_NAME = "AjaxView";

	private AjaxModel m_ajaxModel;
	private AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AjaxView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		return null;
	}
	
	public String DisplayResponse()
	{
		// generate JSON response
		XPStringBuilder buf = new XPStringBuilder(200);
		buf.Append("{");
		buf.Append("oldname:'").Append(NavigationCommonHelpers.EscapeSingleQuotes(m_ajaxModel.getOldName())).Append("', ");
		buf.Append("newname:'").Append(NavigationCommonHelpers.EscapeSingleQuotes(m_ajaxModel.getNewName())).Append("', ");
		buf.Append("classid:'").Append(m_ajaxModel.getClassId()).Append("', ");
		buf.Append("objectid:'").Append(m_ajaxModel.getObjectId()).Append("', ");
		buf.Append("status:'").Append(m_ajaxModel.getStatus()).Append("', ");
		buf.Append("message:'").Append(NavigationCommonHelpers.EscapeSingleQuotes(m_ajaxModel.getMessage())).Append("', ");
		IPTURL refreshURL;
		if (m_ajaxModel.getClassId() == PT_CLASSIDS.PT_MYPAGESCONTAINER_ID) {
			refreshURL = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(m_asOwner, m_ajaxModel.getObjectId(), m_ajaxModel.getNewName());
		} else {
			// DCA - must be a community page
			IPTSession session = (IPTSession) m_asOwner.GetUserSession();
			IPTPageInfo curPage = ((IPTPageManager)session.GetPages()).CachedOpenPageInfo(m_ajaxModel.getObjectId(), false, false);
			refreshURL = TaskAPIUICommunity.CreateCommunityPageCommonOpenerURL(m_asOwner, curPage.GetContainerObjectID(), curPage.GetObjectID(), m_ajaxModel.getNewName());
		}
		buf.Append("refreshURL:'").Append(refreshURL.GetFullURL()).Append("'}");
		return buf.toString();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{		
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_ajaxModel     = (AjaxModel) model;
		m_asOwner 		= parent;
	}
}