package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.abodelete.*;
import com.plumtree.portalpages.browsing.directory.browse.*;
import com.plumtree.portalpages.browsing.directory.browse_D.*;
import com.plumtree.portalpages.browsing.directory.createfolder.*;
import com.plumtree.portalpages.browsing.directory.documentsubmitsimple.*;
import com.plumtree.portalpages.browsing.directory.edit.*;
import com.plumtree.portalpages.browsing.directory.properties.*;
import com.plumtree.portalpages.browsing.directory.relatedresources.*;
import com.plumtree.portalpages.browsing.directory.rest.*;
import com.plumtree.portalpages.browsing.directory.senddoc.*;
import com.plumtree.portalpages.browsing.editors.document.*;
import com.plumtree.portalpages.common.createfolder.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.pathways.tagging.TaggingControl;
import com.plumtree.portaluiinfrastructure.pathways.tagging.TaggingRESTDP;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.keywords.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 */
public class DirAS extends PlumtreeAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.DirAS");

	
	public static final String DIRFOLDERVIEW     = "DirFolderView";

	
	public static final String DIRBANNERVIEW     = "DirBannerView";

	
	public static final String DIROBJECTVIEW     = "DirObjectView";

	
	public static final String DIRBREADCRUMBVIEW = "DirBreadcrumbView";

	
	public static final String STR_MVC_CLASS_NAME = "Dir";

	
	public static final String JS_PARENT_SIMPLE_REPOST = "window.opener." +
		AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
		RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");\n";

	/** storage name for ClosePopUpDP when Editing Cards */
	public static final String EDITCARDPROPERTIES_POPUP = "CardPropertiesPopUp";

	/** storage name for ClosePopUpDP when Clicking Through More Related Resources*/
	public static final String MORE_RELATEDRESOURCES_POPUP = "MoreRelatedResourcesPopUp";

	/** storage name for ClosePopUpDP when Clicking Through More Docs Like This In Card Properties*/
	public static final String CARDPROPERTIES_MOREDOCS_POPUP = "CardPropertiesMoreDocsPopUp";

	/** storage name for ClosePopUpDP after Advanced Card Submit*/
	public static final String CARDSUBMIT_ADVANCED_CONFIM_POPUP = "CardSubmitAdvancedConfirmPopUp";

	/** Display Page name to handle the reloading of the directory after exiting from an editor **/
	public static final String DIR_EDITOR_FINISH = "DirEditorRedirect";

	/**
	 * MJD- Storage name for Keywords classes
	 */
	public static final String STR_MVC_STORAGE_NAME_KEYWORDS = "DirKeywordsObjEditor";

	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirAS();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#GetCurrentPage()
	 */
	public IDisplayPage GetCurrentPage()
	{
		DirModel dirModel = (DirModel) GetModel(DirModel.STR_MVC_CLASS_NAME);
		int nDirMode	  = dirModel.GetDirectoryMode();

		switch (nDirMode)
		{
			case DirConstants.BROWSE_MODE:
			{
				this.SetHelpTopic("PT_BrowseDirectory");
				return GetPage(DirBrowseDP.STR_MVC_CLASS_NAME);
			}
	
			case DirConstants.EDIT_MODE:
			{
				this.SetHelpTopic("PT_EditDirectory");		
				return GetPage(DirEditDP.STR_MVC_CLASS_NAME);
			}
	
			case DirConstants.DISABILITY_MODE:
			{		
				this.SetHelpTopic("PT_BrowseDirectory");
				return GetPage(DirBrowseDP_D.STR_MVC_CLASS_NAME);
			}
	
			default:
			{
				this.SetHelpTopic("PT_BrowseDirectory");
				return GetPage(DirBrowseDP.STR_MVC_CLASS_NAME);
			}
		}
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * This method handles the ClosePopUpDP and passes everything else to the base
	 * implementation.  It adds javascript to the ClosePopUpDP that sets the selected
	 * items on the opener window (if it's a remote tree) and calls a javascript
	 * function on the opener window.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#GetPage(String)
	 */
	public IDisplayPage GetPage(String pageName)
	{
		if (ClosePopUpDP.STR_MVC_CLASS_NAME.equals(pageName))
		{
			// This is called when SimpleCardSubmitDP or CreateFolderDP is canceled.
			ClosePopUpDP result = (ClosePopUpDP) super.GetPage(pageName);

			try
			{
				HTMLScript myScript = new HTMLScript("text/javaScript");
				myScript.AddInnerHTMLString(JS_PARENT_SIMPLE_REPOST);
				result.SetScript(myScript);
			}
			catch (HTMLException he)
			{
				log.Error(he, "Error generating JS for ClosePopUpDP.");
			}

			return result;
		}
		else if (CARDSUBMIT_ADVANCED_CONFIM_POPUP.equals(pageName))
		{
			DirModel dirModel = (DirModel) GetModel(DirModel.STR_MVC_CLASS_NAME);
			dirModel.LoadFoldersAndDocuments();

			DirEditDP result = (DirEditDP) super.GetPage(DirEditDP.STR_MVC_CLASS_NAME);

			int nCardID = dirModel.GetCardID();
			int nLoadedCardID = dirModel.GetLoadedCardID();
			
			if(nLoadedCardID != nCardID)
			{
				ASURL myURL = new ASURL(this);
				myURL.SetLinkGetCachedSpace(this);
				myURL.SetDisplayPage(DirCardSubmitDependenciesDP.STR_MVC_CLASS_NAME);
		
				// popup a new window
				XPStringBuilder sb = new XPStringBuilder(200);
				sb.Append("window.open('").Append(myURL.GetURLAsString())
				.Append("', 'ConfirmDir', 'location=no,menubar=no,height=575,width=600');\n");
				result.SetScript(sb.ToString());
				
				dirModel.SetLoadedCardID(nCardID);
			}
			
			return result;
		}
		else if (DIR_EDITOR_FINISH.equals(pageName))
		{
			DirModel dirModel = (DirModel) GetModel(DirModel.STR_MVC_CLASS_NAME);
			dirModel.LoadFoldersAndDocuments();

			switch (dirModel.GetDirectoryMode())
			{
				case DirConstants.BROWSE_MODE:
				{
					return super.GetPage(DirBrowseDP.STR_MVC_CLASS_NAME);
				}
	
				case DirConstants.EDIT_MODE:
				{
					this.SetHelpTopic("PT_EditDirectory");		
					return super.GetPage(DirEditDP.STR_MVC_CLASS_NAME);
				}
	
				case DirConstants.DISABILITY_MODE:
				{		
					this.SetHelpTopic("PT_BrowseDirectory");
					return super.GetPage(DirBrowseDP_D.STR_MVC_CLASS_NAME);
				}
	
				default:
				{
					return GetPage(DirBrowseDP.STR_MVC_CLASS_NAME);
				}
			}
		}
		else if (MORE_RELATEDRESOURCES_POPUP.equals(pageName))
		{
			// This called when a user clicks through to a Related Resources posted in the More RR popup
			ClosePopUpDP result = (ClosePopUpDP) super.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

			IDirModelRO model = (IDirModelRO) GetModel(DirModel.STR_MVC_CLASS_NAME);
			int nRRCategoryID = model.GetRRCategory();
			int nRRObjectID   = model.GetRRObjectID();
			int nClassID;

			switch (nRRCategoryID)
			{
			case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
				nClassID = PT_CLASSIDS.PT_COMMUNITY_ID;
				break;
			case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS:
				nClassID = PT_CLASSIDS.PT_CATALOGFOLDER_ID;
				break;
			case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
				nClassID = PT_CLASSIDS.PT_GADGET_ID;
				break;

			case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
			case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
				nClassID = PT_CLASSIDS.PT_USER_ID;
				break;

			default:
				return super.GetPage(pageName);
			}

			String strURL = PTOpenerLinks.GetOpenerURLOpenObjID(
				nClassID, nRRObjectID, IPTOpenerConstants.OPENER_MODE_VIEW, this);

			try
			{
				String strAppBaseURL = ConfigHelper.GetApplicationBaseURL(this);

				HTMLScript myScript = new HTMLScript("text/javaScript");
				myScript.AddInnerHTMLString("window.opener.location='" +
					strAppBaseURL + strURL + "';\n");
				result.SetScript(myScript);
			}
			catch (HTMLException he)
			{
				log.Error(he, "Error generating JS for ClosePopUpDP.");
			}

			return result;
		}
		else if (CARDPROPERTIES_MOREDOCS_POPUP.equals(pageName))
		{
			// This is called when a user clicks on "More Docs Like This" property value
			ClosePopUpDP result = (ClosePopUpDP) super.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

			IDirModelRO model = (IDirModelRO) GetModel(DirModel.STR_MVC_CLASS_NAME);
			int nMoreFolderID = model.GetMoreFolderID();
			int nDirMode	  = model.GetDirectoryMode();

			ASURL myURL = new ASURL(this);
			myURL.SetLinkGetCachedSpace(this);

			myURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
			myURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID,
				XPConvert.ToString(nMoreFolderID));
			myURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
				XPConvert.ToString(nDirMode));

			try
			{
				HTMLScript myScript = new HTMLScript("text/javaScript");
				myScript.AddInnerHTMLString("window.opener.location='" +
					myURL.GetURLAsString() + "';\n");
				result.SetScript(myScript);
			}
			catch (HTMLException he)
			{
				log.Error(he, "Error generating JS for ClosePopUpDP.");
			}

			return result;
		}
		else if (EDITCARDPROPERTIES_POPUP.equals(pageName))
		{
			// This is called when Edit button on Section Card Properties is clicked
			ClosePopUpDP result = (ClosePopUpDP) super.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

			IDirModelRO model = (IDirModelRO) GetModel(DirModel.STR_MVC_CLASS_NAME);
			int nCardID		  = model.GetCardID();

			ASURL url = new ASURL(this);
			url.SetLinkCreateNewSpace(CardEditorAS.STR_MVC_CLASS_NAME, this);
			url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
				XPConvert.ToString(nCardID));
			url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));

			// We are in a frame, so we need to call parent, not window
			try
			{
				HTMLScript myScript = new HTMLScript("text/javaScript");
				/* bug 24681 JHQ: in IE5.5 window.opener.location is bugged!  Instead,
				 * doing oWin = window.opener; oWin.location = url;
				 */
				myScript.AddInnerHTMLString("var oWin = window.opener;" +
					"oWin.location='" +
					url.GetURLAsString() + "';\n");
				result.SetScript(myScript);
			}
			catch (HTMLException he)
			{
				log.Error(he, "Error generating JS for ClosePopUpDP.");
			}

			return result;
		}

		return super.GetPage(pageName);
	}

	/**
	 * Returns the name of the repost control class.
	 *
	 * @see com.plumtree.xpshared.form.IRepostAS#GetRepostControlName()
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return DirRepostControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();

		// Directory DisplayPages
		RegisterPage(new DirBrowseDP());
		RegisterPage(new DirEditDP());
		RegisterPage(new CreateFolderDP());
		
		AFormDP page = new DirCardSubmitSimpleDP();
		RegisterPage(page);
		
		RegisterPage(new DirCardSubmitDependenciesDP());
		RegisterPage(new DirCardPropertiesDP());
		RegisterPage(new RelatedResourcesMorePopupDP());
		RegisterPage(new SendDocPopUpDP());

		// Obj Mgr popup Pages -- delete warnings
		RegisterPage(new DirDeleteWarningsDP());
		RegisterPage(new DirABOLinksDP());

		RegisterPage(new ClosePopUpDP());

		// Directory Model
		RegisterModel(DirModel.STR_MVC_CLASS_NAME);

		IModel myModel = GetModel(DirModel.STR_MVC_CLASS_NAME);

		// This page uses the Dir Model (since it handles the View code as well),
		// so it needs to be registered after the model.
		RegisterPage(new DirRESTDP());

		// Directory Views
		RegisterView(DirBreadcrumbView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderBannerView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ObjectView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DocumentBannerView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(RelatedResourcesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(RelatedResourcesMorePopupView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirCreateFolderView.STR_MVC_CLASS_NAME, CreateFolderView.STR_VIEW_STORAGE_NAME, myModel);
		RegisterView(DirCardSubmitSimpleView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirCardSubmitUploadingView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirCardSubmitDoneView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirCardPropertiesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirDeleteWarningsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirABOLinksView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirCardSubmitDependenciesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SendDocPopUpView.STR_MVC_CLASS_NAME, myModel);

		// Directory Controls
		RegisterControl(SetStartItemControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(SetLastItemControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(DirRepostControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(DirCheckDeleteControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(DirRESTControl.STR_MVC_CLASS_NAME, myModel);

		//Pathways Tags Control
		RegisterControl(TaggingControl.STR_MVC_CLASS_NAME, myModel);
		//PathwaysTagging DP
		RegisterPage(new TaggingRESTDP());
		
		// Register the opendirfolder control as opensubfolder control
		RegisterControl(OpenDirFolderControl.STR_MVC_CLASS_NAME,
			OpenSubFolderControl.STR_MVC_CLASS_NAME, myModel);

		// 508 pages and views
		RegisterPage(new DirBrowseDP_D());
		RegisterPage(new DirCardPropertiesDP_D());
		RegisterPage(new DirRelatedResourcesMoreDP_D());
		RegisterView(DirBrowseFooterView_D.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirBrowseHeaderView_D.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirCardPropertiesView_D.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirRelatedResourcesView_D.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DirRelatedResourcesMoreView_D.STR_MVC_CLASS_NAME, myModel);

		// Register Plug-In: Keywords
		RegisterModel(KeywordsModel.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_KEYWORDS);
		RegisterView(DirKeywordsView.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_KEYWORDS,
			GetModel(STR_MVC_STORAGE_NAME_KEYWORDS));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			STR_MVC_STORAGE_NAME_KEYWORDS,
			GetModel(STR_MVC_STORAGE_NAME_KEYWORDS));

		this.SetOverWriteSubSpaces(true);
	}
}