package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author RupaP
 *
 * Constants for the Directory.
 */
public class DirConstants
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.DirConstants");

	// *** Constants ***
	//QueryString arguments


	public static final String QS_DIRECTORY_MODE    = "DirMode";


	public static final String QS_FOLDERPATH		    = "dirPath";


	public static final String QS_CARDID		    = "cardID";


	public static final String QS_ADVANCED_CARDID		    = "ADVcardID";


	public static final String QS_RRCATEGORY	    = "rrCategory";


	public static final String QS_RROBJECTID	    = "rrObjectID";


	public static final String QS_MOREFOLDERID	    = "moreFolderID";


	public static final String QS_RANGE_TO		    = "rangeTo";


	public static final String QS_RANGE_FROM	    = "rangeFrom";

	/* Query String for displaying Number of Cards per page */
	public static final String QS_PER_PAGE			= "numCards";
	
	/* Query String for Displaying Docuument by given Type ID */ 
	public static final String QS_DOCUMENT_TYPEID	= "typeID";

	public static final String QS_SORTBY		    = "sortBy";


	public static final String QS_PARENT_FOLDER     = "ParentFolder";


	public static final String QS_SELFSELECT_EXPERT = "addMeExpert";
	
	
	public static final String QS_RETURN_UPLOAD_PATH = "returnUploadPath";
	
	
	public static final String QS_RETURN_UPLOAD_ERROR = "returnUploadError";
	
	
	public static final String QS_RETURN_UPLOAD_TYPE = "returnUploadType";
	
	
	public static final String QS_RETURN_UPLOAD_DOCID = "returnUploadDocID";
	
	
	public static final String QS_RETURN_UPLOAD_DUID = "duid";
	
	
	public static final String QS_RETURN_UPLOAD_DUSERVER = "duserver";
	
	
	public static final String QS_508_DELETE = "508DeleteCard";
	
	
	// Pop-up Page Names


	public static final String JAVASCRIPT_SIMPLESUBMIT_DONE    = "DirSimpleCardSubmitDone";


	public static final String JAVASCRIPT_CARDPROPERTIES_POPUP    = "DirCardPropertiesPopup";


	public static final String JAVASCRIPT_MORERR_POPUP			  = "MoreRRPopup";


	public static final String JAVASCRIPT_MORERR_CLICKTHROUGH     = "MoreRRClickThrough";


	public static final String JAVASCRIPT_CARDPROPERTIES_MOREDOCS = "DirCardPropertiesMoreDocs";


	public static final String JAVASCRIPT_SENDDOCLINK_POPUP    = "SendDocLinkPopup";

	//Directory Modes


	public static final int BROWSE_MODE     = 1;


	public static final int EDIT_MODE	    = 2;


	public static final int DISABILITY_MODE = 3;


	public static final int INVALID_MODE = -1;


	// Card Submit Modes


	public static final int CARDSUBMITMODE_MAIN     = 1;


	public static final int CARDSUBMITMODE_UPLOADING = 2;


	public static final int CARDSUBMITMODE_DONE     = 3;


	//Related Resource Locations


	public static final int RELATED_RESOURCE_LOCATION_LEFT   = 1;


	public static final int RELATED_RESOURCE_LOCATION_RIGHT  = 2;


	public static final int RELATED_RESOURCE_LOCATION_TOP    = 3;


	public static final int RELATED_RESOURCE_LOCATION_BOTTOM = 4;

	//Folder Description Type


	public static final String DIR_FOLD_DESC_FULL = "FF";


	public static final String DIR_FOLD_DESC_ABBR = "FA";


	public static final String DIR_FOLD_DESC_NONE = "FN";

	//Document Description Type


	public static final String DIR_DOC_DESC_FULL = "DF";


	public static final String DIR_DOC_DESC_ABBR = "DA";


	public static final String DIR_DOC_DESC_NONE = "DN";

	//Directory Browse By


	public static final int BROWSE_BY_SEARCH   = 1;


	public static final int BROWSE_BY_DATABASE = 2;

	//The maximum number of subfolder links to display below each folder in browse mode
	//Administrator can select the actual number in Directory Preferences


	public static final int MAX_NUM_SUB_SUB_FOLDERS_TO_DISPLAY = 5;

	//The maximum number of folder columns in browse mode
	//Administrator can select the actual number in Directory Preferences


	public static final int MAX_NUM_FOLDER_COLUMNS = 8;

	//The maximum number of document columns in browse mode
	//Administrator can select the actual number in Directory Preferences


	public static final int MAX_NUM_DOCUMENT_COLUMNS = 3;


	public static final int DEFAULT_NUMDOCSONPAGE    = 20;


	public static final int DEFAULT_NUMFOLDERCOLUMNS = 3;


	public static final int DEFAULT_NUMSUBSUBFOLDERS = 5;


	public static final int DESCRIPTION_ABBR_LENGTH = 100;


	public static final int SORTING_NOTSET = 0;


	public static final int PROP_COLUMNS_MAX	    = 3;


	public static final int PROP_COLUMNS_INDEX_ID   = 0;


	public static final int PROP_COLUMNS_INDEX_NAME = 1;


	public static final int PROP_COLUMNS_INDEX_TYPE = 2;


	private static final String CHINESE_LOCALE_CODE = "zh";


	public int[] m_arRelatedResourceIDs    =
	{
		PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES,
		PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS,
		PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS,
		PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS,
		PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS
	};


	public boolean m_bShowRelatedResources = true;


	public static final String BREAK = "<br>";


	private static final int URL_MAX_LENGTH = 50;

	private static final int LONG_STRING_MAX_LENGTH = 50;

	/**
	 * This is displayed at the top of directory pages.
	 * It shows the breadcrumb for all folders except the root,
	 */
	public static HTMLTable DisplayBreadcrumbTable(AActivitySpace asOwner)
	{
		IFolderModelRO asFolderModel = (IFolderModelRO) asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);

		HTMLTable table = new HTMLTable();
		table.SetWidth("100%");

		try
		{
			table.SetStyleClass(PTStyleClass.BREADCRUMB_TEXT);

			HTMLTableRow row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);

			HTMLTableCell cell;

			//Breadcrumbs - don't display them in the root folder
			boolean bInRootFolder = asFolderModel.InRootFolder();

			if (!bInRootFolder)
			{
				cell = new HTMLTableCell();
				cell.AddInnerHTMLElement(asOwner.GetView(
						DirBreadcrumbView.STR_MVC_CLASS_NAME).Display());
				row.AddInnerHTMLElement(cell);
			}
			else
			{
				return null;
			}
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Error in DirConstants.DisplayBreadcrumbTable: " +
					he.getMessage());
			
		}

		return table;
	}

	/**
	 * This is displayed below the documents if there are additional documents to view
	 */
	public static HTMLTable DisplayDocumentLinksTable(AActivitySpace asOwner,
		String _strPrevious, String _strNext, String _strTableSummary)
	{
		IDirModelRO asDirModel = (IDirModelRO) asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);

		int nFolderID = asDirModel.GetCurrentFolderID();
		int nDirMode = asDirModel.GetDirectoryMode();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLAnchor myAnchor;

		try
		{
			// Show pagination links if needed
			int nNumDocsDisplayed = asDirModel.GetObjectCount();

			if (0 < nNumDocsDisplayed)
			{
				boolean bShowLinks = false;

				// Create the table, but only add it to the page if there are links
				myTable = new HTMLTable();
				myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				myTable.SetBorder(CommonHTMLStrings.ZERO);
				myTable.SetCellPadding("2");
				myTable.SetCellSpacing("2");
				myTable.SetSummary(_strTableSummary);

				myRow = new HTMLTableRow();
				myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG); //todo: set to 508 style
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myCell.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);
				myCell.SetAlign(CommonHTMLStrings.RIGHT);
				myRow.AddInnerHTMLElement(myCell);

				int nBeginID    = asDirModel.GetCardRangeBegin();
				int nEndID	    = (nBeginID + nNumDocsDisplayed) - 1;
				int nTotalCount = asDirModel.GetTotalResults();

				int nNumDocsPerPage = asDirModel.GetNumDocsPerPage();

				// Show "Prev" link
				if (1 != nBeginID)
				{
					bShowLinks = true;

					int nPrevBegin = nBeginID - nNumDocsPerPage;
					int nPrevEnd   = nBeginID - 1;

					if (1 > nPrevBegin)
					{
						nPrevBegin = 1;
					}

					ASURL myURL = new ASURL(asOwner);
					myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, asOwner);
					myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
					myURL.AddControlArgument(DirConstants.QS_RANGE_FROM,
						nPrevBegin);
					myURL.AddControlArgument(DirConstants.QS_RANGE_TO, nPrevEnd);
					myURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID, nFolderID);
					myURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, nDirMode);
					myAnchor = new HTMLAnchor(myURL.GetURLAsString());

					int nNumDocsInRange = nPrevEnd - nPrevBegin + 1;

					String strPrevious = "<-" + CommonHTMLStrings.SPACE + XPResourceManager.FormatMessage(_strPrevious, XPConvert.ToString(nNumDocsInRange));
					myAnchor.AddInnerHTMLString(strPrevious);
					myAnchor.SetTitle(strPrevious);
					myCell.AddInnerHTMLElement(myAnchor);
				}

				// Show "Next" link
				if (nEndID != nTotalCount)
				{
					bShowLinks = true;

					int nNextBegin = nEndID + 1;
					int nNextEnd   = nEndID + nNumDocsPerPage;

					if (nTotalCount < nNextEnd)
					{
						nNextEnd = nTotalCount;
					}

					ASURL myURL = new ASURL(asOwner);
					myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME, asOwner);
					myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
					myURL.AddControlArgument(DirConstants.QS_RANGE_FROM,
						nNextBegin);
					myURL.AddControlArgument(DirConstants.QS_RANGE_TO, nNextEnd);
					myURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID, nFolderID);
					myURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE, nDirMode);

					myAnchor = new HTMLAnchor(myURL.GetURLAsString());

					int nNumDocsInRange = nNextEnd - nNextBegin + 1;

					String strNext = XPResourceManager.FormatMessage(_strNext, XPConvert.ToString(nNumDocsInRange)) + CommonHTMLStrings.SPACE + "->";
					myAnchor.AddInnerHTMLString(strNext);
					myAnchor.SetTitle(strNext);
					myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
					myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
					myCell.AddInnerHTMLElement(myAnchor);
				}

				if (bShowLinks)
				{
					return myTable;
				}
				else
				{
					return null;
				}
			}
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Error in DirConstants.DisplayDocumentLinksTable.");
			
		}

		return null;
	}

	public static HTMLImg CreateSpacerImage(int nHeight, int nWidth)
	{
		PTConstruct myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
		HTMLImg myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt("");
		myImage.SetWidth(XPConvert.ToString(nWidth));
		myImage.SetHeight(XPConvert.ToString(nHeight));
		myImage.SetBorder("0");

		return myImage;
	}

	/**
	 *
	 *
	 * @param nColSpan
	 * @param nHeight
	 *
	 * @return
	 *
	 * @throws HTMLException
	 */
	public static HTMLTableRow CreateSpacerRow(int nColSpan, int nHeight)
	{
		HTMLTableRow row   = new HTMLTableRow();
		HTMLTableCell cell = new HTMLTableCell();
		cell.SetColSpan(XPConvert.ToString(nColSpan));
		cell.SetHeight(XPConvert.ToString(nHeight));
		row.AddInnerHTMLElement(cell);

		return row;
	}

	/**
	 * Helper method: returns empty table.
	 *
	 * @return HTMLElement
	 */
	public static HTMLElement CreateSpacerTable(int nHeight, int nWidth)
	{
		HTMLElementCollection myResult = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Spacer table");
			myResult.AddInnerHTMLElement(myComment);

			myTable = new HTMLTable();
			myResult.AddInnerHTMLElement(myTable);
			myTable.SetBorder("0");
			myTable.SetWidth("100%");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("0");

			// 1st Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.AddInnerHTMLElement(CreateSpacerImage(nHeight, nWidth));

			myComment = new HTMLComment( "End: Spacer table");
			myResult.AddInnerHTMLElement(myComment);

		}
		catch (Exception e)
		{
			
				log.Error(e, "EditorDP::GetSpacerTable The following error occured when trying to display the HTML: " +
					e.getMessage());
			
		}

		return myResult;
	}

	/**
	 * Inxight languages are specified as a two character string (like "en" or "fr"),
	 * with the exception of the chinese languages which can be "zh-TW" or "zh-CN"
	 */
	public static String TrimCardLanguage(String strLanguage)
	{
		if (strLanguage.length() == 2)
		{
			return XPStringUtility.ToLowerCase(strLanguage);
		}

		else if (strLanguage.length() > 2)
		{
			String strFirstTwoCharacters = strLanguage.substring(0, 2);

			if (0 == XPStringUtility.CompareIgnoreCase(strFirstTwoCharacters,
						CHINESE_LOCALE_CODE))
			{
				return strLanguage;
			}
			else
			{
				return XPStringUtility.ToLowerCase(strFirstTwoCharacters);
			}
		}
		else
		{
			return strLanguage;
		}
	}

	/**
	 *
	 *
	 * @param strURL
	 *
	 * @return
	 */
	public static String BreakUpStringAndHTMLEncode(String strURL)
	{
		return BreakUpStringAndHTMLEncode(strURL, URL_MAX_LENGTH);
	}


	/**
	 *
	 *
	 * @param strURL
	 *
	 * @return
	 */
	public static String BreakUpStringAndHTMLEncode(String strURL, int nLength)
	{
		if (strURL.length() > nLength)
		{
			String strNewString = XPHttpUtility.HtmlEncode(strURL.substring(0, nLength));
			String strLeft	    = strURL.substring(nLength);

			while (strLeft.length() > 0)
			{
				if (strLeft.length() > nLength)
				{
					strNewString     = strNewString + BREAK +
						XPHttpUtility.HtmlEncode(strLeft.substring(0, nLength));
					strLeft			 = strLeft.substring(nLength);
				}
				else
				{
					strNewString = strNewString + BREAK +
						XPHttpUtility.HtmlEncode(strLeft);

					break;
				}
			}

			return strNewString;
		}
		else
		{
			return XPHttpUtility.HtmlEncode(strURL);
		}
	}

	/**
	 *
	 *
	 * @param strURL
	 *
	 * @return
	 */
	public static String BreakUpLongWordsInStringAndHTMLEncode(String strURL)
	{
		return BreakUpLongWordsInStringAndHTMLEncode(strURL, LONG_STRING_MAX_LENGTH);
	}


	/**
	 *
	 *
	 * @param strURL
	 *
	 * @return
	 */
	// SCC: This method iterates through a String and breaks up long words into smaller words
	public static String BreakUpLongWordsInStringAndHTMLEncode(String str, int nLength)
	{
		try {
			int nStringLength = str.length();
			if (nStringLength > nLength)
			{
				XPStringBuilder sb = new XPStringBuilder();

				int nOldPos = 0;
				int nSpacePos = 0;

				while(nSpacePos != -1)
				{
					nSpacePos = str.indexOf(" ", nOldPos);

					// no spaces left
					if(-1 == nSpacePos)
					{
						if(nStringLength - nOldPos > nLength)	// last word too long
						{
							sb.Append(XPHttpUtility.HtmlEncode(str.substring(nOldPos, nOldPos + nLength)));
							sb.Append(BREAK);
							nOldPos = nOldPos + nLength;
							nSpacePos = 0;
						}
						else
						{
							sb.Append(XPHttpUtility.HtmlEncode(str.substring(nOldPos)));
							break;
						}

					}
					else if(nSpacePos - nOldPos > nLength)  // break up the word if too long
					{
						sb.Append(XPHttpUtility.HtmlEncode(str.substring(nOldPos, nOldPos + nLength)));
						sb.Append(BREAK);
						nOldPos = nOldPos + nLength;
					}
					else // add the word to the final String
					{
						sb.Append(XPHttpUtility.HtmlEncode(str.substring(nOldPos, nSpacePos + 1)));
						nOldPos = nSpacePos + 1;
					}
				}

				return sb.ToString();
			}
			else
			{
				return XPHttpUtility.HtmlEncode(str);
			}
		}
		catch(Exception e)
		{
			return str;
		}
	}
}

