package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * this function writes out one folder and its sub-folders in a
 *         small table. ptqrFolders should be a two-level folder query with
 *         default ordering (so that the subfolders of a folder are always
 *         right after the parent).  intQueryIndex should be an index in
 *         ptqrFolders which corresponds to a parent folder.   intQueryIndex
 *         will be changed into the index in ptqrFolders of the next parent
 *         folder. -sra.  The folder link uses cached Directory activity
 *         space.
 *
 * @author StephenC
 */
public class DirFolderViewHelper implements IFolderViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.DirFolderViewHelper");


	public static final String QS_CHECKBOX = "in_cb_folder";

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayObject(int,
	 *      HTMLTableCell, IFolderModelRO)
	 */
	public int DisplayFolder(int nIndexRef, HTMLTableCell tableCell,
		IFolderModelRO model, AActivitySpace space)
	{
		IDirModelRO dirModel = (IDirModelRO) model;

		try
		{
			boolean bSubFoldersFromSearch = dirModel.RetrieveSubFoldersThroughSearch();

			IASQueryResult qrFolders =  null;
			IPTSearchResponse srFolders = null; 
			int nTotalFolderCount;
			int nFolderID;
			String strFolderName = null;
			XPDateTime dtCreatedDate;
            //This is the description for the mouse-over event, that shows the full description
			// all the time
			String strDescription = null;
			// folder desciption - HTML description is shown depending on the Knowledge Preference settings
			String strDescType = dirModel.GetFolderDescriptionType();
			String strDesc     = "";
			boolean bShowDescription = (false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_FOLD_DESC_NONE,strDescType));

		
					
			if(bSubFoldersFromSearch)
			{
				int nMappedIndex = dirModel.GetFolderSearchMapping(nIndexRef);
				srFolders = dirModel.GetFolderSearchResponse();
				nTotalFolderCount = dirModel.GetSubFolderCount();
				nFolderID	   = srFolders.GetFieldsAsInt(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
				strFolderName  = XPHttpUtility.HtmlEncode(srFolders.GetFieldsAsString(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME));
				dtCreatedDate  = SearchResultModel.ConvertSearchDateTimeToXPDateTime(
            						srFolders.GetFieldsAsDouble(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED));

				if (bShowDescription)
				{
					strDesc = XPHttpUtility.HtmlEncode(srFolders.GetFieldsAsString(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY));
				}
			}
			else
			{
				qrFolders = dirModel.GetFolderQueryResult();
				nTotalFolderCount = qrFolders.GetCount();
				nFolderID	   = XPConvert.ToInteger(qrFolders.GetFields(nIndexRef,
									PT_PROPIDS.PT_PROPID_OBJECTID));			
				strFolderName = XPHttpUtility.HtmlEncode((String) qrFolders.GetFields(
									nIndexRef, PT_PROPIDS.PT_PROPID_NAME));
				strDescription = XPHttpUtility.HtmlEncode((String) qrFolders.GetFields(
						nIndexRef, PT_PROPIDS.PT_PROPID_DESCRIPTION));
				dtCreatedDate = (XPDateTime)qrFolders.GetFields(nIndexRef, PT_PROPIDS.PT_PROPID_CREATED);

				if (bShowDescription)
				{
					strDesc = XPHttpUtility.HtmlEncode((String) qrFolders.GetFields(
								nIndexRef, PT_PROPIDS.PT_PROPID_DESCRIPTION));
				}
			}

			String strFolderID = XPConvert.ToString(nFolderID);

			// folder level in hierarchy
			int nTopFolderLevel = dirModel.GetCurrentFolderLevel();

			if (bShowDescription)
			{
				// abbreviate the description if necessary
				if (true == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_FOLD_DESC_ABBR,strDescType))
				{
					if (null == strDesc)
					{
						strDesc = "";
					}

					if (DirConstants.DESCRIPTION_ABBR_LENGTH < strDesc.length())
					{
						strDesc = strDesc.substring(0,
								DirConstants.DESCRIPTION_ABBR_LENGTH) + "...";
					}
				}
			}

			String strOptArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" +
				XPConvert.ToString(((DirModel) model).GetDirectoryMode());

			// Open folder URL
			String strOpenFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID
				(PT_CLASSIDS.PT_CATALOGFOLDER_ID, nFolderID, strFolderName,
				IPTOpenerConstants.OPENER_MODE_VIEW, space,
				space.GetName(), space.GetSpaceID(), strOptArgs);

			// Edit folder URL
			String strEditFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID
				(PT_CLASSIDS.PT_CATALOGFOLDER_ID, nFolderID, strFolderName,
				IPTOpenerConstants.OPENER_MODE_EDIT, space);

			// use an anchor contruct, to seperately set the title, description
			// on the list item, before using a list item
			
			HTMLAnchor topAnchor = new HTMLAnchor(strOpenFolderURL);
			topAnchor.AddInnerHTMLString(strFolderName);
			//topAnchor.AddInnerHTMLEncodedString(strFolderName);
			topAnchor.SetTitle(strDescription);
			
			UIListItem itemConstruct = new UIListItem(topAnchor, space);
			itemConstruct.SetTitleStyleClass(PTStyleClass.LIST_SUBTITLE);

			if(PT_INTRINSICS.PT_FOLDER_UNCLASSIFIEDCARDS != nFolderID)
			{
				itemConstruct.SetNew(dirModel.GetObjectNewTagDate().Before(dtCreatedDate));
			}

			if ((false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_FOLD_DESC_NONE,strDescType)) && (null != strDesc) && (0 != strDesc.length()))
			{
				itemConstruct.SetDescription(strDesc);
			}
			
			itemConstruct.SetItemTypeImage(
			            PTImageType.ICON_FOLDER, 
			            space.GetString(565, "ptmsgs_portalbrowsingmsgs"));

			itemConstruct.SetCellHeight("20");

			// alternating gray and white rows
			int nDirMode = dirModel.GetDirectoryMode();

			switch (nDirMode)
			{
			case DirConstants.DISABILITY_MODE:
			case DirConstants.EDIT_MODE:
				itemConstruct.SetRowStyleClass(((nIndexRef % 2) == 1)
					? PTStyleClass.LIST_ITEM_ONE_BG
					: PTStyleClass.LIST_ITEM_TWO_BG);

				break;

			case DirConstants.BROWSE_MODE:default:
				itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

				break;
			}

			itemConstruct.SetMaxNumSubLinksDisplayed(dirModel.GetNumSubSubFoldersToDisplay());

			nIndexRef++;

			// Show checkbox and pencil icon in Edit Mode
			if (nDirMode == DirConstants.EDIT_MODE)
			{
				if(PT_INTRINSICS.PT_FOLDER_UNCLASSIFIEDCARDS == nFolderID)
				{
					itemConstruct.SetItemEditButton(PTImageType.ICON_EDIT_DISABLED, "", null);
				}
				else
				{
					itemConstruct.SetItemEditButton(PTImageType.ICON_EDIT, space.GetString(1652,
						"ptmsgs_portalbrowsingmsgs"), strEditFolderURL);
					HTMLAnchor anchor = itemConstruct.GetEditAnchor();
					anchor.SetTitle(space.GetString(1652, "ptmsgs_portalbrowsingmsgs"));
				}

				itemConstruct.EnableCheckbox(QS_CHECKBOX, strFolderID,
					strFolderID, model.GetIsFolderSelected(nFolderID)); //to do: specify value
			}

			// Display links to sub-subfolders in Browse Mode
			else if (nDirMode == DirConstants.BROWSE_MODE)
			{
				int nStartIndexRef   = nIndexRef;
				int nThisFolderLevel;

				int nSubSubFolderCount = 0;

				while (nIndexRef < nTotalFolderCount)
				{
					nSubSubFolderCount++;

					// if there are too many subsubfolders to display, skip over them
					if (nIndexRef > (nStartIndexRef +
							dirModel.GetNumSubSubFoldersToDisplay()))
					{
						if(bSubFoldersFromSearch)
						{
							int nMappedIndex = dirModel.GetFolderSearchMapping(nIndexRef);
							nThisFolderLevel = srFolders.GetFieldsAsInt(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
						}
						else
						{
							nThisFolderLevel = XPConvert.ToInteger(qrFolders.GetFields(nIndexRef,
									PT_PROPIDS.PT_PROPID_FOLDER_LEVEL));
						}

						boolean bSkippedFolders = false;
						while (((nTopFolderLevel + 2) == nThisFolderLevel) &&
								(nIndexRef < (nTotalFolderCount - 1)))
						{
							nIndexRef++;
							nSubSubFolderCount++;

							if(bSubFoldersFromSearch)
							{
								int nMappedIndex = dirModel.GetFolderSearchMapping(nIndexRef);
								nThisFolderLevel = srFolders.GetFieldsAsInt(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
							}
							else
							{
								nThisFolderLevel = XPConvert.ToInteger(qrFolders.GetFields(nIndexRef,
										PT_PROPIDS.PT_PROPID_FOLDER_LEVEL));
							}

							bSkippedFolders = true;
						}

						// Important: If we entered the while loop above, we need to back up the index to the last subsubfolder
						if(bSkippedFolders)
						{
							nIndexRef--;
						}
					}

					// break out of loop if the folder is not one level deeper than the top folder
					if(bSubFoldersFromSearch)
					{
						int nMappedIndex = dirModel.GetFolderSearchMapping(nIndexRef);
						nThisFolderLevel = srFolders.GetFieldsAsInt(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_FOLDERLEVEL);
					}
					else
					{
						nThisFolderLevel = XPConvert.ToInteger(qrFolders.GetFields(nIndexRef,
								PT_PROPIDS.PT_PROPID_FOLDER_LEVEL));
					}

					if ((nTopFolderLevel + 2) != nThisFolderLevel)
					{
						break;
					}

					// get sub-subfolder ids
					if(bSubFoldersFromSearch)
					{
						int nMappedIndex = dirModel.GetFolderSearchMapping(nIndexRef);
						nFolderID = srFolders.GetFieldsAsInt(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTID);
					}
					else
					{
						nFolderID	    = XPConvert.ToInteger(qrFolders.GetFields(nIndexRef,
								PT_PROPIDS.PT_PROPID_OBJECTID));
					}

					strFolderID     = XPConvert.ToString(nFolderID);

					// folder name
					String strSubFolderName = null;
					if(bSubFoldersFromSearch)
					{
						int nMappedIndex = dirModel.GetFolderSearchMapping(nIndexRef);
						strSubFolderName = srFolders.GetFieldsAsString(nMappedIndex, PT_INTRINSICS.PT_PROPERTY_OBJECTNAME);
					}
					else
					{
						strSubFolderName     = XPHttpUtility.HtmlEncode((String) qrFolders.GetFields(
									nIndexRef, PT_PROPIDS.PT_PROPID_NAME));
					}

					//construct sub-subfolder URL
					strOptArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" +
						XPConvert.ToString(((DirModel) model).GetDirectoryMode());

					// Open subfolder URL
					String strOpenSubFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID
						(PT_CLASSIDS.PT_CATALOGFOLDER_ID, nFolderID, strSubFolderName,
						IPTOpenerConstants.OPENER_MODE_VIEW, space,
						space.GetName(), space.GetSpaceID(), strOptArgs);

					HTMLAnchor a = new HTMLAnchor(strOpenSubFolderURL);
					a.AddInnerHTMLString(strSubFolderName);

					itemConstruct.AddSubLink(a, false, false);

					//increment to the next folder
					nIndexRef++;
				}

				// SCC: for now, this feature will not be implemented because of confusion
				//      caused by the renaming alrogithm used when creating objects.  Duplicate
				//      objects have the same "(x)" appended to the name.
//				if(1 < nSubSubFolderCount)
//				{
//					strFolderName = strFolderName + " (" + nSubSubFolderCount + ")";
//					itemConstruct.SetTitle(strFolderName, strOpenFolderURL);
//				}
			}

			// convert the construct to table
			try
			{
				HTMLTable folderTable = itemConstruct.GetItemAsTable();

				folderTable.SetCellPadding("0");

				folderTable.SetCellSpacing("2");
				tableCell.AddInnerHTMLElement(folderTable);
			}
			catch (HTMLException e)
			{
				
					log.Error(e, "DirFolderViewHelper.DisplayFolder: HTML Exception");
				
			}
		}
		catch (Exception e)
		{
			log.Error(e, "Couldn't retrieve folder data at index " + nIndexRef +
				", check that the query is valid");
		}

		return nIndexRef;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID, IFolderModelRO _model, AActivitySpace _space)
	{
		// Note: I don't believe this method is actually used.

		String strOptArgs = "&" + DirConstants.QS_DIRECTORY_MODE + "=" +
			XPConvert.ToString(((DirModel) _model).GetDirectoryMode());

		// Open folder URL
		String strOpenFolderURL = PTOpenerLinks.GetOpenerURLOpenObjID
			(PT_CLASSIDS.PT_CATALOGFOLDER_ID, _nFolderID,
			IPTOpenerConstants.OPENER_MODE_VIEW, _space,
		_space.GetName(), _space.GetSpaceID(), strOptArgs);

		_anchor.SetHRef(strOpenFolderURL);
	}
}