package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.documentsubmitsimple.*;
import com.plumtree.portalpages.browsing.directory.edit.*;
import com.plumtree.portalpages.browsing.editors.directory.submit_D.*;
import com.plumtree.portalpages.browsing.editors.folder.*;
import com.plumtree.portalpages.browsing.editors.multipledocumentlinksettings.*;
import com.plumtree.portalpages.common.createfolder.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author StephenC
 *
 */
public class DirRepostControl extends RepostControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.DirRepostControl");

	
	public static final String STR_MVC_CLASS_NAME = "DirRepost";
	private static final String m_sBaseCardSubmitASName = "CardSubmitAdvanced";

	/**
	 * This is used by the portlet/layout based submit to KD HTML to set the
	 * folder to submit the new document into.
	 */
	public static final String CARD_SUBMIT_FOLDER_OVERRIDE = "folderID";
	
	public static final int POSTTOSELF_ACTION_CREATEFOLDER				  = 11;
	public static final int POSTTOSELF_ACTION_EDIT						  = 12;
	public static final int POSTTOSELF_ACTION_MOVE						  = 13;
	public static final int POSTTOSELF_ACTION_COPY						  = 14;
	public static final int POSTTOSELF_ACTION_RENAME					  = 15;
	public static final int POSTTOSELF_ACTION_DELETE					  = 16;
	public static final int POSTTOSELF_ACTION_EDITSECURITY				  = 17;
	public static final int POSTTOSELF_ACTION_APPROVE					  = 19;
	public static final int POSTTOSELF_ACTION_UNAPPROVE					  = 20;
	public static final int POSTTOSELF_ACTION_LINKSETTINGS				  = 21;
	public static final int POSTTOSELF_ACTION_SELECT					  = 22;
	public static final int POSTTOSELF_ACTION_CARDSUBMITSIMPLE_MAIN		  = 23;
	public static final int POSTTOSELF_ACTION_CARDSUBMITSIMPLE_UPLOAD	  = 24;
	public static final int POSTTOSELF_ACTION_CARDSUBMITSIMPLE_WS_UPLOAD  = 36;
	public static final int POSTTOSELF_ACTION_CARDSUBMITSIMPLE_SUBMITMORE = 35;
	public static final int POSTTOSELF_ACTION_CARDSUBMITADVANCED		  = 26;
	public static final int POSTTOSELF_ACTION_CARDSUBMIT508_DATASOURCE	  = 37;
	public static final int POSTTOSELF_ACTION_CARDSUBMIT508_SUBMIT_DS	  = 38;
	
	// this value is used in the file upload service. do not change
	// unless you change file upload as well.
	public static final int POSTTOSELF_ACTION_CARDSUBMIT508_SUBMIT		  = 27;
	public static final int POSTTOSELF_ACTION_CARDSUBMIT508_CANCEL		  = 28;
	public static final int POSTTOSELF_ACTION_SELFSELECTEXPERTS			  = 29;
	public static final int POSTTOSELF_ACTION_EDITCARDPROPERTIES		  = 30;
	public static final int POSTTOSELF_ACTION_CARDSIMPLESUBMIT_CHANGED_DS = 31;
	public static final int POSTTOSELF_ACTION_GOTO_RANGE				  = 32;
	public static final int POSTTOSELF_ACTION_DELETE_LATER				  = 33;
	public static final int POSTTOSELF_ACTION_MIGRATE					  = 34;

	private DirModel m_dirModel;

	/**
	 * 
	 *
	 * @param arObjectIDs 
	 *
	 * @return 
	 */
	public String BuildCommaDelimitedList(int[] arObjectIDs)
	{
		String strObjectIDList = "";

		if (null == arObjectIDs)
		{
			return strObjectIDList;
		}

		int nNumObjects = arObjectIDs.length;

		for (int i = 0; i < nNumObjects; i++)
		{
			int nObjectID = arObjectIDs[i];

			strObjectIDList += nObjectID;

			// No comma if only one object or if this is the last object
			if ((1 != nNumObjects) && (i != (nNumObjects - 1)))
			{
				strObjectIDList += ",";
			}
		}

		return strObjectIDList;
	} 

	/**
	 * This ovverrides the implementation from RepostControl for certain actions
	 * @return Redirect
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String sDataKey;
		String[] aDataValue;

		// Needed for Number of Cards per Page
		sDataKey	= DirConstants.QS_PER_PAGE;
		aDataValue	= (String[]) arguments.GetElement(sDataKey);
		if(aDataValue != null)
		{
			log.Info("Setting Number of Cards Per Page");
			
			int nperPage = XPConvert.ToInteger(aDataValue[0]);
			m_dirModel.SetNumDocsPerPage(nperPage);

			m_dirModel.ClearCardRange();
			m_dirModel.LoadFoldersAndDocuments();

		}
		
		// Needed for Document Type Filter
		sDataKey = DirConstants.QS_DOCUMENT_TYPEID;
		aDataValue = (String[]) arguments.GetElement(sDataKey);
		if(aDataValue != null)
		{
			String strDocType = aDataValue[0];
			log.Info("Setting Document Type Filter to Document Type: " + strDocType);
			m_dirModel.SetDocumentTypeId(strDocType);
			
			m_dirModel.ClearCardRange();
			m_dirModel.LoadFoldersAndDocuments();
		}
		
		// Needed for Advanced Card Creation
		sDataKey	   = DirConstants.QS_ADVANCED_CARDID;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Info("ADVANCED CARD CREATION");

			int nCardID = XPConvert.ToInteger(aDataValue[0]);

			m_dirModel.SetCardID(nCardID);

			Redirect repostURL = new Redirect();
			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetDisplayPage(DirAS.CARDSUBMIT_ADVANCED_CONFIM_POPUP);
			SetRedirect(repostURL);

			return repostURL;
		}

		// Needed for Card Properties Popup: Edit Card Properties
		sDataKey     = DirConstants.QS_CARDID;
		aDataValue = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Info("CARD PROPERTIES POPUP");	

			int nCardID = XPConvert.ToInteger(aDataValue[0]);

			m_dirModel.SetCardID(nCardID);
			m_dirModel.StartCardKeywords(nCardID);

			return null;
		}

		// Needed for Sort By
		sDataKey	   = DirConstants.QS_SORTBY;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			int nSortByPropID = XPConvert.ToInteger(aDataValue[0]);

			log.Info("SORTBY " + nSortByPropID);

			m_dirModel.SetSortByPropID(nSortByPropID);

			m_dirModel.ClearCardRange();
			m_dirModel.LoadFoldersAndDocuments();

			return null;
		}

		// Needed for Card Properties Popup: More Folders Like This
		sDataKey	   = DirConstants.QS_MOREFOLDERID;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			int nMoreFolderID = XPConvert.ToInteger(aDataValue[0]);

			m_dirModel.SetMoreFolderID(nMoreFolderID);

			log.Info("CARDPROPERTIES: MORE LIKE THIS");

			Redirect repostURL = new Redirect();
			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetDisplayPage(DirAS.CARDPROPERTIES_MOREDOCS_POPUP);
			SetRedirect(repostURL);

			return repostURL;
		}

		// Needed for More Related Resources Popup
		sDataKey	   = DirConstants.QS_RRCATEGORY;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			int nCategoryID = XPConvert.ToInteger(aDataValue[0]);

			m_dirModel.SetRRCategory(nCategoryID);

			sDataKey	   = OpenDirFolderControl.m_SubFolderID;
			aDataValue     = (String[]) arguments.GetElement(sDataKey);

			if (aDataValue != null)
			{ // rr popup

				int nSubFolderID = XPConvert.ToInteger(aDataValue[0]);

				// scc: this is important in case the user clicked the back button.  
				m_dirModel.m_nCurrentFolderID = nSubFolderID;
			}

			m_dirModel.LoadFoldersAndDocuments();

			// Needed for More Related Resources Popup
			sDataKey	   = DirConstants.QS_RROBJECTID;
			aDataValue     = (String[]) arguments.GetElement(sDataKey);

			if (aDataValue != null)
			{ // click through

				int nObjectID = XPConvert.ToInteger(aDataValue[0]);

				m_dirModel.SetRRObjectID(nObjectID);

				log.Info("RR CLICKTHROUGH");

				Redirect repostURL = new Redirect();
				repostURL.SetLinkGetCachedSpace(m_asOwner);
				repostURL.SetDisplayPage(DirAS.MORE_RELATEDRESOURCES_POPUP);
				SetRedirect(repostURL);

				return repostURL;
			}

			return null;
		}

		// Needed for Card pagination
		sDataKey	   = DirConstants.QS_RANGE_FROM;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			int nFromRange = XPConvert.ToInteger(aDataValue[0]);

			// Needed for Card pagination in 508 (TO field)
			sDataKey	   = DirConstants.QS_RANGE_TO;
			aDataValue     = (String[]) arguments.GetElement(sDataKey);

			if (aDataValue != null)
			{
				int nToRange = XPConvert.ToInteger(aDataValue[0]);

				// Set the folderID and mode 
				int nFolderID = m_dirModel.GetCurrentFolderID();
				int nDirMode = m_dirModel.GetDirectoryMode();
					
				// dir mode
				sDataKey	   = DirConstants.QS_DIRECTORY_MODE;
				aDataValue     = (String[]) arguments.GetElement(sDataKey);
			
				if (aDataValue != null)
				{
					nDirMode = XPConvert.ToInteger(aDataValue[0]);
				}
				
				// dir folder
				sDataKey	   = OpenDirFolderControl.m_SubFolderID;
				aDataValue     = (String[]) arguments.GetElement(sDataKey);
			
				if (aDataValue != null)
				{
					nFolderID = XPConvert.ToInteger(aDataValue[0]);
				}
				
				m_dirModel.SetFolderIDAndMode(nFolderID, nDirMode);
				m_dirModel.SetCardRange(nFromRange, nToRange);
				m_dirModel.LoadFoldersAndDocuments();
				return null;
			}
			else
			{
				log.Error("could not find the TO range value in query string.");
			}
		}

		// Needed for Self-Selecting Experts in 508
		sDataKey	   = DirConstants.QS_SELFSELECT_EXPERT;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Info("SELF_SELECT EXPERT 508");

			PerformAction(POSTTOSELF_ACTION_SELFSELECTEXPERTS);

			return null;
		}

		
		// Needed for Deletion in 508
		if (DirConstants.DISABILITY_MODE==m_dirModel.GetDirectoryMode())
		{
			sDataKey	   = DirConstants.QS_508_DELETE;
			aDataValue     = (String[]) arguments.GetElement(sDataKey);
	
			if (aDataValue != null)
			{
				
				log.Info("508 Card Deletion");
				
				m_htFormData = arguments;
				PerformAction(POSTTOSELF_ACTION_DELETE);
	
				return null;
			}
		}

		
		// Needed for Create Folder
		sDataKey	   = CreateFolderDP.QS_PARENT_FOLDER;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Info("CREATE FOLDER PARENT");

			int nFolderID = XPConvert.ToInteger(aDataValue[0]);
			m_dirModel.SetFolderIDAndMode(nFolderID, m_dirModel.GetDirectoryMode());

			return null;
		}

		
		// doc upload error
		sDataKey  	   = DirConstants.QS_RETURN_UPLOAD_ERROR;
		aDataValue	   = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Error("CARDSUBMITSIMPLE WebService Upload Error");

			/* TODO: this is such a hack.  we need to figure out a better way
			 * to catch this.  
			 * 
			 * when a 508 user tries to repost out of a submit, the form has
			 * already been set to go to the upload ws, thus, it will error
			 * out sending back the posttoself action.
			 */
			if (XPStringUtility.EqualsIgnoreCase(aDataValue[0],
			        RepostControl.HTMLSUBMIT_508_POSTTOSELF +
					DirRepostControl.POSTTOSELF_ACTION_CARDSUBMIT508_DATASOURCE))
			{
				m_htFormData = arguments;
				PerformAction(POSTTOSELF_ACTION_CARDSUBMIT508_DATASOURCE);
				m_rRedirect.SetIsHTTPRedirect(true);
				return m_rRedirect;
			}
			
			if (XPStringUtility.EqualsIgnoreCase(aDataValue[0],
			        RepostControl.HTMLSUBMIT_508_POSTTOSELF +
					DirRepostControl.POSTTOSELF_ACTION_CARDSUBMIT508_CANCEL))
			{
				m_htFormData = arguments;
				PerformAction(POSTTOSELF_ACTION_CARDSUBMIT508_CANCEL);
				m_rRedirect.SetIsHTTPRedirect(true);
				return m_rRedirect;
			}

			
			/* normal (or rather, abnormal) error */
			UIError myError = new UIError(
				UIErrorLevel.FRIENDLY,		
				UIErrorScope.CURRENT_USER,
				aDataValue[0], 
				"Error From Document Upload Web Service");
			
			UIErrorHandler.RaiseError(
				myError, 
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());


			Redirect repostURL = new Redirect();
			if (DirConstants.DISABILITY_MODE!=m_dirModel.GetDirectoryMode())
			{
				repostURL.SetLinkGetCachedSpace(m_asOwner);
				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			}
			else
			{
				//Return to dir
				repostURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
				repostURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
				repostURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
					((IDirModelRO) m_dirModel).GetDirectoryMode());
				repostURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
					XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));
				repostURL.SetIsHTTPRedirect(true);
			}

			return repostURL;
		}
		
		
		// Needed for doc uploading
		sDataKey	   = DirConstants.QS_RETURN_UPLOAD_PATH;
		aDataValue     = (String[]) arguments.GetElement(sDataKey);

		if (aDataValue != null)
		{
			log.Info("CARDSUBMITSIMPLE WebService Upload");
			
			/* m_htFormData not set? */			
			m_htFormData = arguments;
			PerformAction(POSTTOSELF_ACTION_CARDSUBMITSIMPLE_WS_UPLOAD);
			// for 508, do a true http request in case the user tries to refresh page
			if (DirConstants.DISABILITY_MODE==m_dirModel.GetDirectoryMode())
			    m_rRedirect.SetIsHTTPRedirect(true);
			
			return m_rRedirect;
		}

		return super.CheckActionSecurityAndExecute(arguments);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirRepostControl();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int[] GetCheckedCards()
	{
		// get the checkboxes
		String sDataKey     = EditDocViewHelper.QS_CHECKBOX;
		String[] aDataValue = (String[]) m_htFormData.GetElement(sDataKey);

		if (aDataValue != null)
		{
			int nNumCheckedCards = aDataValue.length;
			int[] arCheckedCards = new int[nNumCheckedCards];

			for (int i = 0; i < nNumCheckedCards; i++)
			{
				int nCardID = XPConvert.ToInteger(aDataValue[i]);

				arCheckedCards[i] = nCardID;
			}

			return arCheckedCards;
		}
		else
		{
			return null;
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int[] GetCheckedFolders()
	{
		// get the checkboxes
		String sDataKey     = DirFolderViewHelper.QS_CHECKBOX;
		String[] aDataValue = (String[]) m_htFormData.GetElement(sDataKey);

		if (aDataValue != null)
		{
			int nNumCheckedFolders = aDataValue.length;
			int[] arCheckedFolders = new int[nNumCheckedFolders];

			for (int i = 0; i < nNumCheckedFolders; i++)
			{
				int nCardID = XPConvert.ToInteger(aDataValue[i]);

				arCheckedFolders[i] = nCardID;
			}

			return arCheckedFolders;
		}
		else
		{
			return null;
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		super.Init(model, space);
		m_dirModel     = (DirModel) model;
		m_asOwner	   = space;
	}

	/**
	 * Performs repost actions.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		String[] sValues;

		Redirect repostURL = new Redirect();

		String strCheckedCards   = "";
		int[] arCheckedCards     = null;
		String strCheckedFolders = "";
		int[] arCheckedFolders   = null;

		// Retrieve Checked Cards
		if ((_nAction == POSTTOSELF_ACTION_APPROVE) ||
				(_nAction == POSTTOSELF_ACTION_UNAPPROVE) ||
				(_nAction == POSTTOSELF_ACTION_LINKSETTINGS) ||
				(_nAction == POSTTOSELF_ACTION_MOVE) ||
				(_nAction == POSTTOSELF_ACTION_COPY) ||
				(_nAction == POSTTOSELF_ACTION_DELETE) ||
				(_nAction == POSTTOSELF_ACTION_MIGRATE) ||
				(_nAction == POSTTOSELF_ACTION_DELETE_LATER) ||
				(_nAction == POSTTOSELF_ACTION_EDITSECURITY))
		{
			arCheckedCards	    = GetCheckedCards();
			strCheckedCards     = BuildCommaDelimitedList(arCheckedCards);

			if ("".equals(strCheckedCards) &&
					((_nAction == POSTTOSELF_ACTION_APPROVE) ||
					(_nAction == POSTTOSELF_ACTION_UNAPPROVE) ||
					(_nAction == POSTTOSELF_ACTION_LINKSETTINGS)))
			{
				
					log.Warn("DirRepostControl::PerformAction No cards have been selected.");
				

				return;
			}
		}

		// Retrieve Checked Folders
		if ((_nAction == POSTTOSELF_ACTION_MOVE) ||
				(_nAction == POSTTOSELF_ACTION_COPY) ||
				(_nAction == POSTTOSELF_ACTION_DELETE) ||
				(_nAction == POSTTOSELF_ACTION_MIGRATE) ||
				(_nAction == POSTTOSELF_ACTION_DELETE_LATER) ||
				(_nAction == POSTTOSELF_ACTION_EDITSECURITY))
		{
			arCheckedFolders	  = GetCheckedFolders();
			strCheckedFolders     = BuildCommaDelimitedList(arCheckedFolders);
		}

		// Warn if both cards and folders are not selected
		if ("".equals(strCheckedCards) && "".equals(strCheckedFolders) &&
				((_nAction == POSTTOSELF_ACTION_MOVE) ||
				(_nAction == POSTTOSELF_ACTION_COPY) ||
				(_nAction == POSTTOSELF_ACTION_DELETE) ||
				(_nAction == POSTTOSELF_ACTION_MIGRATE) ||
				(_nAction == POSTTOSELF_ACTION_EDITSECURITY)))
		{
			
				log.Warn("DirRepostControl::PerformAction No cards or folders have been selected.");
			

			return;
		}

		String strElementKey;

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_CREATEFOLDER:
			
				log.Info("CREATEFOLDER");
			
			repostURL.SetLinkGetCachedSpace(m_asOwner);

			// Name
			sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERNAME);

			if (sValues == null)
			{
				
					log.Error("could not find folder name in query string.");
				

				//Refresh the directory page and close popup
				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}

			String strName = sValues[0];

			// Description
			sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERDESCRIPTION);

			if (sValues == null)
			{
				
					log.Error("could not find folder description in query string.");
				

				//Refresh the directory page and close popup
				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}

			String strDesc = sValues[0];

			try
			{
				m_dirModel.CreateDirectoryFolder(strName, strDesc);
			}
			catch (Exception e)
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						
					UIErrorScope.CURRENT_USER, null,
						m_asOwner.GetString(158, "ptmsgs_portalbrowsingmsgs"),
						e.getMessage());
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}

			// successful creation

			repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);
			return;

		case POSTTOSELF_ACTION_EDIT:
			
				log.Info("EDIT");
			
			repostURL.SetLinkCreateNewSpace(FolderEditorAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			repostURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			repostURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			repostURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
			repostURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
				XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_MOVE:
			
				log.Info("MOVE");
			

			int nMoveTargetFolder = ((IDirModelRO) m_dirModel).RefreshItemFromMoveTargetFolderTree();

			if (null != arCheckedCards)
			{
				m_dirModel.MoveCards(arCheckedCards, nMoveTargetFolder);
			}

			if (null != arCheckedFolders)
			{
				m_dirModel.MoveFolders(arCheckedFolders, nMoveTargetFolder);
			}

			break;

		case POSTTOSELF_ACTION_COPY:
			
				log.Info("COPY");
			

			int nCopyTargetFolder = ((IDirModelRO) m_dirModel).RefreshItemFromCopyTargetFolderTree();

			if (null != arCheckedCards)
			{
				m_dirModel.CopyCards(arCheckedCards, nCopyTargetFolder);
			}

			if (null != arCheckedFolders)
			{
				m_dirModel.CopyFolders(arCheckedFolders, nCopyTargetFolder);
			}

			break;

		case POSTTOSELF_ACTION_RENAME:
			
				log.Info("RENAME");
			

			break;

		case POSTTOSELF_ACTION_DELETE:
			
				log.Info("DELETE");
			

			if (null != arCheckedCards)
			{
				m_dirModel.DeleteCards(arCheckedCards);
				m_dirModel.ClearCardRange();
			}

			if (null != arCheckedFolders)
			{
				m_dirModel.DeleteFolders(arCheckedFolders);
			}

			break;

		case POSTTOSELF_ACTION_MIGRATE:
			
				log.Info("MIGRATE");
			

			String strComment;
			sValues = (String[]) m_htFormData.GetElement(FolderBannerView.HTML_INPUT_COMMENT);

			if (sValues != null)
			{
				strComment = sValues[0];
			}
			else
			{
				strComment = "";
			}

			if (null != arCheckedCards)
			{
				m_dirModel.MigrateObjects(PT_CLASSIDS.PT_CATALOGCARD_ID, arCheckedCards, strComment);
			}

			if (null != arCheckedFolders)
			{
				m_dirModel.MigrateObjects(PT_CLASSIDS.PT_CATALOGFOLDER_ID, arCheckedFolders, strComment);
			}

			break;

		case POSTTOSELF_ACTION_APPROVE:
			
				log.Info("APPROVE");
			
			m_dirModel.doApproval(arCheckedCards, PT_CARDREF_STATES.PT_APPROVED);

			break;

		case POSTTOSELF_ACTION_UNAPPROVE:
			
				log.Info("UNAPPROVE");
			
			m_dirModel.doApproval(arCheckedCards,
				PT_CARDREF_STATES.PT_PENDING_APPROVAL);

			break;

		case POSTTOSELF_ACTION_LINKSETTINGS:
			
				log.Info("LINKSETTINGS");
			
			repostURL.SetLinkCreateNewSpace(MultipleCardLinkSettingsAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			repostURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			repostURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			repostURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
				XPConvert.ToString(arCheckedCards[0]));
			repostURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
			repostURL.AddControlArgument(MultipleCardLinkSettingsModel.QS_CARD_IDS,
				strCheckedCards);
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_SELECT:
			
				log.Info("SELECT");
			

			break;
		case POSTTOSELF_ACTION_CARDSUBMITSIMPLE_MAIN:
			
			log.Info("CARDSUBMITSIMPLE_MAIN");
			
			m_dirModel.SetCardSubmitMode(DirConstants.CARDSUBMITMODE_UPLOADING);

			String strURL;
			int nSimpleDataSourceID = 0;
			String strCardName		  = null;
			String strCardDescription = null;

			repostURL.SetLinkGetCachedSpace(m_asOwner);

			// DataSource
			sValues = (String[]) m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLSELECT_CardDataSource);

			if (sValues == null)
			{
				log.Error("could not find card datasource in query string for simple card submit.");

				//Refresh the directory page and close popup
				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}
			else
			{
				nSimpleDataSourceID = XPConvert.ToInteger(sValues[0]);
				m_dirModel.SetCardSubmitDataSource(nSimpleDataSourceID);
			}

			strElementKey = DirCardSubmitSimpleView.HTMLINPUT_CardPath;

			// URL
			sValues = (String[]) m_htFormData.GetElement(strElementKey);

			if (sValues == null)
			{
				log.Error("could not find card URL in query string.");

				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}
			else
			{
				strURL = sValues[0];
				m_dirModel.SetCardSubmitURL(strURL);
			}

			// Name
			sValues = (String[]) m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLCHECKBOX_SUPPLYNAME);

			if ((null != sValues) && !(0 == sValues.length))
			{
				sValues = (String[]) m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLINPUT_CARDNAME);

				if (sValues != null)
				{
					strCardName = sValues[0];
					m_dirModel.SetCardSubmitName(strCardName);
				}
			}

			// Description
			sValues = (String[]) m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLCHECKBOX_SUPPLYDESCRIPTION);

			if ((null != sValues) && !(0 == sValues.length))
			{
				sValues = (String[]) m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLINPUT_CARDDESCRIPTION);

				if (sValues != null)
				{
					strCardDescription = sValues[0];
					m_dirModel.SetCardSubmitDescription(strCardDescription);
				}
			}
			
			repostURL.SetDisplayPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);

			break;

		case POSTTOSELF_ACTION_CARDSUBMITSIMPLE_UPLOAD:

			log.Info("CARDSUBMITSIMPLE_UPLOAD");

			repostURL.SetLinkGetCachedSpace(m_asOwner);

			try
			{
				// Call SubmitCard with the parameters already stored on the model
				m_dirModel.SubmitCard();
				m_dirModel.SetDefaultCardRefreshSettings(m_dirModel.GetCardID());

				// check for errors, if some were raised, then close the popup and return
				if (UIErrorHandler.GetErrors(m_asOwner.GetSubSession(),m_asOwner.GetApplication(), m_asOwner, true, true).MoveNext())
				{
					repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
					SetRedirect(repostURL);

					return;					
				}
			}
			catch (Exception e)
			{
				log.Error(e, STR_MVC_CLASS_NAME + "::PerformAction An error occured when trying to submit a card.");

				UIError myError = new UIError(UIErrorLevel.FRIENDLY,

				UIErrorScope.CURRENT_USER, null,
					m_asOwner.GetString(159, "ptmsgs_portalbrowsingmsgs"),
					e.getMessage());
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}

			repostURL.SetDisplayPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);

			m_dirModel.SetCardSubmitMode(DirConstants.CARDSUBMITMODE_DONE);

			// Reset the To and From (so that the new card will be displayed)
			m_dirModel.ClearCardRange();

			return;

			case POSTTOSELF_ACTION_CARDSUBMITSIMPLE_WS_UPLOAD:

				log.Info("CARDSUBMITSIMPLE_WS_UPLOAD");

				try
				{
					int nDSID = 0;
					String name		  = null;
					String description = null;
					
					// DataSource
					if (DirConstants.DISABILITY_MODE!=m_dirModel.GetDirectoryMode())
					{
						repostURL.SetLinkGetCachedSpace(m_asOwner);
						
						sValues = (String[]) m_htFormData.GetElement(
							DirCardSubmitSimpleView.HTMLSELECT_CardDataSource);
	
						if (sValues == null)
						{
							log.Error("could not find card datasource in query string for ws upload.");
	
							//Refresh the directory page and close popup
							repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
							SetRedirect(repostURL);
	
							return;
						}
						else
						{
							nDSID = XPConvert.ToInteger(sValues[0]);
							m_dirModel.SetCardSubmitDataSource(nDSID);
						}

						// Folder override for KD submit portlet/layout
						sValues = (String[]) m_htFormData.GetElement(CARD_SUBMIT_FOLDER_OVERRIDE);
						if (sValues != null)
						{
							int nFolderID = XPConvert.ToInteger(sValues[0]);
							// This is used to submit a card in this request, and
							// then is cleared.  This is only an override.
							m_dirModel.SetCardSubmitFolder(nFolderID);
						}

						// Name
						sValues = (String[]) m_htFormData.GetElement(
							DirCardSubmitSimpleView.HTMLINPUT_DUCheckName);
	
						if ((null != sValues) && !(0 == sValues.length))
						{
							sValues = (String[]) m_htFormData.GetElement(
								DirCardSubmitSimpleView.HTMLINPUT_CARDNAME);
	
							if (sValues != null)
							{
								name = sValues[0];
								m_dirModel.SetCardSubmitName(name);
							}
						}
	
						// Description
						sValues = (String[]) m_htFormData.GetElement(
							DirCardSubmitSimpleView.HTMLINPUT_DUCheckDesc);
	
						if ((null != sValues) && !(0 == sValues.length))
						{
							sValues = (String[]) m_htFormData.GetElement(
								DirCardSubmitSimpleView.HTMLINPUT_CARDDESCRIPTION);
	
							if (sValues != null)
							{
								description = sValues[0];
								m_dirModel.SetCardSubmitDescription(description);
							}
						}
					}

					else /* for 508 mode */
					{
						nDSID = m_dirModel.GetCardSubmitDataSource();
					}

					// get path, type, and docid needed to submit card
					/* get document upload properties
					 * DUSERVER: This is the document repository server for 
					 * which the card is created 
					 * DUID: This is the ID that corresponds to the document 
					 * on the document repository server
					 */

					String[] path = (String[]) m_htFormData.
						GetElement(DirConstants.QS_RETURN_UPLOAD_PATH);
					
					String[] type = (String[]) m_htFormData.
						GetElement(DirConstants.QS_RETURN_UPLOAD_TYPE);
					
					String[] docID = (String[]) m_htFormData.
						GetElement(DirConstants.QS_RETURN_UPLOAD_DOCID);
						
					String[] duID = (String[]) m_htFormData.
						GetElement(DirConstants.QS_RETURN_UPLOAD_DUID);
					
					String[] duServer = (String[]) m_htFormData.
						GetElement(DirConstants.QS_RETURN_UPLOAD_DUSERVER);

					
					if ( (null == path || ("").equals(path[0])) ||
						 (null == type || ("").equals(type[0])) ||
						 (null == docID || ("").equals(docID[0])) || 
						 (null == duID || ("").equals(duID[0])) || 
						 (null == duServer || ("").equals(duServer[0])))
					{
						log.Error(STR_MVC_CLASS_NAME +
							"::PerformAction The following error occured when trying to submit a card: upload parameters empty");

						if (DirConstants.DISABILITY_MODE!=m_dirModel.GetDirectoryMode())
						{
							UIError myError = new UIError(UIErrorLevel.FRIENDLY,						
								UIErrorScope.CURRENT_USER, null,
								m_asOwner.GetString(159, "ptmsgs_portalbrowsingmsgs"));
							
							UIErrorHandler.RaiseError(myError, 
								m_asOwner.GetSubSession(), m_asOwner.GetApplication());
	
							repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
							SetRedirect(repostURL);
						}
						else
						{
						    SetErrorAndRedirectToDir508();
						}
						
						return;
					}

					m_dirModel.SetCardSubmitURL(path[0]);
					m_dirModel.SetDocUploadParams(duID[0], duServer[0]);
					m_dirModel.SubmitCard(path[0], type[0], docID[0]);
//					m_dirModel.UpdatePropertiesForDocUpload(duID[0], duServer[0]);
					m_dirModel.SetDefaultCardRefreshSettings(m_dirModel.GetCardID());
					
					// check for errors, if some were raised, then close the popup 
					// and return
					if (UIErrorHandler.GetErrors(m_asOwner.GetSubSession(),m_asOwner.GetApplication(), m_asOwner, true, true).MoveNext())
					{
						repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
						SetRedirect(repostURL);

						return;					
					}
				}
				catch (Exception e)
				{
					log.Error(e, STR_MVC_CLASS_NAME +
						"::PerformAction An error occured when trying to submit a card");

					if (DirConstants.DISABILITY_MODE!=m_dirModel.GetDirectoryMode())
					{
						UIError myError = new UIError(UIErrorLevel.FRIENDLY,
							UIErrorScope.CURRENT_USER, null,
							m_asOwner.GetString(159, "ptmsgs_portalbrowsingmsgs"),
							e.getMessage());
						UIErrorHandler.RaiseError(myError, 
							m_asOwner.GetSubSession(), m_asOwner.GetApplication());

						repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
						SetRedirect(repostURL);
					}
					else
					{
					    SetErrorAndRedirectToDir508();
					}
					
					return;
				}

				if (DirConstants.DISABILITY_MODE!=m_dirModel.GetDirectoryMode())
				{
					repostURL.SetDisplayPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
					m_dirModel.SetCardSubmitMode(DirConstants.CARDSUBMITMODE_DONE);
				}
				else
				{
					repostURL.SetLinkGetSpaceIfCached(DirSubmitAS_D.STR_MVC_CLASS_NAME,m_asOwner);
					repostURL.SetDisplayPage(DirSubmitDoneDP_D.STR_MVC_CLASS_NAME);
				}
				
				// Reset the To and From (so that the new card will be displayed)
				m_dirModel.ClearCardRange();

				SetRedirect(repostURL);

				return;

		case POSTTOSELF_ACTION_CARDSUBMITSIMPLE_SUBMITMORE:
			
				log.Info("CARDSUBMITSIMPLE_SUBMITMORE");
			
			m_dirModel.SetCardSubmitMode(DirConstants.CARDSUBMITMODE_MAIN);

			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetDisplayPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);
			return;

		case POSTTOSELF_ACTION_CARDSUBMIT508_SUBMIT:
			log.Info("CARDSUBMIT508 SUBMIT");

			// Assumes access to datasource
			int nDefaultDataSourceID = m_dirModel.GetCardSubmitDataSource();

			if (m_dirModel.IsWebDataSource(nDefaultDataSourceID))
			{
				strElementKey = DirSubmitCardView_D.HTMLINPUT_WWWCardURL;
			}
			else
			{
				strElementKey = DirSubmitCardView_D.HTMLINPUT_FileCardURL;
			}

			// URL
			sValues = (String[]) m_htFormData.GetElement(strElementKey);
			if (sValues == null)
			{
				
					log.Error("could not find card URL in query string.");
				

				SetErrorAndRedirectToDir508();
				return;
			}
			else
			{
				strURL = sValues[0];

				try
				{
					m_dirModel.SubmitCard(strURL, nDefaultDataSourceID);
					m_dirModel.SetDefaultCardRefreshSettings(m_dirModel.GetCardID());

					// check for errors, if some were raised, then close the popup 
					// and return
					IXPEnumerator errors = UIErrorHandler.GetErrors(
							m_asOwner.GetSubSession(),
							m_asOwner.GetApplication(), m_asOwner, true, true);
					
					if (errors.MoveNext())
					{
						//Return to dir
						repostURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
						repostURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
						repostURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
							((IDirModelRO) m_dirModel).GetDirectoryMode());
						repostURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
							XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));

						SetRedirect(repostURL);

						return;					
					}
				}
				catch (Exception e)
				{
				    SetErrorAndRedirectToDir508();
					return;
				}
			}

			// Reset the To and From (so that the new card will be displayed)
			m_dirModel.ClearCardRange();
			
			repostURL.SetLinkCreateNewSpace(DirSubmitAS_D.STR_MVC_CLASS_NAME, m_asOwner);
			repostURL.SetDisplayPage(DirSubmitDoneDP_D.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_CARDSUBMIT508_SUBMIT_DS:
		    log.Info("CARDSUBMIT508 SUBMIT_DS");

			// DataSource
			sValues = (String[]) 
				m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLSELECT_CardDataSource);

			if (sValues == null)
			{
			    log.Error("could not find card datasource in query string for 508 card submit.");

			    SetErrorAndRedirectToDir508();
				return;
			}
			else
			{
				m_dirModel.SetCardSubmitDataSource(XPConvert.ToInteger(sValues[0]));
				/* tell model not to reset the tempdata, which it does unless a path/url is saved */
				m_dirModel.SetSaveTempData(true); 
			}

			repostURL.SetLinkGetSpaceIfCached(DirSubmitAS_D.STR_MVC_CLASS_NAME, m_asOwner);
			repostURL.SetDisplayPage(DirSubmitCardDP_D.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_CARDSUBMIT508_CANCEL:
			
				log.Info("CARDSUBMIT508 CANCEL");
			
			repostURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
			repostURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
			repostURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
				((IDirModelRO) m_dirModel).GetDirectoryMode());
			repostURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
				XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));
			repostURL.SetIsHTTPRedirect(true);
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_CARDSUBMIT508_DATASOURCE:
		    
		    log.Info("CARDSUBMIT508 DATASOURCE");

		    repostURL.SetLinkGetSpaceIfCached(DirSubmitAS_D.STR_MVC_CLASS_NAME, m_asOwner);
			repostURL.SetDisplayPage(DirDataSourceDP_D.STR_MVC_CLASS_NAME);

			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_CARDSUBMITADVANCED:
			
				log.Info("CARDSUBMITADVANCED");
			

			int nAdvancedDataSourceID = m_dirModel.RefreshItemFromDataSourceTree();

			String strProvName = m_dirModel.GetDataSourceProviderName(nAdvancedDataSourceID);

			repostURL.SetLinkCreateNewSpace(strProvName + m_sBaseCardSubmitASName,
				m_asOwner);

			repostURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			repostURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_CREATE));
			repostURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
			repostURL.AddControlArgument(DirConstants.QS_PARENT_FOLDER,
				XPConvert.ToString(m_dirModel.GetCurrentFolderID()));
			repostURL.AddControlArgument(XUIHelperMethods.QS_XUI_DATASOURCE_ID,
				XPConvert.ToString(nAdvancedDataSourceID));

			SetRedirect(repostURL);

			// Reset the To and From (so that the new card will be displayed)
			m_dirModel.ClearCardRange();

			return;

		case POSTTOSELF_ACTION_SELFSELECTEXPERTS:
			
				log.Info("SELFSELECTEXPERTS");
			
			m_dirModel.LoadFoldersAndDocuments();
			m_dirModel.AddSelfSelectedRelatedExpert();

			break;

		case POSTTOSELF_ACTION_EDITCARDPROPERTIES:
			
				log.Info("CARD PROPERTIES");
			
			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetDisplayPage(DirAS.EDITCARDPROPERTIES_POPUP);
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_CARDSIMPLESUBMIT_CHANGED_DS:
			
				log.Info("SIMPLE SUBMIT DATASOURCE CHANGED");
			

			int nOriginalDataSourceID = m_dirModel.GetCardSubmitDataSource();

			// DataSource
			sValues = (String[]) m_htFormData.GetElement(DirCardSubmitSimpleView.HTMLSELECT_CardDataSource);

			if (sValues == null)
			{
				
					log.Error("could not find card datasource in query string for simple submit datasource change.");
				

				//Refresh the directory page and close popup
				repostURL.SetLinkGetCachedSpace(m_asOwner);
				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);

				return;
			}
			else
			{
				nSimpleDataSourceID = XPConvert.ToInteger(sValues[0]);
				m_dirModel.SetCardSubmitDataSource(nSimpleDataSourceID);
				
				/* for document uploads we need to set the encoding type */
				boolean bSupportsUpload;
				try
				{
					bSupportsUpload = m_dirModel.SupportsUpload(nSimpleDataSourceID); 
				} 
				catch(PTException pte)
				{
					bSupportsUpload = false;
				}
			
				((AFormDP) m_asOwner.
					GetPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME))
					.SetMultiPartEncoding(bSupportsUpload);
			}

			if (m_dirModel.IsWebDataSource(nOriginalDataSourceID))
			{
				strElementKey = DirCardSubmitSimpleView.HTMLINPUT_WWWCardURL;
			}
			else
			{
				strElementKey = DirCardSubmitSimpleView.HTMLINPUT_FileCardURL;
			}

			// URL
			sValues = (String[]) m_htFormData.GetElement(strElementKey);

			if (sValues == null)
			{
				
					log.Error("could not find card URL in query string.");
				

				repostURL.SetLinkGetCachedSpace(m_asOwner);
				repostURL.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);
			}
			else
			{
				strURL = sValues[0];
				m_dirModel.SetCardSubmitURL(strURL);
			}

			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetDisplayPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_GOTO_RANGE:
			
				log.Info("GOTO RANGE");
			

			int nFromRange;
			int nToRange;

			// From
			sValues = (String[]) m_htFormData.GetElement(DocumentBannerView.HTMLINPUT_FROM);

			if (sValues == null)
			{
				
					log.Error("could not find the FROM range value in query string.");
				

				return;
			}
			else
			{
				nFromRange = XPConvert.ToInteger(sValues[0]);
			}

			// To
			sValues = (String[]) m_htFormData.GetElement(DocumentBannerView.HTMLINPUT_TO);

			if (sValues == null)
			{
				
					log.Error("could not find the TO range value in query string.");
				

				return;
			}
			else
			{
				nToRange = XPConvert.ToInteger(sValues[0]);
			}

			repostURL.SetLinkGetCachedSpace(m_asOwner);
			repostURL.SetControl(OpenDirFolderControl.STR_MVC_CLASS_NAME);
			repostURL.AddControlArgument(OpenDirFolderControl.m_SubFolderID,
				XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));
			repostURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
				XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));
			m_dirModel.SetCardRange(nFromRange, nToRange);
			m_dirModel.LoadFoldersAndDocuments();

			SetRedirect(repostURL);

			return;

		case POSTTOSELF_ACTION_DELETE_LATER:

			if (null != arCheckedFolders)
			{
				
					log.Info("SCHEDULE FOLDER DELETE");
				
				m_dirModel.ABODeleteFolders(arCheckedFolders);
			}

			
				log.Info("DELETECARDS");
			

			if (null != arCheckedCards)
			{
				m_dirModel.DeleteCards(arCheckedCards);
			}

			break;
		}

		m_dirModel.LoadFoldersAndDocuments();
	}

	/**
	 * 
	 */
	protected void SaveCurrentPage()
	{
	}

	private void SetErrorAndRedirectToDir508()
	{
	    Redirect repostURL = new Redirect();
	    
	    UIError myError = new UIError(
		        UIErrorLevel.FRIENDLY,
		        UIErrorScope.CURRENT_USER, 
		        null,
				m_asOwner.GetString(159, "ptmsgs_portalbrowsingmsgs"),
				"");
		UIErrorHandler.RaiseError(
		        myError,
		        m_asOwner.GetSubSession(), 
		        m_asOwner.GetApplication());

		//Return to dir
		repostURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
		repostURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
		repostURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
			((IDirModelRO) m_dirModel).GetDirectoryMode());
		repostURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
			XPConvert.ToString(((IDirModelRO) m_dirModel).GetCurrentFolderID()));

		SetRedirect(repostURL);
	}
}





