package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 */
public class DocumentBannerView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.DocumentBannerView");

	
	public static final String STR_MVC_CLASS_NAME = "DocumentBanner";

	
	public static final String HTMLINPUT_FROM	    = "in_tx_From";

	
	public static final String HTMLINPUT_TO		    = "in_tx_To";

	
	public static final String HTMLBUTTON_GOTORANGE = "in_bu_GotoRange";

	
	public static final String JAVASCRIPT_CARDRANGE = "GoToCardRange";

	// Logger
	AActivitySpace m_asOwner				 = null;
	IDirModelRO m_asModel					 = null;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DocumentBannerView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		PTConstruct bannerConstruct;
		PTConstruct buttonConstruct;
		HTMLAnchor myAnchor;
		HTMLInput myInput;
		
		HTMLElementCollection result = new HTMLElementCollection();

		//Documents title banner
		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTBannerType.OBJECT,
					true, this.m_asOwner);
			myConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.GetElementName(
					PTBannerType.ELEMENT_NAME_ID_TITLE),
				m_asModel.GetObjectBannerTitle());

			// add subheader text here 
			myConstruct.ReplaceNestedElementsWithHTMLString(PTBannerType.OBJECT.GetElementName(
					PTBannerType.ELEMENT_NAME_ID_SUBTITLE),
				m_asModel.GetObjectBannerText());

			result.AddInnerHTMLElement(myConstruct.GetHTMLElement());
		}
		catch (HTMLException he)
		{
			
				log.Error("Display: Object banner failed to display.");
			
		}
		catch (Exception e)
		{
			
				log.Error("Display: Object banner creation failed.");
			
		}

		try
		{
			bannerConstruct = UIConstructFactory.GetConstruct(PTBannerType.OBJECT_ACTION_BAR,
					true, this.m_asOwner);
			result.AddInnerHTMLElement(bannerConstruct.GetHTMLElement());

			// View Items
			bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				DirConstants.CreateSpacerImage(1,5));
			HTMLSpan mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(163,
					"ptmsgs_portalbrowsingmsgs"));

			bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				mySpan);
			bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				CommonHTMLStrings.SPACE);

			/* index values used for defaults for 'from' and 'to' fields */
			int[] cardRange = m_asModel.GetCardRange();
			int cardCount = cardRange[DirModel.CARD_CNT];
			int endIndex = cardRange[DirModel.END_INDEX];
			int totalCnt = cardRange[DirModel.TOTAL_CNT_INDEX];
			
			/* calculate the from & to indices */
			int fromIndex = (endIndex < totalCnt) ? endIndex + 1 : totalCnt;
			int toIndex = endIndex + cardCount;
			if (toIndex > totalCnt)
				toIndex = totalCnt;

			myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_FROM, "");
			myInput.SetValue(XPConvert.ToString(fromIndex));
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(8);
			myInput.SetSize(5);

			bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				myInput);
			bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				CommonHTMLStrings.SPACE);

			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(164,
					"ptmsgs_portalbrowsingmsgs"));
			bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				mySpan);
			bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				CommonHTMLStrings.SPACE);

			myInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_TO, "");
			myInput.SetValue(XPConvert.ToString(toIndex));
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(8);
			myInput.SetSize(5);

			bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				myInput);
			bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				CommonHTMLStrings.SPACE);

			myInput = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLBUTTON_GOTORANGE, "");
			myInput.SetValue(">>");
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			myInput.SetOnClick(JAVASCRIPT_CARDRANGE + "(); return false;");

			bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				myInput);
			bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
				CommonHTMLStrings.SPACE);

			//Document actions banner - display only in Edit Mode and if there are any documents
			if( DirConstants.EDIT_MODE == m_asModel.GetDirectoryMode() && 0 != m_asModel.GetTotalResults())
			{
				if(m_asModel.HasAccessToApproveCardInFolder())
				{
					//Approve button
					buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.APPROVE_OBJECT_ACTIONBAR);
	
					buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.APPROVE_OBJECT_ACTIONBAR.TITLE_ELEMENT_NAME,
						m_asOwner.GetString(160, "ptmsgs_portalbrowsingmsgs"));
	
					myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.APPROVE_OBJECT_ACTIONBAR.ANCHOR_ELEMENT_NAME);
					myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(FolderBannerView.JAVASCRIPT_APPROVE +
						"(); return false;");
					ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(160,
						"ptmsgs_portalbrowsingmsgs"));
					ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(160,
						"ptmsgs_portalbrowsingmsgs"));
					bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
						myAnchor);
	
					bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
						CommonHTMLStrings.SPACE);
	
					//Unapprove button
					buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.UNAPPROVE_OBJECT_ACTIONBAR);
	
					buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.UNAPPROVE_OBJECT_ACTIONBAR.TITLE_ELEMENT_NAME,
						m_asOwner.GetString(161, "ptmsgs_portalbrowsingmsgs"));
	
					myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.UNAPPROVE_OBJECT_ACTIONBAR.ANCHOR_ELEMENT_NAME);
					myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(FolderBannerView.JAVASCRIPT_UNAPPROVE +
						"(); return false;");
					ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(161,
						"ptmsgs_portalbrowsingmsgs"));
					ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(161,
						"ptmsgs_portalbrowsingmsgs"));
					bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
						buttonConstruct.GetHTMLElement());
	
					bannerConstruct.AddHTMLStringToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
						CommonHTMLStrings.SPACE);
				}

				//Link Settings button
				buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.LINK_SETTINGS_OBJECT_ACTIONBAR);

				buttonConstruct.ReplaceNestedElementsWithHTMLString(PTButtonType.LINK_SETTINGS_OBJECT_ACTIONBAR.TITLE_ELEMENT_NAME,
					m_asOwner.GetString(162, "ptmsgs_portalbrowsingmsgs"));

				myAnchor = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.LINK_SETTINGS_OBJECT_ACTIONBAR.ANCHOR_ELEMENT_NAME);
				myAnchor.SetHRef(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(FolderBannerView.JAVASCRIPT_LINKSETTINGS +
					"(); return false;");
				ConstructFactory.SetAltOnButtonImages(buttonConstruct, m_asOwner.GetString(162,
					"ptmsgs_portalbrowsingmsgs"));
				ConstructFactory.SetTitleOnButtonImages(buttonConstruct, m_asOwner.GetString(162,
					"ptmsgs_portalbrowsingmsgs"));
				bannerConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
					buttonConstruct.GetHTMLElement());
			}
		}
		catch (Exception e)
		{
			log.Error(e, "DocumentBannerView::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(1222, "ptmsgs_portalbrowsingmsgs"), e);
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		int nObjectCount = m_asModel.GetTotalResults();

		try
		{
			XPStringBuilder sb = new XPStringBuilder(500);
			sb.Append("function IsNumeric(strString) ");
			sb.Append("   //  check for valid numeric strings	 \n");
			sb.Append("   { \n");
			sb.Append("   var strValidChars = \"0123456789\"; \n");
			sb.Append("   var strChar; \n");
			sb.Append("   var blnResult = true; \n");
			sb.Append(" \n");
			sb.Append("   if (strString.length == 0) return false; \n");
			sb.Append(" \n");
			sb.Append(
				"   //  test strString consists of valid characters listed above \n");
			sb.Append(
				"   for (i = 0; i < strString.length && blnResult == true; i++) \n");
			sb.Append("      { \n");
			sb.Append("      strChar = strString.charAt(i); \n");
			sb.Append("      if (strValidChars.indexOf(strChar) == -1) \n");
			sb.Append("         { \n");
			sb.Append("         blnResult = false; \n");
			sb.Append("         } \n");
			sb.Append("      } \n");
			sb.Append("   return blnResult; \n");
			sb.Append("   } \n");
			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(250);
			sb.Append("function WithInRange(nValue)\n");
			sb.Append("{\n");
			sb.Append("  if (nValue < 1 || nValue > ").Append(nObjectCount)
			.Append(")\n");
			sb.Append("  {\n");

			sb.Append("      alert(\"" +
				m_asOwner.GetString(166, "ptmsgs_portalbrowsingmsgs") +
				"\");\n");
			sb.Append("      return false;\n");
			sb.Append("  }\n");
			sb.Append("  return true;\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(250);
			sb.Append("function CheckNumericToFromValues()\n");
			sb.Append("{\n");
			sb.Append("  if (false == IsNumeric(document." + PlumtreeDP.HTMLFORM_NAME +
				"." + HTMLINPUT_FROM + ".value))\n");
			sb.Append("  {\n");

			sb.Append("      alert(\"" +
				m_asOwner.GetString(166, "ptmsgs_portalbrowsingmsgs") +
				"\");\n");
			sb.Append("      return false;\n");
			sb.Append("  } else if (false == IsNumeric(document." +
				PlumtreeDP.HTMLFORM_NAME + "." + HTMLINPUT_TO + ".value))\n");
			sb.Append("  {\n");

			sb.Append("      alert(\"" +
				m_asOwner.GetString(166, "ptmsgs_portalbrowsingmsgs") +
				"\");\n");
			sb.Append("      return false;\n");
			sb.Append("  }\n");
			sb.Append("  return true;\n");
			sb.Append("}\n");
			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(250);
			sb.Append("function ").Append(JAVASCRIPT_CARDRANGE).Append("()\n");
			sb.Append("{\n");
			sb.Append("  if (true == CheckNumericToFromValues())\n");
			sb.Append("  {\n");
			sb.Append("  	var nBegin = parseInt(document.").Append(PlumtreeDP.HTMLFORM_NAME)
			.Append(".").Append(HTMLINPUT_FROM).Append(".value);\n");
			sb.Append("  	var nEnd = parseInt(document.").Append(PlumtreeDP.HTMLFORM_NAME)
			.Append(".").Append(HTMLINPUT_TO).Append(".value);\n");
			sb.Append("     if (nBegin > nEnd)\n");
			sb.Append("     {\n");

			sb.Append("        alert(\"" +
				m_asOwner.GetString(167, "ptmsgs_portalbrowsingmsgs") +
				"\");\n");
			sb.Append(
				"     } else if(WithInRange(nBegin)) \n");
			sb.Append("     {\n");
			sb.Append("        document.").Append(AFormDP.HTMLFORM_NAME).Append(".method='POST';\n");
			sb.Append("        ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM)
			.Append("(").Append(DirRepostControl.POSTTOSELF_ACTION_GOTO_RANGE)
			.Append(");\n");
			sb.Append("     }\n");
			sb.Append("  }\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DirCardPropertiesView::DisplayJavascript An error occured when trying to display the JavaScript.");
			

			throw new XPException(m_asOwner.GetString(165,
					"ptmsgs_portalbrowsingmsgs"), he);
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IDirModelRO) model;
		m_asOwner     = parent;
	}
}

