package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * This interface contains the methods on the DirModel that
 * make changes.  IDirModelRO contains the read-only methods.
 */
public interface IDirModel extends IDirModelRO {

	/**
	 *
	 *
	 * @param arFolderIDs
	 */
	public void ABODeleteFolders(int[] arFolderIDs);

	/**
	 *
	 *
	 * @param arCardIDs
	 * @param nTargetFolder
	 */
	public void CopyCards(int[] arCardIDs, int nTargetFolder);

	/**
	 *
	 *
	 * @param arFolderIDs
	 * @param nTargetFolder
	 */
	public void CopyFolders(int[] arFolderIDs, int nTargetFolder);

	/**
	 * Creates a Directory Folder and calls the PEIs
	 * OnBeforeCreateDirectoryFolder and OnAfterCreateDirectoryFolder.
	 * 
	 * @param strName     Folder Name
	 * @param strDescription     Folder Description
	 */
	public void CreateDirectoryFolder(String strName, String strDescription);

	/**
	 *
	 *
	 * @param arCardIDs
	 */
	public void DeleteCards(int[] arCardIDs);

	/**
	 *
	 *
	 * @param arFolderIDs
	 */
	public void DeleteFolders(int[] arFolderIDs);

	/**
	 * This method adds objects into the migration queue.
	 */
	public void MigrateObjects(int nClassID, int[] nObjects, String sComment);

	public int OpenFolderByPath(String strPath);

	/**
	 *
	 *
	 * @param arCardIDs
	 * @param nTargetFolder
	 */
	public void MoveCards(int[] arCardIDs, int nTargetFolder);

	/**
	 *
	 *
	 * @param arFolderIDs
	 * @param nTargetFolder
	 */
	public void MoveFolders(int[] arFolderIDs, int nTargetFolder);

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModel#OpenSubFolder(int)
	 */
	public void OpenSubFolder(int ID);

	public void SetCardSubmitMode(int nCardID);

	// Card Properties
	public void SetCardID(int nCardID);

	public void ClearCardRange();

	/**
	 *
	 *
	 * @param nRangeBegin
	 * @param nRangeEnd
	 */
	public void SetCardRange(int nRangeBegin, int nRangeEnd);

	/**
	 *
	 *
	 * @param nDataSourceID
	 */
	public void SetCardSubmitDataSource(int nDataSourceID);

	/**
	 *
	 *
	 * @param strURL
	 */
	public void SetCardSubmitURL(String strURL);

	public void SetDocUploadParams(String _duID, String _duServer);

	/**
	 *
	 *
	 * @param strURL
	 */
	public void SetCardSubmitName(String strName);

	/**
	 *
	 *
	 * @param strURL
	 */
	public void SetCardSubmitDescription(String strDescription);

	/**
	 * Set the folder to use when submitting a document.  If this is
	 * not set, the current folder will be used.
	 * 
	 * @param _nFolderID
	 */
	public void SetCardSubmitFolder(int _nFolderID);

	/**
	 * Sets the error associated with the card submit.
	 * 
	 * @param _nErrorCode The error generated during card submission.
	 * -1 means no error, and is the default value.
	 */
	public void SetCardSubmitError(int _nErrorCode);

	/**
	 *
	 *
	 * @param nCardID
	 */
	public void SetDefaultCardRefreshSettings(int nCardID);

	/**
	 * Sets the Directory mode - Browse or Edit.
	 *
	 * @param int    Directory mode constant
	 */
	public void SetDirectoryMode(int nMode);

	/**
	 * This activity space holds only cards, so no need to change the type.
	 *
	 * @param ID     not used
	 */
	public void SetObjectType(int nNewObjectType);

	// SCC: this version uses the parameters stored on the model.
	public void SubmitCard();

	/* this version will create the pbag using the specified path and DS. */
	public void SubmitCard(String _strPath, int _nCSSelectedDataSource);

	/* this version will create an Upload pbag */
	public void SubmitCard(String _path, String _type, String _docID);

	/**
	 *
	 *
	 * @param strPath
	 * @param nDataSourceID
	 * @param strCardName
	 * @param strCardDescription
	 * @param pbagCardProp
	 * @param nFolderID the folder to use.  If this is -1, the current folder will be used.
	 *
	 * @throws Exception
	 */
	public void SubmitCardWithPropertyBag(int nDataSourceID,
			String strCardName, String strCardDescription,
			IXPPropertyBag pbagCardProp, int nFolderID);

	/**
	 *
	 *
	 * @param arFolderIDs
	 * @param strLanguage
	 * @param nDocTypeID
	 * @param nDataSourceID
	 * @param pbagCardProp
	 * @param strCardName
	 * @param strCardDescription
	 *
	 * @throws Exception
	 * @throws XPException
	 */
	public void SubmitCardWithPropertyBag(int[] arFolderIDs,
			String strLanguage, int nDocTypeID, int nDataSourceID,
			IXPPropertyBag pbagCardProp, String strCardName,
			String strCardDescription);

	/**
	 *
	 *
	 * @param arCardIDs
	 * @param nAction
	 */
	public void doApproval(int[] arCardIDs, int nAction /* 2 for approve, 1 for unapprov*/);

	public IPTSearchResponse SearchSubFolders(int nFolderID, int nCurrentLevel);

	public void SetDocumentTypeId(String documentTypeId);

}