package com.plumtree.portalpages.browsing.directory;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.search.SearchExecutionWarning;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This model contains data for both the Browse and Edit Modes of the
 * Directory. The folder and document queries are cached in the model.
 *
 * @author StephenC
 */
public interface IDirModelRO extends IModelRO, IFolderModel, IFolderModelRO,
	IObjectModelRO
{
	/**
	 * This method returns whether or not there are any job IDs to display.
	 *
	 * @return boolean true implies there are job ids to display.
	 */
	public boolean ABOJobIDsToDisplay();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean CheckFoldersForDelete();
      /**
       *  return a warning from the last search query(used in browse by search)
       */
      public SearchExecutionWarning GetWarning();

	/**
	 * 
	 *
	 * @param nActivityRight 
	 *
	 * @return 
	 */
	public boolean CheckForActivityRight(int nActivityRight);

	/**
	 * This method returns the job IDs for the last ABO deletes, and then clears
	 * them.
	 *
	 * @return int[] an array of job IDs for folder deletions.
	 */
	public int[] GetABOJobIDs();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPSortedDictionary GetBasicCardProperties();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetBrowseBy();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetBrowseBySource();

	///////////////////
	// Card Properties
	public int GetCardID();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPSortedDictionary GetCardInformation();

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetCardName();

	/**
	 * 
	 *
	 * @param nCardID 
	 *
	 * @return 
	 */
	public String GetCardName(int nCardID);

	// Card Range
	public int GetCardRangeBegin();
	public int[] GetCardRange();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCardSubmitDataSource();

	/**
	 * 
	 *
	 * @param bIsWebDataSource 
	 *
	 * @return 
	 */
	public String GetCardSubmitURL(boolean bIsWebDataSource);

	/**
	 * @return the folder the card was submitted into (either the
	 * current folder, or the card submit override folder).
	 */
	public int GetCardSubmitFolder();

	/**
	 * Retrieve any errors generated during card submission
	 * using the REST API.
	 * 
	 * @return The error generated during card submission.
	 * -1 if there was no error.
	 */
	public int GetCardSubmitError();

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetCopyTargetFolderTREESUBSPACE();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCreatedFolderID();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPSortedDictionary GetCustomCardProperties();

	/**
	 * returns the name of a given datasource.
	 */
	public String GetDataSourceName(int nDataSourceID);

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetDataSourceTREESUBSPACE();

	/**
	 * Gets the current directory mode - Browse or Edit
	 *
	 * @return int    Directory mode constant
	 */
	public int GetDirectoryMode();

	// Dir Preferences
	public String GetDocDescriptionType();

	/**
	 * returns a list of data sources that support Card Submission
	 */
	public IASQueryResult GetFilteredDataSources();

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetFolderDescriptionType();

	/**
	 * 
	 *
	 * @param nFolderID 
	 *
	 * @return 
	 */
	public String GetFolderName(int nFolderID);

	/**
	 * 
	 *
	 * @param nFolderID 
	 *
	 * @return 
	 */
	public String GetFolderPath(int nFolderID);

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetMoreFolderID();

	/**
	 * 
	 *
	 * @param nRelatedResourceID 
	 *
	 * @return 
	 */
	public Object[][] GetMoreRelatedResources(int nRelatedResourceID);

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetMoveTargetFolderTREESUBSPACE();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumDocsPerPage();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumFolderColumns();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumSubSubFolders();

	/**
	 * this creates a string with the banner sub-header text.
	 */
	public String GetObjectBannerText();

	/**
	 * returns the ID of the Default DataSource for this folder.  It will recursively search up the ancestors to          */
	public int GetParentDefaultDataSourceIDRecursive();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPArrayList GetPropColumns();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetRRCategory();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetRRObjectID();

	/**
	 * 
	 *
	 * @param nRelatedResourceID 
	 *
	 * @return 
	 */
	public IASQueryResult GetRelatedResource(int nRelatedResourceID);

	// Related Resource routines
	public int[] GetRelatedResourceIDs();

	/**
	 * 
	 *
	 * @param nRelatedResourceID 
	 *
	 * @return 
	 */
	public String GetRelatedResourceString(int nRelatedResourceID);

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetRelatedResourcesLocation();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetTotalResults();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean HasAccessToEditCard();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean HasAccessToEditFolder();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean HasSelfSelectExpertRightOnThisFolder();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetSubPortalAccessType();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean InUnclassifiedCardsFolder();

	/**
	 * This method returns whether or not the current folder is at the max level
	 *
	 * @return boolean
	 */
	public boolean IsAtMaxFolderLevel();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsRelatedExpert();

	/**
	 * 
	 *
	 * @param nDataSourceID 
	 *
	 * @return 
	 */
	public boolean IsWebDataSource(int nDataSourceID);

	/**
	 * returns the currently selected Copy TargetFolder ID
	 */
	public int RefreshItemFromCopyTargetFolderTree();

	/**
	 * returns the currently selected DataSource ID
	 */
	public int RefreshItemFromDataSourceTree();

	/**
	 * returns the currently selected Move TargetFolder ID
	 */
	public int RefreshItemFromMoveTargetFolderTree();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean ShowFolderActionBanner();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean ShowRelatedResources();
	
	/**
	 * 
	 *
	 * @return 
	 */
	public XPDateTime GetObjectNewTagDate();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPDateTime GetObjectUpdateTagDate();
	
	/**
	 * 
	 *
	 * @return 
	 */
	public IPTSession GetSession();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetUserPrefOpenDocInNewWindow();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPLocale GetUserPrefLocale();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPTimeZone GetUserPrefTimeZone();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCardSubmitMode();

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean HasAccessToApproveCardInFolder();

	/**
	 * 
	 *
	 * @return 
	 */
	public IASQueryResult GetBreadCrumbPath();

	/**
	 * @return boolean true if the specified data source is valid for
	 * simple submit (i.e. web, or remote document upload).
	 */
	public boolean IsValidSimpleSubmitSource(int _nDataSourceID);

	/**
	 * Returns true if the specified data source supports remote document 
	 * upload.
	 *
	 * @return boolean
	 */
	public boolean SupportsUpload(int _nDataSourceID);
	
	/**
	 * Returns the webservice's upload url if it supports uploads and it is set. 
	 * 
	 * @return String
	 */
	public String GetUploadWSURL(int _nDataSourceID);

	/**
	 * This method returns whether or not subfolders queries are performed through search
	 *
	 * @return boolean
	 */
	public boolean RetrieveSubFoldersThroughSearch();

	/**
	 * Get an IPTSearchResponse containing all of the subfolders of the current folder.
	 */
	public IPTSearchResponse GetFolderSearchResponse();

	/**
	 * Retrieves the index within the SearchResponse that corresponds to the 
	 * ordering that would have been returned from IPTCatalog.QuerySubfolders()
	 */
	public int GetFolderSearchMapping(int nUnmappedIndex);
	
	/**
	 * Retrieves the headers to be displayed in a array that includes the header's name, property Id, 
	 * and sort URL if applicaple.
	 * 
	 * @return
	 */
	public IXPList GetHeaderProperties();
	
	/**
	 * Returns an array list of the values for each custom property in xpCustomProps 
	 * for the document in index _nObjectIndex.
	 * 
	 * @param _nObjectIndex
	 * @param xpCustomProps
	 * @param xpLocale
	 * @param xpTimeZone
	 * @return
	 */
	public XPArrayList GetCustomFields(int _nObjectIndex, XPArrayList xpCustomProps, XPLocale xpLocale, XPTimeZone xpTimeZone);
	
	//////////////////////
	// basic object ids

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetClassID();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetObjectID();

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetObjectUUID();
	
	/**
	 * 
	 * @return
	 */
	public int GetDocumentTypeId();
	

}