package com.plumtree.portalpages.browsing.directory.browse;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Presents Documents through Search
 *
 * @author StephenC
 */
public class BrowseDocViewHelper implements IObjectViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.browse.BrowseDocViewHelper");


	private IDirModelRO m_dirModel;

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#AddObjectViewHTML()
	 */
	public HTMLElement AddObjectViewHTML(IObjectModelRO model)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#Display508Object(int, HTMLTable, IObjectModelRO, AActivitySpace)
	 */
	public void Display508Object(int nObjectIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace parent)
	{
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayJavascriptCollection(AActivitySpace)
	 */
	public HTMLScriptCollection DisplayJavascriptCollection(
		AActivitySpace asOwner, IObjectModelRO model)
	{
		return null;
	}


	/**
	 * @see com.plumtree.portalpages.common.objects.
	 * IObjectViewHelper#GetThereAreNoItemsString(AActivitySpace)
	 */
	public String GetThereAreNoItemsString(AActivitySpace asOwner)
	{
		return null;
	}

	/**
	 * Displays the object at the given index in the query result. This must be
	 * overridden by all subclasses.
	 *
	 * @param nObjectIndex
	 * @param tableObjects
	 * @param model
	 */
	public void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace asOwner)
	{
		m_dirModel = (IDirModelRO) model;

		//Construct definitions
		HTMLTableRow row;
		HTMLTableCell cell;

		try
		{
			boolean bBrowseBySearch = (DirConstants.BROWSE_BY_SEARCH == m_dirModel.GetBrowseBySource());

			// TODO: This method is shared by documentsdatatag, so it should be refactored so the code (and bugs)
			// are not duplicated.

			// Card ID
			int nCardID = XPConvert.ToInteger(m_dirModel.GetObjectFields(
						nObjectIndex,
						(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_OBJECTID
										 : PT_PROPIDS.PT_PROPID_OBJECTID)));

			// Name
			String strName = (String) m_dirModel.GetObjectFields(
						nObjectIndex,
						(bBrowseBySearch ? PT_INTRINSICS.PT_PROPERTY_OBJECTNAME
										 : PT_PROPIDS.PT_PROPID_NAME));

			// Image uiid
			String strImageUIID = (String) m_dirModel.GetObjectFields(nObjectIndex,
					(bBrowseBySearch
					? PT_INTRINSICS.PT_PROPERTY_OBJECTIMAGEUUID
					: PT_PROPIDS.PT_PROPID_IMAGEUUID));

			// Created
			XPDateTime dtCreatedDate = (XPDateTime) model.GetObjectFields(nObjectIndex,
					(bBrowseBySearch
					? PT_INTRINSICS.PT_PROPERTY_OBJECTCREATED
					: PT_PROPIDS.PT_PROPID_CREATED ));
			XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(
				XPDateFormat.SHORT,
				XPDateFormat.SHORT,
				m_dirModel.GetUserPrefLocale(),
				m_dirModel.GetUserPrefTimeZone());
			String strCreatedDate = xpDateTimeFormat.Format(dtCreatedDate);

			// Last Modified
			XPDateTime dtLastModifiedDate = (XPDateTime) m_dirModel.GetObjectFields(nObjectIndex,
					(bBrowseBySearch
					? PT_INTRINSICS.PT_PROPERTY_OBJECTLASTMODIFIED
					: PT_PROPIDS.PT_PROPID_LASTMODIFIED ));

			// Description
			String strDescType = m_dirModel.GetDocDescriptionType();
			String strDesc     = "";

			if (false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,strDescType))
			{
				strDesc = (String) m_dirModel.GetObjectFields(
							nObjectIndex,
							(bBrowseBySearch
							? PT_INTRINSICS.PT_PROPERTY_OBJECTSUMMARY
							: PT_PROPIDS.PT_PROPID_DESCRIPTION));

				if (null == strDesc)
				{
					strDesc = "";
				}

				// abbreviate the description if necessary
				if (true == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_ABBR,strDescType))
				{
					if (DirConstants.DESCRIPTION_ABBR_LENGTH < strDesc.length())
					{
						strDesc = strDesc.substring(0,
								DirConstants.DESCRIPTION_ABBR_LENGTH) + "...";
					}
				}

				// HTMLEncode
				strDesc = XPHttpUtility.HtmlEncode(strDesc);
			}

			XPArrayList xpCustomProps  = null;
			XPArrayList xpCustomFields = null;

			if (bBrowseBySearch)
			{
				xpCustomProps	   = m_dirModel.GetPropColumns();
				xpCustomFields     = m_dirModel.GetCustomFields(nObjectIndex, xpCustomProps, m_dirModel.GetUserPrefLocale(), m_dirModel.GetUserPrefTimeZone());
			}

			String strLink = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGCARD_ID, nCardID, strName, IPTOpenerConstants.OPENER_MODE_VIEW, asOwner);
			strLink = JSHelper.JSEncodeString(strLink);
			String strURL;
			if(m_dirModel.GetUserPrefOpenDocInNewWindow())
			{
				// open document URL in new window.
				strURL = PTOpenerLinks.GetJSOpenInNewWindow(
					"'" + strLink + "'",
					PTOpenerLinks.GetWindowName("" + PT_CLASSIDS.PT_CATALOGCARD_ID + "_" + nCardID),
				    	"800", "600", true);
			}
			else
			{
				// open document URL in same window.
				strURL = PTOpenerLinks.GetJSOpenInSameWindow(
						"'" + strLink + "'");
			}

			String strFittedName = DirConstants.BreakUpLongWordsInStringAndHTMLEncode(strName, 64);

			// use list item construct
			HTMLAnchor nameAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			nameAnchor.SetOnClick(strURL + "; return false;");
			nameAnchor.AddInnerHTMLString(strFittedName);
			UIListItem itemConstruct = new UIListItem(nameAnchor, asOwner);
			itemConstruct.SetTitleStyleClass(PTStyleClass.LIST_SUBTITLE);

			boolean bNeedsNewTag = m_dirModel.GetObjectNewTagDate().Before(dtCreatedDate);
			if(bNeedsNewTag)
				itemConstruct.SetNew(true);
			else
				itemConstruct.SetUpdated(m_dirModel.GetObjectUpdateTagDate().Before(dtLastModifiedDate));

			if ((false == XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE,strDescType)) && (0 != strDesc.length()))
			{
				itemConstruct.SetDescription(strDesc);
			}

			//Properties URL
			HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			myAnchor.SetOnClick(DirConstants.JAVASCRIPT_CARDPROPERTIES_POPUP + "(" + nCardID + "); return false;\n");

			myAnchor.AddInnerHTMLString(asOwner.GetString(26,
					"ptmsgs_portalbrowsingmsgs"));
			itemConstruct.SetPropertiesLink(myAnchor);

			// Image UIID
			HTMLImg myImg = PlumtreeHelpers.GetHTMLImage(strImageUIID, true);
			myImg.SetAlt(XPHttpUtility.HtmlEncode(strName));
			myImg.SetWidth("20");
			itemConstruct.SetItemTypeImage(myImg);

			// convert the construct to table
			try
			{
				row = new HTMLTableRow();
				row.SetStyleClass(((nRowIndex % 2) == 1)
					? PTStyleClass.LIST_ITEM_ONE_BG
					: PTStyleClass.LIST_ITEM_TWO_BG);
				itemConstruct.AddItemCellsToRow(row);

				HTMLImg spacer = (HTMLImg) ConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();
				spacer.SetHeight("13");
				spacer.SetWidth("1");

				if (bBrowseBySearch)
				{
					for (int i = 0; i < xpCustomFields.GetSize(); i++)
					{
						cell = new HTMLTableCell();
						row.AddInnerHTMLElement(cell);
						cell.SetVAlign(CommonHTMLStrings.TOP);
						cell.SetStyleClass(PTStyleClass.LIST_TEXT);

						Object[] arPropInfo = (Object[]) xpCustomProps.GetElement(i);
						int nPropType	    = XPConvert.ToInteger(arPropInfo[DirConstants.PROP_COLUMNS_INDEX_TYPE]);

						cell.SetNoWrap(PT_PROPERTY_TYPES.PT_PROPTYPE_STRING != nPropType);
						cell.AddInnerHTMLElement(spacer);
						cell.AddInnerHTMLString((String) xpCustomFields.GetElement(
								i));
					}
				}
				else
				{
					// Created
					cell = new HTMLTableCell();
					row.AddInnerHTMLElement(cell);
					cell.SetVAlign(CommonHTMLStrings.TOP);
					cell.SetStyleClass(PTStyleClass.LIST_TEXT);
					cell.SetNoWrap(true);
					cell.AddInnerHTMLElement(spacer);
					cell.AddInnerHTMLString(strCreatedDate);
				}

				// Send Doc Link
				cell = new HTMLTableCell();
				cell.SetVAlign(CommonHTMLStrings.TOP);
				row.AddInnerHTMLElement(cell);

				HTMLImg mySendDocImg = (HTMLImg) PTImageType.ACTION_SEND.GetHTMLElement();
				mySendDocImg.SetAlt(asOwner.GetString(1506, "ptmsgs_portalbrowsingmsgs"));

				myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				myAnchor.SetOnClick(DirConstants.JAVASCRIPT_SENDDOCLINK_POPUP + "(" + nCardID + "); return false;");	// mj: removed 'Javascript:' from function name
				myAnchor.AddInnerHTMLElement(mySendDocImg);
				cell.AddInnerHTMLElement(myAnchor);

				tableObjects.AddInnerHTMLElement(row);
			}
			catch (Exception e)
			{
				
					log.Error(e, "BrowseDocViewHelper::Display Object. The following exception occured: " + e.getMessage());
				
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "BrowseDocViewHelper::Display Object. The following exception occured: " + e.getMessage());
			
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#SetExpandButton(HTMLAnchor, IObjectModelRO)
	 */
	public void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model)
	{
	}
}

