package com.plumtree.portalpages.browsing.directory.browse_D;

import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.portalpagesperf.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Main directory display page for 508 mode
 * @author StephenC
 *
 */
public class DirBrowseDP_D extends PlumtreeDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.browse_D.DirBrowseDP_D");

	
	public static final String STR_MVC_CLASS_NAME = "DirBrowse_D";

	private DirModel m_asModel;

	
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		return m_asOwner.GetString(37, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		return m_asOwner.GetString(36, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		SetAddMainForm(true);
		
		parent.SetHelpTopic("PT_BrowseDirectory");
	}

	// SCC: overriding AFormDP's implementation
	protected boolean GetRepostTypeIsPost()
	{
		return false;
	}

	/**
	 * helper display method for PlumtreeDP
	 *
	 * Fill in the body argument with HTML to display in the page.
	 */
	public HTMLElement PageDisplay()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		
		// Increment the performance counters only if info is on for commonlib	
		PerfCounters.INSTANCE.IncrementCounter( PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_DIRECTORY_PAGES );

		m_asModel = (DirModel) m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME);

		HTMLElementCollection wholePageGroup = new HTMLElementCollection();

		((ObjectView) m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME)).SetObjectViewHelper(new BrowseDocViewHelper_D());

		try
		{
			String strFolderName = m_asModel.GetCurrentFolderName();

			// Header
			wholePageGroup.AddInnerHTMLElement(m_asOwner.GetView(
					DirBrowseHeaderView_D.STR_MVC_CLASS_NAME).Display());


			// Folder Header
			myTable = new HTMLTable();
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("2");
			myTable.SetCellSpacing("2");
			myTable.SetSummary(m_asOwner.GetString(1171, "ptmsgs_portalbrowsingmsgs"));
			wholePageGroup.AddInnerHTMLElement(myTable);

			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetStyleClass(PTStyleClass.DIR_HEADER);
			myRow.AddInnerHTMLElement(myCell);

			String strTitle = m_asOwner.GetString(32,
					"ptmsgs_portalbrowsingmsgs") + " \"" +
				XPHttpUtility.HtmlEncode(strFolderName) + "\" ";
			myCell.AddInnerHTMLString(strTitle);

			// Sub Folders
			wholePageGroup.AddInnerHTMLElement(m_asOwner.GetView(
					FolderView.STR_MVC_CLASS_NAME).Display());

			boolean bInRootFolder = m_asModel.InRootFolder();

			if (false == bInRootFolder)
			{
				// ADD extra spacer table
				wholePageGroup.AddInnerHTMLElement(DirConstants.CreateSpacerTable(15,1));

				// Documents Header
				myTable = new HTMLTable();
				myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				myTable.SetBorder(CommonHTMLStrings.ZERO);
				myTable.SetSummary(m_asOwner.GetString(1170, "ptmsgs_portalbrowsingmsgs"));
				wholePageGroup.AddInnerHTMLElement(myTable);

				myRow = new HTMLTableRow();
				myRow.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myCell.SetStyleClass(PTStyleClass.DIR_HEADER);
				myRow.AddInnerHTMLElement(myCell);

				strTitle = m_asModel.GetObjectBannerTitle() +
					m_asModel.GetObjectBannerText();
				myCell.AddInnerHTMLString(strTitle);

				// Documents
				wholePageGroup.AddInnerHTMLElement(m_asOwner.GetView(
						ObjectView.STR_MVC_CLASS_NAME).Display());

				// Document Links
				HTMLTable tableDocLinks = DirConstants.DisplayDocumentLinksTable(m_asOwner,
						m_asOwner.GetString(1662, "ptmsgs_portalbrowsingmsgs"),
						m_asOwner.GetString(1663, "ptmsgs_portalbrowsingmsgs"),
						m_asOwner.GetString(1169, "ptmsgs_portalbrowsingmsgs"));

				if (null != tableDocLinks)
				{
					wholePageGroup.AddInnerHTMLElement(tableDocLinks);
				}
			}

			// Related Resources
			if (m_asModel.ShowRelatedResources())
			{
				// ADD extra spacer table
				wholePageGroup.AddInnerHTMLElement(DirConstants.CreateSpacerTable(15,1));

				wholePageGroup.AddInnerHTMLElement(m_asOwner.GetView(
						DirRelatedResourcesView_D.STR_MVC_CLASS_NAME).Display());
			}

			// ADD extra spacer table
			wholePageGroup.AddInnerHTMLElement(DirConstants.CreateSpacerTable(15,1));

			// Footer
			wholePageGroup.AddInnerHTMLElement(m_asOwner.GetView(
					DirBrowseFooterView_D.STR_MVC_CLASS_NAME).Display());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Error in DirBrowseDP_D::Display: " + he.getMessage());
			
		}

		return wholePageGroup;
	}
}

