package com.plumtree.portalpages.browsing.directory.browse_D;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.editors.directory.submit_D.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * Show the Page Options for the Directory
 */
public class DirBrowseFooterView_D implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.browse_D.DirBrowseFooterView_D");

	
	public static final String STR_MVC_CLASS_NAME = "DirBrowseFooter_D";

	private AActivitySpace m_asOwner;
	private IDirModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirBrowseFooterView_D();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		ASURL myURL;
		HTMLAnchor myAnchor;

		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display DirBrowseFooterView_D");
			result.AddInnerHTMLElement(myComment);

			HTMLTable mainTable = new HTMLTable();
			result.AddInnerHTMLElement(mainTable);
			mainTable.SetBorder("0");
			mainTable.SetWidth("100%");
			mainTable.SetCellPadding("0");
			mainTable.SetCellSpacing("0");
			mainTable.SetSummary(m_asOwner.GetString(1173, "ptmsgs_portalbrowsingmsgs"));

			IASQueryResult asqrFilters = m_asModel.GetFilteredDataSources();

			boolean bHasAccessToAtLeastOneDataSource = false;

			int nDataSourceCount = 0;

			if (null != asqrFilters)
			{
				nDataSourceCount = asqrFilters.GetCount();

				if (0 != nDataSourceCount)
				{
					bHasAccessToAtLeastOneDataSource = true;
				}
			}

			boolean bInRootFolder = m_asModel.InRootFolder();

			if (bHasAccessToAtLeastOneDataSource && (false == bInRootFolder))
			{
				// BEGIN Page Options Row
				myRow = new HTMLTableRow();
				mainTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
				myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
				myCell.SetWidth("100%");
				myRow.AddInnerHTMLElement(myCell);
		
				myCell.AddInnerHTMLString(m_asOwner.GetString(39,
						"ptmsgs_portalbrowsingmsgs"));
		
				// END Page Options Row

				///////////////////////////////////////
				// SUBMIT A CARD - FIRST PICK DATASOURCE
				//
				// BEGIN Submit Card (Pick DS) Row
				myRow = new HTMLTableRow();
				mainTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myCell.SetWidth("100%");
				myRow.AddInnerHTMLElement(myCell);

				// Submit Card (Pick DS)
				myURL = new ASURL(m_asOwner);
				myURL.SetLinkCreateNewSpace(DirSubmitAS_D.STR_MVC_CLASS_NAME, m_asOwner);
				myURL.SetDisplayPage(DirDataSourceDP_D.STR_MVC_CLASS_NAME);

				myAnchor = new HTMLAnchor(myURL.GetURLAsString());
				
				myAnchor.SetTitle(m_asOwner.GetString(38,
						"ptmsgs_portalbrowsingmsgs"));

				myAnchor.AddInnerHTMLString(m_asOwner.GetString(38,
						"ptmsgs_portalbrowsingmsgs"));
				myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
				myCell.AddInnerHTMLElement(myAnchor);

				// END Submit Card Row
				///////////////////////////////////////
				// SELF_SELECTING EXPERTS
				//
				boolean bHasSelfSelectExpertRightOnFolder = m_asModel.HasSelfSelectExpertRightOnThisFolder();

				// Check if the SubPortal setting for Experts is on.
				boolean bRelatedExpertsSubPortalOption = false;
				int[] arrRelatedResourceIDs			   = m_asModel.GetRelatedResourceIDs();

				for (int i = 0; i < arrRelatedResourceIDs.length; i++)
				{
					if (PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS == arrRelatedResourceIDs[i])
					{
						bRelatedExpertsSubPortalOption = true;
					}
				}

				boolean bIsRelatedExpert = m_asModel.IsRelatedExpert();

				boolean bDisplaySelfSelectLink = (true == bRelatedExpertsSubPortalOption) &&
					(true == bHasSelfSelectExpertRightOnFolder) &&
					(false == bIsRelatedExpert);

				if (bDisplaySelfSelectLink)
				{
					myRow = new HTMLTableRow();
					mainTable.AddInnerHTMLElement(myRow);
					myCell = new HTMLTableCell();
					myCell.SetWidth("100%");
					myRow.AddInnerHTMLElement(myCell);

					// BEGIN Add Me as Expert
					myURL = new ASURL(m_asOwner);
					myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME,
						m_asOwner);
					myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
					myURL.AddControlArgument(DirConstants.QS_SELFSELECT_EXPERT);

					myAnchor = new HTMLAnchor(myURL.GetURLAsString());
					myAnchor.SetTitle(m_asOwner.GetString(1172, "ptmsgs_portalbrowsingmsgs"));
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(1172, "ptmsgs_portalbrowsingmsgs"));
					myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
					myCell.AddInnerHTMLElement(myAnchor);

					// END Add Me as Expert
				}
			}

			myComment = new HTMLComment( "End: Display DirBrowseFooterView_D");
			result.AddInnerHTMLElement(myComment);
			
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME +
					"::MainView::Display The following error occured when trying to display the HTML: " +
					he.getMessage());
			

			throw new XPException(m_asOwner.GetString(40,
					"ptmsgs_portalbrowsingmsgs"), he);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IDirModelRO) model;
		m_asOwner     = parent;
	}
}

