package com.plumtree.portalpages.browsing.directory.browse_D;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * List the Related Resources based on the categories to show.
 */
public class DirRelatedResourcesView_D implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.browse_D.DirRelatedResourcesView_D");

	
	public static final String STR_MVC_CLASS_NAME = "DirRelatedResourcesView_D";
	private static final int RELATED_RESOURCE_DISPLAY_LIMIT = 3;

	private AActivitySpace m_asOwner;
	private IDirModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirRelatedResourcesView_D();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLTable sectionTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		HTMLTable mainTable = new HTMLTable();
		mainTable.SetBorder("0");
		mainTable.SetWidth("100%");
		mainTable.SetCellPadding("0");
		mainTable.SetCellSpacing("0");
		mainTable.SetSummary(m_asOwner.GetString(1186, "ptmsgs_portalbrowsingmsgs"));

		try
		{
			int[] arrRelatedResourceIDs = m_asModel.GetRelatedResourceIDs();

			if (null == arrRelatedResourceIDs)
			{
				return mainTable;
			}

			for (int i = 0; i < arrRelatedResourceIDs.length; i++)
			{
				int nRRCategoryID   = arrRelatedResourceIDs[i];
				IASQueryResult asqr = m_asModel.GetRelatedResource(nRRCategoryID);
				int nNumRRToDisplay = 0;

				boolean bHasSelfSelectExpertRightOnFolder = m_asModel.HasSelfSelectExpertRightOnThisFolder();
				boolean bRelatedExperts					  = arrRelatedResourceIDs[i] == PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS;
				boolean bIsRelatedExpert				  = m_asModel.IsRelatedExpert();
				boolean bShowMore						  = false;

				if ((null != asqr) ||
						((true == bHasSelfSelectExpertRightOnFolder) &&
						(true == bRelatedExperts)))
				{
					if (null == asqr)
					{
						nNumRRToDisplay = 0;
					}
					else
					{
						nNumRRToDisplay = asqr.GetCount();
					}

					boolean bDisplaySelfSelectBanner = (true == bRelatedExperts) &&
						(true == bHasSelfSelectExpertRightOnFolder) &&
						(false == bIsRelatedExpert);

					if ((nNumRRToDisplay != 0) || bDisplaySelfSelectBanner)
					{ // always display users banner (to allow self-selecting experts feature)

						//	Get the banner, set the title
						try
						{
							String strCategoryTitle = m_asModel.GetRelatedResourceString(arrRelatedResourceIDs[i]);

							myRow = new HTMLTableRow();
							mainTable.AddInnerHTMLElement(myRow);
							myCell = new HTMLTableCell();
							myCell.SetWidth("100%");
							myRow.AddInnerHTMLElement(myCell);

							sectionTable = new HTMLTable();
							sectionTable.SetBorder("0");
							sectionTable.SetWidth("100%");
							sectionTable.SetCellPadding("0");
							sectionTable.SetCellSpacing("0");
							sectionTable.SetSummary(m_asOwner.GetString(1185, "ptmsgs_portalbrowsingmsgs") +
								CommonHTMLStrings.SPACE + strCategoryTitle);
							myCell.AddInnerHTMLElement(sectionTable);

							myRow = new HTMLTableRow();
							sectionTable.AddInnerHTMLElement(myRow);
							myRow.SetStyleClass(PTStyleClass.DIR_HEADER_BG);

							myCell = new HTMLTableCell();
							myRow.AddInnerHTMLElement(myCell);
							myCell.SetWidth("100%");
							myCell.SetHeight("20");
							myCell.SetStyleClass(PTStyleClass.DIR_HEADER);					

							myCell.AddInnerHTMLString(strCategoryTitle);
						}
						catch (HTMLException he)
						{
							
								log.Error(he, STR_MVC_CLASS_NAME +
									"::DirRelatedResourcesView_D::Display The following error occured when trying to display the HTML: " +
									he.getMessage());
							
						}
					}

					if (nNumRRToDisplay > RELATED_RESOURCE_DISPLAY_LIMIT)
					{
						nNumRRToDisplay     = RELATED_RESOURCE_DISPLAY_LIMIT;
						bShowMore		    = true;
					}
				}

				if (0 < nNumRRToDisplay)
				{
					myRow = new HTMLTableRow();
					mainTable.AddInnerHTMLElement(myRow);
					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);

					sectionTable = new HTMLTable();
					sectionTable.SetBorder("0");
					sectionTable.SetWidth("100%");
					sectionTable.SetCellPadding("0");
					sectionTable.SetCellSpacing("0");
					sectionTable.SetSummary(m_asOwner.GetString(1187, "ptmsgs_portalbrowsingmsgs"));
					myCell.AddInnerHTMLElement(sectionTable);

					// Display values
					for (int j = 0; j < nNumRRToDisplay; j++)
					{
						String strValue = (String) asqr.GetFields(j,
								PT_PROPIDS.PT_PROPID_NAME);
						int nObjectID   = XPConvert.ToInteger(asqr.GetFields(j,
								PT_PROPIDS.PT_PROPID_OBJECTID));

						myRow = new HTMLTableRow();
						sectionTable.AddInnerHTMLElement(myRow);
						myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);

						myCell = new HTMLTableCell();
						myRow.AddInnerHTMLElement(myCell);
						myCell.SetHeight("20");

						String strURL = "";
						
						switch (nRRCategoryID)
						{
						case PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES:
							strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_COMMUNITY_ID,
									nObjectID,
									IPTOpenerConstants.OPENER_MODE_VIEW,
									m_asOwner);

							break;

						case PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS:
							strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_CATALOGFOLDER_ID,
									nObjectID,
									IPTOpenerConstants.OPENER_MODE_VIEW,
									m_asOwner);

							break;

						case PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS:
							strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_GADGET_ID,
									nObjectID,
									IPTOpenerConstants.OPENER_MODE_VIEW,
									m_asOwner);

							break;

						case PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS:
						case PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS:
							strURL = PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_USER_ID,
									nObjectID,
									IPTOpenerConstants.OPENER_MODE_VIEW,
									m_asOwner);

							break;
						}

						HTMLAnchor myAnchor = new HTMLAnchor(strURL);
						String sEncValue = XPHttpUtility.HtmlEncode(strValue);
						myAnchor.AddInnerHTMLString(sEncValue);
						myAnchor.SetTitle(sEncValue);
						myCell.AddInnerHTMLElement(myAnchor);
					}
					 // for

					// Display the More... link				
					if (bShowMore)
					{
						myRow = new HTMLTableRow();
						sectionTable.AddInnerHTMLElement(myRow);
						myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);

						myCell = new HTMLTableCell();
						myRow.AddInnerHTMLElement(myCell);
						myCell.SetHeight("20");
						myCell.SetAlign("right");

						ASURL myURL = new ASURL(m_asOwner);
						myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME,
							m_asOwner);
						myURL.SetDisplayPage(DirRelatedResourcesMoreDP_D.STR_MVC_CLASS_NAME);
						myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
						myURL.AddControlArgument(DirConstants.QS_RRCATEGORY,
							nRRCategoryID);

						HTMLAnchor myAnchor = new HTMLAnchor(myURL.GetURLAsString());

						myAnchor.SetTitle(m_asOwner.GetString(66,
								"ptmsgs_portalbrowsingmsgs"));

						myAnchor.AddInnerHTMLString(m_asOwner.GetString(66,
								"ptmsgs_portalbrowsingmsgs"));
						myCell.AddInnerHTMLElement(myAnchor);
					}
				}
				else if(PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS == nRRCategoryID && bHasSelfSelectExpertRightOnFolder) 
				{
					// If there are no experts then show a message.
					myRow = new HTMLTableRow();
					mainTable.AddInnerHTMLElement(myRow);
					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);

					sectionTable = new HTMLTable();
					sectionTable.SetBorder("0");
					sectionTable.SetWidth("100%");
					sectionTable.SetCellPadding("0");
					sectionTable.SetCellSpacing("0");
					myCell.AddInnerHTMLElement(sectionTable);
					
					// No Experts Message
					myRow = new HTMLTableRow();
					sectionTable.AddInnerHTMLElement(myRow);
					myRow.SetStyleClass(PTStyleClass.MENU_TEXT);

					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetHeight("20");
					myCell.AddInnerHTMLString(m_asOwner.GetString(1217, "ptmsgs_portalbrowsingmsgs"));

					// Add me Link
					myRow = new HTMLTableRow();
					sectionTable.AddInnerHTMLElement(myRow);
					myRow.SetStyleClass(PTStyleClass.MENU_TEXT);

					myCell = new HTMLTableCell();
					myRow.AddInnerHTMLElement(myCell);
					myCell.SetHeight("20");

					ASURL myURL = new ASURL(m_asOwner);
					myURL.SetLinkGetSpaceIfCached(DirAS.STR_MVC_CLASS_NAME,
						m_asOwner);
					myURL.SetControl(DirRepostControl.STR_MVC_CLASS_NAME);
					myURL.AddControlArgument(DirConstants.QS_SELFSELECT_EXPERT);

					HTMLAnchor myAnchor = new HTMLAnchor(myURL.GetURLAsString());
					myAnchor.SetTitle(m_asOwner.GetString(1172, "ptmsgs_portalbrowsingmsgs"));
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(1172, "ptmsgs_portalbrowsingmsgs"));

					myCell.AddInnerHTMLElement(myAnchor);
				}
				 // if

				myRow = new HTMLTableRow();
				mainTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.AddInnerHTMLElement(DirConstants.CreateSpacerTable(1,225));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "DirRelatedResourcesView_D::Display Exception: " +
					e.getMessage());
			
		}

		return mainTable;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IDirModelRO) model;
		m_asOwner     = parent;
	}
}

