package com.plumtree.portalpages.browsing.directory.documentsubmitsimple;


// Framework imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This Section contains the HTML for the dependencies page.
 *
 * @author StephenC
 */
public class DirCardSubmitDependenciesView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.documentsubmitsimple.DirCardSubmitDependenciesView");

	/**
	 * Class name for the activity space
	 */
	public static final String STR_MVC_CLASS_NAME = "DirCardSubmitPopUpDependencies";

	/** HTML Object name: close button */
	public static final String HTMLBUTTON_CLOSE = "in_bu_Close";

	
	/**
	 * Parent AS.
	 */
	protected AActivitySpace m_asOwner;

	/**
	 * Associated read-only Model.
	 */
	protected IDirModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirCardSubmitDependenciesView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myMainTable;
		HTMLTable myTable;
		HTMLTableRow myMainTableRow;
		HTMLTableRow myRow;
		HTMLTableCell myMainTableCell;
		HTMLTableCell myCell;
		HTMLInput myInput;

		try
		{
			// Main table
			myMainTable = new HTMLTable();
			result.AddInnerHTMLElement(myMainTable);
			myMainTable.SetWidth("100%");
			myMainTable.SetHeight("600");
			myMainTable.SetBorder("0");
			myMainTable.SetCellPadding("0");
			myMainTable.SetCellSpacing("0");

			// Main table = row 1
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetHeight("60");
			myMainTableCell.SetWidth("100%");
			myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// Main table = row 2
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("100%");
			myMainTableCell.SetHeight("380");
			myMainTableCell.SetVAlign("top");

			// Content table
			myTable = new HTMLTable();
			myMainTableCell.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("5");

			// Row 1 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_NOTICE_HEADER);
			myCell.AddInnerHTMLString(m_asOwner.GetString(1205, "ptmsgs_portalbrowsingmsgs"));
			myCell.AddInnerHTMLElement(new HTMLBr());

			// Row 1 - end
			// Dependency rows
			myTable.AddInnerHTMLElement(GetHTMLForDependencies());

			// Row Close Button - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			myCell.AddInnerHTMLElement(new HTMLBr());
			myCell.AddInnerHTMLElement(new HTMLBr());

			// Button to close the window and redirect the main one.
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(m_asOwner.GetString(1202, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

			myInput.SetOnClick("self.close();");	// mj: removed 'Javascript:' from function name

			// Row Close Button - end
			// Row 4 - begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("100%");
			myCell.SetColSpan("2");
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			// Row 4 - end
			// Main table = row 3
			myMainTableRow = new HTMLTableRow();
			myMainTable.AddInnerHTMLElement(myMainTableRow);

			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetHeight("160");
			myMainTableCell.SetWidth("100%");
			myMainTableCell.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myMainTableCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}
		catch (HTMLException e)
		{
			
				log.Error(e, "DirCardSubmitDependenciesView::Display The following error occured when trying to display the HTML: ");
			

			throw new XPException(m_asOwner.GetString(1203, "ptmsgs_portalbrowsingmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (IDirModelRO) model;
		m_asOwner     = parent;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLTableCell GetEmptyCell()
	{
		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		myCell.SetWidth("30");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		return myCell;
	}

	/**
	 * Returns the HTML for the successfully created message.
	 * This message can be customized for each Object by extending
	 * this Section and overriding this method.
	 *
	 * @return HTMLElementCollection
	 */
	protected HTMLElementCollection GetHTMLForDependencies()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTableRow myRow;
		HTMLTableCell myCell;

		int nParentFolderID  = m_model.GetCurrentFolderID();
		int nSubmittedCardID = m_model.GetCardID();

		// Row 1 - begin
		myRow = new HTMLTableRow();
		result.AddInnerHTMLElement(myRow);

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetColSpan("2");
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		myCell.AddInnerHTMLString(m_asOwner.GetString(1204, "ptmsgs_portalbrowsingmsgs"));

		// Row 1 - end
		// Row Card Name - begin
		myRow = new HTMLTableRow();
		result.AddInnerHTMLElement(myRow);

		myRow.AddInnerHTMLElement(GetEmptyCell());

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		myCell.AddInnerHTMLString(m_asOwner.GetString(1200, "ptmsgs_portalbrowsingmsgs"));
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_model.GetCardName(
					nSubmittedCardID)));

		// Row Card Name - end
		// Row Card Path - begin
		myRow = new HTMLTableRow();
		result.AddInnerHTMLElement(myRow);

		myRow.AddInnerHTMLElement(GetEmptyCell());

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("100%");
		myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
		myCell.AddInnerHTMLString(m_asOwner.GetString(1201, "ptmsgs_portalbrowsingmsgs"));
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
				m_model.GetFolderPath(nParentFolderID)));

		// Row Card Path - end
		result.AddInnerHTMLElement(DirConstants.CreateSpacerRow(2, 30));

		return result;
	}
}

