package com.plumtree.portalpages.browsing.directory.documentsubmitsimple;

import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 */
public class DirCardSubmitSimpleDP extends AFormDP
{
	public static final String STR_MVC_CLASS_NAME = "DirCardSubmitSimple";

	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		parent.SetHelpTopic( "PT_Submit_SimpleDocument" );
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()
	 */
	public String GetFormTitle()
	{
		return m_asOwner.GetString(83, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormPageType()
	 */
	public FormPageTypes GetFormPageType()
	{
		return FormPageTypes.NO_BUTTONS;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()
	{
		int nCardSubmitMode = ((IDirModelRO) this.m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME)).GetCardSubmitMode();
		switch (nCardSubmitMode)
		{
			case DirConstants.CARDSUBMITMODE_DONE:
				return m_asOwner.GetView(DirCardSubmitDoneView.STR_MVC_CLASS_NAME).Display();
			case DirConstants.CARDSUBMITMODE_UPLOADING:
				return m_asOwner.GetView(DirCardSubmitUploadingView.STR_MVC_CLASS_NAME).Display();
			default:
			case DirConstants.CARDSUBMITMODE_MAIN:
				return m_asOwner.GetView(DirCardSubmitSimpleView.STR_MVC_CLASS_NAME).Display();
		}
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		int nCardSubmitMode = ((IDirModelRO) this.m_asOwner.GetModel(DirModel.STR_MVC_CLASS_NAME)).GetCardSubmitMode();
		
		switch (nCardSubmitMode)
		{
			case DirConstants.CARDSUBMITMODE_DONE:
			case DirConstants.CARDSUBMITMODE_UPLOADING:
				break;
			case DirConstants.CARDSUBMITMODE_MAIN:
				myScripts.AddInnerHTMLElement(m_asOwner.GetView(
					DirCardSubmitSimpleView.STR_MVC_CLASS_NAME).DisplayJavascript());
				break;
		}

		return myScripts;
	}

	/** logger */
	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLAfterForm()
	 */
	public HTMLElementCollection DisplayHTMLAfterForm() 
	{
		/* JHQ 010704: bug 26798 - adding a dhtml div containing a 
		 * pretty uploading message section which is hidden unless 
		 * some JS changes the visiblitity style
		 */
		
		HTMLElementCollection result = new HTMLElementCollection();
		
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLDiv myDiv;

		// BEGIN uploading progress section			
		myDiv = new HTMLDiv();
		result.AddInnerHTMLElement(myDiv);
		myDiv.SetID("ProgressMessage");
		myDiv.SetStyle("position:relative; visibility:hidden");
		myDiv.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			
		HTMLTable divTable = new HTMLTable();
		myDiv.AddInnerHTMLElement(divTable);
		divTable.SetBorder("0");
		divTable.SetWidth("100%");
		divTable.SetCellPadding("0");
		divTable.SetCellSpacing("0");

		// BEGIN Message Row
		myRow = new HTMLTableRow();
		divTable.AddInnerHTMLElement(myRow);
			
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetAlign(CommonHTMLStrings.CENTER);
		myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
		myCell.AddInnerHTMLString(m_asOwner.GetString(1473, "ptmsgs_portalbrowsingmsgs")); 
		// END Message Row
			
		// BEGIN Animated GIF Row
		myRow = new HTMLTableRow();
		divTable.AddInnerHTMLElement(myRow);
			
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetNoWrap(true);
		myCell.SetAlign(CommonHTMLStrings.CENTER);

		HTMLImg mySendDocImg = (HTMLImg) PTImageType.ICON_PROGRESS.GetHTMLElement();
		mySendDocImg.SetAlt(m_asOwner.GetString(1473, "ptmsgs_portalbrowsingmsgs"));
		myCell.AddInnerHTMLElement(mySendDocImg);
		// END Animated GIF Row

		// END uploading progress section
		
		return result;
	}

}

