package com.plumtree.portalpages.browsing.directory.documentsubmitsimple;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tags.data.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.taskapi.portalui.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * 
 *
 * @author StephenC
 */
public class DirCardSubmitSimpleView implements IView {
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.directory.documentsubmitsimple.DirCardSubmitSimpleView");


	public static final String STR_MVC_CLASS_NAME = "DirCardSubmitSimple";

	public static final String SPACE = "&nbsp;";

	public static final String JAVASCRIPT_SUBMITCARD = "CheckAndCreateCard";

	public static final String JAVASCRIPT_CARDNAMECHANGED = "CardNameChanged";

	public static final String JAVASCRIPT_CARDDESCCHANGED = "CardDescChanged";

	public static final String JAVASCRIPT_REMOVEDEFAULTCARDNAME = "ClearName";

	public static final String JAVASCRIPT_REMOVEDEFAULTCARDDESC = "ClearDesc";

	public static final String JAVASCRIPT_SUPPLYNAMECHANGED =
		"SupplyNameChanged";

	public static final String JAVASCRIPT_SUPPLYDESCCHANGED =
		"SupplyDescChanged";

	public static final String JAVASCRIPT_CHECKUNCPATH = "IsValidUNCPath";

	public static final String JAVASCRIPT_UPLOADCARD = "UploadCard";
	
	public static final String JAVASCRIPT_DO_ON_LOAD = "doOnLoad";

	public static final String HTMLCHECKBOX_SUPPLYNAME = "in_cb_SupplyName";

	public static final String HTMLINPUT_CARDNAME = "in_tx_CardName";

	public static final String HTMLCHECKBOX_SUPPLYDESCRIPTION =
		"in_cb_SupplyDescription";

	public static final String HTMLINPUT_CARDDESCRIPTION =
		"in_tx_CardDescription";

	public static final String HTMLINPUT_WWWCardURL = "in_tx_CardURLTemp";

	public static final String HTMLINPUT_FileCardURL = "in_fi_CardURLTemp";

	public static final String HTMLINPUT_CardPath = "in_hi_CardPath";

	public static final String HTMLINPUT_ReturnURL = "in_hi_ReturnURL";

	public static final String HTMLINPUT_DUCheckDesc = "in_hi_DUCheckDesc";

	public static final String HTMLINPUT_DUCheckName = "in_hi_DUCheckName";

	public static final String HTMLSELECT_CardDataSource =
		"in_se_CardDataSource";

	public static final String HTMLBUTTON_EDITOR_FINISH = "in_bu_Done";

	public static final String HTMLBUTTON_EDITOR_CANCEL = "in_bu_Cancel";
	
	private AActivitySpace m_asOwner;

	private IModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() {
		return new DirCardSubmitSimpleView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display() {
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		HTMLInput myInput;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLH1 headerH1;
		
		HTMLTable mainTable = new HTMLTable();
		mainTable.SetBorder("0");
		mainTable.SetWidth("100%");
		mainTable.SetCellPadding("0");
		mainTable.SetCellSpacing("0");

		result.AddInnerHTMLElement(mainTable);

		try {
			// JHQ 010804: This is needed throughout for UI purposes
			BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
			boolean isNetscape =  browser.IsNetscape() || browser.IsNetscape4();

			// JHQ 010804: bug 26914 - need bigger text boxes for netscape
			int iHTMLInputSize;
			if (isNetscape)
			{ 
				iHTMLInputSize = 90;
			}
			else
			{
				iHTMLInputSize = 60;				
			}

			int nDefaultDataSource =
				((IDirModelRO) m_model).GetCardSubmitDataSource();

			ITaskAPIUIDirectory task = TaskAPIUIDirectoryService.GetInstance();

			// This returns the list of data sources with simple submit web services.
			IXPList sources = task.GetSubmitDataSources(m_asOwner);

			boolean bHasAccessToAtLeastOneDataSource = false;

			int nDataSourceCount = 0;

			if (null != sources) {
				nDataSourceCount = sources.GetSize();

				if (0 != nDataSourceCount) {
					bHasAccessToAtLeastOneDataSource = true;
				}
			}

			// begin datasource dropdown
			/* create the select element here so that we don't have to do
			 * two passes.  The select element will be added to the proper
			 * cell a few lines down from here.
			 */
			mySelect = new HTMLSelect(HTMLSELECT_CardDataSource, "e");
			mySelect.SetOnChange(
				AFormDP.JAVASCRIPT_SUBMIT_FORM
					+ "("
					+ DirRepostControl
						.POSTTOSELF_ACTION_CARDSIMPLESUBMIT_CHANGED_DS
					+ ");");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			boolean bDefaultDataSourceVisible = false;
			int nFirstDataSource = -1;

			// Iterate through all the supported datasources
			if (null != sources) {
				String strPropName;

				for (int i = 0; i < nDataSourceCount; i++) {

					HashtableDataObject source = (HashtableDataObject) sources.GetElement(i);

					int nDataSourceID = XPConvert.ToInteger(source.GetData(SubmitDataSourceConstants.ID));

					// commenting out for bug 9496535 this test is too restrictive 
					//if (!((IDirModelRO) m_model).IsValidSimpleSubmitSource(nDataSourceID))
					//{
					//	// The Publisher KD and Crawler Data Sources are set incorrectly
					//	// to be of type simple and advanced, but they are not (Bug#69636).
					//	// We need to remove these invalid options from the select list.
					//	continue;
					//}

					// If the default datasource does not appear (because of security),
					//   then the first datasource will be selected by default.
					if (0 == i) {
						nFirstDataSource = nDataSourceID;
					}

					/* we need to remove extra chars for display purposes */
					// SCC: it should be noted that the "m" charater is much wider than the "i" character.
					//      so while a name like "iiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii" might fit, the
					//      same name with "m"'s will not with non fixed-length fonts.
					if (!isNetscape)
					{
						strPropName = GeneralHelpers.TruncateLongString(
							source.GetData(SubmitDataSourceConstants.NAME),
							ObjEditorModel.OBJECT_NAME_TRUNCATE-15,
							false);
					}
					else
					{
						strPropName = GeneralHelpers.TruncateLongString(
							source.GetData(SubmitDataSourceConstants.NAME),
							ObjEditorModel.OBJECT_NAME_TRUNCATE-20,
							false);
					}
					
					myOption =
						new HTMLOption(XPConvert.ToString(nDataSourceID));
					mySpan = new HTMLSpan();
					myOption.AddInnerHTMLElement(mySpan);
					mySpan.AddInnerHTMLString(
						XPHttpUtility.HtmlEncode(strPropName));
					mySelect.AddInnerHTMLElement(myOption);

					if (nDataSourceID == nDefaultDataSource) {
						myOption.SetSelected(true);
						bDefaultDataSourceVisible = true;
					}
				}
			}

			// END DATASOURCE Row
			int nActiveDataSource =
				bDefaultDataSourceVisible
					? nDefaultDataSource
					: nFirstDataSource;


			boolean bHasAccessToWebService = true;
			/* JHQ 010604: bug 26772 - for document uploads we need to set the 
			 * encoding type 
			 * JHQ TODO: we should probably move this to an earlier process
			 * like on the AS.Init() or on the DisplayPage. 
			 */
			try 
			{
				if (((IDirModelRO) m_model).SupportsUpload(nActiveDataSource))
				{
					((AFormDP) m_asOwner.
						GetPage(DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME))
						.SetMultiPartEncoding(true);
				}
			}
			catch(PTException pte)
			{
				//check and see if this call failed because the user did not have access to the webservice
				if (PT_RESULTCODES.PT_E_ACCESSDENIED == pte.GetErrorCode())
				{
					bHasAccessToWebService = false;
				}
				else
				{
					throw pte;
				}
			}

			HTMLTable sectionTable;
			HTMLTable innerTable;

			myRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			sectionTable = new HTMLTable();
			sectionTable.SetBorder("0");
			sectionTable.SetWidth("100%");
			sectionTable.SetCellPadding("5");
			sectionTable.SetCellSpacing("0");
			myCell.AddInnerHTMLElement(sectionTable);

			// BEGIN Banner and Finish and Cancel buttons
			myRow = new HTMLTableRow();
			sectionTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

			// title
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			myCell.SetHeight("30");
			headerH1.AddInnerHTMLString(
				m_asOwner.GetString(84, "ptmsgs_portalbrowsingmsgs"));
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);

			// buttons
			myCell = new HTMLTableCell();
			myCell.SetAlign("right");
			myCell.SetWidth("175");
			myRow.AddInnerHTMLElement(myCell);

			if (bHasAccessToAtLeastOneDataSource && bHasAccessToWebService) {
				myInput =
					new HTMLInput(
						HTMLInputTypes.BUTTON,
						HTMLBUTTON_EDITOR_FINISH,
						"");
				myCell.AddInnerHTMLElement(myInput);

				myInput.SetValue(
					"  "
						+ m_asOwner.GetString(91, "ptmsgs_portalbrowsingmsgs")
						+ "  ");
				myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);

				/* if this datasource's webservice supports uploading of 
				 * documents, then have the form submit to that webservice 
				 * instead of back to the portal.
				 */
				if (((IDirModelRO) m_model).SupportsUpload(nActiveDataSource)) 
				{
					// JHQ 012604 - bug 27451: the JAVASCRIPT_UPLOADCARD 
					// used to have a javascript parameter where the upload url 
					// was passed in.  this was changed so that the upload url 
					// is determined in DisplayJavascript() passed in via
					// java.  this is so that we can use the function in 
					// PlumtreeHelpers.CreateEnterKeyPressedScript() for when 
					// users use the enter key instead of the "OK" button.

//					int webServiceID =
//						((DirModel) m_model).GetWebServiceID(nActiveDataSource);
//
//					String gwUrl =
//						GatewayHelpers.ConstructPrefPageLink(
//							m_asOwner,
//							webServiceID,
//							0,
//							0,
//							0,
//							PT_CLASSIDS.PT_WEBSERVICE_ID);
//
//					ASURL myCardSubmitURL = new ASURL(m_asOwner);
//					myCardSubmitURL.SetLinkGetCachedSpace(m_asOwner);
//					myCardSubmitURL.SetDisplayPage(
//						DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
//					myCardSubmitURL.SetControl(
//						DirRepostControl.STR_MVC_CLASS_NAME);
//
//					String uploadUrl =
//						gwUrl
//							+ ((IDirModelRO) m_model).GetUploadWSURL(
//								nActiveDataSource)
//							+ "?"
//							+ HTMLINPUT_ReturnURL
//							+ "="
//							+ myCardSubmitURL.GetURLAsString();

//					myInput.SetOnClick(
//						JAVASCRIPT_UPLOADCARD + "('" + uploadUrl + "');");

					myInput.SetOnClick(JAVASCRIPT_UPLOADCARD + "();");
				} 
				else 
				{
					myInput.SetOnClick(JAVASCRIPT_SUBMITCARD + "();");
				}
				// mj: removed 'Javascript:' from function name

				myCell.AddInnerHTMLString(SPACE);
				myCell.AddInnerHTMLString(SPACE);
			}

			// Cancel button
			myInput =
				new HTMLInput(
					HTMLInputTypes.BUTTON,
					HTMLBUTTON_EDITOR_CANCEL,
					"");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(
				m_asOwner.GetString(92, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick(
				"window.opener."
					+ DirCardSubmitSimpleDP.JAVASCRIPT_SUBMIT_FORM
					+ "("
					+ DirRepostControl.POSTTOSELF_ACTION_SIMPLEREPOST
					+ "); self.close();");

			// Add extra spacer row
			mainTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(1, 5));

			myRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			sectionTable = new HTMLTable();
			sectionTable.SetBorder("0");
			sectionTable.SetWidth("100%");
			sectionTable.SetCellPadding("0");
			sectionTable.SetCellSpacing("5");
			myCell.AddInnerHTMLElement(sectionTable);

			myRow = new HTMLTableRow();
			sectionTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			innerTable = new HTMLTable();
			innerTable.SetBorder("0");
			innerTable.SetWidth("100%");
			innerTable.SetCellPadding("2");
			innerTable.SetCellSpacing("2");
			innerTable.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell.AddInnerHTMLElement(innerTable);

			// BEGIN Title Instructions ROW
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			// title
			myCell = new HTMLTableCell();
			myCell.SetColSpan(CommonHTMLStrings.TWO);
			myRow.AddInnerHTMLElement(myCell);

			m_asOwner.SetHelpTopic("PT_Submit_SimpleDocument");
			myCell.AddInnerHTMLElement(
				HTMLConstructHelpers.GetSubHeader(
					m_asOwner.GetString(1212, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner));

			// END Title Instructions ROW

			myRow = new HTMLTableRow();
			sectionTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			innerTable = new HTMLTable();
			innerTable.SetBorder("0");
			innerTable.SetWidth("100%");
			innerTable.SetCellPadding("2");
			innerTable.SetCellSpacing("2");
			innerTable.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell.AddInnerHTMLElement(innerTable);

			sectionTable.AddInnerHTMLElement(
				DirConstants.CreateSpacerRow(2, 5));

			if (false == bHasAccessToAtLeastOneDataSource) {
				// Warning Text
				myRow = new HTMLTableRow();
				innerTable.AddInnerHTMLElement(myRow);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetColSpan("2");
				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);

				mySpan.AddInnerHTMLString(
					m_asOwner.GetString(94, "ptmsgs_portalbrowsingmsgs"));

				return result;
			}

			if (false == bHasAccessToWebService) 
			{
				// Warning Text
				myRow = new HTMLTableRow();
				innerTable.AddInnerHTMLElement(myRow);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetColSpan("2");
				mySpan = new HTMLSpan();
				myCell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);

				mySpan.AddInnerHTMLString(
					m_asOwner.GetString(1737, "ptmsgs_portalbrowsingmsgs"));

				return result;
			}

			// BEGIN DATASOURCE Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myCell.SetWidth("100");
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			myCell.AddInnerHTMLString(
				m_asOwner.GetString(85, "ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			/* this select element was created above when we were looping thru
			 * the available datasources */
			myCell.AddInnerHTMLElement(mySelect);

			boolean bIsWebDataSource =
				((IDirModelRO) m_model).IsWebDataSource(nActiveDataSource);
			String strURL =
				((IDirModelRO) m_model).GetCardSubmitURL(bIsWebDataSource);

			// BEGIN URL Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			myCell.AddInnerHTMLString(
				bIsWebDataSource
					? m_asOwner.GetString(86, "ptmsgs_portalbrowsingmsgs")
					: m_asOwner.GetString(87, "ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// Hidden Card Path
			myInput =
				new HTMLInput(HTMLInputTypes.HIDDEN, HTMLINPUT_CardPath, "");
			myCell.AddInnerHTMLElement(myInput);

			if (bIsWebDataSource) {
				myInput =
					new HTMLInput(
						HTMLInputTypes.TEXT,
						HTMLINPUT_WWWCardURL,
						"URL");
				myInput.SetSize(iHTMLInputSize);
			} else {
				myInput =
					new HTMLInput(
						HTMLInputTypes.FILE,
						HTMLINPUT_FileCardURL,
						"URL");
				myInput.SetSize(iHTMLInputSize-15);
			}

			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(strURL);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(1020);
			myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");

			// END URL Row
			// BEGIN EXAMPLE Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			myCell.AddInnerHTMLString(
				bIsWebDataSource
					? m_asOwner.GetString(89, "ptmsgs_portalbrowsingmsgs")
					: m_asOwner.GetString(88, "ptmsgs_portalbrowsingmsgs"));

			// END EXAMPLE Row
			// BEGIN Name Checkbox Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);

			myInput =
				new HTMLInput(
					HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_SUPPLYNAME,
					"");
			myInput.SetChecked(true);
			myInput.SetValue("x");
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			mySpan.AddInnerHTMLString(
				m_asOwner.GetString(1208, "ptmsgs_portalbrowsingmsgs"));
			mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			myInput.SetOnClick(JAVASCRIPT_SUPPLYNAMECHANGED + "();");
			myInput.SetChecked(false);

			// END Name Checkbox Row
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			myInput =
				new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_CARDNAME, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetValue(
			/*JHQ bug #29103: m_asOwner.GetString(1210, "ptmsgs_portalbrowsingmsgs")*/
			m_asOwner.GetString(1745, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetMaxLength(255);
			myInput.SetSize(iHTMLInputSize);
			myInput.SetOnClick(
				JAVASCRIPT_CARDNAMECHANGED + "(); return false;");
			myInput.SetOnKeyUp("bNameTextClicked=true; return false;");

			// END Name Row
			// BEGIN Description Checkbox Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myCell.SetNoWrap(true);
			myRow.AddInnerHTMLElement(myCell);

			myInput =
				new HTMLInput(
					HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_SUPPLYDESCRIPTION,
					"");
			myInput.SetChecked(true);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			mySpan.AddInnerHTMLString(
				m_asOwner.GetString(1209, "ptmsgs_portalbrowsingmsgs"));
			mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			myInput.SetChecked(false);
			myInput.SetOnClick(JAVASCRIPT_SUPPLYDESCCHANGED + "();");

			// END Description Checkbox Row
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			myInput =
				new HTMLInput(
					HTMLInputTypes.TEXT,
					HTMLINPUT_CARDDESCRIPTION,
					"");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetValue(
//JHQ bug #29103: m_asOwner.GetString(1211, "ptmsgs_portalbrowsingmsgs"));
				m_asOwner.GetString(1746, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetMaxLength(255);
			myInput.SetSize(iHTMLInputSize);
			myInput.SetOnClick(
				JAVASCRIPT_CARDDESCCHANGED + "(); return false;");
			myInput.SetOnKeyUp("bDescTextClicked=true; return false;");

			// END Description Row

			HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			myScript.AddInnerHTMLString(JAVASCRIPT_DO_ON_LOAD + "();\n");

			result.AddInnerHTMLElement(myScript);

			// spacer row
//JHQ 010704: bug 26798 - removing this spacer because we now have a progress
// section which is hidden from view, but this extra spacer was pushing the 
// progress section to low
//			innerTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(2, 15));

		} catch (HTMLException he) {			
			log.Error(he, STR_MVC_CLASS_NAME
				+ "::Display The following error occured when trying to display the HTML.");

			throw new XPException(
				m_asOwner.GetString(93, "ptmsgs_portalbrowsingmsgs"),
				he);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript() {
		HTMLScript myScript;

		// JHQ 012604 - bug 27451: need to change the submittion action
		// when doing file upload and determine the upload url.
		
		// JHQ 060804 - bug 32482: We can't just get the id that is on the 
		// model because on first load this will the default datasource, but
		// the default datasource may not be visible to the current user. 
		// we need loop thru this user's visiable datasources, and if the 
		// default is there, then use it, otherwise, use the first one.
		// TODO: this is the same loop as in Display() when we display all the
		// Datasources.  it would be nice not to do the same loop twice.
		int nActiveDataSourceID =  ((IDirModelRO) m_model).GetCardSubmitDataSource();
		boolean bDefaultDataSourceVisible = false;
		int nFirstDataSourceID = -1;
		
		IASQueryResult asqrFilters = ((IDirModelRO) m_model).GetFilteredDataSources();
		if (null != asqrFilters && asqrFilters.GetCount() > 0) 
		{
			nFirstDataSourceID = XPConvert.ToInteger(
				asqrFilters.GetFields(0,PT_PROPIDS.PT_PROPID_OBJECTID)); 

			// look for the default DS
			for (int i = 0; i < asqrFilters.GetCount(); i++) 
			{
				int nThisDataSourceID = XPConvert.ToInteger(
						asqrFilters.GetFields(i,PT_PROPIDS.PT_PROPID_OBJECTID));

				// we found it, break out of loop
				if (nActiveDataSourceID == nThisDataSourceID) 
				{
					bDefaultDataSourceVisible = true;
					break;
				}
			}

			// we didn't find the default DS, use the first one
			if (!bDefaultDataSourceVisible)
				nActiveDataSourceID = nFirstDataSourceID;
		}


		String sUploadUrl = "";
		if (((IDirModelRO) m_model).SupportsUpload(nActiveDataSourceID))
		{ 
			int webServiceID =
				((DirModel) m_model).GetWebServiceID(nActiveDataSourceID);

			String gwUrl =
				GatewayHelpers.ConstructPrefPageLink(
					m_asOwner,
					webServiceID,
					0,
					0,
					0,
					PT_CLASSIDS.PT_WEBSERVICE_ID);

			ASURL myCardSubmitURL = new ASURL(m_asOwner);
			myCardSubmitURL.SetLinkGetCachedSpace(m_asOwner);
			myCardSubmitURL.SetDisplayPage(
				DirCardSubmitSimpleDP.STR_MVC_CLASS_NAME);
			myCardSubmitURL.SetControl(
				DirRepostControl.STR_MVC_CLASS_NAME);

			sUploadUrl =
				gwUrl
					+ GatewayHelpers.CreateGatewayFriendlyURL(
						((IDirModelRO) m_model).GetUploadWSURL(nActiveDataSourceID)
						+ "?"
						+ HTMLINPUT_ReturnURL
						+ "="
						+ myCardSubmitURL.GetURLAsString());

			myScript = PlumtreeHelpers.
				GetExecuteViaEnterJScript(JAVASCRIPT_UPLOADCARD);
		}
		else
		{
			myScript = PlumtreeHelpers.
				GetExecuteViaEnterJScript(JAVASCRIPT_SUBMITCARD);
		}

		try {

			String sFormName = "document."+DirCardSubmitSimpleDP.HTMLFORM_NAME;
			
			XPStringBuilder sb = new XPStringBuilder(400);

			// JHQ 012604 - bug 27451: this function used to have a javascript 
			// parameter where the upload url was passed in.  changed this so 
			// that the upload url is determined aboved and passed in via
			// java.  this is so that we can use the function in 
			// PlumtreeHelpers.CreateEnterKeyPressedScript() for when users
			// use the enter key instead of the "OK" button.
			sb.Append("function ").Append(JAVASCRIPT_UPLOADCARD).Append("()");
			sb.Append("{\n");
			sb.Append("    var wsURL = \"").Append(sUploadUrl).Append("\";\n");
			sb
				.Append("    var filePath = document.")
				.Append(DirCardSubmitSimpleDP.HTMLFORM_NAME)
				.Append(".")
				.Append(HTMLINPUT_FileCardURL)
				.Append(".value; \n");

			sb.Append("    if (\"\" == filePath) \n");
			sb.Append("    {\n");
			sb
				.Append("       alert(\"")
				.Append(m_asOwner.GetString(95, "ptmsgs_portalbrowsingmsgs"))
				.Append("\");\n");

			sb.Append("       return false;\n");
			sb.Append("    }\n");

			sb.Append("  if(document.").Append(
				DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLCHECKBOX_SUPPLYNAME
					+ ".checked == true)");
			sb.Append("  {\n");
			sb.Append(
				"    var cardName = document."
					+ DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLINPUT_CARDNAME
					+ ".value;\n");

			sb.Append(
				"    if(\"\" == cardName || \""
//JHQ bug #29103:	+ m_asOwner.GetString(1210, "ptmsgs_portalbrowsingmsgs")
					+ m_asOwner.GetString(1745, "ptmsgs_portalbrowsingmsgs")
					+ "\"== cardName)\n");
			sb.Append("    {\n");
			sb.Append(
				"        document."
					+ DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLINPUT_CARDNAME
					+ ".value = \"\";\n");
			sb.Append(
				"        alert(\""
					+ m_asOwner.GetString(1206, "ptmsgs_portalbrowsingmsgs")
					+ "\");\n");
			sb.Append("        return false;\n");
			sb.Append("    } \n");
			sb.Append("  }\n");

			sb
				.Append("    if (bNameCheckValue) \n")
				.Append("	   {\n")
				.Append(
						"          wsURL += \"&"
						+ HTMLINPUT_DUCheckName
						+ "=Y\";\n")
				.Append("    }\n");

			sb
				.Append("    if (bDescCheckValue) \n")
				.Append("	   {\n")
				.Append(
						"          wsURL += \"&"
						+ HTMLINPUT_DUCheckDesc
						+ "=Y\";\n")
				.Append("    }\n");

			sb.Append("    document.").Append(
				DirCardSubmitSimpleDP.HTMLFORM_NAME).Append(
				".action = wsURL;\n\n\n");

			/* JHQ 010704: bug 26798 - call the JS function that makes the 
			 * progress message div section visable. 
			 */
			sb.Append("  setTimeout(\"showProgressMessage()\",1);\n");

			/* JHQ 010704: bug 26798 - disables the finish&cancel buttons so that
			 * impatient users don't go buck wild on them
			 */
			sb.Append("  //disable the finish and cancel buttons\n");
			sb.Append("  document."
						+DirCardSubmitSimpleDP.HTMLFORM_NAME
						+"."
						+HTMLBUTTON_EDITOR_FINISH
						+".disabled=true;\n");
			sb.Append("  document."
						+DirCardSubmitSimpleDP.HTMLFORM_NAME
						+"."
						+HTMLBUTTON_EDITOR_CANCEL
						+".disabled=true;\n\n\n");

			sb.Append("    document.").Append(
				DirCardSubmitSimpleDP.HTMLFORM_NAME).Append(
				".submit();\n");

			sb.Append("    return true;\n");

			sb.Append("}\n");


			/* JHQ 010704: bug 26798 - check the browser type for appropriate dhtml */
			sb.Append("var isDOM = (document.getElementById) ? true : false;\n");
			sb.Append("var isNS4 = (document.layers) ? true : false;\n");
			sb.Append("var isIE = (document.all) ? true : false;\n");
			
			/* JHQ 010704: bug 26798 - js function that that shows progress 
			 * section */
			sb.Append("function showProgressMessage()\n");
			sb.Append("{\n");
			sb.Append("  if (isNS4) document.ProgressMessage.visibility = \"visible\";\n");
			sb.Append("  else if (isIE) document.all.ProgressMessage.style.visibility = \"visible\";\n");
			sb.Append("  else if (isDOM) document.getElementById(\"ProgressMessage\").style.visibility = \"visible\";\n");
			sb.Append("}\n");
			

			sb.Append("function ").Append(JAVASCRIPT_CHECKUNCPATH).Append(
				"(sPath)\n");
			sb.Append("{\n");
			sb.Append("   var len=sPath.length;\n");
			sb.Append("   if(len <= 2) return false;\n");
			BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
			if (!browser.IsMac()) {
				// don't check for UNC path if submitting from a MAC, because MACs don't support it
				sb.Append("   for (i = 0; i < 2; i++) \n");
				sb.Append("    { \n");
				sb.Append("      strChar = sPath.charAt(i); \n");
				sb.Append("      if(\"\\\\\" != strChar) return false;\n");
				sb.Append("   } \n");
			}
			sb.Append("   return true; \n");
			sb.Append("}\n");


			// The JavaScript below checks if the Card Path is empty.
			/* JHQ 012904 - bug 27535: try/catch blocks don't work in netscape
			 * 4.xx.  Using if/else statements instead to catch html elements
			 * that are not defined, which is what the try/catch blocks were
			 * being used for.  Did alittle tidying of the code too.
			 */
			sb.Append("function ").Append(JAVASCRIPT_SUBMITCARD).Append("()\n");
			sb.Append("{\n"); 

			sb.Append("  /* if we are using a www url */\n");
			sb.Append("  if(typeof("+sFormName+"."+HTMLINPUT_WWWCardURL+") != \"undefined\")\n");
			sb.Append("  {\n");
			sb.Append("    var wwwPath="+sFormName+"."+HTMLINPUT_WWWCardURL+".value;\n\n");
			sb.Append("    if (\"\" == wwwPath || \"http://\" == wwwPath || \"HTTP://\" == wwwPath) \n");
			sb.Append("    {\n");
			sb.Append("        alert(\""+m_asOwner.GetString(95, "ptmsgs_portalbrowsingmsgs")+"\");\n");
			sb.Append("        return false;\n");
			sb.Append("    } \n\n");
			sb.Append("    "+sFormName+"."+HTMLINPUT_CardPath+".value = wwwPath;\n");
			sb.Append("  }\n\n");
			
			sb.Append("  /* else if we are using the file path input */\n");
			sb.Append("  else if(typeof("+sFormName+"."+HTMLINPUT_FileCardURL+") != \"undefined\")\n");
			sb.Append("  {\n");
			sb.Append("    var filePath="+sFormName+"."+HTMLINPUT_FileCardURL+".value;\n\n");
			sb.Append("    if (\"\" == filePath || \"http://\" == filePath || \"HTTP://\" == filePath) \n");
			sb.Append("    {\n");
			sb.Append("      alert(\""+m_asOwner.GetString(95, "ptmsgs_portalbrowsingmsgs")+"\");\n");
			sb.Append("      return false;\n");
			sb.Append("    }\n\n");
			sb.Append("    if(false == "+JAVASCRIPT_CHECKUNCPATH+"(filePath))\n");
			sb.Append("    {\n");
			sb.Append("      alert(\""+m_asOwner.GetString(1207, "ptmsgs_portalbrowsingmsgs")+ "\");\n");
			sb.Append("      return false;\n");
			sb.Append("    }\n\n");
			sb.Append("    "+sFormName+"."+ HTMLINPUT_CardPath+".value = filePath;\n");
			sb.Append("  }\n\n");
			
			sb.Append("  /* else we have no input... not good */\n");
			sb.Append("  else \n");
			sb.Append("  {\n");
			sb.Append("    alert(\""+m_asOwner.GetString(95, "ptmsgs_portalbrowsingmsgs")+"\");\n");
			sb.Append("    return false;\n");
			sb.Append("  }\n\n");

			sb.Append("  /* check the card name, which can not be blank */\n"); 			
			sb.Append("  if("+sFormName+"."+HTMLCHECKBOX_SUPPLYNAME+".checked == true)\n");
			sb.Append("  {\n");
			sb.Append("    var cardName = "+sFormName+"."+HTMLINPUT_CARDNAME+".value;\n");
//JHQ bug #29103:	sb.Append("    if(\"\" == cardName || \""+m_asOwner.GetString(1210, "ptmsgs_portalbrowsingmsgs")+"\"== cardName)\n");
			sb.Append("    if(\"\" == cardName || \""+m_asOwner.GetString(1745, "ptmsgs_portalbrowsingmsgs")+"\"== cardName)\n");
			sb.Append("    {\n");
			sb.Append("      "+sFormName+"."+HTMLINPUT_CARDNAME+".value = \"\";\n");
			sb.Append("      "+sFormName+"."+HTMLINPUT_CardPath+".value = \"\";\n\n");
			sb.Append("      alert(\""+m_asOwner.GetString(1206, "ptmsgs_portalbrowsingmsgs")+"\");\n");
			sb.Append("      return false;\n");
			sb.Append("    }\n");
			sb.Append("  }\n\n");
			
			sb.Append("  /* The JavaScript below submits the form */\n");
			sb
				.Append("  ")
				.Append(AFormDP.JAVASCRIPT_SUBMIT_FORM)
				.Append("(")
				.Append(
					DirRepostControl.POSTTOSELF_ACTION_CARDSUBMITSIMPLE_MAIN)
				.Append(");\n");
			sb.Append("  return true;\n");
			
			sb.Append("}\n\n");

			sb.Append("bSupplyNameClicked = false;\n");
			sb.Append("bNameTextClicked = false;\n");
			sb.Append("bNameCheckValue = false;\n");
			sb.Append("bSupplyDescClicked = false;\n");
			sb.Append("bDescTextClicked = false;\n");
			sb.Append("bDescCheckValue = false;\n\n");

			// The JavaScript below clears the text box and checks the checkbox
			sb.Append("function ").Append(JAVASCRIPT_CARDNAMECHANGED).Append(
				"()\n");
			sb.Append("{\n");
			sb.Append("  if(bSupplyNameClicked || bNameTextClicked) return;\n");
			sb.Append("   document.").Append(
				DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLCHECKBOX_SUPPLYNAME
					+ ".checked = true;\n");
			sb.Append("   " + JAVASCRIPT_REMOVEDEFAULTCARDNAME + "();\n");
			sb.Append("   bSupplyNameClicked = true;");
			sb.Append("   bNameTextClicked = true;");
			sb.Append("   bNameCheckValue = true;");
			sb.Append("}\n");

			// The JavaScript below clears the text box and checks the checkbox
			sb.Append("function ").Append(JAVASCRIPT_CARDDESCCHANGED).Append(
				"()\n");
			sb.Append("{\n");
			sb.Append("  if(bSupplyDescClicked || bDescTextClicked) return;\n");
			sb.Append("   document.").Append(
				DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLCHECKBOX_SUPPLYDESCRIPTION
					+ ".checked = true;\n");
			sb.Append("   " + JAVASCRIPT_REMOVEDEFAULTCARDDESC + "();\n");
			sb.Append("   bSupplyDescClicked = true;");
			sb.Append("   bDescTextClicked = true;");
			sb.Append("   bDescCheckValue = true;");
			sb.Append("}\n");

			// The JavaScript below clears the text box 
			sb.Append("function ").Append(JAVASCRIPT_SUPPLYNAMECHANGED).Append(
				"()\n");
			sb.Append("{\n");
			sb.Append("  bNameCheckValue = !bNameCheckValue;\n");
			sb.Append(
				"  if(bSupplyNameClicked || bNameTextClicked) return bNameCheckValue;\n");
			sb.Append(
				"      document."
					+ DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLINPUT_CARDNAME
					+ ".value = \"\";\n");

			sb.Append("}\n");

			// The JavaScript below clears the text box 
			sb.Append("function ").Append(JAVASCRIPT_SUPPLYDESCCHANGED).Append(
				"()\n");
			sb.Append("{\n");
			sb.Append("  bDescCheckValue = !bDescCheckValue;\n");
			sb.Append(
				"  if(bSupplyDescClicked || bDescTextClicked) return bDescCheckValue;\n");
			sb.Append(
				"      document."
					+ DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLINPUT_CARDDESCRIPTION
					+ ".value = \"\";\n");
			sb.Append("}\n");

			// The JavaScript below clears the text box 
			sb.Append("function ").Append(
				JAVASCRIPT_REMOVEDEFAULTCARDNAME).Append(
				"()\n");
			sb.Append("{\n");
			sb
				.Append(
					"   if(document."
						+ DirCardSubmitSimpleDP.HTMLFORM_NAME
						+ "."
						+ HTMLINPUT_CARDNAME
						+ ".value == \"")
//JHQ bug #29103: .Append(m_asOwner.GetString(1210, "ptmsgs_portalbrowsingmsgs"))
				.Append(m_asOwner.GetString(1745, "ptmsgs_portalbrowsingmsgs"))
				.Append("\")\n");
			sb.Append("   {\n");
			sb.Append(
				"      document."
					+ DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLINPUT_CARDNAME
					+ ".value = \"\";\n");
			sb.Append("   }\n");
			sb.Append("}\n");

			// The JavaScript below clears the text box 
			sb.Append("function ").Append(
				JAVASCRIPT_REMOVEDEFAULTCARDDESC).Append(
				"()\n");
			sb.Append("{\n");
			sb
				.Append(
					"   if(document."
						+ DirCardSubmitSimpleDP.HTMLFORM_NAME
						+ "."
						+ HTMLINPUT_CARDDESCRIPTION
						+ ".value == \"")
//JHQ bug #29103:		.Append(m_asOwner.GetString(1211, "ptmsgs_portalbrowsingmsgs"))
				.Append(m_asOwner.GetString(1746, "ptmsgs_portalbrowsingmsgs"))
				.Append("\")\n");
			sb.Append("   {\n");
			sb.Append(
				"      document."
					+ DirCardSubmitSimpleDP.HTMLFORM_NAME
					+ "."
					+ HTMLINPUT_CARDDESCRIPTION
					+ ".value = \"\";\n");
			sb.Append("   }\n");
			sb.Append("}\n");

			sb.Append("function ").Append(JAVASCRIPT_DO_ON_LOAD).Append("()\n");
			sb.Append("{\n");
			sb.Append("	var form = "+sFormName+";\n");
			sb.Append("	if(typeof(form."+HTMLINPUT_FileCardURL+") != \"undefined\")\n");
			sb.Append("	{\n");
			sb.Append("		form."+HTMLINPUT_FileCardURL+".focus();\n");
			sb.Append("	}\n");
			sb.Append("	else \n");
			sb.Append("	{\n");
			sb.Append("		form."+HTMLINPUT_WWWCardURL+".focus();\n");
			sb.Append("	}\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		} catch (HTMLException he) {			
			log.Error(he, "DirCardSubmitSimpleView::DisplayJavascript The following error occured when trying to display the JavaScript.");

			throw new XPException(
				m_asOwner.GetString(96, "ptmsgs_portalbrowsingmsgs"),
				he);
		}

		return myScript;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent) {
		m_model = model;
		m_asOwner = parent;
	}
}