package com.plumtree.portalpages.browsing.directory.opendoc;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * 
 *
 * @author John Osborne
 */
public class OpenDocDP implements IDisplayPage
{
	
	public static final String STR_MVC_CLASS_NAME = "OpenDoc";

	
	private AActivitySpace m_asOwner;

	
	private IOpenDocModelRO m_modMyModelRO;

	/**
	 * 
	 *
	 * @param webData 
	 */
	public void Display(IWebData webData)
	{
		// DCA - this is currently not being used anymore. The code was moved to the OpenDocControl class
		// so that we can do an internal redirect to the Gateway AS and have the gateway URL hidden.
		
		// Get the URL we want to redirect to.
		String strOpenDocURL = m_modMyModelRO.GetOpenDocURL();
		
		// RWW - Bug 33047, the URL being returned isn't completely
		// encoded.  We can't just use a EncodeURL because parts of
		// the URL may already be encoded.  If we end up using this
		// in other parts of the UI, move to a helper class.	
		XPStringBuilder sbOpenDocURLEncoded = new XPStringBuilder(512);		
		byte[] bytesOpenDocURL = XPEncoding.GetBytes(strOpenDocURL, XPStringUtility.DEFAULT_ENCODING);				
		
		for (int i = 0; i < bytesOpenDocURL.length; i ++)
		{
			byte byteCurrentByte = bytesOpenDocURL[i];			

			// In C# a "byte" is unsigned and therefore we need to 
			// check above 127.  In JAVA a "byte" is signed and we
			// therefore need to check for below 0.
			if ((byteCurrentByte < 0) || (byteCurrentByte > 127))
			{
				String strHexRepOfByte = XPConvert.ToHexString(byteCurrentByte);
				sbOpenDocURLEncoded.Append("%").Append(strHexRepOfByte.substring(strHexRepOfByte.length() - 2, strHexRepOfByte.length()));
			}
			else
			{
				sbOpenDocURLEncoded.Append(XPConvert.ToChar(byteCurrentByte));
			}
		}
		
		// Send redirect to the properly encoded URL.
		webData.SendRedirect(sbOpenDocURLEncoded.ToString());
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#GetOwner()
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace _asOwner)
	{
		m_asOwner		   = _asOwner;
		m_modMyModelRO     = (IOpenDocModelRO) m_asOwner.GetModel(OpenDocModel.STR_MVC_CLASS_NAME);
	}
}

