package com.plumtree.portalpages.browsing.directory.properties;

import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.keywords.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author joseq
 *
 * extends KeywordsView so that it can be used with DirAS with in a non-EditorAS.
 * KeywordsView.Init() is overridding so that the explicit casting of the activityspace
 * to EditorAS does not occur.  Also, we wrap the Keywords view in a table to 
 * keep the Properties display page uniform. 
 */
public class DirKeywordsView extends KeywordsView 
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "DirKeywords";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirKeywordsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the View with the read-only Model and the Activity Space.
	 *
	 * @param model
	 * @param parent
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model = model;
		m_asOwner = parent;
	}

	/**
	 * Returns the HTML for the View.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
 		HTMLElementCollection resultWrapper = new HTMLElementCollection();
 		
		/* wrapper table */
		HTMLTable mainTable = new HTMLTable();
		resultWrapper.AddInnerHTMLElement(mainTable);
		mainTable.SetBorder("0");
		mainTable.SetWidth("100%");
		mainTable.SetCellPadding("2");
		mainTable.SetCellSpacing("2");

		/* spacer */
		mainTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(2, 25));

		/* row + cell */
		HTMLTableRow myRow = new HTMLTableRow();
		mainTable.AddInnerHTMLElement(myRow);
		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetColSpan("2");

		/* add the original Keywords view */
		myCell.AddInnerHTMLElement(super.Display());

		return resultWrapper;
	} 
}