package com.plumtree.portalpages.browsing.editors.community;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.communities.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.expandablelist.template.*;
import com.plumtree.portaluiinfrastructure.securitymatrix.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class CommunityEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.community.CommunityEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommunityEditor";

	/** Class Name */
	private static final String sClassName = "com.plumtree.portalpages.browsing.editors.community.CommunityEditorAS";

	/** Javascript Function: alertSaveForPrefs */
	public static final String JS_ALERTSAVEFORPREFS_FUNC = "alertSaveForPrefs";
	
	/** Javascript Function: commTempSelected */
	public static final String JS_COMM_TEMP_SELECTED = "commTempSelected";
	
	public static final String PLUGIN_COMMUNITY_TEMPLATE_SELECTOR = "CommunityTemplateSelector";

	/** PageList Model for adding pages */
	public static final String PLUGIN_PAGE_LIST = "PageList";

	/** SelectPTObject Model for selecting a footer */
	public static final String PLUGIN_SUBCOMMUNITY_LIST = "SubcommunityList";

	/** SelectPTObject Model for selecting a footer */
	public static final String PLUGIN_COMMUNITY_GROUP_LIST = "CommunityGroupList";

	/** SelectPTObject Model for selecting a footer */
	public static final String PLUGIN_COMMUNITY_PORTLET_LIST = "CommunityPortletList";

	/** Control for header and footer */
	public static final String PLUGIN_HEADER_AND_FOOTER_SELECTOR = "HeaderAndFooterSelector";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityEditorAS();
	}

	/**
	 * This is a helper method that all classes that inherit from AFormDP can
	 * override if they like.  The method provides a hook into the head so
	 * that DP's can add javascript. Simply override and return and
	 * HTMLScript.  Also, it is best to return the results of the
	 * DisplayJavaScript functions from the appropriate views.
	 *
	 * @return HTMLScriptCollection the Javascript from the Child IViews
	 * @throws HTMLException 
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostAS#DisplayCommonJavaScript()
	 *      Override this method to Display javascript from child IViews
	 */
	public HTMLScriptCollection DisplayCommonJavaScript()
	{
		HTMLScriptCollection scripts = super.DisplayCommonJavaScript();

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		scripts.AddInnerHTMLElement(script);

		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("\n").Append("function ").Append(JS_ALERTSAVEFORPREFS_FUNC)
		.Append("()").Append("{\n").Append("		if ( confirm('")
		.Append(GetString(1228, "ptmsgs_portalbrowsingmsgs")).Append("') )\n").Append("		{\n")
		.Append("			return true;").Append("		}\n").Append("		return false;")
		.Append("}\n");
		script.AddInnerHTMLString(sb.ToString());

		return scripts;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor#GetDependenciesViewName()
	 */
	public String GetDependenciesViewName()
	{
		return (CommunityDependenciesView.STR_MVC_CLASS_NAME);
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return GetString(217, "ptmsgs_portalbrowsingmsgs");
		}
		return (XPResourceManager.FormatMessage(GetString(1710, "ptmsgs_portalbrowsingmsgs"), GetObjectName()));
	}

	/**
	 * This adds the community invitation link to the help banner.
	 * @return 
	 */
	public PTConstruct GetSubBanner()
	{
		PTConstruct mySubBanner = UIConstructFactory.GetConstruct(PTBannerType.BANNER_ACTION_BAR);
		
		CommunityEditorModel modelCommunity = (CommunityEditorModel) GetModel(CommunityEditorModel.STR_MVC_CLASS_NAME);

		try
		{
			// Add your buttons to the banner
			if (EditorStartControl.EDITOR_START_FLAG_EDIT == modelCommunity.GetEditorType())
			{ 
				// Send to Others Link
				PTConstruct buttonConstruct = UIConstructFactory.GetConstruct(PTButtonType.SEND_TO_OTHERS,
						true, this);
						
				ElementName eName = PTButtonType.SEND_TO_OTHERS.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE);
				// "Send To Others"
				buttonConstruct.ReplaceNestedElementsWithHTMLString(eName,
					this.GetString(640, "ptmsgs_portalcommonmsgs"));
				
				ConstructFactory.SetAltOnButtonImages(buttonConstruct, 
					this.GetString(640, "ptmsgs_portalcommonmsgs"));
	
				HTMLAnchor myAnchor		    = (HTMLAnchor) buttonConstruct.GetNestedElement(PTButtonType.SEND_TO_OTHERS.ANCHOR_ELEMENT_NAME);

				ASURL asurl = new ASURL(this);
				asurl.SetLinkGetSpaceIfCached(CommunitySelectionEditorAS.STR_MVC_CLASS_NAME, this);
				asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
				asurl.SetDisplayPage(CommunityInvitationPopupDP.STR_MVC_CLASS_NAME);
				asurl.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
					XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_CREATE));
				asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationID,
					XPConvert.ToString(modelCommunity.GetObjectID()));
				asurl.AddControlArgument(InvitationPopupControl.strTemporaryInvitationName,
					modelCommunity.GetObjectName());
				String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
				myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
				myAnchor.SetOnClick(strJSUtilVersionPrefix+"PTWindowUtil.openWindow('" +
					asurl.GetURLAsString() + "', 'SendToOthers', '250','600');return false;");
				mySubBanner.AddElementToNestedElement(PTBannerType.BANNER_ACTION_BAR.EXTENDABLE_CELL_ELEMENT_NAME,
					myAnchor);
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "CommunityEditorModel::AddSendToOthersButtonToHelpBanner: The following error occured when trying to get the help banner: " +
					e.getMessage());
			
		}

		return mySubBanner;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (CommunityEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = CommunityEditorModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);
		
		// Bug 7825774 - Disable overwriting of subspaces for the Community Editor space
		// as this wipes out caches of TreeAS objects when viewing Group memberships. This
		// causes an error when the user clicks on a group that was previously clicked on
		// and cached. RefreshTreeControl assumes that the model has already been initialized
		// and does not handle re-initialization of the TreeModel so these cached objects should
		// stay around for the duration of the Community Editor being opened. The code that wiped
		// out the cached TreeAS is in AActivitySpace.RegisterSubSpace when a new TreeAS is created 
		// and initialized.
		((AActivitySpace) this).SetOverWriteSubSpaces(false);

		// Register Security ABO Display Pages and Controls
		ABOBlankSelectDP dpABOBlankSelect = new ABOBlankSelectDP();
		dpABOBlankSelect.SetRepostControlName(CommunityEditorRepostControl.STR_MVC_CLASS_NAME);
		RegisterPage(dpABOBlankSelect);
		ABOPopupSelectDP dpABOPopupSelect = new ABOPopupSelectDP();
		dpABOPopupSelect.SetViewName(ABOCommPopupSelectView.STR_MVC_CLASS_NAME);
		RegisterPage(dpABOPopupSelect);
		ABOBlankResultsDP dpABOBlankResults = new ABOBlankResultsDP();
		dpABOBlankResults.SetRepostControlName(CommunityEditorRepostControl.STR_MVC_CLASS_NAME);
		RegisterPage(dpABOBlankResults);
		RegisterPage(new ABOPopupResultsDP());

		// Register Security ABO Views
		RegisterView(ABOCommPopupSelectView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ABOPopupResultsView.STR_MVC_CLASS_NAME, myModel);

		// Register DisplayPages
		CommunityEditorPagesDP myPage = new CommunityEditorPagesDP();
		myPage.AddToValidationFunction(JS_COMM_TEMP_SELECTED);
		RegisterPage(myPage);
		RegisterPage(new HeaderAndFooterSelectorDP());
		RegisterPage(new CommunityEditorPortletPreferencesDP());
		RegisterPage(new CommunityEditorSubcommunityDP());
		RegisterPage(new CommunityEditorCommGroupDP());
		RegisterPage(new CommunityEditorCommPortletDP());

		// Register Views
		RegisterView(PortletPreferencesView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(DisableSiteMapView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(HeaderAndFooterSelectorView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(CommunityDependenciesView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(CommunityEditorRepostControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(HeaderAndFooterRepostControl.STR_MVC_CLASS_NAME,
			PLUGIN_HEADER_AND_FOOTER_SELECTOR, myModel);
		RegisterControl(PageCreateDefaultControl.STR_MVC_CLASS_NAME, myModel);

		// Register the page list as a plug-in section
		RegisterModel(PageListModel.STR_MVC_CLASS_NAME, PLUGIN_PAGE_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myPageListModel = GetModel(PLUGIN_PAGE_LIST);
		RegisterView(PageListView.STR_MVC_CLASS_NAME, PLUGIN_PAGE_LIST,
			myPageListModel);
		RegisterControl(PageListControl.STR_MVC_CLASS_NAME,
			PLUGIN_PAGE_LIST, myPageListModel);

		// Register the community template selector as a plug-in section
		RegisterModel(CommunityTemplateSelectorModel.STR_MVC_CLASS_NAME, PLUGIN_COMMUNITY_TEMPLATE_SELECTOR);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myCommunityTemplateSelectorModel = GetModel(PLUGIN_COMMUNITY_TEMPLATE_SELECTOR);
		RegisterView(TemplateListView.STR_MVC_CLASS_NAME, PLUGIN_COMMUNITY_TEMPLATE_SELECTOR,
				myCommunityTemplateSelectorModel);	
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
				PLUGIN_COMMUNITY_TEMPLATE_SELECTOR, myCommunityTemplateSelectorModel);
		
		// --- CommunityGroups list/create page BEGIN
		//
		// Register the Subcommunity list/create page plugin model.
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITY_GROUP_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPTObjectModel = GetModel(PLUGIN_COMMUNITY_GROUP_LIST);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITY_GROUP_LIST, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITY_GROUP_LIST, mySelectPTObjectModel);

		//
		// CommunityGroups list/create page END
		// --- Subcommunity list/create page BEGIN
		//
		// Register the Subcommunity list/create page plugin model.
		RegisterModel(CommunityEditorSubcommunityModel.STR_MVC_CLASS_NAME,
			PLUGIN_SUBCOMMUNITY_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		mySelectPTObjectModel = GetModel(PLUGIN_SUBCOMMUNITY_LIST);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			PLUGIN_SUBCOMMUNITY_LIST, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_SUBCOMMUNITY_LIST, mySelectPTObjectModel);

		// 
		// Subcommunity list/create page END
		// --- CommunityPortlet list/create page BEGIN
		//
		// Register the Subcommunity list/create page plugin model.
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITY_PORTLET_LIST);

		// Get back the Model we just registered because we need it to register the Section and the Control
		mySelectPTObjectModel = GetModel(PLUGIN_COMMUNITY_PORTLET_LIST);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITY_PORTLET_LIST, mySelectPTObjectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			PLUGIN_COMMUNITY_PORTLET_LIST, mySelectPTObjectModel);

		//
		// CommunityPortlet list/create page END
		// Set default page
		SetCurrentPage(CommunityEditorPagesDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "Edit Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(220,
					"ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityEditorPagesDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityEditorSubcommunityDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityEditorCommGroupDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityEditorPortletPreferencesDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME);
		//m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,	// DCA - not needed, already shows up in standard setting
		//	ObjectSecurityDP.STR_MVC_CLASS_NAME);

		((ObjectSecurityModel) GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetLeftNavString(GetString(
				221, "ptmsgs_portalbrowsingmsgs"));
		
		m_mEditorMenu.AddJavaScriptValidationToLink(CommunityEditorPortletPreferencesDP.STR_MVC_CLASS_NAME,
			JS_ALERTSAVEFORPREFS_FUNC);

		// END Sub menu "Edit Settings"

		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1229, "ptmsgs_portalbrowsingmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"


		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				
				tm.SetGeneratingClass( sClassName );
				

				int iTitleId = 90;
				int iTipId = 91;
				int iSecondaryTipId = 92;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}								


				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		boolean bAccess = super.CheckBasicAccess(strPage, strControl, bSameSpace);

		// mrc - if this is the control to create a single page in a community, allow access;
		// the control checks security later during CheckActionSecurityAndExecute
		if (PageCreateDefaultControl.STR_MVC_CLASS_NAME.equals(strControl))
			bAccess = true;

		return bAccess;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage(com.plumtree.uiinfrastructure.activityspace.IDisplayPage)
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		// Must override help topic for common security page for communities.
		if( ObjectSecurityDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_Security" );
		}
		else if ( CommunityEditorPagesDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_CommunityPages" );
		}
		else if ( HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_HeaderandFooter" );
		}
		else if ( CommunityEditorCommGroupDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_ThisCommunitysGroups" );
		}
		else if ( CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_ThisCommunitysPortlets" );
		}
		else if ( CommunityEditorPortletPreferencesDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_PortletPreferences" );
		}
		else if ( CommunityEditorSubcommunityDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Community_Subcommunities" );
		}
	}
}

