package com.plumtree.portalpages.browsing.editors.community;

// Plumtree Server
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.communitytemplate.*;
import com.plumtree.portalpages.admin.editors.group.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.sitemap.sitemappage.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.expandablelist.template.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.securitymatrix.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author michaeld
 */
public class CommunityEditorModel extends ObjEditorModel
	implements ICommunityEditorModelRO, IPortletPreferencesModelRO,
		IHeaderAndFooterModel, IFolderSecurityABOModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.community.CommunityEditorModel");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommunityEditor";

	/** List Key: Header */
	public static final int LIST_KEY_HEADER = 4;

	/** List Key: Footer */
	public static final int LIST_KEY_FOOTER = 5;

	// three values to store the state of gadget title bars
	// serverfalse -- in the database, this gadget does not have a title bar
	// preffalse -- according to the community pref, this gadget does not have a title bar
	// preftrue -- the gadget id is not in the community pref, and it's not server false, so this
	// 		gadget has a title bar
	public static final int COMMUNITYEDITOR_GADGETTITLEBARS_SERVERFALSE = 0;
	public static final int COMMUNITYEDITOR_GADGETTITLEBARS_PREFFALSE = 1;
	public static final int COMMUNITYEDITOR_GADGETTITLEBARS_PREFTRUE = 2;

	private XPHashtable m_htFormData = null; // initialization moved into constructor
	private XPHashtable m_mapPortletsWithNoTitleBars;

	/** Old pages */
	private XPSortedDictionary m_xpsdOldPages;

	/** List of gadgets with preferences */
	private PTSortedArrayWrapper[] m_arrSortedPortlets;

	// Header and Footer BEGIN

	/** Name of the Header **/
	private String m_strHeaderName;
	/** Name of the Footer **/
	private String m_strFooterName;

	/** Did footer come from Community Template? */
	private boolean m_bFooterFromCommTemp = false;
	private boolean m_bFooterHasCommunityPrefs;
	private int 	m_nFooterFromCommTemp;

	/** Did header come from Community Template? */
	private boolean m_bHeaderFromCommTemp = false;
	private boolean m_bHeaderHasCommunityPrefs;
	private int		m_nHeaderFromCommTemp;

	/** PortletID of the Footer **/
	private int m_nFooterID = 0;

	/** Portlet ID of the Header **/
	private int m_nHeaderID = 0;

	/** Previous PortletID of the Footer **/
	private int m_nOldFooterID = 0;

	/** Previous Portlet ID of the Header **/
	private int m_nOldHeaderID = 0;

	/** If true, enables the force subportal header/footer checkbox **/
	private boolean m_bIsTemplateSelector = false;
	// Header and Footer END


	/** Set when the community has been temporarily stored */
	private boolean m_bIsTempStored = false;

	/** Flag when in temporary storage mode */
	private boolean m_bTempStore = false;

	/** Store this community's community folder id */
	private int m_nCommFolderID;

	/** Store destination folder id to move the community to */
	private int m_nDestinationFolderID;


	/** Is SiteMap Disabled? */
	private boolean m_bSiteMapDisabled = true;
	
	/** job name for ABO security change */
	private String m_sJobName;

	/** folder name job created in */
	private String m_sFolderJobCreatedInName;

	/** job ID for ABO security change */
	private int m_nABOJobID;

	public CommunityEditorModel()
	{
		super();
		m_htFormData = new XPHashtable();
	}

	/**
	 * If editor was canceled, remove the temp stored community object & folder.
	 *
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Cancel()
	 */
	public void Cancel()
	{
		// Editor was cancelled, delete the temporary stored community if one was stored.
		if (0 != m_nCommFolderID)
		{
			try
			{
				IPTAdminCatalog cat = ((IPTSession) m_asOwner.GetUserSession()).GetAdminCatalog();
				cat.DeleteAdminFolder(m_nCommFolderID);
			}
			catch (Exception e)
			{
				log.Error(e, "Exception deleting temporarily stored community folder: " +
					m_nCommFolderID +
					" Community editor on cancel action.");
			}

			log.Debug("Deleting temporarily saved community folder: " +
				m_nCommFolderID);
		}
	}

	/**
	 * Temporarily store the community object and folder into the unclassified
	 * folder.
	 * Should only be called after a community template and page has been added
	 * to the community.
	 *
	 */
	public void CommunityTempStore()
	{
		// Store the community in the unclassified folder,
		//

		// m_nCommFolderID will be set after the temporary store
		try
		{
			if ((EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType) &&
					(m_nCommFolderID == 0))
			{
				m_ptObject.SetName(m_asOwner.GetString(1516, "ptmsgs_portalbrowsingmsgs"));

				// Do we have a valid parent community folder? If we do, store this community in the parent community folder.
				if (m_bForceSavedInSuppliedFolder)
				{
					m_ptObject.SetAdminFolderID(m_nFolderID);
				}
			}

			// Flag for temporary store
			m_bTempStore = true;

			// Finish without storing security and keep editor type as create
			DoTaskBeforeStore();
			if (PT_LOCKSTATES.PT_UNLOCKED == m_ptObject.GetLockState())
			{
				m_ptObject.LockObject();
			}
			m_ptObject.Store();
			m_ptObject.UnlockObject();
			m_nObjectID = m_ptObject.GetObjectID();
			DoTaskAfterStore();
			// END Finish without storing security

			m_bTempStore     = false;

			m_bIsTempStored     = true;

			if ((EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType) &&
					(m_nCommFolderID == 0))
			{
				((ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).InitializeSecurityPage(m_ptObject,
				   m_Session);
	
				// After storing the community the adminfolderid will contain the parent community folder
				// Remember this for when we are finishing the editor.
				m_nCommFolderID = m_ptObject.GetAdminFolderID();
	
				// Give Object Security Page the Community Folder ID.
				((SelectPTObjectModel)m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetCommunityFolderID(m_nCommFolderID);
	
				if (!m_bForceSavedInSuppliedFolder && PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS != m_nFolderID)
				{
					// Have to do this in case the community gets abandoned
					m_Session.GetAdminCatalog().MoveAdminFolder(m_nCommFolderID, PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);
				}

				log.Debug("Temporarily storing community folder " +
					GetObject().GetAdminFolderID() + " into folder: " +
					m_nFolderID + ", created community folder: " +
					m_nCommFolderID);

				InitSubCommunityCreation((SelectPTObjectModel)m_asOwner.GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST));
				InitCommunityGroupCreation((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST));
				InitCommunityPortletCreation((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST));
			}
				
			((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetItems().ClearArray();
			Object[][] arrDefaultPages = InitializePages(new ASQueryResultWrapper(((IPTCommunity) m_ptObject).QueryPages(0)));
			((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).SetDefaultObjects(arrDefaultPages);
		}
		catch (Exception e)
		{
			log.Error(e, "There was an error temporarily storing the community: " +
				m_nObjectID + " into folder: " + m_nFolderID);

			m_bTempStore = false;
		}
		
		// Enable adding a page
		((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).EnableAddButton();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityEditorModel();
	}

	/**
	 *
	 *
	 * @param arnObjToDelete
	 */
	public void DeleteCommGroupsObjects(int[] arnObjToDelete)
	{
		if (null != arnObjToDelete)
		{
			IPTObjectManager omGroups = GetPTSession().GetUserGroups();

			for (int i = 0; i < arnObjToDelete.length; i++)
			{
				int nGroups = 0;

				try
				{
					nGroups = arnObjToDelete[i];
					omGroups.Delete(nGroups);
				}
				catch (Exception e)
				{
					log.Warn(e, "Error deleting a Community Groups with ID: " +
						nGroups);
				}
			}
		}
	}

	/**
	 *
	 *
	 * @param arnObjToDelete
	 */
	public void DeleteCommPortletObjects(int[] arnObjToDelete)
	{
		if (null != arnObjToDelete)
		{
			IPTObjectManager omPortlet = GetPTSession().GetGadgets();

			for (int i = 0; i < arnObjToDelete.length; i++)
			{
				int nPortletID = 0;

				try
				{
					nPortletID = arnObjToDelete[i];
					omPortlet.Delete(nPortletID);
				}
				catch (Exception e)
				{
					log.Warn(e, "Error deleting a Community Portlet with ID: " +
						nPortletID);
				}
			}
		}
	}

	/**
	 *
	 *
	 * @param arnObjToDelete
	 */
	public void DeleteCommSubcomms(int[] arnObjToDelete)
	{
		if (null != arnObjToDelete)
		{
			IPTObjectManager omSubComms = GetPTSession().GetCommunities();
			IPTQueryResult ptqrSubComms = null;
			IPTAdminCatalog cat		    = ((IPTSession) m_asOwner.GetUserSession()).GetAdminCatalog();

			Object[] arObjIDs = new Object[arnObjToDelete.length];

			for (int i = 0; i < arnObjToDelete.length; i++)
			{
				arObjIDs[i] = new Integer(arnObjToDelete[i]);
			}

			try
			{
				// Get community folder for each community.
				ptqrSubComms = omSubComms.Query(PT_PROPIDS.PT_PROPID_OBJECTID |
						PT_PROPIDS.PT_PROPID_FOLDERID, -1,
						PT_PROPIDS.PT_PROPID_NAME,
						0, -1,
						PlumtreeHelpers.GetQueryFilter(
							PT_PROPIDS.PT_PROPID_OBJECTID,
							PT_FILTEROPS.PT_FILTEROP_IN, arObjIDs));
			}
			catch (Exception e)
			{
				log.Error(e, "Unable to get Subcommunities for delete.");

				return;
			}

			for (int i = 0; i < ptqrSubComms.RowCount(); i++)
			{
				int nCommFolderID = 0;

				try
				{
					nCommFolderID = (ptqrSubComms.ItemAsInt(i,
							PT_PROPIDS.PT_PROPID_FOLDERID));
					cat.DeleteAdminFolder(nCommFolderID);
				}
				catch (Exception e)
				{
					log.Warn(e, "Error deleting a Subcommunity folder with ID: " +
						nCommFolderID);
				}
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#DisplayTitleBarColumn()
	 */
	public boolean DisplayTitleBarColumn()
	{
		return true;
	}

	/**
	 * Code executed after the object is stored.
	 */
	public void DoTaskAfterStore()
	{
		if ((EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType) && !m_bTempStore)
		{
			// Force the community knowledge directory name to be localized for this session
			IPTSiteMapFolder spSiteMapRoot = ((IPTCommunity) m_ptObject).GetSiteMapRoot();
			spSiteMapRoot.SetName(m_asOwner.GetString(1647, "ptmsgs_portalbrowsingmsgs"));
			spSiteMapRoot.SetDescription(m_asOwner.GetString(549, "ptmsgs_portalbrowsingmsgs"));
	
			if (spSiteMapRoot.LockObject())
			{
				spSiteMapRoot.Store();
				spSiteMapRoot.UnlockObject();
			}
			else
			{
				log.Error("Could not lock the root SiteMap folder of the community to update to localized name: ObjectID=" 
					+ spSiteMapRoot.GetObjectID());
			}
		}
		
		// Page operations
		IPTQueryResult ptqrPages = ((IPTCommunity) m_ptObject).QueryPages(0);

		// Get page ids for pages already in Community
		XPArrayList xpapPagesAlreadyAddedToCommunity  = new XPArrayList(ptqrPages.RowCount());

		for (int i = 0; i < ptqrPages.RowCount(); i++)
		{
			xpapPagesAlreadyAddedToCommunity.Add(new Integer(ptqrPages.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID)));
		}

		// Get all the pages from the page list
		PTGrowableSortedArrayWrapper aSelectedObjectValues = ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetItems();

		// Get page count of still valid pages
		int nPageCount		 = aSelectedObjectValues.GetCount();
		XPArrayList xpalPageListPagesToKeep = new XPArrayList(nPageCount);
		PageData myPageModel;

		for (int i = 0; i < nPageCount; i++)
		{
			// Get Page Model for this page
			myPageModel = (PageData) aSelectedObjectValues.GetItem(i,
					PageListModel.EXPLIST_COL_PAGE_MODEL);

			if (0 >= myPageModel.m_nPageID)
			{
				// TODO-MJD : get rid of this when convenient
				throw new XPException("Page did not have a valid ID");
			}

			if ( xpapPagesAlreadyAddedToCommunity.Contains(new Integer(myPageModel.m_nPageID)) || !myPageModel.m_bFromCommTemp )
			{
				// add page id to array for sorting pages later
				xpalPageListPagesToKeep.Add(new Integer(myPageModel.m_nPageID));
			}
		}
		
		int[] anPageIDs		 = new int[xpalPageListPagesToKeep.GetSize()];
		for (int i=0; i<xpalPageListPagesToKeep.GetSize(); i++)
		{
			anPageIDs[i] = XPConvert.ToInteger(xpalPageListPagesToKeep.GetElement(i));
		}

		if (0 < anPageIDs.length)
		{
			// Sort pages
			((IPTCommunity) m_ptObject).AssignPages(anPageIDs);
		}

		// Get pages to remove
		XPArrayList xpPagesToRemove = ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetPagesToRemove();
		for (int i = 0; i < xpPagesToRemove.GetSize(); i++)
		{
			// delete page
			m_Session.GetPages().Delete(XPConvert.ToInteger(xpPagesToRemove.GetElement(i)));
		}

		if (!m_bTempStore)
		{
			// set preferences for gadgets
			// store the array of disabled title bars, which is a community pref

			// Get the no title bar pref name
			((IPTCommunity) m_ptObject).AddPreference(CommunityMyPortalModelHelper.COMGADGETHASNOTITLEBAR,
				GetNoTitleBarPref(), 0, PT_PREF_TYPES.PT_PREFTYPE_ALL_USERS);
		}

		// The community folder & objects are now stored, but in the unclassified folder. Move to the folder the user
		// seleted in the popup. The adminfolderid of the object will contain the id of this folder. Have the community
		// folder stored from initalization of the model.
		// Don't need to move subcommunities, stored in the correct folder already.
		if ((EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType) &&
				!m_bForceSavedInSuppliedFolder && !m_bTempStore)
		{
			try
			{
				IPTAdminCatalog cat = ((IPTSession) m_asOwner.GetUserSession()).GetAdminCatalog();
				cat.MoveAdminFolder(m_nCommFolderID, m_nDestinationFolderID);

				log.Info(" Moving community folder: " + m_nCommFolderID +
					" to: " + m_nDestinationFolderID);
			}
			catch (Exception e)
			{
				log.Error(e, "Exception moving community folder: " +
					m_nCommFolderID + " to destination folder: " +
					m_nDestinationFolderID);
			}

			// And we are done
		}
	}

	/**
	 * Initializes IPTProperty with the property type member  variable just
	 * before we store the object in the DB. Also sets 2 other values to
	 * default.
	 *
	 * @throws XPException
	 */
	public void DoTaskBeforeStore()
	{
		PTGrowableSortedArrayWrapper saData = ((ExpListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).GetItems();
		
		int nCommunityTemplateID = 0;
		boolean bInheritCommunityTemplate = true;
		if (0 < saData.GetCount())
		{
			nCommunityTemplateID = XPConvert.ToInteger(saData.GetItem(0, TemplateListModel.EXPLIST_COL_TEMPLATE_ID));
			bInheritCommunityTemplate = XPConvert.ToBoolean(saData.GetItem(0, TemplateListModel.EXPLIST_COL_INHERIT_TEMPLATE));
		}

		if (((IPTCommunity) m_ptObject).GetCommunityTemplateID() != nCommunityTemplateID)
		{
			try
			{
				((IPTCommunity) m_ptObject).SetCommunityTemplateID(nCommunityTemplateID);
				
				if ( m_bTempStore && 0 != nCommunityTemplateID )
				{
					// get header and footer from new comm temp
					IPTCommunityTemplate ptCommTemp = (IPTCommunityTemplate)m_Session.GetCommunityTemplates().Open(nCommunityTemplateID, false);
					SetupHeaderAndFooter(ptCommTemp.GetHeaderID(), ptCommTemp.GetFooterID());
				}
			}
			catch (Exception e)
			{
				log.Error(e, "CommunityEditorModel::DoTaskBeforeStore Unable to set community template on the community.");

				throw new XPException(m_asOwner.GetString(235,
						"ptmsgs_portalbrowsingmsgs"), e);
			}
		}
		
		if (((IPTCommunity) m_ptObject).GetInheritCommunityTemplate() != bInheritCommunityTemplate)
		{
			try
			{
				// Set whether community inherits community template
				((IPTCommunity) m_ptObject).SetInheritCommunityTemplate(bInheritCommunityTemplate);
			}
			catch (Exception e)
			{
				log.Error(e, "CommunityEditorModel::DoTaskBeforeStore Unable to set community inherits community template on the community.");

				throw new XPException(m_asOwner.GetString(235,
						"ptmsgs_portalbrowsingmsgs"), e);
			}
		}
		
		// Set Header ID
		if (m_nHeaderID != m_nOldHeaderID)
		{
			int nHeaderID = m_nHeaderID;
			if ( m_bHeaderFromCommTemp && m_nHeaderID != CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL )
			{
				nHeaderID = -m_nHeaderID;
			}
			((IPTCommunity) m_ptObject).SetHeaderID(nHeaderID);
			m_nOldHeaderID = m_nHeaderID;
		}

		// Set Footer ID
		if (m_nFooterID != m_nOldFooterID)
		{
			int nFooterID = m_nFooterID;
			if ( m_bFooterFromCommTemp && m_nFooterID != CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL )
			{
				nFooterID = -m_nFooterID;
			}
			((IPTCommunity) m_ptObject).SetFooterID(nFooterID);
			m_nOldFooterID = m_nFooterID;
		}

		if ( ((IPTCommunity) m_ptObject).GetSiteMapDisabled() != m_bSiteMapDisabled ) 
		{
			((IPTCommunity) m_ptObject).SetSiteMapDisabled(m_bSiteMapDisabled);
		}

		// After the save popup the adminfolderid will be the id of the destination folder.
		// We want to move the comm folder there but before that happens there is a store.
		// Want to store in the original comm folder, not new destination folder so swap it.
		// It is messy...
		if ((GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE) &&
				!m_bTempStore)
		{
			m_nDestinationFolderID = GetObject().GetAdminFolderID();
			GetObject().SetAdminFolderID(m_nCommFolderID);
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#Finish()
	 */
	public void Finish()
	{
		IPTAccessList ptOldACL = null;
		if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
		{
			// get the acl before it gets changed by finish, we need it to compare to the new acl
			ptOldACL = GetCurrentFolderACL();
		}
		
		super.Finish();
		
		if (null != ptOldACL)
		{
			if ( IsAdminModifiedOnFolder(ptOldACL) )
			{
				// now create the ABO job to update security
				ApplySecurityChangesUsingABO(false);
			}
		}
	}

	// END ***************** helper methods *****************
	// BEGIN ***************** repost action methods *****************
	public void DoTaskOnChangePage(String _sNewSpaceName, String _sNewPageName)
	{
		if (_sNewPageName.equals(
					CommunityEditorPortletPreferencesDP.STR_MVC_CLASS_NAME))
		{
			// Flag for temporary store
			m_bTempStore = true;

			// Finish without storing security
			DoTaskBeforeStore();
			m_ptObject.LockObject();
			m_ptObject.Store();
			m_ptObject.UnlockObject();
			DoTaskAfterStore();
			// END Finish without storing security

			m_bTempStore = false;

			RepostToPortletPrefs();
		}
		else if (_sNewPageName.equals(
					CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME))
		{
			RepostToCommunityPortlets();
		}
	}

	/**
	 * This method will be called when you come back to the main Editor from a sub Editor.
	 *
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();

		if ((CommunityEditorSubcommunityDP.STR_MVC_CLASS_NAME).equals(m_asOwner.GetCurrentPage().GetName()))
		{
			((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST)).DoTaskOnComeBackFromSubEditor();
		}
		else if ((CommunityEditorCommPortletDP.STR_MVC_CLASS_NAME).equals(m_asOwner.GetCurrentPage().GetName()))
		{
			((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST)).DoTaskOnComeBackFromSubEditor();
		}
		else if ((CommunityEditorCommGroupDP.STR_MVC_CLASS_NAME).equals(m_asOwner.GetCurrentPage().GetName()))
		{
			// Must add community groups onto acl before calling the SelectPTObject.DoTaskOnComeBackFromSubEditor, because that
			// 	deletes the subspace we need to access for some reason.
			// Add new community groups to community security acl
			Object[][] arrCreateNewInfo = ((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST)).GetCreateNewInfo();

			String sEditorASName;
			EditorAS myEditorAS;
			ObjEditorModel myObjEditorModel;
			int nNewGroupID;
			String strNewGroupName;

			// MJD- Check if they are any newly created objects
			for (int i = 0; i < arrCreateNewInfo.length; i++)
			{
				sEditorASName = (String) arrCreateNewInfo[i][SelectPTObjectModel.CREATE_NEW_COL_ASNAME];

				if (m_asOwner.GetSubSpaceExists(sEditorASName))
				{
					myEditorAS			 = (EditorAS) m_asOwner.GetSubSpace(sEditorASName);
					myObjEditorModel     = (ObjEditorModel) myEditorAS.GetModel(myEditorAS.m_strModelName);

					nNewGroupID		    = myObjEditorModel.GetObjectID();
					strNewGroupName     = myObjEditorModel.GetObjectName();

					ObjectSecurityModel myModel = ((ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB));

					int nIndex = myModel.m_nNextIndex;
					myModel.m_nNextIndex++;

					// put new group on community security tab
					Object[] oNewRow = new Object[ObjectSecurityModel.EXPLIST_COL_MAX];
					oNewRow[ObjectSecurityModel.EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(nIndex);
					oNewRow[ObjectSecurityModel.EXPLIST_COL_CLASSID]				  = new Integer(PT_CLASSIDS.PT_USERGROUP_ID);
					oNewRow[ObjectSecurityModel.EXPLIST_COL_OBJECTID]				  = new Integer(nNewGroupID);
					oNewRow[ObjectSecurityModel.EXPLIST_COL_STRING]					  = strNewGroupName;

					// MJD- Defaut selected access level: read
					oNewRow[ObjectSecurityModel.EXPLIST_COL_ACCESSLEVEL_ID]		    = new Integer(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
					oNewRow[ObjectSecurityModel.EXPLIST_COL_ACCESSLEVEL_STRING]     = myModel.GetAccessLevelString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);

					// MJD- By default the user has read/write access to the row
					oNewRow[ObjectSecurityModel.EXPLIST_COL_ROWACCESS]     = new Boolean(ObjectSecurityModel.PT_ACCESS_LIST_ENTRY_READWRITE);

					// MJD- By default the object is not mandatory
					oNewRow[ObjectSecurityModel.EXPLIST_COL_MANDATORY]     = new Integer(ObjectSecurityModel.MANDATORY_FALSE);

					// MJD- By default there is no tree ID
					oNewRow[ObjectSecurityModel.EXPLIST_COL_GROUPTREEASID] = "";
					myModel.GetItems().AddRow(oNewRow);

					// put new group on acl of community folder
					//this.m_Session.GetAdminCatalog().OpenAdminFolder(this.m_nCommFolderID, true);
				}
			}

			((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST)).DoTaskOnComeBackFromSubEditor();
		}
		else if ((CommunityEditorPagesDP.STR_MVC_CLASS_NAME).equals(m_asOwner.GetCurrentPage().GetName()))
		{
			((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).DoTaskOnComeBackFromSubEditor();
		}
	}

	/**
	 * Initializes the property type member variable with  the one from
	 * IPTProperty in Edit mode and the default  value in create mode.
	 *
	 * @param _htFormData
	 *
	 * @throws XPException
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		// init vars
		m_nABOJobID = -1;

		// initialize the title bars hash map; ProcessPortletTitleBars will put values in the hash map
		m_mapPortletsWithNoTitleBars = new XPHashtable();

		StartPageList();

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			m_nHeaderID = ((IPTCommunity)m_ptObject).GetHeaderID();
			if (0 < m_nHeaderID)
			{

				m_nHeaderFromCommTemp = 0;
			}
			else if (-1 > m_nHeaderID)
			{
				m_nHeaderFromCommTemp = -m_nHeaderID;
			}
			else
			{
				m_nHeaderFromCommTemp = m_nHeaderID;
			}

			m_nFooterID = ((IPTCommunity)m_ptObject).GetFooterID();
			if (0 < m_nFooterID)
			{
				m_nFooterFromCommTemp = 0;
			}
			else if (-1 > m_nFooterID)
			{
				m_nFooterFromCommTemp = -m_nFooterID;
			}
			else
			{
				m_nFooterFromCommTemp = m_nFooterID;
			}

			// Get the names and IDs of the header and footer
			SetupHeaderAndFooter(m_nHeaderFromCommTemp, m_nFooterFromCommTemp);

			ProcessPortletTitleBars();

			// Give Object Security Page the Community Folder ID.
			((SelectPTObjectModel)m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB)).SetCommunityFolderID(GetFolderID());
			
			m_bSiteMapDisabled = ((IPTCommunity) m_ptObject).GetSiteMapDisabled();
		}
		else
		{
			m_nHeaderID = 0;
			m_nFooterID = 0;

			// Hide the security page in create mode
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);

			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

		/*
		 * Stores the initially loaded ID's of the header and footer to avoid access
		 * violation when header and footer not changed on save.  Since the edit
		 * header/footer link is hidden if you don't have rights, the ID value won't
		 * change.
		 */
		m_nOldFooterID = m_nFooterID;
		m_nOldHeaderID = m_nHeaderID;

		StartCommGroupSelectPTObject();

		StartSubCommunitySelectPTObject();

		StartCommPortletSelectPTObject();

		StartCommunityTemplateSelector(_htFormData);
	}

	/**
	 * Does nothing in the community editor.
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndFooterModel#SetUseForceSubPortal(boolean)
	 */
	public void SetUseForceSubPortal(boolean bForce)
	{
	}

	/**
	 * Flip the title bar check box.
	 *
	 * @return void
	 */
	public void FlipTitleBar(XPHashtable _htFormData)
	{
		// get the gadgetID
		String sDataKey     = PortletPreferencesView.HTMLHIDDEN_FLIPGADGETID;
		String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);
		int iFlipPortletID   = -1;

		if ((null != aDataValue) && (0 != aDataValue.length))
		{
			try
			{
				iFlipPortletID = XPConvert.ToInteger(aDataValue[0]);
			}
			catch (Exception e)
			{
				log.Error(e, "CommunityEditorModel::FlipPortletID An exception occured" +
					" when trying to get the gadget with ID: " +
					aDataValue[0]);
			}
		}

		if (iFlipPortletID < 0)
		{
			return;
		}

		sDataKey	   = PortletPreferencesView.HTMLHIDDEN_FLIPCURRENTTITLEBARSTATE;
		aDataValue     = (String[]) _htFormData.GetElement(sDataKey);

		int iCurrentTitleBarState = -1;

		if ((null != aDataValue) && (0 != aDataValue.length))
		{
			try
			{
				iCurrentTitleBarState = XPConvert.ToInteger(aDataValue[0]);
			}
			catch (Exception e)
			{
				log.Error(e, "CommunityEditorModel::FlipPortletID An exception occured" +
					" when trying to get the title bar state for gadget with ID: " +
					aDataValue[0]);
			}
		}

		// the only valid values are PREFFALSE and PREFTRUE, SERVERFALSE doesn't even have a checkbox.
		if ((iCurrentTitleBarState < COMMUNITYEDITOR_GADGETTITLEBARS_PREFFALSE) ||
				(iCurrentTitleBarState > COMMUNITYEDITOR_GADGETTITLEBARS_PREFTRUE))
		{
			return;
		}

		// the new state is the opposite of the old state
		int iNewTitleBarState = -1;

		if (iCurrentTitleBarState == COMMUNITYEDITOR_GADGETTITLEBARS_PREFFALSE)
		{
			iNewTitleBarState = COMMUNITYEDITOR_GADGETTITLEBARS_PREFTRUE;

			// take this gadget out of the hashmap
			if (m_mapPortletsWithNoTitleBars.ContainsKey(
						new Integer(iFlipPortletID)))
			{
				m_mapPortletsWithNoTitleBars.RemoveElement(new Integer(
						iFlipPortletID));
			}
		}
		else
		{
			iNewTitleBarState = COMMUNITYEDITOR_GADGETTITLEBARS_PREFFALSE;

			// add this gadget into the hashmap
			if (!m_mapPortletsWithNoTitleBars.ContainsKey(
						new Integer(iFlipPortletID)))
			{
				// map it to 0, this is a dummy value that we never use
				m_mapPortletsWithNoTitleBars.PutElement(new Integer(
						iFlipPortletID), new Integer(0));
			}
		}

		int iTotalPages = GetPageCount();

		for (int iCurrentPageIndex = 0; iCurrentPageIndex < iTotalPages;
				iCurrentPageIndex++)
		{
			int iTotalPortlets = m_arrSortedPortlets[iCurrentPageIndex].GetCount();

			for (int iCurrentPortletRow = 0; iCurrentPortletRow < iTotalPortlets;
					iCurrentPortletRow++)
			{
				int iPortletID = XPConvert.ToInteger(m_arrSortedPortlets[iCurrentPageIndex].GetItem(iCurrentPortletRow,
						PT_PROPIDS.PT_PROPID_OBJECTID));

				if (iPortletID == iFlipPortletID)
				{
					m_arrSortedPortlets[iCurrentPageIndex].SetItem(iCurrentPortletRow,
						PT_PROPIDS.PT_PROPID_GADGET_FLAGS,
						new Integer(iNewTitleBarState));
				}
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.ICommunityEditorModelRO#GetCommunityFolderID()
	 */
	public int GetCommunityFolderID()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			return m_nCommFolderID;
		}
		return GetFolderID();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#GetCommunityID()
	 */
	public int GetCommunityID()
	{
		return m_nObjectID;
	}

	//
	// Header and Footer page stuff BEGIN
	//
	public String GetData(String name)
	{
		String[] values = (String[]) m_htFormData.GetElement(name);

		if (values == null)
		{
			return "";
		}

		return values[0];
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetFooterHasCommunityPrefs()
	{
		return m_bFooterHasCommunityPrefs;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetFooterID()
	{
		
			log.Debug("Footer for this community is: " + m_nFooterID);
		

		return m_nFooterID;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetFooterName()
	 */
	public String GetFooterName()
	{
		
			log.Debug("Footer name for this community is: " + m_strFooterName);
		

		return m_strFooterName;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndFooterModel#IsTemplateSelector()
	 */
	public boolean IsTemplateSelector()
	{
		return m_bIsTemplateSelector;
	}


	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#GetPortletPreferencesList()
	 */
	public PTSortedArrayWrapper GetPortletPreferencesList(int iPageID)
	{
		return m_arrSortedPortlets[iPageID];
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean GetHeaderHasCommunityPrefs()
	{
		return m_bHeaderHasCommunityPrefs;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetHeaderID()
	{
		
			log.Debug("Header for this community is: " + m_nHeaderID);
		

		return m_nHeaderID;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#GetHeaderName()
	 */
	public String GetHeaderName()
	{
		
			log.Debug("Header name for this community is: " + m_strHeaderName);
		

		return m_strHeaderName;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Turn m_mapPortletsWithNoTitleBars into a pref that we can store.
	 *
	 * Executed after the object is stored, this pref is then stored into the DB.
	 */
	public String GetNoTitleBarPref()
	{
		Object[] arrPortletsWithNoTitleBars    = m_mapPortletsWithNoTitleBars.GetArray(XPHashtable.KEYS);
		int nPortletCount					  = arrPortletsWithNoTitleBars.length;
		XPStringBuilder sbPortletsWithNoTitleBars = new XPStringBuilder((4 * nPortletCount));

		for (int i = 0; i < nPortletCount; i++)
		{
			if (0 != i)
			{
				sbPortletsWithNoTitleBars.Append(",");
			}

			sbPortletsWithNoTitleBars.Append(arrPortletsWithNoTitleBars[i]);
		}

		return sbPortletsWithNoTitleBars.ToString();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#GetPageCount()
	 */
	public int GetPageCount()
	{
		return ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetItems()
		.GetCount();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#GetPageID(int)
	 */
	public int GetPageID(int nPageIndex)
	{
		return ((PageData) ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetItems()
		.GetItem(nPageIndex, PageListModel.EXPLIST_COL_PAGE_MODEL)).m_nPageID;
	}

	// BEGIN ***************** helper methods *****************

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.ICommunityEditorModelRO#GetPageModelAt(int)
	 */
	public PageData GetPageModelAt(int nPageIndex)
	{
		return (PageData) ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetItems()
		.GetItem(nPageIndex, PageListModel.EXPLIST_COL_PAGE_MODEL);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#GetPageName(int)
	 */
	public String GetPageName(int nPageIndex)
	{
		return ((PageData) ((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetItems()
		.GetItem(nPageIndex, PageListModel.EXPLIST_COL_PAGE_MODEL)).m_strPageName;
	}

	/**
	 * If this is a subcommunity editor and hence a popup, close it when editor
	 * is done.
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		Redirect redirect = null;
		
		// object id -1 if this is a create new object editor, can't create a friendly url to an invalid
		// community, just create a regular url which will make the editor redirect back to the page
		// the editor was kicked off from
		// Bug: 66181 - Only use friendly url if we are coming from CommunityPageAS. Otherwise we should
		// redirect back to the page where the editor was started from.
		if ( !m_bIsTempStored && m_nObjectID != -1 && TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_COMMUNITY_ID) &&
				(CommunityPageAS.STR_MVC_CLASS_NAME).equals(m_asOwner.GetParentSpaceName()) ) {
			IPTURL m_url = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(m_asOwner, m_nObjectID, "");
			redirect = new Redirect();
			redirect.SetLinkToExternalURL(m_url.GetFullURL());
		} else {
			redirect = super.GetRedirectAfterFinish();
	
			if ((CommunityPageAS.STR_MVC_CLASS_NAME).equals(redirect.GetSpaceName()))
			{
				redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
				redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
					m_nObjectID);
				redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID,
					0);
			}
			
			else if ((SiteMapAS.STR_MVC_CLASS_NAME).equals(redirect.GetSpaceName()))
			{
				redirect.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
				redirect.AddControlArgument(SetSiteMapControl.m_CommunityID,
					m_nObjectID);
				redirect.AddControlArgument(SetSiteMapControl.m_Mode,
					SetSiteMapControl.BROWSE);
			}
		}

		return redirect;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.
	 * IPortletPreferencesModelRO#IsCommunityEditor()
	 */
	public boolean IsCommunityEditor()
	{
		return true;
	}

	/**
	 *
	 *
	 * @return
	 */
	public boolean IsSiteMapDisabled()
	{
		return m_bSiteMapDisabled;
	}

	/**
	 * This method gets the selected items from the tree.
	 */
	public void RefreshItemFromFooterTree(XPHashtable _htFormData)
	{
		if (m_asOwner.GetSubSpaceExists(
					HeaderAndFooterSelectorView.TREE_FOOTER_SUBSPACE))
		{
			AActivitySpace asTree  = m_asOwner.GetSubSpace(HeaderAndFooterSelectorView.TREE_FOOTER_SUBSPACE);
			ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList itemList   = treeModel.GetSelectedItems();

			if (itemList.GetSize() != 1)
			{
				
					log.Error("Footer tree selected wrong number of items.  Expecting 1, got " +
						itemList.GetSize());
				
			}

			TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

			if (item == null)
			{
				
					log.Error("Tree selected item null");
				
				String strError= "A serious error has occured within this editor. The selected tree item is null";
				UIError myError = new UIError(UIErrorLevel.SERIOUS,UIErrorScope.CURRENT_USER, strError, strError);

				myError.SetActivitySpace(m_asOwner.GetName());
				myError.SetDisplayOnSeparatePage(false);
				myError.SetClearWithActivitySpaceChange(true);
				myError.SetImmediateClear(true);

				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
								m_asOwner.GetApplication());

			}

			m_nFooterID		    = item.m_nObjectID;
			m_strFooterName     = item.GetName();
			m_bFooterFromCommTemp = false;
			// query object to see if it supports prefs
			IPTQueryResult ptqrObjects = this.m_Session.GetGadgets().QuerySingleObject(m_nFooterID);
			int nWebServiceID = ptqrObjects.ItemAsInt(0, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);
			m_bFooterHasCommunityPrefs = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
			PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
			this.m_Session);
		}
		else
		{
			
				log.Error("Unable to retrieve the footer portlet tree subspace. Subspace does not exist.");
			
		}
	}

	/**
	 * Get the header and footer selected from the tree.
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#RefreshItemFromHeaderTree(XPHashtable)
	 */
	public void RefreshItemFromHeaderTree(XPHashtable _htFormData)
	{
		if (m_asOwner.GetSubSpaceExists(
					HeaderAndFooterSelectorView.TREE_HEADER_SUBSPACE))
		{
			AActivitySpace asTree  = m_asOwner.GetSubSpace(HeaderAndFooterSelectorView.TREE_HEADER_SUBSPACE);
			ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList itemList   = treeModel.GetSelectedItems();

			if (itemList.GetSize() != 1)
			{
				
					log.Error("Banner tree selected wrong number of items.  Expecting 1, got " +
						itemList.GetSize());
				
			}

			TreeLeafNode item = (TreeLeafNode) itemList.GetElement(0);

			if (item == null)
			{
				
					log.Error("Tree selected item null");
				
				String strError= "A serious error has occured within this editor. The selected tree item is null";
				UIError myError = new UIError(UIErrorLevel.SERIOUS,UIErrorScope.CURRENT_USER, strError, strError);

				myError.SetActivitySpace(m_asOwner.GetName());
				myError.SetDisplayOnSeparatePage(false);
				myError.SetClearWithActivitySpaceChange(true);
				myError.SetImmediateClear(true);

				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
												m_asOwner.GetApplication());
			}

			m_nHeaderID		    = item.m_nObjectID;
			m_strHeaderName     = item.GetName();
			m_bHeaderFromCommTemp = false;
			// query object to see if it supports prefs
			IPTQueryResult ptqrObjects = this.m_Session.GetGadgets().QuerySingleObject(m_nHeaderID);
			int nWebServiceID = ptqrObjects.ItemAsInt(0, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);
			m_bHeaderHasCommunityPrefs = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
			PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
			this.m_Session);
		}
		else
		{
			
				log.Error("Unable to retrieve the footer portlet tree subspace. Subspace does not exist.");
			
		}
	}

	/**
	 * Reverses the sort order of one of the pages of gadget prefs.
	 *
	 * @return void
	 */
	public void ReversePortletPrefsSort(XPHashtable _htFormData)
	{
		String sDataKey		  = PortletPreferencesView.HTMLHIDDEN_SORTINGPAGEINDEX;
		String[] aDataValue   = (String[]) _htFormData.GetElement(sDataKey);
		int iCurrentPageIndex = -1;

		if ((null != aDataValue) && (0 != aDataValue.length))
		{
			try
			{
				iCurrentPageIndex = XPConvert.ToInteger(aDataValue[0]);
			}
			catch (Exception e)
			{
				log.Error(e, "CommunityEditorModel::ReversePortletPrefsSort An exception occured" +
					" when trying to resort gadget preferences for page with ID: " +
					aDataValue[0]);
			}
		}

		if (iCurrentPageIndex < 0)
		{
			return;
		}

		int[][] arrSort = m_arrSortedPortlets[iCurrentPageIndex].GetSort();

		// JF- Get the current sort.
		int nCurrentDirection = arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION];

		// JF-
		if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == nCurrentDirection)
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
		}
		else
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
		}

		m_arrSortedPortlets[iCurrentPageIndex].Sort(arrSort);
	}

	// END ***************** repost action methods *****************

	// Folder Security ABO interface
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#ABOJobIDToDisplay()
	 */
	public boolean ABOJobIDToDisplay() {
		return (m_nABOJobID != -1);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetABOJobID()
	 */
	public int GetABOJobID() {
		return m_nABOJobID;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetCreatedJobName()
	 */
	public String GetCreatedJobName() {
		return m_sJobName;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.securitymatrix.ISecurityMatrixModelRO#GetFolderNameForCreatedJobs()
	 */
	public String GetFolderNameForCreatedJobs() {
		return m_sFolderJobCreatedInName;
	}
	// END Folder Security ABO interface

	/**
	 * 
	 * @return the current IPTAccessList of the folder whose security is being edited
	 */
	public IPTAccessList GetCurrentFolderACL()
	{
		int nFolderID;
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType)
		{
			nFolderID = m_nCommFolderID;
		}
		else
		{
			nFolderID = GetFolderID();
		}
		
		IPTAdminFolder ptFolder = m_Session.GetAdminCatalog()
			.OpenAdminFolder(nFolderID, false);

		// lock the folder for edit								
		return ptFolder.GetACL();
	}

	/**
	 * @param _ptOldACL the IPTAccessList from before the ACLs were changed
	 * @return true if an admin acl was added or an acl was changed to admin.
	 */
	public boolean IsAdminModifiedOnFolder(IPTAccessList _ptOldACL)
	{
		return GetCurrentFolderACL().IsAdminModified(_ptOldACL);
	}
	
	/**
	 * Apply the subportal profile to the users in the folder later, using ABO.
	 * 
	 * @param bPropagateAllACLs - If true propagate all acls to child objects
	 * 	 and subfolders, if false propagate only admin acls.
	 */
	public void ApplySecurityChangesUsingABO(boolean bPropagateAllACLs)
	{
		String strErrors = "";
		IPTAdminFolder ptFolder;

		try
		{
			int nFolderID;
			if (EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType)
			{
				nFolderID = m_nCommFolderID;
			}
			else
			{
				nFolderID = GetFolderID();
			}

			// get the folder
			ptFolder = m_Session.GetAdminCatalog()
				.OpenAdminFolder(nFolderID, false);
			ptFolder.LockObject();

			// schedule a job - set the job type
			// so that the job will do the correct
			// thing, in our case, merge securites
			// Bug 14313 - Erick says we should use REPLACE instead of MERGE from now on.
			int nAdminFolderJobType;
			if ( bPropagateAllACLs )
			{
				nAdminFolderJobType = PT_ADMIN_FOLDER_JOB_TYPES.PT_ADMIN_FOLDER_JOB_PROPAGATEACL_REPLACE;
			}
			else
			{
				nAdminFolderJobType = PT_ADMIN_FOLDER_JOB_TYPES.PT_ADMIN_FOLDER_JOB_PROPAGATEACL_ADMINSONLY;
			}

			ptFolder.SetJobType(nAdminFolderJobType);

			// save and unlock object from db
			ptFolder.Store();
			ptFolder.UnlockObject();

			// create our job
			m_nABOJobID = ((IPTScheduledOperation) ptFolder).ScheduleImmediateJob();
		}
		catch (Exception ex)
		{
			log.Warn(ex, "Error creating job.");
			m_nABOJobID = -1;
		}
		
		try
		{
			// get the job's localized name
			IPTJob myTempJob = (IPTJob) m_Session.
				GetObjectManagers(PT_CLASSIDS.PT_JOB_ID).
				Open(m_nABOJobID, false);
			m_sJobName = myTempJob.GetLocalizedName();
		}
		catch (Exception ex)
		{
			log.Warn(ex, "Error getting job name.");
			m_sJobName = "";
		}
		
		try
		{
			// get the folder that the job was created in's localized name
			IPTAdminFolder myTempAdminFolder = m_Session.GetAdminCatalog().
				OpenAdminFolder(PT_INTRINSICS.PT_ADMIN_FOLDER_INTRINSICOPS, false);
			m_sFolderJobCreatedInName = myTempAdminFolder.GetLocalizedName();
		}
		catch (Exception ex)
		{
			log.Warn(ex, "Error getting job folder name.");
			m_sFolderJobCreatedInName = "";
		}

		// error handling here
		if (m_nABOJobID == -1)
		{
			log.Error(m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) +
				m_nClassID);

			strErrors += (m_asOwner.GetString(1701, ResourceConstants.PORTALADMINMSGS) + "<br />");
		}

		if (!"".equals(strErrors))
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, strErrors, strErrors);

			myError.SetActivitySpace(m_asOwner.GetName());
			myError.SetDisplayOnSeparatePage(false);
			myError.SetClearWithActivitySpaceChange(true);
			myError.SetImmediateClear(true);

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(CommunityEditorPagesDP.STR_MVC_CLASS_NAME))
		{
			((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).SaveSection(_htFormData);
			SaveDisableSiteMapSection(_htFormData);
		}

		if (_sPageName.equals(HeaderAndFooterSelectorDP.STR_MVC_CLASS_NAME))
		{
			// Store our form data for later use - especially for use in the tree control on banner page.
			int nSize				 = _htFormData.GetSize();
			IXPEnumerator xpKeys     = _htFormData.GetKeys();
			IXPEnumerator xpElements = _htFormData.GetElements();

			for (int i = 0; i < nSize; i++)
			{
				xpKeys.MoveNext();
				xpElements.MoveNext();
				m_htFormData.PutElement((String) xpKeys.GetCurrent(),
					(String[]) xpElements.GetCurrent());
			}

			//			// if this is the display page where you have your select ptobject you need to
			//			// call the associated saveSection method.
			//			((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.strStorageSelectHeader)).
			//				SaveSection(_htFormData);
			//			// if this is the display page where you have your select ptobject you need to
			//			// call the associated saveSection method.
			//			((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.strStorageSelectFooter)).
			//				SaveSection(_htFormData);
		}
		else if (_sPageName.equals(
					CommunityEditorPortletPreferencesDP.STR_MVC_CLASS_NAME))
		{
			SavePortletPrefsPage(_htFormData);
		}

		else if (CommunityEditorSubcommunityDP.STR_MVC_CLASS_NAME.equals(
					_sPageName))
		{
			((SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST)).SaveSection(_htFormData);
		}

		return nPageStatus;
	}

	/**
	 * Is this one used??
	 *
	 * @see com.plumtree.portalpages.browsing.editors.community.IHeaderAndBannerModel#SetDefaultHeaderOrFooter(boolean)
	 */
	public void SetDefaultHeaderOrFooter(boolean bHeader)
	{
		if (bHeader)
		{
			if ( m_nHeaderFromCommTemp == 0 )
			{
				m_nHeaderID					= 0;
				m_strHeaderName				= m_asOwner.GetString(243, "ptmsgs_portalbrowsingmsgs");
				m_bHeaderHasCommunityPrefs	= false;
				m_bHeaderFromCommTemp		= false;
			}
		}
		else
		{
			if ( m_nFooterFromCommTemp == 0 )
			{
				m_nFooterID					= 0;
				m_strFooterName				= m_asOwner.GetString(244, "ptmsgs_portalbrowsingmsgs");
				m_bFooterHasCommunityPrefs	= false;
				m_bFooterFromCommTemp		= false;
			}
		}
	}

	//
	// Community portle selector/creation page END
	//

	/**
	 * Helper method to start the Selected Header or Footer List.
	 * Look for header and footer gadget in the community template,
	 * if none is set in the template, look in the community object,
	 * otherwise just get it from the subportal (if one is set).
	 *
	 * Is also called by the pagelistmodel when a community template is set.
	 *
	 */
	public void SetupHeaderAndFooter(int nCommTempHeaderID, int nCommTempFooterID)
	{
		DetermineHeaderOrFooterID(nCommTempHeaderID, m_nHeaderID, m_bHeaderFromCommTemp, true);
		DetermineHeaderOrFooterID(nCommTempFooterID, m_nFooterID, m_bFooterFromCommTemp, false);
	}

	private void DetermineHeaderOrFooterID(int nCommTempHeaderOrFooterID, int nCommHeaderOrFooterID, 
		boolean bIsCommHeaderOrFooterFromTemplate, boolean bIsHeader)
	{
		int nHeaderOrFooterID = 0;
		boolean bNewHeaderOrFooterFromCommTemp = true;
		boolean bHeaderOrFooterHasCommunityPrefs = false;
		String strLabel = "";
		boolean bUseDefaultLabel = false;

		try
		{
			// No header from community template
			if (0 == nCommTempHeaderOrFooterID)
			{
				if (bIsCommHeaderOrFooterFromTemplate)
				{
					nHeaderOrFooterID = 0;
				}
				else
				{
					nHeaderOrFooterID = nCommHeaderOrFooterID;
				}
				bNewHeaderOrFooterFromCommTemp     = false;

				if ( 0 == nHeaderOrFooterID )
				{
					bUseDefaultLabel = true;
					bHeaderOrFooterHasCommunityPrefs     = false;
				}
				else
				{
					IPTQueryResult ptqrObjects = this.m_Session.GetGadgets().QuerySingleObject(nHeaderOrFooterID);

					if (ptqrObjects.RowCount() == 1)
					{
						// DCA - delay htmlencoding til used in view
						//strLabel = XPHttpUtility.HtmlEncode(ptqrObjects.ItemAsString(0,
						//		PT_PROPIDS.PT_PROPID_NAME));
						strLabel = ptqrObjects.ItemAsString(0,
								PT_PROPIDS.PT_PROPID_NAME);

						int nWebServiceID = ptqrObjects.ItemAsInt(0, PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID);

						bHeaderOrFooterHasCommunityPrefs = GatewayUtils.GetWebServiceSupportsPersonalization(nWebServiceID,
								PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
								this.m_Session);
					}
					else
					{
						// couldn't open the header!
						bHeaderOrFooterHasCommunityPrefs     = false;

						try
						{
							//Check if Header and Footer Portlets exist and are not deleted.				
							IPTObjectManager ptGadgetMgr = this.m_Session.GetGadgets();
							
							if(ptGadgetMgr.ObjectExists(nHeaderOrFooterID))
							{
								this.m_Session.GetGadgets().Open(nHeaderOrFooterID, false);
							}
							else 
							{
								log.Warn("Portlet with ID " + nHeaderOrFooterID +" does not exist it may have been deleted, so using the default one instead.");
								nHeaderOrFooterID = 0;
								//  bug fix 9746224 - Community footer not showing correct message after deleting it
								//  In the case that the footer portlet is deleted, the error message strictly states it's loading the default one instead, however
								//  the error message in the editor does not reflect that, so setting bUseDefaultLabel to true to invoke
								//  the correct error message.
								bUseDefaultLabel = true;
							}
						}
						catch (Exception ex)
						{
							log.Warn(ex, "Error opening portlet " + nHeaderOrFooterID);

							if( ex instanceof PTException )
							{
								PTException ptex = (PTException) ex;

								switch ( ptex.GetErrorCode() )
								{
									case PT_RESULTCODES.PT_E_ACCESSDENIED:
									{
										if (bIsHeader)
										{
											strLabel = XPResourceManager.FormatMessage(m_asOwner.GetString(1672, "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nHeaderOrFooterID));
										}
										else
										{
											strLabel = XPResourceManager.FormatMessage(m_asOwner.GetString(1674, "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nHeaderOrFooterID));
										}
										break;
									}
									case PT_RESULTCODES.PT_E_OBJECTNOTFOUND:
									{
										bUseDefaultLabel = true;
										nHeaderOrFooterID = 0;
										break;
									}
									default:
								}
							}
						}
					}
				}
			}
			else if (CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nCommTempHeaderOrFooterID)
			{
				nHeaderOrFooterID = nCommTempHeaderOrFooterID;
				bHeaderOrFooterHasCommunityPrefs = false;
			}
			else
			{
				nHeaderOrFooterID = nCommTempHeaderOrFooterID;

				// get the name of the header/footer so we can display it
				IPTQueryResult ptqrObjects = this.m_Session.GetGadgets().QuerySingleObject(nHeaderOrFooterID);

				if (ptqrObjects.RowCount() == 1)
				{
					// DCA - delay htmlencoding til used in view
					//strLabel = XPHttpUtility.HtmlEncode(ptqrObjects.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME));
					strLabel = ptqrObjects.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
					bNewHeaderOrFooterFromCommTemp = true;

					// find out if the comm template header or footer has community prefs
					bHeaderOrFooterHasCommunityPrefs = GatewayUtils.GetPortletSupportsPersonalization(nHeaderOrFooterID,
							PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER,
							this.m_Session);
				}
				else
				{
					// couldn't open the header!
					try
					{
						this.m_Session.GetGadgets().Open(nHeaderOrFooterID, false);
					}
					catch (Exception ex)
					{
						log.Warn(ex, "Error opening portlet " + nHeaderOrFooterID);

						if( ex instanceof PTException )
						{
							PTException ptex = (PTException) ex;

							switch ( ptex.GetErrorCode() )
							{
								case PT_RESULTCODES.PT_E_ACCESSDENIED:
								{
									if (bIsHeader)
									{
										strLabel = XPResourceManager.FormatMessage(m_asOwner.GetString(1671, "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nHeaderOrFooterID));
									}
									else
									{
										strLabel = XPResourceManager.FormatMessage(m_asOwner.GetString(1673, "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(nHeaderOrFooterID));
									}
									bNewHeaderOrFooterFromCommTemp     = true;
									bHeaderOrFooterHasCommunityPrefs     = false;
									break;
								}
								case PT_RESULTCODES.PT_E_OBJECTNOTFOUND:
								{
									bUseDefaultLabel = true;
									bNewHeaderOrFooterFromCommTemp     = false;
									nHeaderOrFooterID = 0;
									bHeaderOrFooterHasCommunityPrefs     = false;
									break;
								}
								default:
							}
						}
					}

					log.Warn("Couldn't get the stored header ID: " + nHeaderOrFooterID +
						"  for this community.  The header is set in the community template. ");
				}
			}

			if (bIsHeader)
			{
				m_nHeaderID						= nHeaderOrFooterID;
				m_bHeaderFromCommTemp			= bNewHeaderOrFooterFromCommTemp;
				m_bHeaderHasCommunityPrefs		= bHeaderOrFooterHasCommunityPrefs;
				// Remember the header from comm template
				m_nHeaderFromCommTemp			= nCommTempHeaderOrFooterID;

				if (CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nCommTempHeaderOrFooterID)
				{
					m_strHeaderName				= m_asOwner.GetString(1481, "ptmsgs_portalbrowsingmsgs");
				}
				else if (bUseDefaultLabel)
				{
					m_strHeaderName				= m_asOwner.GetString(243, "ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					m_strHeaderName				= strLabel;
				}
			}
			else
			{
				m_nFooterID						= nHeaderOrFooterID;
				m_bFooterFromCommTemp			= bNewHeaderOrFooterFromCommTemp;
				m_bFooterHasCommunityPrefs		= bHeaderOrFooterHasCommunityPrefs;
				// Remember the header from comm template
				m_nFooterFromCommTemp			= nCommTempHeaderOrFooterID;

				if (CommunityTemplateModel.HEADERFOOTER_ID_FORCE_SUBPORTAL == nCommTempHeaderOrFooterID)
				{
					m_strFooterName				= m_asOwner.GetString(1482, "ptmsgs_portalbrowsingmsgs");
				}
				else if (bUseDefaultLabel)
				{
					m_strFooterName				= m_asOwner.GetString(244, "ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					m_strFooterName				= strLabel;
				}
			}
		}
		catch (Exception e)
		{
			log.Warn(e, "Couldn't get the stored header or footer ID: " + nHeaderOrFooterID +
				"  for Community: ");
		}
	}

	//
	// Subcommunity selector/creation page END
	//
	//
	// Community User selector/creation page BEGIN
	//

	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	public void StartCommGroupSelectPTObject()
	{
		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST);

		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(
				259, "ptmsgs_portalbrowsingmsgs"),

		m_asOwner.GetString(260, "ptmsgs_portalbrowsingmsgs"),

		/*PTImageType.ADD_GROUP*/ PTImageType.ACTION_ADD,

		m_asOwner.GetString(264, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_USERGROUP_ID }, 2);

		//     Use the method below to set the icon to display on each row.
		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_GROUP);

		//     Use the method below to set the message and instructions to display when the list is empty.
		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(261,
				"ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(262, "ptmsgs_portalbrowsingmsgs"));

		// DCA - use to not display the add button
		mySelectPTObjectModel.DisableAddButton();

		mySelectPTObjectModel.SetDelRowConfirmMsg(m_asOwner.GetString(1600, "ptmsgs_portalbrowsingmsgs") + "\\n" + m_asOwner.GetString(1603, "ptmsgs_portalbrowsingmsgs"));

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			//
			// Initialize with current community groups in this community
			//
			int nFolderID			  = GetObject().GetAdminFolderID();
			IPTObjectManager omGroups = GetPTSession().GetUserGroups();
			IPTQueryResult ptqrGroups = omGroups.Query(PT_PROPIDS.PT_PROPID_OBJECTID |
					PT_PROPIDS.PT_PROPID_NAME, nFolderID,
					PT_PROPIDS.PT_PROPID_NAME, 0,
					-1, null);

			//     Use the code below to initialize the list with preselected objects.
			int nRows		 = ptqrGroups.RowCount();
			Object[][] oRows = new Object[nRows][SelectPTObjectModel.EXPLIST_COL_MAX];
			int[] arrAdminAccessGroups = GetAdminAccessObjects(omGroups);
			// MJD - Here we know the number of objects we have admin access to and the total number of objects, 
			// so we can take the delta as the size of the array of objects we do not have admin access to.
			int[][] arrNoAdminAccessGroups = new int[nRows - arrAdminAccessGroups.length][2];
			int nIndexForNoAdminAccessGroups = 0;

			for (int i = 0; i < nRows; i++)
			{
				oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectPTObjectModel.m_nNextIndex);
				mySelectPTObjectModel.m_nNextIndex++;
				oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	   = new Integer(PT_CLASSIDS.PT_USERGROUP_ID);
				oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = new Integer(ptqrGroups.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID));
				oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING]	   = ptqrGroups.ItemAsString(i,
						PT_PROPIDS.PT_PROPID_NAME);
						
				boolean bHasAdminAccess = false;
				for (int j = 0; j < arrAdminAccessGroups.length; j++)
				{
					if (arrAdminAccessGroups[j] == ptqrGroups.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID))
					{
						bHasAdminAccess = true;
					}
				}
				if (!bHasAdminAccess)
				{
					arrNoAdminAccessGroups[nIndexForNoAdminAccessGroups][0] = PT_CLASSIDS.PT_USERGROUP_ID;
					arrNoAdminAccessGroups[nIndexForNoAdminAccessGroups][1] = ptqrGroups.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
					nIndexForNoAdminAccessGroups++;
				}
			}

			// JF- Then add the array to the list
			mySelectPTObjectModel.SetDefaultObjects(oRows);

			// MJD - Do NOT allow the user to remove/delete objects they do not have Admin access to.
			mySelectPTObjectModel.SetReadOnlyObjects(arrNoAdminAccessGroups);
		
			// Setup group creation
			InitCommunityGroupCreation(mySelectPTObjectModel);
		}
	}

	private int[] GetAdminAccessObjects(IPTObjectManager om)
	{
		Object[][] qf = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_ACCESSLEVEL, 
			PT_FILTEROPS.PT_FILTEROP_EQ, new Integer(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_ADMIN));
		IPTQueryResult ptqrAdminAccessObjects = om.Query(PT_PROPIDS.PT_PROPID_OBJECTID,
			GetObject().GetAdminFolderID(), PT_PROPIDS.PT_PROPID_OBJECTID, 0, -1, qf);
		int nAdminAccessObjects = ptqrAdminAccessObjects.RowCount();
		int[] arrAdminAccessObjects = new int[nAdminAccessObjects];
		for (int i = 0; i < nAdminAccessObjects; i++)
		{
			arrAdminAccessObjects[i] = ptqrAdminAccessObjects.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
		}
		return arrAdminAccessObjects;
	}

	//
	// Community group selector/creation page END
	//
	//
	// Community portlet selector/creation page BEGIN
	//

	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	public void StartCommPortletSelectPTObject()
	{
		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST);

		mySelectPTObjectModel.InitializeSelectPTObject(m_asOwner.GetString(
				265, "ptmsgs_portalbrowsingmsgs"),
		m_asOwner.GetString(266, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_PORTLET,
		m_asOwner.GetString(270, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_GADGET_ID }, 3);

		//     Use the method below to set the icon to display on each row.
		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_PORTLET);

		//     Use the method below to set the message and instructions to display when the list is empty.
		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(267,
				"ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(268, "ptmsgs_portalbrowsingmsgs"));

		// DCA - use to not display the add button
		mySelectPTObjectModel.DisableAddButton();

		mySelectPTObjectModel.SetDelRowConfirmMsg(m_asOwner.GetString(1602, "ptmsgs_portalbrowsingmsgs") + "\\n" + m_asOwner.GetString(1603, "ptmsgs_portalbrowsingmsgs"));

		if (m_nEditorType == EditorStartControl.EDITOR_START_FLAG_EDIT)
		{
			InitCommunityPortletCreation(mySelectPTObjectModel);
		}
	}

	//
	// Subcommunity selector/creation page BEGIN
	//

	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	public void StartSubCommunitySelectPTObject()
	{
		CommunityEditorSubcommunityModel mySelectPTObjectModel = (CommunityEditorSubcommunityModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST);
		IPTObjectManager ptOM = GetPTSession().GetCommunities();
		int nUserID = GetPTSession().GetSessionInfo().GetCurrentUserID();

		mySelectPTObjectModel.InitializeSelectPTObject(nUserID, ptOM, m_asOwner.GetString(
				253, "ptmsgs_portalbrowsingmsgs"),

		m_asOwner.GetString(254, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ACTION_ADD,

		m_asOwner.GetString(258, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_COMMUNITY_ID }, 1);

		//     Use the method below to set the icon to display on each row.
		mySelectPTObjectModel.SetDefaultRowIcon(PTImageType.ICON_COMMUNITY);

		//     Use the method below to set the message and instructions to display when the list is empty.
		mySelectPTObjectModel.SetEmptyListMessages(m_asOwner.GetString(255,
				"ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(256, "ptmsgs_portalbrowsingmsgs"));

		// DCA - use to not display the add button
		mySelectPTObjectModel.DisableAddButton();

		mySelectPTObjectModel.SetDelRowConfirmMsg(m_asOwner.GetString(1601, "ptmsgs_portalbrowsingmsgs") + "\\n" + m_asOwner.GetString(1603, "ptmsgs_portalbrowsingmsgs"));

		//
		// Initialize with current subcommunities in this community
		//
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			IPTQueryResult ptqrSubcomms = ((IPTCommunity)GetObject()).QuerySubcommunities();

			//     Use the code below to initialize the list with preselected objects.
			int nRows		 = ptqrSubcomms.RowCount();
			Object[][] oRows = new Object[nRows][SelectPTObjectModel.EXPLIST_COL_MAX];
			int[][] arrNoAdminAccessCommunities = new int[nRows][2];

			for (int i = 0; i < nRows; i++)
			{
				oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectPTObjectModel.m_nNextIndex);
				mySelectPTObjectModel.m_nNextIndex++;
				oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	   = new Integer(PT_CLASSIDS.PT_COMMUNITY_ID);
				oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = new Integer(ptqrSubcomms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID));
				oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING]	   = ptqrSubcomms.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
				
				if (PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT >= ptqrSubcomms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_ACCESSLEVEL))
				{
					arrNoAdminAccessCommunities[i][0] = PT_CLASSIDS.PT_COMMUNITY_ID;
					arrNoAdminAccessCommunities[i][1] = ptqrSubcomms.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				}
				else
				{
					// MJD - We do not have access to the number of objects we don't have admin access to before setting up this array.
					// Fortunately the code that checks this doesn't mind filler such as the below.
					arrNoAdminAccessCommunities[i][0] = 0;
					arrNoAdminAccessCommunities[i][1] = 0;
				}
			}

			// JF- Then add the array to the list
			mySelectPTObjectModel.SetDefaultObjects(oRows);

			// MJD - Do NOT allow the user to remove/delete objects they do not have Admin access to.
			mySelectPTObjectModel.SetReadOnlyObjects(arrNoAdminAccessCommunities);

			// Setup subcommunity creation
			InitSubCommunityCreation(mySelectPTObjectModel);
		}
	}

	/**
	 * Returns true if the footer was set in the community template.
	 *
	 * @return true if the footer was set in the community template.
	 */
	public boolean UsingFooterFromCommunityTemplate()
	{
		return m_bFooterFromCommTemp;
	}

	/**
	 * Returns true if the header was set in the community template.
	 *
	 * @return true if the header was set in the community template.
	 */
	public boolean UsingHeaderFromCommunityTemplate()
	{
		return m_bHeaderFromCommTemp;
	}

	// ***CHANGE_HERE*** Implement one method per DP to save it
	// BEGIN ***************** save DP methods *****************

	/**
	 * Saves the data on the gadget prefs page.
	 *
	 * @param _htFormData
	 */
	protected void SavePortletPrefsPage(XPHashtable _htFormData)
	{
	}

	// END ***************** save DP methods *****************
	// ********* private methods

	/**
	 * InitCommunityPortletCreation.
	 * @param _selectModel
	 */
	private void InitCommunityPortletCreation(SelectPTObjectModel _selectModel)
	{
		String[][] strParams = new String[3][2];
		strParams[0][0] = XPConvert.ToString( PTPortlets.PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY );
		strParams[0][1] = XPConvert.ToString( true );
		strParams[1][0] = XPConvert.ToString( PortletModel.QS_SHOWFREEFORM );
		strParams[1][1] = "1";
		strParams[2][0] = XPConvert.ToString( PortletModel.QS_SHOWHEADERFOOTER );
		strParams[2][1] = "1";

		InitObjectCreation(
			_selectModel,
			PT_CLASSIDS.PT_GADGET_ID,
			PortMainPortletEditorAS.STR_MVC_CLASS_NAME,
			m_asOwner.GetString(269,"ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_PORTLET,
			strParams,
			PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS
		);
	}

	/**
	 * InitCommunityGroupCreation.
	 * @param _selectModel
	 */
	private void InitCommunityGroupCreation(SelectPTObjectModel _selectModel)
	{
		InitObjectCreation(
			_selectModel,
			PT_CLASSIDS.PT_USERGROUP_ID,
			GroupEditorAS.STR_MVC_CLASS_NAME,
			m_asOwner.GetString(263,"ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_GROUP,
			null,
			PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_GROUPS
		);
	}

	/**
	 * InitSubCommunityCreation.
	 * @param _selectModel
	 */
	private void InitSubCommunityCreation(SelectPTObjectModel _selectModel)
	{
		InitObjectCreation(
			_selectModel,
			PT_CLASSIDS.PT_COMMUNITY_ID,
			CommunityEditorAS.STR_MVC_CLASS_NAME,
			m_asOwner.GetString(257,"ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_COMMUNITY,
			null,
			PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_COMMUNITIES
		);
	}

	/**
	 * InitObjectCreation.
	 * @param _selectModel
	 * @param _nClassID
	 * @param _strASName
	 * @param _strLabel
	 * @param _ptImgType
	 * @param _strParams
	 * @param _nActivityRight
	 */
	private void InitObjectCreation(SelectPTObjectModel _selectModel, int _nClassID,
		String _strASName, String _strLabel, PTImageType _ptImgType, String[][] _strParams, int _nActivityRight)
	{
		// Check to make sure the user has the correct activity security right for making this time of object.
		if (m_Session.GetSessionInfo().CheckForActivityRight(_nActivityRight))
		{
			int nAdditionalParams = 0;
			if (null != _strParams)
			{
				nAdditionalParams = _strParams.length;
			}
	
			String[][] strParams = new String[2 + nAdditionalParams][2];
			strParams[0][0]	= ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID;
			strParams[0][1]	= XPConvert.ToString(GetCommunityFolderID());
			strParams[1][0]	= ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER;
			strParams[1][1]	= XPConvert.ToString(true);
			for (int i = 0; i < nAdditionalParams; i++)
			{
				strParams[2 + i][0] = _strParams[i][0];
				strParams[2 + i][1] = _strParams[i][1];
			}
	
			// Initialize Creat Object
			Object[][] arrCreateNewInfo = new Object[1][SelectPTObjectModel.CREATE_NEW_COL_MAXWITHPARAMS];
			arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_CLASSID]	= new Integer(_nClassID);
			arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ASNAME]	= _strASName;
			arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_LABEL]	= _strLabel;
			arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ICON]	= _ptImgType;
			arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_PARAMS]	= strParams;
	
			_selectModel.SetEnableCreateNew(arrCreateNewInfo);
		}
	}

	/**
	 * Method InitializePages.
	 * Initializes the community pages using a query result.
	 * Only called when on start editor when editing a community,
	 * or when the community template is selected for the first time
	 * when creating a community.
	 *
	 * @param asqr
	 */
	private Object[][] InitializePages(IASQueryResult asqr)
	{
		int nPageCount;

		if (null == asqr)
		{
			nPageCount = 0;
		}
		else
		{
			nPageCount = asqr.GetCount();
		}

		Object[][] arrReturn = new Object[nPageCount][];
		m_xpsdOldPages = new XPSortedDictionary();

		PageData myPageModel;
		int nPageType;
		int nPageID;
		int nPageTemplateID;
		boolean bFromCommTemp;
		String strPageName;

		for (int i = 0; i < nPageCount; i++)
		{
			// Get information about page to put in page model object
			nPageType     = XPConvert.ToInteger(asqr.GetFields(i,
					PT_PROPIDS.PT_PROPID_PAGES_TYPE));

			nPageID			    = XPConvert.ToInteger(asqr.GetFields(i,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			nPageTemplateID     = XPConvert.ToInteger(asqr.GetFields(i,
					PT_PROPIDS.PT_PROPID_PAGES_PAGETEMPLATEID));

			if (0 == XPConvert.ToInteger(asqr.GetFields(i,
						PT_PROPIDS.PT_PROPID_PAGES_NOTDELETABLE)))
			{
				bFromCommTemp = false;
			}
			else
			{
				bFromCommTemp = true;
			}

			strPageName     = (String) asqr.GetFields(i,
					PT_PROPIDS.PT_PROPID_NAME);

			// Create a page model object for this page
			myPageModel = new PageData(nPageID, m_nObjectID, nPageTemplateID,
					bFromCommTemp, nPageType, strPageName);

			// Setup Old Selected Portlets
			m_xpsdOldPages.PutElement(new Integer(nPageID), "");

			arrReturn[i]													 = new Object[PageListModel.EXPLIST_COL_MAX];
			arrReturn[i][PageListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(i);
			arrReturn[i][PageListModel.EXPLIST_COL_PAGE_MODEL]				 = myPageModel;
		}

		return arrReturn;
	}

	//
	// Header and Footer Category END
	//

	/**
	 * Processes the community pref that holds the lists of gadgets whose title bars have been disabled
	 * by the community owner.
	 *
	 * We create the member hash map once -- when the community is first opened (and only if we're editing
	 * the community, not creating it for the first time).
	 *
	 * The FlipTitleBar function adds and deletes from the map.
	 *
	 * f
	 */
	private void ProcessPortletTitleBars()
	{
		try
		{
			// Get the no title bar pref
			Object[][] saPortletHasNoTitleBar	  = (Object[][]) ((IPTCommunity) m_ptObject).LookupPreference(
				CommunityMyPortalModelHelper.COMGADGETHASNOTITLEBAR, 0, PT_PREF_TYPES.PT_PREFTYPE_ALL_USERS);
			Object oPortletHasNoTitleBar			  = saPortletHasNoTitleBar[1][0];

			String strPortletHasNoTitleBar;

			if (null == oPortletHasNoTitleBar)
			{
				strPortletHasNoTitleBar = "";
			}
			else
			{
				strPortletHasNoTitleBar = (String) oPortletHasNoTitleBar;
			}

			// for each item in the array of gadgets with no title bar, loop through
			// the first token is null, but the tokenizer skips it
			XPStringTokenizer st = new XPStringTokenizer(strPortletHasNoTitleBar,
					",");

			if (st.GetTokenCount() > 0)
			{
				// commented out for reason above
				//st.nextToken(); // need to advance one b/c the first one is an empty ,
				while (st.HasMoreTokens())
				{
					int nPortletID = XPConvert.ToInteger(st.GetNextToken());

					// add this gadget to the map
					// map it to zero -- this is a dummy value, we don't need it
					m_mapPortletsWithNoTitleBars.PutElement(new Integer(
							nPortletID), new Integer(0));
				}
			}
		}
		catch (XPException e)
		{
			// we don't really care why this crashes. we will just show every gadget as expanded..
			log.Warn(e, "CommunityEditorModel.ProcessPortletTitleBars: Exception when getting gadgets with no title bars -- probably are none");
		}
	}

	/**
	 *
	 *
	 * @param _htFormData
	 */
	private void SaveDisableSiteMapSection(XPHashtable _htFormData)
	{
		String[] sValues = (String[]) _htFormData.GetElement(DisableSiteMapView.HTMLINPUT_CHECKBOX_DISABLESITEMAP);

		if (sValues == null)
		{
			m_bSiteMapDisabled = false;
		}
		else
		{
			m_bSiteMapDisabled = true;
		}
	}

	private void RepostToCommunityPortlets()
	{
		//
		// Initialize with current community portlets in this community
		//
		IPTObjectManager omPortlet = GetPTSession().GetGadgets();
		IPTQueryResult ptqrPortlet = omPortlet.Query(PT_PROPIDS.PT_PROPID_OBJECTID |
				PT_PROPIDS.PT_PROPID_NAME, GetObject().GetAdminFolderID(),
				PT_PROPIDS.PT_PROPID_NAME, 0,
				-1, null);

		//     Use the code below to initialize the list with preselected objects.
		int nRows		 = ptqrPortlet.RowCount();
		Object[][] oRows = new Object[nRows][SelectPTObjectModel.EXPLIST_COL_MAX];
		int[] arrAdminAccessPortlets = GetAdminAccessObjects(omPortlet);
		// MJD - Here we know the number of objects we have admin access to and the total number of objects, 
		// so we can take the delta as the size of the array of objects we do not have admin access to.
		int[][] arrNoAdminAccessPortlets = new int[nRows - arrAdminAccessPortlets.length][2];
		int nIndexForNoAdminAccessPortlets = 0;

		SelectPTObjectModel mySelectPTObjectModel = (SelectPTObjectModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST);

		for (int i = 0; i < nRows; i++)
		{
			oRows[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectPTObjectModel.m_nNextIndex);
			mySelectPTObjectModel.m_nNextIndex++;
			oRows[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	   = new Integer(PT_CLASSIDS.PT_GADGET_ID);
			oRows[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = new Integer(ptqrPortlet.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID));
			oRows[i][SelectPTObjectModel.EXPLIST_COL_STRING]	   = ptqrPortlet.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
				
			boolean bHasAdminAccess = false;		
			for (int j = 0; j < arrAdminAccessPortlets.length; j++)
			{
				if (arrAdminAccessPortlets[j] == ptqrPortlet.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID))
				{
					bHasAdminAccess = true;
				}
			}
			if (!bHasAdminAccess)
			{
				arrNoAdminAccessPortlets[nIndexForNoAdminAccessPortlets][0] = PT_CLASSIDS.PT_GADGET_ID;
				arrNoAdminAccessPortlets[nIndexForNoAdminAccessPortlets][1] = ptqrPortlet.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				nIndexForNoAdminAccessPortlets++;
			}
		}

		mySelectPTObjectModel.GetItems().ClearArray();
		mySelectPTObjectModel.SetDefaultObjects(oRows);
		// MJD - Do NOT allow the user to remove/delete objects they do not have Admin access to.
		mySelectPTObjectModel.SetReadOnlyObjects(arrNoAdminAccessPortlets);
	}

	/**
	 *
	 */
	private void RepostToPortletPrefs()
	{
		IPTQueryResult ptqrPages = ((IPTCommunity)m_ptObject).QueryPages(0);
		IPTObjectManager ptPages = m_Session.GetPages();
		m_arrSortedPortlets = new PTSortedArrayWrapper[ptqrPages.RowCount()];

		for (int iCurrentPage = 0; iCurrentPage < ptqrPages.RowCount();
				iCurrentPage++)
		{ // go through each page of the community or My Pages
			IPTPage aPage = (IPTPage)ptPages.Open(ptqrPages.ItemAsInt(iCurrentPage, PT_PROPIDS.PT_PROPID_OBJECTID), false);

			IPTQueryResult gadgets   = aPage.QueryPortlets(); // once the page is opened, the page's gadgets can be queried
			XPArrayList xparrPortlets = new XPArrayList(50);

			for (int j = 0; j < gadgets.RowCount(); j++)
			{ // go through each gadget in the page and check if they have preferences
				String strPortletName = gadgets.ItemAsString(j, PT_PROPIDS.PT_PROPID_NAME);

				XPArrayList gadgetNameID = new XPArrayList(5);
				int nPortletID			 = gadgets.ItemAsInt(j, PT_PROPIDS.PT_PROPID_OBJECTID);

				// figure out the state of the title bar:
				// serverfalse -- if the gadget has no title bar according to the DB
				// preffalse -- if the gadget has no title bar according to the pref
				// preftrue -- if the gadget is not in the pref, and is not set to false in the DB
				// 		which means the gadget has a title bar.
				// we show the checkbox for preffalse or preftrue
				int nPortletTitleBarState;
				boolean bServerSuppressTitleBar = false;

				// This could be null, need to check for that.
				Object oPortletFlags = gadgets.ItemAsObject(j, PT_PROPIDS.PT_PROPID_GADGET_FLAGS);
				if (null != oPortletFlags)
				{
					bServerSuppressTitleBar = (XPConvert.ToInteger(oPortletFlags) &
						PT_GADGET_FLAGS.PT_GADGETFLAG_SUPPRESSTITLEBAR) > 0;
				}

				// if the gadget is a free-form area, then don't show the display title bar box.
				int nPortletAlignment = gadgets.ItemAsInt(j, PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);

				// ok, so if bServerSuppressTitleBar is false, then set the state to server false
				if (bServerSuppressTitleBar ||
						(nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM))
				{
					nPortletTitleBarState = COMMUNITYEDITOR_GADGETTITLEBARS_SERVERFALSE;
				}
				else if (m_mapPortletsWithNoTitleBars.ContainsKey(
							new Integer(nPortletID)))
				{
					// if the gadget is in the pref, then the state is pref false
					nPortletTitleBarState = COMMUNITYEDITOR_GADGETTITLEBARS_PREFFALSE;
				}
				else
				{
					// otherwise it's pref true
					nPortletTitleBarState = COMMUNITYEDITOR_GADGETTITLEBARS_PREFTRUE;
				}

				gadgetNameID.Add(strPortletName);
				gadgetNameID.Add(new Integer(nPortletID));
				gadgetNameID.Add(new Integer(nPortletTitleBarState));

				// bitwise-compare the communityowner bit with the personalization type
				// we add 'true' if the gadget has community prefs, 'false' otherwise
				// JD- this value can be NULL if the portlet that's on the community page
			 	// has no web service.
				Object oPersonalizationType = gadgets.ItemAsObject(j, PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION);
				int nPersonalizationType = 0;
				if (null != oPersonalizationType && oPersonalizationType instanceof Integer)
				{
					nPersonalizationType = XPConvert.ToInteger(oPersonalizationType);
				}

//				if (0 < (nPersonalizationType &
//						PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_COMMUNITYOWNER))
//				{
//					gadgetNameID.Add(new Integer(1));
//				}
//				else
//				{
//					gadgetNameID.Add(new Integer(0));
//				}
				gadgetNameID.Add(new Integer(nPersonalizationType));

				int nGadgetType = gadgets.ItemAsInt(j, PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);
				gadgetNameID.Add(new Integer(nGadgetType));

				xparrPortlets.Add(gadgetNameID);
			}

			// slight hack below -- we have to put propids into the sorted array, but we're not using flags & personalization
			// exactly as they are in the DB.  We basically shove gadget title bar state into the sorted array and call it
			// FLAGS, even though it's a slight variation of flags.
			int[] arrColIDs = new int[5];
			arrColIDs[0]     = PT_PROPIDS.PT_PROPID_NAME;
			arrColIDs[1]     = PT_PROPIDS.PT_PROPID_OBJECTID;
			arrColIDs[2]     = PT_PROPIDS.PT_PROPID_GADGET_FLAGS; // we're setting this to the gadget title bar state
			arrColIDs[3]     = PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION; // we're setting this to true if there are comm prefs
			arrColIDs[4]     = PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE;

			int[][] arrSort  = new int[1][2];
			arrSort[0][0]    = PT_PROPIDS.PT_PROPID_NAME;
			arrSort[0][1]    = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

			int iNumPortlets  = xparrPortlets.GetSize();
			Object[][] arrPortletsForOnePage = new Object[5][iNumPortlets];

			for (int k = 0; k < iNumPortlets; k++)
			{
				arrPortletsForOnePage[0][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(0);
				arrPortletsForOnePage[1][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(1);
				arrPortletsForOnePage[2][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(2);
				arrPortletsForOnePage[3][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(3);
				arrPortletsForOnePage[4][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(4);
			}

			m_arrSortedPortlets[iCurrentPage] = new PTSortedArrayWrapper();
			m_arrSortedPortlets[iCurrentPage].Initialize(arrColIDs,
				arrPortletsForOnePage, arrSort, true);
		}
	}

	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	private void StartPageList()
	{
		// Setup initial pages
		IASQueryResult asqrPages = null;

		((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).
		SetEmptyListMessages(m_asOwner.GetString(251,
				"ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(252, "ptmsgs_portalbrowsingmsgs"));

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			ASQueryResultWrapper qrw = new ASQueryResultWrapper(((IPTCommunity) m_ptObject).QueryPages(0));
			asqrPages = qrw;
		}
		else
		{
			((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).DisableAddButton();
		}

		((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).InitializePageList(m_Session, 4);

		((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).SetEnableMoveRowActions(true);

		// Setup Pages
		Object[][] arrDefaultPages = InitializePages(asqrPages);

		((PageListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).SetDefaultObjects(arrDefaultPages);
	}

	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	private void StartCommunityTemplateSelector(XPHashtable _htFormData)
	{
		int nCommunityTemplateID;
		boolean bInheritCommunityTemplate;

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			((CommunityTemplateSelectorModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).
			SetEmptyListMessages(m_asOwner.GetString(251,
					"ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(252, "ptmsgs_portalbrowsingmsgs"));

			nCommunityTemplateID = ((IPTCommunity) m_ptObject).GetCommunityTemplateID();
			bInheritCommunityTemplate = ((IPTCommunity) m_ptObject).GetInheritCommunityTemplate();
		}
		else
		{
			nCommunityTemplateID = HTTPHelpers.GetArgumentAsInt(_htFormData, PTCommunities.COMM_EDITOR_QS_INT_COMM_TEMPLATE_OBJECT_ID, 0);
			bInheritCommunityTemplate = HTTPHelpers.GetArgumentAsBoolean(_htFormData, PTCommunities.COMM_EDITOR_QS_INT_COMM_TEMPLATE_INHERIT, (0 != nCommunityTemplateID));
			
			((CommunityTemplateSelectorModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).
			SetEmptyListMessages(m_asOwner.GetString(249,
					"ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(250, "ptmsgs_portalbrowsingmsgs"));
		}

		((CommunityTemplateSelectorModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).InitializeCommunityTemplateSelector(m_Session, nCommunityTemplateID, bInheritCommunityTemplate, 63);
		
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType() && 0 != nCommunityTemplateID)
		{
			CommunityTempStore();
		}
	}
	//
	// Header and Footer page stuff END
	//
}