package com.plumtree.portalpages.browsing.editors.community;

// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author MichaelD
 */
public class CommunityEditorPagesDP extends EditorDP {
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommunityEditorPages";
	
	/** Input Hidden: Comm Temp Selected*/
	public static final String STR_HIDDEN_COMM_TEMP_SELECTED = "in_hi_CommTempSelected";

	/**
	 * Returns the String to display on the left navigation menu,  linking to
	 * that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString() {
		return m_asOwner.GetString(273, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() 
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1074, "ptmsgs_portalbrowsingmsgs"),
			this.m_asOwner);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException 
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 */
	public HTMLElement PageDisplay() {
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR).Display());
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_PAGE_LIST).Display());
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(m_asOwner.GetView(DisableSiteMapView.STR_MVC_CLASS_NAME).Display());
		
		HTMLInput inputCommTempSelected = new HTMLInput(HTMLInputTypes.HIDDEN_TYPE, "");
		inputCommTempSelected.SetName(STR_HIDDEN_COMM_TEMP_SELECTED);
		if (0 < ((CommunityTemplateSelectorModel)m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).GetNumObjects())
		{
			inputCommTempSelected.SetValue(CommonHTMLStrings.ONE);
		}
		else
		{
			inputCommTempSelected.SetValue(CommonHTMLStrings.ZERO);
		}
		
		views.AddInnerHTMLElement(inputCommTempSelected);

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * This is a helper method that all classes that inherit from PlumtreeDP need
	 * to implement.  The method should add whatever HTML the child class wants to
	 * use the DisplayJavaScript and add it to the head.
	 *
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#DisplayJavaScriptFromChild()
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection result = super.DisplayJavaScriptFromChild();

		result.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR).DisplayJavascript());
		result.AddInnerHTMLElement(m_asOwner.GetView(CommunityEditorAS.PLUGIN_PAGE_LIST).DisplayJavascript());
		
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		
		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append("function ").Append(CommunityEditorAS.JS_COMM_TEMP_SELECTED).Append("()\n");
		sb.Append("{\n");
		sb.Append("  if (document." + AFormDP.HTMLFORM_NAME + "." +
			STR_HIDDEN_COMM_TEMP_SELECTED + ".value == '0') { \n");

		sb.Append("		alert(\"" + m_asOwner.GetString(1900, ResourceConstants.PORTALBROWSINGMSGS) + "\");\n");
		sb.Append("      return false;\n");
		sb.Append("  }\n");
		sb.Append("  return true;\n");
		sb.Append("}\n");
		myScript.AddInnerHTMLString(sb.ToString());

		
		result.AddInnerHTMLElement(myScript);

		return result;
	}
}

