package com.plumtree.portalpages.browsing.editors.community;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.securitymatrix.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * 
 *
 * @author michaeld
 */
public class CommunityEditorRepostControl extends ObjEditorRepostControl
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommunityEditorRepost";

	public final static int POSTTOSELF_ACTION_CHANGEGADGETPREFSSORT = 13;

	public final static int POSTTOSELF_ACTION_FLIPTITLEBAR = 14;

	public final static int POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER     = 21;

	public final static int POSTTOSELF_ACTION_APPLY_RECURSIVELY = 22;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityEditorRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call  the associated method for each
	 * action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		// set false if don't want normal finish
		boolean doNormalFinish = true;

		// where to go on the next page
		Redirect myRedirect = null;

		// intercept the done button here. if there were
		// changes in security, then redirect to our blank
		// DP which will give the user the option of ABO
		ObjectSecurityModel securityModel = ((ObjectSecurityModel) m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB));
		if ((_nAction == POSTTOSELF_ACTION_FINISH) && ((ObjEditorModel)m_model).GetEditorType() == EditorStartControl.EDITOR_START_FLAG_EDIT && 
				securityModel.HasSecurityChanged())
		{
			if (securityModel.CanPropagateSecurity()) {
				myRedirect = new Redirect();
				myRedirect.SetLinkGetCachedSpace(m_asOwner);
				myRedirect.SetDisplayPage(ABOBlankSelectDP.STR_MVC_CLASS_NAME);
				SetRedirect(myRedirect);
			} else {
				PerformApplySecurity(false);
			}
			// bypass the normal finish
			doNormalFinish = false;
		}

		// since pop-up shares the repost control and
		// opens with no control, we want a bypass
		if (_nAction == POSTTOSELF_ACTION_UNDEFINED)
		{
			doNormalFinish = false;
		}

		// abo - apply only this folder 
		if ( _nAction == POSTTOSELF_ACTION_APPLY_ONLY_THIS_FOLDER )
		{
			PerformApplySecurity(false);
			doNormalFinish = false;
		}

		// abo - apply all acls to child objects and subfolders
		if (_nAction == POSTTOSELF_ACTION_APPLY_RECURSIVELY)
		{
			PerformApplySecurity(true);
		}

		// this is the normal save routine without
		// all our fancy pop-up and redirecting.
		if (doNormalFinish)
		{
			super.PerformAction(_nAction);
		}

		int[] arnIndexToDelete = null;

		//PTGrowableSortedArrayWrapper ptData = null;
		CommunityEditorModel model = ((CommunityEditorModel) m_model);

		// Get the models for list/create pages
		ExpListModel subcommModel = ((ExpListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST));
		ExpListModel commGroups   = ((ExpListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST));
		ExpListModel commPortlet   = ((ExpListModel) m_asOwner.GetModel(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST));

		// Catch the delete actions from these pages.
		int nSubCommDeleteAction     = subcommModel.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE);
		int nCommGroupsDeleteAction  = commGroups.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE);
		int nCommPortletDeleteAction = commPortlet.GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE);

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_CHANGEGADGETPREFSSORT:
			((CommunityEditorModel) m_model).ReversePortletPrefsSort(m_htFormData);

			break;

		case POSTTOSELF_ACTION_FLIPTITLEBAR:
			((CommunityEditorModel) m_model).FlipTitleBar(m_htFormData);

			break;
		}

		// Performs the header and footer actions
		((HeaderAndFooterRepostControl) m_asOwner.GetControl(CommunityEditorAS.PLUGIN_HEADER_AND_FOOTER_SELECTOR)).PerformRepostAction(_nAction,
			m_htFormData);

		// Catch the delete actions from the pt select pages, delete the object right away.
		// Better than comparing added/deleted objects when the editor is done.
		// A little hacky.
		if (_nAction == nSubCommDeleteAction)
		{
			arnIndexToDelete = subcommModel.GetArrayOfObjToDelete(m_htFormData);
			model.DeleteCommSubcomms(GetObjectIDsFromIndexArray(
					arnIndexToDelete, subcommModel.GetItems()));
		}
		else if (_nAction == nCommGroupsDeleteAction)
		{
			arnIndexToDelete = commGroups.GetArrayOfObjToDelete(m_htFormData);
			model.DeleteCommGroupsObjects(GetObjectIDsFromIndexArray(
					arnIndexToDelete, commGroups.GetItems()));
		}
		else if (_nAction == nCommPortletDeleteAction)
		{
			arnIndexToDelete = commPortlet.GetArrayOfObjToDelete(m_htFormData);
			model.DeleteCommPortletObjects(GetObjectIDsFromIndexArray(
					arnIndexToDelete, commPortlet.GetItems()));
		}

		// Delete it in the list too.       
		((ExpListControl) m_asOwner.GetControl(CommunityEditorAS.PLUGIN_SUBCOMMUNITY_LIST)).PerformRepostAction(_nAction,
			m_htFormData);
		((ExpListControl) m_asOwner.GetControl(CommunityEditorAS.PLUGIN_COMMUNITY_GROUP_LIST)).PerformRepostAction(_nAction,
			m_htFormData);
		((ExpListControl) m_asOwner.GetControl(CommunityEditorAS.PLUGIN_COMMUNITY_PORTLET_LIST)).PerformRepostAction(_nAction,
			m_htFormData);

		// You need to call the PerformRepostAction on the community template selector control
		((ExpListControl) m_asOwner.GetControl(CommunityEditorAS.PLUGIN_COMMUNITY_TEMPLATE_SELECTOR)).PerformRepostAction(_nAction,
				m_htFormData);
		// You need to call the PerformRepostAction on the page list control
		((PageListControl) m_asOwner.GetControl(CommunityEditorAS.PLUGIN_PAGE_LIST)).PerformRepostAction(_nAction,
			m_htFormData);
			
		// TODO-MJD : it would be nice if this were in the expandable list framework, currently no way for expandable list control to set the redirect for the main control
		// maybe PerformRepostAction should return a Redirect? This would be a significant change 
		// SE: Bug 61057 - Fix for Toyota. Redirect to Community Editor after a New Page repost action to avoid
		// additional new pages from being created when the user presses refresh.
		if ( ((ExpListModel)m_asOwner.GetModel(CommunityEditorAS.PLUGIN_PAGE_LIST)).GetUniqueInt(ExpListControl.POSTTOSELF_ACTION_DELETE) == _nAction ||
				PageListControl.POSTTOSELF_ACTION_NEW_PAGE == _nAction )
		{
			myRedirect = new Redirect();
			myRedirect.SetLinkGetCachedSpace(m_asOwner);
			myRedirect.SetDisplayPage(CommunityEditorPagesDP.STR_MVC_CLASS_NAME);
			myRedirect.SetIsHTTPRedirect(true);
			SetRedirect(myRedirect);
		}
	}
	
	private void PerformApplySecurity(boolean bPropagateAllACLs) {
		//  get the acl before it gets changed by finish, we need it to compare to the new acl
		IPTAccessList ptOldACL = ((CommunityEditorModel) m_model).GetCurrentFolderACL();
		// manually save acls on the folders
		((CommunityEditorModel) m_model).Finish();
		
		boolean bDisplayJobsPopup = false;
		if (bPropagateAllACLs || ((CommunityEditorModel) m_model).IsAdminModifiedOnFolder(ptOldACL)) {
			// now create the ABO job to update security
			((CommunityEditorModel) m_model).ApplySecurityChangesUsingABO(bPropagateAllACLs);
			bDisplayJobsPopup = true;
		}
		
		if (bDisplayJobsPopup) {
			// we now redirect to our blank page again
			// so that we can show our jobs pop-up
			Redirect myRedirect = new Redirect();
			myRedirect.SetLinkGetCachedSpace(m_asOwner);
			myRedirect.SetDisplayPage(ABOBlankResultsDP.STR_MVC_CLASS_NAME);
			SetRedirect(myRedirect);
		} else {
			if (m_asOwner.IsSubSpace())
			{
				SetRedirectToCloseSubEditor();
			}
			else 
			{
				// MJD- Redirect (default implementation of GetRedirectAfterFinish 
				// redirects to the previous AS).
				Redirect myRedirect = m_model.GetRedirectAfterFinish();

				// Set this redirect to be a true 302 HTTP redirect so that
				// refreshing the page doesn't finish the editor twice.
				myRedirect.SetIsHTTPRedirect(true);
					
				SetRedirect(myRedirect);
			}
		}
	}

	/**
	 * 
	 *
	 * @param arnIndexArray 
	 * @param ptData 
	 *
	 * @return 
	 */
	private int[] GetObjectIDsFromIndexArray(int[] arnIndexArray,
		PTGrowableSortedArrayWrapper ptData)
	{
		int[] arnObjToDelete = new int[arnIndexArray.length];

		for (int i = 0; i < arnObjToDelete.length; i++)
		{
			arnObjToDelete[i] = XPConvert.ToInteger(ptData.GetItem(arnIndexArray[i],
					SelectPTObjectModel.EXPLIST_COL_OBJECTID));
		}

		return arnObjToDelete;
	}
}

