package com.plumtree.portalpages.browsing.editors.community;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Section for a list of pages, with action bar.
 *
 * @author NaveenP
 */
public class DisableSiteMapView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.community.DisableSiteMapView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "DisableSiteMap";

	
	public static final String HTMLINPUT_CHECKBOX_DISABLESITEMAP = "in_cb_DisableSM";

	private AActivitySpace m_asOwner;
	private ICommunityEditorModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DisableSiteMapView();
	}

	/** @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	  *
	  * @return HTMLElement
	  */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			HTMLTable table = new HTMLTable();
			result.AddInnerHTMLElement(table);
			table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			table.SetCellPadding(CommonHTMLStrings.ZERO);
			table.SetCellSpacing(CommonHTMLStrings.ZERO);
			table.SetBorder(CommonHTMLStrings.ZERO);

			HTMLTableRow row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);

			HTMLTableCell cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetColSpan("2");
			cell.SetHeight("20");

			HTMLSpan span = new HTMLSpan();
			cell.AddInnerHTMLElement(span);
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			span.AddInnerHTMLString(m_asOwner.GetString(277,
					"ptmsgs_portalbrowsingmsgs"));

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			// Input selector for object
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("20");
			cell.SetWidth("20");
			cell.SetVAlign(CommonHTMLStrings.CENTER);

			HTMLInput inputSelector = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLINPUT_CHECKBOX_DISABLESITEMAP,
					m_asOwner.GetString(278, "ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(inputSelector);
			inputSelector.SetChecked(m_asModel.IsSiteMapDisabled());
			inputSelector.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);

			// Object Image
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			cell.SetNoWrap(true);
			cell.SetHeight("20");
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			HTMLImg img = null;

			try
			{
				PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_KNOWLEDGE_DIRECTORY,
						true, this.m_asOwner);
				img = (HTMLImg) myConstruct.GetHTMLElement();

				img.SetAlt(m_asOwner.GetString(278, "ptmsgs_portalbrowsingmsgs"));
				img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			}
			catch (Exception e)
			{
				
					log.Error(e, "Display Object: Failed to create image. " +
						e.getMessage());
				
			}

			cell.AddInnerHTMLElement(img);

			// Object Name
			//cell = new HTMLTableCell();
			//row.AddInnerHTMLElement(cell);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			cell.AddInnerHTMLString(m_asOwner.GetString(278,
					"ptmsgs_portalbrowsingmsgs"));
		}
		catch (HTMLException he)
		{
			log.Error(he.getMessage());
		}

		return result;
	}

	/** @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return new HTMLScript("text/javaScript");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/** @see com.plumtree.uiinfrastructure.activityspace.IView#Init()
	  *
	  * @param IModelRO, @param AActivitySpace
	  */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_asModel     = (ICommunityEditorModelRO) model;
	}
}

