package com.plumtree.portalpages.browsing.editors.dircommon;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * 
 *
 * @author stephenc
 */
public class CardPropertyObject
{
    private static OpenLogger log = OpenLogService.GetLogger(
    		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
    		"com.plumtree.portalpages.browsing.editors.dircommon.CardPropertyObject");
	
	public static final int ID_OF_NAME = 1;

	
	public static final int ID_OF_OPEN_DOC_URL = 5;

	
	public static final int ID_OF_DESC = 2;

	
	public static final int ID_OF_DOC_TYPE_PROP = 6;

	
	public static final int ID_OF_IMAGE_UUID = 7;

	
	public static final int ID_OF_CONTENT_LANGUAGE = 8;

	
	public static final int ID_OF_CRAWLER_TAG = 9;

	
	public String m_sPropName;

	
	public String m_sPropValue;

	
	public XPDateTime m_dtDateValue = null; // For date type property values

	
	public boolean m_bIsDate = false;

	
	public boolean m_bIsDeleteable;

	
	public boolean m_bIsDisplayable;

	
	public boolean m_bIsReadOnly;

	
	public boolean m_bIsURL;

	
	public int m_nPropID;

	
	public int m_nPropType;

	/**
	 * Creates a new CardPropertyObject object.
	 *
	 * @param _ptCardPropVal 
	 * @param _nRowNum 
	 * @param _ptqrProperties 
	 */
	public CardPropertyObject(IPTCardPropertyValue _ptCardPropVal, int _nRowNum, IPTQueryResult _ptqrProperties,
                            AActivitySpace _asOwner)
	{
		// Set the property ID
		m_nPropID     = _ptqrProperties.ItemAsInt(_nRowNum, PT_PROPIDS.PT_PROPID_OBJECTID);

		// Set the name
		m_sPropName     = _ptqrProperties.ItemAsString(_nRowNum, PT_PROPIDS.PT_PROPID_NAME);

		// Set the type
		m_nPropType     = _ptqrProperties.ItemAsInt(_nRowNum, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE);

		// Is this property read-only?
		m_bIsReadOnly     = isPropertyReadOnly(_ptqrProperties, _nRowNum);

		// Should this property be displayed as a URL?
		m_bIsURL     = isPropertyDisplayedAsURL(_ptqrProperties, _nRowNum);

		// Should users see this property?
		m_bIsDisplayable     = isPropertyDisplayable(m_nPropID);

		// Should users be able to delete this property?
		m_bIsDeleteable = isPropertyDeletable(m_nPropID);

		// Set the property value
		if (_ptCardPropVal != null)
		{
			try
			{
				if (PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE == m_nPropType)
				{
					m_sPropValue = XPConvert.ToString(_ptCardPropVal.GetValueAsDouble());
				}
				else if (PT_PROPERTY_TYPES.PT_PROPTYPE_LONG == m_nPropType)
				{
					m_sPropValue = XPConvert.ToString(_ptCardPropVal.GetValueAsInt());
				}
				else if (PT_PROPERTY_TYPES.PT_PROPTYPE_STRING == m_nPropType)
				{
					m_sPropValue = _ptCardPropVal.GetValueAsString();
				}
				else if (PT_PROPERTY_TYPES.PT_PROPTYPE_DATE == m_nPropType)
				{
					m_bIsDate = true;
					
					// DCD: Our overall goal here is to put a nicely-formatted string version of the date
					//		into m_sPropValue for reading by the UI.  Sometimes dates are stored as XPDateTimes,
					//		sometimes they're stored as strings.  We handle both cases.

					// DCD: Create a formatter for displaying the final string representation of this date, we'll
					//		use this in a second.
					XPDateFormat xpDateFormat = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM, XPDateFormat.MEDIUM, 
			        		PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(_asOwner),
							PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(_asOwner));
					
				  	// DCD: Card date properties are sometimes stored as Strings.  If the property
					//		is stored as a date, this will return null, otherwise we return a nice string
					String sDateValueAsString = _ptCardPropVal.GetValueAsString();
					
					// DCD: If this was stored as an actual date, read it with the date access method
					if (null == sDateValueAsString)
					{
					    m_dtDateValue = _ptCardPropVal.GetValueAsXPDateTime();
						
					    //	DCD: Set the user-friendly version of our date string-- We're Done!
			        	m_sPropValue = xpDateFormat.Format(m_dtDateValue);
					    
					}
					
					// DCD: If this was stored as a string, we need to rebuild the XPDateTime, then format it
					//		according to user locale info, etc.
					else
					{
					    //	DCD: Create a formatter for parsing the string representing a date
						XPDateFormat format = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM, XPDateFormat.MEDIUM);
						
						try
						{
						    // DCD: Parse the date-time string into an XPDateTime
				        	m_dtDateValue = format.Parse(sDateValueAsString);

				        	//	DCD: This is the user-friendly version of our date string-- We're Done!
				        	m_sPropValue = xpDateFormat.Format(m_dtDateValue);
						}
						catch(Exception e)
						{
						    log.Warn("Unable to parse date string: " + sDateValueAsString + ", for Property " + m_sPropName);
							
						    // DCD: Even though this is not a parsable or formatable string, try to display *something*
						    m_sPropValue = sDateValueAsString;
						}
					}
				}
			}
			// DCD: Something went horribly, horribly wrong.
			catch(Exception e)
			{
			    m_sPropValue = "";
			    log.Warn("Unable to read card property " + m_sPropName);
			   
			}
		}
		// DCD: A null card property is unthinkably catastrophic.
		else
		{
		    log.Warn("Card property " + m_sPropName + " is null.");
			m_sPropValue = "";
		}
	}

	/**
	 * 
	 *
	 * @param _nPropID 
	 *
	 * @return 
	 */
	public static boolean isPropertyDeletable(int _nPropID)
	{
		if ((_nPropID == ID_OF_NAME) || (_nPropID == ID_OF_DESC) || (_nPropID == ID_OF_DOC_TYPE_PROP) || (_nPropID == ID_OF_IMAGE_UUID) || (_nPropID == ID_OF_OPEN_DOC_URL))
		{
			return (true);
		}

		return (false);
	}

	/**
	 * 
	 *
	 * @param _ptqrProperties 
	 * @param _nRowNum 
	 *
	 * @return 
	 */
	public static boolean isPropertyDisplayedAsURL(IPTQueryResult _ptqrProperties, int _nRowNum)
	{
		if (_ptqrProperties.ItemAsInt(_nRowNum, PT_PROPIDS.PT_PROPID_PROP_HREF) == 1)
		{
			return (true);
		}

		return (false);
	}

	/**
	 * 
	 *
	 * @param _nPropID 
	 *
	 * @return 
	 */
	public static boolean isPropertyDisplayable(int _nPropID)
	{
		if (_nPropID == ID_OF_IMAGE_UUID)
		{
			return (true);
		}

		return (false);
	}

	/**
	 * 
	 *
	 * @param _ptqrProperties 
	 * @param _nRowNum 
	 *
	 * @return 
	 */
	public static boolean isPropertyReadOnly(IPTQueryResult _ptqrProperties, int _nRowNum)
	{
		int nObjID = _ptqrProperties.ItemAsInt(_nRowNum, PT_PROPIDS.PT_PROPID_OBJECTID);

		if ((_ptqrProperties.ItemAsInt(_nRowNum, PT_PROPIDS.PT_PROPID_PROP_READONLYVALUE) == 1) || (nObjID == ID_OF_OPEN_DOC_URL))
		{
			return (true);
		}

		return (false);
	}

	/**
	 * 
	 *
	 * @param _ptQR 
	 *
	 * @return 
	 */
	static public XPHashtable createHashtableOfObjIDByRow(IPTQueryResult _ptQR)
	{
		XPHashtable htRetVal = new XPHashtable();

		for (int i = 0; i < _ptQR.RowCount(); i++)
		{
			int nPropID = _ptQR.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
			htRetVal.PutElement(new Integer(nPropID), new Integer(i));
		}

		return ((XPHashtable) htRetVal.Clone());
	}
}

