package com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * This interface is implemented by the Model. It contains all the read-only
 * mothods of the Model accessed by the Views.
 *
 * @author stephenc
 */
public interface IEditCardPropModelRO extends IExpListPropModelRO
{
	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNewlySelectedPropertyID();

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumProperties();

	/**
	 * 
	 *
	 * @return 
	 */
	public PTImageType GetRowIcon();

	/**
	 * 
	 *
	 * @return 
	 */
	public XPSortedDictionary GetUnusedProperties();
	
	/**
	 * If a property has a pick tree or pick list, check that the pick values
	 * can be successfully retrieved.
	 * 
	 * @param _nRowIndex Row index
	 * 
	 * @return True if pick values can be successfully retrieved.
	 */
	public boolean CheckPickValuesAreValid(int _nRowIndex);

	/**
	 * Returns string representation of property value
	 *
	 * @param oValue Property value as Object
	 * @param nPropertyType Property type
	 *
	 * @return Property value as string
	 */
	public String GetStringFromObjectValue(Object oValue, int nPropertyType);
	
	/**
	 * Return pick list values for the property
	 *
	 * @param _nPropertyID Property ID
	 *
	 * @return Pick list values
	 */
	public Object[][] GetPickListValues(int _nPropertyID);
	
	/**
	 * Return the pick type for the property.
	 * 
	 * @param _nRowIndex Row index
	 * 
	 * @return Pick type
	 */
	public int GetPickType(int nRowIndex);
	
	/**
	 * Checks to see if the property is multivalued
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if multivalued. Otherwise returns false.
	 */
	public boolean CheckRowIsMultiValued(int _nRowIndex);
	
	/**
	 * Checks to see if the property is read-only
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if read-only. Otherwise returns false.
	 */
	public boolean CheckRowIsReadOnly(int _nRowIndex);
}

