package com.plumtree.portalpages.browsing.editors.document;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.linksettings.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author StephenC
 */
public class CardEditorAS extends ObjEditorAS
{
	
	public static final String STR_MVC_CLASS_NAME = "CardEditor";

	
	public static final String strLinkSettingsPlugInKey = "CardEditorLinkSettingsPlugIn";

	
	public static final String strCardLanguagePlugInKey = "CardEditorCardLanguagePlugIn";

	
	public static final String strEditCardPropertiesPlugInKey = "CardEditorEditCardPropertiesPlugIn";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CardEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return (XPResourceManager.FormatMessage(GetString(1705, "ptmsgs_portalbrowsingmsgs"), GetObjectName()));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (CardEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = CardEditorModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(CardEditorModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		CardEditorLinkSettingsDP cardLinkDP = new CardEditorLinkSettingsDP();
		cardLinkDP.AddToValidationFunction("CheckNumericLinkValues");
		RegisterPage(cardLinkDP);

		CardEditorMainDP cardMainDP = new CardEditorMainDP();
		cardMainDP.AddToValidationFunction(CardEditorMainView.JAVASCRIPT_CHECKNAME);
		RegisterPage(cardMainDP);

		// Register Views
		RegisterView(CardEditorMainView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(CardEditorDocInfoView.STR_MVC_CLASS_NAME, myModel);

		SetCurrentPage(CardEditorMainDP.STR_MVC_CLASS_NAME);

		// Register Controls
		RegisterControl(CardEditorRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register plug-in sections
		// Link Settings Plug-In
		RegisterModel(LinkSettingsPlugInModel.STR_MVC_CLASS_NAME, strLinkSettingsPlugInKey);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myLinkSettingsPlugInModel = GetModel(strLinkSettingsPlugInKey);
		RegisterView(LinkSettingsPlugInView.STR_MVC_CLASS_NAME, strLinkSettingsPlugInKey, myLinkSettingsPlugInModel);

		// Card Language Plug-In
		RegisterModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myCardLanguagePlugInModel = GetModel(strCardLanguagePlugInKey);
		RegisterView(CardLanguagePlugInView.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey, myCardLanguagePlugInModel);
		RegisterControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME, strCardLanguagePlugInKey, myCardLanguagePlugInModel);

		// Register Plug-In: CardProperties
		RegisterModel(EditCardPropModel.STR_MVC_CLASS_NAME, strEditCardPropertiesPlugInKey);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myEditCardPropertiesPlugInModel = GetModel(strEditCardPropertiesPlugInKey);
		RegisterView(EditCardPropView.STR_MVC_CLASS_NAME, strEditCardPropertiesPlugInKey, myEditCardPropertiesPlugInModel);
		RegisterControl(EditCardPropRepostControl.STR_MVC_CLASS_NAME, strEditCardPropertiesPlugInKey, myEditCardPropertiesPlugInModel);

		//Sets left nav menu
		// BEGIN Sub menu "Properties"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(190, "ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CardEditorMainDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, CardEditorLinkSettingsDP.STR_MVC_CLASS_NAME);

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1502, "ptmsgs_portalbrowsingmsgs"));

		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Properties"
		this.SetHelpTopic("PT_DocumentSettings");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

		String sPageName = page.GetName();

		if (CardEditorMainDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Document_MainSettings");
		}
		else if (CardEditorLinkSettingsDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_DocumentSettings");
		}
		else if (ObjectSecurityDP.STR_MVC_CLASS_NAME.equals(sPageName))
		{
			this.SetHelpTopic("PT_Document_Security");
		}
	}
}

