package com.plumtree.portalpages.browsing.editors.document;

import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * This is class is used to print out together the Views for
 * the General Info page of the Property Editor.
 */
public class CardEditorMainDP extends EditorDP
{
	
	public static final String STR_MVC_CLASS_NAME = "CardEditorMain";

	/**
	 * Displays some HTML after the body tag and before the form tag. For
	 * example this is used by pages using a DHTML calendar to display the div
	 * tag. The function is optional.  If it exists, it will be called by the
	 * framework, and the resulting HTMLElement will be added in the right
	 * place.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException 
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm()
	{
		IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey);

		return iModelRO.GetDateTimePickerControlManager().GetPagePreFormContent();
	}

	/**
	 * Returns the HTML that is placed in the HEAD section of this HTML page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException 
	 */
	public HTMLElementCollection DisplayHTMLinHEAD() 
	{
		IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey);

		return iModelRO.GetDateTimePickerControlManager().GetJSIncludes();
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(198, "ptmsgs_portalbrowsingmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CardEditorMainView.STR_MVC_CLASS_NAME)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strCardLanguagePlugInKey).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strEditCardPropertiesPlugInKey).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(CardEditorDocInfoView.STR_MVC_CLASS_NAME)).Display());

		//Add the Object Properties view
		views.AddInnerHTMLElement(EditorView.GetSpacerTable());
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(ObjEditorAS.STR_MVC_STORAGE_NAME_KEYWORDS)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild() 
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(m_asOwner.GetView(CardEditorAS.strEditCardPropertiesPlugInKey).DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(CardEditorMainView.STR_MVC_CLASS_NAME).DisplayJavascript());

		return myScripts;
	}

	/**
	 * Implement this method to add HTML below the sub header.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	protected HTMLElement GetHTMLBelowSubHeader() 
	{
		return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1453, "ptmsgs_portalbrowsingmsgs"), this.m_asOwner);
	}
}

