package com.plumtree.portalpages.browsing.editors.document;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.editors.dircommon.*;
import com.plumtree.portalpages.browsing.editors.dircommon.editdocumentproperty.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.linksettings.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author StephenC
 *
 * This class contains the IPTCard server object,
 * as well as the set and get methods on that object.
 * This class is called by the CardEditorRepostControl to perform
 * the changes on the Object and by the Views CardEditorMainView,
 * CardEditorMainSettingsView, and CardEditorLinkSettings Section
 * to display the latest values on the page.
 */
public class CardEditorModel extends ObjEditorModel implements ICardEditorModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.document.CardEditorModel");


	public static final String STR_MVC_CLASS_NAME = "Card Editor";


	public IPTCardRefreshAgent m_ptCardRefreshAgent = null;
	protected IPTCardPropertyValues m_ptCardPropertyValues = null;
	protected XPSortedDictionary m_xpBasicProperties = null;
	protected XPSortedDictionary m_xpCardInformation = null;
	protected XPSortedDictionary m_xpCustomProperties = null;

	// END ***************** save DP methods *****************

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CardEditorModel();
	}

	/**
	 * Initializes IPTProperty with the property type member
	 * variable just before we store the object in the DB.
	 * Also sets 2 other values to default.
	 */
	public void DoTaskBeforeStore()
	{
		// Set to index on store
		((IPTCard) m_ptObject).SetCardSettings(PT_CARD_SETTINGS.PT_CARD_INDEXONSTORE,
			1);

		// Save CardLanguage
		String strCardLanguageCode = ((CardLanguagePlugInModel) m_asOwner.GetModel(CardEditorAS.strCardLanguagePlugInKey)).GetCardLanguageCode();
		((IPTCard) m_ptObject).SetContentLanguage(strCardLanguageCode);

		// Save Refresh Info
		IPTCardRefreshInfo ptCardRefreshInfo = ((LinkSettingsPlugInModel) m_asOwner.GetModel(CardEditorAS.strLinkSettingsPlugInKey)).GetCardRefreshInfo();
		IPTPersist ptCardRefreshInfoPersist = (IPTPersist) ptCardRefreshInfo;
		m_ptCardRefreshAgent.SetCardRefreshInfo(this.m_nObjectID, ptCardRefreshInfoPersist.SaveToXML(0));

		((EditCardPropModel) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey)).Finish();
	}

	// END ***************** helper methods *****************

	/**
	 * Initializes the property type member variable with
	 * the one from IPTProperty in Edit mode and the default
	 * value in create mode.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		// Get the Card Refresh Info
		m_ptCardRefreshAgent = (IPTCardRefreshAgent) m_Session.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_CARD_REFRESH_AGENT, false); //*CRC olegs - just cast "IPTObject m_ptObject" from base class

		IPTCardRefreshInfo ptCardRefreshInfo = m_ptCardRefreshAgent.GetCardRefreshInfo(this.m_nObjectID);

		String strCardLanguageCode = ((IPTCard) m_ptObject).GetContentLanguage();

		// Here initialize the plug-in models.
		((CardLanguagePlugInModel) m_asOwner.GetModel(CardEditorAS.strCardLanguagePlugInKey)).InitializePlugIn(strCardLanguageCode, null, null, false);

		((LinkSettingsPlugInModel) m_asOwner.GetModel(CardEditorAS.strLinkSettingsPlugInKey)).InitializePlugIn(false, ptCardRefreshInfo);

		((EditorAS) m_asOwner).GetLeftMenu().HideLink(false, ObjectSecurityDP.STR_MVC_CLASS_NAME);

		if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

		LoadCardProperties();

		StartEditCardProperties();
	}

	// Card Property methods
	public XPSortedDictionary GetBasicCardProperties()
	{
		return m_xpBasicProperties;
	}

	/**
	 *
	 *
	 * @return
	 */
	public XPSortedDictionary GetCardInformation()
	{
		return m_xpCardInformation;
	}

	// BEGIN ***************** helper methods *****************
	public String GetCreated()
	{
		XPDateTime xpCreatedDate = ((IPTCard) m_ptObject).GetCreated();
		XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(
			XPDateFormat.MEDIUM,
			XPDateFormat.MEDIUM,
			PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
			PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner));
		String strCreatedDate = xpDateTimeFormat.Format(xpCreatedDate);
		return strCreatedDate;
	}

	/**
	 *
	 *
	 * @return
	 */
	public XPSortedDictionary GetCustomCardProperties()
	{
		return m_xpCustomProperties;
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetDocType()
	{
		return ((IPTCard) m_ptObject).GetDocumentTypeID();
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetLastModified()
	{
		XPDateTime xpModifiedDate = ((IPTCard) m_ptObject).GetLastModified();
		XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(
			XPDateFormat.MEDIUM,
			XPDateFormat.MEDIUM,
			PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
			PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner));
		String strModifiedDate = xpDateTimeFormat.Format(xpModifiedDate);
		return strModifiedDate;

	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Get the SpaceID of the parent Activity Space
	 *
	 * @return int m_asOwner.GetSpaceID();
	 */
	public String GetSpaceID()
	{
		return m_asOwner.GetSpaceID();
	}

	/**
	 *
	 *
	 * @return
	 */
	public String GetURL()
	{
		return ((IPTCard) m_ptObject).GetDocumentURL();
	}

	/**
	 *
	 */
	public void LoadCardProperties()
	{
		m_xpBasicProperties		   = null;
		m_xpCustomProperties	   = null;
		m_xpCardInformation		   = null;
		m_ptCardPropertyValues     = null;

		XPSortedDictionary xpBasicProperties = new XPSortedDictionary();
		XPSortedDictionary xpCustomProperties = new XPSortedDictionary();
		XPSortedDictionary xpCardInformation = new XPSortedDictionary();

		m_ptCardPropertyValues     = ((IPTCard) m_ptObject).GetPropertyValues();

		// Get all Properties
		IPTQueryResult ptqrProperties = m_Session.GetProperties().Query(PT_PROPIDS.PT_PROPID_OBJECTID | PT_PROPIDS.PT_PROPID_NAME | PT_PROPIDS.PT_PROPID_PROP_VALUETYPE | PT_PROPIDS.PT_PROPID_PROP_HREF | PT_PROPIDS.PT_PROPID_PROP_READONLYVALUE, -1, PT_PROPIDS.PT_PROPID_NAME, 0, -1, null);

		// Get the property IDs for this card
		Object[] arCardPropIDs = (Object[]) m_ptCardPropertyValues.GetPropertyIDs();

		for (int i = 0; i < ptqrProperties.RowCount(); i++)
		{
			int nPropID = ptqrProperties.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);

			if (doesPropertyDescribeCard(arCardPropIDs, nPropID))
			{
				CardPropertyObject cpo = new CardPropertyObject(m_ptCardPropertyValues.GetItem(nPropID), i, ptqrProperties, m_asOwner);

				// Skip Plumtree Card Image UUID
				if (cpo.m_bIsDisplayable)
				{
					continue;
				}

				if (IsIgnoredProperty(cpo))
				{
					continue;
				}

				if (true == IsBasicCardProperty(cpo))
				{
					xpBasicProperties.PutElement(XPConvert.ToString(nPropID), cpo);
				}
				else
				{
					String strPropName = cpo.m_sPropName;
					xpCustomProperties.PutElement(strPropName, cpo);
				}
			}
		}

		// for
		// Get Popularity Stats
		IPTQueryResult ptQR = m_Session.GetCatalog().GetStatistics().QueryCardPopularityStatistics(m_nObjectID);

		String strPopularity = XPConvert.ToString(ptQR.ItemAsInt(0, PT_PROPIDS.PT_PROPID_CARD_POPULARITY));
		String strAccessCount = XPConvert.ToString(ptQR.ItemAsInt(0, PT_PROPIDS.PT_PROPID_CARD_ACCESSCOUNT));

		XPDateTime xpLastModified = ptQR.ItemAsXPDateTime(0, PT_PROPIDS.PT_PROPID_CARD_LASTACCESS);
		XPDateFormat xpDateTimeFormat = XPDateFormat.GetDateTimeInstance(
			XPDateFormat.MEDIUM,
			XPDateFormat.MEDIUM,
			PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
			PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner));
		String strLastModified = xpDateTimeFormat.Format(xpLastModified);

		// Get Card Paths
		IPTQueryResult qrCardPaths = m_Session.GetCatalog().QueryCardPaths(m_nObjectID, false, false);
		int nParentFolderCount = qrCardPaths.RowCount();
		Object[][] arCardPaths = new Object[nParentFolderCount][2];

		for (int i = 0; i < nParentFolderCount; i++)
		{
			arCardPaths[i][0]     = qrCardPaths.ItemAsObject(i, PT_PROPIDS.PT_PROPID_CARD_PARENTFOLDERID);
			arCardPaths[i][1] = qrCardPaths.ItemAsObject(i, PT_PROPIDS.PT_PROPID_FOLDER_PATH);
		}

		xpCardInformation.PutElement(m_asOwner.GetString(207, "ptmsgs_portalbrowsingmsgs"), new CardStatisticObject(m_asOwner.GetString(207, "ptmsgs_portalbrowsingmsgs"), strLastModified, null));

		xpCardInformation.PutElement(m_asOwner.GetString(206, "ptmsgs_portalbrowsingmsgs"), new CardStatisticObject(m_asOwner.GetString(206, "ptmsgs_portalbrowsingmsgs"), strPopularity, null));

		xpCardInformation.PutElement(m_asOwner.GetString(208, "ptmsgs_portalbrowsingmsgs"), new CardStatisticObject(m_asOwner.GetString(208, "ptmsgs_portalbrowsingmsgs"), strAccessCount, null));

		xpCardInformation.PutElement(m_asOwner.GetString(209, "ptmsgs_portalbrowsingmsgs"), new CardStatisticObject(m_asOwner.GetString(209, "ptmsgs_portalbrowsingmsgs"), null, arCardPaths));

		m_xpBasicProperties		 = xpBasicProperties;
		m_xpCustomProperties     = xpCustomProperties;
		m_xpCardInformation		 = xpCardInformation;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nRetVal = super.SavePage(_sPageName, _htFormData);

		int nSectionRetVal;

		if (_sPageName.equals(CardEditorMainDP.STR_MVC_CLASS_NAME))
		{
			// Save Card Language
			nSectionRetVal = ((CardLanguagePlugInModel) m_asOwner.GetModel(CardEditorAS.strCardLanguagePlugInKey)).SaveSection(_htFormData);

			if (RepostControl.PAGE_STATUS_VALID != nSectionRetVal)
			{
				nRetVal = nSectionRetVal;
			}

			// Save Card Properties
			nSectionRetVal = ((EditCardPropModel) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey)).SaveSection(_htFormData);

			if (RepostControl.PAGE_STATUS_VALID != nSectionRetVal)
			{
				nRetVal = nSectionRetVal;
			}

			SaveMainPage(_htFormData);
		}
		else if (_sPageName.equals(CardEditorLinkSettingsDP.STR_MVC_CLASS_NAME))
		{
			// Save Link Settings
			nSectionRetVal = ((LinkSettingsPlugInModel) m_asOwner.GetModel(CardEditorAS.strLinkSettingsPlugInKey)).SaveSection(_htFormData);

			if (RepostControl.PAGE_STATUS_VALID != nSectionRetVal)
			{
				nRetVal = nSectionRetVal;
			}
		}

		return nRetVal;
	}

	// BEGIN ***************** save DP methods *****************

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
		String[] data;

		// CARD NAME
		data = (String[]) _htFormData.GetElement(CardEditorMainView.HTMLINPUT_CARD_NAME);

		if ((null != data) && !(0 == data.length))
		{
			//MES- NOTE: This is NOT the localized name, the user is editing
			//	the primary name.
			String strOldName = m_ptObject.GetName();
			String strNewName = data[0];
			
			// Bug 55036 changing EqualsIgnoreCase to equals. You may want to just change the case
			// of the name and nothing else.
			if (!strOldName.equals(strNewName))
			{
				m_ptObject.SetName(strNewName);
				((IPTCard) m_ptObject).SetCardSettings(PT_CARD_SETTINGS.PT_CARD_OVERWRITENAME, 0);
			}

			
				log.Debug("CardEditorModel::SaveMainPage New card name: " + data[0]);
			
		}
		else
		{
			
				log.Warn("CardEditorModel::SaveMainPage Card name was not in Query String.");
			
		}

		// CARD DESCRIPTION
		data = (String[]) _htFormData.GetElement(CardEditorMainView.HTMLINPUT_CARD_DESCRIPTION);

		if ((null != data) && !(0 == data.length))
		{
			//MES- NOTE: This is NOT the localized description, the user is editing
			//	the primary description.
			String strOldDescription = m_ptObject.GetDescription();
			String strNewDescription = data[0];
			// Bug 55036 changing EqualsIgnoreCase to equals. You may want to just change the case
			// of the description and nothing else.
			if (!strOldDescription.equals(strNewDescription))
			{
				m_ptObject.SetDescription(strNewDescription);
				((IPTCard) m_ptObject).SetCardSettings(PT_CARD_SETTINGS.PT_CARD_OVERWRITEDESCRIPTION, 0);
				log.Debug("CardEditorModel::SaveMainPage New Card description: " + data[0]);
			}
		}
		else
		{
			log.Warn("CardEditorModel::SaveMainPage Card description was not in Query String.");
		}

		// CRAWLER TAG
		data = (String[]) _htFormData.GetElement(CardEditorMainView.HTMLINPUT_CARD_CRAWLERTAG);

		if ((null != data) && !(0 == data.length))
		{
			((IPTCard)m_ptObject).SetCrawlerTag(data[0]);
		}
		else
		{
			
				log.Warn("CardEditorModel::SaveMainPage Card crawler tag was not in Query String.");
			
		}
	}

	/**
	 *
	 *
	 * @param cpo
	 *
	 * @return
	 */
	private boolean IsBasicCardProperty(CardPropertyObject cpo)
	{
		int nPropID = cpo.m_nPropID;
		boolean bReadOnly = cpo.m_bIsReadOnly;

		return ((CardPropertyObject.ID_OF_NAME == nPropID) ||
		(CardPropertyObject.ID_OF_DESC == nPropID) ||
		(CardPropertyObject.ID_OF_DOC_TYPE_PROP == nPropID) ||
		(CardPropertyObject.ID_OF_OPEN_DOC_URL == nPropID) ||
		bReadOnly);
	}

	/**
	 *
	 *
	 * @param cpo
	 *
	 * @return
	 */
	private boolean IsIgnoredProperty(CardPropertyObject cpo)
	{
		int nPropID = cpo.m_nPropID;

		return ((CardPropertyObject.ID_OF_NAME == nPropID)
					|| (CardPropertyObject.ID_OF_DESC == nPropID)
					|| (CardPropertyObject.ID_OF_CRAWLER_TAG == nPropID)
					|| (CardPropertyObject.ID_OF_CONTENT_LANGUAGE == nPropID));
	}

	public String GetCrawlerTag()
	{
		return ((IPTCard) m_ptObject).GetCrawlerTag();
	}

	/**
	 *
	 */
	private void StartEditCardProperties()
	{
		((EditCardPropModel) m_asOwner.GetModel(CardEditorAS.strEditCardPropertiesPlugInKey)).InitializeCardProperties(m_Session, m_ptCardPropertyValues, m_xpCustomProperties, m_asOwner.GetString(211, "ptmsgs_portalbrowsingmsgs"), PTImageType.ICON_PROPERTY, m_asOwner.GetString(210, "ptmsgs_portalbrowsingmsgs"), 13);
	}

	/**
	 *
	 *
	 * @param arCardPropIDs
	 * @param nPropID
	 *
	 * @return
	 */
	private boolean doesPropertyDescribeCard(Object[] arCardPropIDs, int nPropID)
	{
		for (int i = 0; i < arCardPropIDs.length; i++)
		{
			if (nPropID == XPConvert.ToInteger(arCardPropIDs[i]))
			{
				return true;
			}
		}

		return false;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		Redirect redirect = super.GetRedirectAfterFinish();

		if (redirect.GetSpaceName().equals(DirAS.STR_MVC_CLASS_NAME))
		{
			redirect.SetDisplayPage(DirAS.DIR_EDITOR_FINISH);
		}

		return redirect;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetObjectID()
	 */
	public int GetObjectID() 
	{
	    return m_nObjectID;
//		IPTServerContext pSC = null;
//		try
//		{
//			pSC = (IPTServerContext)m_ptObject;
//		}
//		catch (Exception e)
//		{
//			// if the object does not support IPTServerContext, return 0 -jas
//			return 0;
//		}
//		
//		return pSC.GetObjectID();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetObjectUUID()
	 */
	public String GetObjectUUID() {
		IPTMigratable pM = null;
		try
		{
			pM = (IPTMigratable)m_ptObject;
		}
		catch (Exception e)
		{
			// if the object does not support IPTMigratable, return null -jas
			return null;
		}
		
		return pM.GetObjectUUID();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.ILocNamesModelRO#GetClassID()
	 */
	public int GetClassID()
	{
	    return m_nClassID;
//		IPTObject pObj = null;
//		try
//		{
//			pObj = (IPTObject)m_ptObject;
//		}
//		catch (Exception e)
//		{
//			// if the object does not support IPTObject, return 0 -jas
//			return 0;
//		}
//		
//		return pObj.GetClassID();
	}
}