package com.plumtree.portalpages.browsing.editors.editportletprefs;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is class is used to print out together the Views for
 * the Misc Settings page of the Misc Editor.
 *
 * @author Dusting Ang
 */
public class EditPortletPrefsDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.editportletprefs.EditPortletPrefsDP");

	
	public static final String STR_MVC_CLASS_NAME = "EditPortletPrefs";

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		EditPortletPrefsModel iModel = (EditPortletPrefsModel) m_asOwner.GetModel(EditPortletPrefsModel.STR_MVC_CLASS_NAME);

		if (iModel.GetCommunityID() == 0)
		{
			return (m_asOwner.GetString(380, "ptmsgs_portalbrowsingmsgs"));
		}
		else
		{
			return (m_asOwner.GetString(379, "ptmsgs_portalbrowsingmsgs"));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for that Page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				PortletPreferencesView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}
	
	/**
	 * Creates a table with the left nav bar and puts innerElement next to the
	 * left nav bar.
	 *
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#CreateLeftNavBar()
	 * 
	 * @param _Views
	 *
	 * @return HTMLTable
	 *
	 */
	public HTMLTable CreateLeftNavBar(HTMLElement _Views)
	{
		HTMLTable myMainTable;
		HTMLTableRow myMainTableRow;
		HTMLTableCell myMainTableCell;
		EditorLeftNavView myLeftNavView = (EditorLeftNavView) m_asOwner.GetView(EditorLeftNavView.STR_MVC_CLASS_NAME);

		// Start Main table
		myMainTable = new HTMLTable();
		myMainTable.SetBorder("0");
		myMainTable.SetCellPadding("0");
		myMainTable.SetCellSpacing("10");
		myMainTable.SetWidth("100%");

		// Main table 1st Row
		myMainTableRow = new HTMLTableRow();
		myMainTable.AddInnerHTMLElement(myMainTableRow);

		if (!((IEditorModelRO) m_asOwner.GetModel(m_asOwner.m_strModelName)).GetHideLeftNav())
		{
			// Row 1 - Cell 1
			myMainTableCell = new HTMLTableCell();
			myMainTableRow.AddInnerHTMLElement(myMainTableCell);
			myMainTableCell.SetWidth("225");
			myMainTableCell.SetVAlign("top");

			// Display Left Navigation Menu
			myMainTableCell.AddInnerHTMLElement(myLeftNavView.Display());

			myMainTableCell.AddInnerHTMLElement((m_asOwner.GetView(
					TipsView.STR_MVC_CLASS_NAME).Display()));

			// Display Spacer table
			myMainTableCell.AddInnerHTMLElement(GetSpacerTable());
		}

		// Row 2 - Cell 2
		myMainTableCell = new HTMLTableCell();
		myMainTableRow.AddInnerHTMLElement(myMainTableCell);
		myMainTableCell.SetWidth("100%");
		myMainTableCell.SetVAlign("top");

		//	add the error display view.
		myMainTableCell.AddInnerHTMLElement(m_asOwner.GetView(
				ErrorView.STR_MVC_CLASS_NAME).Display());

		myMainTableCell.AddInnerHTMLElement(GetContentHeaderTable(
				((EditorDP) m_asOwner.GetCurrentPage()).GetPageTitle()));
		
		HTMLElement myHTML = GetHTMLBelowSubHeader();
  
  		if (null != myHTML)
  		{
  			// JF- Banner with help link and instructions
  			myMainTableCell.AddInnerHTMLElement(myHTML);
  		}


		// Editor Content table
		//HTMLTable myTable = new HTMLTable();
		myMainTableCell.AddInnerHTMLElement(_Views);
		/*myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("0");
		myTable.SetCellSpacing(this.m_sContentTableCellSpacing);

		// 1st Row
		HTMLTableRow myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);

		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);

		// Editor content
		myCell.AddInnerHTMLElement(_Views);*/

		return myMainTable;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = null;
		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			myScripts = super.DisplayJavaScriptFromChild();

			myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				PortletPreferencesView.STR_MVC_CLASS_NAME).DisplayJavascript());
				
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);	
			script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) + "opennewwindow.js");
			myScripts.AddInnerHTMLElement(script);
		}
		
		return myScripts;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetContentHeaderTable()
	 *
	 * @param _sTitle
	 *
	 * @return HTMLElement
	 */
	private HTMLElement GetContentHeaderTable(String _sTitle)
	{
		HTMLElementCollection myResult = new HTMLElementCollection();
		PTConstruct myContentHeader;

		try
		{
			myResult.AddInnerHTMLString( "\n" );
			
			HTMLComment myComment = new HTMLComment( "Begin: Editor Page header with page title" );
			myResult.AddInnerHTMLElement( myComment );
			
			myResult.AddInnerHTMLString( "\n" );
			
			if (m_asOwner.GetIsAccessStyleStandard())
			{
				myContentHeader = UIConstructFactory.GetConstruct(PTBannerType.WIDE);
				myContentHeader.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE.TITLE_ELEMENT_NAME,
					_sTitle);
			}
			else
			{
				myContentHeader = UIConstructFactory.GetConstruct(PTBannerType.WIDE_508);
				myContentHeader.ReplaceNestedElementsWithHTMLString(PTBannerType.WIDE_508.TITLE_ELEMENT_NAME,
					_sTitle);
			}				
			myResult.AddInnerHTMLElement(myContentHeader.GetHTMLElement());

			myResult.AddInnerHTMLString( "\n" );
			myComment = new HTMLComment( "End: Editor Page header with page title");
			
			myResult.AddInnerHTMLElement( myComment );
			
			myResult.AddInnerHTMLString( "\n" );			
			
		}
		catch (Exception e)
		{
			
				log.Error(e, "EditorDP::GetContentHeaderTable The following error occured when trying to display the HTML: " +
					e.getMessage());
			
		}

		return myResult;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetSpacerTable()
	 *
	 * @return HTMLElement
	 */
	private HTMLElement GetSpacerTable()
	{
		HTMLElementCollection myResult = new HTMLElementCollection();

		PTConstruct myConstruct;
		HTMLImg myImage;
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			
			myResult.AddInnerHTMLString( "\n" );
			
			HTMLComment myComment = new HTMLComment( "Begin: Spacer table" );
			myResult.AddInnerHTMLElement( myComment );
			
			myResult.AddInnerHTMLString( "\n" );
			

			myTable = new HTMLTable();
			myResult.AddInnerHTMLElement(myTable);
			myTable.SetBorder("0");
			myTable.SetWidth("100%");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("0");

			// 1st Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt("");
			myImage.SetWidth("225");
			myImage.SetHeight("1");
			myImage.SetBorder("0");
			myCell.AddInnerHTMLElement(myImage);

			myResult.AddInnerHTMLString("\n" );
			
			
			myComment = new HTMLComment( "End: Spacer table");
			myResult.AddInnerHTMLElement( myComment );
			
			myResult.AddInnerHTMLString("\n" );			
			
		}
		catch (Exception e)
		{
			
				log.Error(e, "EditorDP::GetSpacerTable The following error occured when trying to display the HTML: " +
					e.getMessage());
			
		}

		return myResult;
	}
}


