package com.plumtree.portalpages.browsing.editors.editportletprefs;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.community.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class keeps an up-to-date state of all the settings.  It contains the
 * set and get methods for those settings.  It contains the start, save and
 * finish methods.  This class is used by the Section Misc2View (to get the
 * latest value of the settings to display) and by the  Control
 * Misc2RepostControl (to perform the repost actions).
 *
 * @author RobertZ, Bridget Frey
 */
public class EditPortletPrefsModel extends EditorModel implements IEditorModelRO,
	IPortletPreferencesModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.editportletprefs.EditPortletPrefsModel");

	
	public static final String STR_MVC_CLASS_NAME = "EditPortletPrefs";

	private IPTPage m_curPage;

	/** List of gadgets with preferences */
	private PTSortedArrayWrapper[] m_arrSortedPortlets;

	private int m_nCommunityID;

	private int m_nPageID;
	
	/** Profile ID */
	private int m_nProfileID;

	/**
	 * Modifies the object name on repost.
	 */
	public void ActionOnRepost()
	{
	}

	// ***CHANGE_HERE*** Put your set/get methods and other helper methods
	// BEGIN ***************** helper methods ***************** 

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		if(MyPortalModel.IsGuestSession(m_asOwner))
		{
			return false;
		}
		
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		IPTQueryResult gadgets = null;

		// need to pick up the mandatory gadgets, if this is a personal home page
		IPTQueryResult gadgetsMandatory = null;

		// Check which page to open.
		boolean bHavePageID = false;
		String[] data;
		if (_htFormData.ContainsKey(EditPortletPrefsAS.QS_PARAM_PAGEID))
		{
			data = (String[]) _htFormData.GetElement(EditPortletPrefsAS.QS_PARAM_PAGEID);
			if (null != data && 1 <= data.length)
			{
				if (null != data[0] && !"".equals(data[0]))
				{
					m_nPageID = XPConvert.ToInteger(data[0]);
					bHavePageID = true;
				}
			}
		}
		if (bHavePageID)
		{
			m_curPage = (IPTPage)ptSession.GetPages().Open(m_nPageID, false);

			if (_htFormData.ContainsKey(EditPortletPrefsAS.QS_PARAM_COMMUNITYID))
			{
				m_nCommunityID = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
							EditPortletPrefsAS.QS_PARAM_COMMUNITYID))[0]);
			}
			else
			{
				// TODO-MJD : need to put in a check for the home page that will work
				gadgetsMandatory = ptSession.GetMyPages().QueryMandatoryGadgets();
			}

			gadgets = m_curPage.QueryPortlets();
			
			if ( PT_INTRINSICS.PT_PROFILE_COMMUNITY == m_nCommunityID && _htFormData.ContainsKey(SetCommunityControl.PROFILEID) )
			{
				m_nProfileID = XPConvert.ToInteger(((String[]) _htFormData.GetElement(SetCommunityControl.PROFILEID))[0]);
			}
		}
		else
		{

			
				log.Error("No page ID specified");
			

			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null,
					m_asOwner.GetString(1561, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1562, "ptmsgs_portalbrowsingmsgs"));

			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		int nTotalPortlets = 0;

		if (gadgets != null)
		{
			nTotalPortlets += gadgets.RowCount();
		}

		if (gadgetsMandatory != null)
		{
			nTotalPortlets += gadgetsMandatory.RowCount();
		}

		XPArrayList xparrPortlets = new XPArrayList(nTotalPortlets);
		String strPortletName;

		XPHashtable hashPortlets = new XPHashtable();

		for (int j = 0; j < gadgets.RowCount(); j++)
		{ // go through each gadget in the page and check if they have preferences
			strPortletName = gadgets.ItemAsString(j, PT_PROPIDS.PT_PROPID_NAME);

			XPArrayList gadgetNameID = new XPArrayList(5);
			int nPortletID			 = gadgets.ItemAsInt(j,
					PT_PROPIDS.PT_PROPID_OBJECTID);

			gadgetNameID.Add(strPortletName);
			gadgetNameID.Add(new Integer(nPortletID));
			gadgetNameID.Add(new Integer(-1));

			// bitwise-compare the communityowner bit with the personalization type
			// we add 'true' if the gadget has community prefs, 'false' otherwise
			// JD- this value can be NULL if the portlet has no web service.
			Object oPersonalizationType = gadgets.ItemAsObject(j, PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION);
			int nPersonalizationType = 0;
			if (null != oPersonalizationType &&
				oPersonalizationType instanceof Integer)
			{
				nPersonalizationType = XPConvert.ToInteger(oPersonalizationType);
			}
				
//			if (0 < (nPersonalizationType & PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER))
//			{
//				gadgetNameID.Add(new Integer(1));
//			}
//			else
//			{
//				gadgetNameID.Add(new Integer(0));
//			}
			gadgetNameID.Add(new Integer(nPersonalizationType));
			
			int nGadgetType = gadgets.ItemAsInt(j, PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);
			gadgetNameID.Add(new Integer(nGadgetType));
			
			xparrPortlets.Add(gadgetNameID);

			// keep track of which gadgets have been added; when processing mandatory gadgets, we'll make sure we don't add any
			// duplicates.
			hashPortlets.PutElement(new Integer(nPortletID), new Integer(0));
		}

		// process the mandatory gadgets, if there are any.
		if (gadgetsMandatory != null)
		{
			for (int j = 0; j < gadgetsMandatory.RowCount(); j++)
			{ // go through each gadget in the page and check if they have preferences
				strPortletName = gadgetsMandatory.ItemAsString(j,
						PT_PROPIDS.PT_PROPID_NAME);

				XPArrayList gadgetNameID = new XPArrayList(5);
				int nPortletID			 = gadgetsMandatory.ItemAsInt(j,
						PT_PROPIDS.PT_PROPID_OBJECTID);

				gadgetNameID.Add(strPortletName);
				gadgetNameID.Add(new Integer(nPortletID));
				gadgetNameID.Add(new Integer(-1));

				// bitwise-compare the communityowner bit with the personalization type
				// we add 'true' if the gadget has community prefs, 'false' otherwise
				// JD- this value can be NULL if the portlet has no web service.
				Object oPersonalizationType = gadgetsMandatory.ItemAsObject(j, PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION);
				int nPersonalizationType = 0;
				if (null != oPersonalizationType &&
					oPersonalizationType instanceof Integer)
				{
					nPersonalizationType = XPConvert.ToInteger(oPersonalizationType);
				}

//				if (0 < (nPersonalizationType &
//						PT_GADGETPERSONALIZATION_ROLES.PT_GADGETPERSONALIZATION_ENDUSER))
//				{
//					gadgetNameID.Add(new Integer(1));
//				}
//				else
//				{
//					gadgetNameID.Add(new Integer(0));
//				}
				gadgetNameID.Add(new Integer(nPersonalizationType));
				
				int nGadgetType = gadgetsMandatory.ItemAsInt(j, PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);
				gadgetNameID.Add(new Integer(nGadgetType));

				// make sure we didn't already add the gadget above.
				if (!hashPortlets.ContainsKey(new Integer(nPortletID)))
				{
					xparrPortlets.Add(gadgetNameID);
				}
			}
		}

		// slight hack below -- we have to put propids into the sorted array, but we're not using flags & personalization
		// exactly as they are in the DB.  We basically shove gadget title bar state into the sorted array and call it
		// FLAGS, even though it's a slight variation of flags.
		int[] arrColIDs = new int[5];
		arrColIDs[0]     = PT_PROPIDS.PT_PROPID_NAME;
		arrColIDs[1]     = PT_PROPIDS.PT_PROPID_OBJECTID;
		arrColIDs[2]     = PT_PROPIDS.PT_PROPID_GADGET_FLAGS; // we're setting this to the gadget title bar state
		arrColIDs[3]     = PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION; // we're setting this to true if there are comm prefs
		arrColIDs[4]     = PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE;

		int[][] arrSort  = new int[1][2];
		arrSort[0][0]    = PT_PROPIDS.PT_PROPID_NAME;
		arrSort[0][1]    = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		int iNumPortlets  = xparrPortlets.GetSize();
		Object[][] arrPortletsForOnePage = new Object[5][iNumPortlets];

		for (int k = 0; k < iNumPortlets; k++)
		{
			arrPortletsForOnePage[0][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(0);
			arrPortletsForOnePage[1][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(1);
			arrPortletsForOnePage[2][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(2);
			arrPortletsForOnePage[3][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(3);
			arrPortletsForOnePage[4][k]     = ((XPArrayList) xparrPortlets.GetElement(k)).GetElement(4);
		}

		m_arrSortedPortlets		  = new PTSortedArrayWrapper[1];
		m_arrSortedPortlets[0]     = new PTSortedArrayWrapper();
		m_arrSortedPortlets[0].Initialize(arrColIDs, arrPortletsForOnePage,
			arrSort, true);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EditPortletPrefsModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean DisplayTitleBarColumn()
	{
		return false;
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish()
	{
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCommunityID()
	{
		return m_nCommunityID;
	}

	/**
	 * 
	 *
	 * @param iPageID 
	 *
	 * @return 
	 */
	public PTSortedArrayWrapper GetPortletPreferencesList(int iPageID)
	{
		if (null == m_arrSortedPortlets)
		{
			return null;
		}

		return m_arrSortedPortlets[iPageID];
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetPageCount()
	{
		return 1;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.IPortletPreferencesModelRO#GetPageID(int)
	 */
	public int GetPageID(int nPageIndex)
	{
		return m_nPageID;
	}

	/**
	 * 
	 *
	 * @param nPageIndex 
	 *
	 * @return 
	 */
	public String GetPageName(int nPageIndex)
	{
		return m_curPage.GetName();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.community.
	 * IPortletPreferencesModelRO#IsCommunityEditor()
	 */
	public boolean IsCommunityEditor()
	{
		return false;
	}

	/**
	 * Reverses the sort order of one of the pages of gadget prefs.
	 *
	 * @param _htFormData 
	 */
	public void ReversePortletPrefsSort(XPHashtable _htFormData)
	{
		String sDataKey		  = PortletPreferencesView.HTMLHIDDEN_SORTINGPAGEINDEX;
		String[] aDataValue   = (String[]) _htFormData.GetElement(sDataKey);
		int iCurrentPageIndex = -1;

		if ((null != aDataValue) && (0 != aDataValue.length))
		{
			try
			{
				iCurrentPageIndex = XPConvert.ToInteger(aDataValue[0]);
			}
			catch (Exception e)
			{
				
					log.Error("CommunityEditorModel::ReversePortletPrefsSort An exception occured" +
						" when trying to resort gadget preferences for page with ID: " +
						aDataValue[0]);
				
			}
		}

		if (iCurrentPageIndex < 0)
		{
			return;
		}

		int[][] arrSort = m_arrSortedPortlets[iCurrentPageIndex].GetSort();

		// JF- Get the current sort.
		int nCurrentDirection = arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION];

		// JF-
		if (PTSortedArrayWrapper.PTSAW_SORT_ASCENDING == nCurrentDirection)
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_DESCENDING;
		}
		else
		{
			arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION] = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
		}

		m_arrSortedPortlets[iCurrentPageIndex].Sort(arrSort);
	}

	/**
	 * Returns the Obj Manager Redirect object  (this is were we need to go at
	 * the end of the Editor).
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		// ***CHANGE_HERE*** Replace by the name of the AS you want to 
		// redirect to on finish.
		
		// Did this portlet editor come from a community page or a mypage?
		Redirect redirect = new Redirect();
		IPTURL pturl = null; 
		if (m_nCommunityID > 0)
		{
			if (m_nProfileID > 0) {
				// DCA - handle profile community
			}
			pturl = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(m_asOwner, m_nCommunityID, "");
			redirect.SetLinkToExternalURL(pturl.GetFullURL());
		}
		else
		{
			pturl = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(m_asOwner, m_nPageID, "");
			redirect.SetLinkToExternalURL(pturl.GetFullURL());
		}

		if (null == redirect)
		{
			return super.GetRedirectAfterFinish();
		}
		else
		{
			return redirect;
		}
	}	

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		// ***CHANGE_HERE*** Switch between your DP and for each one call 
		//       the associated save method.
		return RepostControl.PAGE_STATUS_VALID;
	}
}

