package com.plumtree.portalpages.browsing.editors.folder;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author joseq
 *
 * Creates the html for the popup asking if folder ACL changes should 
 * propagate to its children.
 */
public class FolderEditorACLPropagateView extends EditorView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.folder.FolderEditorACLPropagateView");

	public static final String STR_MVC_CLASS_NAME = "FolderEditorACLProp";

	/** html button constants */
	public static final String HTMLBUTTON_YES 		= "in_bu_yes";
	public static final String HTMLBUTTON_NO   		= "in_bu_no";
	public static final String HTMLBUTTON_CANCEL 	= "in_bu_cancel";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderEditorACLPropagateView();
	}

	/**
	 * Helper methods that returns the property type name
	 * corresponding to the property type ID passed in argument.
	 *
	 * @param _nPropType
	 * @return String
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display FolderEditorACLPropagateView");
			result.AddInnerHTMLElement(myComment);

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// Header Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);

			mySpan.AddInnerHTMLString(
				m_asOwner.GetString(1692, "ptmsgs_portalbrowsingmsgs"));

			// instructions ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

			mySpan.AddInnerHTMLString(
				m_asOwner.GetString(1811, "ptmsgs_portalbrowsingmsgs"));

			// spacer ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
						
			// buttons ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.CENTER);
			
			/* yes */
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_YES, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(1694, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick("window.opener."+AFormDP.JAVASCRIPT_SUBMIT_FORM+
				"("+FolderEditorRepostControl.POSTTOSELF_ACTION_PROPAGATE+
				");window.close();");
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			
			/* no */
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_YES, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(1695, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick("window.opener."+AFormDP.JAVASCRIPT_SUBMIT_FORM+
				"("+FolderEditorRepostControl.POSTTOSELF_ACTION_NO_PROPAGATE+
				");window.close();");
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			/* cancel */
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_YES, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetValue(m_asOwner.GetString(1696, "ptmsgs_portalbrowsingmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
			myInput.SetOnClick("window.opener."+AFormDP.JAVASCRIPT_SUBMIT_FORM+
				"("+FolderEditorRepostControl.POSTTOSELF_ACTION_CANCEL_PROPAGATE+
				");window.close();");
			myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			myComment = new HTMLComment( "End: Display FolderEditorACLPropagateView");
			result.AddInnerHTMLElement(myComment);
			
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					he.getMessage());
			

			throw new XPException(
				m_asOwner.GetString(1697,"ptmsgs_portalbrowsingmsgs"), he);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}
