package com.plumtree.portalpages.browsing.editors.folder;


// Framework Imports
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Property Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 */
public class FolderEditorAS extends ObjEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.folder.FolderEditorAS");

	
	public static final String STR_MVC_CLASS_NAME = "FolderEditor";

	public static final String strSelectFilters		   = "SelectFilters";

	
	public static final String strSelectRRCommunity	   = "SelectRRCommunity";

	
	public static final String strSelectRRFolder		   = "SelectRRFolder";

	
	public static final String strSelectRRPortlet		   = "SelectRRGadget";

	
	public static final String strSelectRRExpert		   = "SelectRRExpert";

	
	public static final String strSelectRRContentManager = "SelectRRContentManager";

	
	public static final String strStoragePlugInKey = "FolderSamplePlugIn";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderEditorAS();
	}

	/**
	  * Returns the Editor title.
	    *
	  * @return String
	 */
	public String GetEditorTitle()
	{
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
					m_strModelName)).GetEditorType())
		{
			return (GetString(384, "ptmsgs_portalbrowsingmsgs"));
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(1706, "ptmsgs_portalbrowsingmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (FolderEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = FolderEditorModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(FolderEditorModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		FolderEditorMainDP folderMainDP = new FolderEditorMainDP();
		folderMainDP.AddToValidationFunction("CheckName");

		RegisterPage(folderMainDP);
		RegisterPage(new FolderEditorAdvancedSettingsDP());
		RegisterPage(new FolderEditorRelatedResourcesDP());
		RegisterPage(new FolderEditorACLPropagateDP());

		// Register Views
		RegisterView(FolderEditorMainView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderEditorSortingView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderEditorDataSourceView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderEditorFilterSettingsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderEditorACLPropagateView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(FolderEditorRepostControl.STR_MVC_CLASS_NAME, myModel);

		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, strSelectFilters);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, strSelectFilters,
			GetModel(strSelectFilters));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectFilters,
			GetModel(strSelectFilters));

		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strSelectRRCommunity);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strSelectRRCommunity, GetModel(strSelectRRCommunity));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strSelectRRCommunity, GetModel(strSelectRRCommunity));

		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strSelectRRFolder);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strSelectRRFolder, GetModel(strSelectRRFolder));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRFolder,
			GetModel(strSelectRRFolder));

		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strSelectRRPortlet);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strSelectRRPortlet, GetModel(strSelectRRPortlet));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRPortlet,
			GetModel(strSelectRRPortlet));

		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strSelectRRExpert);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strSelectRRExpert, GetModel(strSelectRRExpert));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, strSelectRRExpert,
			GetModel(strSelectRRExpert));

		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			strSelectRRContentManager);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			strSelectRRContentManager, GetModel(strSelectRRContentManager));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strSelectRRContentManager, GetModel(strSelectRRContentManager));

		// Set default page
		SetCurrentPage(FolderEditorMainDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(386,
					"ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			FolderEditorMainDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			FolderEditorRelatedResourcesDP.STR_MVC_CLASS_NAME);
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			FolderEditorAdvancedSettingsDP.STR_MVC_CLASS_NAME);
		// END Sub menu "General Settings"

		// BEGIN Sub menu "Standard Settings"
		
		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1240, "ptmsgs_portalbrowsingmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);

		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);

		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		
		// END Sub menu "Standard Settings"

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{

				int iTitleId = 93;
				int iTipId = 94;
				int iSecondaryTipId = 95;
												
				tm.SetTipTitle( this.GetString( iTitleId, "ptmsgs_tips") );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, "ptmsgs_tips") );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, "ptmsgs_tips");
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}						
				
				
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
		 
		this.SetHelpTopic("PT_Folder_MainSettings");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage( page );
                   
		String sPageName = page.GetName();

		if( FolderEditorMainDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Folder_MainSettings" );                           
		}
		else if( FolderEditorAdvancedSettingsDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Folder_AdvancedSettings" );                           
		}
		else if( FolderEditorRelatedResourcesDP.STR_MVC_CLASS_NAME.equals( sPageName ))
		{
			this.SetHelpTopic( "PT_Folder_RelatedResources" );                           
		}
	}
}

