package com.plumtree.portalpages.browsing.editors.folder;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * This Section represents a section of the Filters page
 * of the Directory Folder Editor.
 * This Section is printed out by FolderEditorFiltersDP.
 */
public class FolderEditorFilterSettingsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.folder.FolderEditorFilterSettingsView");

	
	public static final String STR_MVC_CLASS_NAME = "FolderEditorFilterSettings";

	// HTML Object names.
	public static final String HTMLRADIO_FILTERSETTINGS  = "in_ra_FilterSettings";

	
	public static final String HTMLSELECT_FILTEROPERATOR = "in_se_FilterOperator";

	
	public static final String HTMLSELECT_DEFAULTFOLDER = "in_se_DefaultSortFolder";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderEditorFilterSettingsView();
	}

	/**
	 * Helper methods that returns the property type name
	 * corresponding to the property type ID passed in argument.
	 *
	 * @param _nPropType
	 * @return String
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLInput myInput;
		HTMLSpan mySpan;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display FolderEditorFilterSettingsView");
			result.AddInnerHTMLElement(myComment);

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						397, "ptmsgs_portalbrowsingmsgs")));

			result.AddInnerHTMLElement(DirConstants.CreateSpacerImage(2,1));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);

			// BEGIN Filter Instructions Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetColSpan(CommonHTMLStrings.TWO);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(398,
					"ptmsgs_portalbrowsingmsgs"));

			// END Filter Instructions Row
			
			myTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(1,2));
			
			// BEGIN Filter Settings + 1st radio option: All Links ROW
			int nAllLinks     = XPConvert.ToInteger(((IFolderEditorModelRO) m_model).GetFolderSetting(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_ALL_CARDS));
			boolean bAllLinks = (1 == nAllLinks);

			int nNoLinks     = XPConvert.ToInteger(((IFolderEditorModelRO) m_model).GetFolderSetting(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_NO_CARDS));
			boolean bNoLinks = (1 == nNoLinks);

			myRow			 = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			myCell.SetWidth("25%");
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(399,
					"ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_FILTERSETTINGS, "");
			myInput.SetChecked(bAllLinks);
			myInput.SetValue("" +
				PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_ALL_CARDS);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(400,
					"ptmsgs_portalbrowsingmsgs"));

			// END Filter Settings + 1st radio option: All Links ROW
			// BEGIN 2nd radio option: No Links ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_FILTERSETTINGS, "");
			myInput.SetValue("" +
				PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_NO_CARDS);
			myInput.SetChecked(bNoLinks);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(401,
					"ptmsgs_portalbrowsingmsgs"));

			// END 2nd radio option: No Links ROW
			// BEGIN 3rd radio option ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_FILTERSETTINGS, "");
			myInput.SetChecked(!bNoLinks && !bAllLinks);
			myInput.SetValue("" + -1); 
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(402,
					"ptmsgs_portalbrowsingmsgs"));

			mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE + CommonHTMLStrings.SPACE);

			// ***<input radio>*** ends here
			// Dropdown for 3rd radio option: Classification Filter Operator
			int nFilterOperator = ((IFolderEditorModelRO) m_model).GetClassificationFiltersOperator();

			mySelect = new HTMLSelect(HTMLSELECT_FILTEROPERATOR, "select1");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// option 1 - All Filters
			myOption     = new HTMLOption(XPConvert.ToString(PT_BOOLOPS.PT_BOOLOP_AND));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(404,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (PT_BOOLOPS.PT_BOOLOP_AND == nFilterOperator)
			{
				myOption.SetSelected(true);
			}

			// option 2 - At least one Filter
			myOption     = new HTMLOption(XPConvert.ToString(PT_BOOLOPS.PT_BOOLOP_OR));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(403,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (PT_BOOLOPS.PT_BOOLOP_OR == nFilterOperator)
			{
				myOption.SetSelected(true);
			}

			// END 3rd radio option ROW
			// BEGIN Default Folder Label + Instructions ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(407,
					"ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(408,
					"ptmsgs_portalbrowsingmsgs"));

			// END Default Folder Label + Instructions ROW
			// BEGIN Default Folder Dropdown Row	
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nDefaultFolderID;

			boolean bDefaultHere = (1 == XPConvert.ToInteger(((IFolderEditorModelRO) m_model).GetFolderSetting(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PUT_CARDS_HERE)));

			if (bDefaultHere)
			{
				nDefaultFolderID = PT_INTRINSICS.PT_NULL_OBJECTID; 
			}
			else
			{
				nDefaultFolderID = XPConvert.ToInteger(((IFolderEditorModelRO) m_model).GetFolderSetting(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_DEFAULT_SUBFOLDERID));
			}

			mySelect = new HTMLSelect(HTMLSELECT_DEFAULTFOLDER, "select3");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// option 1 - No Folder
			myOption     = new HTMLOption("" + PT_INTRINSICS.PT_NULL_OBJECTID +
					""); // Define constant
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(405,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if ((PT_INTRINSICS.PT_NULL_OBJECTID == nDefaultFolderID) &&
					!bDefaultHere)
			{
				myOption.SetSelected(true);
			}

			// option 2 - This Folder
			myOption     = new HTMLOption(XPConvert.ToString(-1));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(406,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (bDefaultHere)
			{
				myOption.SetSelected(true);
			}

			if (EditorStartControl.EDITOR_START_FLAG_EDIT == ((EditorModel) m_model).GetEditorType())
			{
				// options 3 -  x 
				// Iterate through all subfolders
				IASQueryResult asqrSubFolders = ((IFolderEditorModelRO) m_model).GetSubFolders();

				if (null != asqrSubFolders)
				{
					int nSubFolderCount = asqrSubFolders.GetCount();

					for (int i = 0; i < nSubFolderCount; i++)
					{
						int nSubFolderID	    = XPConvert.ToInteger(asqrSubFolders.GetFields(i,
								PT_PROPIDS.PT_PROPID_OBJECTID));
						String strSubFolderName = (String) asqrSubFolders.GetFields(i,
								PT_PROPIDS.PT_PROPID_NAME);

						myOption			    = new HTMLOption("" +
								nSubFolderID + "");
						mySpan				    = new HTMLSpan();
						myOption.AddInnerHTMLElement(mySpan);
						mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
								strSubFolderName));
						mySelect.AddInnerHTMLElement(myOption);

						/* fix bug 23891: this was check that nDefaultFolderID
						 * was not equal to PT_INTRINSICS.PT_NULL_OBJECTID, 
						 * which would be true for all folders???
						 */
						if ((nSubFolderID == nDefaultFolderID) &&
								!bDefaultHere)
						{
							myOption.SetSelected(true);
						}
					}
				}
			}

			// END Default Folder Dropdown Row	
			myComment = new HTMLComment( "End: Display FolderEditorFilterSettingsView");
			result.AddInnerHTMLElement(myComment);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					he.getMessage());
			

			throw new XPException(m_asOwner.GetString(409,
					"ptmsgs_portalbrowsingmsgs"), he);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

