package com.plumtree.portalpages.browsing.editors.folder;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.filter.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * 
 *
 * @author StephenC This class contains the IPTProperty server object,  as well
 *         as the set and get methods on that object. This class is called by
 *         the PropRepostControl to perform  the changes on the Object and by
 *         the Views PropAdvView and  PropMainView to display the latest
 *         values on the page.
 */
public class FolderEditorModel extends ObjEditorModel
	implements IFolderEditorModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.folder.FolderEditorModel");

	
	public static final String STR_MVC_CLASS_NAME = "Folder Editor";

	
	private IPTSession m_ptSession = null;
	
	private int m_nDefaultDataSource = -1;

	/* acl propagation variables */
	private int m_flagACL = -1;
	public static final int YES_PROPAGATE_ACL = 2;
	public static final int NO_PROPAGATE_ACL = 1;
	public static final int CANCEL_PROPAGATE_ACL = 0;
	public static final int UNKNOWN_PROPAGATE_ACL = -1;
	
	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access
	 *         this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		boolean nAccess = super.CheckEditorAccessAndStart(_htFormData);

		StartSelectPTObject();

		m_nDefaultDataSource = LoadDefaultDataSource();

		return nAccess;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderEditorModel();
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#DoNotShowObject(int)
	 */
	public boolean DoNotShowObject(int nIndex)
	{
		return false;
	}

	/**
	 * 
	 */
	public void DoTaskAfterStore()
	{
		// Re-open the folder (required if this folder has just been created)
		IPTFolder ptFolder = m_ptSession.GetCatalog().OpenFolder(m_nObjectID, false);
		
		// Get the Object Properties
		IPTObjectProperties ptObjectProperties = ptFolder.GetObjectProperties();

		// Save Default DataSource
		Object[][] arObjectProperties = new Object[2][1];
		arObjectProperties[0][0] = new Integer(PT_INTRINSICS.PT_PROPERTY_DEFAULTDATASOURCE);

		if (0 == m_nDefaultDataSource)
		{
			arObjectProperties[1][0] = null;
		}
		else
		{
			arObjectProperties[1][0] = new Integer(m_nDefaultDataSource);
		}

		ptObjectProperties.SetPropertyRefData(arObjectProperties);

		///////////////////
		// Save Filters
		///////////////////
		IPTServerContext ptSC = (IPTServerContext) ptFolder.GetInterfaces(
				"IPTServerContext");

		// Remove existing filters
		IPTQueryResult ptQRFilters = ptFolder.QueryClassificationFilters();

		int nNumOldFilters = ptQRFilters.RowCount();

		if (0 < nNumOldFilters)
		{
			ptSC.LockObject();

			for (int i = 0; i < nNumOldFilters; i++)
			{
				int nFilterID = ptQRFilters.ItemAsInt(i,
						PT_PROPIDS.PT_PROPID_FOLDER_CLASSIFICATIONFILTERID);
				ptFolder.RemoveClassificationFilter(nFilterID);
			}

			ptSC.UnlockObject();
		}

		// Add new filters
		PTGrowableSortedArrayWrapper arFilters = ((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectFilters)).GetItems();

		int nNumNewFilters = arFilters.GetCount();

		if (0 < nNumNewFilters)
		{
			ptSC.LockObject();

			for (int i = 0; i < nNumNewFilters; i++)
			{
				int nFilterID = XPConvert.ToInteger(arFilters.GetItem(i,
						SelectPTObjectModel.EXPLIST_COL_OBJECTID));
				ptFolder.AddClassificationFilter(nFilterID);
			}

			ptSC.UnlockObject();
		}

		///////////////////////////
		// Save Related Resources
		///////////////////////////
		PTGrowableSortedArrayWrapper arRRCommunities     = ((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRCommunity)).GetItems();
		int nNumRRCommunities							 = arRRCommunities.GetCount();
		PTGrowableSortedArrayWrapper arRRFolders		 = ((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRFolder)).GetItems();
		int nNumRRFolders								 = arRRFolders.GetCount();
		PTGrowableSortedArrayWrapper arRRPortlets		 = ((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRPortlet)).GetItems();
		int nNumRRPortlets								 = arRRPortlets.GetCount();
		PTGrowableSortedArrayWrapper arRRExperts		 = ((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRExpert)).GetItems();
		int nNumRRExperts								 = arRRExperts.GetCount();
		PTGrowableSortedArrayWrapper arRRContentManagers = ((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRContentManager)).GetItems();
		int nNumRRContentManagers						 = arRRContentManagers.GetCount();

		int nTotalRelatedResources	    = nNumRRCommunities + nNumRRFolders +
			nNumRRPortlets + nNumRRExperts + nNumRRContentManagers;
		int nRRCounter				    = 0;
		Object[][] arRRObjectProperties = new Object[2][5 +
			nTotalRelatedResources]; // scc: add 5 extra rows to clear the existing data

		// Clear the existing values
		arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES);
		arRRObjectProperties[1][nRRCounter]     = null;
		nRRCounter++;
		arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS);
		arRRObjectProperties[1][nRRCounter]     = null;
		nRRCounter++;
		arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS);
		arRRObjectProperties[1][nRRCounter]     = null;
		nRRCounter++;
		arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS);
		arRRObjectProperties[1][nRRCounter]     = null;
		nRRCounter++;
		arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS);
		arRRObjectProperties[1][nRRCounter]     = null;
		nRRCounter++;

		///////////////////////////
		// Save Related Communities
		///////////////////////////
		for (int i = 0; i < nNumRRCommunities; i++)
		{
			int nRRID = XPConvert.ToInteger(arRRCommunities.GetItem(i,
					SelectPTObjectModel.EXPLIST_COL_OBJECTID));

			arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES);
			arRRObjectProperties[1][nRRCounter]     = new Integer(nRRID);
			nRRCounter++;
		}

		///////////////////////////
		// Save Related Folders
		///////////////////////////
		for (int i = 0; i < nNumRRFolders; i++)
		{
			int nRRID = XPConvert.ToInteger(arRRFolders.GetItem(i,
					SelectPTObjectModel.EXPLIST_COL_OBJECTID));

			arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS);
			arRRObjectProperties[1][nRRCounter]     = new Integer(nRRID);
			nRRCounter++;
		}

		///////////////////////////
		// Save Related Portlets
		///////////////////////////
		for (int i = 0; i < nNumRRPortlets; i++)
		{
			int nRRID = XPConvert.ToInteger(arRRPortlets.GetItem(i,
					SelectPTObjectModel.EXPLIST_COL_OBJECTID));

			arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS);
			arRRObjectProperties[1][nRRCounter]     = new Integer(nRRID);
			nRRCounter++;
		}

		///////////////////////////
		// Save Related Experts
		///////////////////////////
		for (int i = 0; i < nNumRRExperts; i++)
		{
			int nRRID = XPConvert.ToInteger(arRRExperts.GetItem(i,
					SelectPTObjectModel.EXPLIST_COL_OBJECTID));

			arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS);
			arRRObjectProperties[1][nRRCounter]     = new Integer(nRRID);
			nRRCounter++;
		}

		///////////////////////////
		// Save Related Content Managers
		///////////////////////////
		for (int i = 0; i < nNumRRContentManagers; i++)
		{
			int nRRID = XPConvert.ToInteger(arRRContentManagers.GetItem(i,
					SelectPTObjectModel.EXPLIST_COL_OBJECTID));

			arRRObjectProperties[0][nRRCounter]     = new Integer(PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS);
			arRRObjectProperties[1][nRRCounter]     = new Integer(nRRID);
			nRRCounter++;
		}

		// Set the Related Resources
		ptObjectProperties.SetPropertyRefData(arRRObjectProperties);


		ptFolder.SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_INDEXONSTORE,
			new Integer(1));
		
		
		///////////////////////////
		// Propagate ACL
		///////////////////////////
		if (YES_PROPAGATE_ACL == m_flagACL)
		{
			IPTCatalog ptCatalog = ((IPTFolder) m_ptObject).GetCatalog();
			PropagateACL(ptCatalog, ptFolder, ptSC.GetACL());
		}


		// Store Folder
		// SCC: This is important because it will update the ExistRR field on the Folder.
		ptSC.LockObject();
		
		try
		{
			ptSC.Store();
		} 
		catch(XPException e)
		{
			log.Error("FolderEditor DoTaskAfterStore Error");

			UIError myError = new UIError(
				UIErrorLevel.FRIENDLY,		
				UIErrorScope.CURRENT_USER,
				"Error occurred when storing Folder",
				e.GetMessage());
			
			UIErrorHandler.RaiseError(
				myError, 
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		if(PT_LOCKSTATES.PT_LOCKED == ptSC.GetLockState())
		{
			ptSC.UnlockObject();
		}
	}

	/**
	 * This method will be called when you come back to the main Editor from a
	 * sub Editor.
	 */
	public void DoTaskOnComeBackFromSubEditor()
	{
		super.DoTaskOnComeBackFromSubEditor();
		
		((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectFilters)).DoTaskOnComeBackFromSubEditor();
	}

	// END ***************** helper methods ***************** 

	/**
	 * Initializes the property type member variable with  the one from
	 * IPTProperty in Edit mode and the default  value in create mode.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		((EditorAS) m_asOwner).GetLeftMenu().HideLink(false,
			ObjectSecurityDP.STR_MVC_CLASS_NAME);

		if (PT_INTRINSICS.PT_FOLDER_ROOTFOLDER == m_nObjectID)
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				FolderEditorRelatedResourcesDP.STR_MVC_CLASS_NAME);
		}

		if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}
	}

	// END ***************** save DP methods ***************** 
	/////////////////////////////////////////
	// Read methods from IFolderEditorModelRO
	/////////////////////////////////////////

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetBrowsingOrderBy()
	 */
	public int GetBrowsingOrderBy()
	{
		return ((IPTFolder) m_ptObject).GetDefaultSearchOrderBy();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetBrowsingOrderByProperties()
	 */
	public IASQueryResult GetBrowsingOrderByProperties()
	{
		IASQueryResult asqr = null;

		try
		{
			IPTQueryResult qr = m_ptSession.GetCatalog().GetOrderByProperties();
			asqr = new ASQueryResultWrapper(qr);
		}
		catch (XPException xpe)
		{
			log.Error(xpe, STR_MVC_CLASS_NAME +
				"::GetBrowsingOrderByProperties(): Unable to retrieve browsing order by properties: " +
				xpe.GetMessage());
		}

		return asqr;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetClassificationFiltersOperator()
	 */
	public int GetClassificationFiltersOperator()
	{
		int op = 0;

		try
		{
			op = ((IPTFolder) m_ptObject).GetClassificationFiltersOperator();
		}
		catch (XPException xpe)
		{
			log.Error(xpe, STR_MVC_CLASS_NAME +
				"::GetClassificationFiltersOperator(): Unable to retrieve classification operator: " +
				xpe.GetMessage());
		}

		return op;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetDataSourceName()
	 */
	public String GetDataSourceName(int nDataSourceID)
	{
		String strDataSourceName = "";

		try
		{
			PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(m_ptSession.GetDataSources());
			omqw.QuerySingleObject(nDataSourceID);
			strDataSourceName = (String)omqw.GetFields(0, PT_PROPIDS.PT_PROPID_NAME);
		}
		catch (XPException xpe)
		{
			log.Error(STR_MVC_CLASS_NAME +
				"::GetDataSourceName(): Unable to retrieve name for datasource" +
				nDataSourceID + ": " + xpe.GetMessage());
		}

		return strDataSourceName;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetDefaultDataSource()
	 */
	public int GetDefaultDataSource()
	{
		if (-1 == m_nDefaultDataSource)
		{
			m_nDefaultDataSource = LoadDefaultDataSource();
		}

		return m_nDefaultDataSource;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetBrowsingOrderBy()
	 */
	public int GetEditingOrderBy()
	{
		return ((IPTFolder) m_ptObject).GetDefaultOrderBy();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetFilteredDataSources()
	 */
	public IASQueryResult GetFilteredDataSources()
	{
		try
		{
			IPTQueryResult ptQR = m_ptSession.GetCatalog()
				.GetCardSubmitDataSources(PT_WEBSERVICE_CARDSUBMIT_TYPES.PT_WEBSERVICE_CARDSUBMIT_SIMPLE);

			return new ASQueryResultWrapper(ptQR);
		}
		catch (XPException xpe)
		{
			log.Error(xpe, STR_MVC_CLASS_NAME +
				"::GetFilteredDataSources Could not retrieve datasources: " +
				xpe.getMessage());
		}

		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetFolderSetting()
	 */
	public Object GetFolderSetting(int nValueName)
	{
		Object oValue = null;

		try
		{
			oValue = new Integer(((IPTFolder) m_ptObject).GetSettings(nValueName));
		}
		catch (XPException xpe)
		{
			log.Error(STR_MVC_CLASS_NAME +
				"::GetFolderSetting(): Unable to retrieve folder setting " +
				nValueName + ": " + xpe.GetMessage());
		}

		return oValue;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetParentDefaultDataSourceNameRecursive()
	 */
	public String GetParentDefaultDataSourceNameRecursive()
	{
		String strDataSourceName = "";

		try
		{
			if (true == IsRootFolder())
			{
				int nDataSourceID = GetDefaultDataSource();

				if (0 == nDataSourceID)
				{
					return m_asOwner.GetString(450, "ptmsgs_portalbrowsingmsgs");
				}

				strDataSourceName = GetDataSourceName(GetDefaultDataSource());
			}
			else
			{
				IPTFolder ptParentFolder = m_ptSession.GetCatalog().OpenFolder(((IPTFolder) m_ptObject).GetParentFolderID(), false);

				int nDataSourceID = ptParentFolder.GetDefaultDataSource();

				if (0 == nDataSourceID)
				{
					return m_asOwner.GetString(450, "ptmsgs_portalbrowsingmsgs");
				}

				strDataSourceName = GetDataSourceName(nDataSourceID);
			}
		}
		catch (XPException xpe)
		{
			log.Error(xpe, STR_MVC_CLASS_NAME +
				"::GetParentDefaultDataSourceNameRecursive(): Unable to retrieve default datasource: " +
				xpe.GetMessage());
		}

		return strDataSourceName;
	}

	/**
	 * Get the SpaceID of the parent Activity Space
	 *
	 * @return int m_asOwner.GetSpaceID();
	 */
	public String GetSpaceID()
	{
		return m_asOwner.GetSpaceID();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetSubFolders()
	 */
	public IASQueryResult GetSubFolders()
	{
		IASQueryResult asQueryResult = null;

		try
		{
			int nPropIDMask   = PT_PROPIDS.PT_PROPID_OBJECTID |
				PT_PROPIDS.PT_PROPID_NAME;
			IPTQueryResult qr = ((IPTFolder) m_ptObject).QuerySubfolders(nPropIDMask,
					0, null, 0, -1, null);
			asQueryResult				  = new ASQueryResultWrapper(qr);
		}
		catch (XPException xpe)
		{
			log.Error(xpe, STR_MVC_CLASS_NAME +
				"::GetSubFolders(): Unable to retrieve subfolders: " +
				xpe.GetMessage());
		}

		return asQueryResult;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		m_ptSession = (IPTSession) parent.GetUserSession();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#IsRootFolder()
	 */
	public boolean IsRootFolder()
	{
		return (PT_INTRINSICS.PT_FOLDER_ROOTFOLDER == m_nObjectID);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetPrimaryName()
	 */
	public String GetPrimaryName()
	{
		return m_ptObject.GetName();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.editors.folder.IFolderEditorModelRO#GetPrimaryDesc()
	 */
	public String GetPrimaryDesc()
	{
		return m_ptObject.GetDescription();
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(FolderEditorMainDP.STR_MVC_CLASS_NAME))
		{
			SaveMainPage(_htFormData);
		}
		else if (_sPageName.equals(
					FolderEditorAdvancedSettingsDP.STR_MVC_CLASS_NAME))
		{
			SaveDataSourcePage(_htFormData);

			((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectFilters)).SaveSection(_htFormData);
		}
		else if (_sPageName.equals(
					FolderEditorRelatedResourcesDP.STR_MVC_CLASS_NAME))
		{
			((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRCommunity)).SaveSection(_htFormData);

			((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRFolder)).SaveSection(_htFormData);

			((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRPortlet)).SaveSection(_htFormData);

			((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRExpert)).SaveSection(_htFormData);

			((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRContentManager)).SaveSection(_htFormData);
		}
		
		return nPageStatus;
	}

	/**
	 * Helper method to start the Select PTObject List.
	 */
	public void StartSelectPTObject()
	{
		//
		// FILTERS
		//
		
		SelectPTObjectModel mySelectFiltersModel = (SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectFilters);

		mySelectFiltersModel.InitializeSelectPTObject(
			m_asOwner.GetString(419, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(420, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_FILTER,
			m_asOwner.GetString(421, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_FILTER_ID }, 
			1);

		mySelectFiltersModel.SetTreeTitle(m_asOwner.GetString(421, "ptmsgs_portalbrowsingmsgs"));
		mySelectFiltersModel.SetTreeSubTitle(m_asOwner.GetString(419, "ptmsgs_portalbrowsingmsgs"));
		mySelectFiltersModel.SetDefaultRowIcon(PTImageType.ICON_FILTER); 

		mySelectFiltersModel.SetEmptyListMessages(
			m_asOwner.GetString(422, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(423, "ptmsgs_portalbrowsingmsgs"));

		Object[][] arrCreateNewInfo = new Object[1][SelectPTObjectModel.CREATE_NEW_COL_MAX];
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_CLASSID]     = new Integer(PT_CLASSIDS.PT_FILTER_ID);
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ASNAME]	    = FilterEditorAS.STR_MVC_CLASS_NAME;
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_LABEL]     = m_asOwner.GetString(424, "ptmsgs_portalbrowsingmsgs");
		arrCreateNewInfo[0][SelectPTObjectModel.CREATE_NEW_COL_ICON]	  = PTImageType.ICON_FILTER; 

		mySelectFiltersModel.SetEnableCreateNew(arrCreateNewInfo);

		//
		// RELATED COMMUNITIES
		//

		SelectPTObjectModel mySelectRRCommunitiesModel = (SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRCommunity);

		mySelectRRCommunitiesModel.InitializeSelectPTObject(
			m_asOwner.GetString(425, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(426, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_COMMUNITY, 
			m_asOwner.GetString(427, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_COMMUNITY_ID }, 
			2);

		mySelectRRCommunitiesModel.SetTreeTitle(m_asOwner.GetString(427, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRCommunitiesModel.SetTreeSubTitle(m_asOwner.GetString(425, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRCommunitiesModel.SetDefaultRowIcon(PTImageType.ICON_COMMUNITY);
		mySelectRRCommunitiesModel.SetEmptyListMessages(
			m_asOwner.GetString(428, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(429, "ptmsgs_portalbrowsingmsgs"));

		// We want to display all communities.
		mySelectRRCommunitiesModel.SetCommunityMode(AObjectTreeModel.ALLCOMMUNITIES);

		//
		// RELATED FOLDERS
		//

		SelectPTObjectModel mySelectRRFoldersModel = (SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRFolder);

		mySelectRRFoldersModel.InitializeSelectPTObject(
			m_asOwner.GetString(430, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(431, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_FOLDER,
			m_asOwner.GetString(432, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_CATALOGFOLDER_ID }, 
			3);

		mySelectRRFoldersModel.SetTreeTitle(m_asOwner.GetString(432, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRFoldersModel.SetTreeSubTitle(m_asOwner.GetString(430, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRFoldersModel.SetDefaultRowIcon(PTImageType.ICON_FOLDER);
		mySelectRRFoldersModel.SetTreeLeafType(TreeConstants.N_COMPOSITESELECT);
		mySelectRRFoldersModel.SetEmptyListMessages(
			m_asOwner.GetString(433, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(434, "ptmsgs_portalbrowsingmsgs"));

		//
		// RELATED PORTLETS
		//

		SelectPTObjectModel mySelectRRPortletsModel = (SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRPortlet);

		mySelectRRPortletsModel.InitializeSelectPTObject(
			m_asOwner.GetString(435, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(436, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_PORTLET,
			m_asOwner.GetString(437, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_GADGET_ID }, 
			4);

		mySelectRRPortletsModel.SetTreeTitle(m_asOwner.GetString(437, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRPortletsModel.SetTreeSubTitle(m_asOwner.GetString(435, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRPortletsModel.SetDefaultRowIcon(PTImageType.ICON_PORTLET);
		mySelectRRPortletsModel.SetEmptyListMessages(
			m_asOwner.GetString(438, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(439, "ptmsgs_portalbrowsingmsgs"));

		//
		// RELATED EXPERTS
		//

		SelectPTObjectModel mySelectRRExpertsModel = (SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRExpert);

		mySelectRRExpertsModel.InitializeSelectPTObject(
			m_asOwner.GetString(440, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(441, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_USER,
			m_asOwner.GetString(442, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_USER_ID }, 
			5);

		mySelectRRExpertsModel.SetTreeTitle(m_asOwner.GetString(442, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRExpertsModel.SetTreeSubTitle(m_asOwner.GetString(440, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRExpertsModel.SetDefaultRowIcon(PTImageType.ICON_USER);
		mySelectRRExpertsModel.SetEmptyListMessages(
			m_asOwner.GetString(443, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(444, "ptmsgs_portalbrowsingmsgs"));

		//
		// RELATED CONTENT MANAGERS
		//

		SelectPTObjectModel mySelectRRContentManagersModel = (SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRContentManager);
		mySelectRRContentManagersModel.InitializeSelectPTObject(
			m_asOwner.GetString(445, "ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(446, "ptmsgs_portalbrowsingmsgs"),
			PTImageType.ICON_USER,
			m_asOwner.GetString(447, "ptmsgs_portalbrowsingmsgs"),
			new int[] { PT_CLASSIDS.PT_USER_ID }, 
			6);

		mySelectRRContentManagersModel.SetTreeTitle(m_asOwner.GetString(447, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRContentManagersModel.SetTreeSubTitle(m_asOwner.GetString(445, "ptmsgs_portalbrowsingmsgs"));
		mySelectRRContentManagersModel.SetDefaultRowIcon(PTImageType.ICON_USER);
		mySelectRRContentManagersModel.SetEmptyListMessages(m_asOwner.GetString(448,
				"ptmsgs_portalbrowsingmsgs"),
			m_asOwner.GetString(449, "ptmsgs_portalbrowsingmsgs"));

		// Seed trees ONLY in Edit mode
		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			// Set Default Filters
			IPTQueryResult ptQRFilters = ((IPTFolder) m_ptObject).QueryClassificationFilters();

			if (null != ptQRFilters)
			{
				int nNumFilters = ptQRFilters.RowCount();

				Object[][] arFilters = new Object[nNumFilters][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nNumFilters; i++)
				{
					int nFilterID = ptQRFilters.ItemAsInt(i,
							PT_PROPIDS.PT_PROPID_FOLDER_CLASSIFICATIONFILTERID);

					IPTQueryResult ptQRFilterName = m_ptSession.GetFilters()
						.QuerySingleObject(nFilterID);

					// todo: error check?
					String strFilterName = ptQRFilterName.ItemAsString(0,
							PT_PROPIDS.PT_PROPID_NAME);

					arFilters[i][SelectPTObjectModel.EXPLIST_COL_CLASSID]	   = new Integer(PT_CLASSIDS.PT_FILTER_ID);
					arFilters[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]     = new Integer(nFilterID);
					arFilters[i][SelectPTObjectModel.EXPLIST_COL_STRING]	   = strFilterName;
				}

				mySelectFiltersModel.SetDefaultObjects(arFilters);
			}

			int[] arRelatedResourceIDs = 
			{
				PT_INTRINSICS.PT_RELATED_RESOURCE_COMMUNITIES,
				PT_INTRINSICS.PT_RELATED_RESOURCE_FOLDERS,
				PT_INTRINSICS.PT_RELATED_RESOURCE_GADGETS,
				PT_INTRINSICS.PT_RELATED_RESOURCE_EXPERTS,
				PT_INTRINSICS.PT_RELATED_RESOURCE_CONTENT_MANAGERS
			};

			Object[] oRR		  = (Object[]) ((IPTFolder) m_ptObject).GetRelatedResources(arRelatedResourceIDs);
			int nNumRRs;
			Object[][] arRRValues;

			// Related Communities
			IPTQueryResult ptQRrr = (IPTQueryResult) oRR[0];

			if (null != ptQRrr)
			{
				nNumRRs     = ptQRrr.RowCount();

				arRRValues = new Object[nNumRRs][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nNumRRs; i++)
				{
					int nRRID		 = ptQRrr.ItemAsInt(i,
							PT_PROPIDS.PT_PROPID_OBJECTID);
					String strRRName = (String) ptQRrr.ItemAsString(i,
							PT_PROPIDS.PT_PROPID_NAME);

					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_COMMUNITY_ID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(nRRID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_STRING] = strRRName;
				}

				((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRCommunity)).SetDefaultObjects(arRRValues);
			}

			// Related Folders
			ptQRrr = (IPTQueryResult) oRR[1];

			if (null != ptQRrr)
			{
				nNumRRs     = ptQRrr.RowCount();

				arRRValues = new Object[nNumRRs][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nNumRRs; i++)
				{
					int nRRID = ptQRrr.ItemAsInt(i,
							PT_PROPIDS.PT_PROPID_OBJECTID);

					IPTFolder ptFolder = (IPTFolder) m_ptSession.GetCatalog()
						.OpenFolder(nRRID, false);
					String strRRName   = ptFolder.GetPath();

					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_CATALOGFOLDER_ID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(nRRID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_STRING] = strRRName;
				}

				((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRFolder)).SetDefaultObjects(arRRValues);
			}

			// Related Portlets
			ptQRrr = (IPTQueryResult) oRR[2];

			if (null != ptQRrr)
			{
				nNumRRs     = ptQRrr.RowCount();

				arRRValues = new Object[nNumRRs][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nNumRRs; i++)
				{
					int nRRID		 = ptQRrr.ItemAsInt(i,
							PT_PROPIDS.PT_PROPID_OBJECTID);
					String strRRName = ptQRrr.ItemAsString(i,
							PT_PROPIDS.PT_PROPID_NAME);

					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_GADGET_ID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(nRRID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_STRING] = strRRName;
				}

				((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRPortlet)).SetDefaultObjects(arRRValues);
			}

			// Related Experts
			ptQRrr = (IPTQueryResult) oRR[3];

			if (null != ptQRrr)
			{
				nNumRRs     = ptQRrr.RowCount();

				arRRValues = new Object[nNumRRs][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nNumRRs; i++)
				{
					int nRRID		 = ptQRrr.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
					String strRRName = ptQRrr.ItemAsString(i,
							PT_PROPIDS.PT_PROPID_NAME);

					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_USER_ID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(nRRID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_STRING] = strRRName;
				}

				((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRExpert)).SetDefaultObjects(arRRValues);
			}

			// Related Content Managers
			ptQRrr = (IPTQueryResult) oRR[4];

			if (null != ptQRrr)
			{
				nNumRRs     = ptQRrr.RowCount();

				arRRValues = new Object[nNumRRs][SelectPTObjectModel.EXPLIST_COL_MAX];

				for (int i = 0; i < nNumRRs; i++)
				{
					int nRRID		 = ptQRrr.ItemAsInt(i,
							PT_PROPIDS.PT_PROPID_OBJECTID);
					String strRRName = ptQRrr.ItemAsString(i,
							PT_PROPIDS.PT_PROPID_NAME);

					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_USER_ID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID] = new Integer(nRRID);
					arRRValues[i][SelectPTObjectModel.EXPLIST_COL_STRING] = strRRName;
				}

				((SelectPTObjectModel) m_asOwner.GetModel(FolderEditorAS.strSelectRRContentManager)).SetDefaultObjects(arRRValues);
			}
		}
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 */
	protected void SaveDataSourcePage(XPHashtable _htFormData)
	{
		String[] data;

		// Default DataSource
		data = (String[]) _htFormData.GetElement(FolderEditorDataSourceView.HTMLRADIO_DEFAULTDATASOURCE);

		boolean bRoot = IsRootFolder();

		if (((null != data) && !(0 == data.length)) || (true == bRoot))
		{
			// Root does not have the first option because it has no parent folder
			int nRadioDefaultDataSource;

			if (bRoot)
			{
				nRadioDefaultDataSource = 1;
			}
			else
			{
				nRadioDefaultDataSource = XPConvert.ToInteger(data[0]);
			}

			if (0 == nRadioDefaultDataSource)
			{
				m_nDefaultDataSource = 0;
			}
			else
			{
				String[] dataDefaultDataSource = (String[]) _htFormData.GetElement(FolderEditorDataSourceView.HTMLSELECT_DEFAULTDATASOURCE);

				if ((null != dataDefaultDataSource) &&
						!(0 == dataDefaultDataSource.length))
				{
					m_nDefaultDataSource = XPConvert.ToInteger(dataDefaultDataSource[0]);
				}
				else
				{
					
						log.Warn("FolderEditorModel::SaveFiltersPage Default DataSource Select was not in Query String.");
					
				}
			}
		}
		else
		{
			
				log.Warn("FolderEditorModel::SaveFiltersPage Default DataSource was not in Query String.");
			
		}
	}

	// BEGIN ***************** save DP methods ***************** 

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
		String[] data;

		// ********************** GENERAL INFO ********************* //
		// FOLDER NAME
		data = (String[]) _htFormData.GetElement(FolderEditorMainView.HTMLINPUT_FOLDER_NAME);

		if ((null != data) && !(0 == data.length))
		{
			m_ptObject.SetName(data[0]);

			
				log.Debug("PropModel::SaveMainPage New property name: " + data[0]);
			
		}
		else
		{
			
				log.Warn("PropModel::SaveMainPage Property name was not in Query String.");
			
		}

		// FOLDER DESCRIPTION
		data = (String[]) _htFormData.GetElement(FolderEditorMainView.HTMLINPUT_FOLDER_DESCRIPTION);

		if ((null != data) && !(0 == data.length))
		{
			m_ptObject.SetDescription(data[0]);

			
				log.Debug("PropModel::SaveMainPage New property description: " +
					data[0]);
			
		}
		else
		{
			
				log.Warn("PropModel::SaveMainPage Property description was not in Query String.");
			
		}

		// ********************** SORTING ********************* //
		// Browsing Sort OrderBy
		data = (String[]) _htFormData.GetElement(FolderEditorSortingView.HTMLSELECT_BROWSING_ORDER_BY);

		if ((null != data) && !(0 == data.length))
		{
			int nBrowsingOrderByPropID = XPConvert.ToInteger(data[0]);
			((IPTFolder) m_ptObject).SetDefaultSearchOrderBy(nBrowsingOrderByPropID);
		}
		else
		{
			
				log.Warn("FolderEditorModel::SaveMainPage Browsing OrderBy String was not in Query String.");
			
		}

		// Editing Sort OrderBy
		data = (String[]) _htFormData.GetElement(FolderEditorSortingView.HTMLSELECT_EDITING_ORDER_BY);

		if ((null != data) && !(0 == data.length))
		{
			int nEditingOrderByPropID = XPConvert.ToInteger(data[0]);
			((IPTFolder) m_ptObject).SetDefaultOrderBy(nEditingOrderByPropID);
		}
		else
		{
			
				log.Warn("FolderEditorModel::SaveMainPage Editing OrderBy String was not in Query String.");
			
		}

		// Sort Default Folder
		data = (String[]) _htFormData.GetElement(FolderEditorFilterSettingsView.HTMLSELECT_DEFAULTFOLDER);

		if ((null != data) && !(0 == data.length))
		{
			int nDefaultFolder = XPConvert.ToInteger(data[0]);

			if (-1 == nDefaultFolder)
			{ // This folder
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PUT_CARDS_HERE,
					new Integer(1));
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_DEFAULT_SUBFOLDERID,
					new Integer(PT_INTRINSICS.PT_NULL_OBJECTID));
			}
			else if (PT_INTRINSICS.PT_NULL_OBJECTID == nDefaultFolder)
			{ // No Folder
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PUT_CARDS_HERE,
					new Integer(0));
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_DEFAULT_SUBFOLDERID,
					new Integer(PT_INTRINSICS.PT_NULL_OBJECTID));
			}
			else
			{ // Put into subfolder
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PUT_CARDS_HERE,
					new Integer(0));
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_DEFAULT_SUBFOLDERID,
					new Integer(nDefaultFolder));
			}
		}
		else
		{
			
				log.Warn("FolderEditorModel::SaveMainPage OrderBy String was not in Query String.");
			
		}

		// Filter Settings
		data = (String[]) _htFormData.GetElement(FolderEditorFilterSettingsView.HTMLRADIO_FILTERSETTINGS);

		if ((null != data) && !(0 == data.length))
		{
			int nFilterSettingOption = XPConvert.ToInteger(data[0]);

			if (-1 == nFilterSettingOption)
			{
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_NO_CARDS,
					new Integer(0));
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_ALL_CARDS,
					new Integer(0));
			}
			else if (PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_NO_CARDS == nFilterSettingOption)
			{
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_ALL_CARDS,
					new Integer(0));
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_NO_CARDS,
					new Integer(1));
			}
			else if (PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_ALL_CARDS == nFilterSettingOption)
			{
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_NO_CARDS,
					new Integer(0));
				((IPTFolder) m_ptObject).SetSettings(PT_FOLDER_SETTINGS.PT_FOLDER_CLASSFN_PASS_ALL_CARDS,
					new Integer(1));
			}
		}
		else
		{
			
				log.Warn("FolderEditorModel::SaveMainPage Filter Settings were not in Query String.");
			
		}

		// Filter Operator
		data = (String[]) _htFormData.GetElement(FolderEditorFilterSettingsView.HTMLSELECT_FILTEROPERATOR);

		if ((null != data) && !(0 == data.length))
		{
			int nClassificationOrderBy = XPConvert.ToInteger(data[0]);
			((IPTFolder) m_ptObject).SetClassificationFiltersOperator(nClassificationOrderBy);
		}
		else
		{
			
				log.Warn("FolderEditorModel::SaveMainPage Classification Operator was not in Query String.");
			
		}
	}

	/**
	 * Helper method that recursively propagates the ACL in the given folder
	 * to all it's cards and subfolders.
	 * 
	 * @param _ptCatalog
	 * @param _ptFolder
	 * @param _ptACL
	 */
	private void PropagateACL(IPTCatalog _ptCatalog, IPTFolder _ptFolder, IPTAccessList _ptACL)
	{
		PropagateACLOnCards(_ptCatalog, _ptFolder, _ptACL);

		IPTQueryResult qrFolders = _ptFolder.QuerySubfolders(
			PT_PROPIDS.PT_PROPID_OBJECTID /* prop mask */, 
			0 	/* depth */,
			null 	/* no order by */,
			0 		/* no skip rows */,
			-1 		/* no max rows */,
			null 	/* no query filter */);

		for (int i=0; i<qrFolders.RowCount(); i++)
		{
			/* get sub folder */
			int id = qrFolders.ItemAsInt(i,PT_PROPIDS.PT_PROPID_OBJECTID);
			IPTFolder ptSubFolder = _ptCatalog.OpenFolder(id,true);
			
			/* recurse */
			PropagateACL(_ptCatalog, ptSubFolder, _ptACL);

			/* get server context */
			IPTServerContext ptSC = (IPTServerContext) ptSubFolder.
				GetInterfaces("IPTServerContext");

			/* get folder acl, clear, and merge empty one with parent acl */
			IPTAccessList ptSubACL = ptSC.GetACL();
			ptSubACL.ClearCompletely();
			ptSubACL.Merge(_ptACL);
			 
			//store the folder
			ptSC.Store();
			ptSC.UnlockObject();
		}
	}
	
	/**
	 * Helper Method that propagates ACL from given folder to all its cards
	 * 
	 * @param _ptCatalog
	 * @param _ptFolder
	 * @param _ptACL
	 */
	private void PropagateACLOnCards(IPTCatalog _ptCatalog, IPTFolder _ptFolder, IPTAccessList _ptACL)
	{
		IPTQueryResult qrCards = _ptFolder.QueryCards(
			PT_PROPIDS.PT_PROPID_OBJECTID /* prop mask */, 
			true 	/* include unapproved */,
			null 	/* no order by */,
			0 		/* no skip rows */,
			-1 		/* no max rows */,
			null 	/* no query filter */);
			
		for (int i=0; i<qrCards.RowCount(); i++)
		{
			/* get each card and open server context */
			int id = qrCards.ItemAsInt(i,PT_PROPIDS.PT_PROPID_OBJECTID);
			IPTCard ptCard = _ptCatalog.OpenCard(id,true);
			IPTServerContext ptSC = (IPTServerContext) ptCard.
				GetInterfaces("IPTServerContext");

			/* get card acl, clear it, and merge empty one with parent acl */
			IPTAccessList ptCardACL = ptSC.GetACL();
			ptCardACL.ClearCompletely();
			ptCardACL.Merge(_ptACL);
			
			//store the card
			ptSC.Store();
			ptSC.UnlockObject();
		}
	}
	
	/**
	 * 
	 *
	 * @return 
	 */
	private int LoadDefaultDataSource()
	{
		IPTObjectProperties spProperties = m_ptObject.GetObjectProperties();

		IPTQueryResult spPropList = spProperties.GetSinglePropertyRefData(PT_INTRINSICS.PT_PROPERTY_DEFAULTDATASOURCE,
				0);

		int nResultCount = spPropList.RowCount();

		if (1 != nResultCount)
		{
			return 0;
		}

		Object oValue = spPropList.ItemAsObject(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);

		if (null == oValue)
		{
			return 0;
		}

		int nDataSourceID = XPConvert.ToInteger(oValue);

		return nDataSourceID;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		Redirect redirect = super.GetRedirectAfterFinish();
		if(redirect.GetSpaceName().equals(DirAS.STR_MVC_CLASS_NAME))
		{
			redirect.SetDisplayPage(DirAS.DIR_EDITOR_FINISH);
		}
		return redirect;
	}
	
	/**
	 * @return
	 */
	public int GetACLFlag() 
	{
		return m_flagACL;
	}
	
	/**
	 * @return
	 */
	public void SetACLFlag(int _ACLFlag) 
	{
		m_flagACL = _ACLFlag;
	}
}

