package com.plumtree.portalpages.browsing.editors.folder;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * This is class is used to print out together the Views for
 * the Related Resources page of the Property Editor.
 */
public class FolderEditorRelatedResourcesDP extends EditorDP
{
	
	public static final String STR_MVC_CLASS_NAME = "FolderEditorRR";
	private IFolderEditorModelRO m_asModel;


	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(451, "ptmsgs_portalbrowsingmsgs"));
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the Advanced Settings page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 * @throws HTMLException
	 */
	public HTMLElement PageDisplay()
	{
		m_asModel = (IFolderEditorModelRO) m_asOwner.GetModel(FolderEditorModel.STR_MVC_CLASS_NAME);

		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// Show Communities
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				FolderEditorAS.strSelectRRCommunity)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// Show Related Folders
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				FolderEditorAS.strSelectRRFolder)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// Show Related Portlets
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				FolderEditorAS.strSelectRRPortlet)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// Show Related Experts
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				FolderEditorAS.strSelectRRExpert)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		// Show Related Content Managers
		views.AddInnerHTMLElement(((EditorView) m_asOwner.GetView(
				FolderEditorAS.strSelectRRContentManager)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				FolderEditorAS.strSelectRRCommunity).DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				FolderEditorAS.strSelectRRFolder).DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				FolderEditorAS.strSelectRRPortlet).DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				FolderEditorAS.strSelectRRExpert).DisplayJavascript());
		myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				FolderEditorAS.strSelectRRContentManager).DisplayJavascript());

		return myScripts;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 * @throws XPException 
	 */
	protected HTMLElement GetHTMLBelowSubHeader()

	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(452, "ptmsgs_portalbrowsingmsgs"),
			this.m_asOwner);
	}
}

