package com.plumtree.portalpages.browsing.editors.folder;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 */
public class FolderEditorRepostControl extends ObjEditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.folder.FolderEditorRepostControl");

	
	public static final String STR_MVC_CLASS_NAME = "FolderEditorRepost";

	/** Repost Action: Apply No Security Propagation */
	public final static int POSTTOSELF_ACTION_PROPAGATE = 70;

	/** Repost Action: Apply Security Propagation */
	public final static int POSTTOSELF_ACTION_NO_PROPAGATE = 71;

	/** Repost Action: Cancel Security Propagation */
	public final static int POSTTOSELF_ACTION_CANCEL_PROPAGATE = 72;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderEditorRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);
		
		/* check propagate ACL and set flag */
		switch (_nAction)
		{	
			case POSTTOSELF_ACTION_NO_PROPAGATE:
				/* save the editor but don't propagate acl */
				((FolderEditorModel) m_model).
					SetACLFlag(FolderEditorModel.NO_PROPAGATE_ACL);
				
				m_model.Finish();
				SetRedirect(m_model.GetRedirectAfterFinish());
				
				break;
				
			case POSTTOSELF_ACTION_PROPAGATE:
				/* save the editor and propagate the acl */
				((FolderEditorModel) m_model).
					SetACLFlag(FolderEditorModel.YES_PROPAGATE_ACL);

				m_model.Finish();
				SetRedirect(m_model.GetRedirectAfterFinish());

				break;
				
			case POSTTOSELF_ACTION_CANCEL_PROPAGATE:
				/* don't save the editor, but keep it open */ 
				((FolderEditorModel) m_model).
					SetACLFlag(FolderEditorModel.UNKNOWN_PROPAGATE_ACL);

				break;

		}
		
		((ExpListControl) m_asOwner.GetControl(FolderEditorAS.strSelectFilters)).PerformRepostAction(_nAction,
			m_htFormData);

		((ExpListControl) m_asOwner.GetControl(FolderEditorAS.strSelectRRCommunity)).PerformRepostAction(_nAction,
			m_htFormData);

		((ExpListControl) m_asOwner.GetControl(FolderEditorAS.strSelectRRFolder)).PerformRepostAction(_nAction,
			m_htFormData);

		((ExpListControl) m_asOwner.GetControl(FolderEditorAS.strSelectRRPortlet)).PerformRepostAction(_nAction,
			m_htFormData);

		((ExpListControl) m_asOwner.GetControl(FolderEditorAS.strSelectRRExpert)).PerformRepostAction(_nAction,
			m_htFormData);

		((ExpListControl) m_asOwner.GetControl(FolderEditorAS.strSelectRRContentManager)).PerformRepostAction(_nAction,
			m_htFormData);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorRepostControl#PerformFinishAction()
	 */
	public void PerformFinishAction() 
	{
		ObjectSecurityModel securityModel = (ObjectSecurityModel) 
			m_asOwner.GetModel(ObjEditorAS.STR_MVC_STORAGE_NAME_SECURITY_TAB);

		/* if the security of this folder has changed, check to see if we've
		 * asked the user to propagate those changes, if not, pop up a window
		 * to do so, if we have then just save the editor.
		 */
		if (securityModel.HasSecurityChanged() && 
			(FolderEditorModel.UNKNOWN_PROPAGATE_ACL == 
				((FolderEditorModel) m_model).GetACLFlag()))
		{
			if (securityModel.CanPropagateSecurity()) {
				OpenSavePopUp();
			} else {
				/* save the editor but don't propagate acl */
				((FolderEditorModel) m_model).
					SetACLFlag(FolderEditorModel.NO_PROPAGATE_ACL);
				super.PerformFinishAction();
			}
		}
		else
		{
			super.PerformFinishAction();
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjEditorRepostControl#OpenSavePopUp()
	 */
	protected void OpenSavePopUp() 
	{
		HTMLScript myScript   = new HTMLScript("text/javaScript");
		ASURL saveObjectPopUp = new ASURL(m_asOwner);
		XPStringBuilder sb;

		saveObjectPopUp.SetLinkGetCachedSpace(m_asOwner);
		saveObjectPopUp.SetDisplayPage(FolderEditorACLPropagateDP.STR_MVC_CLASS_NAME);
		saveObjectPopUp.SetControl(FolderEditorRepostControl.STR_MVC_CLASS_NAME);
		saveObjectPopUp.AddControlArgument(ASConstants.PAGE_INPUT, 
			FolderEditorACLPropagateDP.STR_MVC_CLASS_NAME);
		saveObjectPopUp.AddControlArgument(FolderEditorRepostControl.HTMLINPUT_POSTTOSELF,
			XPConvert.ToString(FolderEditorRepostControl.POSTTOSELF_ACTION_GOTOPAGE));
		
		String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
		// Add a javascript to the page to open a pop-up going to that URL
		try
		{
			sb = new XPStringBuilder(200);
			
			sb.Append(strJSUtilVersionPrefix+"PTWindowUtil.openWindow('")
				.Append(saveObjectPopUp.GetURLAsString())
				.Append("', '_PropagateACLDP_PP', '120', '500');\n");
			myScript.AddInnerHTMLString(sb.ToString());

			((EditorDP) ((EditorAS) m_asOwner).GetCurrentPage()).AddScriptToHead(myScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "FolderEditorRepostControl::OpenSavePopUp The following error occured" +
					" when trying to generate the JavaScript for the save object pop-up window: " +
					he.GetMessage());
			

			throw new XPException(m_asOwner.GetString(159,
					"ptmsgs_portalinfrastructure"), he);
		}
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.editor.ObjEditorRepostControl#DisableSavePopUp()
	 */
	protected boolean DisableSavePopUp()
	{
		return true;
	}

}
