package com.plumtree.portalpages.browsing.editors.folder;


// Plumtree Server
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * This Section represents a section of the Main Settings page
 * of the Folder Editor.
 * This Section is printed out by FolderEditorMainDP.
 */
public class FolderEditorSortingView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.folder.FolderEditorSortingView");

	
	public static final String STR_MVC_CLASS_NAME = "FolderEditorSorting";

	// HTML Object names.
	public static final String HTMLSELECT_BROWSING_ORDER_BY = "in_se_BrowsingOrderBy";

	
	public static final String HTMLSELECT_EDITING_ORDER_BY = "in_se_EditingOrderBy";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderEditorSortingView();
	}

	/**
	 * Helper methods that returns the property type name
	 * corresponding to the property type ID passed in argument.
	 *
	 * @param _nPropType
	 * @return String
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLSpan mySpan;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display FolderEditorSortingView");
			result.AddInnerHTMLElement(myComment);

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						454, "ptmsgs_portalbrowsingmsgs")));

			result.AddInnerHTMLElement(DirConstants.CreateSpacerImage(2,1));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// BEGIN Sorting Instructions Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetColSpan("2");
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(456,
					"ptmsgs_portalbrowsingmsgs"));

			// END Sorting Instructions Row
			// BEGIN OrderBy Browsing Label  + dropdown ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			myCell.SetWidth("25%");
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(457,
					"ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nBrowsingOrderByPropID = ((IFolderEditorModelRO) m_model).GetBrowsingOrderBy();

			mySelect = new HTMLSelect(HTMLSELECT_BROWSING_ORDER_BY, "select1");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// options
			// Iterate through all properties
			IASQueryResult asqrProps = ((IFolderEditorModelRO) m_model).GetBrowsingOrderByProperties();

			if (null != asqrProps)
			{
				int nPropCount = asqrProps.GetCount();

				for (int i = 0; i < nPropCount; i++)
				{
					int nPropID		   = XPConvert.ToInteger(asqrProps.GetFields(i,
							PT_PROPIDS.PT_PROPID_OBJECTID));
					String strPropName = (String) asqrProps.GetFields(i,
							PT_PROPIDS.PT_PROPID_NAME);

					myOption		   = new HTMLOption(XPConvert.ToString(nPropID));
					mySpan			   = new HTMLSpan();
					myOption.AddInnerHTMLElement(mySpan);
					mySpan.AddInnerHTMLString(XPHttpUtility.HtmlEncode(
							strPropName));
					mySelect.AddInnerHTMLElement(myOption);

					if (nPropID == nBrowsingOrderByPropID)
					{
						myOption.SetSelected(true);
					}
				}
			}

			// END OrderBy Browsing Label  + dropdown ROW
			// BEGIN OrderBy Editing Label  + dropdown ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(458,
					"ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nEditingOrderByPropID = ((IFolderEditorModelRO) m_model).GetEditingOrderBy();

			mySelect = new HTMLSelect(HTMLSELECT_EDITING_ORDER_BY, "select2");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// NAME
			myOption     = new HTMLOption(XPConvert.ToString(PT_PROPIDS.PT_PROPID_NAME));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(459,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (PT_PROPIDS.PT_PROPID_NAME == nEditingOrderByPropID)
			{
				myOption.SetSelected(true);
			}

			// CREATED
			myOption     = new HTMLOption("" + PT_PROPIDS.PT_PROPID_CREATED +
					"");
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(462,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (PT_PROPIDS.PT_PROPID_CREATED == nEditingOrderByPropID)
			{
				myOption.SetSelected(true);
			}

			// LAST MODIFIED
			myOption     = new HTMLOption("" +
					PT_PROPIDS.PT_PROPID_LASTMODIFIED + "");
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(461,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (PT_PROPIDS.PT_PROPID_LASTMODIFIED == nEditingOrderByPropID)
			{
				myOption.SetSelected(true);
			}

			// DESCRIPTION
			myOption     = new HTMLOption("" +
					PT_PROPIDS.PT_PROPID_DESCRIPTION + "");
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(460,
					"ptmsgs_portalbrowsingmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (PT_PROPIDS.PT_PROPID_DESCRIPTION == nEditingOrderByPropID)
			{
				myOption.SetSelected(true);
			}

			// END OrderBy Editing Label  + dropdown ROW
			myComment = new HTMLComment( "End: Display FolderEditorSortingView");
			result.AddInnerHTMLElement(myComment);
			
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME +
					"::Display The following error occured when trying to display the HTML: " +
					he.getMessage());
			

			throw new XPException(m_asOwner.GetString(463,
					"ptmsgs_portalbrowsingmsgs"), he);
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}

