package com.plumtree.portalpages.browsing.editors.folder;

import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;

/**
 * @author StephenC
 *
 * This interface is implemented by FolderEditorModel.
 * It contains all the read-only mothods of FolderEditorModel.
 */
public interface IFolderEditorModelRO extends IObjEditorModelRO
{
	/**
	 * Returns the propID to order by when BROWSING
	 */
	public int GetBrowsingOrderBy();

	/**
	 * Returns a query result of the card properties to sort by when BROWSING
	 */
	public IASQueryResult GetBrowsingOrderByProperties();

	/**
	 * returns the value of the Folder's ClassificationFiltersOperator Setting
	 */
	public int GetClassificationFiltersOperator();

	/**
	 * returns the name of a given datasource.
	 */
	public String GetDataSourceName(int nDataSourceID);

	/**
	 * returns the name of the Default DataSource for this folder.  (non-recursive)
	 */
	public int GetDefaultDataSource();

	/**
	 * Returns the propID to order by when EDITING
	 */
	public int GetEditingOrderBy();

	/**
	 * returns a list of data sources that support Card Submission
	 */
	public IASQueryResult GetFilteredDataSources();

	/**
	 * returns the value of a particular Folder Setting
	 */
	public Object GetFolderSetting(int nValueName);

	/**
	 * returns the name of the Default DataSource for this folder.  It will recursively search up the ancestors to get this.
	 */
	public String GetParentDefaultDataSourceNameRecursive();

	/**
	 * Returns a query result of the sub-folders
	 */
	public IASQueryResult GetSubFolders();

	/**
	 * returns whether this is the root folder
	 */
	public boolean IsRootFolder();

	/**
	 * returns primary name
	 */
	public String GetPrimaryName();

	/**
	 * returns primary name
	 */
	public String GetPrimaryDesc();

}

