package com.plumtree.portalpages.browsing.editors.multipledocumentlinksettings;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.common.linksettings.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author StephenC
 */
public class MultipleCardLinkSettingsModel extends ObjEditorModel
	implements IMultipleCardLinkSettingsModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.multipledocumentlinksettings.MultipleCardLinkSettingsModel");

	
	public static final String STR_MVC_CLASS_NAME = "MultipleCardLinkSettings";

	public static final String QS_CARD_IDS = "CardIDs";

	
	public IPTCardRefreshAgent m_ptCardRefreshAgent = null;

	
	public IPTSession m_ptSession = null;

	
	public String m_strCardNames = "";

	
	public int[] m_arCardIDs;

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		String[] data;

		// CARDIDS
		data = (String[]) _htFormData.GetElement(QS_CARD_IDS);

		if ((null != data) && !(0 == data.length))
		{
			String strCardIDs = data[0];

			int nCardCount = 1;
			int nPos	   = 0;
			int nLastPos;

			while (-1 != (nPos = strCardIDs.indexOf(",", nPos + 1)))
			{
				nCardCount++;
			}

			nPos = 0;

			String strCardID;
			m_arCardIDs = new int[nCardCount];

			for (int nCardIndex = 0; nCardIndex < nCardCount; nCardIndex++)
			{
				nLastPos     = nPos;
				nPos		 = strCardIDs.indexOf(",", nLastPos + 1);

				if (-1 == nPos)
				{
					// Read last CardID
					strCardID				    = strCardIDs.substring(nLastPos);
					m_arCardIDs[nCardIndex]     = XPConvert.ToInteger(strCardID);
				}
				else
				{
					strCardID				    = strCardIDs.substring(nLastPos,
							nPos);
					m_arCardIDs[nCardIndex]     = XPConvert.ToInteger(strCardID);

					nPos++;
				}
			}
		}
		else
		{
			
				log.Warn("MultipleCardLinkSettingsModel::StartEditor CardIDs not found in Query String.");
			
		}

		return super.CheckEditorAccessAndStart(_htFormData);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MultipleCardLinkSettingsModel();
	}

	/**
	 * 
	 */
	public void DoTaskBeforeStore()
	{
		// Get the settings back from the plug-in Model and sets them on the Object before the Framework stores it.
		IPTCardRefreshInfo ptCardRefreshInfo = ((LinkSettingsPlugInModel) m_asOwner.GetModel(MultipleCardLinkSettingsAS.strLinkSettingsPlugInKey)).GetCardRefreshInfo();
		IPTPersist ptCardRefreshInfoPersist  = (IPTPersist) ptCardRefreshInfo.GetInterfaces(
				"IPTPersist");

		// Save Refresh Info for each Card
		for (int i = 0; i < m_arCardIDs.length; i++)
		{
			int nObjectID = m_arCardIDs[i];

			try
			{
				m_ptCardRefreshAgent.SetCardRefreshInfo(nObjectID,
					ptCardRefreshInfoPersist.SaveToXML(0));
			}
			catch (XPException xpe)
			{
				log.Error(xpe, STR_MVC_CLASS_NAME +
					"::DoTaskBeforeStore(): Unable to store link settings for Card " +
					nObjectID);
			}
		}
	}

	/**
	 * Initializes the property type member variable with
	 * the one from IPTProperty in Edit mode and the default
	 * value in create mode.
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		try
		{
			// Concatenate Card Names
			// limit of 50 characters
			int nCardNamesCharLimit = 50;

			for (int i = 0; i < m_arCardIDs.length; i++)
			{
				IPTCard ptCard;

				try
				{
					ptCard = m_ptSession.GetCatalog().OpenCard(m_arCardIDs[i], false);
				}
				catch (XPException xpe)
				{
					log.Warn(xpe, STR_MVC_CLASS_NAME +
						"::DoTaskOnStartEditor Unable to open card  " +
						m_arCardIDs[i]);

					break;
				}

				if (i > 0)
				{
					m_strCardNames += ", ";
				}

				m_strCardNames += ptCard.GetLocalizedName();

				if (m_strCardNames.length() > nCardNamesCharLimit)
				{
					m_strCardNames = m_strCardNames.substring(0,
							nCardNamesCharLimit);
					m_strCardNames += "...";

					break;
				}
			}

			// Get the Card Refresh Info
			m_ptCardRefreshAgent = (IPTCardRefreshAgent) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_CARD_REFRESH_AGENT,
					false);

			IPTCardRefreshInfo ptCardRefreshInfo = m_ptCardRefreshAgent.GetCardRefreshInfo(this.m_nObjectID);

			((LinkSettingsPlugInModel) m_asOwner.GetModel(MultipleCardLinkSettingsAS.strLinkSettingsPlugInKey)).InitializePlugIn(true,
				ptCardRefreshInfo);
		}
		catch (XPException xpe)
		{
			log.Error(xpe, STR_MVC_CLASS_NAME +
				"::DoTaskOnStartEditor Unable to retrieve Card Refresh Settings for card " +
				this.m_nObjectID);
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetCardNames()
	{
		return m_strCardNames;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
		m_ptSession = (IPTSession) parent.GetUserSession();
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(MultipleCardLinkSettingsMainDP.STR_MVC_CLASS_NAME))
		{
			((LinkSettingsPlugInModel) m_asOwner.GetModel(MultipleCardLinkSettingsAS.strLinkSettingsPlugInKey)).SaveSection(_htFormData);
		}

		return nPageStatus;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		Redirect redirect = super.GetRedirectAfterFinish();
		if(redirect.GetSpaceName().equals(DirAS.STR_MVC_CLASS_NAME))
		{
			redirect.SetDisplayPage(DirAS.DIR_EDITOR_FINISH);
		}
		return redirect;
	}
}

