/**
 * Created on Dec 20, 2002
 * by adolfoc
 */
package com.plumtree.portalpages.browsing.editors.objectdelivery.common;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;

/**
 * @author adolfoc
 *
 * This class is a simple representation of a dependency returned by the ObjectMigration API,
 * with some bonus features.
 */
public class ODDependency
{
	/**
	 * These constants are used as a mask with the GetODDependency call to
	 * select what type of dependencies to return.
	 */
	public static final int ODD_GET_ALL = -1;
	public static final int ODD_GET_SUPPORTED = 1;
	public static final int ODD_GET_UNSUPPORTED = 2;
	public static final int ODD_GET_HIDDEN = 4;
	
	
	protected IPTMigrationElement m_ptMEParent = null;
	
	

	/**
	 * Our local information
	 */
	protected String m_strName	  = "";
	protected String m_strUUID	  = "";
	protected int m_nCLASSID		  = -1;
	protected int m_nDependencyType = 0;

	/**
	 * Constructor for ODDependency.
	 */
	public ODDependency(String strName, String strUUID, int nCLASSID,
		int nDependencyType, IPTMigrationElement ptMEParent)
	{
		m_strName			  = strName;
		m_strUUID			  = strUUID;
		m_nCLASSID			  = nCLASSID;
		m_nDependencyType     = nDependencyType;
		m_ptMEParent		  = ptMEParent;		
	}

	/**
	 * Returns the CLASSID.
	 * @return int
	 */
	public int GetCLASSID()
	{
		return m_nCLASSID;
	}

	/**
	 * Returns the dependencyType.
	 * @return int
	 */
	public int GetDependencyType()
	{
		return m_nDependencyType;
	}

	/**
	 * Returns the mEParent.
	 * @return IPTMigrationElement
	 */
	public IPTMigrationElement GetMEParent()
	{
		return m_ptMEParent;
	}

	/**
	 * Returns the name.
	 * @return String
	 */
	public String GetName()
	{
		return m_strName;
	}

	// Static methods;
	
	/**
	 * Static method which creates a bunch of ODDependencies given a Migration Element and a 
	 * selection criteria (see the mask defined above).
	 * 
	 */
	public static XPArrayList GetODDependencies(IPTMigrationElement ptME, int nSelectMask)
	{
		XPArrayList xpalResult = new XPArrayList();

		Object objDepends = ptME.GetDependencies();

		if (null == objDepends)
		{
			// This is one end point for the recursion (no dependencies found).
			return xpalResult;
		}

		Object[][] arDependencies = (Object[][]) objDepends;
		int nDependencies		  = arDependencies[0].length;

		for (int nIndex = 0; nIndex < nDependencies; nIndex++)
		{
			String strName	    = ((String) arDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_NAME][nIndex]);
			String strUUID	    = ((String) arDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_UUID][nIndex]);
			int nCLASSID	    = XPConvert.ToInteger(arDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_CLASSID][nIndex]);
			int nDependencyType = XPConvert.ToInteger(arDependencies[PT_OBJECT_DEPENDENCY_COLS.PT_ODC_DEPENDENCY_TYPE][nIndex]);

			
			boolean bAdd = ((0 != (nSelectMask & ODD_GET_SUPPORTED)) && ObjectDeliveryHelper.IsSupported(nCLASSID))
							|| ((0 != (nSelectMask & ODD_GET_UNSUPPORTED)) && !ObjectDeliveryHelper.IsSupported(nCLASSID) && !(ObjectDeliveryHelper.IsHidden(nCLASSID) || ObjectDeliveryHelper.IsHiddenDependencyType(nDependencyType)))
							|| ((0 != (nSelectMask & ODD_GET_HIDDEN)) && (ObjectDeliveryHelper.IsHidden(nCLASSID) || ObjectDeliveryHelper.IsHiddenDependencyType(nDependencyType))); 
			if (bAdd)
			{
				xpalResult.Add(new ODDependency(strName, strUUID, nCLASSID,
					nDependencyType, ptME));
			}

		}

		return xpalResult;		
	}
	

	/**
	 * Static method which creates a bunch of ODDependencies, given a MigrationElement.
	 */
	public static XPArrayList GetODDependencies(IPTMigrationElement ptME)
	{
		return GetODDependencies(ptME, ODD_GET_ALL);	
	}

	/**
	 * Static method which creates a bunch of ODDependencies, given a MigrationElement.
	 * Returns an array of only those ODDependencies that are supported (as listed in
	 * ObjectDeliveryHelper.m_arSupportedCLASSIDS); This method does not return
	 * Folders as supported dependencies.
	 */
	public static XPArrayList GetSupportedODDependencies(
		IPTMigrationElement ptME)
	{
		return GetODDependencies(ptME,ODD_GET_SUPPORTED);
	}

	/**
	 * Returns the uUID.
	 * @return String
	 */
	public String GetUUID()
	{
		return m_strUUID;
	}

	/**
	 * Static method which creates a bunch of ODDependencies, given a MigrationElement.
	 * Returns an array of only those ODDependencies that are NOT supported (as listed in
	 * ObjectDeliveryHelper.m_arSupportedCLASSIDS); This method DOES NOT return Folder
	 * Dependencies or Users as UnSupported.
	 */
	public static XPArrayList GetUnImportableODDependencies(
		IPTMigrationElement ptME)
	{
		return GetODDependencies(ptME,ODD_GET_UNSUPPORTED);
	}

	/**
	 * Static method which creates a bunch of ODDependencies, given a MigrationElement.
	 * Returns an array of only those ODDependencies that are NOT supported (as listed in
	 * ObjectDeliveryHelper.m_arSupportedCLASSIDS); This method DOES return Folder
	 * Dependencies or Users as UnSupported.
	 */
	public static XPArrayList GetAllUnImportableODDependencies(
		IPTMigrationElement ptME)
	{
		return GetODDependencies(ptME,ODD_GET_UNSUPPORTED | ODD_GET_HIDDEN);
	}

	/**
	 * Returns whether or not this dependency is of this dependency type:
	 * @return boolean
	 */
	public boolean IsDependentBy(int nDependencyMask)
	{
		if (0 == (nDependencyMask & m_nDependencyType))
		{
			return false;
		}
		else
		{
			return true;
		}
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object arg0)
	{
		try
		{
			ODDependency odEquand = (ODDependency) arg0;

			if (0 == m_strUUID.compareTo(odEquand.GetUUID()))
			{
				return true;
			}
		}
		catch (Exception e)
		{
		}

		return false;
	}
}

