package com.plumtree.portalpages.browsing.editors.sitemap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * @author NaveenP
 *
 */
public class SiteMapFolderCheckAccessControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.sitemap.SiteMapFolderCheckAccessControl");

	/** name of the refresh object selection control */
	public static final String STR_MVC_CLASS_NAME = "SiteMapFolderCheckAccess";

	/** Activity Space */
	protected AActivitySpace m_asOwner;

	/** Internal data **/
	protected SiteMapFolderModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		if (!((EditorModel) m_asModel).GetUserHasAccessToEditor())
		{
			Redirect myRedirectToLogin = new Redirect();
			myRedirectToLogin.SetIsErrorRedirect(true);
			myRedirectToLogin.SetLinkCreateNewSpace(m_asOwner.GetName(), m_asOwner);
			myRedirectToLogin.SetControl(STR_MVC_CLASS_NAME);
			myRedirectToLogin.AddControlArguments(arguments);

			return myRedirectToLogin;
		}

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapFolderCheckAccessControl();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		try
		{
			m_asModel     = (SiteMapFolderModel) model;
		}
		catch (Exception e)
		{
			
				log.Error(e, "SiteMapFolderCheckAccessControl::Init Unable to cast the Object " + model +
					" to SiteMapFolderModel. The following exception occured: " +
					e.getMessage());
			

			// JF- No need to extract, this is an unexpected error.
			throw new XPException("Unable to cast the Object " + model +
				" to SiteMapFolderModel.", e);
		}

		m_asOwner     = space;
	}
}

