package com.plumtree.portalpages.browsing.editors.sitemap;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapFolderModel.java
 * -----------------------------
 *
 * @author NaveenP
 */
public class SiteMapFolderModel extends ObjEditorModel
	implements ISiteMapFolderRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.sitemap.SiteMapFolderModel");

	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SiteMapFolder";

	/** The parent folder id query string argment */
	public static final String QS_PARENTFOLDERID = "ParentFolderID";

	/** The edit type query string argument */
	public static final String QS_NAMEORSECURITY = "EditType";

	/** Query string argument indicating the starting context for the editor */
	public static final String QS_STARTEDINSITEMAP = "StartedInSiteMap";
	
	/** Query string argument indicating to show localized names page only */
	public static final String QS_LOCALIZEDNAME = "LocalizeNamePage";

	/** Constant representing the name and description page */
	public static final int EDIT_TYPE_NAME_DESC = 0;

	/** Constant representing the security page */
	public static final int EDIT_TYPE_SECURITY = 1;

	/** Constant indicating no parent admin folder */
	public static final int NO_PARENT = -1;
	
	//Member variables
	private IPTSiteMapFolder m_ptParentFolder;
	private boolean m_bStartedInSiteMap = false;
	private boolean m_bFromSubportalNav = false;
	private int m_nNameOrSecurity		 = -1;
	private int m_nParentSiteMapFolderID = -1; // this should be NO_PARENT, but in order for the j2c tool to work properly i just set the real value here.

	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapFolderModel();
	}

	/**
	 * This function cleans up the folder created at the outset if the user
	 * cancels the editor
	 */
	public void DeleteFolderOnCancel()
	{
		if (GetEditorType() == EditorStartControl.EDITOR_START_FLAG_CREATE)
		{
			IPTServerContext objSC = (IPTServerContext) m_ptObject.GetInterfaces(
					"IPTServerContext");
			int nObjectID		   = objSC.GetObjectID();
			IPTObjectManager objOM = m_Session.GetSiteMapFolders();
			objOM.Delete(nObjectID);
		}
	}

	/**
	 * This function saves the site map link folder at the outset, at least
	 * temporarily, so we can add links to it.
	 */
	public void DoInitialStore()
	{
		m_ptObject.SetAdminFolderID(PT_INTRINSICS.PT_ADMIN_FOLDER_UNCLASSIFIEDOBJECTS);

		IPTServerContext objSC = (IPTServerContext) m_ptObject.GetInterfaces(
				"IPTServerContext");
		objSC.Store();
		objSC.UnlockObject();
	}

	/**
	 * Initializes member variables when the editor starts
	 *
	 * @param _htFormData
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		InitializeSiteMapPlugIn();

		if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(m_bFromSubportalNav,
				ObjectSecurityDP.STR_MVC_CLASS_NAME);
		}
		else if (EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType())
		{
			if (NO_PARENT == m_nParentSiteMapFolderID)
			{
				DoInitialStore();
			}
		}

		if (EditorStartControl.EDITOR_START_FLAG_EDIT != GetEditorType())
		{
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);
		}

	}

	/**
	 * Helper method to initialize the plug-in section for navigation link
	 * creation
	 */
	public void InitializeSiteMapPlugIn()
	{
		SiteMapFolderPlugInModel mySiteMapFolderModel = (SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderEditorAS.STR_MVC_SITEMAP_PLUGIN);
		try
		{
			mySiteMapFolderModel.InitializePlugIn((IPTSiteMapFolder) m_ptObject);
		}
		catch (Exception e)
		{
			
				log.Error("SiteMapFolderModel::InitializeSiteMapPlugIn " + m_asOwner.GetString(1457, "ptmsgs_portalbrowsingmsgs") +
					e);
			

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
				UIErrorScope.CURRENT_USER, null,m_asOwner.GetString(1457, "ptmsgs_portalbrowsingmsgs"), "");
			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

	}

	/**
	 *
	 * @return boolean
	 */
	public boolean FolderHasParent()
	{
		return (NO_PARENT != m_nParentSiteMapFolderID);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	// END ***************** repost action methods ***************** 

	/**
	 * Returns Redirect object where the Framework should
	 * redirect to on Finish.
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		if ((NO_PARENT != m_nParentSiteMapFolderID) ||
				(-1 != m_nNameOrSecurity))
		{
			Redirect redirect	    = new Redirect();
			ClosePopUpDP closePopup = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			HTMLScript script	    = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

			try
			{
				script.AddInnerHTMLString(
					"window.opener.postToSelf(" + RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");"); //location.reload(true);");
					//DCA - changed to get rid of page refresh warning
			}
			catch (HTMLException he)
			{
				log.Error(he, he.getMessage());
			}

			closePopup.SetScript(script);

			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			redirect.SetControl(SiteMapFolderCheckAccessControl.STR_MVC_CLASS_NAME);

			return redirect;
		}
		else
		{
			return super.GetRedirectAfterFinish();
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetStartedInSiteMap()
	{
		return m_bStartedInSiteMap;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nPageStatus = super.SavePage(_sPageName, _htFormData);

		if (_sPageName.equals(SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME))
		{
			SaveEditLinkPage(_htFormData);
		}

		return nPageStatus;
	}

	/**
	 * Helper method to check the current user rights to this Object Editor.
	 *
	 * @param _htFormData Form data
	 * @return boolean
	 */
	protected boolean CheckEditorAccess(XPHashtable _htFormData)
	{
		String[] values = (String[]) _htFormData.GetElement(QS_PARENTFOLDERID);

		if (values != null)
		{
			m_nParentSiteMapFolderID = XPConvert.ToInteger(values[0]);
			((EditorAS) m_asOwner).SetCurrentPage(LocNamesDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
		}

		values = (String[]) _htFormData.GetElement(QS_NAMEORSECURITY);

		if (values != null)
		{
			m_nNameOrSecurity = XPConvert.ToInteger(values[0]);
		}

		if (m_nNameOrSecurity == EDIT_TYPE_NAME_DESC)
		{
			((EditorAS) m_asOwner).SetCurrentPage(LocNamesDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);	
			((EditorAS) m_asOwner).GetLeftMenu().HideSubMenu(true, ((SiteMapFolderEditorAS) m_asOwner).m_nMenuGeneralID);
		}
		else if (m_nNameOrSecurity == EDIT_TYPE_SECURITY)
		{
			((EditorAS) m_asOwner).SetCurrentPage(ObjectSecurityDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				LocNamesDP.STR_MVC_CLASS_NAME);
			((EditorAS) m_asOwner).GetLeftMenu().HideLink(true,
				SiteMapFolderEditLinksDP.STR_MVC_CLASS_NAME);
		}

		values = (String[]) _htFormData.GetElement(QS_STARTEDINSITEMAP);

		if (values != null)
		{
			// we came from the site map, so change the title to "Edit Folder" or "Create Folder".
			SetStartedInSiteMap(true);
		}
		
		values = (String[]) _htFormData.GetElement(QS_LOCALIZEDNAME);

		if (values != null)
		{
			// we only want to show the name page.
			m_bFromSubportalNav = true;
		}

		// JF- In create mode and from site map page, check parent folder access rights
		if ((EditorStartControl.EDITOR_START_FLAG_CREATE == m_nEditorType) &&
				(NO_PARENT != m_nParentSiteMapFolderID))
		{
			IPTObjectManager ptOM = m_Session.GetSiteMapFolders();
			m_ptParentFolder = (IPTSiteMapFolder) ptOM.Open(m_nParentSiteMapFolderID, false);

			return (ptOM.IsObjectAccessible(m_nParentSiteMapFolderID,
				m_Session.GetSessionInfo().GetCurrentUserID(),
				PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT));
		}
		else
		{
			return super.CheckEditorAccess(_htFormData);
		}
	}

	/**
	 * Initializes the object being created or edited with this editor
	 */
	protected void InitPTObject(XPHashtable _htFormData)
	{
		if ((EDITOR_OBJECTID_UNKNOWN == m_nObjectID) &&
				(EditorStartControl.EDITOR_START_FLAG_CREATE == GetEditorType()))
		{
			if (NO_PARENT == m_nParentSiteMapFolderID)
			{
				m_ptObject = (IPTObject) m_Session.GetObjectManagers(m_nClassID)
					.Create(m_nFolderID);
				m_ptObject.SetName(m_asOwner.GetString(1443, "ptmsgs_portalbrowsingmsgs"));
			}
			else
			{
				try
				{
					m_ptObject = (IPTObject) m_ptParentFolder.CreateSubfolder(m_asOwner.GetString(
								548, "ptmsgs_portalbrowsingmsgs"),
							m_asOwner.GetString(549, "ptmsgs_portalbrowsingmsgs"));
				}
				catch (Exception e)
				{
					log.Error(e, "Unable to create child folder in parent.  Either parent could not be opened, or child creation failed: " +
						e.getMessage());
				}
			}
		}
		else if (EditorStartControl.EDITOR_START_FLAG_EDIT == GetEditorType())
		{
			
			m_ptObject = (IPTObject) m_Session.GetObjectManagers(m_nClassID).Open(m_nObjectID, false);
		}

		IPTServerContext objSC = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
		m_nObjectID = objSC.GetObjectID();
	}

	/**
	 * Saves the values from the edit link page into member variables.  In this
	 * case, it actually just replaces the copy of the object we have with the
	 * one it retrieves from the plug-in section.
	 * 
	 * @param _htFormData
	 * @return int
	 */
	protected int SaveEditLinkPage(XPHashtable _htFormData)
	{
		int nPageStatus = RepostControl.PAGE_STATUS_VALID;
		
		//Save the links
		try
		{
			((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderEditorAS.STR_MVC_SITEMAP_PLUGIN)).SaveSection(_htFormData);

			m_ptObject = ((SiteMapFolderPlugInModel) m_asOwner.GetModel(SiteMapFolderEditorAS.STR_MVC_SITEMAP_PLUGIN)).GetPTObject();
		}
		catch (Exception e)
		{
			
				log.Error("SiteMapFolderModel::SaveEditLinkPage " + m_asOwner.GetString(1458, "ptmsgs_portalbrowsingmsgs") +
					e);
			
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null,
					m_asOwner.GetString(1458, "ptmsgs_portalbrowsingmsgs") + e,"");

			UIErrorHandler.RaiseError(myError,
				m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());

			nPageStatus = RepostControl.PAGE_STATUS_INVALID;
		}

		return nPageStatus;
	}

	// BEGIN ***************** helper methods ***************** 
	// END ***************** helper methods ***************** 
	private void SetStartedInSiteMap(boolean bStartedInSiteMap)
	{
		m_bStartedInSiteMap = bStartedInSiteMap;
	}
}

