package com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;

/**
 * @author John Hogan
 *
 * This interface is implemented by the Model.
 * It contains all the read-only mothods of the Model
 * accessed by the Views.
 */

public interface ISiteMapFolderPlugInModelRO
{
	/**
	 * Returns the Links
	 *
	 * @return ASQueryResultWrapper
	 */
	public XPArrayList GetLinks();
	
	/**
	 * Returns the Links sorted alphabetically
	 *
	 * @return PTSortedArrayWrapper
	 */
	public PTSortedArrayWrapper GetLinksAlphaSorted();

	/**
	 * Returns the IPTSiteMapFolder object being manipulated
	 */
	public IPTSiteMapFolder GetPTObject();

	/**
	 * Returns the objectID for the site map folder being edited
	 * @return int
	 */
	public int GetObjectID();

	/**
	 * Returns true if the site map folder is used on multiple subportals
	 * @return boolean
	 */
	public boolean IsDuplicated();
	
	/**
	 * Returns the subspace ID used by the Expert tree control.  This is used to
	 * ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 *
	 * @return String
	 */
	public String GetExpertSubSpaceID();
	
	/**
	 * Returns the subspace ID used by the Document tree control.  This is used
	 * to ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 *
	 * @return String
	 */
	public String GetDocumentSubSpaceID();

	/**
	 * Returns the subspace ID used by the Community Page tree control.  This is
	 * used to ensure that trees that already exist in memory are reused instead
	 * of recreated.
	 *
	 * @return String
	 */
	public String GetCommPageSubSpaceID();
	
	/**
	 * Returns a 2D array of strings containing all of the web link information
	 * @return String[][]
	 */
	public String[][] GetWebLinks();
	
	/**
	 * Returns the description of the web link we are working on.
	 * @return String
	 */
	public String GetWebLinkDesc();

	/**
	 * Returns the name of the web link we are working on.
	 * @return String
	 */
	public String GetWebLinkName();

	/**
	 * Returns the URL of the web link we are working on.
	 * @return String
	 */
	public String GetWebLinkURL();

	/**
	 * Returns the unique identifier for the web link that the user is
	 * currently editing (if any).  If no link is being edited, the member
	 * variable should contain an empty string.
	 *
	 * @return String
	 */
	public String GetEditedID();

	/**
	 * Helper method to return the number of links currently cached in the working list
	 * @return int
	 */
	public int GetWebLinkCount();
	
	/**
	 * Get the selected users for the tree in the "classid, object format"
	 * @return String
	 */
	public String GetSelectedUsersString();
	
	
	/**
	 * Get the selected docs and folders for the tree in the "classid, objectid"
	 * format
	 * @return String
	 */
	public String GetSelectedDirItemsAsString();
	
	/**
	 * Get the selected community pages for the tree in
	 * "communityid,pageid;communityid,pageid" format
	 * (this is how the comm page tree is set to display
	 * the locations)
	 * 
	 * @return String
	 */
	public String GetSelectedCommPagesAsString();
	
	/**
	 * Is the directory enabled for this subportal?
	 * 
	 * @return boolean
	 */
	public boolean IsDirectoryEnabled();
	
	
	/**
	 * Are communities enabled for this subportal?
	 * 
	 * @return boolean
	 */
	public boolean AreCommunitiesEnabled();
}

