package com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.sitemap.sitemappage.*;
import com.plumtree.portalpages.portlets.sitemap.prefs.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * This Control contains the repost actions for the Site Map Folder plug-in
 * section.
 *
 * @author John Hogan
 */

public class SiteMapFolderPlugInControl extends EditorHelperRepostControl
{
	/** Unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SiteMapFolderPlugInControl";

	/** Delete the selected links from the list */
	public final static int POSTTOSELF_ACTION_DELETE = 11;
	/** Detach this site map folder from other subportals that may be sharing it */
	public final static int POSTTOSELF_ACTION_DETACH = 12;
	/** Submit chosen experts from the expert choosing tree and add them to the links list */
	public final static int POSTTOSELF_ACTION_EXPERTTREESUBMIT = 13;
	/** Submit chosen pages from the Community Page choosing tree and add them to the links list */
	public final static int POSTTOSELF_ACTION_COMMPAGETREESUBMIT = 14;
	/** Cancel action - clears the temporary list of links */
	public final static int POSTTOSELF_ACTION_CANCEL = 15;
	/** Submit chosen documents or folders from the folder/document choosing tree and add them to the links list */
	public final static int POSTTOSELF_ACTION_DOCUMENTTREESUBMIT = 16;
	/** Add a web link to the working set of web links */
	public final static int POSTTOSELF_ACTION_ADDLINK = 17;
	/** Commit changes to the working set of web links */
	public final static int POSTTOSELF_ACTION_SAVELINKS = 18;
	/** Remove checked links from the working set of web links */
	public final static int POSTTOSELF_ACTION_REMOVELINKS = 19;
	/** Change a selected web link to 'Edit' mode */
	public final static int POSTTOSELF_ACTION_EDITLINK = 20;
	/** Change a selected web link to 'Edit' mode */
	public final static int POSTTOSELF_ACTION_OPENWEBLINKS = 71;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapFolderPlugInControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Performs the requested action on repost.
	 *
	 * @param _nAction
	 * @param _htFormData
	 */
	public void PerformRepostAction(int _nAction, XPHashtable _htFormData)
	{
		SiteMapPortletPrefsSortedLinksModel smPrefsSortedLinksModel = null;
		if(m_asOwner.GetModelExists(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME)) {
			smPrefsSortedLinksModel = (SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(
				SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME);
		}
		boolean bInPrefsEditor = smPrefsSortedLinksModel != null;
		
		SiteMapModel smPageModel = null;
		if(m_asOwner.GetModelExists(SiteMapModel.STR_MVC_CLASS_NAME)) {
			smPageModel = (SiteMapModel) m_asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
		}
		boolean bInSiteMapPage = smPageModel != null;
		
		switch (_nAction)
		{
			case POSTTOSELF_ACTION_DELETE:
				((SiteMapFolderPlugInModel) m_model).DeleteLinks();
				if(bInPrefsEditor) {
					smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
				}

				break;
			case POSTTOSELF_ACTION_DETACH:
				((SiteMapFolderPlugInModel) m_model).DetachLinks();
				break;
				
			case POSTTOSELF_ACTION_EXPERTTREESUBMIT:
				((SiteMapFolderPlugInModel) m_model).RefreshItemFromTree(POSTTOSELF_ACTION_EXPERTTREESUBMIT, SiteMapFolderPlugInView.EXPERT_TREE_SUBSPACE);
				if(bInPrefsEditor) {
					smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
					smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
				}
				if(bInSiteMapPage) {
					try {
						((SiteMapFolderPlugInModel) m_model).StoreLinks();
					} catch(Exception e) {
						
					}		
				}
				break;
				
			case POSTTOSELF_ACTION_DOCUMENTTREESUBMIT:
				((SiteMapFolderPlugInModel) m_model).RefreshItemFromTree(POSTTOSELF_ACTION_DOCUMENTTREESUBMIT, SiteMapFolderPlugInView.DOCUMENT_TREE_SUBSPACE);
				if(bInPrefsEditor) {
					smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
					smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
				}
				if(bInSiteMapPage) {
					try {
						((SiteMapFolderPlugInModel) m_model).StoreLinks();
					} catch(Exception e) {

					}
				}
			break;

			case POSTTOSELF_ACTION_COMMPAGETREESUBMIT:
				((SiteMapFolderPlugInModel) m_model).RefreshItemFromTree(POSTTOSELF_ACTION_COMMPAGETREESUBMIT, SiteMapFolderPlugInView.COMMPAGE_TREE_SUBSPACE);
				if(bInPrefsEditor) {
					smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
					smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
				}
				if(bInSiteMapPage) {
					try {
						((SiteMapFolderPlugInModel) m_model).StoreLinks();
					} catch(Exception e) {

					}
				}
			break;

			case POSTTOSELF_ACTION_ADDLINK:
				((SiteMapFolderPlugInModel) m_model).AddWebLink(_htFormData);
			break;

			case POSTTOSELF_ACTION_SAVELINKS:
				((SiteMapFolderPlugInModel) m_model).AddWebLink(_htFormData);
				((SiteMapFolderPlugInModel) m_model).SaveWebLinks(_htFormData);
				if(bInPrefsEditor) {
					smPrefsSortedLinksModel.AddRowsOnRepost(_htFormData);
					smPrefsSortedLinksModel.UpdateRowsOnRepost(_htFormData);
					smPrefsSortedLinksModel.DeleteRowsOnRepost(_htFormData);
				}
				if(bInSiteMapPage) {
					try {
						((SiteMapFolderPlugInModel) m_model).StoreLinks();
					} catch(Exception e) {

					}
				}

			break;
			
			case POSTTOSELF_ACTION_REMOVELINKS:
				((SiteMapFolderPlugInModel) m_model).RemoveLinks(_htFormData);

			break;
			
			case POSTTOSELF_ACTION_EDITLINK:
				((SiteMapFolderPlugInModel) m_model).EditWebLink(_htFormData);

			break;
			
			case POSTTOSELF_ACTION_CANCEL:
				((SiteMapFolderPlugInModel) m_model).ClearLinks();
				
			break;
		}
	}
}

