package com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.subportal.*;
import com.plumtree.portalpages.browsing.sitemap.linkselector.*;
import com.plumtree.portalpages.portlets.sitemap.prefs.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 * This Model contains the state of the plug-in section.
 *
 * @author Julie Fournier
 */

public class SiteMapFolderPlugInModel extends EditorHelperModel
	implements ISiteMapFolderPlugInModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.SiteMapFolderPlugInModel");


	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "SiteMapFolderPlugInModel";

	//Member variables
	/** The site map folder object being manipulated */
	private IPTSiteMapFolder m_ptObject;
	
	/** Array of links to delete from the list */
	private String[] m_arrLinkIDsToDelete = null;
	
	/** True if this site map folder is used by more than one subportal */
	private boolean m_bDuplicated = false;

	/** The identifier for the expert sub-activity space */
	private String m_strExpertSubSpaceID = "";
	
	/** The identifier for the Document sub space */
	private String m_strDocumentSubSpaceID = "";
	
	/** The identifier for the Community Pages sub space */
	private String m_strCommPageSubSpaceID = "";
	
	/** Temporary storage for the name of the link being actively edited */
	private String m_strWebLinkName= "";
	
	/** Temporary storage for the description of the link being actively edited */
	private String m_strWebLinkDesc= "";
	
	/** Temporary storage for the URL of the link being actively edited */
	private String m_strWebLinkURL= "";

	/** Member variable to store the unique ID of the link being edited (if any) */
	private String m_strEditedID = "";
	
	/** this object holds the temporary links and stores them when needed */
	private SiteMapLinkContainer linkContainer;

	/**
	 * This class is the data storage format for a web link
	 *
	 * @author johnh
	 *
	 */
	static class WebLink
	{
		/** A unique identifier for the link */
		public String strID;

		/** The name for the web link */
		public String strName;

		/** The description for the web link */
		public String strDesc;

		/** The URL for the web link */
		public String strWebURL;
	}


	// BEGIN ***************** repost action methods ***************** 
	/**
	 *  Deletes the links selected in the tree
	 */
	public void DeleteLinks()
	{
		if (m_arrLinkIDsToDelete != null)
		{
			for (int i = 0; i < m_arrLinkIDsToDelete.length; i++)
			{
				XPStringTokenizer myTokenizer = new XPStringTokenizer(m_arrLinkIDsToDelete[i], ",");
				int nType = XPConvert.ToInteger(myTokenizer.GetNextToken());
				int nObjectID = XPConvert.ToInteger(myTokenizer.GetNextToken());
				
				linkContainer.DeleteLink(nType, nObjectID);
			}

			m_arrLinkIDsToDelete = null;
		}
	}

	/**
	 * This method gets the selected items from the tree, setting member
	 * variables for ObjectID and name of the object selected.  It is called
	 * on repost.
	 *
	 * @param intObjectType intObjectType - equal to the corresponding repost
	 * action
	 */
	public void RefreshItemFromTree(int intObjectType, String strSubSpaceID)
	{
		if (m_asOwner.GetSubSpaceExists(strSubSpaceID))
		{
			AActivitySpace asTree  = m_asOwner.GetSubSpace(strSubSpaceID);
			ITreeModelRO treeModel = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList itemList   = treeModel.GetSelectedItems();
	
			try
			{					
				switch (intObjectType)
				{
					case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_EXPERTTREESUBMIT:
						linkContainer.ProcessUserData(itemList, m_asOwner);
						break;
					case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_COMMPAGETREESUBMIT:
						linkContainer.ProcessCommPageData(itemList, m_asOwner);	
						break;
					case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_DOCUMENTTREESUBMIT:
						linkContainer.ProcessDirectoryData(itemList, m_asOwner);	
						break;
					default:
						// shouldn't get here
				}				
			}
			catch (Exception e)
			{
				XPStringBuilder sb = new XPStringBuilder(100);
				sb.Append(m_asOwner.GetString(1493,
								"ptmsgs_portalbrowsingmsgs")).Append(e);
				
				log.Error(e, "SiteMapFolderPlugInModel::SaveWebLinks " + sb.ToString());
				
				UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER, null, sb.ToString(),
						sb.ToString());
				UIErrorHandler.RaiseError(myError,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
			
		}
	}

	/**
	 * This function clones the site map folder that is attached to a subportal
	 * and replaces the working copy with the clone.  This allows for the case
	 * where a subportal is copied, but the user does not wish to share the
	 * mandatory links.
	 * 
	 * @author JohnH
	 */
	public void DetachLinks()
	{
		try
		{
			IPTObjectManager objMan = ((IPTSession) m_asOwner.GetUserSession()).GetSiteMapFolders();
			int intNewSMFolderID;
			int intParentFolderID = m_ptObject.GetParentFolderID();
			
			if ( 0 == intParentFolderID )
			{
				intParentFolderID = 2;
			}

			intNewSMFolderID = objMan.Clone( ((IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext")).GetObjectID(), intParentFolderID);
			
			//save the old ptObject
			IPTSiteMapFolder oldPTObject= m_ptObject;
			
			m_ptObject = (IPTSiteMapFolder) objMan.Open(intNewSMFolderID, false);
			CopyLinks(m_ptObject, oldPTObject);
			
			// Set this to false since this subportal has its own copy now.
			m_bDuplicated = false;
			

		}
		catch (Exception e)
		{
			log.Error(e, "Error detaching links.");

			XPStringBuilder sb = new XPStringBuilder(100);
			if ( (e instanceof PTException) )
			{
				sb.Append(m_asOwner.GetString(1485,
								"ptmsgs_portalbrowsingmsgs")).Append(((PTException)e).GetMessage());
	
				UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER, null, sb.ToString(),
						sb.ToString());
				UIErrorHandler.RaiseError(myError,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
			else
			{
				sb.Append(m_asOwner.GetString(1485,
								"ptmsgs_portalbrowsingmsgs")).Append(e);

				UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER, null, sb.ToString(),
						sb.ToString());
				UIErrorHandler.RaiseError(myError,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
		}

	}
	
	
	/**
		 * This function clones links from source site map folder to destination site map folder.
		 * 
		 * @author DavidWi
		 */
	public void CopyLinks(IPTSiteMapFolder _siteMapFolderDest, IPTSiteMapFolder _siteMapFolderSrc ){
		
		IPTQueryResult queryResult= _siteMapFolderSrc.QueryLinks(); 
		
		
		for(int i=0; i< queryResult.RowCount(); i++){
				//process link and add it to the new one	
				IPTSiteMapLink link= _siteMapFolderDest.CreateLink();
		
				int nType = queryResult.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID);
				int objectID = queryResult.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);

				switch (nType) {
					case PT_CLASSIDS.PT_PAGE_ID :
						int commID = queryResult.ItemAsInt(i,PT_PROPIDS.PT_PROPID_SITEMAP_LINKPAGEID);
											
						link.SetLinkClassID(PT_CLASSIDS.PT_COMMUNITY_ID);
						link.SetLinkObjectID(commID);
						link.SetLinkPageID(objectID);

						break;

					case PT_CLASSIDS.PT_USER_ID :
						link.SetLinkClassID(PT_CLASSIDS.PT_USER_ID);
						link.SetLinkObjectID(objectID);

						break;

					case PT_CLASSIDS.PT_CATALOGCARD_ID :
						link.SetLinkClassID(PT_CLASSIDS.PT_CATALOGCARD_ID);
						link.SetLinkObjectID(objectID);
						break;
						
					case PT_CLASSIDS.PT_CATALOGFOLDER_ID :
						link.SetLinkClassID(PT_CLASSIDS.PT_CATALOGFOLDER_ID);
						link.SetLinkObjectID(objectID);
						
						break;

					case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID :
						String strWebURL =queryResult.ItemAsString(i,PT_PROPIDS.PT_PROPID_SITEMAP_LINKURL);
						String strName = queryResult.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
						String strDesc =queryResult.ItemAsString(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
							
						link.SetLinkClassID(PT_CLASSIDS.PT_SITEMAPWEBLINK_ID);
						link.SetName(strName);
						link.SetDescription(strDesc);
						link.SetLinkURL(strWebURL);

						break;

					default :
						log.Error("Invalid Link Type");
				}
		
			
			try {
				link.Store();
			} catch (Exception e) {
				throw new XPException("Unable to store link while copying links.", e);
			}
		}		
				
	}
	
	/**
	 * Repost action method for adding a link being edited to the array of links
	 * being actively worked on.
	 */
	public void AddWebLink(XPHashtable _htFormData)
	{
		String[] data;
		//Get the currently active web link information - name, desc, URL
		data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_LINKNAME);
		if ((null != data) && !(0 == data.length))
		{
			/*if (data[0].equals(""))
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null,
					m_asOwner.GetString(1491, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1491, "ptmsgs_portalbrowsingmsgs"));
				UIErrorHandler.RaiseError(myError,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
			else
			{*/
				m_strWebLinkName = data[0];
			//}
		}

		data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_LINKDESC);
		if ((null != data) && !(0 == data.length))
		{
			m_strWebLinkDesc = data[0];
		}

		data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_LINKURL);
		if ((null != data) && !(0 == data.length))
		{
			/*if (data[0].equals(""))
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null,
					m_asOwner.GetString(1492, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1492, "ptmsgs_portalbrowsingmsgs"));
				UIErrorHandler.RaiseError(myError,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}
			else
			{*/
				m_strWebLinkURL = data[0];
			//}
		}

		/*WebLink myLink = new WebLink();
		myLink.strID = XPConvert.ToString(arrWebLinks.GetSize());
		myLink.strName = m_strWebLinkName;
		myLink.strDesc = m_strWebLinkDesc;
		myLink.strWebURL = m_strWebLinkURL;

		arrWebLinks.Add(myLink);
		*/
		
		if(!("").equals(XPStringUtility.Trim(m_strWebLinkName)) && !("").equals(XPStringUtility.Trim(m_strWebLinkURL)))
		{
			linkContainer.ProcessWebLinkData(m_strWebLinkName, m_strWebLinkDesc, m_strWebLinkURL);
		}
	}

	/**
	 * This method commits the current working set of web links to the Plumtree
	 * object
	 */
	public void SaveWebLinks(XPHashtable _htFormData)
	{
		if(!("").equals(GetEditedID()))
		{
			WebLink myLink = new WebLink();
				
			String[] data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_EDITLINKNAME);
			if (data != null && !(data[0].equals("")))
			{
				myLink.strName = data[0];
			}
			data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_EDITLINKDESC);
			if (data != null)
			{
				myLink.strDesc = data[0];
			}
			else //this is the only one that can legitimately be null.  The others we just leave the same
			{
				myLink.strDesc = "";					
			}
			data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_EDITLINKURL);
			if (data != null  && !(data[0].equals("")) )
			{
				myLink.strWebURL = data[0];
			}
			
			int intIndex = XPConvert.ToInteger(GetEditedID()); 
			linkContainer.EditWebLink(intIndex, myLink.strName, myLink.strDesc, myLink.strWebURL);			
		}
		SetEditedID("");
	}

	/**
	 * This repost function removes links from the temporary working set.  These
	 * changes are not committed until SaveWebLinks() is called.
	 * @param _htFormData
	 */
	public void RemoveLinks(XPHashtable _htFormData)
	{
		String[] data;
		data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLCHECKBOX_WEBLINK);

		if (data != null)
		{
			for (int i = 0; i < data.length; i++)
			{
				linkContainer.DeleteWebLink(XPConvert.ToInteger(data[i]));
			}
		}
	}
	
	/**
	 * This repost method sets the m_strEditedID member variable, which is read
	 * by the view.  When the view displays the link row whose unique identifier
	 * matches this value, the row is displayed in 'Edit' mode, i.e. with an
	 * input text box rather than a span.
	 * 
	 * @param _htFormData - The HTML data coming back from the view
	 */
	public void EditWebLink(XPHashtable _htFormData)
	{
		String[] data;
		data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLCHECKBOX_WEBLINK);
		int intIndex = XPConvert.ToInteger(data[0]);

		if ( (data[0] != null) && (m_strEditedID.equals("")) )
		{
			//Just get the first one in the array - there shouldn't be more than one anyway
			SetEditedID(data[0]);
		}
		else
		{
			//WebLink myLink = (WebLink) arrWebLinks.GetElement(intIndex);
			//Also refresh the item in the array
			WebLink myLink = new WebLink();
				
			data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_EDITLINKNAME);
			if (data != null && !(data[0].equals("")))
			{
				myLink.strName = data[0];
			}
			data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_EDITLINKDESC);
			if (data != null)
			{
				myLink.strDesc = data[0];
			}
			else //this is the only one that can legitimately be null.  The others we just leave the same
			{
				myLink.strDesc = "";					
			}
			data = (String[]) _htFormData.GetElement(SiteMapCreateWebLinkView.HTMLINPUT_EDITLINKURL);
			if (data != null  && !(data[0].equals("")) )
			{
				myLink.strWebURL = data[0];
			}
			
			if(m_strEditedID.equals(XPConvert.ToString(intIndex)))
			{
				SetEditedID("");
			} else {
				String strOldIndex = XPConvert.ToString(intIndex);
				intIndex = XPConvert.ToInteger(m_strEditedID);
				SetEditedID(strOldIndex);
			}
			
			linkContainer.EditWebLink(intIndex, myLink.strName, myLink.strDesc, myLink.strWebURL);
		}

	}
	
	public XPArrayList GetNewlyAddedLinks()
	{
		return linkContainer.GetNewlyAddedLinks();	
	}
	
	public void ClearNewlyAddedLinks()
	{
		linkContainer.ClearNewlyAddedLinks();
	}
	
	public XPArrayList GetUpdatedWebLinks()
	{
		return linkContainer.GetUpdateWebLinks();
	}

	public void ClearUpdatedWebLinks()
	{
		linkContainer.ClearUpdateWebLinks();
	}
	
	public XPArrayList GetDeletedLinks()
	{
		return linkContainer.GetDeletedLinks();
	}

	public void ClearDeletedLinks()
	{
		linkContainer.ClearDeletedLinks();
	}	
	
	/**
	 * This repost function clears the list of web links (in reverse order) 
	 */
	public void ClearLinks()
	{
		/*for (int i = (arrWebLinks.GetSize() - 1); i >= 0; i-- )
		{
			arrWebLinks.RemoveAt(i);
		}*/
	}
	
	// END ***************** repost action methods *****************

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapFolderPlugInModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	// BEGIN ***************** helper methods ***************** 

	/**
	 * Returns the IPTSiteMapFolder object being manipulated
	 */
	public IPTSiteMapFolder GetPTObject()
	{
		return m_ptObject;
	}
	
	/**
	 * Returns a queryresult wrapper with the list of links associated with the
	 * object being edited
	 * 
	 */
	public XPArrayList GetLinks()
	{
		return linkContainer.GetAllLinks();
	}
	
	/* (non-Javadoc)
     * @see com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.ISiteMapFolderPlugInModelRO#GetLinksAlphaSorted()
     */
    public PTSortedArrayWrapper GetLinksAlphaSorted() 
    {
        return linkContainer.GetAllLinksAlphaSorted();
    }

	// END ***************** helper methods ***************** 

	/**
	 * To initialize this plug-in you need to set the DP name
	 * and the default value of the plug-in setting.
	 *
	 * @param _sPlugInSetting
	 */
	public void InitializePlugIn(IPTSiteMapFolder _SiteMapFolder)
	{
		m_ptObject = _SiteMapFolder;
        if (m_ptObject.GetLockState() == PT_LOCKSTATES.PT_NEWLYCREATED) {
            linkContainer = new SiteMapLinkContainer(null);
        } else {
            linkContainer = new SiteMapLinkContainer(m_ptObject.QueryLinks());
        }
		ASQueryResultWrapper qrSubPortals = null;
		if(m_asOwner.GetName().equals(SubPortalAS.STR_MVC_CLASS_NAME)) 
		{
			try
			{
				IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
				Object[][] myFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_SUBPORTAL_MANDATORYLINKSID, PT_FILTEROPS.PT_FILTEROP_EQ, new Integer(((IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext")).GetObjectID()));
				
				qrSubPortals = 
					new ASQueryResultWrapper(ptSession.GetSubPortals().Query(PT_PROPIDS.PT_PROPID_OBJECTID,-1,PT_PROPIDS.PT_PROPID_NAME,0,-1,myFilter));
			}
			catch (Exception e)
			{
				XPStringBuilder sb = new XPStringBuilder(100);
				if ( (e instanceof PTException) )
				{
					sb.Append(m_asOwner.GetString(1486,
									"ptmsgs_portalbrowsingmsgs")).Append(((PTException)e).GetMessage());

					log.Warn(e, "SiteMapFolderPlugInModel::InitializePlugIn " + sb.ToString());

					m_bDuplicated = false;
				}
				else
				{
					sb.Append(m_asOwner.GetString(1486,
									"ptmsgs_portalbrowsingmsgs")).Append(e);

					log.Warn(e, "SiteMapFolderPlugInModel::InitializePlugIn " + sb.ToString());

					m_bDuplicated = false;
				}
			}
		}			
		if ( (null != qrSubPortals) && (qrSubPortals.GetCount() > 1) )
		{
			m_bDuplicated = true;
		}
		else
		{
			m_bDuplicated = false;
		}	
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 * @return int Status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		String[] data;
		int intReturnValue = RepostControl.PAGE_STATUS_VALID;
		
		String strCheckboxLookup = SiteMapFolderPlugInView.HTMLCHECKBOX_DELROW;
		if(m_asOwner.GetName().equals(SiteMapPortletPrefsEditorAS.STR_MVC_CLASS_NAME)) 
		{
			SiteMapPortletPrefsSortedLinksModel sortedLinksModel = (SiteMapPortletPrefsSortedLinksModel) m_asOwner.GetModel(SiteMapPortletPrefsSortedLinksModel.STR_MVC_CLASS_NAME);
			strCheckboxLookup = sortedLinksModel.GetUniqueString(SiteMapFolderPlugInView.HTMLCHECKBOX_DELROW);
		}
		
		data = (String[]) _htFormData.GetElement(strCheckboxLookup); 

		if (data != null)
		{
			m_arrLinkIDsToDelete = new String[data.length];

			for (int i = 0; i < data.length; i++)
			{
				m_arrLinkIDsToDelete[i] = data[i];
			}
		}

		data = (String[]) _htFormData.GetElement(SiteMapFolderPlugInView.HTMLHIDDEN_EXPERT_SPACE);

		if ((null != data) && !(0 == data.length))
		{
			SetExpertSubSpaceID(data[0]);
		}

		data = (String[]) _htFormData.GetElement(SiteMapFolderPlugInView.HTMLINPUT_FOLDERNAME);

		if ((null != data) && !(0 == data.length))
		{
			m_ptObject.SetName(data[0]);
		}

		return intReturnValue;
	}

	public void StoreLinks()
	{
		linkContainer.StoreAll(m_ptObject);
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.ISiteMapFolderPlugInModelRO#IsDirectoryEnabled()
	 */
	public boolean IsDirectoryEnabled()
	{
		if(m_asOwner.GetName().equals(SubPortalAS.STR_MVC_CLASS_NAME)) {
			SubPortalModel subPortalModel = (SubPortalModel) m_asOwner.GetModel(SubPortalModel.STR_MVC_CLASS_NAME);
			return ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS & subPortalModel.GetAccessType()) != 0);
		} else {
			IPTSession objSession = (IPTSession) m_asOwner.GetUserSession();
			IPTSubPortalInfo subPortalInfo = objSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
			return ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS & subPortalInfo.GetAccessType()) != 0);
		}	
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.ISiteMapFolderPlugInModelRO#AreCommunitiesEnabled()
	 */
	public boolean AreCommunitiesEnabled()
	{
		if(m_asOwner.GetName().equals(SubPortalAS.STR_MVC_CLASS_NAME)) {
			SubPortalModel subPortalModel = (SubPortalModel) m_asOwner.GetModel(SubPortalModel.STR_MVC_CLASS_NAME);
			return ((PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS & subPortalModel.GetAccessType()) != 0);
		} else {
			// no need to do check here because communities must be enabled to be
			// visiting community knowledge directory or prefs page for community links portlet
			return true;	
		}
	}

	/**
	 * Returns the objectID for the site map folder being edited
	 * @return int
	 */
	public int GetObjectID() 
	{	
		IPTServerContext myContext;
		myContext = (IPTServerContext) m_ptObject.GetInterfaces("IPTServerContext");
		
		return myContext.GetObjectID();
	}

	public String GetSelectedUsersString()
	{
		return linkContainer.GetSelectedUsersAsStringForTree();
	}			

	public String GetSelectedDirItemsAsString()
	{
		return linkContainer.GetSelectedDirItemsAsStringForTree();	
	}
	
	public String GetSelectedCommPagesAsString()
	{
		// PageName and Community Names are removed from the returned string of this
		// method, because the Location is stored differently when the Links are saved
		// In order to compare and locate the Leaf location properly in the Tree, Only CommunityID
		// and ObjectID are provided for each selected Item, So the string returned will be as follows
		// communityID1,ObjectID1;communityID2,ObjectID2
		
		String selComPages = linkContainer.GetSelectedCommPagesAsStringForTree();
		XPStringTokenizer pgList = new XPStringTokenizer(selComPages, ";");
				
		if(pgList.GetTokenCount() > 0 ){
			
			XPStringBuilder newComString = new XPStringBuilder();
			
			while (pgList.HasMoreElements()){
			XPStringTokenizer tok = new XPStringTokenizer(pgList.GetNextElement(), ",");
				for (int i = 0; i < 2 ; i ++)
				{				
					newComString.Append(tok.GetNextElement()).Append( (i == 0) ? "," : ";");				
				}
			}
			if(newComString.GetLength() == 0)
			{
				return "";
			}
			else
			{
				return newComString.Substring(0, newComString.GetLength() -1 );
			}
			
		}
		else 
		{
			return selComPages;
		}
	}

	/**
	 * Returns true if the site map folder is used on multiple subportals
	 * @return boolean
	 */
	public boolean IsDuplicated() {
		return m_bDuplicated;
	}

	/**
	 * Returns the subspace ID used by the Expert tree control.  This is used to
	 * ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 *
	 * @return String
	 */
	public String GetExpertSubSpaceID()
	{
		return m_strExpertSubSpaceID;
	}

	/**
	 * Returns the subspace ID used by the Expert tree control.  This is used to
	 * ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 * @param __strExpertSubSpaceID The subspace id being set
	 */
	public void SetExpertSubSpaceID(String _strExpertSubSpaceID)
	{
		m_strExpertSubSpaceID = _strExpertSubSpaceID;

		
			log.Debug("SiteMapFolderPlugInModel::SetExpertSubSpaceID succeeded.  New value: " +
			_strExpertSubSpaceID);
		
	}

	/**
	 * Returns the subspace ID used by the Document tree control.  This is used
	 * to ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 *
	 * @return String
	 */
	public String GetDocumentSubSpaceID()
	{
		return m_strDocumentSubSpaceID;
	}

	/**
	 * Returns the subspace ID used by the Document tree control.  This is used
	 * to ensure that trees that already exist in memory are reused instead of
	 * recreated.
	 * @param __strExpertSubSpaceID The subspace id being set
	 */
	public void SetDocumentSubSpaceID(String _strDocumentSubSpaceID)
	{
		m_strDocumentSubSpaceID = _strDocumentSubSpaceID;

		
			log.Debug("SiteMapFolderPlugInModel::SetDocumentSubSpaceID succeeded.  New value: " +
			_strDocumentSubSpaceID);
		
	}

	/**
	 * Returns the subspace ID used by the Community Page tree control.  This is
	 * used to ensure that trees that already exist in memory are reused instead
	 * of recreated.
	 *
	 * @return String
	 */
	public String GetCommPageSubSpaceID()
	{
		return m_strCommPageSubSpaceID;
	}

	/**
	 * Returns the subspace ID used by the Community Page tree control.  This is
	 * used to ensure that trees that already exist in memory are reused instead
	 * of recreated.
	 * @param __strCommPageSubSpaceID The subspace id being set
	 */
	public void SetCommPageSubSpaceID(String _strCommPageSubSpaceID)
	{
		m_strCommPageSubSpaceID = _strCommPageSubSpaceID;

		
			log.Debug("SiteMapFolderPlugInModel::SetCommPageSubSpaceID succeeded.  New value: " +
			_strCommPageSubSpaceID);
		
	}
	
	/**
	 * Returns a 2D array of strings containing all of the web link information
	 * @return String[][]
	 */
	public String[][] GetWebLinks()
	{
		return linkContainer.GetWebLinks();
	}
	
	/**
	 * Helper method to return the number of links currently cached in the working list
	 * @return int
	 */
	public int GetWebLinkCount()
	{
		return linkContainer.GetWebLinks().length;
	}
	
	/**
	 * Returns the description of the web link we are working on.
	 * @return String
	 */
	public String GetWebLinkDesc() {
		return m_strWebLinkDesc;
	}

	/**
	 * Returns the name of the web link we are working on.
	 * @return String
	 */
	public String GetWebLinkName() {
		return m_strWebLinkName;
	}

	/**
	 * Returns the URL of the web link we are working on.
	 * @return String
	 */
	public String GetWebLinkURL() {
		return m_strWebLinkURL;
	}

	/**
	 * Sets the desccription of the URL we are working on.
	 * @param desc The description to set
	 */
	public void SetWebLinkDesc(String desc) {
		m_strWebLinkDesc = desc;
	}

	/**
	 * Sets the name of the link we are working on.
	 * @param name The name to Set
	 */
	public void SetWebLinkName(String name) {
		m_strWebLinkName = name;
	}

	/**
	 * Sets the URL of the link we are working on.
	 * 
	 * @param webURL The URL to Set
	 */
	public void SetWebLinkURL(String webURL) {
		m_strWebLinkURL = webURL;
	}

	/**
	 * Returns the unique identifier for the web link that the user is
	 * currently editing (if any).  If no link is being edited, the member
	 * variable should contain an empty string.
	 * 
	 * @return String
	 */
	public String GetEditedID() {
		return m_strEditedID;
	}

	/**
	 * Sets the unique identifier for the web link that the user is currently
	 * editing (if any).  If no link is being edited, the member variable should
	 * contain an empty string.
	 * 
	 * @param editedID The editedID to set
	 */
	public void SetEditedID(String editedID) {
		m_strEditedID = editedID;
	}

}

