package com.plumtree.portalpages.browsing.editors.smartsort;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.migrationhistory.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectsecurity.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Smart Sort Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author OlegS
 */
public class SmartSortEditorAS extends ObjEditorAS
{
	
	public static final String STR_MVC_CLASS_NAME = "SmartSortEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SmartSortEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{	
		if (EditorStartControl.EDITOR_START_FLAG_CREATE == ((EditorModel) GetModel(
			m_strModelName)).GetEditorType())
		{
			return (GetString(551, "ptmsgs_portalbrowsingmsgs"));
		}
		else
		{
			return (XPResourceManager.FormatMessage(GetString(1709, "ptmsgs_portalbrowsingmsgs"), GetObjectName()));
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Smart Sort Editor Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SmartSortEditorRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = SmartSortEditorModel.STR_MVC_CLASS_NAME;

		// Warning: m_myModel must be initialized before super.Init() is called.
		super.Init();

		/* job is auto created
		// Register plug-in sections
		RegisterPage(new SetJobDP());
		
		// Register classes for the set job and for the object owner
		RegisterModel(SetJobModel.STR_MVC_CLASS_NAME);
		RegisterControl(SetJobRepostControl.STR_MVC_CLASS_NAME,GetModel(SetJobModel.STR_MVC_CLASS_NAME));
		RegisterView(ObjectOwnerView.STR_MVC_CLASS_NAME,GetModel(SetJobModel.STR_MVC_CLASS_NAME));
		
		// Register classes for Job selector
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
			GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB,
			GetModel(SetJobModel.STR_MVC_STORAGE_NAME_SELECT_JOB));
		*/

		IModel myModel = GetModel(SmartSortEditorModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new SmartSortEditorMainDP());

		// Register Views
		RegisterView(SmartSortEditorMainView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(SmartSortEditorRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Set default page
		// (It will be the page selected by default when the user starts the Editor).
		SetCurrentPage(SmartSortEditorMainDP.STR_MVC_CLASS_NAME);

		// set left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(553,
					"ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			SmartSortEditorMainDP.STR_MVC_CLASS_NAME);

		/* job is auto created
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SetJobDP.STR_MVC_CLASS_NAME);
		*/
		
		// BEGIN Sub menu "Standard Settings"

		int nMenuTwoID = m_mEditorMenu.StartNewSubMenu(GetString(1242, "ptmsgs_portalbrowsingmsgs"));

		//Properties and Names
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, LocNamesDP.STR_MVC_CLASS_NAME);
		//Security
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, ObjectSecurityDP.STR_MVC_CLASS_NAME);
		//Migration History
		m_mEditorMenu.AddLinkToSubMenu(nMenuTwoID, MigrationHistoryPluginDP.STR_MVC_CLASS_NAME);

		// END Sub menu "Standard Settings"

		// END Sub menu "Properties"
		this.SetHelpTopic("PT_Smartsort_MainSettings");
	}
	
	/**
	* @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	* @param IDisplayPage the current Display Page
	*/
	public void SetCurrentPage(IDisplayPage page)	{
		super.SetCurrentPage(page);
		String sPageName=page.GetName();
		if(SmartSortEditorMainDP.STR_MVC_CLASS_NAME.equals(sPageName))
			SetHelpTopic("PT_SmartSort_MainSettings");
		/* job is auto created
		else if(SetJobDP.STR_MVC_CLASS_NAME.equals(sPageName))
			SetHelpTopic("PT_SetJob");
		*/
	}
}

