package com.plumtree.portalpages.browsing.editors.userprofile;

import com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 * @author jennifersu
 * This is the General Profile Display Page that will be used to display all of
 * the Profile Sections.   It will retrieve the title and
 * names from the different sections.
 *
 */
public class GeneralProfileDP extends EditorDP
{
	/** object name it is overridden below**/
	public String STR_MVC_CLASS_NAME = "GeneralProfile";

	/** object title - it is overridden below **/
	public String _ui_PageTitle = "";

	/** This is the IPTProfilePage that is passed in for the first time and contains all the Sections */
	protected IPTProfilePage m_profilePage = null;

	/** This is the index of the specific view which contains all the Sections */
	protected int m_profilePageIndex = 0;

	/** Flag used to update mandatory page status only the first time the left nav string is retrieved */
	protected boolean bFirstTimeOnPage = true;

    private String subHeaderResourceStr = null;


    /**
     * We need to have a constructor that takes in the IPTProfilePage object associated
     * with this Display Page.
     * @param subHeaderResourceStr The
     */
    public GeneralProfileDP(IPTProfilePage profilepage, int index, String name, String uiName, String subHeaderResourceStr)
    {
        super();
        m_profilePage = profilepage;
        m_profilePageIndex = index;
        STR_MVC_CLASS_NAME = name;

        _ui_PageTitle = uiName;

        this.subHeaderResourceStr = subHeaderResourceStr;
    }



	/**
	 * Displays some HTML after the body tag and before the form tag. For
	 * example this is used by pages using a DHTML calendar to display the div
	 * tag. The function is optional.  If it exists, it will be called by the
	 * framework, and the resulting HTMLElement will be added in the right
	 * place.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm() throws HTMLException
	{
		IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + "0");

		return iModelRO.GetDateTimePickerControlManager().GetPagePreFormContent();
	}

	/**
	 * Returns the HTML that is placed in the HEAD section of this HTML page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	public HTMLElementCollection DisplayHTMLinHEAD() throws HTMLException
	{
		IExpListPropModelRO iModelRO = (IExpListPropModelRO) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + "0");
	
		if (m_asOwner.GetAccessStyle().equals(AccessStyles.STANDARD))
		{
			return iModelRO.GetDateTimePickerControlManager().GetJSIncludes();
		}
		return null;
	}

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		// Update mandatory page status the first time left nav string is retrieved.
		UpdateMandatoryPageStatus();

		return _ui_PageTitle;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Implement this method to add HTML below the sub header.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	protected HTMLElement GetHTMLBelowSubHeader() throws HTMLException
	{
        if(subHeaderResourceStr == null)
        {
            // Safety. subHeaderResourceStr should always be non-null but we prevent it from being so.
            subHeaderResourceStr = m_asOwner.GetString(1804, ResourceConstants.PORTALBROWSINGMSGS);
        }
        return HTMLConstructHelpers.GetSubHeader(subHeaderResourceStr, m_asOwner);
	}

	/**
	 * Returns the Profile Page that contains all of the section and property
	 * information.
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public IPTProfilePage GetProfilePage()
	{
		return m_profilePage;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetProfilePageIndex()
	{
		return m_profilePageIndex;
	}

	/**
	 * Dynamically update mandatory page status. In this case, all of the Profile Sections
	 * to see if there are any mandatory properties.
	 */
	public void UpdateMandatoryPageStatus()
	{
		if (bFirstTimeOnPage)
		{
			boolean bPageIsMandatory = false;

			Object[] arSectionIDs = m_profilePage.GetChildSections();
			for (int indSection = 0; indSection < arSectionIDs.length; indSection++)
			{
				IObjPropModelRO iModel = (IObjPropModelRO) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + indSection);

				if (iModel.CheckDisplayPageIsMandatory())
				{
					bPageIsMandatory = true;
				}
			}

			((EditorAS) m_asOwner).GetLeftMenu().SetMandatoryPage(bPageIsMandatory, GetName());

			bFirstTimeOnPage = false;
		}
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay() throws HTMLException
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		// set the profile page so that the model knows which page to save
		UserProfileModel profileModel = (UserProfileModel) m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName);
		profileModel.SetCurrentProfilePage(m_profilePageIndex);

		// loop through the page and add the various sections as EditorViews
		Object[] arSectionIDs = m_profilePage.GetChildSections();
		for (int indSection = 0; indSection < arSectionIDs.length; indSection++)
		{
			// store the section in the XPHashtable
			views.AddInnerHTMLElement(((GeneralInfoView) m_asOwner.GetView(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + indSection)).Display());

			// add a spacer table if there are more sections
			if ((indSection + 1) < arSectionIDs.length)
			{
				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
			}
		}

		result.AddInnerHTMLElement(CreateLeftNavBar(views));
		
		if (AccessStyles.STANDARD != m_asOwner.GetAccessStyle())
		{
			m_asOwner.GetLeftMenu().RemovePageFromMandatoryArray(m_asOwner.GetCurrentPage().GetName());
		}

		return result;
	}

	/**
	 * Display the Javascripts for the Views.
	 *
	 * @return HTMLScriptCollection
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild() throws HTMLException
	{
		HTMLScriptCollection myScripts = super.DisplayJavaScriptFromChild();

		Object[] arSectionIDs = m_profilePage.GetChildSections();
		for (int indSection = 0; indSection < arSectionIDs.length; indSection++)
		{
			myScripts.AddInnerHTMLElement(m_asOwner.GetView(UserProfileEditorAS.m_strUserProfileObjEdit + m_profilePageIndex + indSection).DisplayJavascript());
		}

		return myScripts;
	}
}

