package com.plumtree.portalpages.browsing.editors.userprofile;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author DanD, JenniferSu
 */
public class UserProfileEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.userprofile.UserProfileEditorAS");

	private static final String sClassName = "com.plumtree.portalpages.browsing.editors.userprofile.UserProfileEditorAS";

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "UserProfileEditor";

	/** member variable describing the user profile object editor **/
	public static final String m_strUserProfileObjEdit = "ObjectEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserProfileEditorAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 */
	public String GetEditorTitle()
	{
		return (GetString(577, "ptmsgs_portalbrowsingmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (UserProfileRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = UserProfileModel.STR_MVC_CLASS_NAME;

		super.Init();
		
		UserProfileModel myModel = (UserProfileModel)GetModel(m_strModelName);

		RegisterControl(UserProfileRepostControl.STR_MVC_CLASS_NAME, myModel);

		InitProfilePages();
		
		if (GetAccessStyle() != AccessStyles.STANDARD)
		{
			// register view that displays list of dynamic Display Pages
			RegisterView(ProfilePageListView_D.STR_MVC_CLASS_NAME, myModel);
		}

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass(sClassName);

				int iTitleId = 105;
				int iTipId = 106;
				int iSecondaryTipId = 107;

				tm.SetTipTitle(this.GetString(iTitleId, com.plumtree.portalpages.common.constants.ResourceConstants.TIPS));

				HTMLGenericElement e = new HTMLGenericElement(this.GetString(iTipId, com.plumtree.portalpages.common.constants.ResourceConstants.TIPS));

				tm.SetTip(e);

				String sSecondary = this.GetString(iSecondaryTipId, com.plumtree.portalpages.common.constants.ResourceConstants.TIPS);

				if (!("none_do_not_translate".equals(sSecondary)))
				{
					e = new HTMLGenericElement(sSecondary);

					tm.SetSecondarTip(e);
				}
			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}

		//	Got the tips model
		this.SetHelpTopic("PT_EditUserProfile_MainSettings");
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		// make sure this is not the guest user
		boolean isGuest = PlumtreeHelpers.IsGuestSession(this);
		if (isGuest)
		{
			return false;
		}
		IPTSessionInfo sessionInfo = ((IPTSession)GetUserSession()).GetSessionInfo();
		if (!sessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_OWN_PROFILE))
		{
			return false;
		}
		
		return true;
	}	
	
	/**
	 * Registers all necessary classes for each profile page.
	 *
	 */
	private void InitProfilePages()
	{
		UserProfileModel myModel = (UserProfileModel)GetModel(m_strModelName);

		XPArrayList alPortlets = new XPArrayList();
		String sStartPage = "";

		//Sets left nav menu the adding of the names will be done in the loop
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(578, "ptmsgs_portalbrowsingmsgs"));

		XPArrayList xpalProfilePages = myModel.GetProfilePages();
		IPTObjectManager profileSectionMgr = ((IPTSession)GetUserSession()).GetProfileSections();
		if (xpalProfilePages != null)
		{
			int nPageCounter = 0;
			for (int indPage = 0; indPage < xpalProfilePages.GetSize(); indPage++)
			{
				IPTProfilePage ptProfilePage = (IPTProfilePage)xpalProfilePages.GetElement(indPage);
				IPTGadget portlet = myModel.LookupPortlet(ptProfilePage);
				int portletID = portlet.GetObjectID();
				Object[] arProfileSections = ptProfilePage.GetChildSections();
				if (arProfileSections.length < 1)
				{
					continue;
				}

				IPTProfileSection ptProfileSection;
				UserProfileObjEditModel myObjEditorModel = null;

				// Register DisplayPages
                GeneralProfileDP userProfileDP
                    = new GeneralProfileDP(
                        ptProfilePage, 
                        nPageCounter,
                        "portlet_" + portletID,
                        portlet.GetLocalizedName(),
                        GetString(1804, ResourceConstants.PORTALBROWSINGMSGS));
                RegisterPage(userProfileDP, "portlet_" + portletID);
				m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, "portlet_" + portletID);

				if (indPage == 0)
				{
					sStartPage = "portlet_" + portletID;
				}

				// JYS: register one model per section
				((UserProfileModel) GetModel(m_strModelName)).SetNumProfileSectionsTable(nPageCounter, arProfileSections.length);

				for (int j = 0; j < arProfileSections.length; j++)
				{
					int nProfileSectionID = XPConvert.ToInteger(arProfileSections[j]);
					ptProfileSection = (IPTProfileSection)profileSectionMgr.Open(nProfileSectionID, false);
					RegisterModel(UserProfileObjEditModel.STR_MVC_CLASS_NAME, m_strUserProfileObjEdit + nPageCounter + j);

					// Get back the Model we just registered because we need it to register the Section
					myObjEditorModel = (UserProfileObjEditModel) GetModel(m_strUserProfileObjEdit + nPageCounter + j);
					myObjEditorModel.Init(ptProfileSection);
					RegisterView(GeneralInfoView.STR_MVC_CLASS_NAME, m_strUserProfileObjEdit + nPageCounter + j, myObjEditorModel);
					RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, m_strUserProfileObjEdit + nPageCounter + j, myObjEditorModel);
				}

				alPortlets.Add(portlet);
				nPageCounter++;
			}
		}

		// if in 508 mode add display page for list of profile pages 
		if (GetAccessStyle() != AccessStyles.STANDARD)
		{
			RegisterPage(new ProfilePageListDP_D(alPortlets), ProfilePageListDP_D.STR_MVC_CLASS_NAME);

			// make this the starting page
			sStartPage = ProfilePageListDP_D.STR_MVC_CLASS_NAME;
		}	
		
		SetCurrentPage(sStartPage);

	}
}

