package com.plumtree.portalpages.browsing.editors.userprofile;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.pei.*;
import com.plumtree.portalpages.portlets.userprofile.eoddisplay.prefs.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.*;
import com.plumtree.portaluiinfrastructure.expandablelist.properties.*;
import com.plumtree.portaluiinfrastructure.profile.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * @author DanD, jennifersu
 */
public class UserProfileModel extends EditorModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.userprofile.UserProfileModel");

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "UserProfile";

	
	/** Web Service ID for User Profile Portlets. **/
	protected XPHashtable m_numProfileSectionsTable;
	protected XPHashtable m_htPropValueTable;
	protected XPHashtable m_htPropTypeTable;
	protected int m_numProfilePages = 0;
	protected int m_currProfilePage = 0;
	protected XPHashtable m_htPageToPortletMapping;
	protected XPArrayList m_alProfilePages;

	/**
	 * Code executed when the Editor is starting. Get all of the property
	 * information for the user
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{		
		if (m_numProfilePages <= 0)
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER, m_asOwner.GetString(1, "ptmsgs_userprofile"), m_asOwner.GetString(1, "ptmsgs_userprofile"));
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			return false;
		}
		return true;
	}
	
	/**
	 * Returns an XPHashtable, with portlet ID as the key, profile page ID as the value.
	 * @return
	 */
	public XPArrayList GetProfilePages()
	{
		return m_alProfilePages;
	}
	
	public IPTGadget LookupPortlet(IPTProfilePage _ptProfilePage)
	{
		IPTGadget ptPortlet = null;
		Object objPortlet = m_htPageToPortletMapping.GetElement(_ptProfilePage);
		if (null != objPortlet)
		{
			ptPortlet = (IPTGadget)objPortlet;
		}
		
		return ptPortlet;
	}

	/**
	 * 
	 *
	 * @param aspace 
	 */
	public void Init(AActivitySpace aspace)
	{
		super.Init(aspace);

		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		// Look up all Profile Pages.
		IPTObjectManager wsManager = ptSession.GetWebServices();
		PTObjectManagerQueryWrapper omqw1 = new PTObjectManagerQueryWrapper(wsManager);
		Object[][] qf1 = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION, PT_FILTEROPS.PT_FILTEROP_GTE, new Integer(PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE));
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = PT_PROPIDS.PT_PROPID_NAME;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
		omqw1.Query(PT_PROPIDS.PT_PROPID_ALL, -1, arrSort, qf1);
		
		Object[][] adminSettings;
		m_alProfilePages = new XPArrayList();
		m_htPageToPortletMapping = new XPHashtable();
		IPTObjectManager profilePageMgr = ptSession.GetProfilePages();
		for (int j = 0; j < omqw1.GetCount(); j++)
		{
			int nPersonalization = XPConvert.ToInteger(omqw1.GetItem(j, PT_PROPIDS.PT_PROPID_WEBSERVICE_PERSONALIZATION));
			if (0 != (nPersonalization & PT_GADGETPERSONALIZATION_ROLES.PT_WEBSERVICEPERSONALIZATION_PROFILE))
			{
				IPTObjectManager portletManager = ptSession.GetGadgets();
				PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(portletManager);
				Object[][] queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_GADGET_WEBSERVICEID, PT_FILTEROPS.PT_FILTEROP_EQ, omqw1.GetItem(j, PT_PROPIDS.PT_PROPID_OBJECTID));
				arrSort = new int[1][2];
				arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = PT_PROPIDS.PT_PROPID_NAME;
				arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
				omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, arrSort, queryFilter);

				for (int i = 0; i < omqw.GetCount(); i++)
				{
					Object portletID = omqw.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID);
					IPTGadget portlet = (IPTGadget) portletManager.Open(XPConvert.ToInteger(portletID), false);
					IPTAdminSettings ptAdminSettings = (IPTAdminSettings) portlet;
					adminSettings = ptAdminSettings.LookupAdminGadgetSettings(EODPortletPrefsModel.SETTING_PROFILEPAGEID);
			
					// if the Profile Page hasn't been configured yet, skip over this
					// portlet and don't count it in the Profile Page count
					if (adminSettings[1][0] == null)
					{
				
						log.Info(STR_MVC_CLASS_NAME + "::Init  Skipping portlet " + portletID + " because no profile page was found.");
					
						continue;
					}
					else
					{
						Object profilePageID = adminSettings[1][0];
						IPTProfilePage profilePage = (IPTProfilePage)profilePageMgr.Open(XPConvert.ToInteger(profilePageID), false);
						if (profilePage.GetChildSections().length < 1)
						{
							log.Info(STR_MVC_CLASS_NAME + "::Init  Skipping portlet " + portletID + " because profile page contained no sections.");
							continue;
						}
						m_alProfilePages.Add(profilePage);
						m_htPageToPortletMapping.PutElement(profilePage, portlet);
						m_numProfilePages++;
					}
				}
			}
		}
		
		if (m_numProfilePages <= 0)
		{
			
				log.Error(STR_MVC_CLASS_NAME + "::Init  Could not find any User Profile Pages.");
			
		}
		else
		{		
			
				log.Info(STR_MVC_CLASS_NAME + "::Init  Found " + m_numProfilePages + " Profile Pages.");
			
		}

		//Load all property values into a hashtable
		m_htPropTypeTable = new XPHashtable();
		m_htPropValueTable = PutUserPropertiesIntoHashtable();
	}

	/**
	 *
	 * @param _sNewSpaceName
	 * @param _sNewPageName
	 */
	public void DoTaskOnChangePage(String _sNewSpaceName, String _sNewPageName)
	{
		if (m_asOwner.GetPageExists(_sNewPageName))
		{
			GeneralProfileDP page = (GeneralProfileDP) m_asOwner.GetPage(_sNewPageName);
			int pageIndex = page.GetProfilePageIndex();
			m_currProfilePage = pageIndex;

			int numProfileSections = GetNumProfileSections(pageIndex);

			for (int i = 0; i < numProfileSections; i++)
			{
				UserProfileObjEditModel listModel = (UserProfileObjEditModel) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + pageIndex + i);
				listModel.LoadProperties((IPTSession) m_asOwner.GetUserSession());
			}
		}
	}

	/**
	 * 
	 * @param index
	 */
	public void SetCurrentProfilePage(int index)
	{
		m_currProfilePage = index;
	}
	
	/**
	 *
	 * @return
	 */
	public XPHashtable GetUserValues()
	{
		return m_htPropValueTable;
	}

	/**
	 * Return object property non-reference data
	 *
	 * @param _ptObjProp IPTObjectProperties
	 *
	 * @return Data in query result
	 *
	 * @throws XPException
	 */
	protected IASQueryResult GetObjectPropData(IPTObjectProperties _ptObjProp)
	{
		IASQueryResult asqrObjectPropData = null;

		try
		{
			if (null != _ptObjProp)
			{
				IPTQueryResult qrObjectPropData = _ptObjProp.GetPropertyData(PT_PROPIDS.PT_PROPID_ALL);
				asqrObjectPropData = new ASQueryResultWrapper(qrObjectPropData);
			}
		}
		catch (Exception e)
		{
			
				log.Error(STR_MVC_CLASS_NAME + "::GetObjectPropData " + m_asOwner.GetString(97, "ptmsgs_portalinfrastructure") + ". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(97, "ptmsgs_portalinfrastructure"), e);
		}

		return asqrObjectPropData;
	}

	/**
	 * Return object property reference data
	 *
	 * @param _ptObjProp IPTObjectProperties
	 *
	 * @return Data in query result
	 *
	 * @throws XPException
	 */
	protected IASQueryResult GetObjectPropRefData(IPTObjectProperties _ptObjProp)
	{
		IASQueryResult asqrObjectPropRefData = null;

		try
		{
			if (null != _ptObjProp)
			{
				IPTQueryResult qrObjectPropRefData = _ptObjProp.GetPropertyRefData(PT_PROPIDS.PT_PROPID_ALL);
				asqrObjectPropRefData = new ASQueryResultWrapper(qrObjectPropRefData);
			}
		}
		catch (Exception e)
		{
			
				log.Error(STR_MVC_CLASS_NAME + "::GetObjectPropRefData " + m_asOwner.GetString(97, "ptmsgs_portalinfrastructure") + ". The following exception occured: " + e);
			

			throw new XPException(m_asOwner.GetString(97, "ptmsgs_portalinfrastructure"), e);
		}

		return asqrObjectPropRefData;
	}

	/**
	 *
	 *
	 * @param ptSession
	 * @param profileUserID
	 *
	 * @return
	 */
	protected XPHashtable PutUserPropertiesIntoHashtable()
	{
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		//get all the properties for this user
		IPTProfileManager pm = (IPTProfileManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER, false);
		boolean bRequestEdit = true;
		IPTObjectProperties profileEOD = pm.GetUserProperties(ptSession.GetSessionInfo().GetCurrentUserID(), bRequestEdit);

		//put all the properties in a hashtable, indexed by object id
		XPHashtable profileData = new XPHashtable();

		XPArrayList valList;
		int propertyIndex;

		// First get non-reference property data
		IASQueryResult profileQR = GetObjectPropData(profileEOD);

		propertyIndex = 0;

		while (propertyIndex < profileQR.GetCount())
		{
			// get value type
			valList = GetAllValues(profileQR, propertyIndex, false);
			profileData.RemoveElement(profileQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
			profileData.PutElement(profileQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_OBJECTID), valList);
			m_htPropTypeTable.PutElement(profileQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_OBJECTID), profileQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
			
			if (valList.GetSize() == 0)
			{
				break;
			}

			propertyIndex += valList.GetSize();
		}

		IASQueryResult profileRefQR = GetObjectPropRefData(profileEOD);
		propertyIndex = 0;

		while (propertyIndex < profileRefQR.GetCount())
		{
			// get value type
			valList = GetAllValues(profileRefQR, propertyIndex, true);
			profileData.RemoveElement(profileRefQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
			profileData.PutElement(profileRefQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_OBJECTID), valList);
			m_htPropTypeTable.PutElement(profileRefQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_OBJECTID), profileRefQR.GetFields(propertyIndex, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));

			if (valList.GetSize() == 0)
			{
				break;
			}

			propertyIndex += valList.GetSize();
		}

		return profileData;
	}

	/**
	 *
	 * @param qrData
	 * @param _nRowIndex
	 * @return XPArrayList - array of objects that make up the multiple value
	 */
	private XPArrayList GetAllValues(IASQueryResult qrData, int _nRowIndex, boolean isRefData)
	{
		XPArrayList valList = new XPArrayList();

		int currPropID = XPConvert.ToInteger(qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
		int nextPropID;
		int valType;
		Object propVal;

		// first add the current property
		valType = XPConvert.ToInteger(qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
		propVal     = GetPropValue(qrData, _nRowIndex, valType);
		valList.Add(propVal);

		// now check for multiple values
		while (_nRowIndex < (qrData.GetCount() - 1))
		{
			nextPropID = XPConvert.ToInteger(qrData.GetFields(_nRowIndex + 1, PT_PROPIDS.PT_PROPID_OBJECTID));

			if (nextPropID == currPropID)
			{
				_nRowIndex++;
				valType     = XPConvert.ToInteger(qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
				propVal     = GetPropValue(qrData, _nRowIndex, valType);

				if (propVal != null)
				{
					valList.Add(propVal);
				}
			}
			else
			{
				return valList;
			}
		}

		return valList;
	}

	/**
	 * 
	 *
	 * @param qrData 
	 * @param _nRowIndex 
	 * @param valType 
	 *
	 * @return 
	 */
	private Object GetPropValue(IASQueryResult qrData, int _nRowIndex, int valType)
	{
		Object value;

		if (qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE) == null)
		{
			value = null;
		}
		else
		{
			switch (valType)
			{
			case PT_PROPERTY_TYPES.PT_PROPTYPE_DOUBLE:
				value = qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_DATE:
				value = qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_LONG:
				value = qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);

				break;

			case PT_PROPERTY_TYPES.PT_PROPTYPE_REF:
				value = qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);

				break;

			default:
				value = qrData.GetFields(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_VALUE);

				break;
			}
		}

		return value;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserProfileModel();
	}

	/**
	 * Code executed in finish.  Loop through the current properties and store
	 * them in the Plumtree Database
	 */
	public void Finish()
	{
		// UserProfileActions PEI
		// BrianH: All of the following code will load all of the available UserProfileAction
		// PEIs and process through them. If they return a false string an error will
		// appear and the saving of the user profile information will stop.
		Object[] oa;
		Object o;
		UserProfileObjEditModel objEditModel;
		IUserProfileActions iActions;
		IApplication application = m_asOwner.GetApplication();

		oa = (Object[]) application.GetCachingManager().GetEntry("UserProfileActions");

		if (oa != null)
		{
			String sErrorMsgs = "";
			
			XPHashtable htPropObjs = new XPHashtable();
			for (int j = 0;	j < XPConvert.ToInteger(m_numProfileSectionsTable.GetElement(new Integer(m_currProfilePage))); j++)
			{
				objEditModel     = (UserProfileObjEditModel) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_currProfilePage + j);
				for (int k = 0; k < objEditModel.GetNumPropsTotal(); k++)
				{
					Object objPropertyID = objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_OBJECTID);
					Object xpalValue = m_htPropValueTable.GetElement(objPropertyID);
					int nPicktype = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
					int nIsHREF = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_HREF));
					int nIsMandatory = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_MANDATORY));
					int nIsMultiValued = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_MULTIVALUED));
					int nIsReadOnly = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_READONLYVALUE));
					int nIsVisible = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_VISIBLE));
					int nRefClassID = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_REFCLASS));
					Property prop = new Property(XPConvert.ToInteger(objPropertyID), XPConvert.ToString(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_NAME)), nPicktype, xpalValue, nPicktype, nIsHREF, nIsMandatory, nIsMultiValued, nIsReadOnly, nIsVisible, nRefClassID, null);
					htPropObjs.PutElement(new Integer(prop.GetID()), prop);
				}
			}
								
			for (int x = 0; x < oa.length; x++)
			{
				o = oa[x];

				
					log.Debug(STR_MVC_CLASS_NAME + "::Finish - About to call OnBeforeStoreUserProfile on an: " + o);
				

				if (o != null)
				{
					String sError;
					
					iActions = (IUserProfileActions) o;
					sError = iActions.OnBeforeStoreUserProfile(m_asOwner, 
						(IPTSession) m_asOwner.GetUserSession(), htPropObjs);
						
					if ((null != sError) && (sError.length() > 0))
					{
						sErrorMsgs += sError + " ";
					}
				}
			}
			
			if ((null != sErrorMsgs) && (sErrorMsgs.length() > 0))
			{
				UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER, null, sErrorMsgs, sErrorMsgs);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

				
				log.Error(STR_MVC_CLASS_NAME + "::Finish()  There was an error saving the property data. " + sErrorMsgs);
				
						
				return;
			}
		}

		try
		{			
			// logon with the current plumtree user session
			IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

			// get the profile manager
			IPTProfileManager pm = GetPTProfileManager(ptSession);

			// get the profile manager object properties
			IPTObjectProperties profileEOD = GetPTObjectProperties(ptSession, pm);

			// get the array and set the data in the DB for non-ref property types
			Object[][] aEditPropInfo = CreateArrayForEdit(false);
			profileEOD.SetPropertyData(aEditPropInfo);

			// get the array and set the data in the DB for non-ref property types
			Object[][] aEditRefPropInfo = CreateArrayForEdit(true);
			profileEOD.SetPropertyRefData(aEditRefPropInfo);

			// store the information on the ptsession, otherwise it would not be
			// there until a query back to the database.
			int userID = ptSession.GetSessionInfo().GetCurrentUserID();

			ptSession.GetUserInfo().Merge(pm.GetUserInfo(userID));

			
			log.Info(STR_MVC_CLASS_NAME + "::Finish  Everything was saved to the profile manager successfully.");
			
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(580, "ptmsgs_portalbrowsingmsgs"), "");
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

			log.Error(e, "UserProfileModel::Finish()  There was an error saving the property data.");
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		UserProfileObjEditModel objEditModel;

		// if this is the 508 profile list page, just return, there is nothing to save
		if (_sPageName.equals(ProfilePageListDP_D.STR_MVC_CLASS_NAME))
		{
			return RepostControl.PAGE_STATUS_VALID;
		}

		// UserProfileActions PEI
		// BrianH: All of the following code will load all of the available UserProfileAction
		// PEIs and process through them. If they return a false string an error will
		// appear and the saving of the user profile information will stop.
		Object[] oa;
		Object o;
		IUserProfileActions iActions;
		IApplication application = m_asOwner.GetApplication();

		oa = (Object[]) application.GetCachingManager().GetEntry("UserProfileActions");

		if (oa != null)
		{
			String sErrorMsgs = "";
			
			XPHashtable htPropObjs = new XPHashtable();
			for (int j = 0;	j < XPConvert.ToInteger(m_numProfileSectionsTable.GetElement(new Integer(m_currProfilePage))); j++)
			{
				objEditModel     = (UserProfileObjEditModel) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_currProfilePage + j);
				for (int k = 0; k < objEditModel.GetNumPropsTotal(); k++)
				{
					String htmlKey = objEditModel.GetUniqueString(ExpListPropEditView.HTMLINPUT_ITEM) + k;
					Object objPropertyID = objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_OBJECTID);
					Object xpalValue = m_htPropValueTable.GetElement(objPropertyID);
					int nPicktype = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
					int nIsHREF = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_HREF));
					int nIsMandatory = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_MANDATORY));
					int nIsMultiValued = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_MULTIVALUED));
					int nIsReadOnly = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_READONLYVALUE));
					int nIsVisible = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_VISIBLE));
					int nRefClassID = XPConvert.ToInteger(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_PROP_REFCLASS));
					Property prop = new Property(XPConvert.ToInteger(objPropertyID), XPConvert.ToString(objEditModel.GetRowPropertyInfo(k, PT_PROPIDS.PT_PROPID_NAME)), nPicktype, xpalValue, nPicktype, nIsHREF, nIsMandatory, nIsMultiValued, nIsReadOnly, nIsVisible, nRefClassID, null);
					htPropObjs.PutElement(htmlKey, prop);
				}
			}
								
			for (int x = 0; x < oa.length; x++)
			{
				o = oa[x];

				
					log.Debug(STR_MVC_CLASS_NAME + "::SavePage - About to call OnBeforeChangeUserProfile on an: " + o);
				

				if (o != null)
				{
					String sError;

					iActions = (IUserProfileActions) o;
					sError = iActions.OnBeforeChangeUserProfile(m_asOwner, 
						(IPTSession) m_asOwner.GetUserSession(), _htFormData, htPropObjs);

					if ((null != sError) && (sError.length() > 0))
					{
						sErrorMsgs += sError + " ";
					}
				}
			}
			
			if ((null != sErrorMsgs) && (sErrorMsgs.length() > 0))
			{
				UIError myError = new UIError(UIErrorLevel.WARNING, UIErrorScope.CURRENT_USER, null, sErrorMsgs, sErrorMsgs);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

				return RepostControl.PAGE_STATUS_INVALID;
			}
		}

		int status;

		for (int j = 0;
				j < XPConvert.ToInteger(m_numProfileSectionsTable.GetElement(new Integer(m_currProfilePage)));
				j++)
		{
			objEditModel     = (UserProfileObjEditModel) m_asOwner.GetModel(UserProfileEditorAS.m_strUserProfileObjEdit + m_currProfilePage + j);
			status			 = objEditModel.SaveSection(_htFormData);

			if (status == RepostControl.PAGE_STATUS_INVALID)
			{
				return RepostControl.PAGE_STATUS_INVALID;
			}
			else
			{
				UpdateAllPages(objEditModel);
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @param currCategory 
	 */
	private void UpdateAllPages(UserProfileObjEditModel currCategory)
	{
		PTGrowableSortedArrayWrapper currList = currCategory.GetItems();

		for (int i = 0; i < currList.GetCount(); i++)
		{
			XPArrayList propVals = new XPArrayList();
			Object propID = currList.GetItem(i, ObjPropModel.EXPLIST_COL_PROPID);
			Object propVal = currList.GetItem(i, UserProfileObjEditModel.EXPLIST_COL_VALUE);
			propVals.Add(propVal);

			if (XPConvert.ToInteger(currCategory.GetRowPropertyInfo(i, PT_PROPIDS.PT_PROPID_PROP_MULTIVALUED)) == 1)
			{
				i++;

				while (i < currList.GetCount())
				{
					Object nextPropID = currList.GetItem(i, ObjPropModel.EXPLIST_COL_PROPID);

					if (XPConvert.ToInteger(nextPropID) == XPConvert.ToInteger(propID))
					{
						propVals.Add(currList.GetItem(i, UserProfileObjEditModel.EXPLIST_COL_VALUE));
						i++;
					}
					else
					{
						break;
					}
				}

				i--;
			}

			m_htPropValueTable.RemoveElement(propID);
			m_htPropValueTable.PutElement(propID, propVals);
		}
	}

	/**
	 * Create an array for editing the Property information in the Database.  It
	 * will use the global Property Value object to get the property values.
	 * @return Object[][]
	 */
	private Object[][] CreateArrayForEdit(boolean isRefData)
	{
		Object oPropID;
		Object oPropVal;

		int numProps = 0;

		Object[] arObjPropIDs = m_htPropValueTable.GetArray(XPHashtable.KEYS);
		Object[] arXpalPropVals = m_htPropValueTable.GetArray(XPHashtable.VALUES);

		for (int indProp = 0; indProp < arObjPropIDs.length; indProp++)
		{
			XPArrayList onePropList = (XPArrayList)arXpalPropVals[indProp];

			int nPropType = XPConvert.ToInteger(m_htPropTypeTable.GetElement(arObjPropIDs[indProp]));
			if ((!isRefData && (nPropType != PT_PROPERTY_TYPES.PT_PROPTYPE_REF)) 
					|| (isRefData && (nPropType == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)))
			{
				numProps += onePropList.GetSize();
			}
		}

		Object[][] aEditPropInfo = new Object[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_INVALID][numProps];
		int nIndex = 0;

		for (int indProp = 0; indProp < arObjPropIDs.length; indProp++)
		{
			XPArrayList onePropList = (XPArrayList)arXpalPropVals[indProp];

			int nPropType = XPConvert.ToInteger(m_htPropTypeTable.GetElement(arObjPropIDs[indProp]));
			if ((!isRefData && (nPropType != PT_PROPERTY_TYPES.PT_PROPTYPE_REF)) 
					|| (isRefData && (nPropType == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)))
			{
				for (int i = 0; i < onePropList.GetSize(); i++)
				{
					oPropID	= arObjPropIDs[indProp];
					oPropVal = onePropList.GetElement(i);
					aEditPropInfo[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_PROPERTYID][nIndex] = oPropID;
					aEditPropInfo[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_VALUE][nIndex] = oPropVal;
					nIndex++;
				}
			}
		}

		return aEditPropInfo;
	}

	/**
	 * @param ptSession the current ptsession
	 * @param profileMan the PTProfileManager object
	 * @return the IPTObjectProperties for the current user
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#StartEditor(XPHashtable)
	 */
	private IPTObjectProperties GetPTObjectProperties(IPTSession ptSession, IPTProfileManager profileMan)
	{
		boolean bRequestEdit = true;
		int icurrentUser = ptSession.GetSessionInfo().GetCurrentUserID();

		
			log.Info(STR_MVC_CLASS_NAME + "::GetPTObjectProperties  Retrieving the Property information for the current user: " + icurrentUser);
		

		return profileMan.GetUserProperties(icurrentUser, bRequestEdit);
	}

	/**
	 * @param ptSession an IPTSession object used to get the profileManager
	 * @return Returns the PTProfileManager object for the current user
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#StartEditor(XPHashtable)
	 */
	private IPTProfileManager GetPTProfileManager(IPTSession ptSession)
	{
		//get all the properties for this user
		return (IPTProfileManager) ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER, false);
	}

	/**
	 *
	 *
	 * @return
	 */
	public int GetNumProfilePages()
	{
		return m_numProfilePages;
	}

	/**
	 *
	 *
	 * @param sectionNum
	 * @param numCategories
	 */
	public void SetNumProfileSectionsTable(int profilePageNum, int numProfileSections)
	{
		if (m_numProfileSectionsTable == null)
		{
			m_numProfileSectionsTable = new XPHashtable();
		}

		m_numProfileSectionsTable.PutElement(new Integer(profilePageNum), new Integer(numProfileSections));
	}

	/**
	 *
	 *
	 * @param _sectionIndex
	 *
	 * @return
	 */
	public int GetNumProfileSections(int _profilePageIndex)
	{
		return XPConvert.ToInteger(m_numProfileSectionsTable.GetElement(new Integer(_profilePageIndex)));
	}

	/**
	 * DCA - The 508 has a different logic than standard.
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		Redirect myRedirect;

		if ((m_asOwner.GetAccessStyle() != AccessStyles.STANDARD) && (m_asOwner.GetCurrentPage().GetName() != ProfilePageListDP_D.STR_MVC_CLASS_NAME))
		{
			myRedirect = new Redirect();
			myRedirect.SetLinkGetCachedSpace(m_asOwner);
			myRedirect.SetDisplayPage(ProfilePageListDP_D.STR_MVC_CLASS_NAME);
		}
		else
		{

			int nCurrnetCommunityID;
			// This is the specific condition that we don't know where the editor was started from
			// so we will just redirect to user profile page.
			if(null == m_asOwner.GetParentSpace() && UserProfileEditorAS.STR_MVC_CLASS_NAME == m_asOwner.GetName() ) {
				nCurrnetCommunityID = PT_INTRINSICS.PT_PROFILE_COMMUNITY;
			// We know where the editor is started from and we will try to get parent space and redirect back
			// to that page.
			} else {
				nCurrnetCommunityID = TaskAPIUICommunity.GetCurrentCommunityID(m_asOwner.GetParentSpace());
			}
			
			// Use friendly url to redirect back to user profile page if user friendly urls are supported
			// and if editor was kicked off from the profile community. Otherwise, we should redirect back
			// to the page where the editor was started from.
			
			if ( nCurrnetCommunityID == PT_INTRINSICS.PT_PROFILE_COMMUNITY ) 
			{
				myRedirect = new Redirect();
				IPTSession session = (IPTSession) m_asOwner.GetUserSession();
				IPTSessionInfo info = session.GetSessionInfo();
				int userID = info.GetCurrentUserID();
				String username = info.GetCurrentUserName();
				
				IPTURL pturl = TaskAPIUICommunity.CreateUserProfilePageCommonOpenerURL(m_asOwner, userID, username);
				myRedirect.SetLinkToExternalURL(pturl.GetFullURL());	
			}
			else
			{
				myRedirect = super.GetRedirectAfterFinish();
			}
		}

		return myRedirect;
	}
	
	/**
	 * Returns the name for an object
	 *
	 * @param nClassID Class ID of object
	 * @param nObjectID Object ID of object
	 *
	 * @return Name of object.
	 */
	public String GetNameFromObjectID(int nClassID, int nObjectID)
	{
		// Get the name of the reference object
		switch (nClassID)
		{
		case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
		{
			IPTAdminCatalog ptAC = ((IPTSession)m_asOwner.GetUserSession()).GetAdminCatalog();

			if (ptAC.IsAdminFolderAccessible(nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				IPTAdminFolder ptAdminFolder = ptAC.OpenAdminFolder(nObjectID, false);

				return ptAdminFolder.GetLocalizedName();
			}

			break;
		}

		case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
		{
			IPTCatalog ptCatalog = ((IPTSession)m_asOwner.GetUserSession()).GetCatalog();

			if (ptCatalog.IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID, nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				IPTFolder ptFolder = ptCatalog.OpenFolder(nObjectID, false);

				return ptFolder.GetLocalizedName();
			}

			break;
		}

		default:
		{
			// Get the object manager for the object and query for the name
			IPTAdminCatalog ptAC = ((IPTSession)m_asOwner.GetUserSession()).GetAdminCatalog();
			IPTObjectManager ptOM = ptAC.GetObjectManager(nClassID);
			IPTQueryResult ptQR = ptOM.QuerySingleObject(nObjectID);

			if (0 < ptQR.RowCount())
			{
				return ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
			}

			break;
		}
		}

		return null;
	}

}

