package com.plumtree.portalpages.browsing.editors.userprofile;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author dand, jennifersu
 *
 * This is the model that is used to contain all of the Object Properties and
 * values for a given user profile.  This is necesssary for me to use the
 * ObjPropModel
 */
public class UserProfileObjEditModel extends ObjPropModel implements IObjPropModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.userprofile.UserProfileObjEditModel");

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "UserProfileObjEdit";

	/** Number total of columns */
	public static final int EXPLIST_COL_MAX = 8;
	public static final int EXPLIST_COL_ROWID = 5;
	public static final int EXPLIST_COL_MULTIID = 6;
	public static final int EXPLIST_COL_REFVALUE_NAME = 7;
	
	protected IPTProfileSection m_profileSection;
	protected int m_numRefProps;
	protected int m_numPropsTotal;
	protected XPHashtable m_htPropSortIndex;
	protected IPTQueryResult m_ptqrPropertyInfo;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserProfileObjEditModel();
	}

	/**
	 * Initialize the expandable list associated with this Section.
	 * @param __ptProfileSection - IPTProfileSection that this expandable list represents.
	 */
	public void Init(IPTProfileSection _ptProfileSection)
	{
		m_profileSection		   = _ptProfileSection;

		SetTableInstructions(XPHttpUtility.HtmlEncode(m_profileSection.GetLocalizedDescription()));
		
		// logon with the current plumtree user session
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		// Attempt to initialize object properties.  If object doesn't support EOD, then flag will be set to false.
		InitializeObjectProperties(ptSession, XPHttpUtility.HtmlEncode(m_profileSection.GetLocalizedName()), _ptProfileSection.GetObjectID());
	}

	/**
	 * Adds a new row to the list of object property values.
	 *
	 * @param _htFormData - Hashtable of form data
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ObjPropModel#AddRowsOnRepost(XPHashtable)
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
		{
			String sSubmitValue = UserProfileRepostControl.HTMLSUBMIT_508_ADDREMOVEROW + GetUniqueInt(UserProfileRepostControl.POSTTOSELF_ACTION_508_ADDROW);
			IXPEnumerator keys = _htFormData.GetKeys();
			while (keys.MoveNext())
			{
				String sKey = XPConvert.ToString(keys.GetCurrent());
				if (sKey.startsWith(sSubmitValue))
				{
					String sRowIndex = sKey.substring(sSubmitValue.length() + 1);
					_htFormData.RemoveElement(GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX));
					_htFormData.PutElement(GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX), new String[]{sRowIndex});
					
					_htFormData.RemoveElement(GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX));
					_htFormData.PutElement(GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX), _htFormData.GetElement(GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX) + "_" + sRowIndex));
					break;
				}
			}
		
		}
		// Get the hidden input with the row to modify
		String sRowKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);
		String sPropertyKey = GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX);

		if (_htFormData.ContainsKey(sRowKey) && _htFormData.ContainsKey(sPropertyKey))
		{
			String[] aRowValue = (String[]) _htFormData.GetElement(sRowKey);
			String[] aPropertyValue = (String[]) _htFormData.GetElement(sPropertyKey);

			if ((null != aRowValue) && (aRowValue.length > 0) && (null != aPropertyValue) && (aPropertyValue.length > 0))
			{
				// 1) Prepare column values to be inserted into list. 
				// nRowIndex is the row index of the property (not including multivalues),
				// as opposed to the actual index in the list.  This distinction
				// is used for multi-valued properties, where the user can add
				// a new value to a property.  In such a case, two different values
				// for the Property would share the same nRowIndex as modeled in the
				// expandable list, but visibly different row indices in the UI.
				// nSortIndex is the row index within multi-valued properties. This
				// tells the UI what order to display additional values of the same
				// property.
				int nRowIndex = XPConvert.ToInteger(aRowValue[0]);
				int nPropertyIndex = XPConvert.ToInteger(aPropertyValue[0]);
				Object nPropertyID = GetRowPropertyInfo(nRowIndex, PT_PROPIDS.PT_PROPID_OBJECTID);

				int nSortIndex = UpdateMaxSortIndex(nPropertyID);
				
				// 2) Create new row to add to list.
				Object[] oRow = new Object[EXPLIST_COL_MAX];
				oRow[EXPLIST_COL_PROPID]		  = nPropertyID;
				oRow[EXPLIST_COL_VALUE]			  = m_oDefaultValue;
				oRow[EXPLIST_COL_NAME]			  = GetRowName(nRowIndex);
				oRow[EXPLIST_COL_TYPE]			  = new Integer(GetRowType(nRowIndex));
				oRow[EXPLIST_COL_STATUS]		  = new Integer(ROW_STATUS_ADDED);
				oRow[EXPLIST_COL_ROWID]			  = new Integer(nPropertyIndex);
				oRow[EXPLIST_COL_MULTIID]		  = new Integer(nSortIndex);

				// 4) Now we can safely add the new row in the correct place.
				m_saData.AddRow(oRow);
				m_numPropsTotal++;
				if (GetRowType(nRowIndex) == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)
				{
					m_numRefProps++;
				}

				// Update unique datetime keys whenever expandable list is modified.
				UpdateDateTimeUniqueKeys();

				// Update mandatory page status whenever expandable list is modified.
				UpdateMandatoryPageStatus();
			}
		}
	}

	/**
	 * Deletes am existing row from the list of object property values.
	 *
	 * @param _htFormData Hash table of form data
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#DeleteRowsOnRepost(XPHashtable)
	 */
	public void DeleteRowsOnRepost(XPHashtable _htFormData)
	{
		if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
		{
			String sSubmitValue = UserProfileRepostControl.HTMLSUBMIT_508_ADDREMOVEROW + GetUniqueInt(UserProfileRepostControl.POSTTOSELF_ACTION_508_REMOVEROW);
			IXPEnumerator keys = _htFormData.GetKeys();
			while (keys.MoveNext())
			{
				String sKey = XPConvert.ToString(keys.GetCurrent());
				if (sKey.startsWith(sSubmitValue))
				{
					String sRowIndex = sKey.substring(sSubmitValue.length() + 1);
					_htFormData.RemoveElement(GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX));
					_htFormData.PutElement(GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX), new String[]{sRowIndex});
					
					_htFormData.RemoveElement(GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX));
					_htFormData.PutElement(GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX), _htFormData.GetElement(GetUniqueString(GeneralInfoView.HTMLHIDDEN_PROPERTYINDEX) + "_" + sRowIndex));
					break;
				}
			}
		
		}

		String sDataKey = GetUniqueString(ExpListView.HTMLHIDDEN_ROWINDEX);

		if (_htFormData.ContainsKey(sDataKey))
		{
			String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && (aDataValue.length > 0))
			{
				int nRowIndex = XPConvert.ToInteger(aDataValue[0]);

				if (ROW_STATUS_ADDED == GetRowStatus(nRowIndex))
				{
					m_numPropsTotal--;

					if (GetRowType(nRowIndex) == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)
					{
						m_numRefProps--;
					}

					m_saData.RemoveRow(nRowIndex);

					// Update unique datetime keys whenever expandable list is modified.
					UpdateDateTimeUniqueKeys();

					// Update mandatory page status whenever expandable list is modified.
					UpdateMandatoryPageStatus();
				}
				else
				{
					SetRowStatus(nRowIndex, ROW_STATUS_DELETED);
				}
			}
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Initialize the expandable list.
	 * @param _ptSession
	 * @param _ptObjProp
	 * @param _sSectionTitle
	 * @param _nListKey
	 */
	public void InitializeObjectProperties(IPTSession _ptSession, String _sSectionTitle, int _nListKey)
	{
		m_ptSession     = _ptSession;

		m_bSupportsEOD = true;

		Object[][] arrExpListColInfo = new Object[2][EXPLIST_COLUMN_INVALID];

		// The first column will be the property name and will not be sortable
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_NAME);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(100, "ptmsgs_portalinfrastructure");
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "20%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		// The second column will be the property value and will not be sortable
		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_VALUE);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = m_asOwner.GetString(101, "ptmsgs_portalinfrastructure");
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "80%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "2";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		// Initialize as read-only list because we don't want checkboxes or action bar
		InitializeReadOnlyExpandableList(_sSectionTitle, arrExpListColInfo, _nListKey);

		// Load the properties only after expandable list is initialized.
		LoadProperties(_ptSession);

		// Update datetime keys
		UpdateDateTimeUniqueKeys();

		// Update mandatory page status whenever expandable list is modified.
		UpdateMandatoryPageStatus();

		SetEmptyListMessages(m_asOwner.GetString(96, "ptmsgs_portalinfrastructure"), m_asOwner.GetString(95, "ptmsgs_portalinfrastructure"));
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)  with a column
	 * mapping and an array of sort. The growable array will be sorted by the
	 * 2 columns, first the name and second propID, ascending
	 *
	 * @param _saData
	 *
	 * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#InitializeSortedArray(PTGrowableSortedArrayWrapper)
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[EXPLIST_COL_MAX];

		arrColumns[EXPLIST_COL_PROPID]			  = EXPLIST_COL_PROPID;
		arrColumns[EXPLIST_COL_VALUE]			  = EXPLIST_COL_VALUE;
		arrColumns[EXPLIST_COL_NAME]			  = EXPLIST_COL_NAME;
		arrColumns[EXPLIST_COL_TYPE]			  = EXPLIST_COL_TYPE;
		arrColumns[EXPLIST_COL_STATUS]			  = EXPLIST_COL_STATUS;
		arrColumns[EXPLIST_COL_ROWID]			  = EXPLIST_COL_ROWID;
		arrColumns[EXPLIST_COL_MULTIID]			  = EXPLIST_COL_MULTIID;
		arrColumns[EXPLIST_COL_REFVALUE_NAME]     = EXPLIST_COL_REFVALUE_NAME;

		// The growable array will be sorted by 2 columns, first the property index and second multivalue index.
		int[][] arrSort = new int[2][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_ROWID;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
		arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_MULTIID;
		arrSort[1][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null bellow)
		_saData.Initialize(arrColumns, null, arrSort, true);
	}

	/**
	 * Load the Properties into the expandable list representation.
	 * @param ptSession
	 */
	public void LoadProperties(IPTSession ptSession)
	{
		int nStatus = ObjPropModel.ROW_STATUS_NO_CHANGE;
	
		// Start with a fresh list
		m_saData.ClearArray();

		// Get all property values associated with this user
		XPHashtable userPropTable = ((UserProfileModel) m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName)).GetUserValues();

		// Initialize counters
		m_numRefProps	    = 0;
		m_numPropsTotal     = 0;

        // Cache the properties in memory. The underlying PTProfileSection uses an PlumtreeObjectCache.
		m_ptqrPropertyInfo = m_profileSection.GetProperties();
		
		m_htPropSortIndex = new XPHashtable(m_ptqrPropertyInfo.RowCount());

		// Load up!
		for (int indProperty = 0; indProperty < m_ptqrPropertyInfo.RowCount(); indProperty++)
		{
			Object[] aRowToAdd = new Object[EXPLIST_COL_MAX];

			Object objPropertyID = m_ptqrPropertyInfo.ItemAsObject(indProperty, PT_PROPIDS.PT_PROPID_OBJECTID);
			// Get the Property and associated user values
			XPArrayList onePropList = (XPArrayList) userPropTable.GetElement(objPropertyID);

			// If the Property is valid, 
			// Load the values into columns, and add the row to the list
			if (onePropList != null)
			{
				int nPropertyID = XPConvert.ToInteger(objPropertyID);
				for (int j = 0; j < onePropList.GetSize(); j++)
				{
					// 1) Prepare column values to be inserted into list. 
					// EXPLIST_COL_ROWID is the row index of the property (not including multivalues),
					// as opposed to the actual index in the list.  This distinction
					// is used for multi-valued properties, where the user can add
					// a new value to a property.  In such a case, two different values
					// for the Property would share the same EXPLIST_COL_ROWID as modeled in the
					// expandable list, but visibly different row indices in the UI.
					// nSortIndex is the row index within multi-valued properties. This
					// tells the UI what order to display additional values of the same
					// property.
					Object oValue = onePropList.GetElement(j);
					int nType = m_ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE);;
				
					int nSortIndex = UpdateMaxSortIndex(objPropertyID);

				// 2) Create the row
					aRowToAdd[EXPLIST_COL_PROPID]		   = objPropertyID;
					aRowToAdd[EXPLIST_COL_VALUE]		   = oValue;
					aRowToAdd[EXPLIST_COL_NAME]			   = m_ptqrPropertyInfo.ItemAsString(indProperty, PT_PROPIDS.PT_PROPID_NAME);
					aRowToAdd[EXPLIST_COL_TYPE]			   = new Integer(nType);
					aRowToAdd[EXPLIST_COL_STATUS]		   = new Integer(nStatus);
					aRowToAdd[EXPLIST_COL_ROWID]		   = new Integer(indProperty);
					aRowToAdd[EXPLIST_COL_MULTIID]		   = new Integer(nSortIndex);

					if (nType == PT_PROPERTY_TYPES.PT_PROPTYPE_REF)
					{
						int nClassID = m_ptqrPropertyInfo.ItemAsInt(indProperty, PT_PROPIDS.PT_PROPID_PROP_REFCLASS);
						if (null == oValue)
						{
							aRowToAdd[EXPLIST_COL_REFVALUE_NAME] = "";
						}
						else
						{
							aRowToAdd[EXPLIST_COL_REFVALUE_NAME] = GetNameFromObjectID(nClassID, XPConvert.ToInteger(oValue));							
						}
						m_numRefProps++;
					}

					if (onePropList.GetSize() > 1)
					{
						aRowToAdd[EXPLIST_COL_STATUS] = new Integer(ObjPropModel.ROW_STATUS_ADDED);
					}

				// 3) Add the row to the list
					if (aRowToAdd[EXPLIST_COL_PROPID] != null)
					{
						m_saData.AddRow(aRowToAdd);
					}

					m_numPropsTotal++;
				}
			}
			else
			{
				// If the Property isn't valid,
				// don't load it for display.
				log.Warn(STR_MVC_CLASS_NAME + "::LoadProperties  Property was not loaded: {0}", objPropertyID);
			}
		}

		if ((m_saData == null) || (m_saData.GetCount() == 0))
		{
			
				log.Warn(STR_MVC_CLASS_NAME + "::LoadProperties  The properties were not properly loaded.");
			
		}
	}

	/**
	 * Looks up the max sort index from table using property ID.
	 * 
	 * @param nPropertyID Property ID
	 * 
	 * @return Updated sort index for the property
	 */
	private int UpdateMaxSortIndex(Object nPropertyID)
	{
		int nSortIndex;
					
		if (!m_htPropSortIndex.ContainsKey(nPropertyID))
		{
			// Set sort index to 0
			nSortIndex = 0; 
		}
		else
		{
			// Increment sort index by 1
			nSortIndex = XPConvert.ToInteger(m_htPropSortIndex.GetElement(nPropertyID)) + 1;
		}

		// Update sort index
		m_htPropSortIndex.PutElement(nPropertyID, new Integer(nSortIndex));
		
		return nSortIndex;
	}


	/**
	 * Get the number of reference Properties in this Category.
	 * @return int
	 */
	public int GetNumRefProps()
	{
		return m_numRefProps;
	}

	/**
	 * Get the total number of Properties in this Category.
	 * @return int
	 */
	public int GetNumPropsTotal()
	{
		return m_numPropsTotal;
	}

	/**
	 * Checks to see if the property is read-only
	 *
	 * @param _nRowIndex Current row index
	 *
	 * @return Returns true if read-only. Otherwise returns false.
	 *
	 * @see com.plumtree.portaluiinfrastructure.editor.commonpages.objectproperties.IObjPropModelRO#CheckRowIsReadOnly(int)
	 */
	public boolean CheckRowIsReadOnly(int _nRowIndex)
	{
		if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
		{
			Object objType = m_saData.GetItem(_nRowIndex, EXPLIST_COL_TYPE);
			if (PT_PROPERTY_TYPES.PT_PROPTYPE_REF == XPConvert.ToInteger(objType))
			{
				return true;
			}
			
			int intPickType = XPConvert.ToInteger(GetRowPropertyInfo(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_PICKTYPE));
			if (PT_PICKTABLE_TYPES.PT_PICKTABLE_TYPE_PICKTREE == intPickType)
			{
				return true;
			}
		}

		int propID = XPConvert.ToInteger(GetRowPropertyInfo(_nRowIndex, PT_PROPIDS.PT_PROPID_OBJECTID));

		if ((propID == 1) || (propID == 2))
		{
			// property is name or description.  this should always be read-only
			return true;
		}

        // Note that because m_ptqrPropertyInfo uses a PlumtreeObjectCache,
        // we won't have up-to-date information about state that changed *outside* the
        // user profile editor, such as a property becoming read-only (42283)
		return super.CheckRowIsReadOnly(_nRowIndex);
	}

	/**
	 * Gets values of the given Property attribute for a row.
	 * @param _nRowIndex Row index to look up
	 * @param nPropID Property attribute to look up
	 * 
	 * @return value of attribute
	 */
	public Object GetRowPropertyInfo(int _nRowIndex, int nPropID)
	{
		int nMappedRowIndex = XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, EXPLIST_COL_ROWID));
        // Get the property info from our cached DB query results
		return m_ptqrPropertyInfo.ItemAsObject(nMappedRowIndex, nPropID);
		
//		switch (nPropID)
//		{
//		case PT_PROPIDS.PT_PROPID_OBJECTID:
//			return new Integer(rowProp.GetObjectID());
//
//		case PT_PROPIDS.PT_PROPID_PROP_PICKTYPE:
//			return new Integer(rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_PICKTYPE));
//
//		case PT_PROPIDS.PT_PROPID_PROP_HREF:
//			return new Boolean(1 == rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_HREF));
//
//		case PT_PROPIDS.PT_PROPID_PROP_MANDATORY:
//			return new Boolean(1 == rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MANDATORY));
//
//		case PT_PROPIDS.PT_PROPID_PROP_MULTIVALUED:
//			return new Boolean(1 == rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_MULTIVALUED));
//
//		case PT_PROPIDS.PT_PROPID_PROP_READONLYVALUE:
//			return new Boolean(1 == rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_READONLYVALUE));
//
//		case PT_PROPIDS.PT_PROPID_PROP_VISIBLE:
//			return new Boolean(1 == rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_VISIBLE));
//
//		case PT_PROPIDS.PT_PROPID_PROP_REFCLASS:
//			return new Integer(rowProp.GetCharacteristicsAsInt(PT_PROPERTY_CHARACTERISTICS.PT_PROPCHAR_REFCLASS));
//
//		default:
//			return null;
//		}
	}
	
	/**
	 * Saves the data value for the row
	 *
	 * @param _nRowIndex Row index
	 * @param _htFormData Form data
	 *
	 * @return Valid if row was saved successfully.
	 */
	protected int SaveDataValue(int _nRowIndex, XPHashtable _htFormData)
	{
		String sDataKey = GetDataKey(_nRowIndex, _htFormData);

		if (_htFormData.ContainsKey(sDataKey))
		{
			String[] aDataValues = (String[]) _htFormData.GetElement(sDataKey);

			if (aDataValues.length > 0)
			{
				Object oValue = null;
				String strValue = aDataValues[0];
				int nPropertyType = GetRowType(_nRowIndex);

				int nStatus = ValidateMandatoryDataValue(_nRowIndex, strValue);

				if (RepostControl.PAGE_STATUS_INVALID == nStatus)
				{
					return nStatus;
				}

				try
				{
					if (XPConvert.ToBoolean(GetRowPropertyInfo(_nRowIndex, PT_PROPIDS.PT_PROPID_PROP_HREF))
						&& (XPStringUtility.StartsWith(strValue, "javascript:") || XPStringUtility.StartsWith(strValue, "Javascript:")))
					{
						UIError myError = new UIError(UIErrorLevel.FRIENDLY,
								UIErrorScope.CURRENT_USER, m_asOwner.GetString(1752, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1752, "ptmsgs_portalbrowsingmsgs"));
						UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
							m_asOwner.GetApplication());

						return RepostControl.PAGE_STATUS_INVALID;
					}
					// Convert string to object
					oValue = GetPropValueFromString(strValue, nPropertyType);
				}
				catch (Exception e)
				{
					// There was a problem converting the string value to the object value.
					String strErrorMsg = GetRowErrorMessage(_nRowIndex, m_asOwner.GetString(98, "ptmsgs_portalinfrastructure"));
					UIError myError = new UIError(UIErrorLevel.FRIENDLY, UIErrorScope.CURRENT_USER, e, strErrorMsg, strErrorMsg);
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(), m_asOwner.GetApplication());

					return RepostControl.PAGE_STATUS_INVALID;
				}

				// Update the value
				UpdateRowInList(_nRowIndex, oValue);
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * Based on the ExpList row index (EXPLIST_COL_ID), return the property index 
	 * of the given row index.  This is different in the case of multi-valued
	 * properties.  Additional values for the same property have the same property
	 * row index, but different visual row indices.
	 * @param _nRowIndex
	 * @return
	 */
	public int GetRowID(int _nRowIndex)
	{
		return XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, UserProfileObjEditModel.EXPLIST_COL_ROWID));
	}
	
	/**
	 * Returns the name for an object
	 *
	 * @param nClassID Class ID of object
	 * @param nObjectID Object ID of object
	 *
	 * @return Name of object.
	 */
	protected String GetNameFromObjectID(int nClassID, int nObjectID)
	{
		// Get the name of the reference object
		switch (nClassID)
		{
		case PT_CLASSIDS.PT_ADMIN_FOLDER_ID:
		{
			IPTAdminCatalog ptAC = ((IPTSession)m_asOwner.GetUserSession()).GetAdminCatalog();

			if (ptAC.IsAdminFolderAccessible(nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				IPTAdminFolder ptAdminFolder = ptAC.OpenAdminFolder(nObjectID, false);

				return ptAdminFolder.GetLocalizedName();
			}

			break;
		}

		case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
		{
			IPTCatalog ptCatalog = ((IPTSession)m_asOwner.GetUserSession()).GetCatalog();

			if (ptCatalog.IsCatalogObjectAccessible(PT_CLASSIDS.PT_CATALOGFOLDER_ID, nObjectID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
			{
				IPTFolder ptFolder = ptCatalog.OpenFolder(nObjectID, false);

				return ptFolder.GetLocalizedName();
			}

			break;
		}

		default:
		{
			// Get the object manager for the object and query for the name
			IPTAdminCatalog ptAC = ((IPTSession)m_asOwner.GetUserSession()).GetAdminCatalog();
			IPTObjectManager ptOM = ptAC.GetObjectManager(nClassID);
			IPTQueryResult ptQR = ptOM.QuerySingleObject(nObjectID);

			if (0 < ptQR.RowCount())
			{
				return ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
			}

			break;
		}
		}

		return null;
	}
	
}

