package com.plumtree.portalpages.browsing.editors.userprofile;


import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 *
 * @author jennifersu
 */
public class UserProfileRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.editors.userprofile.UserProfileRepostControl");

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "UserProfileRepost";

	public static final int POSTTOSELF_ACTION_508_ADDROW = 30;
	public static final int POSTTOSELF_ACTION_508_REMOVEROW = 31;
	public static final String HTMLSUBMIT_508_ADDREMOVEROW = "in_su_508AddRemoveRow_";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UserProfileRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		for (int i = 0; i < ((UserProfileModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName)).GetNumProfilePages(); i++) {
			for (int j = 0; j < ((UserProfileModel)m_asOwner.GetModel(((EditorAS)m_asOwner).m_strModelName)).GetNumProfileSections(i); j++) {
				((ExpListControl) m_asOwner.GetControl(UserProfileEditorAS.m_strUserProfileObjEdit + i + j)).PerformRepostAction(_nAction,
					m_htFormData);
			}
		}
	}
	
	/**
	 * Get the repost action mode from the form data
	 * hashtable and set it in the member variable.
	 *
	 */
	protected void SetRepostAction()
	{
		if ((AccessStyles.LOW_BANDWIDTH == m_asOwner.GetAccessStyle()) ||
				(AccessStyles.SECTION_508 == m_asOwner.GetAccessStyle()))
		{
			// JF- If we are in 508 mode, we get the repost action from the submit button name.
			// E.g.: if the button that submitted the form was:
			//       <input type="submit" name="in_su_508PostToSelf_2" value="Done">
			//       The repost action will be 2.
			IXPEnumerator enumFormKeys = m_htFormData.GetKeys();
			String sKey;

			while (enumFormKeys.MoveNext())
			{
				sKey = (String) enumFormKeys.GetCurrent();

				if (sKey.startsWith(UserProfileRepostControl.HTMLSUBMIT_508_ADDREMOVEROW))
				{
					try
					{
						String sRepostAction = sKey.substring(UserProfileRepostControl.HTMLSUBMIT_508_ADDREMOVEROW.length(), sKey.lastIndexOf('_'));
						m_nAction = XPConvert.ToInteger(sRepostAction);

							log.Debug(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID value: " +
								m_nAction);
						
						break;
					}
					catch (Exception e)
					{
							log.Error(e, STR_MVC_CLASS_NAME + "::SetRepostAction Unable to retrieve the 508 repost " +
								"action from the submit button: " + sKey);
					}
				}
				else if (sKey.startsWith(HTMLSUBMIT_508_POSTTOSELF))
				{
					try
					{
						String sRepostAction = sKey.substring(RepostControl.HTMLSUBMIT_508_POSTTOSELF.length());
						m_nAction = XPConvert.ToInteger(sRepostAction);

							log.Debug(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID value: " +
								m_nAction);

						break;
					}
					catch (Exception e)
					{
							log.Error(e, STR_MVC_CLASS_NAME + "::SetRepostAction Unable to retrieve the 508 repost " +
								"action from the submit button: " + sKey);
					}
				}
			}
		}
		else if (m_htFormData.ContainsKey(HTMLINPUT_POSTTOSELF))
		{
			String[] data = (String[]) m_htFormData.GetElement(HTMLINPUT_POSTTOSELF);

			if ((0 != data.length) && (null != data[0]))
			{
				m_nAction = XPConvert.ToInteger(data[0]);
				
					log.Debug(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID value: " +
						m_nAction);
			}
			else
			{
					log.Warn(STR_MVC_CLASS_NAME + "::SetRepostAction Repost action ID was not in Query String.");
			}
		}
	}
}

