package com.plumtree.portalpages.browsing.gateway;

import com.plumtree.openfoundation.io.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.opendoc.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.sso.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.interpreter.filter.utils.*;
import com.plumtree.uiinfrastructure.login.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * @author daniilk
 *
 */
public class GatewayControl implements IHTTPControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_GATEWAY),
		"com.plumtree.portalpages.browsing.gateway.GatewayControl");


	public static final String STR_MVC_CLASS_NAME = "Gateway";

	/** ClassID of Intrinsic Portlet Provider */
	public static final String PROVIDER_CLSID_IGP = PT_PROVIDER_CLSIDS.PT_INTRINSICPORTLET_PROVIDER;

	private AActivitySpace m_asOwner;

	private IGatewayModel m_gwModel;
	private String m_strGatewayedURL = null;
	private String m_strMethod		 = null;
	private String m_strMyURL		 = null;
	private String m_strUIMode		 = GatewayHelpers.UI_STD;
	private String m_strRawHeaders;
	private byte[] m_arrbytePostData;
	private boolean m_bLoginTokenPresent = false;
	private WebData m_wdWebData = null;

	/* gateway parameters */
	private int m_iCommunityID = 0;
	private int m_iPortletID    = 0;
	private int m_iPageID     = 0;
	private int m_iPrefPageID = 0;
	private int m_iResourceTypeID = 43;
	private boolean m_bParsedArgs	= false;
	private boolean m_bTriedToParse = false;
	private int m_iRefreshMode = PlumtreeExtensibility.PT_REFRESH_NONE;
	private String m_strReferer = null;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Execute()
	 *
	 * In this case, the arguments XPHashtable will always be null.
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
		IPTGadgetGateway objGateway = (IPTGadgetGateway) ptSession.OpenGlobalObject(104, false);
		IPTState objAppData;
		IPTContent ptContent;
		boolean bAssociatedContentIDSent = (m_iPrefPageID & (GatewayHelpers.POPUPFLAG - 1)) > 0;
		int iAssociatedContentID = (m_iPrefPageID & (GatewayHelpers.POPUPFLAG - 1)) - 1;

		try
		{
			// Notify all other gateway components that control was called. It is ugly.
			if (!m_bParsedArgs)
			{				
				log.Warn("Could not parse the gateway URL [" + m_strMyURL + "]");				
				GatewayUtils.SetRedirectToLastHostedPage(m_asOwner, m_gwModel);
				return null;
			}

			// First thing we check is that we actually tried to parse the arguments.
			// If we did not, that's a problem and probably someone tries to use gateway
			// as the parent space. Stupid idea. But since world is full of situations like
			// that we will try to handle them gracefully. Wink-wink. ;)
			if (!m_bTriedToParse)
			{				
				log.Info("Looks like Gateway space is used as a parent space. " 
						  + "Could not parse the gateway URL [" + m_strMyURL + "]");				
				GatewayUtils.SetRedirectToLastHostedPage(m_asOwner, m_gwModel);
				return null;
			}
		
			m_gwModel.SetControlCalled();
			
			//Figure out if this is a refresh request			
			m_gwModel.SetRefreshMode(m_iRefreshMode);
			
			// The following method will either return a valid AppDataObject or NULL.
			//
			// if NULL is returned, it means that the requested gateway URL was treated
			// as return.asp in 4.x version. It is a special case, when gateway will just
			// redirect to the last visited My Page or Community Page or will close a
			// popup window. No call to the server will be made in this case.
			//
			// In case a valid AppDataObject is returned, gateway should ask server for
			// the specified resource and send the data back to the browser. Which is what
			// the rest of this function is supposed to do.
			objAppData = SetupGatewayAppDataObject(ptSession, objGateway, iAssociatedContentID);

			// If null was returned, we are done.
			if (null == objAppData)
			{
				return null;
			}

			if (ShouldRedirectOnGuestAccess(ptSession))
			{
				/* we use return value as a boolean: null vs non-null. */
				return new Redirect();
			}
			
			// If this is a refresh request, we need to set the host page query string on UserInfo.
			if (m_iRefreshMode > PlumtreeExtensibility.PT_REFRESH_NONE && null != m_strReferer && m_strReferer.length() > 0)
			{
				//Parse the URL to get the query string
				FullURL refURL = new FullURL(null, m_strReferer);
				ptSession.GetUserInfo().SetHostPageQueryString(refURL.GetURI());
			}
						
			// JYS: Update SSO cookie header before
			// making request out to remote server.
			// SSOIntegrator takes care of checking that 
			// SSO is enabled for the current subportal.
			SSOIntegrator.UpdateSSOCookieHeader(m_asOwner);				
			
			// Fix for #66477 - Need to get cached profile data from session since it is not passed in 
			// gateway request.
			// Set Profile Data if this request originated from the profile community 
			if (  m_iCommunityID == PT_INTRINSICS.PT_PROFILE_COMMUNITY ) {
				// The activityspace session contains the profile data from the last viewed profile page, set on
				// MyPortalModel.
				Object profileData = m_asOwner.GetSubSession().GetAttribute(MyPortalModel.PROFILEDATA_SESSIONVAR_NAME);
				if ( profileData != null && profileData instanceof  XPHashtable) {
					XPHashtable table = (XPHashtable)profileData;
					// set the profile data on the user info object
					IPTUserInfo currInfo = ptSession.GetUserInfo();
					log.Info("Found cached User Profile data for gateway request for portlet with id: {0} from User Profile Page for user id: {1}",
							m_iPortletID, table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERID));
					
					currInfo.AddUserInfoSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERID, (String)table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERID));
					currInfo.AddUserInfoSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERNAME, (String)table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUSERNAME));
					currInfo.AddUserInfoSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEDESCRIPTION, (String)table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILEDESCRIPTION));
					currInfo.AddUserInfoSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEUNIQUENAME, (String)table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILEUNIQUENAME));
					currInfo.AddUserInfoSetting(PlumtreeExtensibility.PT_USERINFO_PROFILEAUTHNAME, (String)table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILEAUTHNAME));
					currInfo.AddUserInfoSetting(PlumtreeExtensibility.PT_USERINFO_PROFILELOGINNAME, (String)table.GetElement(PlumtreeExtensibility.PT_USERINFO_PROFILELOGINNAME));
					
				} else {
					log.Warn("Gatewaying from Profile Community but no profile data was found for the gateway request: '{0}'"+ " originating from: '{1}'", m_strMyURL, m_strReferer);
				}
			}
			
			// If the portlet id is invalid, then we assume that this gateway link is clicked from
			// the portlet editor and the portlet object was saved on the session. 
			if (m_iPortletID == 0)
			{
				// Get the portlet object from a session
				IPTGadget ptPortlet = (IPTGadget) m_asOwner.GetSubSession().GetAttribute(GatewayUtils.GetSavedPortletName());

				// pagelet portlet use intrinsic admin editors
				if (XPStringUtility.EqualsIgnoreCase(ptPortlet.GetGadgetProviderCLSID(),PT_PROVIDER_CLSIDS.PT_REMOTEPAGELET_PROVIDER) ) 
				{
					IPTWebService ptWebService = (IPTWebService) ptSession.GetWebServices().Open(ptPortlet.GetWebServiceID(), false);
					// passing in -1 as community id to flag this prefs editor url as admin type, kinda hacky but this code is already
					// hacky. community id value read by IntrinsicPortletPrefsModel
					String returnURL = CreateIntrinsicPrefsEditorURL(ptPortlet.GetObjectID(), m_iPageID, m_iCommunityID, 
							true, iAssociatedContentID, ptWebService);
					m_gwModel.SetReturnURIContent(302, "Location: " + returnURL + "\r\n\r\n", null);
					return null;
				}
				// we are in the admin prefs, but they are implemented as multi-page wizard
				// and therefore we have to pass the URL and not the interger.
				else if ((null == m_strGatewayedURL) || XPStringUtility.EqualsIgnoreCase("?",m_strGatewayedURL) || XPStringUtility.EqualsIgnoreCase("",m_strGatewayedURL))
				{ 
					// this is the first page of the admin prefs wizard.
					ptContent = (IPTContent) objGateway.GetContent(objAppData,
							iAssociatedContentID, ptPortlet,
							m_iResourceTypeID, m_iPageID, m_iCommunityID,
							m_strUIMode, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
				}
				else
				{
					ptContent = (IPTContent) objGateway.GetContent(objAppData,
							m_strGatewayedURL, ptPortlet,
							m_iResourceTypeID, m_iPageID, m_iCommunityID,
							m_strUIMode, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
				}
			}
			else // we got a valid portlet id
			{
				// if it is a request for the pref page
				if (bAssociatedContentIDSent && ((null == m_strGatewayedURL) || XPStringUtility.EqualsIgnoreCase("",m_strGatewayedURL)))
				{
					
					// CR: this next if statement is messy since we are opening portlets and webservices to figure out intrinsic prefs pages
					// ideally this should be taken care of in the server layer to avoid opening objects
					
					//Before opening a portlet, make sure it's not a web service
					if (m_iResourceTypeID == PT_CLASSIDS.PT_GADGET_ID)
					{
						// Open the portlet to determine whether or not it is an intrinsic portlet
						IPTGadget ptPortlet = (IPTGadget) ptSession.GetGadgets().Open(m_iPortletID, false);

						// is it an intrinsic portlet?
						// also special casing for pagelet portlets - use intrinsic prefs editor to edit pagelet parameters
						if ( XPStringUtility.EqualsIgnoreCase(ptPortlet.GetGadgetProviderCLSID(),PROVIDER_CLSID_IGP) || 
							 (XPStringUtility.EqualsIgnoreCase(ptPortlet.GetGadgetProviderCLSID(),PT_PROVIDER_CLSIDS.PT_REMOTEPAGELET_PROVIDER) &&
							PT_ASSOCIATEDCONTENT.PT_ASSOCIATEDCONTENT_PREFSPAGE == iAssociatedContentID ||
							PT_ASSOCIATEDCONTENT.PT_ASSOCIATEDCONTENT_COMMUNITYPREFSPAGE == iAssociatedContentID ||
							PT_ASSOCIATEDCONTENT.PT_ASSOCIATEDCONTENT_ADMINPREFSPAGE == iAssociatedContentID) )
						{
							IPTWebService ptWebService = (IPTWebService) ptSession.GetWebServices().Open(ptPortlet.GetWebServiceID(), false);

							String returnURL;
							
							if (PT_ASSOCIATEDCONTENT.PT_ASSOCIATEDCONTENT_HELPPAGE == iAssociatedContentID) {
								returnURL = IntrinsicPortletPrefsUtils.GetHelpURL(ptWebService);
							} else {
								// RT - Check For Community Prefs ActivitySpace has been properly set or not
								// RT - If it is not set properly then we serve up the content in GadgetGateway								
								IXPPropertyBag ptProviderInfo = (IXPPropertyBag) ptWebService.GetProviderInfo();
								String strPrefsSpace = ptProviderInfo.ReadAsString(AExtensibilityConstants.PTC_I_GADGET_COMMUNITYPREFS_SPACE);
								
								if(null != strPrefsSpace){
									returnURL = CreateIntrinsicPrefsEditorURL(m_iPortletID, m_iPageID, m_iCommunityID, false, iAssociatedContentID, ptWebService);
									m_gwModel.SetReturnURIContent(302, "Location: " + returnURL + "\r\n\r\n", null);
									return null;
								}								
							}							
						}
					}

					// pass in an integer as the second arg
					ptContent = (IPTContent) objGateway.GetContent(objAppData, iAssociatedContentID, 
							m_iPortletID, m_iResourceTypeID, m_iPageID, m_iCommunityID, m_strUIMode, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
				}
				else
				{
					if (m_iResourceTypeID == PT_CLASSIDS.PT_CATALOGCARD_ID) {
						// DCA - the portlet Id is actually the card Id when trying to open a document
						int nCardId = m_iPortletID;
						Redirect peiRedirect = OpenDocControl.PerformOnClickThroughToDocPEI(nCardId, m_asOwner);
						if (null != peiRedirect) {
							return peiRedirect;
						} else {
							// DCA - add filename for header
							m_gwModel.SetFileName(m_strGatewayedURL);
						}
					}
					
					// otherwise pass in a real URL
					ptContent = (IPTContent) objGateway.GetContent(objAppData,
							m_strGatewayedURL,
							m_iPortletID, m_iResourceTypeID, m_iPageID, m_iCommunityID,
							m_strUIMode,
							PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
				}
			}

			m_gwModel.SetCommunityID(m_iCommunityID);
			m_gwModel.SetIPTContent(ptContent);
			SetTitleAndSubtitleOnModel();
		}
		catch (Exception e)
		{
			UIError errorGateway = null;
			String strUserName = "";
			String strUserID = "";
			int iLocalizedErrorMessageID = 623; // default generic message
			String strErrorMessage = "";
			String strHTMLCommentMessage = "";
			
			try
			{
				strUserName = ((IPTSession)m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserName();
				strUserID = "" + ((IPTSession)m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserID();
			}
			catch(Exception ex)
			{
				// ignore this exception, we have enough problems already...
			}
			
			strErrorMessage = "A user [" + strUserName + "] with ID [" + strUserID  
							  + "]\r\n failed to access URL [" + m_strMyURL + "]\r\n ";
			strHTMLCommentMessage = strErrorMessage;
			
			int iErrorCode = 0;
			
			// if this is a Plumtree server exception
			if( e instanceof PTException )
			{
				PTException ptEx = (PTException) e;
				iErrorCode = ptEx.GetErrorCode();
				String strPrevFailure = 
					(String)(m_asOwner.GetSubSession().GetAttribute(GatewayHandlers.GATEWAY_FAILURE_FLAG));
				String strErrorInfo = "\r\nError info: [" + ptEx.GetErrorCode() + ": " 
									  + ptEx.GetMessage() + "]\r\n" + ptEx.GetStackTrace() + "\r\n";
									  
				strHTMLCommentMessage = strErrorMessage + strErrorInfo; 
				
				// now check if it was a security error or not. If it was a security access violation
				// then we just redirect to login page and give a user chance to login. This method
				// is always called from the HandleGatewayRequest method in the interpreter and the caller
				// always treats the resulting redirect as a boolean flag (null or not-null). If it is not
				// null, then we just redirect to login.
				if (iErrorCode == PT_RESULTCODES.PT_E_ACCESSDENIED && strPrevFailure == null)
				{
					
						strErrorMessage += "because of insufficient privileges. Redirecting to login page.\r\n";
						log.Warn(strErrorMessage);
					
					m_asOwner.GetSubSession().SetAttribute(GatewayHandlers.GATEWAY_FAILURE_FLAG, 
					GatewayHandlers.GATEWAY_FAILURE_FLAG);
					return new Redirect();
				}
				else if (iErrorCode == PT_RESULTCODES.PT_E_GADGET_TIMEOUT)
				{
					strErrorMessage += 
						"because the request page timed out. You can increase gateway timeout for " 
						+ "corresponding web service to accomodate slow remote servers.";
					iLocalizedErrorMessageID = 1741; 
				}
				else if (iErrorCode == PT_RESULTCODES.PT_E_ACCESSDENIED)
				{
					strErrorMessage += "because of insufficient privileges.";
					iLocalizedErrorMessageID = 1740;
				}
				else if (iErrorCode == PT_RESULTCODES.PT_E_GADGET_RUNTIME_ERROR)
				{
					strErrorMessage += "because of the network errors. " +
										"Enable WebDownloadParallel Warn and Error tracing to get more info.";
					iLocalizedErrorMessageID = 1742;
				}
				else if (iErrorCode == PT_RESULTCODES.PT_E_MYPORTAL_GADGETDISABLED)
				{
					strErrorMessage += "because a portlet or webservice [" + m_iPortletID 
									    + "] was disabled by the administrator.";
					iLocalizedErrorMessageID = 1743;
				}
				else
				{
					iLocalizedErrorMessageID = 623;
					strErrorMessage = strHTMLCommentMessage;					
				}				
			}
			else // if this is NOT a plumtree server exception, but some other generic exception
			{
				// if this is a generic Java exception, we will try to get as much as we can, 
				// but it won't be much
				strErrorMessage += "\r\nServer error: [" + e.getMessage() + "]";
				strHTMLCommentMessage = strErrorMessage;
				iLocalizedErrorMessageID = 623;				
			}

			
			log.Warn(e, strErrorMessage);
			
			String strLocalizedErrorMessage = m_asOwner.GetString(iLocalizedErrorMessageID, "ptmsgs_portalbrowsingmsgs");
			
			errorGateway = new UIError(UIErrorLevel.SERIOUS, UIErrorScope.CURRENT_USER,
									   strLocalizedErrorMessage, strHTMLCommentMessage);
			
			if (m_wdWebData != null)
			{
				// we want to make sure that if we are displaying error page
				// we use all the default headers (no cache, UTF-8, etc.)
				m_wdWebData.SetSuppressAutomaticHeaders(false);
			}
			
			//Only raise an error if we are NOT in Refresh mode. Otherwise, it won't be cleared.
			if (((IGatewayModelRO)m_gwModel).GetRefreshMode() == PlumtreeExtensibility.PT_REFRESH_NONE)
			{
				UIErrorHandler.RaiseError(errorGateway,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());
			}

			m_gwModel.SetError(iErrorCode, strLocalizedErrorMessage, strHTMLCommentMessage);
		}

		m_asOwner.GetSubSession().RemoveAttribute(GatewayHandlers.GATEWAY_FAILURE_FLAG);
		
		// in case gateway control will ever be cached (it shouldn't)
		// we want to release a reference to the webdata object
		m_wdWebData = null; 
		return null;
	}

	/**
	 * Creates URL to preference editor
	 * 
	 * @param iAssociatedContentID
	 * @param ptWebService
	 * @return
	 */
	private String CreateIntrinsicPrefsEditorURL(int portletId, int pageId, int commId, boolean isAdminPref, int iAssociatedContentID, IPTWebService ptWebService)
	{
		ASURL asURLPortletPrefs = IntrinsicPortletPrefsUtils.GetPrefsURL(ptWebService, pageId, commId, portletId, isAdminPref, 
				iAssociatedContentID, m_asOwner);
				
		String returnURL = asURLPortletPrefs.GetURLAsString();
		returnURL = IntrinsicPortletPrefsUtils.GetAccessStyleComplientPortletPrefURL(returnURL, m_asOwner);
		return returnURL;
	}

	private boolean ShouldRedirectOnGuestAccess(IPTSession ptSession)
	{
		// if this is a guest user
		if (ptSession.GetSessionInfo().CheckCurrentUserIsGuest())
		{
			// and
			if ( (m_iPrefPageID & GatewayHelpers.REDIRECTGUEST) != 0 // REDIRECT GUEST flag is set
				|| m_bLoginTokenPresent)							  // or RememberMyPassword cookie is set
			{
				// then redirect to login page and to the gateway back again
				return true;
			}
		}
		// otherwise continue executing the gateway control
		return false;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new GatewayControl();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_gwModel     = (IGatewayModel) model;
		m_asOwner     = space;
	}

	/* the URL that is passed into this function should look like:
	 * [/gateway/PAGE-SPECIAL-ARGS_PREFID_GID_CID_PID/gatewayed_URL.jsp?argtoremoteserver1=1&argtoremoteserver2=2]
	 * This function tries to parse this URL and set all the member variables.
	 *
	 * All the comments in this function are based on the sample URL above.
	 *
	 *         -- Moose
	 */
	public boolean ParseGatewayURL(String strURL)
	{
		/* Set the default resource type id if it is not specified in the URL */
		m_iResourceTypeID = PT_CLASSIDS.PT_GADGET_ID;

		int arr_iGWParams[] = new int[6];

		/* try to find "/gateway/PAGE_SPECIAL_ARGS_" substring */
		int iStartIndex = strURL.indexOf(GatewayHelpers.GATEWAY_URL_PREFIX);

		/* if it was not found - URL is malformed. Return false */
		if (-1 == iStartIndex)
		{
			return false;
		}
		//fixing j2c compile error -mgs
		String sGatewayUrlPrefix = GatewayHelpers.GATEWAY_URL_PREFIX;
		/* Skip the [/gateway/PAGE-SPECIAL-ARGS_] part */
		iStartIndex += sGatewayUrlPrefix.length();

		/* Try to find the beginning of the gateway URL [/gatewayed_URL.jsp?...] */
		int iStartGatewayURLIndex = strURL.indexOf("/", iStartIndex);

		/* If we could not find it - return false. */
		if (-1 == iStartGatewayURLIndex)
		{
			return false;
		}

		/* put [gatewayed_URL.jsp?...] part into a separate string object. This is just for readability. */
		String strGatewayURL    = strURL.substring(iStartGatewayURLIndex + 1); /* +1 is to skip the "/" symbol */
		String strGatewayParams = strURL.substring(iStartIndex,
				iStartGatewayURLIndex);

		/* a fix for .NET and also make this component more bullet-proof
		 *
		 * The basic idea is that if gatewayed URL start with "?", then
		 * it means that the actual URL has been missing and only the query string was
		 * passed in. In order to make sure that such URLs won't cause problems in the
		 * editors, when we access associated content by ID, rather than by URL i just
		 * remove it here, since the code in the CheckActivityRightsAndExecute relies
		 * on the fact that the URL should be blank.
		 *
		 * 		-- moose
		 */
		if (strGatewayURL == null || strGatewayURL.length() < 1 || strGatewayURL.charAt(0) == '?')
		{
			strGatewayURL = "";
		}
		
		log.Debug("ParseGatewayURL(): " + "GATEWAY URL: " + strURL);
		log.Debug("ParseGatewayURL(): " + "GATEWAYED URL: " + strGatewayURL);
		log.Debug("ParseGatewayURL(): " + "PARAMETERS: " + strGatewayParams);
				
		m_strGatewayedURL = FixURLInTomcat(strGatewayURL);		
		
		m_strGatewayedURL = HttpUtils.GetSafeURL( m_strGatewayedURL );
		
		m_strGatewayedURL = FixSpacesInURL(m_strGatewayedURL);

		/* parse the parameters part of the URL */
		int iParamStart = 0;
		int iParamEnd   = 0;
		boolean bLastParamFound = false;
		int i = 0;

		for (i = 0; i < 6 && !bLastParamFound; i ++)
		{
			iParamEnd	    = strGatewayParams.indexOf('_', iParamStart);
			if (-1 == iParamEnd)
			{
				iParamEnd	    = strGatewayParams.length();
				bLastParamFound = true;
			}

			arr_iGWParams[i] = XPConvert.ToInteger
									(strGatewayParams.substring
										(iParamStart, iParamEnd)
									);
			iParamStart     = iParamEnd + 1;
		}

		m_iPrefPageID = arr_iGWParams[0];

		/* if we found 6 params, skip the first one (user id) */
		i = (i < 6) ? 0 : 1;

		m_iPortletID = arr_iGWParams[i+1];
		m_iCommunityID = arr_iGWParams[i+2];
		m_iPageID = arr_iGWParams[i+3];
		m_iResourceTypeID = arr_iGWParams[i+4];

		
			log.Debug("ParseGatewayURL(): " + "PrefID=" + m_iPrefPageID +
				"; PortletID=" + m_iPortletID + "; CommunityID=" +
				m_iCommunityID + "; PageID=" + m_iPageID + "; ResourceTypeID=" +
				m_iResourceTypeID);
			log.Debug("ParseGatewayURL(): " + "Gateway URL: " + m_strGatewayedURL);
		

		return true;
	}

	private String FixSpacesInURL(String strURL)
	{
		// if we got null - return null
		if (null == strURL) return null;

		// declare variables and set their value
		int iQSStart = -1;
		String strQS = "";
		String strURLToFix = "";

		// find the beginning of the query string
		iQSStart = strURL.indexOf("?");

		// save the query string in the local variable if it was found
		if (iQSStart > -1)
		{
			strQS = strURL.substring(iQSStart);
			strURLToFix = strURL.substring(0, iQSStart);
		}
		else
		{
			strQS = "";
			strURLToFix = strURL;
		}

		int iPreviousLoc = 0;
		int iSpaceLoc = 0;
		XPStringBuilder strFixedURL = new XPStringBuilder(strURL.length() * 3);

		do
		{
			iSpaceLoc = strURLToFix.indexOf(' ', iPreviousLoc);
			if (iSpaceLoc > -1)
			{
				strFixedURL.Append(strURLToFix.substring(iPreviousLoc, iSpaceLoc) + "%20");
				iPreviousLoc = iSpaceLoc + 1;
			}
			else
			{
				strFixedURL.Append(strURLToFix.substring(iPreviousLoc));
				break;
			}
		} while (iPreviousLoc < strURLToFix.length());
		strFixedURL.Append(strQS);

		return strFixedURL.ToString();
	}

	/**
	 * This function is not currently used.
	 *
	 * @param strHeaderValue
	 *
	 * @return
	 */
	public boolean ParseSpecialHeader(String strHeaderValue)
	{
		/* Set the default resource type id in case it is not passed in the header */
		m_iResourceTypeID = PT_CLASSIDS.PT_GADGET_ID;

		/* Try to find the beginning of the gateway URL [/gatewayed_URL.jsp?...] */
		int iStartGatewayURLIndex = strHeaderValue.indexOf("/");

		/* If we could not find it - return false. */
		if (-1 == iStartGatewayURLIndex)
		{
			return false;
		}

		/* put [gatewayed_URL.jsp?...] part into a separate string object. This is just for readability. */
		m_strGatewayedURL = strHeaderValue.substring(iStartGatewayURLIndex + 1); /* +1 is to skip the "/" symbol */

		String strGatewayParams = strHeaderValue.substring(0,
				iStartGatewayURLIndex);

		
			log.Debug("ParseSpecialHeader() " + "HeaderValue: " + strHeaderValue);
			log.Debug("ParseSpecialHeader() " + "Gatewayed URL: " +
				m_strGatewayedURL);
			log.Debug("ParseSpecialHeader() " + "Parameters: " + strGatewayParams);
		

		/* parse the parameters part of the URL */
		int iParamStart = 0;
		int iParamEnd   = strGatewayParams.indexOf('_');

		if (-1 == iParamEnd)
		{
			return false;
		}

		m_iPrefPageID     = XPConvert.ToInteger(strGatewayParams.substring(
					iParamStart, iParamEnd));

		iParamStart     = iParamEnd + 1;
		iParamEnd	    = strGatewayParams.indexOf('_', iParamStart);

		if (-1 == iParamEnd)
		{
			return false;
		}

		m_iPortletID     = XPConvert.ToInteger(strGatewayParams.substring(
					iParamStart, iParamEnd));

		iParamStart		   = iParamEnd + 1;
		iParamEnd		   = strGatewayParams.indexOf('_', iParamStart);

		if (-1 == iParamEnd)
		{
			return false;
		}

		m_iCommunityID     = XPConvert.ToInteger(strGatewayParams.substring(
					iParamStart, iParamEnd));

		/* this is how it should be. Uncomment it when the corresponding server change is coded. */
		/*
		iParamStart = iParamEnd + 1;
		iParamEnd = strGatewayParams.indexOf('_', iParamStart);
		if (-1 == iParamEnd) return false;
		m_iPageID = XPConvert.ToInteger(strGatewayParams.substring(iParamStart, iParamEnd));

		iParamStart = iParamEnd + 1;
		iParamEnd = strGatewayParams.indexOf('_', iParamStart);
		if (-1 == iParamEnd) iParamEnd = strGatewayParams.length();
		m_iResourceTypeID = XPConvert.ToInteger(strGatewayParams.substring(iParamStart, iParamEnd));
		*/
		/* this code handles gateway URLs with or without the resource ID in the params list.
		 * It should be removed once the server change in the transformers is coded.
		 */
		iParamStart     = iParamEnd + 1;
		iParamEnd	    = strGatewayParams.indexOf('_', iParamStart);

		if (-1 == iParamEnd)
		{
			iParamEnd     = strGatewayParams.length();
			m_iPageID     = XPConvert.ToInteger(strGatewayParams.substring(
						iParamStart, iParamEnd));
		}
		else
		{
			m_iPageID			  = XPConvert.ToInteger(strGatewayParams.substring(
						iParamStart, iParamEnd));
			iParamStart			  = iParamEnd + 1;
			iParamEnd			  = strGatewayParams.indexOf('_', iParamStart);

			if (-1 == iParamEnd)
			{
				iParamEnd = strGatewayParams.length();
			}

			m_iResourceTypeID = XPConvert.ToInteger(strGatewayParams.substring(
						iParamStart, iParamEnd));
		}

		
			log.Debug("ParseGatewayURL(): " + "PrefID=" + m_iPrefPageID +
				"; PortletID=" + m_iPortletID + "; CommunityID=" +
				m_iCommunityID + "; PageID=" + m_iPageID + "; ResourceTypeID=" +
				m_iResourceTypeID);
			log.Debug("ParseGatewayURL(): " + "Gateway URL: " + m_strGatewayedURL);
		

		return true;
	}

	/**
	 *
	 *
	 * @param xpRequest
	 * @param pageData
	 */
	public void SetHTTPItems(IXPRequest xpRequest, IWebData pageData)
	{
		GetPostData(xpRequest);

		if (XPStringUtility.CompareIgnoreCase(xpRequest.GetScheme(),HttpUtils.HTTPS_SCHEME) == 0
			|| PTConfigHelper.GetSecurityMode() == 3)
		{
			m_asOwner.SetIsASSecured(true);
		}
		else
		{
			m_asOwner.SetIsASSecured(false);
		}

		m_wdWebData = (WebData)pageData; 
		m_wdWebData.SetSuppressAutomaticHeaders(true);
		m_wdWebData.RequireNonEmptyBody(false);
		m_strUIMode = GatewayHelpers.GetUIMode(xpRequest, m_asOwner);
		m_gwModel.SetUIMode(m_strUIMode);
		
		// Get the headers
		GetRawHeaders(xpRequest);
		// DCA - see if there's a document click through URL
		m_strMyURL = (String) m_asOwner.GetSubSession().GetAttribute(OpenDocControl.STR_MVC_CLASS_NAME);
		if (null == m_strMyURL) {
			// DCA - use current request URL
			m_strMyURL = m_asOwner.GetCurrentRequestURL();
		} else {
			// DCA - clear attribute so that we don't keep getting it
			m_asOwner.GetSubSession().RemoveAttribute(OpenDocControl.STR_MVC_CLASS_NAME);
		}
		log.Debug("SetXPRequest(): Gateway URL: [" + m_strMyURL + "]");						

		// Parse the URL
		m_gwModel.SetUserURL(m_strMyURL);
		m_bParsedArgs = ParseGatewayURL(m_strMyURL);
		m_bTriedToParse = true;

		/* Get the method of the request (PUT or GET) */
		m_strMethod = xpRequest.GetMethod();
		/* Check if the RemeberMyPassword cookie is present */
		m_bLoginTokenPresent = IsLoginTokenPresent(xpRequest);

		return;
	}

	/**
	 * @param iPageID
	 * @param iCommunityID
	 *
	 * @return
	 */
	private String ConstructRealReturnURL()
	{
		/* Get the value from the session */
		String strURL = (String) (m_asOwner.GetSubSession().GetAttribute(HttpUtils.RETURN_URI));

		/* if the session is valid, then just return the value that was stored there.
		 * In case, when session has expired the following condition will not be
		 * satisfied and so we will construct the URL ourselves.
		 */
		if ((null != strURL) && (strURL.length() > 0))
		{
			return strURL;
		}

		return TaskAPIUISubPortal.GetURLForMyHome( m_asOwner ).GetFullURL();		
	}

	/**
	 * @return
	 */
	private String ConstructReturnURI()
	{
		String strReturnURL = GatewayHelpers.ConstructReturnURI(m_asOwner, m_iPageID,
								m_iCommunityID, (m_iPrefPageID & GatewayHelpers.POPUPFLAG) == GatewayHelpers.POPUPFLAG,
								(m_iPrefPageID & GatewayHelpers.REFRESHFLAG) == GatewayHelpers.REFRESHFLAG);
		return strReturnURL;
	}

	/**
	 *
	 *
	 * @param strURL
	 *
	 * @return
	 */
	private String FixURLInTomcat(String strURL)
	{
		if (null == strURL)
		{
			return null;
		}

		if (XPStringUtility.ToLowerCase(strURL).startsWith("http:/") &&
				(strURL.charAt(6) != '/'))
		{
			return "http://" + strURL.substring(6);
		}

		if (XPStringUtility.ToLowerCase(strURL).startsWith("https:/") &&
				(strURL.charAt(7) != '/'))
		{
			return "https://" + strURL.substring(7);
		}

		return strURL;
	}

	/**
	 * Retreive the binary body of the request
	 */
	private void GetPostData(IXPRequest xpRequest)
	{
		/* Get the input stream */
		XPInputStream xpInputStream = xpRequest.GetInputStream();

		/* Find out the length of the body */
		int iRequestContentLength = xpRequest.GetContentLength();
		int iStreamContentLength  = xpInputStream.GetAvailableBytes();

		int iContentLength = (iRequestContentLength > iStreamContentLength)
			? iRequestContentLength : iStreamContentLength;

		if (iStreamContentLength < 0)
		{			
			log.Info("GetPostData(): Request.GetAvailableBytes() call returned negative number! Either you are running WebSphere or some other code read the body.");
		}

		if (iContentLength < 0)
		{
			log.Info("GetPostData(): Request.GetContentLength() call returned negative number! Looks like you are running WebSphere. Engaging work-around...");
			iContentLength = 0;
			iStreamContentLength = 0;
		}
		
		/* allocate memory for the binary body */
		m_arrbytePostData = new byte[iContentLength];

		/* read the binary body from the input stream */
		int iBytesRead = 0;

		while (iBytesRead < iContentLength)
		{
			int iBytesReadLastTime = xpInputStream.Read(m_arrbytePostData,
					iBytesRead, iContentLength - iBytesRead);

			if (iBytesReadLastTime < 0)
			{
				break;
			}

			iBytesRead += iBytesReadLastTime;
		}

		
			log.Debug("GetPostData: The length of the input stream is " +
				iStreamContentLength + " bytes");
			log.Debug("GetPostData: The content length of the request body is " +
				iRequestContentLength + " bytes");
			log.Debug("GetPostData: The content length is " + iContentLength +
				" bytes");
			log.Debug("GetPostData: Read " + iBytesRead + " bytes of binary body.");
		
	}

	/**
	 * Get the headers of the request.
	 * 
	 *         -- Moose
	 */
	private boolean GetRawHeaders(IXPRequest xpRequest)
	{
		m_strRawHeaders = "";

		XPStringBuilder strbRawHeaders = new XPStringBuilder(10240);
		IXPEnumerator xpenumHeaders    = xpRequest.GetHeaderNames();

		while (xpenumHeaders.MoveNext())
		{
			String strHeaderName  = (String) xpenumHeaders.GetCurrent();
			String strHeaderValue = xpRequest.GetHeader(strHeaderName);
			
			log.Debug( "GetRawHeaders: Adding request header [" 
						+ strHeaderName + ": " + strHeaderValue + "] to raw headers.");			

			if (XPStringUtility.EqualsIgnoreCase(GatewayHelpers.PT_REQUEST_TYPE_HEADER, strHeaderName))
			{
				if (XPStringUtility.EqualsIgnoreCase(GatewayHelpers.PT_PORTLET_REFRESH_HEADER_VALUE, strHeaderValue))
				{
					m_iRefreshMode = PlumtreeExtensibility.PT_REFRESH_PORTLET;
				}
				else if (XPStringUtility.EqualsIgnoreCase(GatewayHelpers.PT_CLIENT_SIDE_HEADER_VALUE, strHeaderValue))
				{
					m_iRefreshMode = PlumtreeExtensibility.PT_REFRESH_CLIENT_SIDE;
				}
			}
			else
			{
				//Save the referer header
				if (XPStringUtility.EqualsIgnoreCase(GatewayHelpers.PT_REFERER_HEADER, strHeaderName))
				{
					m_strReferer = strHeaderValue;
				}
				strbRawHeaders.Append(strHeaderName);
				strbRawHeaders.Append(": ");
				strbRawHeaders.Append(strHeaderValue);
				strbRawHeaders.Append("\r\n");		
			}
		}
		m_strRawHeaders = strbRawHeaders.ToString();
		
		log.Debug("GetRawHeaders: Raw headers are set to [" + m_strRawHeaders + "]");				
		return false;
	}

	/**
	 * @return
	 */
	private boolean HandleRequestToReturnURL()
	{
		// if we are passed all 0's, then this call is equivalent to "return.asp" in 4.x versions.
		// we should figure out what the return URI should be and redirect to it.
		if ((m_iPrefPageID & GatewayHelpers.RETURNFLAG) != 0)
		{
			// if it is a popup that should also refresh the parent page, 
			// then we just need to close the popup and refresh the parent page.
			if ((m_iPrefPageID & GatewayHelpers.POPUPREFRESHFLAG) == GatewayHelpers.POPUPREFRESHFLAG)
			{
				if (PTConfigHelper.GetSecurityMode() != 1)
				{
					m_gwModel.SetReturnURIContent(200, "Content-Type: text/html\r\n\r\n",
						GatewayHelpers.CLOSEPOPUPANDREFRESHJAVASCRIPT);
				}
				else
				{
					// In security mode 1 IE does not allow you to access a parent window
					// if it uses a different access scheme (HTTP vs. HTTPS). This causes
					// the popup window not to close. In order to avoid it, we just close
					// the popup without refreshing the parent page.
					m_gwModel.SetReturnURIContent(200, "Content-Type: text/html\r\n\r\n",
						GatewayHelpers.CLOSEPOPUPJAVASCRIPT);					
				}
			}			
			// if it is a popup, then we just need to close it.
			else if ((m_iPrefPageID & GatewayHelpers.POPUPFLAG) == GatewayHelpers.POPUPFLAG)
			{
				m_gwModel.SetReturnURIContent(200, "Content-Type: text/html\r\n\r\n",
					GatewayHelpers.CLOSEPOPUPJAVASCRIPT);
			}
			else // otherwise we need to leave the window open and just redirect to the last visited MyPage or CommunityPage.
			{
				String strURL = ConstructRealReturnURL();

				/* now we need to get all the extra query string argumets that could have been
				 * appended to the return URI and stick them at the end of the real URI. For example,
				 * if return URI looked like "http://localhost/HTTPServlet/gateway/PTARGS_16_0_0_0_0_43/a?b=c&d=e&f=g&#216"
				 * then we need to stick "d=e&f=g&#216" at the end of the strURL.
				 *
				 * 		-moose
				 */
				int iAmpIndex = m_strGatewayedURL.indexOf('&');
				/* if the first ampersand is not the last character in the string */
				if ( (iAmpIndex > -1) && (iAmpIndex < (m_strGatewayedURL.length() - 1)))
				{
					/* append the rest of the return URI to the new URL we are redirecting to */
					strURL += m_strGatewayedURL.substring(iAmpIndex+1, /* skip the ampersand itself */
														  m_strGatewayedURL.length());
				}


				
					log.Debug("Execute(): Setting return URI to [" + strURL + "]");
				

				// if we are redirecting from secure URL to non-secure URL
				if (XPStringUtility.ToLowerCase(strURL).startsWith(ConfigHelper.HTTP_SCHEME) 
					&& m_asOwner.GetIsSecuredSpace())
					{
						// we need to do a meta refresh, otherwise the user will get
						// a popup warning about leaving secure zone.
						m_gwModel.SetReturnURIContent(200,
							"Content-Type: text/html\r\n\r\n",
							"<html><head><meta HTTP-EQUIV=\"REFRESH\" CONTENT=\"0; URL=" 
							+ GeneralHelpers.Replace(strURL, ";", "%3B") + "\"></head></html>");						
					}
					else
					{
						// on all other cases just redirect.
						m_gwModel.SetReturnURIContent(302,
							"Location: " + strURL + "\r\n\r\n", null);
					}
			}

			return true;
		}

		// the request was not for the return page.
		return false;
	}

	/**
	 *
	 *
	 * @param ptSession
	 * @param objGateway
	 *
	 * @return
	 */
	private IPTState SetupGatewayAppDataObject(IPTSession ptSession, IPTGadgetGateway objGateway, int contentId)
	{
		IPTState objAppData;
		int iCanSetAdminPrefs     = PlumtreeExtensibility.PT_CAN_NOT_SET;

		// make sure that community id is valid (>= 0).
		if (m_iCommunityID < 0)
		{
			m_iCommunityID = 0;
		}

		// Check if it is an admin prefs page (it will also be true in case 0_0_0_0, but that does not matter)
		if (m_iPortletID < 1)
		{
			iCanSetAdminPrefs = PlumtreeExtensibility.PT_CAN_SET;
		}

		// check if we need to issue a redirect. This happens either when return URI is requested
		// or when security mode needs to be fixed.
		if (HandleRequestToReturnURL() || NeedsSecurityRedirect())
		{
			return null;
		}
		
		// #Fix for bug 8374723 
		int allowExternalRedirects = 1;
		try {
			allowExternalRedirects = 
				PTConfigHelper.GetConfigVariableAsInt(GatewayHelpers.OPENCONFIG_GATEWAY_COMPONENT, 
						GatewayHelpers.OPENCONFIG_ALLOW_EXTGWREDIRECTS, "value", m_asOwner);
		} catch (XPException e) {
			// if it isn't there assume it is allowed
		}
		

		// get initialized app data object
		objAppData = AppDataObject.GetAppDataObject(m_iCommunityID, m_iPageID, m_iPrefPageID,
													m_strMyURL, m_asOwner, false);

		// set some fields on it
		objAppData.Add(PlumtreeExtensibility.PT_RETURN_URI_KEY, ConstructReturnURI(), 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_CAN_SET_ADMIN_KEY, iCanSetAdminPrefs, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_HTTP_METHOD_KEY, m_strMethod, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_HEADERS_KEY, m_strRawHeaders, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_BINARY_BODY_KEY, m_arrbytePostData, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_TOTAL_BYTES_KEY, m_arrbytePostData.length, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_CLASS_ID_KEY, m_iResourceTypeID, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_OBJECT_ID_KEY, m_iPortletID, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_REFRESH_TYPE_KEY, m_iRefreshMode, 0, true);
		objAppData.Add(PlumtreeExtensibility.PT_ASSOCIATED_CONTENTID_KEY, contentId, 0, true);
					
		objAppData.Add(PlumtreeExtensibility.PT_ALLOW_EXTERNAL_REDIRECTS, allowExternalRedirects, 0, true);
		
		return objAppData;
	}

	boolean IsLoginTokenPresent(IXPRequest xpRequest)
	{
		XPCookie [] arrCookies = xpRequest.GetCookies();

		if (arrCookies == null) return false;

		for (int i = 0; i < arrCookies.length; i ++)
		{
			XPCookie cookie = arrCookies[i];

			if (LoginHelper.LOGIN_TOKEN_COOKIE_NAME.equals(cookie.GetName()))
			{
				
					log.Debug("Found a login token.");
				

				if (!LoginHelper.LOGIN_TOKEN_COOKIE_DEFUNCT_VALUE.equals(cookie.GetValue()))
				{
					return true;
				}
			}
		}
		return false;
	}

	boolean NeedsSecurityRedirect()
	{
		int iSecurityMode = PTConfigHelper.GetSecurityMode();
		int iAssociatedContentID = m_iPrefPageID & 0x7;
		String strHTTPPrefix = "http://";

		String strSecureAppBaseURL = 
			ConfigHelper.GetApplicationBaseURL(ConfigHelper.GetNormalizedBaseURL(m_strMyURL), 
												true);

		/* GetApplicationBaseURL returns URL with "?" appended. Since it is too late to change 
		 * it i will just fix the URL here. In case someone will ever decide to fix it, we will
		 * take an intelligent approach and search for "?" first, instead of blindly removing
		 * the last character.
		 * 		-- Moose
		 */
		if (null != strSecureAppBaseURL)
		{
			int iQuestionMarkLocation = strSecureAppBaseURL.indexOf("?");
			if (-1 != iQuestionMarkLocation)
			{
				strSecureAppBaseURL = strSecureAppBaseURL.substring(0, iQuestionMarkLocation);
			}
		}

		switch(iSecurityMode)
		{
			case 1:
				if (XPStringUtility.StartsWith(XPStringUtility.ToLowerCase(m_strMyURL), strHTTPPrefix)
					&& (iAssociatedContentID != 0) && (iAssociatedContentID != GatewayHelpers.HELP) 
					&& (iAssociatedContentID != GatewayHelpers.PORTLETCONTENT))
				{
//					String strNewURL = strSecureAppBaseURL + GatewayHelpers.GATEWAY_URL_PREFIX
//										+ m_iPrefPageID + "_0_" + m_iPortletID + "_" + m_iCommunityID
//										+ "_" + m_iPageID + "_" + m_iResourceTypeID + "/"
//										+ m_strGatewayedURL;
					String strNewURL = 
						GatewayHelpers.ConstructGatewayURL(strSecureAppBaseURL, m_iPortletID, m_iCommunityID, m_iPageID, m_iPrefPageID, m_iResourceTypeID, 0, m_strGatewayedURL);
					m_gwModel.SetReturnURIContent(302, "Location: " + strNewURL + "\r\n\r\n", null);
					return true;
				}
				break;
			case 2:
				if (XPStringUtility.StartsWith(XPStringUtility.ToLowerCase(m_strMyURL), strHTTPPrefix))
				{
//					String strNewURL = strSecureAppBaseURL + GatewayHelpers.GATEWAY_URL_PREFIX
//										+ m_iPrefPageID + "_0_" + m_iPortletID + "_" + m_iCommunityID
//										+ "_" + m_iPageID + "_" + m_iResourceTypeID + "/"
//										+ m_strGatewayedURL;
					String strNewURL = 
						GatewayHelpers.ConstructGatewayURL(strSecureAppBaseURL, m_iPortletID, m_iCommunityID, m_iPageID, m_iPrefPageID, m_iResourceTypeID, 0, m_strGatewayedURL);
					m_gwModel.SetReturnURIContent(302, "Location: " + strNewURL + "\r\n\r\n", null);
					return true;
				}
				break;
			case 3:
				m_strMyURL = HttpUtils.GetNormalizedURL(m_strMyURL, true);
				
					log.Debug("Normalized URL for the security mode 3. New URL is ["
								 + m_strMyURL + "]");
				
		}
		return false;
	}
	
	/**
	 * Figures out and correctly sets the title and subtitle on the model.
	 *
	 */
	void SetTitleAndSubtitleOnModel()
	{
		try
		{
			String strPageName = "";
			String strRealmName = m_asOwner.GetString(625, "ptmsgs_portalbrowsingmsgs");
			
			//Set the default PageName and RealmName so that in case there is an error thrown below,
			//the values are not null.
			m_gwModel.SetTitle(strRealmName);
			m_gwModel.SetSubtitle(strPageName);
			
			//Need to figure out the appropriate page name and realm name if we're in portlet refresh  mode
			//Also, want to make sure we're on a mypage with portlets, not some other gateway page
			//Also, we check if the page is an actual page and has a valid id to get pageinfo values.
			if((m_iRefreshMode > PlumtreeExtensibility.PT_REFRESH_NONE) &&
					(m_iPortletID > 0) && (m_iResourceTypeID == PT_CLASSIDS.PT_GADGET_ID) && (m_iPageID > 0))
			{
				boolean bIsMypage = true;
				if (m_iCommunityID > 0)
				{
					bIsMypage = false;
				}

				IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

				if (bIsMypage)
				{
					strRealmName = m_asOwner.GetString(672, "ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					IPTCommunityInfo ptCommInfo = ((IPTCommunityManager)ptSession.GetCommunities()).CachedOpenCommunityInfo(m_iCommunityID, false);
					strRealmName = ptCommInfo.GetName();
				}
				
				IPTPageInfo ptPageInfo = ((IPTPageManager)ptSession.GetPages()).CachedOpenPageInfo(m_iPageID, bIsMypage, false);
				strPageName = ptPageInfo.GetName();
				
				m_gwModel.SetTitle(strRealmName);
				m_gwModel.SetSubtitle(strPageName);
			
			// This condition is to set the title when the Gateway Page is in
			// community and displays an outside page in hosted display mode.
			// in this scenario we don't have any portlet refresh.
			} else if (m_iCommunityID > 0) {
				
				IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
				IPTCommunityInfo ptCommInfo = ((IPTCommunityManager)ptSession.GetCommunities()).CachedOpenCommunityInfo(m_iCommunityID, false);
				strRealmName = ptCommInfo.GetName();
				
				m_gwModel.SetTitle(strRealmName);
				
			}
		}
		catch(Exception e)
		{
			//This exception really isn't a huge deal. In the worst case the title and subtitles will be empty.
			log.Warn("Could not set title and subtitle on the gateway page." + e.getMessage());
		}
	}
}

