package com.plumtree.portalpages.browsing.gateway;

import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.portalpagesperf.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author daniilk
 *
 */
public class GatewayHostedDP extends PlumtreeDP
{
	public static final String STR_MVC_CLASS_NAME = "GatewayHosted";

	/**
	 * 
	 *
	 * @param webData 
	 */
	public void Display(IWebData webData)
	{
		IGatewayModelRO gwModel = (IGatewayModelRO) m_asOwner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);

		GatewayUtils.AddHeadersToResponse(gwModel.GetHeaders(), webData);
		super.Display(webData);
		webData.SetStatus(gwModel.GetStatus());
	}

	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		IGatewayModelRO gwModel = (IGatewayModelRO) m_asOwner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
		String strSubtitle = gwModel.GetSubtitle();
		
		if (strSubtitle == null) strSubtitle = "";
		
		return strSubtitle;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		IGatewayModelRO gwModel = (IGatewayModelRO) m_asOwner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
		String strTitle = gwModel.GetTitle();
		if (strTitle == null || strTitle.length() < 1)
		{ 
			strTitle = HttpUtils.GetHeaderValue(gwModel.GetHeaders(), "CSP-Title-Bar");
		}
		return strTitle;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()
	{
		GatewayModel gwModel = (GatewayModel) m_asOwner.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
		HTMLElement result   = new HTMLElementCollection();

		HTMLElement resultHTML = gwModel.GetDisplayElement(); 
		String strHTML = null;
		if (resultHTML != null)
		{
			strHTML = resultHTML.GetDisplayString();
		}

		// increment perfcounter
		PerfCounters.INSTANCE.IncrementCounter( PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_CLICKTHROUGHS);

		if (null != strHTML)
		{
			result.AddInnerHTMLString(strHTML);
		}
		else
		{
			result.AddInnerHTMLString(
				"<B>" + m_asOwner.GetString(623, "ptmsgs_portalbrowsingmsgs") + "</B>\r\n"
				// the following line can stay non-localized, since it's going to be in the HTML comments
				// and will not be displayed in the browser.
				+ "<!-- GetTextBody call returned NULL. There was a problem accessing gateway content. -->");
		}

		// Moose: save the url on the session
		if (gwModel.GetUserURL() != null)
		{
			m_asOwner.GetSubSession().SetAttribute(GatewayHelpers.LAST_VISITED_HOSTED_PAGE, gwModel.GetUserURL());
		}
		
		return result;
	}
}

