package com.plumtree.portalpages.browsing.gateway;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.tags.xml.*;
import com.plumtree.server.*;
import com.plumtree.server.impl.portlet.providers.*;

/**
 * This class contains utilities for the integration between the
 * Gateway and the Tag Engine.
 */
public class TagEngineUtils
{
	/**
	 * This method determines whether or not we will need to include the
	 * JS includes data in the head.  If this page is hosted, then the
	 * portal banner will handle the JS includes and we don't have to.
	 * Hosted mode will make this method return false.
	 * 
	 * @param _markupList
	 * @return true if we need to add the JSIncludes data.
	 */
	public boolean NeedsCSAPIinNonHostedPage(XPArrayList _markupList)
	{
		boolean bHostedMode = false;
		boolean bNeedsCSAPI = false;
		// Search the fragments for the CSAPI include & display mode tags
		// We need to loop through the whole page, because we only use the last
		// display mode tag.
		for (int i = 0; i < _markupList.GetSize(); i++)
		{
			IMarkupFragment fragment = (IMarkupFragment) _markupList.GetElement(i);

			if (fragment.GetFragmentType() == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
			{
				// Found a PTXML tag
				if (TagConstants.DISPLAY_MODE_TAG_FULL_NAME.equals(fragment.GetXMLFragment().GetName(0)))
				{
					bHostedMode = IsHostedModeTag(fragment.GetXMLFragment());
				} else if (AutoJSTransformTagConstants.TAG_FULL_NAME.equals(fragment.GetXMLFragment().GetName(0)))
				{
					bNeedsCSAPI = true;
				}
			}
		}

		return !bHostedMode && bNeedsCSAPI;
	}

	/**
	 * This method determines whether or not we will need to include the
	 * JS includes data in the head.  If this page is hosted, then the
	 * portal banner will handle the JS includes and we don't have to.
	 * Hosted mode will make this method return false.
	 * 
	 * @param _objArrMarkup The markup
	 * @return true if we need to add the JSIncludes data.
	 */
	public boolean NeedsCSAPIinNonHostedPage(Object[][] _objArrMarkup)
	{
		boolean bHostedMode = false;
		boolean bNeedsCSAPI = false;
		// Search the fragments for the CSAPI include & display mode tags
		// We need to loop through the whole page, because we only use the last
		// display mode tag.
		for (int i = 0; i < _objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE].length; i++)
		{
			int nFragmentType = XPConvert.ToInteger(_objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_TYPE][i]);

			if (nFragmentType == PT_MARKUP_FRAGMENT_TYPES.PT_MARKUP_FRAGMENT_TYPE_PT_XML)
			{

				Object[][] arrXML = (Object[][]) _objArrMarkup[PT_MARKUP_ARRAY_COLS.PT_MARKUP_ARRAY_COLS_FRAGMENT][i];

				// Assume the name is the first attribute				
				String strName = XPConvert.ToString(arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][0]);

				// Found a PTXML tag
				if (TagConstants.DISPLAY_MODE_TAG_FULL_NAME.equals(strName))
				{
					bHostedMode = IsHostedModeTag(arrXML);
				} else if (AutoJSTransformTagConstants.TAG_FULL_NAME.equals(strName))
				{
					bNeedsCSAPI = true;
				}
			}
		}

		return !bHostedMode && bNeedsCSAPI;
	}

	/**
	 * This helper method determines whether or not the given display mode tag
	 * is set to hosted mode.
	 * 
	 * @param _tag
	 * @return whether or not the given display mode tag is set to hosted mode.
	 */
	public boolean IsHostedModeTag(IXMLFragment _tag)
	{
		for (int i = 0; i < _tag.GetNumberOfRows(); i++)
		{
			if (_tag.GetType(i) == PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT)
			{
				if (XPStringUtility.EqualsIgnoreCase(_tag.GetName(i).trim(),
					(TagConstants.DISPLAY_MODE_ATTRIBUTE_HOSTED_VALUE)))
				{
					return true;
				}
			}
		}

		return false;
	}

	/**
	 * This helper method determines whether or not the given display mode tag
	 * is set to hosted mode.
	 * 
	 * @param _tag
	 * @return whether or not the given display mode tag is set to hosted mode.
	 */
	public boolean IsHostedModeTag(Object[][] _arrXML)
	{
		for (int i = 0; i < _arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE].length; i++)
		{
			// If it's an attribute
			if (XPConvert.ToInteger(_arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_TYPE][i]) ==
				PT_XML_TYPES.PT_XML_TYPES_PTUI_ATT)
			{
				// and the name is "mode"
				if (XPStringUtility.EqualsIgnoreCase(
					XPConvert.ToString(_arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_NAME][i]).trim(),
					(TagConstants.DISPLAY_MODE_TAG_MODE_ATTRIBUTE)))
				{
					// and the value is "Hosted"
					if (XPStringUtility.EqualsIgnoreCase(
						XPConvert.ToString(_arrXML[PT_XML_ARRAY_COLS.PT_XML_ARRAY_COLS_VALUE][i]).trim(),
						(TagConstants.DISPLAY_MODE_ATTRIBUTE_HOSTED_VALUE)))
					{
						return true;
					}
				}
			}
		}

		return false;
	}
}