package com.plumtree.portalpages.browsing.layoutselection;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * 
 *
 * @author michaeld
 */
public class LayoutSelectionEditorAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "LayoutSelectionEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String, java.lang.String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		boolean bAccess = super.CheckBasicAccess(strPage, strControl, bSameSpace);

		// MJD- Otherwise make sure this is the refresh control. The access will be checked by those controls.
		if ((null != strControl) && (strControl.equals(RefreshLayoutSelectControl.STR_MVC_CLASS_NAME)))
		{
			bAccess = true;
		}

		return bAccess;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LayoutSelectionEditorAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		return GetString(628, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (LayoutSelectionRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		log.Info("Layout Selection Editor Activity Space");

		// Layout Selection Model
		m_strModelName = LayoutSelectionModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(LayoutSelectionModel.STR_MVC_CLASS_NAME);

		// Model has to be initialized in Init method because it requires PTSession.
		log.Info("Registered model");

		// Layout Selection DisplayPages
		AFormDP myPage = new LayoutSelectionDP();
		myPage.AddToValidationFunction(LayoutSelectionView.JAVASCRIPT_SUBMIT_TO_PARENT);
		RegisterPage(myPage);
		log.Info("Registered page");

		// Layout Selection Views
		RegisterView(LayoutSelectionView.STR_MVC_CLASS_NAME, myModel);
		log.Info("Registered views");

		// Layout Selection Controls
		RegisterControl(LayoutSelectionRepostControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(RefreshLayoutSelectControl.STR_MVC_CLASS_NAME, myModel);
		log.Info("Registered controls");

		// Set default page
		SetCurrentPage(LayoutSelectionDP.STR_MVC_CLASS_NAME);
		
		SetHelpTopic("PT_ChooseLayout");
	}
}

