package com.plumtree.portalpages.browsing.layoutselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * 
 *
 * @author michaeld
 */
public class LayoutSelectionModel extends EditorModel
	implements ILayoutSelectionModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
			"com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionModel");
	
	/** Object name */
	public static final String STR_MVC_CLASS_NAME = "LayoutSelection";

	/** Parent Form Name */
	private String m_strParentFormName = "";

	/** Parent Form Select Input */
	private String m_strParentFormSelectInput = "";

	/** Parent Form Space ID */
	private String m_strParentFormSpaceID = "";

	/** Parent Form Submit Function */
	private String m_strParentFormSubmitFunction = "";

	/** Selector has free form portlet? */
	private boolean m_bHasFreeFormPortlet;

	/** Layout Column Count */
	private int m_nLayoutColumnCount = 4;

	/** Selector allows free form layouts */
	private boolean m_bFreeFormLayoutAllowed;

	/** Selected Layout */
	private int m_nSelectedLayout;
	
	protected IPTQueryResult m_layouts;

	// END ***************** save DP methods ***************** 
	// ***CHANGE_HERE*** Implement the repost action methods that you 
	//      will call from your Repost Control.
	// BEGIN ***************** repost action methods ***************** 

	/**
	 * Modifies the object name on repost.
	 */
	public void ActionOnRepost()
	{
	}
	
	/**
	 * Initializes the list of layouts
	 * 
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Init(com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(AActivitySpace owner)
	{
		
		ILayoutChooser chooser = LayoutService.getChooserInstance();
		if ( chooser.GetPortletLayoutsEnabled(owner) ) {
			IPTQueryResult layouts = chooser.GetAvailableWebServices(Layouts.PORTLET, owner);
			m_layouts = layouts;
		} else {
			m_layouts = null;
		}
		
	}

	// END ***************** helper methods ***************** 

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		SetValuesFromQueryString(_htFormData);

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LayoutSelectionModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish()
	{
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetLayoutColumnCount()
	 */
	public int GetLayoutColumnCount()
	{
		return m_nLayoutColumnCount;
	}

	////////////////////////////////////////////////////
	// Read only methods from ILayoutSelectionModelRO
	////////////////////////////////////////////////////

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetPageHasFreeFormPortlet()
	 */
	public boolean GetPageHasFreeFormPortlet()
	{
		return m_bHasFreeFormPortlet;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetPageSupportsFreeFormSection()
	 */
	public boolean GetPageSupportsFreeFormSection()
	{
		return m_bFreeFormLayoutAllowed;
	}

	/////////////////////////////////////
	// Read only methods from IModelRO
	/////////////////////////////////////

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormName()
	 */
	public String GetParentFormName()
	{
		return m_strParentFormName;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormSelectInput()
	 */
	public String GetParentFormSelectInput()
	{
		return m_strParentFormSelectInput;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormSpaceID()
	 */
	public String GetParentFormSpaceID()
	{
		return m_strParentFormSpaceID;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetParentFormSubmitFunction()
	 */
	public String GetParentFormSubmitFunction()
	{
		return m_strParentFormSubmitFunction;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.layoutselection.ILayoutSelectionModelRO#GetSelectedLayout()
	 */
	public int GetSelectedLayout()
	{
		return m_nSelectedLayout;
	}

	/**
	 * Method RefreshHasFreeFormPortlet.
	 * Refreshes the available choices based upon whether the opening page has a
	 * freeform layout or not.
	 * @param _htFormData
	 */
	public void RefreshHasFreeFormPortlet(XPHashtable _htFormData)
	{
		// Set Selector has free form portlet Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_HAS_FREE_FORM))
		{
			m_bHasFreeFormPortlet = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(
						LayoutSelectionRepostControl.STR_HAS_FREE_FORM))[0]);
		}
	}

	// END ***************** repost action methods ***************** 

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		if (_sPageName.equals(LayoutSelectionDP.STR_MVC_CLASS_NAME))
		{
			SaveMainPage(_htFormData);
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	// BEGIN ***************** save DP methods ***************** 

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
		String[] data;

		// Saving setting1
		data = (String[]) _htFormData.GetElement(LayoutSelectionView.HTMLINPUT_LAYOUT);

		if ((null != data) && !(0 == data.length))
		{
			m_nSelectedLayout = XPConvert.ToInteger(data[0]);
		}
	}

	/**
	 * Set values of member variable from Query String
	 *
	 * @param XPHashTable _htFormData
	 */
	private void SetValuesFromQueryString(XPHashtable _htFormData)
	{
		RefreshHasFreeFormPortlet(_htFormData);
		
		// Set Selector has free form portlet Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_HAS_FREE_FORM))
		{
			m_bHasFreeFormPortlet = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(
						LayoutSelectionRepostControl.STR_HAS_FREE_FORM))[0]);
		}

		// Set Parent Form Selected Items Name Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_SELECTED_ITEM))
		{
			m_nSelectedLayout = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
						LayoutSelectionRepostControl.STR_SELECTED_ITEM))[0]);
		}

		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_FREE_FROM_LAYOUT_ALLOWED))
		{
			m_bFreeFormLayoutAllowed = XPConvert.ToBoolean(((String[]) _htFormData.GetElement(
						LayoutSelectionRepostControl.STR_FREE_FROM_LAYOUT_ALLOWED))[0]);
		}

		// Set Parent Form Name Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_PARENT_FORM_NAME))
		{
			// CheckSafeName will throw an exception if the name contains suspicious characters.
			m_strParentFormName = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_FORM_NAME))[0]);
		}

		// Set Parent Form Space ID Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_PARENT_FORM_SPACE_ID))
		{
			// CheckSafeName will throw an exception if the name contains suspicious characters.
			m_strParentFormSpaceID = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_FORM_SPACE_ID))[0]);
		}

		// Set Parent Form Submit Function Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_PARENT_SUBMIT_CALL))
		{
			// CheckSafeName will throw an exception if the name contains suspicious characters.
			m_strParentFormSubmitFunction = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_SUBMIT_CALL))[0]);
		}

		// Set Parent Form Select Input Value
		if (_htFormData.ContainsKey(
					LayoutSelectionRepostControl.STR_PARENT_FORM_SELECTED_INPUT))
		{
			// CheckSafeName will throw an exception if the name contains suspicious characters.
			m_strParentFormSelectInput = CheckSafeName(((String[]) _htFormData.GetElement(LayoutSelectionRepostControl.STR_PARENT_FORM_SELECTED_INPUT))[0]);
		}
	}

	/**
	 * A utility method that checks if the parameter name is safe to
	 * protect against cross-site scripting attacks. 
	 * 
	 * @param _strName The name to check.
	 * @return The safe name.
	 * @throws XPIllegalArgumentException if the name is not safe.
	 */
	public String CheckSafeName(String _strName)
	{
		if (GeneralHelpers.ContainsUnsafeCharacters(_strName, true))
		{
			throw new XPIllegalArgumentException("Unsafe character found in " +
				"the Layout Selection Model parameters.  Possible hack attempt " +
				"from parameter '" + _strName + "'.");
		}

		return _strName;
	}

	/**
	 * 
	 * @return Available portlet page layouts, null if adaptive page layouts are disabled
	 */
	public IPTQueryResult GetAdaptiveLayouts() {
		return m_layouts;
	}
}