package com.plumtree.portalpages.browsing.layoutselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class LayoutSelectionRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionRepostControl");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "SelectLayout";

	/** Selected item will be selected by default. */
	public static final String STR_SELECTED_ITEM = "SelectedItem";

	// NOTE: The following four QS params (form name, form space ID, parent submit, and
	// parent selected input) need to be protected against cross-site scripting
	// attacks.  Therefore, we screen them for suspicicious characters such as angle
	// brackets, slashes, etc...  We could get rid of the form name, since it's only
	// used once and is the default, but we'd still need to protect the other 3
	// variables.  Bugs#69340 and 69341.
	
	// These two (form name and form space ID) should be used together or not at all.

	/**
	 * The name of the parent form that you would like the data passed back to.
	 * 
	 * NOTE: This parameter cannot contain angle brackets, slashes, etc....
	 **/
	public static final String STR_PARENT_FORM_NAME = "Form";

	/** The name of the input in the parent form that you would like the AActivitySpace
	 *  ID  of the tree space put into.
	 *  
	 * NOTE: This parameter cannot contain angle brackets, slashes, etc....
	 */
	public static final String STR_PARENT_FORM_SPACE_ID = "Input";

	/**
	 * The name of the javascript function in the parent page to call when the tree
	 * is  submitted. This should not include the '();'. In  Javascript submit
	 * mode this method should take an array argument which will be made up
	 * of objects with name, ObjectID, and ClassID member  variables. see
	 * ATreeAS for details.
	 * 
	 * NOTE: This parameter cannot contain angle brackets, slashes, etc....
	 */
	public static final String STR_PARENT_SUBMIT_CALL = "Submit";

	/**
	 * NOTE: This parameter cannot contain angle brackets, slashes, etc....
	 */
	public static final String STR_PARENT_FORM_SELECTED_INPUT = "SelectInput";

	
	public static final String STR_HAS_FREE_FORM = "HasFreeForm";

	/** Free form layout allowed */
	public static final String STR_FREE_FROM_LAYOUT_ALLOWED = "ffok";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LayoutSelectionRepostControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call  the associated method for each
	 * action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);
	}

	/**
	 * This method is called when we finish a sub Editor.
	 * It takes care of closing the sub Editor pop-up winodws
	 * and repost the main Editor window.
	 *
	 */
	protected void SetRedirectToCloseSubEditor()
	{
		((EditorModel) m_model).SetDeleteOnCancel(false);

		// Set up submit function in parent form, if it exists.
		String strOpenerFunction = ((ILayoutSelectionModelRO)m_model).GetParentFormSubmitFunction();

		int nSize = 20;

		if ((strOpenerFunction != null) &&
				(!"".equals(strOpenerFunction)))
		{
			nSize += 100;
		}

		XPStringBuilder sb = new XPStringBuilder(nSize);
		
		// Add method to call on opening form, if it exists
		if ((strOpenerFunction != null) &&
				(!"".equals(strOpenerFunction)))
		{
			sb.Append("  window.opener.").Append(strOpenerFunction).Append("();\n");
		}

		// We are in a frame, so we need to call parent, not window
		sb.Append("window.close();\n");

		HTMLScript myScript = new HTMLScript("text/javaScript");
		try
		{
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "Error generating JS for ClosePopUpDP.");
		}

		ClosePopUpDP myClosePopUp = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
		myClosePopUp.SetScript(myScript);

		// Close the Tree pop-up
		Redirect myRedirect = new Redirect();
		myRedirect.SetLinkGetCachedSpace(m_asOwner);
		myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

		SetRedirect(myRedirect);
	}
}

