package com.plumtree.portalpages.browsing.layoutselection;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View for generating the list of available layouts,
 *
 * 
 * @author michaeld
 * @author Robert Zhang
 */
public class LayoutSelectionView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.layoutselection.LayoutSelectionView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "LayoutSelection";

	/** Layout Count */
	public static final int LAYOUT_COUNT = 13;
	
	/** Layout: number of columns */
	public static final int LAYOUT_COLUMNS = 3;

	/** Column: Layout Name */
	public static final int LAYOUT_COL_NAME = 0;

	/** Column: Layout Image */
	public static final int LAYOUT_COL_IMG = 1;
	
	/** Column: Layout allows free form section */
	public static final int LAYOUT_COL_ALLOWSFREEFORM = 2;
	
	/** HTML input names. */
	public static final String HTMLINPUT_LAYOUT = "in_ra_Layout";

	/** Javascript function: submitToParent */
	public static final String JAVASCRIPT_SUBMIT_TO_PARENT = "submitToParent";
	
	public static final String ELEMENT_SELECT_ID = "layoutselect";
	public static final String ELEMENT_SELECT_NAME = "in_se_layoutselect";
	public static final String ELEMENT_RADIO_ID = "layoutradio";
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LayoutSelectionView();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;
		HTMLBr br					  = new HTMLBr();

		HTMLTable table = new HTMLTable();
		table.SetBorder("1");
		table.SetBorder("0");
		table.SetCellPadding("1");
		table.SetCellSpacing("1");

		IPTQueryResult layouts = ((LayoutSelectionModel)m_model).GetAdaptiveLayouts();
		// null if adaptive layouts are disabled
		if ( null != layouts && layouts.RowCount() > 0 )
		{
			/**
			 * The same form field is used to send the value for either adaptive layout ids 
			 * or classical page layout type. 
			 */
			
			// Showing Adaptive Layouts Label before displaying the Options
			// row for adaptive layout selection
			HTMLTableRow layoutRow = new HTMLTableRow();
			
			table.AddInnerHTMLElement(layoutRow);
			// spacer cell
			super.AddEmptyCellToRow(layoutRow, "28");
			// cell for select			
			HTMLTableCell layoutCell = new HTMLTableCell();
			
			layoutCell.SetColSpan("1");	
			layoutCell.SetStyleClass(PTStyleClass.OBJECT_HEADER);	
			layoutCell.AddInnerHTMLEncodedString(m_asOwner.GetString(1947, "ptmsgs_portalbrowsingmsgs")+ ":");
			layoutRow.AddInnerHTMLElement(layoutCell);
			
			
			//	 row for adaptive layout selection
			layoutRow = new HTMLTableRow();
			
			table.AddInnerHTMLElement(layoutRow);
			// spacer cell
			super.AddEmptyCellToRow(layoutRow, "28");
			
			layoutCell = new HTMLTableCell();
			layoutCell.SetColSpan("3");
			
			
			
			// This is the input form field that stores the layout id
			// The value is set with javascript when the select element is changed 
			HTMLInput layoutRadio = new HTMLInput(HTMLInputTypes.RADIO,
										HTMLINPUT_LAYOUT,
										"");
			layoutRadio.SetID(ELEMENT_RADIO_ID);
			layoutCell.AddInnerHTMLElement(layoutRadio);
			
			// display combobox with list of adaptive layouts
			HTMLSelect select = new HTMLSelect(ELEMENT_SELECT_NAME, ELEMENT_SELECT_ID);
			// Javascript that updates the id on the radio button and also checks the radio button if
			// the user selects an entry before clicking on the radio button
			// webservice id are stored as negative numbers to more clearly differentiate against page types
			select.SetOnChange("document.getElementById('"+ELEMENT_RADIO_ID+"').value = -this.options[this.options.selectedIndex].value; "+
				"document.getElementById('"+ELEMENT_RADIO_ID+"').checked = true;");
			select.SetOnClick("document.getElementById('"+ELEMENT_RADIO_ID+"').value = -this.options[this.options.selectedIndex].value; "+
				"document.getElementById('"+ELEMENT_RADIO_ID+"').checked = true;");
			layoutCell.AddInnerHTMLElement(select);
			layoutRow.AddInnerHTMLElement(layoutCell);
			
			// set the first entry as the default value
			if ( layouts.RowCount() > 0 ) {
				layoutRadio.SetValue(-layouts.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID)+"");
			}
			int selectedLayout = ((ILayoutSelectionModelRO) m_model).GetSelectedLayout();
			// add an entry in the select element for each layout and puts in initial values 
			for ( int i = 0; i < layouts.RowCount(); i++ ) {
				int objId = layouts.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				String name = layouts.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
				
				HTMLOption option = new HTMLOption(objId+"", name);
				select.AddInnerHTMLElement(option);
				// check the radio button and activate the dropdown
				if (selectedLayout == -objId) {
					option.SetSelected(true);
					layoutRadio.SetChecked(true);
					layoutRadio.SetValue(-objId+"");
				}
				
			}
		}
		
		
		// display the pre-defined layouts
		HTMLTableRow row;
		HTMLTableCell cell;
		HTMLInput inputSelector;
		HTMLImg imgLayout;

		try
		{
			myGroup.AddInnerHTMLElement(table);

			// Showing Classic Layouts Label before displaying the Options
			super.AddEmptyRowToTable(table, "15");
			row = new HTMLTableRow();
			super.AddEmptyCellToRow(row, "28");
			cell = new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			cell.SetColSpan("4");
			cell.AddInnerHTMLEncodedString(m_asOwner.GetString(1948, "ptmsgs_portalbrowsingmsgs") + ":");
			row.AddInnerHTMLElement(cell);
			table.AddInnerHTMLElement(row);
			
			for (int iLayout = 0; iLayout < LAYOUT_COUNT; iLayout++)
			{
				
				row = new HTMLTableRow();

				for (int j = 0; j < ((ILayoutSelectionModelRO) m_model).GetLayoutColumnCount(); j++)
				{
					
					super.AddEmptyCellToRow(row, "28");
					cell = new HTMLTableCell();
					
					if (LAYOUT_COUNT > iLayout)
					{
						if ( ( ((ILayoutSelectionModelRO) m_model).GetPageSupportsFreeFormSection() ||
								!GetLayoutAllowsFreeForm(iLayout) ) &&
							 ( !((ILayoutSelectionModelRO) m_model).GetPageHasFreeFormPortlet() ||
								GetLayoutAllowsFreeForm(iLayout) ) )
						{
							//cell.SetID("layout"+j);
							// display layout
							inputSelector = new HTMLInput(HTMLInputTypes.RADIO, HTMLINPUT_LAYOUT, 
									XPResourceManager.FormatMessage(m_asOwner.GetString(629, "ptmsgs_portalbrowsingmsgs"),
										GetLayoutName(iLayout)));
							//inputSelector.SetOnClick("document.getElementById('layout"+j+"').className = 'objectHeaderBg';");
							cell.AddInnerHTMLElement(inputSelector);
							inputSelector.SetValue(XPConvert.ToString(iLayout));
							// is the current radiobutton the checked one?
							if (iLayout == ((ILayoutSelectionModelRO) m_model).GetSelectedLayout())
							{
								inputSelector.SetChecked(true);
								//cell.SetStyleClass("objectHeaderBg");
							}
	
							cell.AddInnerHTMLElement(br);
	
							PTConstruct myConstruct = 
								UIConstructFactory.GetConstruct(GetLayoutImageType(iLayout), true, this.m_asOwner);
							imgLayout = (HTMLImg) myConstruct.GetHTMLElement();
							cell.AddInnerHTMLElement(imgLayout);
							imgLayout.SetAlt(GetLayoutName(iLayout));
						}
					}

					row.AddInnerHTMLElement(cell);

					if ( (((ILayoutSelectionModelRO) m_model).GetLayoutColumnCount() - 1) > j )
					{
						iLayout++;
					}
				}

				table.AddInnerHTMLElement(row);
			}
		}
		catch (HTMLException he)
		{
			result = new HTMLGenericElement(
					"Error creating layout selection view: " + he.getMessage());
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating layout image: " +
					e.getMessage());
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		// Set up submit function in parent form, if it exists.
		String strOpenerFunction = ((ILayoutSelectionModelRO) m_model).GetParentFormSubmitFunction();

		if (strOpenerFunction == null)
		{
			strOpenerFunction = "";
		}

		// Set up parent form space ID
		String strSpaceIDInput = ((ILayoutSelectionModelRO) m_model).GetParentFormSpaceID();

		// Calculate approximate string builder size
		int nSize = 400;

		if (!"".equals(strOpenerFunction))
		{
			// Add space for calling a function on the parent page
			nSize += 75;
		}

		if ((strSpaceIDInput != null) && (!"".equals(strSpaceIDInput)))
		{
			// Add space for setting the space ID on the parent page
			nSize += 20;
		}

		XPStringBuilder sb = new XPStringBuilder(nSize);

		// Select submit function (multi and single)
		// Different cases for a single radio/checkbox button vs. multiple
		// radio/checkbox buttons:
		// - single is just an object
		// - multiple is an array of objects
		sb.Append("\n")
		.Append("function ").Append(JAVASCRIPT_SUBMIT_TO_PARENT).Append("()\n")
		.Append("{\n")
		.Append("	var varLayout = document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_LAYOUT).Append(";\n")
		.Append("	if ((varLayout) && (varLayout.length)) {\n")
		.Append("		for ( var i = 0; i < varLayout.length; i++ ) {\n")
		.Append("			if ( varLayout[i].checked == true ) {\n")
		.Append("				window.opener.document.").Append(((ILayoutSelectionModelRO) m_model).GetParentFormName())
		.Append(".").Append(((ILayoutSelectionModelRO) m_model).GetParentFormSelectInput()).Append(".value = varLayout[i].value;\n")
		.Append("				return true;\n")
		.Append("			}\n")
		.Append("		}\n")
		.Append("	}\n")
		.Append("	return true;\n")
		.Append("}\n\n");

		// Onload method to set the Space ID
		if ((strSpaceIDInput != null) && (!"".equals(strSpaceIDInput)))
		{
			// TODO: Should this only be called the first time the tree is displayed?
			sb.Append("window.opener.document.")
			.Append(((ILayoutSelectionModelRO) m_model).GetParentFormName())
			.Append(".").Append(strSpaceIDInput).Append(".value= ")
			.Append(m_asOwner.GetSpaceID()).Append(";\n\n");
		}

		HTMLScript result = new HTMLScript("text/javaScript");

		try
		{
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element: " +
					he.getMessage());
			
		}

		return result;
	}

	protected Object[] GetLayout(int iLayoutIndex)
	{
		Object[] aLayout = new Object[LAYOUT_COLUMNS];
		switch (iLayoutIndex)
		{
			case 0:
			{
				aLayout[LAYOUT_COL_NAME]			= "Zero";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT0;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(false);
				break;
			}
			case 1:
			{
				aLayout[LAYOUT_COL_NAME]			= "One";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT1;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(false);
				break;
			}
			case 2:
			{
				aLayout[LAYOUT_COL_NAME]			= "Two";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT2;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(false);
				break;
			}
			case 3:
			{
				aLayout[LAYOUT_COL_NAME]			= "Three";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT3;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(false);
				break;
			}
			case 4:
			{
				aLayout[LAYOUT_COL_NAME]			= "Four";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT4;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 5:
			{
				aLayout[LAYOUT_COL_NAME]			= "Five";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT5;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 6:
			{
				aLayout[LAYOUT_COL_NAME]			= "Six";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT6;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 7:
			{
				aLayout[LAYOUT_COL_NAME]			= "Seven";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT7;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 8:
			{
				aLayout[LAYOUT_COL_NAME]			= "Eight";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT8;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 9:
			{
				aLayout[LAYOUT_COL_NAME]			= "Nine";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT9;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 10:
			{
				aLayout[LAYOUT_COL_NAME]			= "Ten";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT10;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 11:
			{
				aLayout[LAYOUT_COL_NAME]			= "Eleven";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT11;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			case 12:
			{
				aLayout[LAYOUT_COL_NAME]			= "Twelve";
				aLayout[LAYOUT_COL_IMG]				= PTImageType.LAYOUT12;
				aLayout[LAYOUT_COL_ALLOWSFREEFORM]	= new Boolean(true);
				break;
			}
			default:
				return null;
		}
		
		return aLayout;
	}
	
	/**
	 * @param iLayout
	 * @return the image type for the icon of the current layout
	 */
	private PTImageType GetLayoutImageType(int iLayout)
	{
		return (PTImageType)(GetLayout(iLayout)[LAYOUT_COL_IMG]);
	}

	/**
	 * @param iLayout
	 * @return name of the current layout
	 */
	private String GetLayoutName(int iLayout)
	{
		return (String)(GetLayout(iLayout)[LAYOUT_COL_NAME]);
	}

	/**
	 * @param iLayout
	 * @return whether the current layout allows a free form or content canvas section
	 */
	private boolean GetLayoutAllowsFreeForm(int iLayout)
	{
		return XPConvert.ToBoolean(GetLayout(iLayout)[LAYOUT_COL_ALLOWSFREEFORM]);
	}
}

