package com.plumtree.portalpages.browsing.layoutselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;

/**
 * @author MichaelD
 *
 * This  control is used to re-open a previously opened layout selection and
 * refresh the contents.
 */
public class RefreshLayoutSelectControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.layoutselection.RefreshLayoutSelectControl");

	/** name of the refresh layout selection control */
	public static final String STR_MVC_CLASS_NAME = "RefreshLayoutSel";

	/** Activity Space */
	protected AActivitySpace m_asOwner;

	/** Internal data **/
	protected LayoutSelectionModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// MJD- On each repost we check if the user has the rights to be in this Editor.
		if (!((EditorModel) m_asModel).GetUserHasAccessToEditor())
		{
			Redirect myRedirectToLogin = new Redirect();
			myRedirectToLogin.SetIsErrorRedirect(true);
			myRedirectToLogin.SetLinkCreateNewSpace(m_asOwner.GetName(), m_asOwner);
			myRedirectToLogin.SetControl(STR_MVC_CLASS_NAME);
			myRedirectToLogin.AddControlArguments(arguments);

			return myRedirectToLogin;
		}

		m_asModel.RefreshHasFreeFormPortlet(arguments);

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		try
		{
			m_asModel     = (LayoutSelectionModel) model;
		}
		catch (Exception e)
		{
			
				log.Error(e, "RefreshLayoutSelectControl::Init Unable to cast the Object " + model +
					" to LayoutSelectionModel. The following exception occured: " +
					e.getMessage());
			

			// JF- No need to extract, this is an unexpected error.
			throw new XPException("Unable to cast the Object " + model +
				" to LayoutSelectionModel.", e);
		}

		m_asOwner     = space;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RefreshLayoutSelectControl();
	}

}

