package com.plumtree.portalpages.browsing.login;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.sso.ensemble.*;
import com.plumtree.portalpages.common.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.login.*;
import com.plumtree.uiinfrastructure.opener.*;
import com.plumtree.uiinfrastructure.opener.types.classtypes.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class handles the control logic for login.
 *
 * @author BenG
 */
public class LoginControl implements ILoginControl, IHTTPControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.login.LoginControl");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "Login";

	/** Query string parameters to the Login space (Common Opener style) */
	// open=space&name=Login
	public static final String LOGIN_SPACE_COMMONOPENER_STYLE = IOpenerConstants.QS_OPEN
														   + LinkConstants.EQUALS
														   + ASConstants.SPACENAME
														   + LinkConstants.AMPERSAND
														   + UIActivitySpaces.QS_ACTIVITY_SPACE_NAME
														   + LinkConstants.EQUALS
														   + LoginHandlers.LOGINSPACE;
														   
	/** these need to be nulled out after execution. */
	private IWebData m_WebData   = null;
	private IXPRequest m_xpRequest = null;

	/** MVC Objects */
	private AActivitySpace m_asOwner;
	private LoginModel m_asModel;

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		log.Debug("CheckActionSecurityAndExecute()");

		String[] sValues;

		// User name
		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_USERNAME);

		if (sValues != null)
		{
			log.Debug("userName: " + sValues[0]);

			m_asModel.SetUserName(sValues[0]);
		}

		// User Pass
		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_USERPASS);

		if (sValues != null)
		{
			m_asModel.SetUserPass(sValues[0]);
		}

		Redirect myRedirect  = null;

		// Remember password
		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_REMEMBER);

		if (sValues != null)
		{
			m_asModel.SetRememberPassword(true);
		}

		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_SHOWAUTHSOURCES);

		if (sValues != null)
		{
			String sTemp = sValues[0];
			
			if( sTemp != null )
			{
				if( XPConvert.ToBoolean( sTemp ))
				{
					// This will be ignored if show auth sources mode is 3
					this.m_asModel.SetShowAuthSources( true );
				}
			}
		}


		// Do Login
		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_DOLOGIN);

		if (sValues != null)
		{
			log.Debug("doLogin: " + sValues[0]);

			boolean bDoLogin;

			try
			{
				bDoLogin = XPConvert.ToBoolean(sValues[0]);
			}
			catch (Exception e)
			{
				log.Error(e, "Unexpected data for param DoLogin: " + sValues[0]);

				bDoLogin = false;
			}

			if (bDoLogin)
			{
				this.m_asModel.SetDoAttemptLogin(true);
			}
		}

		// Do Login 508
		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_DOLOGIN_508);

		if (sValues != null)
		{
			log.Debug("doLogin: " + sValues[0]);

			this.m_asModel.SetDoAttemptLogin(true);
		}

		// Authentication source
		sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_AUTHSOURCE);
		if (sValues == null)
		{
			sValues = (String[]) arguments.GetElement(LoginHTML.PARAM_HIDDEN_AUTHSOURCE);
		}

		if (sValues != null)
		{
			log.Debug("authSource: " + sValues[0]);

			this.m_asModel.SetAuthSource(sValues[0]);
		}

		// Do Logout
		sValues = (String[]) arguments.GetElement(LoginHelper.PARAM_DOLOGOUT);

		if (sValues != null)
		{
			log.Debug("logging out!");
			
			// Bug 53270 - login and logout in the same cycle
			// Make sure if an internal Logout redirect is created (by OnAfterLogin)
			// We cancel any login attempt. Otherwise, after logout we re-login again
			// while displaying the login page for redirectAfterLogout.
			this.m_asModel.SetDoAttemptLogin(false);
			
			// Do logout
			this.m_asModel.SetDoAttemptLogout(true);
			this.m_asModel.SetRedirectAfterLogin(null);
			this.m_asModel.Logout(m_WebData);
			
			//PEI : LoginActions
			Redirect logoutRedirect;

			logoutRedirect = DoTasksBeforeLogout();

			if (logoutRedirect == null)
			{
				// DCA - if not redirecting anywhere, refresh to make sure the right
				// navigation scheme views are registered.
				logoutRedirect = new Redirect();
				
				//RT - If this value is set then the wci will be redirected to the value of this
				// parameter after logout is done.
				sValues = (String[]) arguments.GetElement(EnsembleHandlerControl.LOGOUT_REDIRECT_URL);
				if (sValues != null){
					logoutRedirect.SetLinkToExternalURL(XPStringUtility.Trim(sValues[0]));
					return logoutRedirect;
				
				} else{
				
					// mj: check whether we're supposed to redirect to the default 
					// guest page when a user logs out.  if bJustRedirect is set to true,
					// we will redirect below instead of visiting the normal login page.
					if (IsRedirectOnLogoutEnabled()) {
					    // DCA - Check whether we want to use the Default Login Page or the Guest MyPage
						// (which is stored in the user's sandbox session) 
					    boolean bDefaultLogin = true;
						ISessionManager smSandbox = m_asOwner.GetSubSession();
						if (null != smSandbox)
						{
							String str = (String)smSandbox.GetAttribute(Authenticator.GUESTLOGIN_REDIRECTONLOGOUT);
							if (null != str)
							{
							    bDefaultLogin = XPConvert.ToBoolean(str);
							}			
						}
						if (bDefaultLogin) {
						    logoutRedirect.SetLinkGetCachedSpace(m_asOwner);
						} else {
						    logoutRedirect.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
						    logoutRedirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
						    logoutRedirect.AddControlArgument(SetPageControl.STR_PAGE_ID, SetPageControl.N_HOME_PAGE_ID);
						}
					} else {
					    logoutRedirect.SetLinkGetCachedSpace(m_asOwner);
						logoutRedirect.AddControlArgument(LoginHelper.PARAM_DONT_LOGIN_JUST_REDIRECT, true);
					}
				}
			}

			if (logoutRedirect != null)
			{
				myRedirect = logoutRedirect;
				m_xpRequest = null;
				m_WebData = null;
				
				//RT - This custom sso feature between Ensemble and WCI is disabled and not supported in NEO release.
				// To achieve SSO between WCI and Ensemble or other WebCenter products like spaces it is suggested to use
				// a generic SSO setup which includes thirdparty SSO solution like OSSO, OAM etc to achieve SSO between WCI
				// and Ensemble. For setting up generic SSO it is suggested to follow WCI documentation.				
				
				if(EnsembleHandlerControl.FEATURE_DISABLED){
				// Start - Ensemble SSO Processing
								
					if(EnsembleHandlerTasks.GetSSOTimeout() > 0 ) {
						
						if(null != EnsembleHandlerTasks.GetEnsembleBaseUrl()){
							//If enabled inject EnsembleSSO Logout Redirect
							log.Info("Ensemble SSO feature is enabled and in logout redirection to Ensemble" );
							
		
							//Encrypted Portal return url
							String replyURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(m_asOwner) + myRedirect.GetQueryString();
							String encReplyURL = EnsembleHandlerTasks.EncryptUsingSeedToken(replyURL);
							
							//Ensemble SSO End Point
							String strURL = EnsembleHandlerTasks.GetEnsembleBaseUrl() 
												+ EnsembleHandlerTasks.STR_CONTEXT_APPEND + EnsembleHandlerControl.EN_URL_SSO_SUFIX ;
							strURL = EnsembleHandlerTasks.AddQueryStringParam(strURL, EnsembleHandlerControl.SSO_ACTION, EnsembleHandlerControl.LOGOUT_VALUE);
							strURL = EnsembleHandlerTasks.AddQueryStringParam(strURL, EnsembleHandlerControl.ES_POST_REDIRECT_URL, encReplyURL);
							log.Info("Processing logout in WCI and sending logout request to Ensemble: " + strURL);
							//Ensemble SSO redirect and return it.
							myRedirect = new Redirect();
							myRedirect.SetLinkToExternalURL(strURL);
							return myRedirect;
						} else {
							log.Error("Ensemble SSO feature is enabled, but Ensemble endpoint is not configured properly. Check Ensemble configuration in WCI!");
						}
	
					}else {
						log.Debug("Ensemble SSO feature is disabled");
					}
				}
				
				// End - Ensemble SSO Processing
				
				return myRedirect;
			}
			//PEI : OnLogout : END
		}

		// Check for redirect after login URL
		Redirect r = this.m_asModel.GetRedirectAfterLogin();
		if (null == r) 
		{
			// hidden input REDIRECT_AFTER_LOGIN_INPUT is used by login portlet and tag login portlet
			sValues = (String[]) arguments.GetElement(ASConstants.REDIRECT_AFTER_LOGIN_INPUT);

			if (sValues != null && sValues.length>0)
			{
				log.Debug("redirect after login: " + sValues[0]);

				r = new Redirect();
				r.SetLinkToExternalURL(sValues[0]);
				log.Info("Redirect after login QS param: {0}", sValues[0]);

				SetRedirectForUseAfterLogin(r);
			}
		}
		
		//	Here we go through the cookies and see if there's a
		//	access style cookie.  This is for the following case.  User
		//	sets access style to something, and then clicks the logout link.
		//	That user is taken to the login page, and the LoginControl executes,
		//	and must intercept this cookie to display the appropriate access
		//	style.  In the usual case, where a user just opens a browser and
		//	hits the login page, the default login control executes and
		//	intercepts cookies.

		// Check value of access style cookie and set it on the model.
		LoginControlHelpers.CheckAccessStyleCookie(m_xpRequest, this.m_asModel);

		boolean bJustRedirect = false;

		sValues = (String[]) arguments.GetElement
			(LoginHelper.PARAM_DONT_LOGIN_JUST_REDIRECT);

		if (sValues != null)
		{
			bJustRedirect = true;
		}

		if (bJustRedirect)
		{
			// Since we're just redirecting, the model hasn't been fully initialized,
			// so we need to set the current user session on the model.
			m_asModel.SetSession((IPTSession) m_asOwner.GetUserSession());
			myRedirect = GetRedirect((IPTSession) m_asOwner.GetUserSession());
		}
		else if (this.m_asModel.GetDoAttemptLogin())
		{
			// Log in
			myRedirect = this.m_asModel.attemptLogin(m_xpRequest, m_WebData);

			// A new session implies successful login
			if (m_asModel.GetSession() != null)
			{
				log.Debug("Login Succeeded!");
				
				// we want to use a new application (http) session after succesful (non-guest) login to avoid session fixation attacks
				// for bug #7824904 (oracle bug db). 
				// Set a flag to tell XPPage to use new application session on next request, we only want to do it after a succesful
				// login
				// We have to set a flag to abandon session on next request. Abandoning session in this request looses the session
				// in security mode 1 where a new session is created with secure session id cookie which is not accessible to a non
				// secure page after login redirect.
				if ( !m_asModel.GetSession().GetSessionInfo().CheckCurrentUserIsGuest() ) {
					XPSession oldAppSession = ((XPRequest)m_xpRequest).GetSession();
					// only do it for java, dotnet uses a different approach by clearing session id cookie in javascript before
					// submitting login form (LoginHTML)
					if (!XPSystem.IsRunningInDotNet()) {
						oldAppSession.SetAttribute(XPPage.USE_NEW_SESSION_FLAG, "");
					}
				}
				
				if (myRedirect == null)
				{
					myRedirect = GetRedirect(m_asModel.GetSession());
	
					//	clear this from the model
					m_asModel.SetRedirectAfterLogin(null);
				}
			}				
		}

		// null out member variables so we don't leak them
		m_xpRequest = null;
		m_WebData = null;

		
		return myRedirect;
	}

	/**
	 * This method is used to determine if the guest user should
	 * be redirected to their default page or to the login page
	 * if a space is not specified.
	 * 
	 * @param RequestData
	 * @return boolean true implies the guest should redirect to
	 * login if no space is specified.  Login is default.
	 */
	private boolean IsRedirectOnLogoutEnabled()
	{	
		// default value
		boolean bResult = true;

		// then use the default setting in the x_config.xml
		ConfigVarPack vpConfig = (ConfigVarPack) m_asOwner.GetApplication().GetVarPackManager().GetVariablePackage
			(ConfigVarPack.VARPACK_ID);

		String strGuestRedirect = vpConfig.GetConfigValueAsString(
			ConfigConstants.AUTHENTICATION_SECTION, "RedirectOnLogout",
			ConfigConstants.VALUE_ATTRIBUTE);

		if ((strGuestRedirect != null) && (!"".equals(strGuestRedirect)))
		{
			if (XPConvert.ToInteger(strGuestRedirect) == 0)
			{
				bResult = false;
			}
		}

		return bResult;
	}

	/////////////
	// IMVCObject
	/////////////

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LoginControl();
	}

	/////////////////////////////
	// Methods from ILoginControl
	/////////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#DoGetSession()
	 */
	public boolean DoGetSession()
	{
		// The interpreter should ask us for the session.
		return true;
	}
	
	/**
	 * Call the Logout function in the Model
	 * 
	 * @return Redirect - retrieve the correct Redirect object.
	 */
	public Redirect DoTasksBeforeLogout()
	{
		return this.m_asModel.DoTasksBeforeLogout(m_xpRequest, m_WebData);
	}
	
	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#GetSession()
	 */
	public Object GetSession()
	{
		IPTSession session = m_asModel.GetSession();

		if (session == null)
		{
			if (!this.m_asModel.GetDoAttemptLogout())
			{
				log.Debug("GetSession() - Session on the model is null, and the user is not logging out, recycling the session from our Activity Space.");

				//	if we didn't get a new IPTSession, then
				//	we return the current session.  This prevents
				//	the guest user from logging out and logging back in.
				session = (IPTSession) this.m_asOwner.GetUserSession();
			}
		}

		return session;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#Init(IModelRW)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (LoginModel) model;
		m_asOwner     = space;
	}

	/**
	 * @see IHTTPControl
	 *
	 * @param r 
	 * @param pageData 
	 */
	public void SetHTTPItems(IXPRequest r, IWebData pageData)
	{
		m_xpRequest     = r;
		m_WebData     = pageData;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#SetRedirectForUseAfterLogin(Redirect)
	 */
	public void SetRedirectForUseAfterLogin(Redirect r)
	{
		this.m_asModel.SetRedirectAfterLogin(r);
	}

	/**
	 * 
	 *
	 * @param mySession 
	 *
	 * @return 
	 */
	private Redirect GetRedirect(IPTSession mySession)
	{
		// Get redirect if user was trying to access a specific page
		Redirect myRedirect = this.m_asModel.GetRedirectAfterLogin();

		// bjf -- special case for if the user was trying to hit the login page originally,
		// but they weren't logged in, so the portal took them to the login page, the user
		// logged in, and then the portal tries to redirect them to the page they were
		// originally trying to hit -- which is the login page!  pretty circular, but the point
		// is that, once a user has logged in, we do not ever want to immediately redirect
		// them to the login page.  So if the redirect is set to LoginAS, just clear it,
		// and then code below will get the SubPortalRedirectAfterLogin.
		
		// WilliamA -- the loop may involve external URL (302 redirect), e.g., 
		// SSO in security mode 1, so want to check the space name from the URL QS as well 
		// (in 6.0 common opener style: open=space&name=Login)
		if (myRedirect != null)
		{
			if (myRedirect.GetIsExternalURL())
			{
				String externalURL = myRedirect.GetExternalURL();
				
				if (null != externalURL)
				{
					if (-1 != XPStringUtility.IndexOf(externalURL, LOGIN_SPACE_COMMONOPENER_STYLE))
					{
						// This is a loop through external URL HTTP redirect, break it.					
						myRedirect = null;	
				
						log.Debug("LoginControl:GetRedirect -- redirect is set to LoginAS (through a 302 redirect), but the user has already logged in.  Clear this, and redirect them to the SubportalRedirectAfterLogin instead.");
					}
				}				
			}
			else
			{
				if (LoginAS.STR_MVC_CLASS_NAME.equals(myRedirect.GetSpaceName()))
				{
					myRedirect = null;	

					log.Debug("LoginControl:GetRedirect -- redirect is set to LoginAS, but the user has already logged in.  Clear this, and redirect them to the SubportalRedirectAfterLogin instead.");
				}
			}
		}	

		if (null == myRedirect)
		{
			// Otherwise get sub-portal redirect
			// Put this in when subportals work.
			myRedirect = m_asModel.GetSubPortalRedirectAfterLogin(mySession);

			if (myRedirect == null)
			{
				// If that fails, just redirect to mypage.
				// redirect to myPage
				myRedirect = new Redirect();
				myRedirect.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME,
					m_asOwner);
				myRedirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
				myRedirect.AddControlArgument(SetPageControl.STR_PAGE_ID, SetPageControl.N_HOME_PAGE_ID);
			}
		}

		// Make this use a true 302 redirect
		myRedirect.SetIsHTTPRedirect(true);

		return myRedirect;
	}
}
