package com.plumtree.portalpages.browsing.login;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;

/**
 * @author donh
 */
public class LoginControlHelpers {
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.login.LoginControlHelpers");

	/**
	 * This helper method check to see if there is a valid access style cookie
	 * and sets the result on the model if there is one.
	 * 
	 * @param xpRequest
	 * @param loginModel
	 */
	public static void CheckAccessStyleCookie(IXPRequest xpRequest, LoginModel loginModel)
	{
		XPCookie[] cookies = null;

		if (xpRequest != null)
		{
			cookies = xpRequest.GetCookies();
		}

		if (cookies != null)
		{
			int nNumCookies   = cookies.length;
			XPCookie currentCookie;

			
				log.Debug("CheckActionSecurityAndExecute() - got " + nNumCookies + " cookies!");
			

			for (int i = 0; i < nNumCookies; i++)
			{
				currentCookie = cookies[i];

				if (PTPersonalSettingsHelper.ACCESS_STYLE_COOKIE_NAME.equals(currentCookie.GetName()))
				{
					//	access style cookie
					
						log.Debug("CheckActionSecurityAndExecute() - Found an access style cookie.");
					

					String sStyleFromCookie = currentCookie.GetValue();

					try
					{
						if ((null != sStyleFromCookie) && AccessStyles.IsValidAccessID(XPConvert.ToInteger(sStyleFromCookie)))
						{
							loginModel.SetAccessStyle(XPConvert.ToInteger(sStyleFromCookie));
							return;
						}
					} catch (Exception e)
					{
						
							log.Error(e, "Unable to process access style cookie.");
						
					}
				}
			}
		}
	}
}

