package com.plumtree.portalpages.browsing.login.createaccount;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.ResourceConstants;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * 
 *
 * @author BenG
 */
public class CreateAccountControl implements ILoginControl, IHTTPControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.login.createaccount.CreateAccountControl");

	/** object name */
	public static final String STR_MVC_CLASS_NAME = "CreateAccountControl";

	/** these need to be nulled out after execution */
	private IXPRequest m_xpRequest = null;
	private IWebData m_WebData = null;

	
	public static final String PARAM_USERNAME		  = "in_tx_username";

	
	public static final String PARAM_USERPASS		  = "in_pw_userpass";

	
	public static final String PARAM_CONFIRM_USERPASS = "in_pw_confupass";

	
	public static final String PARAM_DOCREATEACCOUNT = "in_hi_docreate";

	
	public static final String PARAM_INVITATION = "Invite";
	
	/** The control argumen for the invite token */
	public static final String CONTROLARGUMENT_INVCODE = "in_hi_invcode";	
	
	public static final String INVITE_CREATEUSER_COMMAND = "PTInternalCreateUser";
	
	private AActivitySpace m_asOwner;

	/** MVC Objects */
	private CreateAccountModel m_asModel;

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		
			log.Debug("Execute()");
		

		Redirect myRedirect = null;

		String[] sValues = null;
		
		// Create Account Invite Code
		// Invite code
		sValues = (String[]) arguments.GetElement(CONTROLARGUMENT_INVCODE);

		if (sValues != null)
		{
			
				log.Debug("invite code: " + sValues[0]);
			

			m_asModel.SetInviteCode(sValues[0]);
		}

		// User name
		sValues = (String[]) arguments.GetElement(PARAM_USERNAME);

		if (sValues != null)
		{
			
				log.Debug("userName: " + sValues[0]);
			
			if(sValues[0] == null || sValues[0].length() <= 0)
			{
				// if name is blank
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(2483,"ptmsgs_portaladminmsgs"),
						m_asOwner.GetString(2483,"ptmsgs_portaladminmsgs"));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
					
				return null;
			}
			
			//bug fix 8461417 - do not allow "\" or "/" characters in the login name.  These characters are used by
			//the Portal as deliminators, ie:  NA\lmah
			if ( !(XPStringUtility.IndexOf(sValues[0], "/") < 0) 
					|| !(XPStringUtility.IndexOf(sValues[0], "\\") < 0) )
			{
				// if name contains "\" or "/" characters
				log.Debug("CreateAccountControl.CheckActionSecurityAndExecute:  login name contains restricted \\ or / character.");

				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(3171, ResourceConstants.PORTALADMINMSGS),
						m_asOwner.GetString(3171, ResourceConstants.PORTALADMINMSGS));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
									
				return null;
			}
			
			m_asModel.SetUserName(sValues[0]);
		}

		// User Pass
		sValues = (String[]) arguments.GetElement(PARAM_USERPASS);

		if (sValues != null)
		{
			
				log.Debug("userPass: " + sValues[0]);
			
			
			if(sValues[0] == null || sValues[0].length() <= 0)
			{
				// if password is blank
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(2173,"ptmsgs_portaladminmsgs"),
						m_asOwner.GetString(2173,"ptmsgs_portaladminmsgs"));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
		
				return null;
			}
			
			if(sValues[0].length() > 0 && sValues[0].length() < 5)
			{
				// if password is too short
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(2172,"ptmsgs_portaladminmsgs"),
						m_asOwner.GetString(2172,"ptmsgs_portaladminmsgs"));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				return null;
			}
			
			String[] sConfirmValues = (String[]) arguments.GetElement(PARAM_CONFIRM_USERPASS);
			
			if(sConfirmValues != null && sConfirmValues[0] != null)
			{				
				if(!sConfirmValues[0].equals(sValues[0]))
				{
					// if two passwords aren't equal
					UIError myError = new UIError(UIErrorLevel.FRIENDLY,
							UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(2171,"ptmsgs_portaladminmsgs"),
							m_asOwner.GetString(2171,"ptmsgs_portaladminmsgs"));
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
						m_asOwner.GetApplication());

					return null;
				}
			}
			

			m_asModel.SetUserPass(sValues[0]);
		}

		// Do Create Account
		sValues = (String[]) arguments.GetElement(PARAM_DOCREATEACCOUNT);

		if (sValues != null)
		{
			boolean boTemp;

			try
			{
				boTemp = XPConvert.ToBoolean(sValues[0]);
			}
			catch (Exception e)
			{
				
					log.Error("Unexpected data: " + sValues[0]);
				

				boTemp = false;
			}

			if (boTemp || m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
			{
				myRedirect = m_asModel.DoCreateAccount(m_xpRequest, m_WebData);

				// This method tells the interpeter whether or not to get a new
				// session, which is basically the same as whether or not login
				// succeeded.
				if (m_asModel.DoGetSession())
				{
					
						log.Debug("Execute() - account created successfully.");
					

					if (myRedirect == null)
					{
						log.Debug("Execute() - Redirecting to welcome DP.");

						myRedirect = new Redirect();
						myRedirect.SetLinkGetCachedSpace(m_asOwner);
						myRedirect.SetDisplayPage(WelcomeDP.STR_MVC_CLASS_NAME);
						// Make this a 302 redirect so that the 508 help page
						// can get back to the appropriate URL.
						myRedirect.SetIsHTTPRedirect(true);
					}
				}
			}
		}

		// null out XPRequest & IWebData
		m_xpRequest = null;
		m_WebData = null;

		return myRedirect;
	}

	/////////////
	// IMVCObject
	/////////////

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CreateAccountControl();
	}

	/////////////////////////////
	// Methods from ILoginControl
	/////////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#DoGetSession()
	 */
	public boolean DoGetSession()
	{
		// The interpreter should ask us for the session.
		return m_asModel.DoGetSession();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#GetSession()
	 */
	public Object GetSession()
	{
		return m_asModel.GetSession();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#Init(IModelRW)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (CreateAccountModel) model;
		m_asOwner     = space;
	}

	/**
	 * 
	 *
	 * @param r 
	 * @param webdata
	 */
	public void SetHTTPItems(IXPRequest r, IWebData webdata)
	{
		m_xpRequest     = r;
		m_WebData     = webdata;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.ILoginControl#SetRedirectForUseAfterLogin(Redirect)
	 */
	public void SetRedirectForUseAfterLogin(Redirect r)
	{
		//Not implemented
	}
}

