package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * Control to expand or collapse a portlet on a given community or my page. 
 *
 * @author michaeld
 */
public class CollapsePortletControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.CollapsePortletControl");

	public static final String STR_MVC_CLASS_NAME = "CollapsePortlet";
	
	public static final String STR_PORTLET_TO_COLLAPSE_EXPAND = "CollapseOrExpandThisGadget";
	
	public static final String STR_EXPAND_CONTROL = "ExpandPortlet";
	
	public static final String STR_COLLAPSE_CONTROL = "CollapsePortlet";

	/** Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IMyPortalModel m_asModel;

	/**
	 * Constructor for CollapsePortletControl.
	 */
	public CollapsePortletControl()
	{
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		if(MyPortalModel.IsGuestSession(m_asOwner))
		{
			return null;
		}
		
		// Get Page ID.
		String[] saPageID = (String[]) arguments.GetElement(SetPageControl.STR_PAGE_ID);
		if (saPageID == null)
		{
			
				log.Error("could not find page ID in query string.");
			

			return null;
		}
		int nPageID = XPConvert.ToInteger(saPageID[0]);
		
		// Get Community ID
		String[] saCommunityID = (String[]) arguments.GetElement(SetCommunityControl.STR_COMMUNITY_ID);
		int nCommunityID=0;
		if (saCommunityID == null)
		{
			
				log.Debug("could not find community ID in query string; will assume this is a mypage.");
			
		} else {
			nCommunityID = XPConvert.ToInteger(saCommunityID[0]);	
		}	

		// Get ID of portlet to collapse or expand.				
		String[] saPortletID = (String[]) arguments.GetElement(STR_PORTLET_TO_COLLAPSE_EXPAND);

		if (saPortletID == null)
		{
			
				log.Error("could not find portlet index in query string.");
			

			return null;
		}
		
		// DCA - for collapsing/expanding through ajax (not currently used)
		String[] saPage = (String[]) arguments.GetElement(ASConstants.PAGE);
		if (null != saPage && saPage[0].equals(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME)) {
			m_asOwner.SetIsInPlaceRefreshDisplayOn(true);
		}

		//		Get whether to expand or collapse the portlet.
	 	String[] saControlName = (String[]) arguments.GetElement(ASConstants.CONTROL);
	 	if (saControlName == null)
		{
			
				log.Error("Could not find control name in query string.");
			
   
			return null;
		}		
		
		// Expand or Collapse Portlet.
		if ((STR_COLLAPSE_CONTROL).equals(saControlName[0]))
		{
			m_asModel.CollapsePortlet(nCommunityID, nPageID, XPConvert.ToInteger(saPortletID[0]));
			// DCA - for collapsing/expanding through ajax (not currently used)
			if (m_asOwner.GetIsInPlaceRefreshDisplayOn()) {
				MyPortalPartialPortletsDP page = (MyPortalPartialPortletsDP) m_asOwner.GetPage(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
				page.SetDisplayHelperToCollapseExpand();
			}
		}
		else if ((STR_EXPAND_CONTROL).equals(saControlName[0]))
		{
			m_asModel.ExpandPortlet(nCommunityID, nPageID, XPConvert.ToInteger(saPortletID[0]));
			// DCA - for collapsing/expanding through ajax (not currently used)
			if (m_asOwner.GetIsInPlaceRefreshDisplayOn()) {
				MyPortalPartialPortletsDP page = (MyPortalPartialPortletsDP) m_asOwner.GetPage(MyPortalPartialPortletsDP.STR_MVC_CLASS_NAME);
				page.SetDisplayHelperToCollapseExpand();
			}
		}
		else
		{
			log.Error("Control name \"" + saControlName[0] + "\" in query string is not correct.");
			return null;
		}

		// MJD: the following code was lifted from SetCommunityControl
		// Get the profile user id, if any. This is needed for the user profile community.
		int nProfileID = 0;

		if (nCommunityID == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
		{
			// Default value of -1 indicates the user is looking at their own profile
			// value of 0 would mean this isn't a profile page.
			nProfileID = -1;
			String[] saProfileID = (String[]) arguments.GetElement(SetCommunityControl.PROFILEID);
			if (saProfileID != null)
			{
				nProfileID = XPConvert.ToInteger(saProfileID[0]);
			}
			
			// dap: force help on user profiel community to appropriate page
			m_asOwner.SetHelpTopic("PT_SectionUserProfile");
		}
		// Set the profile ID.
		boolean bSetProfileSuccessful = m_asModel.SetProfileID(nProfileID);

		// Set Raw Headers
		String strHeaders = HttpUtils.GetRawHeaders( m_asOwner.GetCurrentHTTPRequest() );
		m_asModel.SetRawHeaders( strHeaders );
		
		Redirect redirect = null;
		
		if (0 != nCommunityID)
		{
			// Is a community.

			// GET THE REAL PAGEID AFTER GET COMMUNITY (handles the pageid=0 case)

			boolean bSetCommunitySuccessful = false;
			// Avoid useless work if we have to redirect anyway.
			if (bSetProfileSuccessful) 
			{
				bSetCommunitySuccessful = m_asModel.SetCommunity(nCommunityID, nPageID);
			}

			// If either SetPage or SetCommunity fails, we want to redirect here.
			if (!bSetProfileSuccessful || !bSetCommunitySuccessful)
			{
				redirect = new Redirect();
				redirect.SetIsErrorRedirect(true);
				redirect.SetLinkGetCachedSpace(m_asOwner);
				redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
				redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, nCommunityID);
				redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID, nPageID);
				if (nProfileID != -1)
				{
					redirect.AddControlArgument(SetCommunityControl.PROFILEID, nProfileID);
				}
			}
		}
		else
		{
			// Is a my page.
			
			// Setup the My Page.
			boolean bSuccessful = m_asModel.SetPage(nPageID);
			
			// If setting the my page was not successful, then redirect to an error page.
			if (!bSuccessful)
			{
				redirect = new Redirect();
				redirect.SetIsErrorRedirect(true);
				redirect.SetLinkGetCachedSpace(m_asOwner);
				redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
				redirect.AddControlArgument(SetPageControl.STR_PAGE_ID, nPageID);
			}
		}

		return redirect;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CollapsePortletControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel = (IMyPortalModel) model;
		m_asOwner     = space;
	}
}

