/*
 * Created on Mar 11, 2003
 */
package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.objectselection.communities.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * Handles fallback case where there's no control available.  This can occur
 * on various fallthrough conditions such as ClearErrorsAndReturn().
 * 
 * @author DavidP
 */
public class DefaultPageControl implements IControl 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.DefaultPageControl");

	
	public static final String STR_MVC_CLASS_NAME = "DefaultPage";

	/** Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IMyPortalModel m_asModel;

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#CheckActionSecurityAndExecute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments) 
	{
		// Determine what space we're hanging off of here
		if (m_asOwner instanceof MyPageAS)
		{
			// it's a mypage
			return RedirectToMyPage(arguments);
		}
		else if (m_asOwner instanceof CommunityPageAS)
		{
			// it's a community page
			return RedirectToCommunityPage(arguments);
		}
		else if (m_asOwner instanceof PreviewCommunityAS)
		{
			// it's a community preview page
			return RedirectToCommunityPage(arguments);
		}
		else
		{
			return GetSubPortalRedirectDefaultPage();	
		}
	}
	
	/**
	 * Redirects to a mypage.
	 * 
	 * @param arguments
	 * @return Redirect
	 */
	public Redirect RedirectToMyPage(XPHashtable arguments)
	{
		Redirect redirect = null;
		int nPageID = 0;
		boolean bSuccessful = false;

		nPageID = m_asModel.GetPageID();
		
		bSuccessful = m_asModel.SetPage(nPageID);

		if (!bSuccessful)
		{
			redirect = GetSubPortalRedirectDefaultPage();
			UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return redirect;
	}
	
	/**
	 * Redirects to a community page.
	 * 
	 * @param arguments
	 * @return Redirect
	 */
	public Redirect RedirectToCommunityPage(XPHashtable arguments)
	{
		Redirect redirect = null;
		int nCommunityID = NavigationModel.NO_CURRENT_COMMID;
		int nPageID = 0;

		boolean bSuccessful = false;

		nCommunityID = m_asModel.GetCommunityID();
		nPageID = m_asModel.GetPageID();	
		 
		bSuccessful = m_asModel.SetCommunity(nCommunityID, nPageID);

		// If this is a user profile community, we also need to set the
		// profile ID.  This is mainly necessary because when an editor
		// finishes and tries to return to the user profile community,
		// it will have lost the ID of the user being viewed and we need
		// to regenerate all the necessary data.
		if (nCommunityID == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
		{
			// Setting the ID setups the page to view the requested user.
			boolean bResult = m_asModel.SetProfileID(m_asModel.GetProfileID());
	
			bSuccessful = bSuccessful && bResult;
		}

		if (!bSuccessful)
		{
			redirect = GetSubPortalRedirectDefaultPage();
			UIErrorHandler.ClearErrors(m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return redirect;	
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (IMyPortalModel) model;
		m_asOwner     = space;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName() 
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create() 
	{
		return new DefaultPageControl();

	}

	/**
	 * 
	 *
	 * @return 
	 */
	private Redirect GetSubPortalRedirectDefaultPage()
	{
		// *** Subportal redirection BEGIN
		
			log.Debug("Entering subportal redirect.");
		

		Redirect redirect    = new Redirect();
		redirect.SetIsHTTPRedirect(true);
		int nDefaultPageType = GetSubPortalFirstPageType();
		int nDefaultPageID   = GetSubPortalPageID();

		switch (nDefaultPageType)
		{
		case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS:

			// 1. Go to comm page
			// 2. If no access to comm page -> Go to default comm
			// 3. If no default comm -> Join comm page
			nDefaultPageID = GetAccessibleCommunityID(nDefaultPageID);

			if (nDefaultPageID != -1)
			{
				redirect.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME,
					m_asOwner);
				redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
				redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
					nDefaultPageID);
				redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID,
					0);

				
					log.Info("Redirecting to community with id: " + nDefaultPageID);
				
			}
			else
			{
				redirect.SetLinkCreateNewSpace(CommunitySelectionEditorAS.STR_MVC_CLASS_NAME,
					m_asOwner);
				redirect.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
				redirect.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
					EditorStartControl.EDITOR_START_FLAG_MISC);

				
					log.Info("No Community memberships, redirecting to community selection page.");
				
			}

			break;

		case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_DIRECTORY_ACCESS:
			redirect.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
			redirect.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
			redirect.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
				DirConstants.BROWSE_MODE);
			redirect.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
				nDefaultPageID);

			
				log.Info("Redirecting to directory page with folder id: " +
					nDefaultPageID);
			

			break;

		case PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS:
			redirect.SetLinkCreateNewSpace(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
			redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
			redirect.AddControlArgument(SetPageControl.STR_PAGE_ID,
				SetPageControl.N_HOME_PAGE_ID);

			
				log.Info("Redirecting to mypage.");
			

			break;
		}

		return redirect;

		// *** Subportal redirection END
	}

	/**
	 *
	 * @param nSubPortalCommID
	 * @return int
	 */
	private int GetAccessibleCommunityID(int nSubPortalCommID)
	{
		// 1. Go to comm page
		// 2. If no access to comm page -> Go to default comm
		// 3. If no default comm -> Join comm page
		IPTSession m_ptSession = m_asModel.GetSession();

		IPTObjectManager objOMCommunites = m_ptSession.GetCommunities();

		if (objOMCommunites.IsObjectAccessible(nSubPortalCommID,
					m_ptSession.GetSessionInfo().GetCurrentUserID(),
					PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ))
		{
			return nSubPortalCommID;
		}

		IPTQueryResult ptCommunityMembership = m_ptSession.GetSessionInfo()
			.GetCurrentCommunityMembership();

		if (ptCommunityMembership.RowCount() != 0)
		{
			int intFirstCommunityID = ptCommunityMembership.ItemAsInt(0, PT_PROPIDS.PT_PROPID_OBJECTID);

			return intFirstCommunityID;
		}
		return -1;
	}
	
	/**
	 *
	 * @return int
	 */
	private int GetSubPortalFirstPageType()
	{
		IPTSession ptSession = m_asModel.GetSession();

		try
		{
			IPTSubPortalInfo subPortal = (ptSession.GetSessionInfo()
				.GetCurrentUserCachedSubPortalInfo());
			int nAccessType			   = subPortal.GetDefaultFirstPageType();

			return nAccessType;
		}
		catch (Exception e)
		{
			
				log.Error(e, "Unable to get the SubPortalInfo object for First Page type: " +
					e.getMessage());
			

			return -1;
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	private int GetSubPortalPageID()
	{
		IPTSession ptSession = m_asModel.GetSession();

		try
		{
			IPTSubPortalInfo subPortal = (ptSession.GetSessionInfo()
				.GetCurrentUserCachedSubPortalInfo());
			int nFirstPageID		   = subPortal.GetDefaultFirstPageID();

			return nFirstPageID;
		}
		catch (Exception e)
		{
			
				log.Error(e, "Unable to get the SubPortalInfo object for First Page ID: " +
					e.getMessage());
			

			return -1;
		}
	}

}

