package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openfoundation.util.*;

/**
 * Model interface used by plugin navigation. All setters and
 * modifiers should go here.
 *
 * @author btse
 */
public interface IMyPortalModel extends IMyPortalModelRO 
{
	/**
	 * Adds a single portlet to the page. First opens the page, locks it,
	 * adds the portlet, stores and unlocks the page.
	 * @param nPageID
	 * @param nPortletID
	 */
	public void AddSinglePortlet (int nPageID, int nPortletId);

	/**
	 * Adds a portlet bundle to the page. First opens the page, locks it,
	 * adds the portlets, stores and unlocks the page.
	 * @param nPageID
	 * @param nPortletBundleID
	 */
	public void AddPortletBundle (int nPageID, int nPortletBundleID);

	/**
	 * Collapses the gadget at the given index.
	 *
	 * @param nPortletIndex nPortletID
	 */
	public void CollapsePortlet(int nCommunityID, int nPageID, int nPortletToCollapse);
	
	/**
	 * Expands the gadget at the given index.
	 *
	 * @param nPortletIndex nPortletID
	 */
	public void ExpandPortlet(int nCommunityID, int nPageID, int nPortletToExpand);

	/**
	 * Reassigns the specified column (region) in the page with the given portlet array.
	 *
	 * @param arrPortletIDs array of portlet IDs
	 * @param nColumn nColumn
	 * @param nPageID nPageID
	 */
	public void ReassignPortlets (int[] arrPortletIDs, int nColumn, int nPageID);

	/**
	 * Removes single portlet from the page. First opens the page and locks it
	 * Remove the portlet, stores and unlocks the page.
	 * @param nPageID
	 * @param nPortletIndex
	 */
	public void RemoveSinglePortlet (int nPageID, int nPortletIndex);
	
	/**
	 * Sets the community to be viewed and calls SetPage
	 *
	 * @param nCommunityID nCommunityID
	 * @param nPageID nPageID
	 * @return true if successful, else false
	 */
	public boolean SetCommunity(int nCommunityID, int nPageID);
	
	/**
	 * Sets the page to be a preview page or not.
	 *
	 * @param bIsPreviewPage bIsPreviewPage
	 */
	public void SetIsPreviewPage(boolean bIsPreviewPage);
	
	/**
	 * Sets up the page of the given ID.
	 *
	 * @param nPageID nPageID
	 * @return true if successful, else false; false requires login redirect
	 */
	public boolean SetPage(int nPageID);
	
	/**
	 * Method SetProfileID.  Returns false if the current user doesn't have access to the given profile.
	 *
	 * @param nProfileID
	 * @return true if successful, else false
	 */
	public boolean SetProfileID(int nProfileID);
	
	/**
	 * Sets the raw headers from the request.
	 * 
	 * @param strRawHeaders
	 */
	public void SetRawHeaders(String strRawHeaders);

	/**
	 * Resets the list of recently added portlets.
	 *
	 */
	public void ResetRecentlyAddedPortlets();

	/**
	 * Queries the portlet content of the recently added portlets, if
	 * there are any.  Does nothing if there are no recently added portlets
	 * (including not resetting the content data), so be sure to check that
	 * there are recently added portlets before calling this.
	 */
	public boolean QueryRecentlyAddedPortletContent();
	
	/**
	 * Queries the portlet content of the recently collapsed portlets, if
	 * there are any.  Does nothing if there are no recently collapsed portlets
	 * (including not resetting the content data), so be sure to check that
	 * there are recently collapsed portlets before calling this.
	 */
	public boolean QueryRecentlyCollapsedExpandedPortletContent();

	/**
	 * Resets the variable to 0
	 *
	 */
	public void ResetRecentlyRemovedPortlet();
	
	/**
	 * Resets the variable to 0
	 *
	 */
	public void ResetRecentlyCollapsedExpandedPortlet();
	
	/**
	 * Register model, view, and control for intrinsic portlet.  Initialize
	 * portlet with the portletID, the IPTMyPortal object, and the
	 * AppDataState object.
	 *
	 * @param _strPortletClass Class identifier for portlet
	 * @param _strStorageName Storage name for portlet
	 * @param _nPortletIndex Portlet index
	 *
	 * @throws XPException Exception thrown if model, view, or control is not
	 *         registered successfully.
	 */
	public void SetupIntrinsicPortlet(String _strPortletClass, String _strStorageName, int _nPortletIndex);
}