package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Model interface used by plugin navigation
 *
 * @author MichaelD
 * @author DavidP
 */
public interface IMyPortalModelRO extends IModelRO
{
	/**
	 * Get the community ID of the community we are currently viewing.
	 *
	 * @return int nCommunityID
	 */
	public int GetCommunityID();

	/**
	 * Get the name of the community we are currently viewing.
	 *
	 * @return string
	 */
	public String GetCommunityName();

	/**
	 * Get the pages in the community.
	 *
	 * @return IPTQueryResult ptqrCommunityPages
	 */
	public IPTQueryResult GetCommunityPages();

	/**
	 * Get the first gadget index in the given column.
	 *
	 * @param nPortletColumn nPortletColumn
	 *
	 * @return int nPortletIndex
	 */
	public int GetFirstPortletIndexInColumn(int nPortletColumn);

	/**
	 * Get the whether the gadget at the given index is collapsed.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletCollapsed
	 */
	public boolean GetPortletCollapsed(int nPortletIndex);
	
	/**
	 * Get the gadget column from the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return int nPortletColumn
	 */
	public int GetPortletColumnFromIndex(int nPortletIndex);

	/**
	 * Get the number of gadgets on the page we are currently viewing.
	 *
	 * @return int nPortletCount
	 */
	public int GetPortletCount();

	/**
	 * Get the gadget's disabled message from the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletDisabledMessage
	 */
	public String GetPortletDisabledMessage(int nPortletIndex);

	/**
	 * Get the whether the gadget at the given index is enabled.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletEnabled
	 */
	public boolean GetPortletEnabled(int nPortletIndex);

	/**
	 * If there was an error, display the gadget header regardless of any other
	 * settings.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bDisplayHeader
	 */
	public boolean GetDisplayPortletHeaderDueToError(int nPortletIndex);
	
	/**
	 * If there was an error, display the gadget header regardless of any other
	 * settings.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 */
	public void SetDisplayPortletHeaderDueToError(int nPortletIndex, boolean bDisplayHeader);


	/**
	 * Get the gadget content from the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletHTMLText
	 */
	public Object[][] GetPortletHTMLTextFromIndex(int nGadgetIndex);

	/**
	 * Get whether the gadget at the given index has a help URL.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasHelpURL
	 */
	public boolean GetPortletHasHelpURL(int nPortletIndex);

	/**
	 * Get whether the gadget at the given index has a Admin Preference URL.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasAdminPrefsURL
	 */
	public boolean GetPortletHasAdminPrefsURL(int nPortletIndex);
	
	/**
	 * Get whether the gadget at the given index has a Community Preference URL.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasCommunityPrefsURL
	 */
	public boolean GetPortletHasCommunityPrefsURL(int nPortletIndex);
	
	/**
	 * Get whether the gadget at the given index has a User Preference URL.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasUserPrefsURL
	 */
	public boolean GetPortletHasUserPrefsURL(int nPortletIndex);

	/**
	 * Get whether the gadget at the given index has a Collapse/Expand URL.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasCollapseExpandURL
	 */
	public boolean GetPortletHasCollapseExpandURL(int nPortletIndex);

	/**
	 * Get the UUID of the portlet.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strUUID
	 */
	public String GetPortletUUID(int nPortletIndex);	

	/**
	 * Get whether a gadget has a title bar or not.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasTitleBar
	 */
	public boolean GetPortletHasTitleBar(int nPortletIndex);

	/**
	 * Get the gadget help URL at the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletHelpURL
	 */
	public String GetPortletHelpURL(int nPortletIndex);
	
	/**
	 * Get the gadget Admin Preference URL at the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletAdminPrefsURL
	 */
	public String GetPortletAdminPrefsURL(int nPortletIndex);
	
	/**
	 * Get the gadget Community Preference URL at the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletCommunityPrefsURL
	 */
	public String GetPortletCommunityPrefsURL(int nPortletIndex);
	
	/**
	 * Get the gadget User Preference URL at the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletUserPrefsURL
	 */
	public String GetPortletUserPrefsURL(int nPortletIndex);
	
	/**
	 * Get the gadget Collapse/Expand URL at the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 * @param strControl strControl
	 *
	 * @return String strPortletCollapseExpandURL
	 */
	public String GetPortletCollapseExpandURL(int nPortletIndex, String strControl);
	
	/**
	 * Get the gadget Remove URL at the given index.
	 * 
	 * @param nPortletIndex
	 * 
	 * @return String strPortletRemoveURL
	 */
	public String GetPortletRemoveURL(int nPortletIndex); 

	/**
	 * Get the gadget ID from the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return int nPortletID
	 */
	public int GetPortletIDFromIndex(int nPortletIndex);

	/**
	 * Get the whether the gadget at the given index is mandatory.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletIsMandatory
	 */
	public boolean GetPortletIsMandatory(int nPortletIndex);

	/**
	 * Get the gadget name from the given index.
	 *
	 * @param nPortletColumn nPortletIndex
	 *
	 * @return String strPortletName
	 */
	public String GetPortletNameFromIndex(int nPortletColumn);

	/**
	 * Get the gadget ID string from the given index.
	 *
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return String strPortletID
	 */
	public String GetIDStringForPortlet(int nPortletIndex);
	
	/**
	 * Returns whether or not the gadget supports 508 mode
	 */
	public boolean GetPortletSupports508(int nPortletIndex);
	
	/**
	 * Returns a bitmask of the types of personalization this portlet supports. 
	 */
	public int GetPortletSupportsPersonalization(int nPortletIndex);

	/**
	 * Get the helper object for this model.
	 *
	 *
	 * @return IMyPortalModelHelper
	 */
	public IMyPortalModelHelper GetHelper();

	/**
	 * Get whether the current page is a community page.
	 *
	 * @return boolean bIsCommunityPage
	 */
	public boolean GetIsCommunityPage();

	/**
	 * Get the last gadget index in the given column.
	 *
	 * @param nPortletColumn nPortletColumn
	 *
	 * @return int nPortletIndex
	 */
	public int GetLastPortletIndexInColumn(int nPortletColumn);

	/**
	 * Get the ASURL for the page we are on.
	 *
	 * @return ASURL asurlPage
	 */
	public ASURL GetPageASURL();

	/**
	 * Get the page ID of the page we are currently viewing.
	 *
	 * @return int nPageID
	 */
	public int GetPageID();

	/**
	 * Get the name of the page we are currently viewing.
	 *
	 * @return string
	 */
	public String GetPageName();

	/**
	 * Get the page type of the page we are currently viewing.
	 *
	 * @return int nPageType
	 */
	public int GetPageType();
	
	/**
	 * 
	 * @return The Portlet Layout Webservice Id, or 0 if none is set on this page.
	 */
	public int GetPortletLayoutId();
	
	
	/**
	 * If the current page has an adaptive Portlet Layout set.
	 * 
	 * @return
	 */
	public boolean UsesPortletLayout();

	/**
	 * Get the current IPTSession. This method should only be used by
	 * MyPortalModel.
	 *
	 * @return int nPageID
	 */
	public IPTSession GetSession();
	
	/**
	 * Get the PortletPrefButton boolean from the varpack.
	 * 
	 * @return string
	 */
	public String GetPortletPrefButtonBoolean();
	
	/**
	 * Returns whether the portlet at a given index has a Refresh button.
	 * @param nPortletIndex nPortletIndex
	 *
	 * @return boolean bPortletHasRefreshButton
	 */
	public boolean GetPortletHasRefreshButton(int nPortletIndex);
	
	/**
	 * Returns the markup which should be displayed in case of a collapsed or error portlet.
	 * @param nPortletIndex
	 * @return object markup array
	 */
	public Object[][] GetCollapsedOrErrorContent(int nPortletIndex);
	
	/**
	 * Returns the id of the portlet that was recently added to the page
	 * @return a list of the portlets that were recently added to the page.
	 */
	public XPArrayList GetRecentlyAddedPortlets();

	/**
	 * Returns the id of the portlet that was recently removed from the page
	 * @return id of portlet
	 */
	public int GetRecentlyRemovedPortlet();
	
	/**
	 * Returns the id of the portlet that was recently collapsed from the page
	 * @return id of portlet
	 */
	public int GetRecentlyCollapsedExpandedPortlet();

	/**
	 * Get the profile ID of the user being viewed on the user profile community.
	 * @return the user ID of the profile being viewed, 0 if not used.
	 */
	public int GetProfileID();
	
	/**
	 * Get the portlet pref actions.
	 * 
	 * @param nPortletIndex
	 * @return list of FullURLs
	 */
	public IXPList GetPortletPreferenceActionsData(int nPortletIndex);
}