package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;

/**
 * This object is primarily used for the IMyPortalPageActions as the return parameter
 * of the OnCreateMyPortalPage. It will contain a page name and page type that will refer
 * to one of the valid PageTypeConstants.
 * 
 * Created: April 27, 2003
 * @author Brian C. Harrison
 */
public class MyPortalPageArguments
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.MyPortalPageArguments");

	//Member variable String corresponding to the Page Name.
	private String m_MYPAGE_NAME = "";
	
	//Member variable int corresponding to a valid PageTypeConstant.
	private int m_MYPAGE_TYPE;	
	
	/**
	 * Return the Page Name
	 * 
	 * @return - return the member variable of the object corresponding to the Page Name.
	 */
	public String GetMyPortalPageName()
	{
		return m_MYPAGE_NAME;
	}
	
	/**
	 * Return the Page Type
	 * 
	 * @return - return the member variable of the object corresponding to the Page Type.
	 */
	public int GetMyPortalPageType()
	{
		return m_MYPAGE_TYPE;
	}
	
	/**
	 * This method will set a Page Name for a possible modified My Portal Page.
	 * 
	 * @param _strPageName - String corrsponding to a Page Name.
	 */
	public void SetMyPortalPageName(String _strPageName)
	{
		m_MYPAGE_NAME = _strPageName;
	}
	
	/**
	 * This method will allow for a Page Type to be set
	 * 
	 * @param _ptcPageType - int type that must correspond to a valid Page Type Constant.
	 */
	public void SetMyPortalPageType(int _ptcPageType)
	{
		if (_ptcPageType < 0 || _ptcPageType > 12)
		{
			
				log.Error("MyPortalPageArguments.SetMyPortalPage - Invalid Page Type value.");
			
		}
		else
		{
			m_MYPAGE_TYPE = _ptcPageType;
		}
	}
}
