package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * 
 *
 * @author MichaelD
 */
public class SetCommunityControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.SetCommunityControl");

	
	public static final String STR_MVC_CLASS_NAME = "SetCommunity";

	
	public static final String STR_COMMUNITY_ID = "CommunityID";

	
	public static final String STR_PAGE_ID = "PageID";

	/** User ID */
	public static final String PROFILEID = "ProfileID";
	
	/** Is Preview? */
	public static final String PREVIEW = "Preview";

	/** Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IMyPortalModel m_asModel;

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// Get Community ID.
		String[] saCommunityID = (String[]) arguments.GetElement(STR_COMMUNITY_ID);
		if (saCommunityID == null)
		{
			
				log.Error("could not find community ID in query string.");
			

			return null;
		}
		int nCommunityID = XPConvert.ToInteger(saCommunityID[0]);

		// Get Page ID.
		int nPageID = 0;
		String[] saPageID = (String[]) arguments.GetElement(STR_PAGE_ID);
		if (saPageID != null)
		{
			nPageID = XPConvert.ToInteger(saPageID[0]);
		}
		// this will get executed if the user is using an old URL that uses a negative page id
		if ( 0 > nPageID )
		{
			nPageID = 0;
		}

		// Get whether this is a Preview Page.
		boolean bIsPreviewPage = false;
		String[] saIsPreview = (String[]) arguments.GetElement(PREVIEW);
		if(saIsPreview != null)
		{
			bIsPreviewPage = true;	
		}
		// Set whether this is a Preview Page.
		m_asModel.SetIsPreviewPage(bIsPreviewPage);
		
		// Get the profile user id, if any. This is needed for the user profile community.
		int nProfileID = 0;
		if (nCommunityID == PT_INTRINSICS.PT_PROFILE_COMMUNITY)
		{
			// Default value of -1 indicates the user is looking at their own profile
			// value of 0 would mean this isn't a profile page.
			nProfileID = -1;
			String[] saProfileID = (String[]) arguments.GetElement(PROFILEID);
			if (saProfileID != null)
			{
				nProfileID = XPConvert.ToInteger(saProfileID[0]);
			}
			
			// dap: force help on user profiel community to appropriate page
			m_asOwner.SetHelpTopic("PT_SectionUserProfile");
		}
		// Set the profile ID.
		boolean bSetProfileSuccessful = m_asModel.SetProfileID(nProfileID);

		// Set Raw Headers
		String strHeaders = HttpUtils.GetRawHeaders( m_asOwner.GetCurrentHTTPRequest() );
		m_asModel.SetRawHeaders( strHeaders );
		
		// GET THE REAL PAGEID AFTER GET COMMUNITY (handles the pageid=0 case)
		
		boolean bSetCommunitySuccessful = false;
		// Avoid useless work if we have to redirect anyway.
		if (bSetProfileSuccessful) 
		{
			// Setup Community
			bSetCommunitySuccessful = m_asModel.SetCommunity(nCommunityID, nPageID);
		}

		Redirect redirect = null;

		// If either SetPage or SetCommunity fails, we want to redirect here.
		if (!bSetProfileSuccessful || !bSetCommunitySuccessful)
		{
			redirect = new Redirect();
			redirect.SetIsErrorRedirect(true);
			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
			redirect.AddControlArgument(STR_COMMUNITY_ID, nCommunityID);
			redirect.AddControlArgument(STR_PAGE_ID, nPageID);
			if (nProfileID != -1)
			{
				redirect.AddControlArgument(PROFILEID, nProfileID);
			}
		}

		return redirect;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetCommunityControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#Init(IModelRW)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (IMyPortalModel) model;
		m_asOwner     = space;
	}
}

