package com.plumtree.portalpages.browsing.myportal;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * Handles the MyPage control flow
 *
 * @author MichaelD
 */
public class SetPageControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.SetPageControl");

	/** Class Name */
	public static final String STR_MVC_CLASS_NAME = "SetPage";

	/** Page ID */
	public static final String STR_PAGE_ID = "PageID";
	
	/** Home Page ID constant */
	public static final int N_HOME_PAGE_ID = 0;

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IMyPortalModel m_asModel;

	/**
	 * Constructor for SetPageControl.
	 */
	public SetPageControl()
	{
		super();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// Get Page ID.
		String[] saPageID = (String[]) arguments.GetElement(STR_PAGE_ID);
		if (saPageID == null)
		{
			
				log.Error("could not find page ID in query string.");
			

			return null;
		}
		int nPageID = XPConvert.ToInteger(saPageID[0]);
		
		// My Pages are never previewable.
		m_asModel.SetIsPreviewPage(false);
		// My Pages never receive a profile ID.
		m_asModel.SetProfileID(0);

		// Set Raw Headers.
		String strHeaders = HttpUtils.GetRawHeaders( m_asOwner.GetCurrentHTTPRequest() );
		m_asModel.SetRawHeaders( strHeaders );
		
		// Setup the My Page.
		boolean bSuccessful = m_asModel.SetPage(nPageID);

		Redirect redirect = null;
		
		// If setting the my page was not successful, then redirect to an error page.
		if (!bSuccessful)
		{
			redirect = new Redirect();
			redirect.SetIsErrorRedirect(true);
			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
			redirect.AddControlArgument(SetPageControl.STR_PAGE_ID, nPageID);
		}

		return redirect;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetPageControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#getName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (IMyPortalModel) model;
		m_asOwner     = space;
	}
}

