package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * 
 *
 * @author MichaelD
 */
public class CommunityMyPortalModelHelper implements IMyPortalModelHelper
{
	
	public static final String COMCOLLAPSEDGADGETS    = "COMCollapsedGadgets";

	
	public static final String COMGADGETHASNOTITLEBAR = "COMPortletHasNoTitleBar";

	
	private AActivitySpace m_asOwner				 = null;
	private IPTCommunityManager m_ptCommunityManager = null;
	

	/**
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetCollapsedPortletsPrefName()
	 */
	public String GetCollapsedPortletsPrefName()
	{
		return COMCOLLAPSEDGADGETS;
	}

	/**
	 * Return the access level for the community.
	 */
	public int GetCommunityAccessLevel(int nCommunityID)
	{
		try
		{
			return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).GetAccessLevel();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, e,
				m_asOwner.GetString(1518, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1519, "ptmsgs_portalbrowsingmsgs"));

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_NONE;
	}

	/**
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetCommunityPages(int)
	 */
	public IPTQueryResult GetCommunityPages(int nCommunityID)
	{
		return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).GetPages();
	}

	/**
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetPortletHasNoTitleBar(int)
	 */
	public Object[][] GetPortletHasNoTitleBar(int nCommunityID)
	{
		return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).LookupPreference(COMGADGETHASNOTITLEBAR, 0, PT_PREF_TYPES.PT_PREFTYPE_ALL_USERS);
	}

	/**
	 * Return the headerID for the community; used when processing the style
	 * sheet.
	 */
	public int GetHeaderID(int nCommunityID)
	{
		try
		{
			return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID,
				false).GetHeaderID();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, e,
				m_asOwner.GetString(1520, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1521, "ptmsgs_portalbrowsingmsgs"));

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return 0;
	}

	/**
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetIsCommunityPage()
	 */
	public boolean GetIsCommunityPage()
	{
		return true;
	}

	/**
	 * Return the stylesheet for the community; used when processing the style
	 * sheet.
	 */
	public String GetStyleSheet(int nCommunityID)
	{
		try
		{
			return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID,
				false).GetStyleSheet();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, e,
				m_asOwner.GetString(1522, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1523, "ptmsgs_portalbrowsingmsgs"));

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return "";
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init(AActivitySpace)
	 */
	public void Init(IPTSession ptSession, AActivitySpace parent)
	{
		m_ptCommunityManager     = (IPTCommunityManager) ptSession.GetCommunities()
			.GetInterfaces("IPTCommunityManager");
		m_asOwner				 = parent;
	}

	//////////////////////////////////////
	// Methods from IMyPortalModelHelper
	//////////////////////////////////////

	/**
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#OpenPage(int,
	 *      int)
	 */
	public IPTPageInfo OpenPage(int nCommunityID, int nPageID)
	{
		try
		{
			return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false)
			.GetPage(nPageID);
		}
		catch (PTException ptex)
		{
			if ( PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_PAGE != ptex.GetErrorCode() &&
				PT_RESULTCODES.PT_E_COMMUNITY_NO_ACL_ON_ALL_PAGES != ptex.GetErrorCode() )
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, ptex,
					m_asOwner.GetString(1524, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1525, "ptmsgs_portalbrowsingmsgs"));
			
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}

			// TODO: Won't this just cause the error to be displayed anyway down below,
			// even though the above if statement doesn't want it to be displayed?
			throw ptex;
		}
		catch (Exception ex)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, ex,
				m_asOwner.GetString(1524, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1525, "ptmsgs_portalbrowsingmsgs"));
			
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
		
		return null;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelHelper#GetCommunityName(int)
	 * @deprecated Use NavigationModel.GetCurCommunityName instead.
	 */
	public String GetCommunityName(int nCommunityID)
	{
		return m_ptCommunityManager.CachedOpenCommunityInfo(nCommunityID, false).GetName();
	}
}

