package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.openfoundation.internationalization.XPResourceManager;
import com.plumtree.openfoundation.web.XPHttpUtility;
import com.plumtree.openlog.OpenLogService;
import com.plumtree.openlog.OpenLogger;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.uiinfrastructure.activityspace.AActivitySpace;
import com.plumtree.uiinfrastructure.activityspace.IModelRO;
import com.plumtree.uiinfrastructure.activityspace.IView;
import com.plumtree.xpshared.htmlconstructs.PTStyleClass;
import com.plumtree.xpshared.htmlelements.CommonHTMLStrings;
import com.plumtree.xpshared.htmlelements.HTMLAnchor;
import com.plumtree.xpshared.htmlelements.HTMLElement;
import com.plumtree.xpshared.htmlelements.HTMLException;
import com.plumtree.xpshared.htmlelements.HTMLScript;
import com.plumtree.xpshared.htmlelements.HTMLTable;
import com.plumtree.xpshared.htmlelements.HTMLTableCell;
import com.plumtree.xpshared.htmlelements.HTMLTableRow;

/**
 * Section for unsubscribing/quitting from a community via UnsubscribeCurCommunityControl. 
 * This view displays a successful message if the user successfully unsubscribed, and an 
 * error message if the user is already unsubscribed from the community.
 *
 * @author btse
 */
public class CommunityUnsubscribeView implements IView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
			"com.plumtree.portalpages.browsing.myportal.communities.CommunityUnsubscribeView");
	
	public static final String STR_MVC_CLASS_NAME = "CommunityUnsubscribe";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private IUnsubscribeCommunityModel m_asModel;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityUnsubscribeView();
	}
	
	/**
	 * Method CreateConfirmOfUnsubscribePage - displays page that confirms the unsubscribing
	 * of community and allows to view the unsubscribed community
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	public HTMLElement CreateConfirmOfUnsubscribePage()
	{
		//mainTable components
		HTMLTable mainTable		   = new HTMLTable();
		HTMLTableRow mainRow1	   = new HTMLTableRow();
		HTMLTableRow mainRow2	   = new HTMLTableRow();
		HTMLTableRow mainRow3	   = new HTMLTableRow();
		HTMLTableCell mainRow1Cell = new HTMLTableCell();
		HTMLTableCell mainRow2Cell = new HTMLTableCell();
		HTMLTableCell mainRow3Cell = new HTMLTableCell();

		//congratsTable componenets
		HTMLTable confirmationTable    = new HTMLTable();
		HTMLTableRow confirmationRow   = new HTMLTableRow();
		HTMLTableCell confirmationCell = new HTMLTableCell();

		//linksTable components
		HTMLTable linksTable	    = new HTMLTable();
		HTMLTableRow linksRow1	    = new HTMLTableRow();
		HTMLTableRow linksRow2	    = new HTMLTableRow();
		HTMLTableRow linksRow3	    = new HTMLTableRow();
		HTMLTableCell linksRow1Cell = new HTMLTableCell();
		HTMLTableCell linksRow2Cell = new HTMLTableCell();
		HTMLTableCell linksRow3Cell = new HTMLTableCell();

		//Anchors
		String strNewCommURL		 = m_asModel.GetCommunityURL();
		HTMLAnchor newCommAnchor = new HTMLAnchor(strNewCommURL);

		newCommAnchor.AddInnerHTMLString(m_asOwner.GetString(1922,
				"ptmsgs_portalbrowsingmsgs"));

		//Community Name
		String strCommName = m_asModel.GetCommunityName();

		//Specifying mainTable attributes
		mainTable.SetAlign("center");
		mainTable.SetBorder("0");
		mainTable.SetCellPadding("0");
		mainTable.SetWidth("90%");
		mainTable.SetHeight("30%");

		//Specifying confirmationTable attributes

		confirmationTable.SetBorder("0");
		confirmationTable.SetCellPadding("0");
		confirmationTable.SetWidth("100%");

		//Specifying linksTable attributes
		linksTable.SetBorder("0");
		linksTable.SetCellPadding("0");
		linksTable.SetWidth("100%");

		//Setting up confirmation table
		confirmationCell.SetStyleClass(PTStyleClass.DIALOGUE_TITLE);

		confirmationCell.AddInnerHTMLString(XPResourceManager.FormatMessage(
				m_asOwner.GetString(1921, "ptmsgs_portalbrowsingmsgs"),
				XPHttpUtility.HtmlEncode(strCommName)));
		PreviewCommunityView.addRowCell(confirmationTable, confirmationRow, confirmationCell);

		//Setting up linksTable
		linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
		linksRow1Cell.AddInnerHTMLElement(newCommAnchor);
		PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
		PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
		PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);

		//Setting up the Main Table
		mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		mainRow2Cell.AddInnerHTMLElement(confirmationTable);
		mainRow3Cell.AddInnerHTMLElement(linksTable);
		PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);

		//display page
		return mainTable;
	}

	/**
	 * Method createErrorPage - displays the error page if user is already a
	 * member of the community specified
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	public HTMLElement CreateErrorPage()
	{
		//mainTable components
		HTMLTable mainTable		   = new HTMLTable();
		HTMLTableRow mainRow1	   = new HTMLTableRow();
		HTMLTableRow mainRow2	   = new HTMLTableRow();
		HTMLTableRow mainRow3	   = new HTMLTableRow();
		HTMLTableCell mainRow1Cell = new HTMLTableCell();
		HTMLTableCell mainRow2Cell = new HTMLTableCell();
		HTMLTableCell mainRow3Cell = new HTMLTableCell();

		//errorTable componenets
		HTMLTable errorTable    = new HTMLTable();
		HTMLTableRow errorRow   = new HTMLTableRow();
		HTMLTableCell errorCell = new HTMLTableCell();

		//linksTable components
		HTMLTable linksTable	    = new HTMLTable();
		HTMLTableRow linksRow1	    = new HTMLTableRow();
		HTMLTableRow linksRow2	    = new HTMLTableRow();
		HTMLTableRow linksRow3	    = new HTMLTableRow();
		HTMLTableCell linksRow1Cell = new HTMLTableCell();
		HTMLTableCell linksRow2Cell = new HTMLTableCell();
		HTMLTableCell linksRow3Cell = new HTMLTableCell();

		//Anchors
		String strNewCommName	 = m_asModel.GetCommunityName();
		String strNewCommURL	 = m_asModel.GetCommunityURL();
		HTMLAnchor newCommAnchor = new HTMLAnchor(strNewCommURL);

		newCommAnchor.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1924,
							"ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strNewCommName)));

		//Specifying mainTable attributes
		//align="center" border="0" cellpadding="0" width="90%" height="30%"
		mainTable.SetAlign("center");
		mainTable.SetBorder("0");
		mainTable.SetCellPadding("0");
		mainTable.SetWidth("90%");
		mainTable.SetHeight("30%");

		//Specifying errorTable attributes
		errorTable.SetBorder("0");
		errorTable.SetCellPadding("0");
		errorTable.SetWidth("100%");

		//Specifying linksTable attributes
		linksTable.SetBorder("0");
		linksTable.SetCellPadding("0");
		linksTable.SetWidth("100%");

		//Setting up errorTable
		errorCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);

		errorCell.AddInnerHTMLString(XPResourceManager.FormatMessage(
				m_asOwner.GetString(1923, "ptmsgs_portalbrowsingmsgs"),
				XPHttpUtility.HtmlEncode(strNewCommName)));
		PreviewCommunityView.addRowCell(errorTable, errorRow, errorCell);

		//Setting up linksTable
		linksRow1Cell.SetStyleClass(PTStyleClass.ALERT_TEXT);
		linksRow1Cell.AddInnerHTMLElement(newCommAnchor);
		PreviewCommunityView.addRowCell(linksTable, linksRow1, linksRow1Cell);
		PreviewCommunityView.addRowCell(linksTable, linksRow2, linksRow2Cell);
		PreviewCommunityView.addRowCell(linksTable, linksRow3, linksRow3Cell);

		//Setting up the Main Table
		mainRow1Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		mainRow2Cell.AddInnerHTMLElement(errorTable);
		mainRow3Cell.AddInnerHTMLElement(linksTable);
		PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);

		//display page
		return mainTable;
	}	

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement page = null;

		try
		{
			if (m_asModel.CommunityUnsubscribeFailed())
			{
				page = CreateErrorPage();
			}
			else
			{
				page = CreateConfirmOfUnsubscribePage();
			}
		}
		catch (HTMLException he)
		{
			log.Error(he, "Error displaying page.");
		}

		return page;
	}

	/**
	 * Display JavaScript
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IUnsubscribeCommunityModel) model;
		m_asOwner     = parent;
	}	
}
