package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * File: JoinCommunityControl.java
 * -------------------------------
 * Control that decides whether the user is already
 * a member of the community.  If so, set the page
 * to be an error page, otherwise join the community
 * and congratulate the user.
 *
 * @author NaveenP/DustinA
 */
public class JoinCommunityControl implements IControl
{
	
	public static final String STR_MVC_CLASS_NAME = "JoinCommunity";

	/** Community ID Query String Param */
	public static final String m_CommunityID = "CommunityID";
	private AActivitySpace m_asOwner;

	/** model */
	private PreviewCommunityBarModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		if (!m_asModel.IsCommunityMember())
		{
			m_asModel.SetErrorPage(false);
			if(m_asOwner.GetAccessStyle() == AccessStyles.STANDARD) {
				m_asModel.AddCommunity();
			} else {
				if(arguments.GetElement(RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH) != null)
				{
					m_asModel.AddCommunity();
				}
			}
		}
		else
		{
			m_asModel.SetErrorPage(true);
		}

		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			return null;
		}

		Redirect redirect = new Redirect();
		redirect.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME,
			m_asOwner);
		redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
		redirect.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
			m_asModel.GetCommunityID());
		redirect.AddControlArgument(SetCommunityControl.STR_PAGE_ID,
			0);

		return redirect;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JoinCommunityControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asOwner     = space;
		m_asModel     = (PreviewCommunityBarModel) model;
	}
}

