package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: NoCommunityAccessView.java
 * -------------------------------
 * @author NaveenP/DustinA
 */
public class NoCommunityAccessView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.communities.NoCommunityAccessView");

	
	public static final String STR_MVC_CLASS_NAME = "NoCommunityAccess";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NoCommunityAccessView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		NavigationModel navModel = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
		
		HTMLTable mainTable = new HTMLTable();
		HTMLTableRow mainRow;
		HTMLTableCell mainCell;
		HTMLAnchor anchor;
		ASURL defaultURL = navModel.GetDefaultSubportalURL();

		try
		{			
			mainRow = new HTMLTableRow();
			mainTable.AddInnerHTMLElement(mainRow);
			
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
			mainCell.AddInnerHTMLString(m_asOwner.GetString(1253, "ptmsgs_portalbrowsingmsgs"));
			
			mainCell = new HTMLTableCell();
			mainRow.AddInnerHTMLElement(mainCell);
			mainCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);
			mainCell.AddInnerHTMLString(m_asOwner.GetString(1254, "ptmsgs_portalbrowsingmsgs"));
			
			anchor = new HTMLAnchor(m_asOwner.GetString(1255, "ptmsgs_portalbrowsingmsgs"));
			mainCell.AddInnerHTMLElement(anchor);
			anchor.SetHRef(defaultURL.GetURLAsString());
			anchor.AddInnerHTMLString(m_asOwner.GetString(1255, "ptmsgs_portalbrowsingmsgs"));			
		}
		catch (HTMLException e)
		{
			log.Error(e, e.getMessage());
		}

		return mainTable;
	}

	/**
	 * Display JavaScript - this includes the static source file
	 *
	 * return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		return script;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
	}
}

