package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * File: PreviewCommunityControl.java
 * ----------------------------------
 * Control that sets the community and page IDs
 * and sets the preview type.
 *
 * @author NaveenP/DustinA
 */
public class PreviewCommunityBarControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityBarControl");

	
	public static final String STR_MVC_CLASS_NAME = "PreviewCommunityBar";

	/** Community ID Query String Param */
	public static final String m_CommunityID = "CommunityID";

	/** Community PageID Query String Param */
	public static final String m_PageID = "PageID";

	/** Preview Type Query String Param */
	public static final String m_PreviewType = "PreviewType";

	/** Community Index Query String Param */
	public static final String m_CommunityIndex = "CommunityIndex";

	/** Community Checked Query String Param */
	public static final String m_CommunityChecked = "CommunityChecked";
	
	/** QueryString Parameter for the Join Community Javascript override */
	public static final String m_strJoinCommunityJavascriptOverride = "JoinCommunityJS";

	/** model */
	private PreviewCommunityBarModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String[] sValues = (String[]) arguments.GetElement(m_CommunityID);

		if (sValues == null)
		{
			
				log.Error("could not find community ID in query string.");
			

			return null;
		}

		m_asModel.SetCommunityIDAndOpen(XPConvert.ToInteger(sValues[0]));

		sValues = (String[]) arguments.GetElement(m_PreviewType);

		if (sValues == null)
		{
			
				log.Error("could not find preview type in query string.");
			

			return null;
		}
		
		int nPreviewType = XPConvert.ToInteger(sValues[0]);

		if (nPreviewType == PreviewCommunityBarModel.SELECTIONPREVIEWHEADER)
		{
			m_asModel.SetCommunityToSelectionPreviewPage();
			sValues = (String[]) arguments.GetElement(m_CommunityIndex);

			if (sValues == null)
			{
				
					log.Error("could not find community index in query string.");
				

				return null;
			}

			int nCommunityIndex = XPConvert.ToInteger(sValues[0]);
			m_asModel.SetCommunityIndex(nCommunityIndex);

			sValues = (String[]) arguments.GetElement(m_CommunityChecked);

			if (sValues != null)
			{
				boolean bCommunityChecked = XPConvert.ToBoolean(sValues[0]);
				m_asModel.SetCommunityChecked(bCommunityChecked);
			}
		}
		else if (nPreviewType == PreviewCommunityBarModel.INVITEHEADER)
		{
			m_asModel.SetCommunityToInvitePage();
		}
		else
		{
			m_asModel.SetCommunityToPreviewPage();
		}
		
		// Check for a Javascript override for the JoinCommunity function
		sValues = (String[]) arguments.GetElement(m_strJoinCommunityJavascriptOverride);
		if ((sValues != null) && (sValues[0] != null) && (sValues[0].length() > 0))
		{
			m_asModel.SetJoinCommunityJavaScriptOverride(sValues[0]);
		}

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewCommunityBarControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel = (PreviewCommunityBarModel) model;
	}
}

