package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.pei.*;
import com.plumtree.portaluiinfrastructure.ptlink.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * File: CommunityInvitationModelHelper.java
 * -----------------------------------------
 * ModelHelper for Community Preview/Invitations
 * This is necessary because we don't need this
 * for all MyPortal Pages, yet we want it on the
 * MyPortal Model.
 *
 * @author NaveenP/DustinA
 */
public class PreviewCommunityBarModel implements IModel, IModelRO, IJoinPreviewCommunityModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityBarModel");

	
	public static final String STR_MVC_CLASS_NAME = "PreviewCommunityBar";

	/** Constant: No Preview Header Bar */
	public static final int NOPREVIEWHEADER = 0;

	/** Constant: Preview Header Bar for Selection Page*/
	public static final int SELECTIONPREVIEWHEADER = 1;

	/** Constant: Invite Header Bar */
	public static final int INVITEHEADER = 2;

	/** Constant: Preview Header Bar for preview only (as in Community Editor)*/
	public static final int PREVIEWHEADER = 3;
	
	/** Join Community Javascript override **/
	public String m_strJavascriptOverride = null;

	/** Activity Space */
	private AActivitySpace m_asOwner = null;

	/** Session */
	private IPTSession m_ptSession;

	/** Community Checked */
	private boolean m_bCommunityChecked;

	/** Is Error Page */
	private boolean m_bErrorPage;

	/** Community ID */
	private int m_nCommunityID;

	/** Community Index for selection page */
	private int m_nCommunityIndex;

	/** Which bar is being used */
	private int m_nPreviewStatus;
	
	/** Community Name */
	private String m_strCommName = "";

	/** Community Desc */
	private String m_strCommDesc = "";
	
	/** Check if community exist */
	private boolean m_bCommunityOpened = true;

	
	public void CleanupTempData()
	{
		
	}
	
	public void CleanupAllData()
	{
		
	}

	/**
	 * Creates a new CommunityInvitationModelHelper object.
	 *
	 * @param ptSession
	 * @param nCommunityID
	 * @param strCommunityName
	 */

	/*public PreviewCommunityModel(IPTSession ptSession, int nCommunityID, String strCommunityName, String nSpaceID)
	{
	    m_ptSession        = ptSession;
	    m_nCommunityFolderID     = nCommunityID;
	    m_strCommunityName = strCommunityName;
	    m_nSpaceID = nSpaceID;

	    m_objCommunityManager = m_ptSession.GetCommunities();
	}*/

	/**
	 * Method addCommunity - adds the user into the community's membership list
	 * as a free member
	 *
	 * @throws HTMLException
	 */
	public void AddCommunity()
	{
		/** adds user as a free member of the community, IsCommunityMember should
		 *    always be called before this method is invoked
		 */
		((IPTCommunityManager)m_ptSession.GetCommunities()).JoinCommunity(m_nCommunityID,
			PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE);
			
		try
		{
			//PEI : CommunityActions
			// MJD: All of the following code will load all of the available CommunityAction
			// PEIs and process through them.
			IApplication application = m_asOwner.GetApplication();
			Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
					
			if (oa != null)
			{
				for (int iCommAction = 0; iCommAction < oa.length; iCommAction++)
				{
					Object o = oa[iCommAction];
	
					if(o != null)
					{
						ICommunityActions iActions = (ICommunityActions) o;
						iActions.OnAfterUserJoinsCommunity(m_asOwner, 
							(IPTSession) m_asOwner.GetUserSession(), new int[]{m_nCommunityID});
					}
				}
			}
			//PEI : CommunityActions : END
		}
		catch (Exception ex)
		{
			
				log.Error(ex, "OnAfterUserJoinsCommunity PEI failed.");
			
		}
	}

	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewCommunityBarModel();
	}

	/**
	 * Get community description
	 *
	 * @return String
	 */
	public String GetCommunityDescription()
	{
		return m_strCommDesc;
	}

	/**
	 * Set to use Preview Header
	 */
	public int GetCommunityID()
	{
		return m_nCommunityID;
	}

	/**
	 * Get to use for preview from selection page
	 */
	public int GetCommunityIndex()
	{
		return m_nCommunityIndex;
	}

	/**
	 * Get community Name
	 *
	 * @return String
	 */
	public String GetCommunityName()
	{
		return m_strCommName;
	}

	/**
	 * Get invited or preview community URL
	 *
	 * @return String
	 */
	public String GetCommunityURL()
	{
	    IPTURL url = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(m_asOwner, GetCommunityID(), GetCommunityName());
		return (url.GetFullURL());
	}

	/**
	 * Get User's default community URL
	 *
	 * @return String
	 */
	public String GetDefaultCommunityURL()
	{
		IPTQueryResult myCommunities = m_ptSession.GetSessionInfo()
			.GetCurrentCommunityMembership();
		int defCommunityID			 = myCommunities.ItemAsInt(0,
				PT_PROPIDS.PT_PROPID_OBJECTID);

		ASURL url = new ASURL(m_asOwner);
		url.SetLinkCreateNewSpace(CommunityPageAS.STR_MVC_CLASS_NAME, m_asOwner);
		url.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
		url.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID,
			defCommunityID);
		url.AddControlArgument(SetCommunityControl.STR_PAGE_ID,
			0);

		return (url.GetURLAsString());
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetDescriptionURL()
	 */
	public String GetDescriptionURL()
	{
		ASURL url = new ASURL(m_asOwner);
		url.SetLinkGetCachedSpace(m_asOwner);
		url.SetDisplayPage(PreviewCommunityDescPopupDP.STR_MVC_CLASS_NAME);

		return (url.GetURLAsString());
	}

	/**
	 * @see com.plumtree.portalpages.browsing.myportal.IMyPortalModelRO#GetJoinURL()
	 */
	public String GetJoinURL()
	{
		ASURL url = new ASURL(m_asOwner);
		url.SetLinkGetCachedSpace(m_asOwner);
		url.SetControl(JoinCommunityControl.STR_MVC_CLASS_NAME);
		url.SetDisplayPage(CommunityInvitationJoinDP.STR_MVC_CLASS_NAME);
		url.AddControlArgument(JoinCommunityControl.m_CommunityID,
			XPConvert.ToString(m_nCommunityID));

		return (url.GetURLAsString());
	}

	///////////////////////////////////////
	// Read only methods from IModelRO
	///////////////////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/////////////////////////
	// Methods from IModel
	/////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner	    = parent;
		m_ptSession     = (IPTSession) m_asOwner.GetUserSession();
		
	}
	
	/**
	 * Get to check if community exist
	 */
	public boolean IsCommunityOpened()
	{
		return m_bCommunityOpened;
	}

	/**
	 * Get to check for selected community
	 */
	public boolean IsCommunityChecked()
	{
		return m_bCommunityChecked;
	}

	/**
	 * Is Community Invite Page
	 *
	 * @return boolean
	 */
	public boolean IsCommunityInvitePage()
	{
		return (m_nPreviewStatus == INVITEHEADER);
	}

	/**
	 *
	 */
	public boolean IsCommunityMember()
	{
		IPTQueryResult membershipList = m_ptSession.GetSessionInfo().GetCurrentCommunityMembership();
		boolean bIsMember			  = false;

		int communityID;

		for (int i = 0; i < membershipList.RowCount(); i++)
		{ // go through user's list of communities joined
			communityID = membershipList.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);

			if (communityID == m_nCommunityID)
			{ // if community specified by commID is in the list
				bIsMember = true; // user is already a member of community

				break;
			}
		}

		return bIsMember;
	}

	/**
	 * Is Community Preview Page
	 *
	 * @return boolean
	 */
	public boolean IsCommunityPreviewPage()
	{
		return (m_nPreviewStatus == PREVIEWHEADER);
	}

	/**
	 * Is Community Selection Preview Page
	 *
	 * @return boolean
	 */
	public boolean IsCommunitySelectionPreviewPage()
	{
		return (m_nPreviewStatus == SELECTIONPREVIEWHEADER);
	}

	/**
	 * Is Error Page
	 */
	public boolean CommunityJoinFailed()
	{
		return m_bErrorPage;
	}

	/**
	 * Set community as selected
	 */
	public void SetCommunityChecked(boolean bCommunityChecked)
	{
		m_bCommunityChecked = bCommunityChecked;
	}

	/**
	 * Set to use Preview Header
	 */
	public void SetCommunityIDAndOpen(int nCommunityID)
	{
		m_nCommunityID = nCommunityID;
		
		// DCA - Open up community to see if exist... Since opening up community, might as well get name and desciption.
		try {
			IPTCommunity objComm = (IPTCommunity) m_ptSession.GetCommunities()
			.Open(m_nCommunityID, false);
			m_strCommName = objComm.GetLocalizedName();
			m_strCommDesc = objComm.GetLocalizedDescription();
		} catch (Exception e) {
			m_bCommunityOpened = false;	
		}
	}

	/**
	 * Set to use selection page
	 */
	public void SetCommunityIndex(int nCommunityIndex)
	{
		m_nCommunityIndex = nCommunityIndex;
	}

	/**
	 * Set to use Invite Header
	 */
	public void SetCommunityToInvitePage()
	{
		m_nPreviewStatus = INVITEHEADER;
	}

	/**
	 * Set to use Preview Header
	 */
	public void SetCommunityToPreviewPage()
	{
		m_nPreviewStatus = PREVIEWHEADER;
	}

	/**
	 * Set to use Selection Preview Header
	 */
	public void SetCommunityToSelectionPreviewPage()
	{
		m_nPreviewStatus = SELECTIONPREVIEWHEADER;
	}

	/**
	 * Set to use Preview Header
	 */
	public void SetErrorPage(boolean bErrorPage)
	{
		m_bErrorPage = bErrorPage;
	}

	/**
	 * Set to use Preview Header
	 */
	public boolean UserHasReadAccess()
	{
		return m_ptSession.GetCommunities().IsObjectAccessible(m_nCommunityID,
				m_ptSession.GetSessionInfo().GetCurrentUserID(),
				PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
	}

	/**
	 * Set to use Preview Header
	 */
	public boolean UserHasSelectAccess()
	{
		return m_ptSession.GetCommunities().IsObjectAccessible(m_nCommunityID,
				m_ptSession.GetSessionInfo().GetCurrentUserID(),
				PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
	}
	
	/**
	 * Get Join Community Javascript override.
	 * 
	 * This javascript should be the name of the javascript function to be
	 * used in the onclick attribute of the join community button.  The function should
	 * take 2 arguments: the community ID, and a reference to the popup window.
	 * (i.e. If the name is "joinCommunity", then the function will look like
	 * this: "joinCommunity(communityID, self)").  This function name can also
	 * include an optional window reference (i.e. "opener.joinCommunity").
	 *
	 * @return String the name of the javascript function to use when joining the community.
	 * This string will be null if there is no override.
	 */
	public String GetJoinCommunityJavaScriptOverride()
	{
		return m_strJavascriptOverride;
	}

	/**
	 * Set the Join Community Javascript override.
	 * 
	 * This javascript should be the name of the javascript function to be
	 * used in the onclick attribute of the join community button.  The function should
	 * take 2 arguments: the community ID, and a reference to the popup window.
	 * (i.e. If the name is "joinCommunity", then the function will look like
	 * this: "joinCommunity(communityID, self)").  This function name can also
	 * include an optional window reference (i.e. "opener.joinCommunity").
	 *
	 * Null means to use the default javascript.
	 */
	public void SetJoinCommunityJavaScriptOverride(String _strOverride)
	{
		m_strJavascriptOverride = _strOverride;
	}
}

