package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * File: CommunityInvitationModelHelper.java
 * -----------------------------------------
 * ModelHelper for Community Preview/Invitations
 * This is necessary because we don't need this
 * for all MyPortal Pages, yet we want it on the
 * MyPortal Model.
 *
 * @author NaveenP/DustinA
 */
public class PreviewCommunityModel implements IModel, IModelRO
{
	
	public static final String STR_MVC_CLASS_NAME = "PreviewCommunity";

	/** Constant: No Preview Header Bar */
	public static final int NOPREVIEWHEADER = 0;

	/** Constant: Preview Header Bar for Selection Page*/
	public static final int SELECTIONPREVIEWHEADER = 1;

	/** Constant: Invite Header Bar */
	public static final int INVITEHEADER = 2;

	/** Constant: Preview Header Bar for preview only (as in Community Editor)*/
	public static final int PREVIEWHEADER = 3;

	/** Which bar is being used */
	public int m_nPreviewStatus;
	
	/** Join Community Javascript override **/
	public String m_strJavascriptOverride = null;

	/** Activity Space */
	private AActivitySpace m_ActivitySpace = null;

	/** Session */
	private IPTSession m_ptSession;

	/** Community Checked */
	private boolean m_bCommunityChecked;

	/** Community ID */
	private int m_nCommunityID;

	/** Community Index for selection page */
	private int m_nCommunityIndex;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewCommunityModel();
	}

	/**
	 * Set to use Preview Header
	 */
	public int GetCommunityID()
	{
		return m_nCommunityID;
	}

	/**
	 * Get to use for preview from selection page
	 */
	public int GetCommunityIndex()
	{
		return m_nCommunityIndex;
	}

	///////////////////////////////////////
	// Read only methods from IModelRO
	///////////////////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.IModelRO#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/////////////////////////
	// Methods from IModel
	/////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		m_ActivitySpace     = parent;
		m_ptSession		    = (IPTSession) m_ActivitySpace.GetUserSession();
	}

	/**
	 * Get to check for selected community
	 */
	public boolean IsCommunityChecked()
	{
		return m_bCommunityChecked;
	}

	/**
	 * Set community as selected
	 */
	public void SetCommunityChecked(boolean bCommunityChecked)
	{
		m_bCommunityChecked = bCommunityChecked;
	}

	/**
	 * Set to use Preview Header
	 */
	public void SetCommunityID(int nCommunityID)
	{
		m_nCommunityID = nCommunityID;
	}

	/**
	 * Set to use selection page
	 */
	public void SetCommunityIndex(int nCommunityIndex)
	{
		m_nCommunityIndex = nCommunityIndex;
	}

	/**
	 * Set to use Invite Header
	 */
	public void SetCommunityToInvitePage()
	{
		m_nPreviewStatus = INVITEHEADER;
	}

	/**
	 * Set to use Preview Header
	 */
	public void SetCommunityToPreviewPage()
	{
		m_nPreviewStatus = PREVIEWHEADER;
	}

	/**
	 * Set to use Selection Preview Header
	 */
	public void SetCommunityToSelectionPreviewPage()
	{
		m_nPreviewStatus = SELECTIONPREVIEWHEADER;
	}
	
	public boolean UserHasCommunityAccess()
	{
		IPTSubPortalInfo subPortalInfo = m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
		int nBool = subPortalInfo.GetAccessType() & PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_COMMUNITIES_ACCESS;

		return nBool != 0;
	}
	
	/**
	 * Get Join Community Javascript override.
	 * 
	 * This javascript should be the name of the javascript function to be
	 * used in the onclick attribute of the join community button.  The function should
	 * take 2 arguments: the community ID, and a reference to the popup window.
	 * (i.e. If the name is "joinCommunity", then the function will look like
	 * this: "joinCommunity(communityID, self)").  This function name can also
	 * include an optional window reference (i.e. "opener.joinCommunity").
	 *
	 * @return String the name of the javascript function to use when joining the community.
	 * This string will be null if there is no override.
	 */
	public String GetJoinCommunityJavaScriptOverride()
	{
		return m_strJavascriptOverride;
	}

	/**
	 * Set the Join Community Javascript override.
	 * 
	 * This javascript should be the name of the javascript function to be
	 * used in the onclick attribute of the join community button.  The function should
	 * take 2 arguments: the community ID, and a reference to the popup window.
	 * (i.e. If the name is "joinCommunity", then the function will look like
	 * this: "joinCommunity(communityID, self)").  This function name can also
	 * include an optional window reference (i.e. "opener.joinCommunity").
	 *
	 * Null means to use the default javascript.
	 */
	public void SetJoinCommunityJavaScriptOverride(String _strOverride)
	{
		m_strJavascriptOverride = _strOverride;
	}
}

