package com.plumtree.portalpages.browsing.myportal.communities;

import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.objectselection.communities.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The community preview and invitation files span the
 * CommunityPageAS as well as the CommunitySelectionEditorAS.
 *
 * Includes the following MVC and DP files:
 *         Models:        CommunityInvitationModelHelper
 *                     CommunityMyPortalModelHelper
 *                     CommunitySelectionModelHelper (in objectselection/communities)
 *
 *         Views:        CommunityInvitationJoinView
 *                     PreviewCommunityDescPopupView
 *                     PreviewCommunityView
 *                     CommunityInvitationPopupView (in objectselection/communities)
 *                     CommunitySelectionViewHelper (in objectselection/communities)
 *
 *         DPs:        CommunityInvitationJoinDP
 *                     PreviewCommunityDescPopupDP
 *                     CommunityInvitationPopupDP (in objectselection/communities)
 *
 *         Controls:    JoinCommunityControl
 *                     PreviewCommunityControl
 *
 * These files make up the functionality for previewing a community
 * in three ways:
 *         1. Preview Community in Selection Page and adding it
 *         2. Receiving a Community Invitation and adding it
 *         3. Previewing the Community in the Community Editor
 *
 * These files also include the popup for the Community Invitation
 * Text on a Selection Page (the "Send to Others" link).  As well
 * as the description popup when previewing a community.
 *
 * @author NaveenP/DustinA
 */
/**
 * File: PreviewCommunityView.java
 * -------------------------------
 * Section that prints the preview bar for the community.
 * The bar is different based on the preview type.
 *
 *
 *
 *
 * @author NaveenP/DustinA
 */
public class PreviewCommunityView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.communities.PreviewCommunityView");

	
	public static final String STR_MVC_CLASS_NAME = "PreviewCommunity";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private PreviewCommunityBarModel m_asModel;

	/**
	 * Method addRowCell - adds the cell into the row and adds the row into the
	 * table
	 *
	 * @param table
	 * @param row
	 * @param cell
	 *
	 * @throws HTMLException
	 */
	public static void addRowCell(HTMLTable table, HTMLTableRow row,
		HTMLTableCell cell)

	{
		row.AddInnerHTMLElement(cell);
		table.AddInnerHTMLElement(row);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewCommunityView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement bar = null;

		try
		{
			bar = PreviewBar();
		}
		catch (HTMLException e)
		{
			log.Error(e, e.getMessage());
		}

		return bar;
	}

	/**
	 * Display JavaScript - this includes the static source file
	 *
	 * return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (PreviewCommunityBarModel) model;
		m_asOwner     = parent;
	}

	/**
	 * Method JoinCommunityInPreviewPageScript - prints javascript for joining the community
	 * while in selection page
	 *
	 * @return HTMLScript
	 *
	 * @throws HTMLException
	 */
	public HTMLScript JoinCommunityInPreviewPageScript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		
		if (m_asModel.UserHasSelectAccess())
		{
			if (!m_asModel.IsCommunityOpened()) 
			{
				script.AddInnerHTMLString("alert('" +
					m_asOwner.GetString(1563, "ptmsgs_portalbrowsingmsgs") + 
					"')");
			} 
			else {
				// We only need to display this javascript for the default case.
				// If we are overriding the javascript method, we don't need this.
				if (m_asModel.GetJoinCommunityJavaScriptOverride() == null)
				{
					script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) +
							"updateParent.js");
				}
			}
		}
		else
		{
			if (m_asModel.UserHasReadAccess())
			{
				script.AddInnerHTMLString("alert('" +
					m_asOwner.GetString(660, "ptmsgs_portalbrowsingmsgs") +
					"')");
			}			
			else
			{
			
				script.AddInnerHTMLString("alert('" +
					m_asOwner.GetString(661, "ptmsgs_portalbrowsingmsgs") +
					"')");
			}
		}

		return script;
	}

	/**
	 * Method previewBar - displays bar (with buttons to join, or cancel) above
	 * community preview
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	private HTMLElement PreviewBar()
	{
		//mainTable components
		HTMLTable mainTable     = new HTMLTable();
		HTMLTableRow mainRow    = new HTMLTableRow();
		HTMLTableCell mainCell2 = new HTMLTableCell();
		HTMLTableCell mainCell3 = new HTMLTableCell();

		//join and close buttons
		HTMLInput description = new HTMLInput(1, "in_bu_description",
				m_asOwner.GetString(654, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(654, "ptmsgs_portalbrowsingmsgs"));

		String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
		String strDes		  = strJSUtilVersionPrefix+"PTWindowUtil.openWindow('" +
			m_asModel.GetDescriptionURL() + "','PUWEBDIALOG',200,450,false)";

		description.SetValue(m_asOwner.GetString(655,
				"ptmsgs_portalbrowsingmsgs"));
		description.SetOnClick(strDes);
		description.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);

		HTMLInput join    = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_join",
				m_asOwner.GetString(652, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(653, "ptmsgs_portalbrowsingmsgs"));
		String joinString;

		if (m_asModel.IsCommunitySelectionPreviewPage())
		{
			if (m_asModel.GetJoinCommunityJavaScriptOverride() != null)
			{
				String jsOverride = TaskAPIUIHTML.HTMLEncode( m_asModel.GetJoinCommunityJavaScriptOverride() ); 
				joinString = jsOverride + "(" + m_asModel.GetCommunityID() + ", parent)";
			} else
			{
				joinString = "updateParent(" +	// mj: removed 'JavaScript:' from function name
						m_asModel.GetCommunityIndex() + ",'" + EditorDP.HTMLFORM_NAME +
						"." + CommunitySelectionViewHelper.HTMLINPUT_SELECTION_OBJECT +
						"','parent')";
			}
		}
		else
		{
			joinString = "parent.location='" + m_asModel.GetJoinURL() + "'";
		}

		join.SetValue(m_asOwner.GetString(653, "ptmsgs_portalbrowsingmsgs"));
		join.SetOnClick(joinString);
		join.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);

		HTMLInput closeOrDefault;

		if (!m_asModel.IsCommunityInvitePage())
		{
			closeOrDefault = new HTMLInput(1, "in_bu_close",
					m_asOwner.GetString(656, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(656, "ptmsgs_portalbrowsingmsgs"));

			String cancelString = "parent.close()";

			closeOrDefault.SetValue(m_asOwner.GetString(657,
					"ptmsgs_portalbrowsingmsgs"));
			closeOrDefault.SetOnClick(cancelString);
			closeOrDefault.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
		}
		else if (m_asModel.IsCommunityMember())
		{
		    closeOrDefault = new HTMLInput(1, "in_bu_community",
					"in_bu_community",
					XPHttpUtility.HtmlEncode(m_asOwner.GetString(1899, "ptmsgs_portalbrowsingmsgs")) );

			String defaultString = "parent.location='" +
				m_asModel.GetCommunityURL() + "'";

			closeOrDefault.SetValue(m_asOwner.GetString(1899,
					"ptmsgs_portalbrowsingmsgs"));
			closeOrDefault.SetOnClick(defaultString);
			closeOrDefault.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
		}
		else
		{
			ASURL asurl = new ASURL(m_asOwner);
			asurl.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);

			closeOrDefault = new HTMLInput(1, "in_bu_default",
					"in_bu_default",
					XPHttpUtility.HtmlEncode(m_asOwner.GetString(658, "ptmsgs_portalbrowsingmsgs")) );

			String defaultString = "parent.location='" +
				asurl.GetURLAsString() + "'";

			closeOrDefault.SetValue(m_asOwner.GetString(659,
					"ptmsgs_portalbrowsingmsgs"));
			closeOrDefault.SetOnClick(defaultString);
			closeOrDefault.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);
		}

		//Specifying the mainTable attributes
		//class="boxBrowserGray" width="100%" height="40" border="0" cellpadding="4" cellspacing="0" bgcolor="#D6D3CE"
		mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
		mainTable.SetBorder("0");
		mainTable.SetCellPadding("4");
		mainTable.SetCellSpacing("0");
		mainTable.SetWidth("100%");
		mainTable.SetHeight("40");
		mainTable.SetBGColor("#D6D3CE");

		//Setting up the Main Table
		mainCell3.SetAlign("center");
		mainCell3.SetStyleClass(PTStyleClass.BAN_TEXT);
		mainCell3.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		mainCell2.SetAlign("right");
		mainCell2.SetStyleClass(PTStyleClass.BAN_TEXT);

		if (m_asModel.UserHasSelectAccess() && m_asModel.IsCommunityOpened() &&
				(m_asModel.IsCommunitySelectionPreviewPage() ||
				m_asModel.IsCommunityInvitePage()))
		{
			if (m_asModel.IsCommunitySelectionPreviewPage())
			{
				if (!m_asModel.IsCommunityChecked())
				{
					mainCell2.AddInnerHTMLElement(join);
					mainCell3.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				}
				else
				{
					mainCell2.AddInnerHTMLString(m_asOwner.GetString(662,
							"ptmsgs_portalbrowsingmsgs"));
				}
			}
			else if (!m_asModel.IsCommunityMember())
			{
				mainCell2.AddInnerHTMLElement(join);
				mainCell3.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			}
			else
			{
				mainCell2.AddInnerHTMLString(m_asOwner.GetString(662,
						"ptmsgs_portalbrowsingmsgs"));
			}

			mainCell3.AddInnerHTMLElement(description);
			mainCell3.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}

		mainRow.AddInnerHTMLElement(mainCell2);
		mainCell3.AddInnerHTMLElement(closeOrDefault);

		PreviewCommunityView.addRowCell(mainTable, mainRow, mainCell3);

		return mainTable;
	}
}

