package com.plumtree.portalpages.browsing.myportal.editpage;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: EditMyPagePortletLayoutDP_D.java
 * ------------------------
 *
 * @author NaveenP
 */
public class EditMyPagePortletLayoutDP_D extends EditorDP
{
	
	public static final String STR_MVC_CLASS_NAME = "EditMyPagePortletLayout";

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormPageType()
	 */
	public FormPageTypes GetFormPageType()
	{
		return FormPageTypes.NORMAL_PAGE;
	}

	/**
	  * This is a helper method that all classes that inherit from AFormDP and
	  * want to have the Done and Cancel buttons displayed in the header for
	  * them need to implement.  The method should return the title add whatever
	  * HTML the child class wants to display to the body argument.  The parent
	  * class will then add that HTML to the HTMLPage after filling in the
	  * banner and navigation.
	  *Override this method to set the form title
	  *
	  * @return String the title for the form header (if used)
	  */
	public String GetFormTitle()
	{
		EditMyPagePortletLayoutModel_D myModel = (EditMyPagePortletLayoutModel_D) m_asOwner.GetModel(EditMyPagePortletLayoutModel_D.STR_MVC_CLASS_NAME);
		
		return XPResourceManager.FormatMessage(
					m_asOwner.GetString(1261, "ptmsgs_portalbrowsingmsgs"),
					XPHttpUtility.HtmlEncode(myModel.GetPageName()));
	}

	public String GetLeftNavString()
	{
		EditMyPagePortletLayoutModel_D myModel = (EditMyPagePortletLayoutModel_D) m_asOwner.GetModel(EditMyPagePortletLayoutModel_D.STR_MVC_CLASS_NAME);
		
		return XPResourceManager.FormatMessage(
					m_asOwner.GetString(1261, "ptmsgs_portalbrowsingmsgs"),
					XPHttpUtility.HtmlEncode(myModel.GetPageName()));
	}
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * helper display method for PlumtreeDP
	 *
	 * Fill in the body argument with HTML to display in the page.
	 */
	public HTMLElement PageDisplay()
		throws HTMLException
	{
		HTMLTable table = new HTMLTable();
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		table.SetBorder(CommonHTMLStrings.ZERO);
		table.SetCellSpacing("10");
		table.SetCellPadding(CommonHTMLStrings.ZERO);

		HTMLTableRow row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);
		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);	
		
		
		HTMLElementCollection result = new HTMLElementCollection();

		result.AddInnerHTMLElement(m_asOwner.GetView(
						EditMyPagePortletLayoutAS_D.strPageNamePlugInKey).Display());

		result.AddInnerHTMLElement(m_asOwner.GetView(
				EditMyPagePortletLayoutView_D.STR_MVC_CLASS_NAME).Display());

		cell.AddInnerHTMLElement(result);

		return table;
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayJavaScriptFromChild()
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
		throws HTMLException
	{
		return new HTMLScriptCollection();
	}


	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLBeforeForm()
	 */
	public HTMLElementCollection DisplayHTMLBeforeForm()
	{
		HTMLElementCollection beforeform = super.DisplayHTMLBeforeForm();
		
		if (beforeform == null)
		{
			beforeform = new HTMLElementCollection();
		}
		
		// Construct table to contain the page.
		HTMLTable myTable = new HTMLTable();
		beforeform.AddInnerHTMLElement(myTable);
		myTable.SetBorder(CommonHTMLStrings.ZERO);
		myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myTable.SetCellPadding(CommonHTMLStrings.ZERO);
		myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
		HTMLTableRow myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		HTMLTableCell myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetAutoFit(true);
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("15");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);


		// Instructional text
		String strInstructions = null;
		if (m_asOwner.GetAccessStyle() == AccessStyles.LOW_BANDWIDTH)
		{
			strInstructions = m_asOwner.GetString(1260, "ptmsgs_portalbrowsingmsgs") + CommonHTMLStrings.SPACE + m_asOwner.GetString(1262, "ptmsgs_portalbrowsingmsgs");
		}
		else
		{
			strInstructions = m_asOwner.GetString(1260, "ptmsgs_portalbrowsingmsgs");
		} 
		myCell.AddInnerHTMLElement(HTMLConstructHelpers.GetSubHeader(strInstructions, this.m_asOwner));

		myCell = new HTMLTableCell();
		myRow.AddInnerHTMLElement(myCell);
		myCell.SetWidth("15");
		myCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		return beforeform;
	}

}

