package com.plumtree.portalpages.browsing.myportal.editpage;


// Framework Imports
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class is used to register all the Model, Views, Display Pages,
 * and Controls created for the Edit Page Editor.
 * This class can also be used to get any of those objects back with
 * the class name.
 *
 * @author MichaelD
 */
public class EditMyPortalPageAS extends PTEditorAS
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "EditMyPortalPage";

	/** Plug in Key: PageName */
	public static final String strPageNamePlugInKey = "PageName";
	
	/** Layout table top */
	public static final int LAYOUTTABLE_TOP = 226;

	/** Layout table left */
	public static final int LAYOUTTABLE_LEFT = 13;


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String, java.lang.String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		boolean bAccess = super.CheckBasicAccess(strPage, strControl, bSameSpace);

		// MJD- Otherwise make sure this is the refresh control or the default page creation control. 
		// The access will be checked by those controls.
		if ((null != strControl) && 
				((strControl.equals(RefreshEditPageControl.STR_MVC_CLASS_NAME))) || 
				((strControl.equals(EditPageCreateDefaultControl.STR_MVC_CLASS_NAME))))
		{
			bAccess = true;
		}

		return bAccess;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EditMyPortalPageAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		if ( ((EditMyPortalPageModel) GetModel(m_strModelName)).IsCreateMyPage() ) {
			return (GetString(1256, "ptmsgs_portalbrowsingmsgs"));
		}
		return (GetString(664, "ptmsgs_portalbrowsingmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (EditPageRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 *
	 */
	public void Init()
	{
		m_strModelName = EditMyPortalPageModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(EditMyPortalPageModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		AFormDP myPage = new EditMyPortalPageDP();
		myPage.AddToValidationFunction(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
		myPage.AddToValidationFunction(PageNameView.JS_VALIDATE_PAGENAME_FUNC);
		RegisterPage(myPage);

		// Register Views
		RegisterView(EditCommunityPageView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(EditPageRepostControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(RefreshEditPageControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(EditPageCreateDefaultControl.STR_MVC_CLASS_NAME, myModel);

		// Set default page
		SetCurrentPage(EditMyPortalPageDP.STR_MVC_CLASS_NAME);

		// Register common sections
		//      Register each Section/Model for your plug-in sections
		RegisterModel(PageNamePlugInModel.STR_MVC_CLASS_NAME);
		IModel myPageNameModel = GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME);
		RegisterView(PageNameView.STR_MVC_CLASS_NAME, myPageNameModel);

		RegisterModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
		IModel myPageLayoutModel = GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME);
		RegisterView(PageLayoutView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterView(PageLayoutHeaderView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterView(PageLayoutAlternateView.STR_MVC_CLASS_NAME, myPageLayoutModel);
		RegisterControl(PageLayoutControl.STR_MVC_CLASS_NAME, myPageLayoutModel);
	}
	
	/**
	* Distinguish between community and non-community edit page by checking the
	* name of the parent form.  Community edit page is launched from the
	* community editor, so it has a parent, while my page edit page does not
	* have a parent.  bjf -- also, fixed a bug with this, it was comparing the
	* parent form name to the empty string, but actually the parent form name
	* appears to be null.  Now checking for both empty and null.
	*
	* @return boolean True if this is a community page.
	*/
	public boolean IsCommunityEditPage()
	{
		String strParentFormName = ((IEditMyPortalPageModelRO) GetModel(
							EditMyPortalPageModel.STR_MVC_CLASS_NAME)).GetParentFormName();
		boolean bIsCommunityPage = !("").equals(strParentFormName) && null != strParentFormName;
		return bIsCommunityPage;	
	}	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page)
	{
		super.SetCurrentPage(page);

//		String sPageName = page.GetName();

		if (IsCommunityEditPage())
		{
			SetHelpTopic( "PT_Community_EditPage" );
		}
		else
		{
			if( ((EditMyPortalPageModel) GetModel(EditMyPortalPageModel.STR_MVC_CLASS_NAME)).IsCreateMyPage() )
			{
				SetHelpTopic( "PT_CreatePage" );			
			}
			else
			{
				SetHelpTopic( "PT_MyPage_EditPage" );			
			}
		}				
	}

}

