package com.plumtree.portalpages.browsing.myportal.editpage;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * This class creates a single default page with a one-click operation
 *
 * @author MattC
 */
public class EditPageCreateDefaultControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.editpage.EditPageCreateDefaultControl");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "EditPageCreateDefault";

	/** Associated Activity Space */
	public AActivitySpace m_asOwner;

	/** Associated Model */
	protected EditMyPortalPageModel m_model;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EditPageCreateDefaultControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	public void Init(IModel model, AActivitySpace space)
	{
		m_model = (EditMyPortalPageModel)model;
		m_asOwner = space;
	}
	
	/**
	 * Simply creates a new page and redirects the browser back to that page
	 *
	 * @param arguments contains HTTP arguments from the post
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		m_model.SetUserHasAccessToEditor(m_model.CheckEditorAccessAndStart(arguments));
		((PageLayoutPlugInModel) m_asOwner.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).SaveSection(CheckRequiredArgs(arguments));
		m_model.Finish();
		log.Info("EditPageDefaultControl: created new MyPage");
		return m_model.GetRedirectAfterFinish();
	}
	
	/**
	 * Takes an argument hashtable and returns a new table 
	 * that includes required (but missing) arguments
	 *
	 * @param arguments contains HTTP arguments from the post
	 */
	private XPHashtable CheckRequiredArgs(XPHashtable arguments)
	{
		// initialize a new hashtable for the arguments in case we need to add any
		XPHashtable tempTable = new XPHashtable(arguments);
		String[] data;

		// Page Layout Type
		data = (String[]) arguments.GetElement(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE);
		if ((null == data) || (0 == data.length))
		{
			// grab the type from the default page already created in the model
			int pageType = m_model.getPTPage().GetPageType();
			tempTable.PutElement(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE, new String[] {XPConvert.ToString(pageType)});
		}

		// Portlet To Delete
		data = (String[]) arguments.GetElement(PageLayoutHeaderView.HTMLINPUT_DELETE_GADGETID);
		if ((null == data) || (0 == data.length))
			tempTable.PutElement(PageLayoutHeaderView.HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE, new String[] {""});
		
		// Three gadget order columns
		for (int i=0; i<3; i++)
		{
			data = (String[]) arguments.GetElement(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER_PREFIX + XPConvert.ToString(i));
			if ((null == data) || (0 == data.length))
				tempTable.PutElement(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER_PREFIX + XPConvert.ToString(i), new String[] {""});
		}
		
		return tempTable;
	}
}

