package com.plumtree.portalpages.browsing.myportal.editpage;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class contains the additional repost actions.
 * The ones specific to the Edit Page Editor (other than
 * "change page", "finish" and "cancel" actions).
 *
 * @author MichaelD
 */
public class EditPageRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.myportal.editpage.EditPageRepostControl");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "EditPageRepost";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EditPageRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param int
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		// You need to call the PerformRepostAction on the page layout control
		((PageLayoutControl) m_asOwner.GetControl(PageLayoutControl.STR_MVC_CLASS_NAME)).PerformRepostAction(_nAction,
			m_htFormData);
	}

	/**
	 * This method is called when we finish a sub Editor.
	 * It takes care of closing the sub Editor pop-up winodws
	 * and repost the main Editor window.
	 *
	 */
	protected void SetRedirectToCloseSubEditor()
	{
		((EditorModel) m_model).SetDeleteOnCancel(false);

		String strOpenerFunction = ((IEditMyPortalPageModelRO)m_model).GetParentFormSubmitFunction();

		int nSize = 20;

		if ((strOpenerFunction != null) &&
				(!"".equals(strOpenerFunction)))
		{
			nSize += 100;
		}

		XPStringBuilder sb = new XPStringBuilder(nSize);

		// Add method to call on opening form, if it exists
		if ((strOpenerFunction != null) &&
				(!"".equals(strOpenerFunction)))
		{
			sb.Append("  window.opener.").Append(JSHelper.escapeJS(strOpenerFunction))
			.Append("();\n");
		}

		// We are in a frame, so we need to call parent, not window
		sb.Append("window.close();\n");

		HTMLScript myScript = new HTMLScript("text/javaScript");
		try
		{
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			log.Error(he, "Error generating JS for ClosePopUpDP.");
		}

		ClosePopUpDP myClosePopUp = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
		myClosePopUp.SetScript(myScript);

		// Close the Tree pop-up
		Redirect myRedirect = new Redirect();
		myRedirect.SetLinkGetCachedSpace(m_asOwner);
		myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

		SetRedirect(myRedirect);
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorRepostControl#PerformCancelAction()
	 */
	protected void PerformCancelAction()
	{
		// TODO Auto-generated method stub
		super.PerformCancelAction();

		if (!m_asOwner.IsSubSpace() && null == m_rRedirect)
		{
			Redirect result = new Redirect();

			// JF- If the parent space is already in the cache, we redirect to it.
			if (null != m_asOwner.GetParentSpace())
			{
				result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
			}
			// JF- If not, we redirect to a new one.
			else if ((null != m_asOwner.GetParentSpaceName()) &&
				(!"".equals(m_asOwner.GetParentSpaceName())))
			{	
				result.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
			}
			// If we don't have a parent, just redirect to the mypage
			else
			{
				result.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
			}

			SetRedirect(result);
		}
	}
}