package com.plumtree.portalpages.browsing.objectselection;

/**
 * This interface contains the methods on the Object Selection
 * Model that change the state of the model.  Read Only methods
 * are on the IObjectSelectionModelRO.
 */
public interface IObjectSelectionModel
{
	/**
	 * This method is used by the portlet flyout control to switch from browse mode
	 * to search mode.
	 * 
	 * @param _bDisplaySearch whether or not we are in search mode.
	 */
	public void SetDisplaySearch(boolean _bDisplaySearch);

	/**
	 * Sets the index of the object view the page is currently displaying.
	 * Called from the class displaying the different object types.
	 *
	 * @param nObjectViewIndex
	 */
	public void SetObjectViewIndex(int nObjectViewIndex);

	/**
	 * This method refreshes the selected objects by requerying for them
	 * on the page.  This should not be necessary in normal operation and
	 * should only be used if the portlets on the page have changed outside
	 * of the editor model (i.e. in the portlet flyout).
	 */
	public void RefreshSelectedObjects();

	/**
	 * Set the first displayable item for pagination in the object selection
	 * model if pagination is used.
	 * 
	 * @param _nFirstItem
	 */
	public void SetFirstDisplayableItem(int _nFirstItem);

	/**
	 * Set the number of items per page for pagination in the object selection
	 * model if pagination is used.
	 * 
	 * @param _nItemsPerPage
	 */
	public void SetItemsPerPage(int _nItemsPerPage);
}