package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * 
 *
 * @author michaeld
 */
public interface IObjectSelectionModelHelper
{
	/**
	 * Add a unique input to the form input hash table.
	 *
	 * @param htFormData
	 * @param IASQueryResult asqr
	 * @param itn nObjectViewIndex
	 */
	public void AddFormInputsForEachObject(XPHashtable htFormData,
		IASQueryResult asqr, int nObjectViewIndex);

	/**
	 * Get object IDs of object not to show in the object selection.
	 *
	 * @param ObjectSelectionModel model
	 * @param int nObjectViewIndex
	 * @return XPSortedDictionary
	 */
	public XPSortedDictionary GetDoNotShowObjectIDs(
		ObjectSelectionModel model, int nObjectViewIndex);

	/**
	 * Returns the strings for the headers.
	 *
	 * @param int nObjectViewIndex
	 * @return String[]
	 */
	public String[] GetHeaders(int nObjectViewIndex);

	/**
	 * Returns the number of object views this model must display.
	 *
	 * @return int
	 */
	public int GetNumObjectViews();

	/**
	 * Get the banner title for the object banner.
	 *
	 * @param String strCurrentFolderName
	 * @param int nObjectViewIndex
	 * @return String
	 */
	public String GetObjectBannerTitle(String strCurrentFolderName,
		int nObjectViewIndex);

	/**
	 * Gets the object input name
	 *
	 * @param int nObjectViewIndex
	 * @return String strObjectInputName
	 */
	public String GetObjectInputName(int nObjectViewIndex);

	/**
	 * Gets the an object manager.
	 *
	 * @param IPTSession ptSession
	 * @param int nObjectViewIndex
	 * @return IPTObjectManager
	 */
	public IPTObjectManager GetObjectMan(IPTSession ptSession,
		int nObjectViewIndex);

	/**
	 * Gets the object type.
	 *
	 * @param int nObjectViewIndex
	 * @return int nObjectType
	 */
	public int GetObjectType(int nObjectViewIndex);

	/**
	 * Gets a queryresult of the objects to display.  Used instead of
	 * IPTObjectManager GetObjects when  displaying non managed objects.
	 *
	 * @param IPTSession ptSession
	 * @param IPTAdminFolder ptFolder
	 * @return ASQueryResult
	 */
	public IASQueryResult GetObjects(IPTSession ptSession,
		IPTAdminFolder ptFolder);

	/**
	 * Gets the property IDs to query for.
	 *
	 * @param int nObjectViewIndex
	 * @return int nPropIDs
	 */
	public int GetPropIDsToQuery(int nObjectViewIndex);

	/**
	 * Get query filter to use when query for selectable objects. The use of the first column
	 * of thise array, [0][0] - [2][0], is reserved for use by ObjectSelectionModel. Start adding filters to the
	 * array at [0][1] - [2][1].
	 *
	 * @param ObjectSelectionModel model
	 * @param int nObjectViewIndex
	 * @return Object[][] oQueryFilter
	 */
	public Object[][] GetQueryFilter(ObjectSelectionModel model,
		int nObjectViewIndex);

	/**
	 * Get the redirect for after the editor has finished.
	 *
	 * @param ObjectSelectionModel model
	 * @param int nObjectViewIndex
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish(ObjectSelectionModel model);

	/**
	 * Get the title for the search header.
	 * 
	 * @return String
	 */
	public String GetSearchHeaderTitle();

	/**
	 * Gets the information to store in the selected dictionary.
	 *
	 * @param nIndex
	 * @param ASQueryResult
	 * @return Object[]
	 */
	public Object[] GetSelectedInfo(int nIndex, IASQueryResult asqr);

	/**
	 * Get the selected objects
	 *
	 * @param ObjectSelectionModel model
	 * @return Object[][]
	 */
	public Object[][] GetSelectedObjects(ObjectSelectionModel model);

	/**
	 * Returns whether the model should save the page on repost.
	 * Currently only community pages returns false.
	 *
	 * @return boolean
	 */
	public boolean GetShouldSavePage();

	/**
	 * Returns whether the object selection page should start in search mode.
	 * 
	 * @return boolean
	 */
	public boolean GetStartInSearch();

	/**
	 * Initialize the form input hash table.
	 *
	 * @param htFormData
	 */
	public void InitializeFormInputs(XPHashtable htFormData);

	/**
	 * Set the selected objects. This may involve in sending them to a parent
	 * editor to be set, or actually setting them here.
	 *
	 * @param ObjectSelectionModel model
	 * @param xpsdOldSelectedObjects xpsdOldSelectedObjects
	 * @param xpsdNewSelectedObjects xpsdNewSelectedObjects
	 */
	public void SetSelectedObjects(ObjectSelectionModel model,
		XPSortedDictionary xpsdOldSelectedObjects,
		XPSortedDictionary xpsdNewSelectedObjects);
		
	/**
	 * @param nSearch508StringIndex is the index of the message files index
	 * @return the index of the string in the message file from the index passed in
	 */
	public int Get508SearchStringMsgIndex(int nSearch508StringIndex);
}

