package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.search.*;

/**
 * @author michaeld
 */
public interface IObjectSelectionModelRO extends IObjectModelRO
{
	/**
	 * This method returns a 2d query result with folder level, id, and name.
	 * 
	 * @return IASQueryResult
	 */
	public IASQueryResult GetBreadCrumbPath();

	/**
	 * Returns true if we need to display the search results view.
	 *
	 * @return boolean
	 */
	public boolean GetDisplaySearch();

	/**
	 * Returns the value of the given input.
	 *
	 * @param String strInput
	 * @return String strValue
	 */
	public String GetInputValue(String strInput);

	/**
	    * Get wether we can select multiple or single.
	    *
	    * @return boolean
	    */
	public boolean GetMultipleSelect();

	/**
	 * Get the name of the parent window's form.
	 *
	 * @return String
	 */
	public String GetParentFormName();

	/**
	 * Get the name of the form element for selected items.
	 *
	 * @return String
	 */
	public String GetParentFormSelectedItems();

	/**
	 * Get the string that is the parent form space ID.
	 *
	 * @return String
	 */
	public String GetParentFormSpaceID();

	/**
	 * Get the string that is the parent form submit function.
	 *
	 * @return String
	 */
	public String GetParentFormSubmitFunction();

	/**
	 * Returns true if a search has been initialized.
	 *
	 * @return boolean
	 */
	public boolean GetSearchStarted();
	
	/**
	 * Returns the Search Setting Collection.
	 * 
	 * @return SearchSettingCollection
	 */
	public SearchSettingCollection GetSearchSettingCollection();

	/**
	 * Get the selected names as a string.
	 *
	 * @return String strSelectedNames
	 */
	public String GetSelectedNamesAsString();

	/**
	 * Get the selector's class ID.
	 *
	 * @return int nSelectorClassID
	 */
	public int GetSelectorClassID();

	/**
	 * Get the selector's community folder ID.
	 *
	 * @return int nSelectorCommunityFolderID
	 */
	public int GetSelectorCommunityFolderID();

	/**
	 * Get the selector's community  ID.
	 *
	 * @return int nSelectorCommunityID or 0 if not in a community
	 */
	public int GetSelectorCommunityID();
	
	/**
	 * Get the selector's object ID.
	 *
	 * @return int nSelectorObjectID
	 */
	public int GetSelectorObjectID();

	/**
	 * Get the selector's page ID.
	 *
	 * @return int nSelectorPageID
	 */
	public int GetSelectorPageID();

	/**
	 * Get the id for object in the invitation pop-up.
	 *
	 * @return int
	 */
	public int GetTemporaryInvitationID();

	/**
	 * Get the name for object in the invitation pop-up.
	 *
	 * @return String
	 */
	public String GetTemporaryInvitationName();
	
	/**
	 * Get whether or not to show an object given the objectID
	 * 
	 * @param nObjectID
	 * @return boolean
	 */
	public boolean DoNotShowObjectWithID(int nObjectID);
	
	/**
	 * Initializes the model. 
	 * Normally just called by the Interpreter, but used by the PortletDataTag when this model
	 * is run in delayed initialization mode.
	 * @param htFormData
	 * @return
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable htFormData);
	
	/**
	 * Gets the current property id that the model is ordered by.
	 * 
	 * @return
	 */
	public int GetSortPropertyId(); 
	
	
	public boolean IsHomeMyPage();
	public boolean IsMyPage();
	public boolean IsCommunityPage();
	public boolean IsPageTemplate();

	/**
	 * Get the first displayable item for pagination in the object selection
	 * model if pagination is used.
	 * 
	 * @return the first displayable item.
	 */
	public int GetFirstDisplayableItem();

	/**
	 * Get the number of items per page for pagination in the object selection
	 * model if pagination is used.
	 * 
	 * @return the number of items per page.
	 */
	public int GetItemsPerPage();

	/**
	 * Get the total number of items for pagination in the object selection
	 * model if pagination is used.
	 * 
	 * This includes all object types currently being displayed.
	 * 
	 * @return the total number of items.
	 */
	public int GetTotalItems();
}