package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class ObjSelFolderViewHelper implements IFolderViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.ObjSelFolderViewHelper");

	// Query parameter name for the checkbox

	
	public static final String QS_CHECKBOX = "in_cb_checkbox";

	/** Javascript function: openFolder */
	public static final String JAVASCRIPT_OPEN_FOLDER = "openFolder";

	/** HTML Input hidden: Open Folder ID */
	public static final String HTMLINPUT_OPENFOLDERID = "in_hi_openFolderID";
	private int m_nRepostAction = 0;

	public ObjSelFolderViewHelper()
	{
		m_nRepostAction = ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayFolder(int, HTMLTableCell, IFolderModelRO, AActivitySpace)
	 */
	public int DisplayFolder(int nFolderIndex, HTMLTableCell tableCell,
		IFolderModelRO model, AActivitySpace space)
	{
		try
		{
			// get the folder query
			IASQueryResult qrFolders = model.GetFolderQueryResult();
			int nIndex				 = nFolderIndex;

			// get name, folder ID, and folder URL from query
			String strName     = (String) qrFolders.GetFields(nIndex,
					PT_PROPIDS.PT_PROPID_NAME);
			int nFolderID	   = XPConvert.ToInteger(qrFolders.GetFields(nIndex,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			int nFolderType	   = XPConvert.ToInteger(qrFolders.GetFields(nIndex,
					PT_PROPIDS.PT_PROPID_FOLDER_FOLDERTYPE));		
			String strFolderID = XPConvert.ToString(nFolderID);

			// Open folder URL
			HTMLAnchor myAnchor;

			if (AccessStyles.STANDARD != space.GetAccessStyle())
			{
				ASURL myAsurl = ((AFormDP) space.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
				myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
					nFolderID);
				myAsurl.AddInnerHTMLEncodedString(strName);
				myAnchor = (HTMLAnchor) myAsurl.GetURLAsHTMLElement();
			}
			else
			{
				myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strName),
						JAVASCRIPT_OPEN_FOLDER + "('" + strFolderID + "')");
			}

			// use list item construct
			UIListItem itemConstruct = new UIListItem(myAnchor, space);
			if (nFolderType == PT_ADMIN_FOLDER_TYPES.PT_ADMIN_FOLDER_TYPE_COMMUNITYFOLDER)
			{
				itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_COMMUNITY,
					space.GetString(1781, "ptmsgs_portalbrowsingmsgs"));				
			} else {	
				itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER,
					space.GetString(1782, "ptmsgs_portalbrowsingmsgs"));
			}		
			itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

			// convert the construct to table
			try
			{
				HTMLTable folderTable = itemConstruct.GetItemAsTable();
				tableCell.AddInnerHTMLElement(folderTable);
			}
			catch (Exception e)
			{
						
					log.Error(e, "Error in ObjSelFolderViewHelper::DisplayFooter: ");
				
			}

			nFolderIndex++;
		}
		catch (Exception e)
		{
			log.Error("Couldn't retrieve folder at " + nFolderIndex);
		}

		return nFolderIndex;
	}

	/**
	 * 
	 *
	 * @param asOwner 
	 *
	 * @return 
	 */
	public HTMLScript DisplayJavascript(AActivitySpace asOwner)
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		XPStringBuilder sb = new XPStringBuilder(200);

		sb.Append("\n")
		.Append("function ").Append(JAVASCRIPT_OPEN_FOLDER).Append("(folderID)\n")
		.Append("{\n")
		.Append("		if (document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE).Append(") {\n")
		.Append("			document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE).Append(".value = 'false';\n")
		.Append("		}\n")
		.Append("		document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_OPENFOLDERID).Append(".value = folderID;\n")
		.Append("		postToSelf('").Append(m_nRepostAction).Append("');\n")
		.Append("}\n");

		try
		{
			script.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript: Failed to add 'openFolder' javascript function to page. " +
					he.getMessage());
			
		}

		return script;
	}

	/**
	 * 
	 *
	 * @param strControlName 
	 */
	public void SetControlName(String strControlName)
	{
	}

	/**
	 * 
	 *
	 * @param nRepostAction 
	 */
	public void SetRepostAction(int nRepostAction)
	{
		m_nRepostAction = nRepostAction;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int)
	 */
	public void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID, IFolderModelRO _model, AActivitySpace _space)
	{
		if (AccessStyles.STANDARD != _space.GetAccessStyle())
		{
			ASURL myAsurl = ((AFormDP) _space.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
			myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID,
				_nFolderID);
			_anchor.SetHRef(myAsurl.GetURLAsString());
		}
		else
		{
			_anchor.SetHRef( CommonHTMLStrings.POUND_SYMBOL );
			_anchor.SetOnClick(ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "('" + _nFolderID + "');return false;");
		}
	}
}

