package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 *
 */
public class ObjSelSearchFormView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.ObjSelSearchFormView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "ObjSelSearchFormView";

	/** Get Logger */
	/** hidden input constants */
	/** true implies tree, false implies search */
	public static final String HTMLINPUT_VIEWTYPE = "in_hi_ViewType";

	/** constants */
	public static final String JAVASCRIPT_START_SEARCH = "submitSearch";
	
	/** Form Submit Name */
	public static final String FORM_SUBMIT = "in_su_ptobjsearch";

	/** Javascript constants */
	public static final String JAVASCRIPT_SWITCH_VIEW = "switchView";

	/** Activity Space */
	protected AActivitySpace m_asOwner;
	private IFolderModelRO m_asFolderModel;

	/** Model */
	private IObjectSelectionModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjSelSearchFormView();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = null;

		if (AccessStyles.STANDARD != m_asOwner.GetAccessStyle() && !m_asModel.GetDisplaySearch())
		{
			result = new HTMLSpan();
			result.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);
			ASURL myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_UNDEFINED);
			myAsurl.AddControlArgument(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE, XPConvert.ToString(Boolean.TRUE));
			myAsurl.AddInnerHTMLString(((IObjectSelectionAS) m_asOwner).GetSearchPrompt());
			result.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
		}
		else
		{
			try
			{
				// Get the search box if we're in tree mode
				result = makeObjectSearchForm();
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "Unable to create search box form elements: " +
						he.getMessage());
				
	
				result = null;
			}
	
			if (result == null)
			{
				// still need to display the hidden input if we're in search mode
				// or the search box failed
				result = new HTMLElementCollection();
			}
		}

		try
		{
			// The hidden input for the view type of the tree (tree vs. search)
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLINPUT_VIEWTYPE, "");
			result.AddInnerHTMLElement(myInput);
			myInput.SetValue(XPConvert.ToString(m_asModel.GetDisplaySearch()));
		}
		catch (HTMLException he)
		{
				
				log.Error(he, "Unable to create hidden view type input: " +
					he.getMessage());
				
		}

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result  = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		sb = new XPStringBuilder(150);
		sb.Append("\n");

		//  start search / switch view type function
		sb.Append("function ").Append(JAVASCRIPT_START_SEARCH).Append("()\n")
		.Append("{\n").Append// Switch view type to search
		("  	document.").Append(AFormDP.HTMLFORM_NAME).Append(".")
		.Append(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE)
		.Append(".value = '").Append(XPConvert.ToString(true)).Append("';\n")
		.Append("  	return true;\n").Append("}\n\n");

		try
		{
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element: " +
					he.getMessage());
			
		}

		if (m_asModel.GetSearchStarted())
		{
			sb = new XPStringBuilder(150);
			sb.Append("\n");

			// switch header function
			sb.Append("function ").Append(JAVASCRIPT_SWITCH_VIEW).Append("()\n")
			.Append("{\n").Append// Switch view type
			("  	document.").Append(AFormDP.HTMLFORM_NAME).Append(".")
			.Append(ObjSelSearchFormView.HTMLINPUT_VIEWTYPE)
			.Append(".value = '")
			.Append(XPConvert.ToString(!m_asModel.GetDisplaySearch())).Append("';\n")
			.Append("  	postToSelf(")
			.Append(RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST).Append(");\n")
			.Append("  	return false;\n").Append("}\n");

			try
			{
				result.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element: " +
						he.getMessage());
				
			}
		}

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel		    = (IObjectSelectionModelRO) model;
		m_asFolderModel     = (IFolderModelRO) model;
		m_asOwner		    = parent;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	private HTMLElement makeObjectSearchForm()

	{
		// Some search forms have optional constraints that a user can choose via
		// a pulldown or set of radio button.  This example shows how to create such
		// a form (in this case, a form that searches for gadgets, crawlers, or all
		// objects, in a single folder, a folder plus its subfolders, or all folders).
		// Make the factory with a unique name
		// false means to add this to a larger form
		boolean returnCompleteForm;
		String strFormName;

		if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
		{
			returnCompleteForm = false;
			strFormName = AFormDP.HTMLFORM_NAME;
		}
		else
		{
			returnCompleteForm = true;
			strFormName = "508searchform";
		}

		SearchFormFactory factory = new SearchFormFactory(strFormName,
			strFormName, m_asOwner, returnCompleteForm);

		// Don't set the search form's target, as we are using our own form.
		// Set the javascript validation function
		if (AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
		{
			factory.SetValidationFunction(JAVASCRIPT_START_SEARCH);
		}
		else
		{
			factory.SetTarget(m_asOwner.GetName(), m_asOwner.GetSpaceID(), m_asOwner.GetCurrentPage().GetName());
		}

		// Add required constraints that should be used for ALL searches.
		factory.AddRequiredSettings(m_asModel.GetSearchSettingCollection());

		if (-1 != m_asFolderModel.GetCurrentFolderID())
		{
			// Add constraint for which folder to search in
			factory.AddRequiredSetting(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS,
				new int[] { m_asFolderModel.GetCurrentFolderID() });
		}

		// Finally, get the form from the factory and add the pulldown to it,
		// along with whatever other HTML elements you want.  This part is
		// basically the same as the first example.
		HTMLElement result = factory.GetResult();

		HTMLTable table;
		HTMLTableRow row;
		HTMLTableCell cell;

		// Search table
		table = new HTMLTable();
		result.AddInnerHTMLElement(table);
		table.SetCellSpacing(CommonHTMLStrings.ZERO);
		table.SetCellPadding("3");
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		table.SetBorder(CommonHTMLStrings.ZERO);

		row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);
		row.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG);

		// text
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetHeight("25");
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		cell.SetNoWrap(true);

		HTMLSpan mySpan = new HTMLSpan();
		cell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
		mySpan.AddInnerHTMLString(((IObjectSelectionAS) m_asOwner).GetSearchPrompt() + CommonHTMLStrings.SPACE);

		// Input box
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetHeight("25");
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		cell.SetNoWrap(true);

		HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT,
				factory.GetInputBoxName(), ((IObjectSelectionAS) m_asOwner).GetSearchPrompt());
		input.SetOnKeyDown(factory.GetInputBoxOnKeyDown());
		input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		cell.AddInnerHTMLElement(input);

		// Add submit button
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetHeight("25");
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		cell.SetNoWrap(true);

		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			HTMLAnchor submitLink = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			submitLink.SetOnClick(factory.GetAnchorOnClick());
			submitLink.SetPreComment("Search");
	
			PTConstruct searchButton = null;
	
			try
			{
				searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON,
						true, this.m_asOwner);
			}
			catch (Exception e)
			{
				// TODO: handle this
			}
	
			if (null != searchButton)
			{
				HTMLImg searchButtonImg = (HTMLImg) searchButton.GetHTMLElement();
				searchButtonImg.SetAlt(((IObjectSelectionAS) m_asOwner).GetSearchPrompt());
				submitLink.AddInnerHTMLElement(searchButtonImg);
			}
			else
			{
				submitLink.AddInnerHTMLString(((IObjectSelectionAS) m_asOwner).GetSearchPrompt());
			}
	
			cell.AddInnerHTMLElement(submitLink);

			// Spacer cell at end
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("25");
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			cell.SetNoWrap(true);

			// spacer table
			table = new HTMLTable();
			result.AddInnerHTMLElement(table);
			table.SetCellSpacing(CommonHTMLStrings.ZERO);
			table.SetCellPadding(CommonHTMLStrings.ZERO);
			table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			table.SetBorder(CommonHTMLStrings.ZERO);

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);

			try
			{
				PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER);
				HTMLImg myImg		    = (HTMLImg) myConstruct.GetHTMLElement();
				myImg.SetHeight("10");
				cell.AddInnerHTMLElement(myImg);
			}
			catch (Exception e)
			{
					log.Error("Unable to create spacer image: " + e.getMessage());
			}
		}
		else
		{
			HTMLInput searchSubmitButton = new HTMLInput(HTMLInputTypes.SUBMIT,
					FORM_SUBMIT, m_asOwner.GetString(46, "ptmsgs_portal508quickkeymsgs"));

			searchSubmitButton.SetValue(m_asOwner.GetString(341,
					"ptmsgs_portalcommonmsgs")); // "Search"
			searchSubmitButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			searchSubmitButton.SetAccessKey(m_asOwner.GetString(4, "ptmsgs_portal508quickkeymsgs"));
			cell.AddInnerHTMLElement(searchSubmitButton);

			// Spacer cell at end
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("25");
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			cell.SetNoWrap(true);
		}

		return result;
	}
}

