package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.portlets.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Handle reposts for the Object Selection Model.
 */
public class ObjectSelectionRepostControl extends EditorRepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.ObjectSelectionRepostControl");

	public static final String STR_MVC_CLASS_NAME = "ObjectSelectRepost";

	// These two should be used together or not at all.
	// The name of the parent form that you would like the data passed back to.
	public static final String strPARENT_FORM_NAME = "Form";

	// The name of the input in the parent form that you would like the AActivitySpace
	// ID of the tree space put into.
	public static final String strPARENT_FORM_SPACE_ID = "Input";

	// The name of the javascript function in the parent page to call when the tree
	// is submitted.  This should not include the '();'.
	// In Javascript submit mode this method should take an array argument which will
	// be made up of objects with name, ObjectID, and ClassID member variables.
	// see ATreeAS for details.
	public static final String strPARENT_SUBMIT_CALL = "Submit";

	public final static int POSTTOSELF_ACTION_MISC = 10;

	/** Post to self after adding portlets from a bundle */
	public final static int POSTTOSELF_ACTION_ADDPORTLETS_FROMBUNDLE = 40;

	/** Post to self to select portlet bundle */
	public final static int POSTTOSELF_ACTION_SELECT_BUNDLE = 41;

	/** Post to self to open a folder by way of folder view or breadcrumbs */
	public final static int POSTTOSELF_ACTION_OPENFOLDER = 42;

	/** Post to self to add a object using the 508 UI */
	public final static int POSTTOSELF_508_ACTION_ADDOBJECT = 43;

	/** Post to self to remove a object using the 508 UI */
	public final static int POSTTOSELF_508_ACTION_REMOVEOBJECT = 44;

	/** Post to self to add all portlets from a bundle. */
	public final static int POSTTOSELF_508_ACTION_ADDBUNDLE = 45;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectSelectionRepostControl();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call  the associated method for each
	 * action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);

		switch (_nAction)
		{
		case -1: //POSTTOSELF_ACTION_UNDEFINED:
			((ObjectSelectionModel) m_model).RepostToSearch();

			break;

		case POSTTOSELF_ACTION_ADDPORTLETS_FROMBUNDLE:
			((ObjectSelectionModel) m_model).RepostAddPortletsFromBundle();

			break;

		case POSTTOSELF_ACTION_SELECT_BUNDLE:
			((ObjectSelectionModel) m_model).RepostSelectPortletBundle();

			break;

		case POSTTOSELF_ACTION_OPENFOLDER:
			((ObjectSelectionModel) m_model).RepostOpenFolder();

			break;

		case POSTTOSELF_508_ACTION_ADDOBJECT:
			((ObjectSelectionModel) m_model).RepostAddObject();

			break;

		case POSTTOSELF_508_ACTION_REMOVEOBJECT:
			((ObjectSelectionModel) m_model).RepostRemoveObject();

			break;
		}
	}

	/**
	 * This method is called when we finish a sub Editor.
	 * It takes care of closing the sub Editor pop-up winodws
	 * and repost the main Editor window.
	 *
	 */
	protected void SetRedirectToCloseSubEditor()
	{
		((EditorModel) m_model).SetDeleteOnCancel(false);

		String strOpenerFunction = ((IObjectSelectionModelRO)m_model).GetParentFormSubmitFunction();

		int nSize = 20;

		if ((strOpenerFunction != null) &&
				(!"".equals(strOpenerFunction)))
		{
			nSize += 100;
		}

		XPStringBuilder sb = new XPStringBuilder(nSize);

		// Add method to call on opening form, if it exists
		if ((strOpenerFunction != null) &&
				(!"".equals(strOpenerFunction)))
		{
			// strOpenerFunction should just be the method name, so escaping it will
			// prevent cross-site scripting hacks.
			sb.Append("  parent.opener.").Append(JSHelper.escapeJS(strOpenerFunction))
			.Append("();\n");
		}

		// We are in a frame, so we need to call parent, not window
		sb.Append("parent.close();\n");

		HTMLScript myScript = new HTMLScript("text/javaScript");
		try
		{
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
				log.Error(he, "Error generating JS for ClosePopUpDP.");
		}

		ClosePopUpDP myClosePopUp = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
		myClosePopUp.SetScript(myScript);

		// Close the Tree pop-up
		Redirect myRedirect = new Redirect();
		myRedirect.SetLinkGetCachedSpace(m_asOwner);
		myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

		SetRedirect(myRedirect);
	}
	
	/**
	 * Helper method to implement the Cancel action.
	 * On cancel, we just redirect to whatever is
	 * returned by GetRedirectAfterFinish.
	 * If this is a sub Editor in Create mode we also
	 * delete the sub Editor from the list. And then we
	 * close the pop-up.
	 *
	 */
	protected void PerformCancelAction()
	{
		((EditorModel) m_model).Cancel();

		if (m_asOwner.IsSubSpace())
		{
			if (((EditorModel) m_model).GetDeleteOnCancel())
			{
				m_asOwner.GetParentSpace().DeleteSubSpace(m_asOwner.GetSubSpaceKey());
			}

			Redirect myRedirect = new Redirect();
			myRedirect.SetLinkGetCachedSpace(m_asOwner);

			ClosePopUpDP myClosePopUpDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			
			if(m_asOwner.GetName().equals(PortletSelectionEditorAS.STR_MVC_CLASS_NAME))
			{
				myClosePopUpDP.SetToClose(false);
				HTMLScript script = new HTMLScript("text/javaScript");
				script.AddInnerHTMLString("parent.close();");
				myClosePopUpDP.SetScript(script);
			} else {
				myClosePopUpDP.SetToClose(true);
				myClosePopUpDP.SetScript(null);	
			}
			
			myRedirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

			SetRedirect(myRedirect);
		}
		else
		{
			super.PerformCancelAction();
		}
	}
}