package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class ObjectSelectionView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.ObjectSelectionView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "ObjectSelection";

	/** Form Input: Object radio button */
	public static final String HTMLINPUT_SELECTION_RA_OBJECT = "in_ra_Object";

	/** Form Input: Object checkbox */
	public static final String HTMLINPUT_SELECTION_CB_OBJECT = "in_cb_Object";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IObjectSelectionModelRO m_asmModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectSelectionView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection collection = new HTMLElementCollection();
		HTMLElement myElement			 = collection;

		try
		{
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID, "");
			collection.AddInnerHTMLElement(myInput);
		}
		catch (HTMLException he)
		{
			log.Error(he, "Display(): Failed to add selected objects input to collection.");
		}

		return myElement;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = null;

		// Set up parent form space ID
		String strSpaceIDInput = m_asmModel.GetParentFormSpaceID();

		XPStringBuilder sb = new XPStringBuilder(100);

		// Onload method to set the Space ID
		if ((strSpaceIDInput != null) && (!"".equals(strSpaceIDInput)))
		{
			sb.Append("parent.opener.").Append(JSHelper.escapeJS(m_asmModel.GetParentFormName()))
			.Append(".").Append(JSHelper.escapeJS(strSpaceIDInput)).Append(".value= ")
			.Append(m_asOwner.GetSpaceID()).Append(";\n");
			sb.Append("\n");
		}

		try
		{
			result = new HTMLScript("text/javaScript");

			result.AddInnerHTMLString(sb.ToString());
		} catch (HTMLException he)
		{
			log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element.");
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asmModel     = (IObjectSelectionModelRO) model;
		m_asOwner	   = parent;
	}
}