package com.plumtree.portalpages.browsing.objectselection;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class SelectedObjectsView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.SelectedObjectsView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "SelectedObjects";

	/**
	 * JS function to refresh the page.
	 */
	public static final String JAVASCRIPT_REFRESH = "refresh";
	
	/** Javascript Function: addNewlySelected */
	public static final String JAVASCRIPT_ADD_SELECTED = "addNewlySelected";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IObjectSelectionModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SelectedObjectsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		try
		{
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("5");

			// Row for You have selected:
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myCell.SetHeight("20");
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.DIALOGUE_SUBHEAD);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(746,
					"ptmsgs_portalbrowsingmsgs"));

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.DIALOGUE_GRAY_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetHeight("25");
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetStyleClass(PTStyleClass.DIALOGUE_TEXT);

			myCell.AddInnerHTMLEncodedString(m_model.GetSelectedNamesAsString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Display: Failed to display the selected objects's names. " +
					he.getMessage());
			
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		ASURL viewSelectedURL = new ASURL(m_asOwner);
		viewSelectedURL.SetLinkGetCachedSpace(m_asOwner);
		viewSelectedURL.SetDisplayPage(SelectedObjectsDP.STR_MVC_CLASS_NAME);
		

		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("\n");
		sb.Append("function ").Append(JAVASCRIPT_REFRESH).Append("()\n");
		sb.Append("{\n");
		sb.Append("  window.location = '").Append(viewSelectedURL.GetURLAsString()).Append("';\n");
		sb.Append("}\n");

		// DCA - javascript to encode non-sjis characters
		sb.Append("function my_hex(n, len) {\n");
		sb.Append("	var out, i;\n");
		sb.Append("	out = \"\";\n");
		sb.Append("	for(i = 0; i < len; i++) {\n");
		sb.Append("		out = \"0123456789ABCDEF\".charAt(n & 0xf) + out;\n");
		sb.Append("		n >>= 4;\n");
		sb.Append("	}\n");
		sb.Append("	return out;\n");
		sb.Append("}\n");
		
		sb.Append("function my_escape(str) {\n");
		sb.Append("	var c, i, out;\n");
		sb.Append("	out = \"\";\n");
		sb.Append("	for(i = 0; i < str.length; i++) {\n");
		sb.Append("		c = str.charAt(i);\n");
		sb.Append("		if(c.match(/[^.0-9A-Z_a-z-]/)) {\n");
		sb.Append("			c = str.charCodeAt(i);\n");
		sb.Append("			if(c < 256)\n");
		sb.Append("				out += \"%\" + my_hex(c, 2);\n");
		sb.Append("			else\n");
		sb.Append("				out += \"%u\" + my_hex(c, 4);\n");
		sb.Append("		} else\n");
		sb.Append("			out += c;\n");
		sb.Append("	}\n");
		sb.Append("	return out;\n");
		sb.Append("}\n");

		sb.Append("function utf16to8(str) {\n");
		sb.Append("	var out, i, len, c;\n");
		sb.Append("	out = \"\";\n");
		sb.Append("	len = str.length;\n");
		sb.Append("	for(i = 0; i < len; i++) {\n");
		sb.Append("		c = str.charCodeAt(i);\n");
		sb.Append("		if ((c >= 0x0001) && (c <= 0x007F)) {\n");
		sb.Append("			out += str.charAt(i);\n");
		sb.Append("		} else if (c > 0x07FF) {\n");
		sb.Append("			out += String.fromCharCode(0xE0 | ((c >> 12) & 0x0F));\n");
		sb.Append("			out += String.fromCharCode(0x80 | ((c >>  6) & 0x3F));\n");
		sb.Append("			out += String.fromCharCode(0x80 | ((c >>  0) & 0x3F));\n");
		sb.Append("		} else {\n");
		sb.Append("			out += String.fromCharCode(0xC0 | ((c >>  6) & 0x1F));\n");
		sb.Append("			out += String.fromCharCode(0x80 | ((c >>  0) & 0x3F));\n");
		sb.Append("		}\n");
		sb.Append("	}\n");
		sb.Append("	return out;\n");
		sb.Append("}\n");
		
		// DCA - javascript function to refresh bottom frame w/ newly added or removed object
		viewSelectedURL = new ASURL(m_asOwner);
		viewSelectedURL.SetLinkGetCachedSpace(m_asOwner);
		viewSelectedURL.SetDisplayPage(SelectedObjectsDP.STR_MVC_CLASS_NAME);
		viewSelectedURL.SetControl(RefreshObjSelControl.STR_MVC_CLASS_NAME);
		viewSelectedURL.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKOBJECTID);

		sb.Append("function ").Append(JAVASCRIPT_ADD_SELECTED).Append("(objID, alignment, name, bselect)\n");
		sb.Append("{\n");
		sb.Append("	 name = my_escape(utf16to8(name));\n");
		sb.Append("  var address = '").Append(viewSelectedURL.GetURLAsString()).Append("' + objID; \n");
		sb.Append("	 	if (bselect) {\n");
		sb.Append(" 		address = address + '&").Append(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKALIGNMENT)
			.Append("=' + alignment + '&").Append(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_ONCLICKNAME)
			.Append("=' + name;\n");
		sb.Append("		}\n");
		sb.Append("  window.location = address;\n");
		sb.Append("}\n");
		
		HTMLScript result = new HTMLScript("text/javaScript");

		try
		{
			result.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add javascript to the HTMLScript element.");
			

			return null;
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = (IObjectSelectionModelRO) model;
		m_asOwner     = parent;
	}
}

