package com.plumtree.portalpages.browsing.objectselection.communities;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: CommunityInvitationPopupView.java
 * ---------------------------------------
 * Section for for the Invitation Popup on
 * the gadget selection page (when clicking
 * "Send to Others.")
 *
 * @author NaveenP/DustinA
 */
public class CommunityInvitationPopupView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.communities.CommunityInvitationPopupView");

	
	public static final String STR_MVC_CLASS_NAME = "CommunityInvitationPopup";
	private AActivitySpace m_asOwner;

	/** model */
	private ObjectSelectionModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CommunityInvitationPopupView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement page = null;

		try
		{
			page = InviteURLPopup();
		}
		catch (HTMLException e)
		{
			log.Error(e, "Error displaying invitation URL popup.");
		}

		return page;
	}

	/**
	 * Display javaScript
	 *
	 * @return null
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (ObjectSelectionModel) model;
		m_asOwner     = parent;
	}

	/**
	 * Method inviteURL- displays popup of email message with url to join the
	 * community specified
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	public HTMLElement InviteURLPopup()
	{
		//mainPage components
		HTMLPage mainPage	    = new HTMLPage();
		HTMLHead pageHead	    = new HTMLHead();

		HTMLTitle pageTitle = new HTMLTitle(m_asOwner.GetString(1655,
					"ptmsgs_portalbrowsingmsgs"));
		pageHead.AddInnerHTMLElement(pageTitle);

		HTMLBody pageBody = new HTMLBody();
		pageBody.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

		//mainTable components
		HTMLTable mainTable		   = new HTMLTable();
		HTMLTableRow mainRow1	   = new HTMLTableRow();
		HTMLTableRow mainRow2	   = new HTMLTableRow();
		HTMLTableRow mainRow3	   = new HTMLTableRow();
		HTMLTableRow mainRow4	   = new HTMLTableRow();
		HTMLTableCell mainRow1Cell = new HTMLTableCell();
		HTMLTableCell mainRow2Cell = new HTMLTableCell();
		HTMLTableCell mainRow3Cell = new HTMLTableCell();
		HTMLTableCell mainRow4Cell = new HTMLTableCell();

		//closeButton
		HTMLInput closeButton = new HTMLInput(1, "in_bu_close",
				m_asOwner.GetString(686, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(686, "ptmsgs_portalbrowsingmsgs"));
		closeButton.SetValue(m_asOwner.GetString(17, "ptmsgs_portalbrowsingmsgs"));
		closeButton.SetOnClick("self.close()");
		closeButton.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);

		//Community Name
		String strCommName = TaskAPIUIHTML.HTMLEncode( m_asModel.GetTemporaryInvitationName() );
		int nCommID		   = m_asModel.GetTemporaryInvitationID();

		//email message to be sent
		HTMLTextArea messageTextArea = new HTMLTextArea("100", "8");
		messageTextArea.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

		boolean bIsInviteURLSecure = (1 == PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.INVITATIONS_SECTION, PTConfigConstants.IS_INVITATION_URL_SECURE,
																				"value", m_asOwner));

		ASURL urlInvite = new ASURL(m_asOwner);
		urlInvite.SetUseMainServerURL(true, bIsInviteURLSecure);
		urlInvite.SetLinkGetSpaceIfCached(PreviewCommunityAS.STR_MVC_CLASS_NAME, m_asOwner);
		urlInvite.SetControl(PreviewCommunityControl.STR_MVC_CLASS_NAME);
		urlInvite.AddControlArgument(PreviewCommunityControl.m_PreviewType,
			XPConvert.ToString(PreviewCommunityModel.INVITEHEADER));
		urlInvite.AddControlArgument(PreviewCommunityControl.m_CommunityID,
			XPConvert.ToString(nCommID));
        urlInvite.SetDisplayPage(PreviewCommunityDP.STR_MVC_CLASS_NAME);

		messageTextArea.AddInnerHTMLString("\n" + 
				XPResourceManager.FormatMessage(m_asOwner.GetString(687, ResourceConstants.PORTALBROWSINGMSGS), strCommName) + " \n\n" + 
				m_asOwner.GetString(688, "ptmsgs_portalbrowsingmsgs") + "\n" +
				urlInvite.GetURLAsString() + "\n\n" +
				m_asOwner.GetString(689, "ptmsgs_portalbrowsingmsgs"));

		//Specifying mainTable attributes
		//border="0" cellpadding="4" width="100%"
		mainTable.SetBorder("0");
		mainTable.SetCellPadding("4");
		mainTable.SetWidth("100%");
		mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

		//Setting up mainTable
		mainRow1Cell.SetStyleClass(PTStyleClass.DIR_TEXT);

		mainRow1Cell.AddInnerHTMLString(m_asOwner.GetString(690,
				"ptmsgs_portalbrowsingmsgs"));
		mainRow2Cell.SetStyleClass(PTStyleClass.DIR_TEXT);
		mainRow2Cell.AddInnerHTMLElement(messageTextArea);
		mainRow3Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		mainRow4Cell.SetAlign("center");
		mainRow4Cell.SetStyleClass(PTStyleClass.BAN_TEXT);
		mainRow4Cell.AddInnerHTMLElement(closeButton);

		PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow4, mainRow4Cell);
		pageBody.AddInnerHTMLElement(mainTable);

		try
		{
			pageHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
		}
		catch (Exception e)
		{
			log.Error(e, "Error adding stylesheets.");
		}

		mainPage.SetHead(pageHead);
		mainPage.SetBody(pageBody);

		return mainPage;
	}
}

