package com.plumtree.portalpages.browsing.objectselection.communities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class CommunitySelectionDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.communities.CommunitySelectionDP");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "CommunitySelectionTopFrame";

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(691, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader() throws HTMLException {
		if (!((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetDisplaySearch())
		{
			return HTMLConstructHelpers.GetSubHeader(
				m_asOwner.GetString(1452, "ptmsgs_portalbrowsingmsgs"),
				this.m_asOwner);
		}
		return null;
	}

	/**
	 * Returns the HTML for that Page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException 
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLElementCollection views  = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		ObjectSelectionModel model = ((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME));

		// Add a "search for communities" form
		views.AddInnerHTMLElement(m_asOwner.GetView(
				ObjSelSearchFormView.STR_MVC_CLASS_NAME).Display());

		views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
		
		if (!model.GetDisplaySearch())
		{
			if (1 < model.GetCurrentFolderID())
			{
				views.AddInnerHTMLElement(m_asOwner.GetView(
					ObjSelBreadCrumbView.STR_MVC_CLASS_NAME).Display());
				views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
			}

			views.AddInnerHTMLElement(m_asOwner.GetView(
					FolderView.STR_MVC_CLASS_NAME).Display());
			views.AddInnerHTMLElement(EditorView.GetSpacerTable());

			if (1 != model.GetCurrentFolderID())
			{
				views.AddInnerHTMLElement(m_asOwner.GetView(
						ObjectView.STR_MVC_CLASS_NAME).Display());
				// DCA - javascript to check the check all box if all checkboxes are checked		
				views.AddInnerHTMLElement(
						((ObjectView) m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME)).GetCheckAllScript());
			}
		}
		else
		{
			views.AddInnerHTMLElement(m_asOwner.GetView(ObjSelSearchHeaderView.STR_MVC_CLASS_NAME).Display());
			views.AddInnerHTMLElement(HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1452,
				"ptmsgs_portalbrowsingmsgs"), this.m_asOwner));
			views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());

			SearchResultModel searchModel = ((SearchResultModel) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME));
			SearchExecutionError error = searchModel.GetError();

			if (error == null)
			{
			    String myQueryText = ((ISearchResultModelRO) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME)).GetSearchString();

				// if somebody actually typed something in and did a search then we want this
				// displayed. the first time the page is displayed we don't want it
                            if (null == myQueryText || myQueryText.equals("") || myQueryText.equals("*"))
				{
				    // don't show anything
				}
				else
				{
					    views.AddInnerHTMLElement(ReorganizationViewHelper.DisplayReorganization(
						        searchModel, m_asOwner, /*showCustomOptions=*/ false));
					    views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				    views.AddInnerHTMLElement(m_asOwner.GetView(SearchSummaryView.STR_MVC_CLASS_NAME).Display());
				}
				views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				views.AddInnerHTMLElement(m_asOwner.GetView(
					GroupedResultsView.STR_MVC_CLASS_NAME).Display());
				if ((searchModel.GetNumDisplayableItems() < searchModel.GetTotalItems()) && (0 == searchModel.GetNumResultGroups()))
				{
					views.AddInnerHTMLElement(m_asOwner.GetView(SearchFooterView.STR_MVC_CLASS_NAME).Display());
				}
			}
			else
			{
				HTMLSpan mySpan = new HTMLSpan();
				views.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
				mySpan.AddInnerHTMLString(error.GetMessage());
			}
		}

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(m_asOwner.GetView(
				ObjectSelectionView.STR_MVC_CLASS_NAME).Display());

		result.AddInnerHTMLElement(CreateContentTable(views,
				null));

		model = null;

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection scripts		    = new HTMLScriptCollection();
		HTMLScript myScript;
		HTMLScriptCollection myScriptCollection;

		ObjectSelectionModel model = ((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME));

		if (model.GetDisplaySearch() && ((SearchResultModel) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME)).IsInitialized())
		{
			myScript = m_asOwner.GetView(GroupedResultsView.STR_MVC_CLASS_NAME)
				.DisplayJavascript();

			if (null != myScript)
			{
				scripts.AddInnerHTMLElement(myScript);
			}
		}

		myScript = ((ObjSelFolderViewHelper) model.GetFolderViewHelper()).DisplayJavascript(m_asOwner);

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		myScript = m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME)
			.DisplayJavascript();

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		myScriptCollection = ((ObjectView) m_asOwner.GetView(ObjectView.STR_MVC_CLASS_NAME)).DisplayJavascriptCollection();

		if (null != myScriptCollection)
		{
			scripts.AddInnerHTMLElement(myScriptCollection);
		}

		myScript = m_asOwner.GetView(ObjSelSearchFormView.STR_MVC_CLASS_NAME)
			.DisplayJavascript();

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		model = null;

		// Add javascript to automatically refresh the bottom pane
		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append("\n");

		// Only refresh if the bottom pane exists and has the refresh function
		sb.Append("if ((parent.").Append(FrameSetDP.BODY_FRAME)
		.Append(") && (parent.").Append(FrameSetDP.BODY_FRAME).Append(".")
		.Append(SelectedObjectsView.JAVASCRIPT_REFRESH).Append("))\n");
		sb.Append("  parent.").Append(FrameSetDP.BODY_FRAME).Append(".")
		.Append(SelectedObjectsView.JAVASCRIPT_REFRESH).Append("();\n");

		HTMLScript reloadScript = new HTMLScript("text/javaScript");

		try
		{
			reloadScript.AddInnerHTMLString(sb.ToString());
			scripts.AddInnerHTMLElement(reloadScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add reload javascript to the HTMLScript element.");
			
		}

		return scripts;
	}
}

