package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class BundleSelectionViewHelper implements IObjectViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.BundleSelectionViewHelper");

	/** HTML Input Checkbox */
	public static final String HTMLINPUT_SELECTION_OBJECT = "in_bu_Bundle";

	/** Selection Header */
	public static final String SELECTION_HEADER = CommonHTMLStrings.SPACE;

	/** HTML Input Hidden: Portlet Bundle AS ID Prefix - add bundle id to the end of this */
	public static final String HTMLINPUT_BUNDLE_ASID_PREFIX = "in_hi_bundleASID";

	/** HTML Input Hidden: Currently open bundle */
	public static final String HTMLINPUT_CURRENT_BUNDLE = "in_hi_currentBundle";

	/** HTML Input Hidden: Select this bundle */
	public static final String HTMLINPUT_SELECT_BUNDLE = "in_hi_selectBundle";

	/** Javascript Function: openBundle */
	public static final String JAVASCRIPT_OPEN_BUNDLE = "openBundle";

	/** Javascript Function: ORaddPortletsFromBundle */
	public static final String JAVASCRIPT_ONRETURN_ADDPORTLETS_FROMBUNDLE = "ORaddPortletsFromBundle";

	/** Javascript Function: selectBundle */
	public static final String JAVASCRIPT_SELECT_BUNDLE = "selectBundle";

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#AddObjectViewHTML()
	 */
	public HTMLElement AddObjectViewHTML(IObjectModelRO model)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLInput myInput;

		try
		{
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLINPUT_CURRENT_BUNDLE, "");
			result.AddInnerHTMLElement(myInput);
			myInput.SetValue(((IObjectSelectionModelRO) model).GetInputValue(
					HTMLINPUT_CURRENT_BUNDLE));
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "AddObjectViewHTML: Failed to add current bundle hidden input to object view. " +
					he.getMessage());
			
		}

		try
		{
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLINPUT_SELECT_BUNDLE, "");
			result.AddInnerHTMLElement(myInput);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "AddObjectViewHTML: Failed to add select bundle hidden input to object view. " +
					he.getMessage());
			
		}

		return result;
	}


	/**
	 * @see com.plumtree.portalpages.common.objects.
	 * IObjectViewHelper#GetThereAreNoItemsString(AActivitySpace)
	 */
	public String GetThereAreNoItemsString(AActivitySpace asOwner)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#Display508Object(int, HTMLTable, IObjectModelRO, AActivitySpace)
	 */
	public void Display508Object(int nObjectIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace parent)
	{
		HTMLTableRow row;
		HTMLTableCell cell;
		HTMLSpan span;
		ASURL myAsurl;
		HTMLBr br = new HTMLBr();

		int iObjectID		    = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_OBJECTID));
		String strObjectName	    = (String) model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_NAME);
		Object oDescription = model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_DESCRIPTION);

		try
		{
			row = new HTMLTableRow();
			tableObjects.AddInnerHTMLElement(row);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetVAlign(CommonHTMLStrings.MIDDLE);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetVAlign(CommonHTMLStrings.MIDDLE);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

			span = new HTMLSpan();
			cell.AddInnerHTMLElement(span);
			span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			span.AddInnerHTMLEncodedString(strObjectName);

			cell.AddInnerHTMLElement(br);

			if (null != oDescription)
			{
				if (!"".equals(oDescription))
				{
					cell.AddInnerHTMLEncodedString((String)oDescription);
					cell.AddInnerHTMLElement(br);
				}
			}

			myAsurl = ((AFormDP) parent.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_SELECT_BUNDLE);
			myAsurl.AddControlArgument(BundleSelectionViewHelper.HTMLINPUT_SELECT_BUNDLE,
				iObjectID);
			myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(parent.GetString(1272, "ptmsgs_portalbrowsingmsgs"), 
				XPHttpUtility.HtmlEncode(strObjectName)));
			cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());

			row = new HTMLTableRow();
			tableObjects.AddInnerHTMLElement(row);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetColSpan("2");
			cell.SetAlign(CommonHTMLStrings.CENTER);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}
		catch (HTMLException e)
		{
			
				log.Error("Portlet Bundle " + XPConvert.ToString(iObjectID) +
					" failed to display: " + e.getMessage());
			
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayJavascriptCollection(AActivitySpace)
	 */
	public HTMLScriptCollection DisplayJavascriptCollection(
		AActivitySpace asOwner, IObjectModelRO model)
	{
		HTMLScriptCollection collection = new HTMLScriptCollection();

		ASURL myNewSelector;
		ASURL myOldSelector;
		XPStringBuilder sb;

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			collection.AddInnerHTMLElement(script);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascriptCollection: Failed to add script to collection. ");
			
		}

		// The url to open a previously opened tree
		// This needs to have the SpaceID added to it within the javascript function
		myOldSelector = new ASURL(asOwner);
		myOldSelector.SetLinkCreateNewSpace(PortletInBundleSelectionAS.STR_MVC_CLASS_NAME,
			asOwner);

		// The URL to open a new tree to select a portlet bundle
		myNewSelector = new ASURL(asOwner);
		myNewSelector.SetLinkCreateNewSpace(PortletInBundleSelectionAS.STR_MVC_CLASS_NAME,
			asOwner);
		myNewSelector.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		myNewSelector.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
			XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_MISC));
		int nPageID = ((IObjectSelectionModelRO) model).GetSelectorPageID();
		if (0 == nPageID)
		{
			nPageID = ((IObjectSelectionModelRO) model).GetSelectorObjectID();
		}
		myNewSelector.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORPAGEID,
			nPageID);
		myNewSelector.AddControlArgument(ObjectSelectionRepostControl.strPARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewSelector.AddControlArgument(ObjectSelectionRepostControl.strPARENT_SUBMIT_CALL,
			JAVASCRIPT_ONRETURN_ADDPORTLETS_FROMBUNDLE);
		myNewSelector.IsSubSpace();

		try
		{
			sb = new XPStringBuilder(300);

			sb.Append("\n").Append("function ").Append(JAVASCRIPT_OPEN_BUNDLE)
			.Append("(myInput, bundleID)\n").Append("{\n").Append("		document.")
			.Append(AFormDP.HTMLFORM_NAME).Append(".")
			.Append(HTMLINPUT_CURRENT_BUNDLE).Append(".value = bundleID;\n")
			.Append("		var myInputArgument = '';\n")
			.Append("  	if (myInput.value != '') {\n")
			.Append("    		myInputArgument = '&").Append(ASConstants.SPACEID)
			.Append("=' + myInput.value;\n").Append("  	}\n")
			.Append("    	window.open('").Append(myNewSelector.GetURLAsString())
			.Append("&").Append(ASConstants.SUBSPACE).Append("=")
			.Append(PortletSelectionModelHelper.SUBSPACE_NAME_PORTLETSINBUNDLE)
			.Append("' + bundleID + '").Append("&")
			.Append(ObjectSelectionRepostControl.strPARENT_FORM_SPACE_ID)
			.Append("=").Append(HTMLINPUT_BUNDLE_ASID_PREFIX)
			.Append("' + bundleID + '").Append("&")
			.Append(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID)
			.Append("=' + bundleID + myInputArgument")
			.Append(", 'Bundle', 'location=no,menubar=no,height=600,width=600,resizable=yes,scrollbars=yes');\n")
			.Append("}\n");

			script.AddInnerHTMLString(sb.ToString());

			// On return from Tree function
			sb = new XPStringBuilder(200);
			sb.Append("function ")
			.Append(JAVASCRIPT_ONRETURN_ADDPORTLETS_FROMBUNDLE).Append("()\n");
			sb.Append("{\n");
			sb.Append(" 	postToSelf('")
			.Append(ObjectSelectionRepostControl.POSTTOSELF_ACTION_ADDPORTLETS_FROMBUNDLE)
			.Append("');\n");
			sb.Append("}\n");

			script.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascriptCollection: Failed to add javascript function " +
					JAVASCRIPT_OPEN_BUNDLE + " to javscript collection. " +
					he.getMessage());
			
		}

		try
		{
			sb = new XPStringBuilder(200);

			sb.Append("\n").Append("function ").Append(JAVASCRIPT_SELECT_BUNDLE)
			.Append("(bundleID)\n").Append("{\n").Append("		document.")
			.Append(AFormDP.HTMLFORM_NAME).Append(".")
			.Append(HTMLINPUT_SELECT_BUNDLE).Append(".value = bundleID;\n")
			.Append("		postToSelf('")
			.Append(ObjectSelectionRepostControl.POSTTOSELF_ACTION_SELECT_BUNDLE)
			.Append("');\n").Append("}\n");

			script.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascriptCollection: Failed to add javascript function " +
					JAVASCRIPT_SELECT_BUNDLE + " to javscript collection. " +
					he.getMessage());
			
		}

		return collection;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayObject(int, HTMLTable, IObjectModelRO, AActivitySpace)
	 */
	public void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace asOwner)
	{
		HTMLBr br = new HTMLBr();

		HTMLTableRow row;
		HTMLTableCell cell;

		int iObjectID  = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_OBJECTID));
		String strObjectID = XPConvert.ToString(iObjectID);

		String strObjectName = (String) model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_NAME);

		try
		{
			row = new HTMLTableRow();
			tableObjects.AddInnerHTMLElement(row);

			if ((nRowIndex % 2) != 0)
			{
				row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
			}
			else
			{
				row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			}

			// Input selector for object
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("20");
			cell.SetVAlign(CommonHTMLStrings.TOP);
			cell.SetAlign(CommonHTMLStrings.CENTER);

			HTMLInput inputSelector = new HTMLInput(HTMLInputTypes.BUTTON,
					HTMLINPUT_SELECTION_OBJECT, "");
			cell.AddInnerHTMLElement(inputSelector);
			inputSelector.SetValue(asOwner.GetString(1273, "ptmsgs_portalbrowsingmsgs"));

			inputSelector.SetTitle(XPResourceManager.FormatMessage(
					asOwner.GetString(707, "ptmsgs_portalbrowsingmsgs"),
					XPHttpUtility.HtmlEncode(strObjectName)));
			inputSelector.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			inputSelector.SetOnClick(JAVASCRIPT_SELECT_BUNDLE +	// mj: removed 'Javascript:' from function name
				"('" + strObjectID + "');");

			// Object Image
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("23");
			cell.SetVAlign(CommonHTMLStrings.TOP);
			cell.SetAlign(CommonHTMLStrings.CENTER);

			HTMLImg img = null;

			try
			{
				PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_PORTLET_BUNDLE);
				img = (HTMLImg) myConstruct.GetHTMLElement();

				img.SetAlt(asOwner.GetString(708, "ptmsgs_portalbrowsingmsgs"));
			}
			catch (Exception e)
			{
				
					log.Error(e, "Display Object: Failed to create image. " +
						e.getMessage());
				
			}

			cell.AddInnerHTMLElement(img);

			// Object Name
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);

			HTMLAnchor openBundleAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strObjectName),
					JAVASCRIPT_OPEN_BUNDLE + "(document." +
					AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_BUNDLE_ASID_PREFIX +
					strObjectID + ", '" + strObjectID + "')");
			cell.AddInnerHTMLElement(openBundleAnchor);
			openBundleAnchor.SetTitle(asOwner.GetString(710,
					"ptmsgs_portalbrowsingmsgs"));

			Object oDescription = model.GetObjectFields(nObjectIndex,
					PT_PROPIDS.PT_PROPID_DESCRIPTION);

			if (null != oDescription)
			{
				if (!"".equals(oDescription))
				{
					cell.AddInnerHTMLElement(br);
	
					// Object Description
					cell.AddInnerHTMLEncodedString((String)oDescription);
				}
			}

			// Hidden Input for Portlet Bundle AS ID
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLINPUT_BUNDLE_ASID_PREFIX + strObjectID, "");
			cell.AddInnerHTMLElement(myInput);
			myInput.SetValue(((IObjectSelectionModelRO) model).GetInputValue(HTMLINPUT_BUNDLE_ASID_PREFIX +
					strObjectID));
		}
		catch (HTMLException e)
		{
			
				log.Error(e, "Portlet Bundle " + strObjectID + " failed to display: " +
					e.getMessage());
			
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#SetExpandButton(HTMLAnchor, IObjectModelRO)
	 */
	public void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model)
	{
	}
}

