package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author dustina/michaeld
 */
public class CreatePortletActionBarView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.CreatePortletActionBarView");


	public static final String STR_MVC_CLASS_NAME = "CreatePortletActionBarView";

	/** Subspace Key for Creating a portlet */
	public static final String SUBSPACE_NAME_CREATEPORTLET = "CreatePortlet";
	protected AActivitySpace m_asOwner;
	protected IModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CreatePortletActionBarView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			PTConstruct construct = UIConstructFactory.GetConstruct( PTBannerType.FOLDER, true, this.m_asOwner );
			construct.ReplaceNestedElementsWithHTMLString( PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE),
				m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs") );

			PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct( PTButtonType.GO_UP, true, this.m_asOwner );
			myButtonConstruct.ReplaceNestedElementsWithHTMLString( PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE),
				m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs") );
			ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
			ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));
			HTMLAnchor myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement( PTButtonType.GO_UP.GetElementName(
				PTButtonType.ELEMENT_NAME_ID_ANCHOR) );
			myAnchor.SetHRef( CommonHTMLStrings.POUND_SYMBOL );
			myAnchor.SetOnClick(ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "('" + PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER + "');return false;");
			myAnchor.SetTitle(m_asOwner.GetString(1564, "ptmsgs_portalbrowsingmsgs"));

			construct.AddElementToNestedElement(
				PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
				myButtonConstruct.GetHTMLElement() );

			result.AddInnerHTMLElement(construct.GetHTMLElement());

			IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();
			if(ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_CREATE_PORTLETS))
			{
				construct = UIConstructFactory.GetConstruct( PTBannerType.OBJECT_ACTION_BAR, true, this.m_asOwner );
				
				//	Get a button construct
				myButtonConstruct = UIConstructFactory.GetConstruct( PTButtonType.CREATE_PORTLET, true, this.m_asOwner );
				myButtonConstruct.ReplaceNestedElementsWithHTMLString(
					PTButtonType.CREATE_PORTLET.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE), m_asOwner.GetString(711,
					"ptmsgs_portalbrowsingmsgs") + CommonHTMLStrings.SPACE );
				myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement( PTButtonType.CREATE_PORTLET.GetElementName(
					PTButtonType.ELEMENT_NAME_ID_ANCHOR) );
				myAnchor.SetHRef( CommonHTMLStrings.POUND_SYMBOL );
				myAnchor.SetOnClick("CreatePopUp();return false;");
				myAnchor.SetTitle(m_asOwner.GetString(711, "ptmsgs_portalbrowsingmsgs"));
	
				construct.AddElementToNestedElement( PTBannerType.OBJECT_ACTION_BAR.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
					myButtonConstruct.GetHTMLElement() );
	
				result.AddInnerHTMLElement(construct.GetHTMLElement());
			}

			result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
		}
		catch (Exception e)
		{
			
				log.Error(e, "CreatePortletActionBarView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(" ", e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		//ASURL myASURL;
		XPStringBuilder sb;
		ASURL myASURL;

		try
		{
			myASURL = new ASURL(m_asOwner);
			myASURL.SetLinkCreateNewSpace(PortMainPortletEditorAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			myASURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			myASURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				EditorStartControl.EDITOR_START_FLAG_CREATE);
			myASURL.SetSubSpaceKey(SUBSPACE_NAME_CREATEPORTLET);
			myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID,
				((IObjectSelectionModelRO) m_model).GetSelectorCommunityFolderID());
			myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER,
				true);
			myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
			myASURL.AddControlArgument(PTPortlets.PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY, true);

			sb = new XPStringBuilder(400);
			sb.Append("function CreatePopUp()\n");
			sb.Append("{\n");
			sb.Append("    window.open('").Append(myASURL.GetURLAsString())
			.Append("', 'PopUpCreateMode', 'location=no,menubar=no,scrollbars,height=600,width=800');\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException e)
		{
		}

		return myScript;
	}

	/***/
	/**
	 */
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Inits the Section with the read-only Model and the Activity Space.
	 *
	 * @param model
	 * @param parent
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model = model;

		try
		{
			m_asOwner = parent;
		}
		catch (Exception e)
		{
			
				log.Error(e, "CreatePortletActionBarView::Init Unable to cast the Object " +
					parent +
					" to AActivitySpace. The following exception occured: " +
					e.getMessage());
			

			// JF- No need to extract, this is an unexpected error.
			throw new XPException("Unable to cast the Object " + parent +
				" to AActivitySpace.", e);
		}
	}
}

