package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author michaeld
 */
public class MyCustomPortletsView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.MyCustomPortletsView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "MyCustomPortlets";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** Model */
	private IObjectSelectionModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MyCustomPortletsView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection collection = new HTMLElementCollection();
		HTMLElement result				 = collection;

		try
		{
			HTMLTable myTable = new HTMLTable();
			collection.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);

			HTMLTableRow myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetVAlign(CommonHTMLStrings.TOP);

			HTMLTableCell myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

			int folderID = m_asModel.GetSelectorCommunityFolderID();

			// Open folder URL
			HTMLAnchor myAnchor;
			if ( m_asOwner.GetAccessStyle() == AccessStyles.STANDARD )
			{
				myAnchor = ConstructStaticHelpers.GetJavascriptAnchor(m_asOwner.GetString(
							733, "ptmsgs_portalbrowsingmsgs"),
						ObjSelFolderViewHelper.JAVASCRIPT_OPEN_FOLDER + "('" +
						folderID + "')"); 
			} else {
				ASURL myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_OPENFOLDER);
				myAsurl.AddControlArgument(ObjSelFolderViewHelper.HTMLINPUT_OPENFOLDERID, folderID);
				myAnchor = new HTMLAnchor(myAsurl.GetURLAsString());
				myAnchor.AddInnerHTMLString(m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs"));				
			}

			// use list item construct
			UIListItem itemConstruct = new UIListItem(myAnchor, this.m_asOwner );
			itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_OPEN,
				"folder");
			itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

			// convert the construct to table
			HTMLTable folderTable = itemConstruct.GetItemAsTable();
			myCell.AddInnerHTMLElement(folderTable);
		}
		catch (HTMLException he)
		{
			log.Error(he, "Couldn't display " +
				m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs") +
				" folder.");
		}
		catch (Exception e)
		{
			log.Error(e, "Couldn't display " +
				m_asOwner.GetString(733, "ptmsgs_portalbrowsingmsgs") +
				" folder.");
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IObjectSelectionModelRO) model;
		m_asOwner     = parent;
	}
}

