package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author michaeld
 */
public class PortletInBundleSelectionModelHelper
	implements IObjectSelectionModelHelper
{
	/** Selected Info Array: Number of Columns */
	public static final int COL_GADGET_MAX = 2;

	/** Selected Info Array: Portlet Alignment Column */
	public static final int COL_GADGET_ALIGNMENT = 1;

	/** Header Array: Number of Columns for gadget */
	public static final int COL_HEADER_PORTLET_MAX = 4;

	/** Header Array: Number of Columns for bundle */
	public static final int COL_HEADER_BUNDLE_MAX = 2;

	/** Header Array: Checkbox Input Name */
	public static final int COL_HEADER_CB = 0;

	/** Header Array: Names */
	public static final int COL_HEADER_NAME = 1;

	/** Header Array: Portlet Size */
	public static final int COL_HEADER_SIZE = 2;

	/** Header Array: Invites */
	public static final int COL_HEADER_INVITE = 3;
	protected AActivitySpace m_asOwner;

	/**
	 * Creates a new PortletInBundleSelectionModelHelper object.
	 *
	 * @param asOwner 
	 */
	public PortletInBundleSelectionModelHelper(AActivitySpace asOwner)
	{
		m_asOwner = asOwner;
	}

	// don't let people instantiate this without an asOwner; it's needed for internationalization.
	private PortletInBundleSelectionModelHelper()
	{
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#AddFormInputsForEachObject(XPHashtable, IASQueryResult, int)
	 */
	public void AddFormInputsForEachObject(XPHashtable htFormData,
		IASQueryResult asqr, int nObjectViewIndex)
	{
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetDoNotShowObjectIDs(ObjectSelectionModel, int)
	 */
	public XPSortedDictionary GetDoNotShowObjectIDs(
		ObjectSelectionModel model, int nObjectViewIndex)
	{
		XPSortedDictionary xpsd = new XPSortedDictionary();

		if ( model.IsHomeMyPage() )
		{
			IPTQueryResult ptqr = model.GetPTSession().GetMyPages()
				.QueryMandatoryGadgets();
			int nCount		    = ptqr.RowCount();

			for (int i = 0; i < nCount; i++)
			{
				xpsd.PutElement(ptqr.ItemAsObject(i, PT_PROPIDS.PT_PROPID_OBJECTID), "");
			}
		}

		return xpsd;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetHeaders(int)
	 */
	public String[] GetHeaders(int nObjectViewIndex)
	{
		if (m_asOwner.GetModelExists(ObjectSelectionModel.STR_MVC_CLASS_NAME))
		{
			IModel baseModel = m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
			// If this is the special portlet in bundle object selection model, ...
			if (XPStringUtility.CompareIgnoreCase(baseModel.GetName(),
				PortletInBundleObjectSelectionModel.STR_MVC_CLASS_NAME) == 0)
			{
				PortletInBundleObjectSelectionModel model = (PortletInBundleObjectSelectionModel) baseModel;
	
				if (model.GetSimpleMode())
				{
					// If we're in simple submit mode, don't display the checkbox column.
					String[] astrSimpleHeader = new String[COL_HEADER_PORTLET_MAX - 1];
					astrSimpleHeader[COL_HEADER_NAME - 1] = m_asOwner.GetString(737, "ptmsgs_portalbrowsingmsgs");
					astrSimpleHeader[COL_HEADER_SIZE - 1] = m_asOwner.GetString(738, "ptmsgs_portalbrowsingmsgs");
					astrSimpleHeader[COL_HEADER_INVITE - 1] = m_asOwner.GetString(739, "ptmsgs_portalbrowsingmsgs");
	
					return astrSimpleHeader;
				}
			}
		}
		String[] astrHeader = new String[COL_HEADER_PORTLET_MAX];
		astrHeader[COL_HEADER_CB]     = PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;

		astrHeader[COL_HEADER_NAME]     = m_asOwner.GetString(737,
				"ptmsgs_portalbrowsingmsgs");

		astrHeader[COL_HEADER_SIZE]     = m_asOwner.GetString(738,
				"ptmsgs_portalbrowsingmsgs");

		astrHeader[COL_HEADER_INVITE] = m_asOwner.GetString(739,
				"ptmsgs_portalbrowsingmsgs");

		return astrHeader;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetNumObjectViews()
	 */
	public int GetNumObjectViews()
	{
		return 1;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectBannerTitle(String, int)
	 */
	public String GetObjectBannerTitle(String strCurrentFolderName,
		int nObjectViewIndex)
	{
		return XPResourceManager.FormatMessage(m_asOwner.GetString(736,
				"ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strCurrentFolderName));
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectInputName(int)
	 */
	public String GetObjectInputName(int nObjectViewIndex)
	{
		return PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectMan(IPTSession, int)
	 */
	public IPTObjectManager GetObjectMan(IPTSession ptSession,
		int nObjectViewIndex)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjectType(int)
	 */
	public int GetObjectType(int nObjectViewIndex)
	{
		return -PT_CLASSIDS.PT_GADGET_ID;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetObjects(IPTSession, IPTAdminFolder)
	 */
	public IASQueryResult GetObjects(IPTSession ptSession,
		IPTAdminFolder ptFolder)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetPropIDsToQuery(int)
	 */
	public int GetPropIDsToQuery(int nObjectViewIndex)
	{
		return 0;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetQueryFilter(ObjectSelectionModel, int)
	 */
	public Object[][] GetQueryFilter(ObjectSelectionModel model,
		int nObjectViewIndex)
	{
		Object[][] ptqf;

		if (model.IsMyPage())
		{
			ptqf		   = new Object[3][5];
			ptqf[0][4]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);
			ptqf[1][4]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
			ptqf[2][4]     = new Integer(PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL);
		}
		else
		{
			ptqf = new Object[3][4];
		}

		ptqf[0][1]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
		ptqf[1][1]     = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		ptqf[2][1]     = new Integer(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER);
		ptqf[0][2]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
		ptqf[1][2]     = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		ptqf[2][2]     = new Integer(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER);
		ptqf[0][3]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
		ptqf[1][3]     = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
		ptqf[2][3]     = new Integer(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM);

		return ptqf;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetRedirectAfterFinish(ObjectSelectionModel)
	 */
	public Redirect GetRedirectAfterFinish(ObjectSelectionModel model)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSelectedInfo(int, IASQueryResult)
	 */
	public Object[] GetSelectedInfo(int nIndex, IASQueryResult asqr)
	{
		Object[] aoSelectedInfo = new Object[COL_GADGET_MAX];
		aoSelectedInfo[COL_GADGET_ALIGNMENT] = asqr.GetFields(nIndex,
				PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);

		return aoSelectedInfo;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSelectedObjects(ObjectSelectionModel)
	 */
	public Object[][] GetSelectedObjects(ObjectSelectionModel model)
	{
		XPSortedDictionary xpsdGadgets;
		Object[][] aoGadgets;

		ASCache myCache			   = (ASCache) m_asOwner.GetSubSession()
			.GetAttribute(ASConstants.SANDBOXASCACHE);
		AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
			m_asOwner.GetParentSpaceID());

		boolean bSimple = false;
		// If this is the special portlet in bundle object selection model
		if (XPStringUtility.CompareIgnoreCase(model.GetName(), PortletInBundleObjectSelectionModel.STR_MVC_CLASS_NAME) == 0)
		{
			bSimple = ((PortletInBundleObjectSelectionModel) model).GetSimpleMode();
		}

		if (bSimple)
		{
			// In simple mode, this model is called from the flyout space, which isn't an
			// object selection space (even though it looks like one), so we can't
			// get the parent object selection model.
			xpsdGadgets = new XPSortedDictionary();
		} else
		{
			ObjectSelectionModel parentModel = (ObjectSelectionModel) parentSpace.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
			xpsdGadgets	= parentModel.GetSelectedObjectsForParent();
		}

		aoGadgets = GetGadgetIDsInIntegerArray(xpsdGadgets);

		return aoGadgets;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetShouldSavePage()
	 */
	public boolean GetShouldSavePage()
	{
		return true;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#InitializeFormInputs(XPHashtable)
	 */
	public void InitializeFormInputs(XPHashtable htFormData)
	{
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#SetSelectedObjects(ObjectSelectionModel, XPSortedDictionary, XPSortedDictionary)
	 */
	public void SetSelectedObjects(ObjectSelectionModel model,
		XPSortedDictionary xpsdOldSelectedObjects,
		XPSortedDictionary xpsdNewSelectedObjects)
	{
	}

	/**
	 * Method GetGadgetIDsInIntegerArray.
	 * Puts the object id and info of each item in the query in the Object array
	 *
	 * @param xpsdGadgets
	 * @return Object[][]
	 */
	private Object[][] GetGadgetIDsInIntegerArray(
		XPSortedDictionary xpsdGadgets)
	{
		Object[][] aoGadgets = new Object[xpsdGadgets.GetSize()][ObjectSelectionModel.COL_OBJECT_MAX];

		IXPEnumerator xpeKeys = xpsdGadgets.GetKeys();

		int i = 0;

		while (xpeKeys.MoveNext())
		{
			// Get Portlet ID
			aoGadgets[i][ObjectSelectionModel.COL_OBJECT_ID]     = new Integer(XPConvert.ToInteger((String) xpeKeys.GetCurrent()));

			// Get Portlet Info
			aoGadgets[i][ObjectSelectionModel.COL_OBJECT_INFO] = xpsdGadgets.GetElement(xpeKeys.GetCurrent());

			i++;
		}

		return aoGadgets;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetStartInSearch()
	 */
	public boolean GetStartInSearch()
	{
		return false;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSearchHeaderTitle()
	 */
	public String GetSearchHeaderTitle()
	{
		return "";
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#Get508SearchStringMsgIndex(int)
	 */
	public int Get508SearchStringMsgIndex(int nSearch508StringIndex)
	{
		return 0;
	}
}