package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author MichaelD
 */
public class PortletSelGroupedResults508ViewHelper implements IGroupedResultsViewHelper
{
	protected AActivitySpace m_asOwner = null;
	protected ISearchResultModelRO m_model = null;
	protected GroupedResultsView m_view = null;

	protected static final String CELL_HEIGHT     = "25";
	protected static final String LOW_CELL_HEIGHT = "20";

	protected XPDateFormat m_dateFormat = null;

	  /* i had to remove final from the declaration above and move it into the
	   * constructor in order to get the JUMP to .NET process to work correctly.
	   * If this is a big problem for you, please, let me know and we will figure
	   * something out.
	   * 		-- moose
	   */
	  public PortletSelGroupedResults508ViewHelper()
	  {
	  }

	public void Init(AActivitySpace _owner,
					 ISearchResultModelRO _model,
					 GroupedResultsView _view) {
	  m_asOwner = _owner;
	  m_model = _model;
	  m_view = _view;

	  m_dateFormat = _model.GetDateFormat(m_asOwner);
	}

	/**
	 *  Helper method to format path string in a friendly way
	 */
	public String formatPath(String path)
	{
	  final int MAX_LENGTH = 100;
	  int len         = path.length();

	  if (len < MAX_LENGTH)
	  {
		return path;
	  }
	  return "... " + path.substring(len - MAX_LENGTH);
	}

	/**
	 *  Helper method to format size string in a friendly way
	 */
	public String formatSize(int sizeInBytes)
	{
	  if (sizeInBytes < 500)
	  {
		return XPConvert.ToString(sizeInBytes);
	  }

	  double kb = sizeInBytes / 1024;

	  if (kb < 500)
	  {
		kb = ((int) (kb * 10)) / 10;

		return XPResourceManager.FormatMessage(m_asOwner.GetString(833,
			"ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(kb));
	  }

	  double mb = kb / 1024;

	  mb = ((int) (mb * 10)) / 10;

	  return XPResourceManager.FormatMessage(m_asOwner.GetString(834,
		  "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(mb));
	}

	/**
	 *  Returns javascript for the view.
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 *  Returns the element that all other elements will be added to,
	 *  such as an HTMLTable.  If null is returned, a generic
	 *  HTMLElementCollection will be used.
	 */
	public HTMLElement DisplayCollection()
	{

		// If no results were returned, don't display anything.
		if (0 == m_model.GetTotalItems()) {
		  return null;
		}

		// Finally, construct the table in which the results will go
		HTMLTable resultTable = new HTMLTable();

		resultTable.SetCellSpacing("2");
		resultTable.SetCellPadding("3");
		resultTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

		return resultTable;
	}

	/**
	 *  Returns an element that will appear before all results, whether
	 *  or not the results are grouped.
	 */
	public HTMLElement DisplayHeader()
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns an element that will appear after all results regardless
	 *  of whether the results are grouped.
	 */
	public HTMLElement DisplayFooter()
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns the header element (e.g. an HTMLTableRow containing column
	 *  headings) that will be used if the results are not grouped.  Not called
	 *  if the results are grouped.
	 */
	public HTMLElement DisplayHeaderIfUngrouped()
	{
		// Not needed
		return null;
	}

	/**
	 *  Returns an element that will appear after all results if the results
	 *  are not grouped.  Not called if the results are grouped.
	 */
	public HTMLElement DisplayFooterIfUngrouped()
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns the header element (e.g. an HTMLTableRow containing column
	 *  headings) that will be used if the results are grouped.  Not called
	 *  if the results are ungrouped.
	 */
	public HTMLElement DisplayGroupHeader(int groupNum)
	{
		return m_view.DisplayStandardGroupHeaderRow(groupNum, CELL_HEIGHT, "2", true);
	}

	/**
	 *  Returns an element that will appear after all results in a single group.
	 *  Not called if the results are ungrouped.
	 */
	public HTMLElement DisplayGroupFooter(int groupNum)
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns the header element (e.g. an HTMLTableRow) headings) for a single
	 *  search result.
	 */
	public HTMLElement DisplaySingleResult(int _nResultIndex, boolean oddRow, int groupNum) 
	{
		boolean b508Portlet = false;

		String strUserInterfaces = m_model.GetResultPortletField(_nResultIndex, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_USER_INTERFACES);
		String strDisplayInterfaces = "";
		if (null != strUserInterfaces)
		{
			if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_508_USER_INTERFACE))
			{
				b508Portlet = true;
				if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_WML_USER_INTERFACE))
				{
					strDisplayInterfaces = m_asOwner.GetString(1644, "ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					strDisplayInterfaces = m_asOwner.GetString(1645, "ptmsgs_portalbrowsingmsgs");
				}
			}
			else if ((m_asOwner.GetAccessStyle() != AccessStyles.SECTION_508) && (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_WML_USER_INTERFACE)))
			{
				strDisplayInterfaces = m_asOwner.GetString(1646, "ptmsgs_portalbrowsingmsgs");
			}
		}

		HTMLBr br = new HTMLBr();

		int nObjectID = m_model.GetResultObjectID(_nResultIndex);
		int nClassID = m_model.GetResultClassID(_nResultIndex);
		String strObjectName    = m_model.GetResultName(_nResultIndex);

		HTMLTableRow row = new HTMLTableRow();

		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

		if (m_asOwner.GetAccessStyle() == AccessStyles.SECTION_508 && !b508Portlet && PT_CLASSIDS.PT_GADGET_ID == nClassID)
		{
			cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1632, "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strObjectName)));
		}
		else
		{
			if (("").equals(strDisplayInterfaces))
			{
				HTMLB bold = new HTMLB();
				bold.AddInnerHTMLEncodedString(strObjectName);
				cell.AddInnerHTMLElement(bold);
			}
			else
			{
				cell.AddInnerHTMLString(XPResourceManager.FormatMessage(strDisplayInterfaces, XPHttpUtility.HtmlEncode(strObjectName)));
			}
	
			cell.AddInnerHTMLElement(br);
	
			// Add the keyword-in-context (KWIC) information to the same cell
			String kwic = m_model.GetKWIC(_nResultIndex);
	
			if ((null != kwic) && (0 != kwic.length()))
			{
				cell.AddInnerHTMLString(kwic);
				cell.AddInnerHTMLElement(br);
			}
			
			// Last modified date
			cell.AddInnerHTMLString(m_asOwner.GetString(826,
				"ptmsgs_portalbrowsingmsgs") + ": " + m_dateFormat.Format(m_model.GetResultLastModified(_nResultIndex)));
			cell.AddInnerHTMLElement(br);
	
			ASURL myAsurl;
			if (PT_CLASSIDS.PT_GADGETBUNDLE_ID != nClassID)
			{
				if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetIsObjectSelected(nObjectID))
				{
					if(((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).DoNotShowObjectWithID(nObjectID))
					{
						cell.AddInnerHTMLString(m_asOwner.GetString(1660, "ptmsgs_portalbrowsingmsgs"));	
					} else {
						myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_508_ACTION_REMOVEOBJECT);
						myAsurl.AddControlArgument(PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT, nObjectID);
						myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1278, "ptmsgs_portalbrowsingmsgs"), 
							XPHttpUtility.HtmlEncode(strObjectName)));
						cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
					}
				}
				else
				{
					myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_508_ACTION_ADDOBJECT);
					myAsurl.AddControlArgument(PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
						nObjectID);
					myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1277, "ptmsgs_portalbrowsingmsgs"), 
						XPHttpUtility.HtmlEncode(strObjectName)));
					cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
				}
			}
			else
			{
				myAsurl = ((AFormDP) m_asOwner.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_ACTION_SELECT_BUNDLE);
				myAsurl.AddControlArgument(BundleSelectionViewHelper.HTMLINPUT_SELECT_BUNDLE, nObjectID);
				myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1272, "ptmsgs_portalbrowsingmsgs"), 
					XPHttpUtility.HtmlEncode(strObjectName)));
				cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
			}
		}

		cell.AddInnerHTMLElement(br);
		cell.AddInnerHTMLElement(br);

		return row;
	}
	
	/*
	 * Called before a set of results is displayed.
	 * 
	 * @see com.plumtree.portaluiinfrastructure.search.IGroupedResultsViewHelper#InitDisplayResults()
	 */
	public void InitDisplayResults()
	{
	}

}

