package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * @author MichaelD
 */
public class PortletSelGroupedResultsViewHelper implements IGroupedResultsViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelGroupedResultsViewHelper");

	protected AActivitySpace m_asOwner = null;
	protected ISearchResultModelRO m_model = null;
	protected GroupedResultsView m_view = null;

	protected static final String CELL_HEIGHT     = "25";
	protected static final String LOW_CELL_HEIGHT = "20";

	private int _groupsDisplayed = 0;

	protected XPDateFormat m_dateFormat = null;

	  /* i had to remove final from the declaration above and move it into the
	   * constructor in order to get the JUMP to .NET process to work correctly.
	   * If this is a big problem for you, please, let me know and we will figure
	   * something out.
	   * 		-- moose
	   */
	  public PortletSelGroupedResultsViewHelper()
	  {
	  }

	public void Init(AActivitySpace _owner,
					 ISearchResultModelRO _model,
					 GroupedResultsView _view) {
	  m_asOwner = _owner;
	  m_model = _model;
	  m_view = _view;

    m_dateFormat = _model.GetDateFormat(m_asOwner);
	}

	/**
	 *  Helper method to format path string in a friendly way
	 */
	public String formatPath(String path)
	{
	  final int MAX_LENGTH = 100;
	  int len         = path.length();

	  if (len < MAX_LENGTH)
	  {
		return path;
	  }
	  return "... " + path.substring(len - MAX_LENGTH);
	}

	/**
	 *  Helper method to format size string in a friendly way
	 */
	public String formatSize(int sizeInBytes)
	{
	  if (sizeInBytes < 500)
	  {
		return XPConvert.ToString(sizeInBytes);
	  }

	  double kb = sizeInBytes / 1024;

	  if (kb < 500)
	  {
		kb = ((int) (kb * 10)) / 10;

		return XPResourceManager.FormatMessage(m_asOwner.GetString(833,
			"ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(kb));
	  }

	  double mb = kb / 1024;

	  mb = ((int) (mb * 10)) / 10;

	  return XPResourceManager.FormatMessage(m_asOwner.GetString(834,
		  "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(mb));
	}

	/**
	 *  Returns javascript for the view.
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append("function ")
		  .Append(ReorganizationViewHelper.JAVASCRIPT_RESORT)
		  .Append("() {")
		  .Append(AFormDP.JAVASCRIPT_SUBMIT_TO_CONTROL)
		  .Append("(\"")
		  .Append(ReorganizationControl.STR_MVC_CLASS_NAME)
		  .Append("\",\"")
		  .Append(SearchResultControl.KEY_DATA)
		  .Append("=")
		  .Append(m_model.GetCurrentKey())
		  .Append("\"); }");

		try
		{
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript: Failed to add '" +
				ReorganizationViewHelper.JAVASCRIPT_RESORT +
					"' javscript function to the page. " +
					he.getMessage());
			
		}
		return myScript;
	}

	/**
	 *  Returns the element that all other elements will be added to,
	 *  such as an HTMLTable.  If null is returned, a generic
	 *  HTMLElementCollection will be used.
	 */
	public HTMLElement DisplayCollection()
	{

	  // If no results were returned, don't display anything.
	  if (0 == m_model.GetTotalItems()) {
		return null;
	  }

	  // Initialize some member variables..

	  _groupsDisplayed = 0;

	  // Finally, construct the table in which the results will go
	  HTMLTable resultTable = new HTMLTable();

	  resultTable.SetCellSpacing("2");
	  resultTable.SetCellPadding("3");
	  resultTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

	  return resultTable;
	}

	/**
	 *  Returns an element that will appear before all results, whether
	 *  or not the results are grouped.
	 */
	public HTMLElement DisplayHeader()
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns an element that will appear after all results regardless
	 *  of whether the results are grouped.
	 */
	public HTMLElement DisplayFooter()
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns the header element (e.g. an HTMLTableRow containing column
	 *  headings) that will be used if the results are not grouped.  Not called
	 *  if the results are grouped.
	 */
	public HTMLElement DisplayHeaderIfUngrouped()
	{
	  return GetHeaderRow();
	}

	/**
	 *  Returns an element that will appear after all results if the results
	 *  are not grouped.  Not called if the results are grouped.
	 */
	public HTMLElement DisplayFooterIfUngrouped()
	 {
	  // Not needed
	  return null;
	}

	/**
	 *  Returns the header element (e.g. an HTMLTableRow containing column
	 *  headings) that will be used if the results are grouped.  Not called
	 *  if the results are ungrouped.
	 */
	public HTMLElement DisplayGroupHeader(int groupNum)
	{

	  HTMLElement he = m_view.DisplayStandardGroupHeaderRow(groupNum,
														   CELL_HEIGHT,
														   ("6"), true);

	  if (null == he) {
		// Nothing in this group
		return null;
	  }

	  HTMLElementCollection c = new HTMLElementCollection();

	  {
		// Add a blank row to separate groups

		HTMLTableRow row = new HTMLTableRow();
		HTMLTableCell cell = new HTMLTableCell();
		cell.SetColSpan("6");
		if (0 == _groupsDisplayed) {
		  cell.SetHeight("5");
		} else {
		  cell.SetHeight("15");
		}
		row.AddInnerHTMLElement(cell);
		c.AddInnerHTMLElement(row);
	  }

	  c.AddInnerHTMLElement(he);

	  // Add the column headings for this group too
	  c.AddInnerHTMLElement(GetHeaderRow());

	  _groupsDisplayed += 1;

	  return c;
	}

	/**
	 *  Returns an element that will appear after all results in a single group.
	 *  Not called if the results are ungrouped.
	 */
	public HTMLElement DisplayGroupFooter(int groupNum)
	{
	  // Not needed
	  return null;
	}

	/**
	 *  Returns the header element (e.g. an HTMLTableRow) headings) for a single
	 *  search result.
	 */
	public HTMLElement DisplaySingleResult(int _nResultIndex, boolean oddRow, int groupNum) 
	{
		HTMLSpan span;

	  // Create a table row
	  HTMLTableRow row = new HTMLTableRow();

	  if (oddRow)
	  {
		row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
	  }
	  else
	  {
		row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
	  }

	  int nObjectID = m_model.GetResultObjectID(_nResultIndex);
	  int nClassID = m_model.GetResultClassID(_nResultIndex);
	  String strObjectName    = m_model.GetResultName(_nResultIndex);

	  // Add cells for the checkbox, type, name, last-modified, size, and action list
	  
	  // checkbox
	  HTMLTableCell cell = new HTMLTableCell();
	  row.AddInnerHTMLElement(cell);
	  cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	  cell.SetWidth("20");
	  cell.SetHeight(CELL_HEIGHT);
	  cell.SetVAlign(CommonHTMLStrings.TOP);
	  cell.SetAlign(CommonHTMLStrings.CENTER);

	  HTMLInput inputSelector;
	if (PT_CLASSIDS.PT_GADGETBUNDLE_ID != nClassID)
	{
		inputSelector = new HTMLInput(HTMLInputTypes.CHECKBOX,
				PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
				XPResourceManager.FormatMessage(m_asOwner.GetString(726,
						"ptmsgs_portalbrowsingmsgs"), strObjectName));
		inputSelector.SetValue(XPConvert.ToString(_nResultIndex));
//		DCA - onclick for updating the bottom frame
		inputSelector.SetOnClick(SelectedObjectsView.JAVASCRIPT_ADD_SELECTED + "(this); return true;");
						
		if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetIsObjectSelected(nObjectID))
		{
			inputSelector.SetChecked(true);
		}
		if (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).DoNotShowObjectWithID(nObjectID))
		{
			inputSelector.SetDisabled(true);
		}
	}
	else
	{
		  inputSelector = new HTMLInput(HTMLInputTypes.BUTTON,
				BundleSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT, 
				XPResourceManager.FormatMessage(m_asOwner.GetString(707, 
						"ptmsgs_portalbrowsingmsgs"), strObjectName));
		  inputSelector.SetValue(m_asOwner.GetString(1273, "ptmsgs_portalbrowsingmsgs"));

		  inputSelector.SetTitle(XPResourceManager.FormatMessage(
				m_asOwner.GetString(707, "ptmsgs_portalbrowsingmsgs"),
				  strObjectName));
		  inputSelector.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
		  inputSelector.SetOnClick(BundleSelectionViewHelper.JAVASCRIPT_SELECT_BUNDLE +	// mj: removed 'Javascript:' from function name
			  "('" + nObjectID + "');");
	}
	BrowserType browser = (BrowserType) m_asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
	if(browser.IsNetscape4() && (((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).DoNotShowObjectWithID(nObjectID)))
	{
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	} else {
		cell.AddInnerHTMLElement(inputSelector);
	}

	  // type icon
	  cell = new HTMLTableCell();
	  cell.SetWidth("20");
	  cell.SetAlign(CommonHTMLStrings.CENTER);
	  cell.SetVAlign(CommonHTMLStrings.MIDDLE);
	  row.AddInnerHTMLElement(cell);

	  HTMLImg icon = null;
	  String strUserInterfaces = m_model.GetResultPortletField(_nResultIndex, PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_USER_INTERFACES);
	  if (null != strUserInterfaces)
	  {
		  if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_508_USER_INTERFACE))
		  {
			  PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_508);
			icon = (HTMLImg) myConstruct.GetHTMLElement();
	
			  if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_WML_USER_INTERFACE))
			  {
				icon.SetAlt(m_asOwner.GetString(1641, "ptmsgs_portalbrowsingmsgs"));
			  }
			  else
			  {
				icon.SetAlt(m_asOwner.GetString(1642, "ptmsgs_portalbrowsingmsgs"));
			  }
			cell.AddInnerHTMLElement(icon);
		  }
		  else if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_WML_USER_INTERFACE))
		  {
			  PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_DEVICE);
			icon = (HTMLImg) myConstruct.GetHTMLElement();
	
			icon.SetAlt(m_asOwner.GetString(1643, "ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(icon);
		  }
		  else
		  {
			icon = (HTMLImg) m_model.GetResultIcon(_nResultIndex);

			if (null != icon)
			{
			  icon.SetWidth("20");
			  icon.SetHeight("20");
			  icon.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			  icon.SetBorder(CommonHTMLStrings.ZERO);
			  cell.AddInnerHTMLElement(icon);
			}
			else
			{
			  cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			}
		  }
	  }
	  else
	  {
		icon = (HTMLImg) m_model.GetResultIcon(_nResultIndex);

		if (null != icon)
		{
		  icon.SetWidth("20");
		  icon.SetHeight("20");
		  icon.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		  icon.SetBorder(CommonHTMLStrings.ZERO);
		  cell.AddInnerHTMLElement(icon);
		}
		else
		{
		  cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}
	  }

	  // name
	  cell = new HTMLTableCell();
	  cell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
	  cell.SetWidth("100%");

	  //    cell.SetNoWrap(true);
	  row.AddInnerHTMLElement(cell);

		String strGadgetType = m_model.GetResultPortletField(_nResultIndex,
			PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_TYPE);
		int nGadgetType;
		if (!("").equals(strGadgetType))
		{
			nGadgetType = XPConvert.ToInteger(strGadgetType);
		}
		else
		{
			nGadgetType = PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL;
		}

		String strGadgetAlignment = m_model.GetResultPortletField(_nResultIndex,
			PT_SEARCH_INTERNAL_FIELD.PT_SEARCH_IF_GADGET_ALIGNMENT);
		int nGadgetAlignment;
		if (!("").equals(strGadgetAlignment))
		{
			nGadgetAlignment = XPConvert.ToInteger(strGadgetAlignment);
		}
		else
		{
			nGadgetAlignment = 0;
		}
		
		// Make a clickthru URL.
	  if (PT_CLASSIDS.PT_GADGETBUNDLE_ID != nClassID)
	  {
	  	if (nGadgetType != PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY)
	  	{
		  HTMLAnchor previewGadgetAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strObjectName),
				  PortletSelectionViewHelper.JAVASCRIPT_PREVIEW_GADGET + "('" + nObjectID +
				  "', '" + nGadgetAlignment + "', '" + _nResultIndex +
				  "')");
		  cell.AddInnerHTMLElement(previewGadgetAnchor);

		  previewGadgetAnchor.SetTitle(m_asOwner.GetString(732,
				  "ptmsgs_portalbrowsingmsgs"));
		}
		else
		{
			cell.AddInnerHTMLEncodedString(strObjectName);
		}
	  }
	  else
	  {
		HTMLAnchor openBundleAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strObjectName),
				BundleSelectionViewHelper.JAVASCRIPT_OPEN_BUNDLE + "(document." +
				AFormDP.HTMLFORM_NAME + "." + BundleSelectionViewHelper.HTMLINPUT_BUNDLE_ASID_PREFIX +
				nObjectID + ", '" + nObjectID + "')");
		cell.AddInnerHTMLElement(openBundleAnchor);
		openBundleAnchor.SetTitle(m_asOwner.GetString(710,
				"ptmsgs_portalbrowsingmsgs"));

		// Hidden Input for Portlet Bundle AS ID
		HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
			BundleSelectionViewHelper.HTMLINPUT_BUNDLE_ASID_PREFIX + nObjectID, "");
		cell.AddInnerHTMLElement(myInput);
		myInput.SetValue(((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME))
			.GetInputValue(BundleSelectionViewHelper.HTMLINPUT_BUNDLE_ASID_PREFIX + nObjectID));
	  }

	  // Add the keyword-in-context (KWIC) information to the same cell
	  String kwic = m_model.GetKWIC(_nResultIndex);

	  if ((null != kwic) && (0 != kwic.length()))
	  {

		cell.AddInnerHTMLElement(new HTMLBr());

		span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.LIST_TEXT);

		// Note that the Search server htmlencodes the KWIC for us
		span.AddInnerHTMLString(kwic);

		cell.AddInnerHTMLElement(span);
	  }

	  // Get Portlet Alignment
	  String strGadgetSize;

	if (PT_CLASSIDS.PT_GADGETBUNDLE_ID != nClassID)
	{
		// Hidden Inputs with Portlet information
		HTMLInput inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN,
			ObjectSelectionModel.HTMLINPUT_HIDDEN_ID + _nResultIndex, "");
		inputHidden.SetValue(XPConvert.ToString(nObjectID));
		cell.AddInnerHTMLElement(inputHidden);
		inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN,
			ObjectSelectionModel.HTMLINPUT_HIDDEN_NAME + _nResultIndex, "");
		inputHidden.SetValue(XPHttpUtility.HtmlEncode(strObjectName));
		cell.AddInnerHTMLElement(inputHidden);
		inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN,
			ObjectSelectionModel.HTMLINPUT_HIDDEN_ALIGNMENT + _nResultIndex, "");
		inputHidden.SetValue(strGadgetAlignment);
		cell.AddInnerHTMLElement(inputHidden);
			
	  if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW == nGadgetAlignment)
	  {
		  strGadgetSize = m_asOwner.GetString(729,
				  "ptmsgs_portalbrowsingmsgs");
	  }
	  else
	  {
		  strGadgetSize = m_asOwner.GetString(730,
				  "ptmsgs_portalbrowsingmsgs");
	  }
	}
	else
	{
		strGadgetSize = m_asOwner.GetString(1554,
			"ptmsgs_portalbrowsingmsgs");
	}

	  // Print Portlet Alignment
	  cell = new HTMLTableCell();
	  row.AddInnerHTMLElement(cell);
	  cell.SetVAlign(CommonHTMLStrings.MIDDLE);
	  cell.SetNoWrap(true);
	  cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	  cell.SetWidth("75");
	  cell.AddInnerHTMLString(strGadgetSize);

	  // modified date
	  cell = new HTMLTableCell();
	  cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	  cell.SetNoWrap(true);
	  cell.SetWidth("125");
	  row.AddInnerHTMLElement(cell);
	  cell.AddInnerHTMLString(m_dateFormat.Format(m_model.GetResultLastModified(
			_nResultIndex)));

		// Send to Others Link
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetWidth("20");
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetNoWrap(true);
		cell.SetStyleClass(PTStyleClass.LIST_TEXT);

		if (nGadgetType != PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY && PT_CLASSIDS.PT_GADGETBUNDLE_ID != nClassID)
		{
			HTMLAnchor sendToOthersAnchor = ConstructStaticHelpers.GetJavascriptAnchor("",
					PortletSelectionViewHelper.JAVASCRIPT_OPEN_INVITE + "('" + _nResultIndex + "')");
			cell.AddInnerHTMLElement(sendToOthersAnchor);

			sendToOthersAnchor.SetTitle(m_asOwner.GetString(731,
					"ptmsgs_portalbrowsingmsgs"));
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEND);
			HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();
			myImg.SetAlt(m_asOwner.GetString(731, "ptmsgs_portalbrowsingmsgs"));
			sendToOthersAnchor.AddInnerHTMLElement(myImg);
		}
		else
		{
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}

	  return row;
	}

	/**
	 *  Helper function, returns the standard column headings
	 */
	private HTMLTableRow GetHeaderRow() throws SearchModelException, HTMLException
	{
		// Column headers
		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
	
		// "Rank"
		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		cell.SetHeight(LOW_CELL_HEIGHT);
		cell.SetAlign(CommonHTMLStrings.CENTER);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		cell.SetColSpan("2");
		cell.AddInnerHTMLString(m_asOwner.GetString(825,
			"ptmsgs_portalbrowsingmsgs"));
	
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		cell.AddInnerHTMLString(m_asOwner.GetString(723,
			"ptmsgs_portalbrowsingmsgs"));
		
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		cell.AddInnerHTMLString(m_asOwner.GetString(826,
			"ptmsgs_portalbrowsingmsgs"));
		
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		
		PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_ARROW_DESCEND,
				true, m_asOwner);
		HTMLImg myImage = (HTMLImg) myConstruct.GetHTMLElement();
		myImage.SetAlt(m_asOwner.GetString(288, "ptmsgs_portalbrowsingmsgs"));
		myImage.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		cell.AddInnerHTMLElement(myImage);
	
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	
		return row;
	}

	/* 
	 * Called before a set of results is displayed.
	 * 
	 * @see com.plumtree.portaluiinfrastructure.search.IGroupedResultsViewHelper#InitDisplayResults()
	 */
	public void InitDisplayResults()
	{
	}

}

