package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class PortletSelectionDP extends EditorDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionDP");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "GadgetSelectionTopFrame";

	/** Object Section Index: gadgets */
	public static final int GADGET_INDEX = 0;

	/** Object Section Index: bundles */
	public static final int BUNDLE_INDEX = 1;
	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(713, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()

	{
		if (!((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetDisplaySearch())
		{
			return HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1076,
						"ptmsgs_portalbrowsingmsgs"), this.m_asOwner);
		}
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for that Page.
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException 
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLElementCollection views  = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		ObjectSelectionModel model = ((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME));

		// Add a "search for gadgets" form
		views.AddInnerHTMLElement(m_asOwner.GetView(
				ObjSelSearchFormView.STR_MVC_CLASS_NAME).Display());
		
		views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
		
		if (!model.GetDisplaySearch())
		{
			if (model.IsCommunityPage())
			{
				if (1 >= model.GetCurrentFolderID())
				{
					// JHQ: Don't display on the userprofile community
					if (model.GetSelectorCommunityFolderID() != PT_INTRINSICS.PT_ADMIN_FOLDER_PROFILECOMMUNITY)
					{
						views.AddInnerHTMLElement(m_asOwner.GetView(
							MyCustomPortletsView.STR_MVC_CLASS_NAME).Display());
					}
				}
				else if (model.GetSelectorCommunityFolderID() == model.GetCurrentFolderID())
				{
					views.AddInnerHTMLElement(m_asOwner.GetView(
							CreatePortletActionBarView.STR_MVC_CLASS_NAME)
						.Display());
				}
				else
				{
					views.AddInnerHTMLElement(m_asOwner.GetView(
						ObjSelBreadCrumbView.STR_MVC_CLASS_NAME).Display());
					views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				}
			}
			else if (1 < model.GetCurrentFolderID())
			{
				views.AddInnerHTMLElement(m_asOwner.GetView(
					ObjSelBreadCrumbView.STR_MVC_CLASS_NAME).Display());
				views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
			}

			if (model.GetSelectorCommunityFolderID() != model.GetCurrentFolderID())
			{
				views.AddInnerHTMLElement(m_asOwner.GetView(
						FolderView.STR_MVC_CLASS_NAME).Display());
				views.AddInnerHTMLElement(EditorView.GetSpacerTable());
			}

			if (1 != model.GetCurrentFolderID())
			{
				if (model.GetSelectorCommunityFolderID() != model.GetCurrentFolderID())
				{
					model.SetObjectViewIndex(BUNDLE_INDEX);
					views.AddInnerHTMLElement(m_asOwner.GetView(
							PortletSelectionEditorAS.BUNDLE_VIEW).Display());
					views.AddInnerHTMLElement(EditorView.GetSpacerTable());
				}
				model.SetObjectViewIndex(GADGET_INDEX);
				views.AddInnerHTMLElement(m_asOwner.GetView(
						PortletSelectionEditorAS.GADGET_VIEW).Display());
				// DCA - javascript to check the check all box if all checkboxes are checked		
				views.AddInnerHTMLElement(
						((ObjectView) m_asOwner.GetView(PortletSelectionEditorAS.GADGET_VIEW)).GetCheckAllScript());
			}
		}
		else
		{
			views.AddInnerHTMLElement(m_asOwner.GetView(ObjSelSearchHeaderView.STR_MVC_CLASS_NAME).Display());
			views.AddInnerHTMLElement(HTMLConstructHelpers.GetSubHeader(m_asOwner.GetString(1076,
				"ptmsgs_portalbrowsingmsgs"), this.m_asOwner));
			views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());

			SearchResultModel searchModel = ((SearchResultModel) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME));
			SearchExecutionError error = searchModel.GetError();

			if (error == null)
			{
			    model.SetObjectViewIndex(GADGET_INDEX);

			    String myQueryText = ((ISearchResultModelRO) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME)).GetSearchString();
				// if somebody actually entered a search term then we want this
				// displayed. the first time the page is displayed we don't want it
                            if (null == myQueryText || myQueryText.equals("") || myQueryText.equals("*"))
				{
				    // don't show anything
				}
				else
				{
					    views.AddInnerHTMLElement(ReorganizationViewHelper.DisplayReorganization(
						        searchModel, m_asOwner, /*showCustomOptions=*/ false));
					    views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				    views.AddInnerHTMLElement(m_asOwner.GetView(SearchSummaryView.STR_MVC_CLASS_NAME).Display());
				}
				views.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				views.AddInnerHTMLElement(m_asOwner.GetView(
					GroupedResultsView.STR_MVC_CLASS_NAME).Display());
				if ((searchModel.GetNumDisplayableItems() < searchModel.GetTotalItems()) && (0 == searchModel.GetNumResultGroups()))
				{
				    views.AddInnerHTMLElement(m_asOwner.GetView(SearchFooterView.STR_MVC_CLASS_NAME).Display());
				}
				views.AddInnerHTMLElement(((ObjectView)m_asOwner.GetView(PortletSelectionEditorAS.BUNDLE_VIEW)).GetObjectViewHelper().AddObjectViewHTML(model));
			}
			else
			{
				HTMLSpan mySpan = new HTMLSpan();
				views.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
				mySpan.AddInnerHTMLString(error.GetMessage());
			}
		}

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement(m_asOwner.GetView(
				ObjectSelectionView.STR_MVC_CLASS_NAME).Display());

		result.AddInnerHTMLElement(CreateContentTable(views,
				null));

		model = null;

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection scripts		    = new HTMLScriptCollection();
		HTMLScript myScript;
		HTMLScriptCollection myScriptCollection;

		ObjectSelectionModel model = ((ObjectSelectionModel) m_asOwner.GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME));

		if (!model.GetDisplaySearch())
		{
			myScript = m_asOwner.GetView(CreatePortletActionBarView.STR_MVC_CLASS_NAME)
				.DisplayJavascript();
		
			if (null != myScript)
			{
				scripts.AddInnerHTMLElement(myScript);
			}
		}
		else if (((SearchResultModel) m_asOwner.GetModel(SearchResultModel.STR_MVC_CLASS_NAME)).IsInitialized())
		{
			myScript = m_asOwner.GetView(GroupedResultsView.STR_MVC_CLASS_NAME)
				.DisplayJavascript();

			if (null != myScript)
			{
				scripts.AddInnerHTMLElement(myScript);
			}
		}

		myScript = ((ObjSelFolderViewHelper) model.GetFolderViewHelper()).DisplayJavascript(m_asOwner);

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		myScript = m_asOwner.GetView(PortletSelectionEditorAS.GADGET_VIEW)
			.DisplayJavascript();

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		myScriptCollection = ((ObjectView) m_asOwner.GetView(PortletSelectionEditorAS.GADGET_VIEW)).DisplayJavascriptCollection();

		if (null != myScriptCollection)
		{
			scripts.AddInnerHTMLElement(myScriptCollection);
		}
		
		if (model.GetSelectorCommunityFolderID() != model.GetCurrentFolderID())
		{
			myScriptCollection = ((ObjectView) m_asOwner.GetView(PortletSelectionEditorAS.BUNDLE_VIEW)).DisplayJavascriptCollection();
		
			if (null != myScriptCollection)
			{
				scripts.AddInnerHTMLElement(myScriptCollection);
			}
		}

		myScript = m_asOwner.GetView(ObjSelSearchFormView.STR_MVC_CLASS_NAME)
			.DisplayJavascript();

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}

		myScript = m_asOwner.GetView(ObjectSelectionView.STR_MVC_CLASS_NAME)
			.DisplayJavascript();

		if (null != myScript)
		{
			scripts.AddInnerHTMLElement(myScript);
		}
		
		model = null;

		// Add javascript to automatically refresh the bottom pane
		XPStringBuilder sb = new XPStringBuilder(100);
		sb.Append("\n");

		// Only refresh if the bottom pane exists and has the refresh function
		sb.Append("if ((parent.").Append(FrameSetDP.BODY_FRAME)
		.Append(") && (parent.").Append(FrameSetDP.BODY_FRAME).Append(".")
		.Append(SelectedObjectsView.JAVASCRIPT_REFRESH).Append("))\n");
		sb.Append("  parent.").Append(FrameSetDP.BODY_FRAME).Append(".")
		.Append(SelectedObjectsView.JAVASCRIPT_REFRESH).Append("();\n");

		HTMLScript reloadScript = new HTMLScript("text/javaScript");

		try
		{
			reloadScript.AddInnerHTMLString(sb.ToString());
			scripts.AddInnerHTMLElement(reloadScript);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascript couldn't add reload javascript to the HTMLScript element.");
			
		}

		return scripts;
	}
}

