package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.impl.community.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;

/**
 * 
 *
 * @author michaeld
 */
public class PortletSelectionEditorAS extends PTEditorAS
	implements IObjectSelectionAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionEditorAS");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "GadgetSelection";

	/** Object Section: Gadgets */
	public static final String GADGET_VIEW = "GadgetView";
 
	/** Object Section: Bundles */
	public static final String BUNDLE_VIEW = "BundleView";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(java.lang.String, java.lang.String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		boolean bAccess = super.CheckBasicAccess(strPage, strControl, bSameSpace);

		// fix for bug 9033606 - caius
		XPHashtable myFormData = this.GetCurrentFormData();
		//-100 is an arbitrary number
		int selectorPageID = -100;
		if (myFormData.ContainsKey(
				ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORPAGEID)) {
			selectorPageID = XPConvert.ToInteger(((String[]) myFormData.GetElement(
					ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORPAGEID))[0]);
		}
		if (-100 != selectorPageID) {
			try {
				IPTSession userSession = (IPTSession)this.GetUserSession();
				boolean myReturnValue = false;
				PTPageManager myPageManager = (PTPageManager)userSession.GetPages();
				int adminFolderId = myPageManager.GetAdminFolderID(selectorPageID);
				// if the admin folder ID is negative it's a mypage so permissions aren't an issue here
				if (adminFolderId >= 0) {
					myReturnValue = userSession.GetPages().IsObjectAccessible(
							selectorPageID, 
							userSession.GetSessionInfo().GetCurrentUserID(),
							PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
					if (!myReturnValue) {
						return myReturnValue;
					}
				}
			} catch (XPException e) {
				// this exception isn't a problem but should be logged for debug purposes.
				log.Debug("Exception caught in 9033606 fix code");
				log.Error(e.GetMessage());
			}						
		}
		
		
		//RT- Bug 9033606 User can get Add Portlets Editor in different way
		// and it uses SelectorObjectID for Portlet selection, So we also need 
		// to check for SelectorObjectID access for the current user.
		if (myFormData.ContainsKey(
				ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID)) {
			try {
				int selectorObjectID = XPConvert.ToInteger(((String[]) myFormData.GetElement(
						ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID))[0]);
				log.Debug("Value of SelectorObjectID is :" + selectorObjectID);
				IPTSession userSession = (IPTSession)this.GetUserSession();
				
				PTPageManager myPageManager = (PTPageManager)userSession.GetPages();
				int adminFolderId = myPageManager.GetAdminFolderID(selectorObjectID);
				log.Debug("Value of Admin Folder ID is :" + adminFolderId);
				// If AdminFolderID is < 0 then it is a mypage
				if (adminFolderId >= 0) {
					boolean retVal = userSession.GetPages().IsObjectAccessible(
							selectorObjectID, 
							userSession.GetSessionInfo().GetCurrentUserID(),
							PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);					
					if(!retVal)
					{
						log.Debug("User does not have access to the Page with SelectorObjectID :" + selectorObjectID);
						return retVal;
					}
				}				
			} catch (XPException e) {
				// this exception isn't a problem but should be logged for debug purposes.
				log.Debug(e.GetMessage());
			}
		}
		
		// MJD- Otherwise make sure this is the refresh control. The access will be checked by those controls.
		if ((null != strControl) && (strControl.equals(RefreshObjSelControl.STR_MVC_CLASS_NAME)))
		{
			bAccess = true;
		}

		if ((null != strControl) && (strControl.equals(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME))) 
		{
			bAccess = true;	
		}
		
		if ((null != strControl) && (strControl.equals(InvitationPopupControl.STR_MVC_CLASS_NAME)))
		{
			bAccess = true;
		}
		
		return bAccess;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletSelectionEditorAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		return GetString(714, "ptmsgs_portalbrowsingmsgs") + ": " + ((PortletSelectionModelHelper)((ObjectSelectionModel)GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME)).GetSelectionModelHelper()).GetPageName((ObjectSelectionModel)GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME));
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetObjectBannerText()
	 */
	public String GetObjectBannerText()
	{
		return GetString(717, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetObjectBannerTitle()
	 */
	public String GetObjectBannerTitle()
	{
		return GetString(716, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (ObjectSelectionRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionAS#GetSearchPrompt()
	 */
	public String GetSearchPrompt()
	{
		return GetString(715, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#Init(IPTSession)
	 */
	public void Init()
	{
		log.Info("Initializing Portlet Selection Activity Space");

		// Portlet Selection Model
		m_strModelName = ObjectSelectionModel.STR_MVC_CLASS_NAME;

		super.Init();

		// Call IntegratedSearchAS.RegisterSearchClasses to register search stuff.
		IntegratedSearchAS.RegisterSearchClasses(this);

		// Get our instance of SearchResultModel; the views that display
		// results will need it.
		IModel searchModel = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);

		ObjectSelectionModel myModel = (ObjectSelectionModel) GetModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);
		myModel.SetSelectionModelHelper(new PortletSelectionModelHelper(this));
		myModel.SetShowFolderBanner(true);

		// Model has to be initialized in Init method because it requires PTSession.
		log.Info("Registered model");

		// Portlet Selection DisplayPages
		RegisterPage(new PortletSelectionDP());
		RegisterPage(new PortletSelectionDP_D());
		RegisterPage(new SelectedObjectsDP());
		RegisterPage(new ObjSelFrameSetDP());
		((ObjSelFrameSetDP)GetPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME))
			.SetupFrameSet(GetString(1276, "ptmsgs_portalbrowsingmsgs"),
			PortletSelectionDP.STR_MVC_CLASS_NAME);

		PortletInvitationPopupDP GadgetInvitationPopup = new PortletInvitationPopupDP();
		GadgetInvitationPopup.Init(this);
		RegisterPage(GadgetInvitationPopup);
		log.Info("Registered page");

		// Portlet Selection Views
		RegisterView(ObjSelBreadCrumbView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(FolderView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ObjectSelectionView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(SelectedObjectsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ObjectView.STR_MVC_CLASS_NAME, GADGET_VIEW, myModel);
		RegisterView(ObjectView.STR_MVC_CLASS_NAME, BUNDLE_VIEW, myModel);
		RegisterView(MyCustomPortletsView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(CreatePortletActionBarView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(CreatePortletActionBarView_D.STR_MVC_CLASS_NAME, myModel);

		// Register views that present search results, passing in
		// the SearchResultModel
		RegisterView(ObjSelSearchHeaderView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ObjSelSearch508BodyView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(ObjSelSearchFormView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(GroupedResultsView.STR_MVC_CLASS_NAME, searchModel);
		RegisterView(SearchSummaryView.STR_MVC_CLASS_NAME, searchModel);
		RegisterView(SearchFooterView.STR_MVC_CLASS_NAME, searchModel);
		RegisterView(OrganizationView.STR_MVC_CLASS_NAME, searchModel);

		// Portlet Preview/Invitation Views
		RegisterView(PortletInvitationPopupView.STR_MVC_CLASS_NAME, myModel);

		// Set the view helper for the grouped results view
		GroupedResultsView grv = (GroupedResultsView) GetView(GroupedResultsView.STR_MVC_CLASS_NAME);
		if (GetAccessStyle() == AccessStyles.STANDARD)
		{
			grv.SetHelper(new PortletSelGroupedResultsViewHelper());
		}
		else
		{
			grv.SetHelper(new PortletSelGroupedResults508ViewHelper());
		}

		log.Info("Registered views");

		// Portlet Selection Controls
		RegisterControl(OpenSubFolderControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(SetStartItemControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(SetLastItemControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(ObjectSelectionRepostControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(InvitationPopupControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(RefreshObjSelControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME, myModel);
		log.Info("Registered controls");

		// Set view helpers on views
		((ObjectView) GetView(PortletSelectionEditorAS.GADGET_VIEW)).SetObjectViewHelper(new PortletSelectionViewHelper());
		((ObjectView) GetView(PortletSelectionEditorAS.BUNDLE_VIEW)).SetObjectViewHelper(new BundleSelectionViewHelper());

		// Set default page
		if(GetAccessStyle() == AccessStyles.STANDARD) 
		{
			SetCurrentPage(GetPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME));
		}
		else
		{
			SetCurrentPage(GetPage(PortletSelectionDP_D.STR_MVC_CLASS_NAME));
		}
		
		
		this.SetHelpTopic( "PT_AddPortlets" );
		
	}
}

