package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.common.editpage.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.ptlink.IPTURL;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.TaskAPIUICommon;
import com.plumtree.taskapi.portalui.TaskAPIUICommunity;
import com.plumtree.taskapi.portalui.TaskAPIUIMyPages;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class PortletSelectionModelHelper implements IObjectSelectionModelHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionModelHelper");

	/** Subspace Key for Portlets in Portlet Bundle */
	public static final String SUBSPACE_NAME_PORTLETSINBUNDLE = "Bundle";

	/** Section Index: Portlet */
	public static final int VIEW_INDEX_PORTLET = 0;

	/** Section Index: Bundle */
	public static final int VIEW_INDEX_BUNDLE = 1;

	/** Selected Info Array: Number of Columns */
	public static final int COL_GADGET_MAX = 2;

	/** Selected Info Array: Portlet Alignment Column */
	public static final int COL_GADGET_ALIGNMENT = 1;
	
	/** Header Array: Number of Columns for gadget */
	public static final int COL_HEADER_PORTLET_MAX = 4;

	/** Header Array: Number of Columns for bundle */
	public static final int COL_HEADER_BUNDLE_MAX = 2;

	/** Header Array: Checkbox Input Name */
	public static final int COL_HEADER_CB = 0;

	/** Header Array: Names */
	public static final int COL_HEADER_NAME = 1;

	/** Header Array: Portlet Size */
	public static final int COL_HEADER_SIZE = 2;

	/** Header Array: Invites */
	public static final int COL_HEADER_INVITE = 3;
	
	/** Activity Space */
	protected AActivitySpace m_asOwner;

	/** Gadgets not to show from page template */
	private XPSortedDictionary m_xpsdPortletsNotToShow = null;

	/**
	 * Creates a new PortletSelectionModelHelper object.
	 *
	 * @param asOwner 
	 */
	public PortletSelectionModelHelper(AActivitySpace asOwner)
	{
		m_asOwner = asOwner;
	}

	// don't let people instantiate this without an asOwner; it's needed for internationalization.
	private PortletSelectionModelHelper()
	{
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#AddFormInputsForEachObject(XPHashtable, IASQueryResult, int)
	 */
	public void AddFormInputsForEachObject(XPHashtable htFormData,
		IASQueryResult asqr, int nObjectViewIndex)
	{
		if (VIEW_INDEX_BUNDLE == nObjectViewIndex)
		{
			String strObjectID;

			for (int i = 0; i < asqr.GetCount(); i++)
			{
				strObjectID = XPConvert.ToString(asqr.GetFields(i,
							PT_PROPIDS.PT_PROPID_OBJECTID));

				if (!htFormData.ContainsKey(BundleSelectionViewHelper.HTMLINPUT_BUNDLE_ASID_PREFIX +
							strObjectID))
				{
					htFormData.PutElement(BundleSelectionViewHelper.HTMLINPUT_BUNDLE_ASID_PREFIX +
						strObjectID, "");
				}
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetDoNotShowObjectIDs(ObjectSelectionModel)
	 */
	public XPSortedDictionary GetDoNotShowObjectIDs(
		ObjectSelectionModel model, int nObjectViewIndex)
	{
		XPSortedDictionary xpsd = new XPSortedDictionary();

		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			if ( model.IsHomeMyPage() )
			{
				IPTQueryResult ptqr = model.GetPTSession().GetMyPages()
					.QueryMandatoryGadgets();
				int nCount		    = ptqr.RowCount();

				for (int i = 0; i < nCount; i++)
				{
					xpsd.PutElement(ptqr.ItemAsObject(i,
							PT_PROPIDS.PT_PROPID_OBJECTID), "");
				}
			}

			if (model.IsCommunityPage())
			{
				// gadgets from page template
				xpsd = m_xpsdPortletsNotToShow;
			}
		}

		return xpsd;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetHeaders()
	 */
	public String[] GetHeaders(int nObjectViewIndex)
	{
		String[] astrHeader;

		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			astrHeader					  = new String[COL_HEADER_PORTLET_MAX];
			astrHeader[COL_HEADER_CB]     = PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;

			astrHeader[COL_HEADER_NAME]     = m_asOwner.GetString(722,
					"ptmsgs_portalbrowsingmsgs");

			astrHeader[COL_HEADER_SIZE]     = m_asOwner.GetString(723,
					"ptmsgs_portalbrowsingmsgs");

			astrHeader[COL_HEADER_INVITE] = CommonHTMLStrings.SPACE;
		}
		else
		{
			astrHeader					  = new String[COL_HEADER_BUNDLE_MAX];
			astrHeader[COL_HEADER_CB]     = BundleSelectionViewHelper.SELECTION_HEADER;

			astrHeader[COL_HEADER_NAME] = m_asOwner.GetString(725,
					"ptmsgs_portalbrowsingmsgs");
		}

		return astrHeader;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetNumObjectViews()
	 */
	public int GetNumObjectViews()
	{
		return 2;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjectBannerTitle(String)
	 */
	public String GetObjectBannerTitle(String strCurrentFolderName,
		int nObjectViewIndex)
	{
		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			if (null == strCurrentFolderName)
			{
				return m_asOwner.GetString(719, "ptmsgs_portalbrowsingmsgs");
			}
			return XPResourceManager.FormatMessage(m_asOwner.GetString(
				718, "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strCurrentFolderName));
		}
		if (null == strCurrentFolderName)
		{
			return m_asOwner.GetString(721, "ptmsgs_portalbrowsingmsgs");
		}
		return XPResourceManager.FormatMessage(m_asOwner.GetString(
			720, "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strCurrentFolderName));
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjectInputName(ObjectSelectionModel)
	 */
	public String GetObjectInputName(int nObjectViewIndex)
	{
		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			return PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
		}
		return BundleSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjects(IPTSession)
	 */
	public IPTObjectManager GetObjectMan(IPTSession ptSession,
		int nObjectViewIndex)
	{
		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			return ptSession.GetGadgets();
		}
		return ptSession.GetGadgetBundles();
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetObjectType()
	 */
	public int GetObjectType(int nObjectViewIndex)
	{
		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			return PT_CLASSIDS.PT_GADGET_ID;
		}
		return PT_CLASSIDS.PT_GADGETBUNDLE_ID;
	}

	/**
	 * 
	 *
	 * @param ptSession 
	 * @param ptFolder 
	 *
	 * @return 
	 */
	public IASQueryResult GetObjects(IPTSession ptSession,
		IPTAdminFolder ptFolder)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetPropIDsToQuery()
	 */
	public int GetPropIDsToQuery(int nObjectViewIndex)
	{
		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			return PT_PROPIDS.PT_PROPID_NAME |
			PT_PROPIDS.PT_PROPID_DESCRIPTION |
			PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT |
			PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE |
			PT_PROPIDS.PT_PROPID_GADGET_USERINTERFACES |
			PT_PROPIDS.PT_PROPID_LASTMODIFIED;
		}
		return PT_PROPIDS.PT_PROPID_NAME |
			PT_PROPIDS.PT_PROPID_DESCRIPTION |
			PT_PROPIDS.PT_PROPID_LASTMODIFIED;
	}

	/**
	 * Get query filter to use when query for selectable objects. The use of the first column
	 * of thise array, [0][0] - [2][0], is reserved for use by ObjectSelectionModel. Start adding filters to the
	 * array at [0][1] - [2][1].
	 *
	 * 
	 */
	public Object[][] GetQueryFilter(ObjectSelectionModel model,
		int nObjectViewIndex)
	{
		Object[][] ptqf;
		int nQueryFilters = 1;

		//    	int nAccessStyleIndex = 0;
		if (VIEW_INDEX_PORTLET == nObjectViewIndex)
		{
			nQueryFilters = nQueryFilters + 3;

			if ( model.IsMyPage() )
			{
				nQueryFilters++;
			}
			
			ptqf = new Object[3][nQueryFilters];

			if ( model.IsMyPage() )
			{
				ptqf[0][4]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE);
				ptqf[1][4]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
				ptqf[2][4]     = new Integer(PT_GADGET_TYPES.PT_GADGETTYPE_PERSONAL);
			}

			ptqf[0][1]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
			ptqf[1][1]     = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
			ptqf[2][1]     = new Integer(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER);
			ptqf[0][2]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
			ptqf[1][2]     = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
			ptqf[2][2]     = new Integer(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER);
			ptqf[0][3]     = new Integer(PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);
			ptqf[1][3]     = new Integer(PT_FILTEROPS.PT_FILTEROP_NE);
			ptqf[2][3]     = new Integer(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM);
		}
		else
		{
			ptqf = new Object[3][nQueryFilters];
		}

		return ptqf;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish(ObjectSelectionModel model)
	{
		Redirect redirect = new Redirect();
		
		
	
			ASURL asurl = new ASURL(m_asOwner);
	
			ASCache myCache			   = (ASCache) m_asOwner.GetSubSession()
				.GetAttribute(ASConstants.SANDBOXASCACHE);
			AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
				m_asOwner.GetParentSpaceID());
	
			if(m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
			{
				redirect.SetLinkGetCachedSpace(parentSpace);
				
				if ((redirect.GetSpaceName()).equals(MyPageAS.STR_MVC_CLASS_NAME))
				{
					redirect.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
				}
				else
				{
					redirect.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
				}
				redirect.AddControlArgument(SetPageControl.STR_PAGE_ID,
					XPConvert.ToString(model.GetSelectorPageID()));
				return redirect;	
			}
			
			String strRedirectURL;
			if(TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID) || TaskAPIUICommon.UseFriendlyURLS(PT_CLASSIDS.PT_COMMUNITY_ID) ) {
				
				IPTURL m_url = null;		
				if (0!= model.GetSelectorCommunityID())
				{
					if( 0 != model.GetSelectorPageID()){
						m_url = TaskAPIUICommunity.CreateCommunityPageCommonOpenerURL(m_asOwner, model.GetSelectorCommunityID(), model.GetSelectorPageID(), "");												
					} else {
						m_url = TaskAPIUICommunity.CreateCommunityCommonOpenerURL(m_asOwner, model.GetSelectorCommunityID(), "");
					}					
				}
			else
				{
					m_url = TaskAPIUIMyPages.CreateMyPageCommonOpenerURL(m_asOwner, model.GetSelectorPageID(), "");
				}
				
				strRedirectURL = m_url.GetFullURL();
				
			} else {

				asurl.SetLinkGetCachedSpace(parentSpace);
		
				if ((parentSpace.GetName()).equals(MyPageAS.STR_MVC_CLASS_NAME))
				{
					asurl.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
				}
				else
				{
					asurl.SetControl(SetCommunityControl.STR_MVC_CLASS_NAME);
				}
				if ( 0 != model.GetSelectorCommunityID())
				{
					asurl.AddControlArgument(SetCommunityControl.STR_COMMUNITY_ID, model.GetSelectorCommunityID());
				}
				asurl.AddControlArgument(SetPageControl.STR_PAGE_ID,
					model.GetSelectorPageID());
				
				strRedirectURL = asurl.GetURLAsString();
			}
			
			
	
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString("parent.location='" + strRedirectURL + "';");
			
			ClosePopUpDP closeDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			closeDP.SetScript(script);
			closeDP.SetToClose(false);
			
			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			redirect.SetControl(ObjSelFrameCheckAccessControl.STR_MVC_CLASS_NAME);

			return redirect;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSelectedInfo(int, IASQueryResult)
	 */
	public Object[] GetSelectedInfo(int nIndex, IASQueryResult asqr)
	{
		Object[] aoSelectedInfo = new Object[COL_GADGET_MAX];
		aoSelectedInfo[COL_GADGET_ALIGNMENT] = asqr.GetFields(nIndex,
				PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT);

		return aoSelectedInfo;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetSelectedObjects(ObjectSelectionModel)
	 */
	public Object[][] GetSelectedObjects(ObjectSelectionModel model)
	{
		XPSortedDictionary xpsdPortlets;
		Object[][] aoPortlets;
		Object[] aoSelectedInfo;
		
		ASCache myCache			   = (ASCache) m_asOwner.GetSubSession()
			.GetAttribute(ASConstants.SANDBOXASCACHE);
		AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
			m_asOwner.GetParentSpaceID());

		if ( null != parentSpace && parentSpace.GetModelExists(PageLayoutPlugInModel.STR_MVC_CLASS_NAME) ) 
		{
			if (null == m_xpsdPortletsNotToShow)
			{
				m_xpsdPortletsNotToShow     = ((PageLayoutPlugInModel) parentSpace.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetPortletsToHide();
			}
			xpsdPortlets	= ((PageLayoutPlugInModel) parentSpace.GetModel(PageLayoutPlugInModel.STR_MVC_CLASS_NAME)).GetSelectedPortlets();
			aoPortlets		= GetGadgetIDsInIntegerArray(xpsdPortlets);
		}
		else
		{
			int nPageID = model.GetSelectorPageID();
			if (0 == nPageID)
			{
				nPageID = model.GetSelectorObjectID();
			}

			IASQueryResult asqrGadgets = null;
			XPArrayList arrListGadgetIDs = new XPArrayList();
			XPArrayList arrListGadgetInfo = new XPArrayList();
			ASQueryResultWrapper qrw = null;

			IPTPage ptPage = (IPTPage) model.GetPTSession().GetPages().Open(nPageID, false);

			if ( model.IsCommunityPage() )
			{
				m_xpsdPortletsNotToShow     = new XPSortedDictionary();
			}
			else
			{
				
				if(model.IsHomeMyPage())
				{
					ASQueryResultWrapper qrwMandatory = new ASQueryResultWrapper(model.GetPTSession().GetMyPages().QueryMandatoryGadgets());
					asqrGadgets     = qrwMandatory;
				
					for (int i = 0; i < asqrGadgets.GetCount(); i++)
					{
						arrListGadgetIDs.Add(asqrGadgets.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
						aoSelectedInfo											   = GetSelectedInfo(i,
								asqrGadgets);
						aoSelectedInfo[ObjectSelectionModel.COL_SELECTED_NAME]     = asqrGadgets.GetFields(i,
								PT_PROPIDS.PT_PROPID_NAME);
		
						arrListGadgetInfo.Add(aoSelectedInfo);
					}	
				}
			}
				
			qrw = new ASQueryResultWrapper(ptPage.QueryPortlets());

			asqrGadgets     = qrw;

			for (int i = 0; i < asqrGadgets.GetCount(); i++)
			{
				arrListGadgetIDs.Add(asqrGadgets.GetFields(i, PT_PROPIDS.PT_PROPID_OBJECTID));
				aoSelectedInfo											   = GetSelectedInfo(i,
						asqrGadgets);
				aoSelectedInfo[ObjectSelectionModel.COL_SELECTED_NAME]     = asqrGadgets.GetFields(i,
						PT_PROPIDS.PT_PROPID_NAME);

				arrListGadgetInfo.Add(aoSelectedInfo);

				// bjf -- get PT_PROPID_GADGET_FROMPAGETEMPLATE only if this is a community page
				if ( model.IsCommunityPage() )
				{
					if (1 == XPConvert.ToInteger(asqrGadgets.GetFields(i,
								PT_PROPIDS.PT_PROPID_GADGET_FROMPAGETEMPLATE)))
					{
						// add to list of gadgets not to show if it is from a page template
						m_xpsdPortletsNotToShow.PutElement(asqrGadgets.GetFields(
								i, PT_PROPIDS.PT_PROPID_OBJECTID), "");
					}
				}
			}
			
			aoPortlets = new Object[arrListGadgetIDs.GetSize()][ObjectSelectionModel.COL_OBJECT_MAX];
			
			for(int i = 0; i < arrListGadgetIDs.GetSize(); i++)
			{
				aoPortlets[i][ObjectSelectionModel.COL_OBJECT_ID] = arrListGadgetIDs.GetElement(i);
				aoPortlets[i][ObjectSelectionModel.COL_OBJECT_INFO] = arrListGadgetInfo.GetElement(i);
			}
		}

		return aoPortlets;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#GetShouldSavePage()
	 */
	public boolean GetShouldSavePage()
	{
		return true;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#InitializeFormInputs(XPHashtable)
	 */
	public void InitializeFormInputs(XPHashtable htFormData)
	{
		htFormData.PutElement(BundleSelectionViewHelper.HTMLINPUT_CURRENT_BUNDLE,
			"");
	}

	/**
	 * @see com.plumtree.portalpages.browsing.selection.IObjectSelectionModelHelper#SetSelectedObjects(ObjectSelectionModel,
	 *      XPSortedDictionary, XPSortedDictionary)
	 */
	public void SetSelectedObjects(ObjectSelectionModel model,
		XPSortedDictionary xpsdOldSelectedObjects,
		XPSortedDictionary xpsdNewSelectedObjects)
	{
		if ((0 != model.GetSelectorPageID()) &&
				!(PageLayoutHeaderView.HTMLINPUT_ADDGADGETASID).equals(
					model.GetParentFormSpaceID()))
		{
			IPTPage ptPage = (IPTPage) model.GetPTSession().GetPages().Open(model.GetSelectorPageID(), false);
			int nPageType = ptPage.GetPageType();
			int nGadgetAlignment;

			IXPEnumerator xpeKeys = xpsdNewSelectedObjects.GetKeys();

			while (xpeKeys.MoveNext())
			{
				if (xpsdOldSelectedObjects.ContainsKey(xpeKeys.GetCurrent()))
				{
					xpsdOldSelectedObjects.RemoveElement(xpeKeys.GetCurrent());
				}
				else
				{
					// Get alignment of gadget
					nGadgetAlignment = XPConvert.ToInteger(((Object[]) xpsdNewSelectedObjects.GetElement(xpeKeys.GetCurrent()))[COL_GADGET_ALIGNMENT]);

					try
					{
						if(!model.DoNotShowObjectWithID(XPConvert.ToInteger((String) xpeKeys.GetCurrent())))
						{
							if ((PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE == nGadgetAlignment) ||
									(PageTypeConstants.ONE_COLUMN == nPageType) || (PageTypeConstants.ONE_COLUMN_WITH_FREE_FORM_CONTENT == nPageType))
							{
								ptPage.AddPortlet(XPConvert.ToInteger((String) xpeKeys.GetCurrent()),
									PortletColumnConstants.WIDE_ONE.ToInt());
							}
							else
							{
								ptPage.AddPortlet(XPConvert.ToInteger((String) xpeKeys.GetCurrent()),
									PortletColumnConstants.NARROW_ONE.ToInt());
							}
						}
					}
					catch (Exception e)
					{
						
							log.Warn(e, "SetSelectedObjects: Portlet has already been added to this page. " +
								e.getMessage());
						
					}
				}
			}

			xpeKeys = xpsdOldSelectedObjects.GetKeys();

			while (xpeKeys.MoveNext())
			{
				ptPage.RemovePortlet(XPConvert.ToInteger((String) xpeKeys.GetCurrent()));
			}
		}
	}

	/**
	 * Method GetGadgetIDsInIntegerArray.
	 * Puts the object id and info of each item in the query in the Object array
	 *
	 * @param xpsdGadgets
	 * @return Object[][]
	 */
	private Object[][] GetGadgetIDsInIntegerArray(
		XPSortedDictionary xpsdGadgets)
	{
		Object[][] aoGadgets  = new Object[xpsdGadgets.GetSize()][ObjectSelectionModel.COL_OBJECT_MAX];
		Object[] aoGadgetInfo;
		Object[] tempInfo;

		IXPEnumerator xpeKeys = xpsdGadgets.GetKeys();

		int i = 0;

		while (xpeKeys.MoveNext())
		{
			// Get Portlet ID
			aoGadgets[i][ObjectSelectionModel.COL_OBJECT_ID]     = new Integer(XPConvert.ToInteger((String) xpeKeys.GetCurrent()));

			// Get Portlet Info
			tempInfo												 = ((Object[]) xpsdGadgets.GetElement(xpeKeys.GetCurrent()));
			aoGadgetInfo											 = new Object[COL_GADGET_MAX];
			aoGadgetInfo[ObjectSelectionModel.COL_SELECTED_NAME]     = tempInfo[PageLayoutPlugInModel.COL_GADGET_NAME];
			aoGadgetInfo[COL_GADGET_ALIGNMENT]     = tempInfo[PageLayoutPlugInModel.COL_GADGET_ALIGNMENT];

			aoGadgets[i][ObjectSelectionModel.COL_OBJECT_INFO] = aoGadgetInfo;

			i++;
		}

		return aoGadgets;
	}
	
	/**
	 * Method GetPageName.
	 * @param model
	 * @return String
	 */
	public String GetPageName(ObjectSelectionModel model)
	{
		ASCache myCache			   = (ASCache) m_asOwner.GetSubSession()
			.GetAttribute(ASConstants.SANDBOXASCACHE);
		AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
			m_asOwner.GetParentSpaceID());

		if ( parentSpace.GetModelExists(LocNamesModel.STR_MVC_CLASS_NAME) )
		{
			return ((LocNamesModel) parentSpace.GetModel(LocNamesModel.STR_MVC_CLASS_NAME)).GetPrimaryName();
		}
		else if ( parentSpace.GetModelExists(PageNamePlugInModel.STR_MVC_CLASS_NAME) )
		{
			return ((PageNamePlugInModel) parentSpace.GetModel(PageNamePlugInModel.STR_MVC_CLASS_NAME)).GetPageName();
		}
		else
		{
			int nPageID = model.GetSelectorPageID();
			if (0 == nPageID)
			{
				nPageID = model.GetSelectorObjectID();
			}
			return ((IPTPage) model.GetPTSession().GetPages().Open(nPageID, false)).GetLocalizedName();
		}
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetStartInSearch()
	 */
	public boolean GetStartInSearch()
	{
		return true;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#GetSearchHeaderTitle()
	 */
	public String GetSearchHeaderTitle()
	{
		return m_asOwner.GetString(1471, "ptmsgs_portalbrowsingmsgs");
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.objectselection.IObjectSelectionModelHelper#Get508SearchStringFromArray(int)
	 */
	public int Get508SearchStringMsgIndex(int nStringIndex)
	{
		switch (nStringIndex)
		{
			case Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_AVAILABLE:
				return 1771;
			case Search508StringIndexConstants.N_THERE_ARE_BLANK_OBJECTS_IN_THIS_FOLDER:
				return 1773;
			case Search508StringIndexConstants.N_OBJECTS_IN_BLANK:
				return 1776;
			default:
				return 0;
		}
	}
}

