package com.plumtree.portalpages.browsing.objectselection.portlets;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * 
 *
 * @author michaeld
 */
public class PortletSelectionViewHelper implements IObjectViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.objectselection.portlets.PortletSelectionViewHelper");

	/** HTML Input Checkbox */
	public static final String HTMLINPUT_SELECTION_OBJECT = "in_cb_Object";
	
	/** Javascript Function: openInvite */
	public static final String JAVASCRIPT_OPEN_INVITE = "openInvite";

	/** Javascript Function: previewGadget */
	public static final String JAVASCRIPT_PREVIEW_GADGET = "previewGadget";
	
	/** Section 508 User Interface String */
	public static final String STR_508_USER_INTERFACE = "http://www.plumtree.com/uis/section508";
	
	/** Devices User Interface String */
	public static final String STR_WML_USER_INTERFACE = "http://www.plumtree.com/uis/wml";
	
	/** subspace key for preview portlet */
	public static final String PREVIEW_PORTLET_SUBSPACE = "PreviewPortletSubspace";

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#AddObjectViewHTML()
	 */
	public HTMLElement AddObjectViewHTML(IObjectModelRO model)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.
	 * IObjectViewHelper#GetThereAreNoItemsString(AActivitySpace)
	 */
	public String GetThereAreNoItemsString(AActivitySpace asOwner)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#Display508Object(int, HTMLTable, IObjectModelRO, AActivitySpace)
	 */
	public void Display508Object(int nObjectIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace parent)
	{
		boolean b508Portlet = false;

		Object oUserInterfaces = model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_GADGET_USERINTERFACES);
		String strDisplayInterfaces = "";
		if (null != oUserInterfaces)
		{
			String strUserInterfaces = XPConvert.ToString(oUserInterfaces);
			if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_508_USER_INTERFACE))
			{
				b508Portlet = true;
				if (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_WML_USER_INTERFACE))
				{
					strDisplayInterfaces = parent.GetString(1644, "ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					strDisplayInterfaces = parent.GetString(1645, "ptmsgs_portalbrowsingmsgs");
				}
			}
			else if ((parent.GetAccessStyle() != AccessStyles.SECTION_508) && (0 <= XPStringUtility.IndexOf(strUserInterfaces, PortletSelectionViewHelper.STR_WML_USER_INTERFACE)))
			{
				strDisplayInterfaces = parent.GetString(1646, "ptmsgs_portalbrowsingmsgs");
			}
		}

		HTMLTableRow row;
		HTMLTableCell cell;
		ASURL myAsurl;
		HTMLBr br = new HTMLBr();

		int iObjectID		    = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
		String strObjectName	    = (String) model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_NAME);
		Object oDescription = model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_DESCRIPTION);

		boolean bSimple = GetSimpleMode(model);

		try
		{
			row = new HTMLTableRow();
			tableObjects.AddInnerHTMLElement(row);

			if (!bSimple)
			{
				// The cell for the input checkbox that we're not displaying
				cell = new HTMLTableCell();
				row.AddInnerHTMLElement(cell);
				cell.SetVAlign(CommonHTMLStrings.MIDDLE);
				cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			}

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetVAlign(CommonHTMLStrings.MIDDLE);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

			if (parent.GetAccessStyle() == AccessStyles.SECTION_508 && !b508Portlet)
			{
				cell.AddInnerHTMLString(XPResourceManager.FormatMessage(parent.GetString(1632, "ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strObjectName)));
			}
			else
			{
				if (("").equals(strDisplayInterfaces))
				{
					HTMLB bold = new HTMLB();
					bold.AddInnerHTMLEncodedString(strObjectName);
					cell.AddInnerHTMLElement(bold);
				}
				else
				{
					cell.AddInnerHTMLString(XPResourceManager.FormatMessage(strDisplayInterfaces, XPHttpUtility.HtmlEncode(strObjectName)));
				}

				cell.AddInnerHTMLElement(br);
	
				if (null != oDescription)
				{
					if (!"".equals(oDescription))
					{
						cell.AddInnerHTMLEncodedString((String)oDescription);
						cell.AddInnerHTMLElement(br);
					}
				}
	
				if (!bSimple)
				{
					if (model.GetIsObjectSelected(iObjectID))
					{
						if(model.DoNotShowObject(nObjectIndex))
						{
							cell.AddInnerHTMLString(parent.GetString(1660, "ptmsgs_portalbrowsingmsgs"));						
						} else {
							myAsurl = ((AFormDP) parent.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_508_ACTION_REMOVEOBJECT);
							myAsurl.AddControlArgument(PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
								iObjectID);
							myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(parent.GetString(1278, "ptmsgs_portalbrowsingmsgs"), 
								XPHttpUtility.HtmlEncode(strObjectName)));
							cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
						}
					}
					else
					{
						myAsurl = ((AFormDP) parent.GetCurrentPage()).Get508RepostURL(ObjectSelectionRepostControl.POSTTOSELF_508_ACTION_ADDOBJECT);
						myAsurl.AddControlArgument(PortletSelectionViewHelper.HTMLINPUT_SELECTION_OBJECT,
							iObjectID);
						myAsurl.AddInnerHTMLString(XPResourceManager.FormatMessage(parent.GetString(1277, "ptmsgs_portalbrowsingmsgs"), 
							XPHttpUtility.HtmlEncode(strObjectName)));
						cell.AddInnerHTMLElement(myAsurl.GetURLAsHTMLElement());
					}
				}
			}

			// The cell for the portlet width
			cell.AddInnerHTMLElement(br);

			// The cell for the portlet invitation.
			cell.AddInnerHTMLElement(br);
		}
		catch (HTMLException e)
		{
			log.Error(e, "Portlet " + XPConvert.ToString(iObjectID) +
				" failed to display.");
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayJavascriptCollection()
	 */
	public HTMLScriptCollection DisplayJavascriptCollection(
		AActivitySpace asOwner, IObjectModelRO model)
	{
		HTMLScriptCollection collection = new HTMLScriptCollection();

		ASURL asurl;
		XPStringBuilder sb;

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			collection.AddInnerHTMLElement(script);

			script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(asOwner) + "opennewwindow.js");
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascriptCollection: Failed to add opennewwindow.js to javascript collection. " +
					he.getMessage());
			
		}

		script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			collection.AddInnerHTMLElement(script);
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascriptCollection: Failed to add script to collection. " +
					he.getMessage());
			
		}

		asurl = new ASURL(asOwner);
		asurl.SetLinkGetCachedSpace(asOwner);
		asurl.SetControl(InvitationPopupControl.STR_MVC_CLASS_NAME);
		asurl.SetDisplayPage(PortletInvitationPopupDP.STR_MVC_CLASS_NAME);

		try
		{
			sb = new XPStringBuilder(200);

			String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
			sb.Append("\n").Append("function ").Append(JAVASCRIPT_OPEN_INVITE)
			.Append("(gadgetIndex)\n").Append("{\n")
			.Append("		"+strJSUtilVersionPrefix+"PTWindowUtil.openWindow('").Append(asurl.GetURLAsString())
			.Append("&").Append(InvitationPopupControl.strInviteIndex)
			.Append("=' + gadgetIndex").Append(", 'SendToOthers', '250','600');\n").Append("}\n");

			script.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "DisplayJavascriptCollection: Failed to add javascript function " +
					JAVASCRIPT_OPEN_INVITE + " to javscript collection. " +
					he.getMessage());
			
		}

		if (!GetSimpleMode(model))
		{
			asurl = new ASURL(asOwner);
			asurl.SetSubSpaceKey("PortletSelection");
			asurl.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME, asOwner);
			asurl.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
			asurl.SetDisplayPage(PreviewPortletDP.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(PreviewPortletControl.m_PreviewType,
				XPConvert.ToString(PreviewPortletModel.SELECTIONPREVIEWHEADER));
	
			try
			{
				sb = new XPStringBuilder(200);
	
				sb.Append("\n").Append("function ").Append(JAVASCRIPT_PREVIEW_GADGET)
				.Append("(gadgetID, gadgetAlign, gadgetIndex)\n").Append("{\n")
				.Append("		var checkBoxes = document." + AFormDP.HTMLFORM_NAME +
					"." + HTMLINPUT_SELECTION_OBJECT + ";\n").Append("		var checked = '" + XPConvert.ToString(false) + "';\n");
	
				sb.Append("		if (checkBoxes && checkBoxes.length) {\n");
				sb.Append("			for(var i = 0; i < checkBoxes.length; i++) {\n"); 
				sb.Append("				if(checkBoxes[i].checked && checkBoxes[i].value == gadgetIndex){\n");
				sb.Append("					checked = '" + XPConvert.ToString(true) + "';\n");
				sb.Append("					break;\n");
				sb.Append("				}\n");
				sb.Append("			}\n");
				sb.Append("		} else if (checkBoxes.checked) {\n")
				.Append("			checked = '" + XPConvert.ToString(true) + "';\n").Append("		}\n")
				.Append("		var url = '").Append(asurl.GetURLAsString()).Append("&")
				.Append(PreviewPortletControl.m_strPortletParam)
				.Append("=' + gadgetID").Append(" + '&")
				.Append(PreviewPortletControl.m_strPortletIndex)
				.Append("=' + gadgetIndex").Append(" + '&")
				.Append(PreviewPortletControl.m_strPortletChecked)
				.Append("=' + checked;\n").Append("		if ( ")
				.Append(PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW)
				.Append(" == gadgetAlign )\n").Append("		{\n")
				.Append("			OpenNarrowGadgetPreviewWindow(url);\n").Append("		}\n")
				.Append("		else\n").Append("		{\n")
				.Append("			OpenWideGadgetPreviewWindow(url);\n").Append("		}\n")
				.Append("}\n");
	
				script.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "DisplayJavascriptCollection: Failed to add javascript function " +
						JAVASCRIPT_PREVIEW_GADGET + " to javscript collection. " +
						he.getMessage());
				
			}
			
			try {
				sb = new XPStringBuilder(200);
				sb.Append("\n").Append("function ").Append(SelectedObjectsView.JAVASCRIPT_ADD_SELECTED)
					.Append("(checkbox)\n").Append("{\n");
				sb.Append("	parent.").Append(FrameSetDP.BODY_FRAME).Append(".")
					.Append(SelectedObjectsView.JAVASCRIPT_ADD_SELECTED).Append("(document.")
					.Append(AFormDP.HTMLFORM_NAME).Append("['").Append(ObjectSelectionModel.HTMLINPUT_HIDDEN_ID)
					.Append("' +checkbox.value].value, document.").Append(AFormDP.HTMLFORM_NAME).Append("['")
					.Append(ObjectSelectionModel.HTMLINPUT_HIDDEN_ALIGNMENT).Append("' +checkbox.value].value, document.")
					.Append(AFormDP.HTMLFORM_NAME).Append("['").Append(ObjectSelectionModel.HTMLINPUT_HIDDEN_NAME)
					.Append("' +checkbox.value].value, checkbox.checked);\n");
				sb.Append("}\n");			
				
				script.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "DisplayJavascriptCollection: Failed to add javascript function " +
						SelectedObjectsView.JAVASCRIPT_ADD_SELECTED + " to javscript collection. " +
						he.getMessage());
				
			}
		}

		return collection;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayObject(int,
	 *      HTMLTable)
	 */
	public void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace asOwner)
	{
		boolean bShowObject = true;
		if ( model.GetObjectType() == -PT_CLASSIDS.PT_GADGET_ID && 
			PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT > XPConvert.ToInteger(model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_ACCESSLEVEL)) )
		{
			// if displaying portlets in portlet bundle, and the user has less than select access on this portlet 
			bShowObject = false;
		}
		
		if (bShowObject)
		{
			HTMLBr br = new HTMLBr();
	
			HTMLTableRow row;
			HTMLTableCell cell;
	
			int iObjectID  = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_OBJECTID));
			String strObjectID = XPConvert.ToString(iObjectID);
	
			String strObjectName = (String) model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_NAME);

			boolean bSimple = GetSimpleMode(model);

			try
			{
				row = new HTMLTableRow();
				tableObjects.AddInnerHTMLElement(row);
	
				if ((nRowIndex % 2) != 0)
				{
					row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
				}
				else
				{
					row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
				}

				// Don't show the checkbox if we are in simple mode
				if (!bSimple)
				{
					// Input selector for object
					cell = new HTMLTableCell();
					row.AddInnerHTMLElement(cell);
					cell.SetHeight("20");
					cell.SetVAlign(CommonHTMLStrings.TOP);
					cell.SetAlign(CommonHTMLStrings.CENTER);
		
					HTMLInput inputSelector = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLINPUT_SELECTION_OBJECT,
							XPResourceManager.FormatMessage(asOwner.GetString(726,
									"ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strObjectName)));
					inputSelector.SetValue(XPConvert.ToString(nObjectIndex));
	//				DCA - onclick for updating the bottom frame
					inputSelector.SetOnClick(SelectedObjectsView.JAVASCRIPT_ADD_SELECTED + "(this); return true;"); 
		
					if (model.GetIsObjectSelected(iObjectID))
					{
						inputSelector.SetChecked(true);
					}
					if (model.DoNotShowObject(nObjectIndex))
					{
						inputSelector.SetDisabled(true);	
					}
					BrowserType browser = (BrowserType) asOwner.GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
					if(browser.IsNetscape4() && (model.DoNotShowObject(nObjectIndex)))
					{
						cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
					} else {	
						cell.AddInnerHTMLElement(inputSelector);
					}
				}

				// Object Image
				cell = new HTMLTableCell();
				row.AddInnerHTMLElement(cell);
				cell.SetWidth("23");
				cell.SetVAlign(CommonHTMLStrings.TOP);
				cell.SetAlign(CommonHTMLStrings.CENTER);
	
				HTMLImg img = null;
	
				try
				{
					Object oUserInterfaces = model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_GADGET_USERINTERFACES);
					if (null != oUserInterfaces)
					{
						String strUserInterfaces = XPConvert.ToString(oUserInterfaces);
						if (0 <= XPStringUtility.IndexOf(strUserInterfaces, STR_508_USER_INTERFACE))
						{
							PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_508);
							img = (HTMLImg) myConstruct.GetHTMLElement();
		
							if (0 <= XPStringUtility.IndexOf(strUserInterfaces, STR_WML_USER_INTERFACE))
							{
								img.SetAlt(asOwner.GetString(1641, "ptmsgs_portalbrowsingmsgs"));
							}
							else
							{
								img.SetAlt(asOwner.GetString(1642, "ptmsgs_portalbrowsingmsgs"));
							}
						}
						else if (0 <= XPStringUtility.IndexOf(strUserInterfaces, STR_WML_USER_INTERFACE))
						{
							PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_DEVICE);
							img = (HTMLImg) myConstruct.GetHTMLElement();
		
							img.SetAlt(asOwner.GetString(1643, "ptmsgs_portalbrowsingmsgs"));
						}
						else
						{
							PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_PORTLET);
							img = (HTMLImg) myConstruct.GetHTMLElement();
		
							img.SetAlt(asOwner.GetString(727, "ptmsgs_portalbrowsingmsgs"));
						}
					}
					else
					{
						PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_PORTLET);
						img = (HTMLImg) myConstruct.GetHTMLElement();
		
						img.SetAlt(asOwner.GetString(727, "ptmsgs_portalbrowsingmsgs"));
					}
				}
				catch (Exception e)
				{
					
						log.Error(e, "Display Object: Failed to create image. " +
							e.getMessage());
					
				}
	
				cell.AddInnerHTMLElement(img);
	
				// Object Name
				cell = new HTMLTableCell();
				row.AddInnerHTMLElement(cell);
				cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	
				int nGadgetType		 = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
					PT_PROPIDS.PT_PROPID_GADGET_GADGETTYPE));
				int nGadgetAlignment = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
					PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT));
	
				HTMLSpan mySpan = new HTMLSpan();
				cell.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
				// Don't show the preview link if it's a community portlet
				// or if we are in simple mode
				if ((nGadgetType != PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY) && (!bSimple))
				{
					HTMLAnchor previewGadgetAnchor = ConstructStaticHelpers.GetJavascriptAnchor(XPHttpUtility.HtmlEncode(strObjectName),
							JAVASCRIPT_PREVIEW_GADGET + "('" + strObjectID +
							"', '" + nGadgetAlignment + "', '" + nObjectIndex +
							"')");
					mySpan.AddInnerHTMLElement(previewGadgetAnchor);
	
					previewGadgetAnchor.SetTitle(asOwner.GetString(732,
							"ptmsgs_portalbrowsingmsgs"));
				}
				else
				{
					mySpan.AddInnerHTMLEncodedString(strObjectName);
				}
	
				// Get Portlet Alignment
				String strGadgetSize = null;
	
				if (PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW == nGadgetAlignment)
				{
					strGadgetSize = asOwner.GetString(729,
							"ptmsgs_portalbrowsingmsgs");
				}
				else
				{
					strGadgetSize = asOwner.GetString(730,
							"ptmsgs_portalbrowsingmsgs");
							
					nGadgetAlignment = PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE;
				}
	
				Object oDescription = model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_DESCRIPTION);
				if (null != oDescription)
				{
					if (!"".equals(oDescription))
					{
						cell.AddInnerHTMLElement(br);
		
						// Object Description
						cell.AddInnerHTMLEncodedString((String)oDescription);
					}
				}
				
				// Hidden Inputs with Portlet information
				HTMLInput inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN,
					ObjectSelectionModel.HTMLINPUT_HIDDEN_ID + nObjectIndex, "");
				inputHidden.SetValue(strObjectID);
				cell.AddInnerHTMLElement(inputHidden);
				inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN,
					ObjectSelectionModel.HTMLINPUT_HIDDEN_NAME + nObjectIndex, "");
				inputHidden.SetValue(XPHttpUtility.HtmlEncode(strObjectName));
				cell.AddInnerHTMLElement(inputHidden);
				inputHidden = new HTMLInput(HTMLInputTypes.HIDDEN,
					ObjectSelectionModel.HTMLINPUT_HIDDEN_ALIGNMENT + nObjectIndex, "");
					inputHidden.SetValue(XPConvert.ToString(nGadgetAlignment));
				cell.AddInnerHTMLElement(inputHidden);
				
				// Print Portlet Alignment
				cell = new HTMLTableCell();
				row.AddInnerHTMLElement(cell);
				cell.SetAlign(CommonHTMLStrings.CENTER);
				cell.SetVAlign(CommonHTMLStrings.MIDDLE);
				cell.SetNoWrap(true);
				cell.SetStyleClass(PTStyleClass.LIST_TEXT);
				cell.AddInnerHTMLString(strGadgetSize);
	
				// Send to Others Link
				cell = new HTMLTableCell();
				row.AddInnerHTMLElement(cell);
				cell.SetAlign(CommonHTMLStrings.CENTER);
				cell.SetVAlign(CommonHTMLStrings.MIDDLE);
				cell.SetNoWrap(true);
				cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	
				// just using asurl to build the url - will soon pass it into an HTMLAnchor
				if (nGadgetType != PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY)
				{
					HTMLAnchor sendToOthersAnchor = ConstructStaticHelpers.GetJavascriptAnchor("",
							JAVASCRIPT_OPEN_INVITE + "('" + XPConvert.ToString(nObjectIndex) + "')");
					cell.AddInnerHTMLElement(sendToOthersAnchor);
	
					sendToOthersAnchor.SetTitle(asOwner.GetString(731,
							"ptmsgs_portalbrowsingmsgs"));
					PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEND);
					HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();
					myImg.SetAlt(asOwner.GetString(731, "ptmsgs_portalbrowsingmsgs"));
					sendToOthersAnchor.AddInnerHTMLElement(myImg);
				}
				else
				{
					cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				}
			}
			catch (HTMLException e)
			{
				
					log.Error(e, "Portlet " + strObjectID + " failed to display: " +
						e.getMessage());
				
			}
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#SetExpandButton(HTMLAnchor, IObjectModelRO)
	 */
	public void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model)
	{
	}

	/**
	 * This helper method gets whether or not we are in simple mode.
	 * @param _model the current model.
	 * @return whether or not we are in simple mode.
	 */
	public boolean GetSimpleMode(IObjectModelRO _model)
	{
		if (XPStringUtility.CompareIgnoreCase(_model.GetName(), PortletInBundleObjectSelectionModel.STR_MVC_CLASS_NAME) == 0)
		{
			return ((PortletInBundleObjectSelectionModel) _model).GetSimpleMode();
		}

		return false;
	}
}