package com.plumtree.portalpages.browsing.portalsettings;



import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Portal settings view management handler
 *
 * @author DavidP
 */
public class PortalSettingsView implements IView
{
	public static final String STR_MVC_CLASS_NAME = "PortalSettings";
	private AActivitySpace m_asOwner;
	private IPortalSettingsModelRO m_asmModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortalSettingsView();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = null;
		
		m_asmModel.InitSettings(m_asOwner);
		
		IPTSession ptSession = (IPTSession) m_asOwner.GetUserSession();

		try
		{
			HTMLTable psTable = new HTMLTable();
			psTable.SetAlign("left");
			psTable.SetCellPadding("5");
			psTable.SetCellSpacing("0");
			psTable.SetBorder("0");
			psTable.SetWidth("100%");
			psTable.SetSummary(m_asOwner.GetString( 1610, "ptmsgs_portalbrowsingmsgs"));

			HTMLTableRow headerRow = new HTMLTableRow();
			psTable.AddInnerHTMLElement(headerRow);

			HTMLTableCell headerCell = new HTMLTableCell();
			headerCell.SetAlign("left");
			headerCell.SetVAlign("top");

			headerRow.AddInnerHTMLElement(headerCell);
			headerRow.SetStyleClass(PTStyleClass.DIR_HEADER_BG);

			HTMLSpan headerSpan = new HTMLSpan();
			headerSpan.SetStyleClass(PTStyleClass.DIR_HEADER);
			headerSpan.AddInnerHTMLString(this.m_asOwner.GetString( 1604, "ptmsgs_portalbrowsingmsgs" ));
			headerCell.AddInnerHTMLElement(headerSpan);

			for (int i = 0; i < m_asmModel.GetNumSettingItems(); i++)
			{
				String text			 = m_asmModel.GetSettingItemName(i);
				String desc			 = m_asmModel.GetSettingItemDescription(i);
				String strSettingURL = m_asmModel.GetSettingItemURL(i);
				int nActivityRight 	 = m_asmModel.GetActivityRightRestriction(i);
				boolean bHasRight = true;
				
				if (PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE != nActivityRight) bHasRight = ptSession.GetSessionInfo().CheckForActivityRight(nActivityRight);
				
				
				if (bHasRight) {
					HTMLTableRow tRow = new HTMLTableRow();
					psTable.AddInnerHTMLElement(tRow);
					HTMLTableCell tCell = new HTMLTableCell();
					tRow.AddInnerHTMLElement(tCell);
					tCell.SetStyleClass(PTStyleClass.MENU_TEXT);

					HTMLAnchor tAnchor = new HTMLAnchor(strSettingURL);
					tCell.AddInnerHTMLElement(tAnchor);
					tAnchor.AddInnerHTMLString(text);
					tAnchor.SetTitle(text);
					tAnchor.SetName(text);
					// In 508 the Change Password link gets an access key treatment
					if (m_asOwner.GetAccessStyle() == AccessStyles.SECTION_508 
							&& text.equals(m_asOwner.GetString(1305, ResourceConstants.PORTALBROWSINGMSGS)))
					{
						tAnchor.SetTitle(m_asOwner.GetString(20, ResourceConstants.PORTAL508QUICKKEYMSGS));
						tAnchor.SetAccessKey(m_asOwner.GetString(7, ResourceConstants.PORTAL508QUICKKEYMSGS)); 						
					}				
					
					tCell.AddInnerHTMLString("<br>" + desc);

					AddBreakRow(psTable);
				}

				
			}

			result = psTable;
		}
		catch (HTMLException e)
		{
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**PortalSettings
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asmModel     = (IPortalSettingsModelRO) model;
		m_asOwner	   = parent;
	}

	/**
	 * 
	 *
	 * @param table 
	 *
	 * @throws HTMLException 
	 */
	protected void AddBreakRow(HTMLTable table)

	{
		HTMLTableRow tRow   = new HTMLTableRow();
		HTMLTableCell tCell = new HTMLTableCell();

		tRow.AddInnerHTMLElement(tCell);
		table.AddInnerHTMLElement(tRow);
		tCell.SetHeight("6");
	}
}

