package com.plumtree.portalpages.browsing.portalsettings.displayoptions;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 */
public class DisplayOptAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.displayoptions.DisplayOptAS");

	
	public static final String STR_MVC_CLASS_NAME = "DisplayOpt";

	private static final String sClassName = "com.plumtree.portalpages.browsing.portalsettings.displayoptions.DisplayOptAS";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DisplayOptAS();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		return (GetString(996, "ptmsgs_portalbrowsingmsgs"));
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (DisplayOptRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * 
	 */
	public void Init()
	{
		m_strModelName = DisplayOptModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(m_strModelName);

		RegisterPage(new MainDP());

		RegisterView(DisplayOptView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(AccessibilityView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(GreetingView.STR_MVC_CLASS_NAME, myModel);
		RegisterView(TimeoutView.STR_MVC_CLASS_NAME, myModel);

		RegisterControl(DisplayOptRepostControl.STR_MVC_CLASS_NAME, myModel);
		SetCurrentPage(MainDP.STR_MVC_CLASS_NAME);

		// Set left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(997,
					"ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, MainDP.STR_MVC_CLASS_NAME);
		
		IPTServerConfigSettings config = (IPTServerConfigSettings) ((IPTSession) GetUserSession()).
			OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);
		// Only show advanced settings page if debuggin mode is enabled
		if (config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_SUBPORTAL_RULES_MODE) == 1) {
			RegisterPage(new AdvancedSettingsDP());
			RegisterView(RulesDebugModeView.STR_MVC_CLASS_NAME, myModel);
			m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, AdvancedSettingsDP.STR_MVC_CLASS_NAME);
		}

		// END Sub menu "General Settings"		
		
		

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				
				
				int iTitleId = 99;
				int iTipId = 100;
				int iSecondaryTipId = 101;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}

								

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
		 
		 				
		
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		// make sure this is not the guest user
		boolean isGuest = PlumtreeHelpers.IsGuestSession(this);
		if (isGuest && !PlumtreeHelpers.IsEditingDefaultProfile(this))
		{
			return false;
		}
		
		return true;
	}	

}

