package com.plumtree.portalpages.browsing.portalsettings.displayoptions;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author Sample
 */
public class DisplayOptModel extends EditorModel implements IDisplayOptModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.displayoptions.DisplayOptModel");

	
	public static final String STR_MVC_CLASS_NAME = "DisplayOpt";
	protected IPTSession m_ptSession;
	private String m_strAccess = "";

	// these are the settings
	private String m_strGreeting = "";
	private String m_strOpenWin = "";
	private String m_strRefreshRate = "10";
	private int m_nTimeout		    = -1;
	private boolean m_bEnableRulesDebugMode = false;

	/**
	 * 
	 *
	 * @param strErrorMsgs 
	 * @param strNewMessage 
	 *
	 * @return 
	 */
	public String AddToErrorString(String strErrorMsgs, String strNewMessage)
	{
		if (strErrorMsgs.length() > 0)
		{
			return strErrorMsgs + ", " + strNewMessage;
		}
		else
		{
			return strNewMessage;
		}
	}

	// interface PropertyValidatorOwner 
	// TODO: olegs - need this? class does not implement this interface
	// implementation
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		LoadSettings();

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DisplayOptModel();
	}

	/**
	 * 
	 */
	public void Finish()
	{
		try
		{
			SetStringSetting(PersonalSettingNames.GREETING, m_strGreeting);

			if (-1 != m_nTimeout)
			{
				SetIntSetting(PersonalSettingNames.PORTLET_TIMEOUT,
					m_nTimeout * 1000);
			}
			else
			{
				SetIntSetting(PersonalSettingNames.PORTLET_TIMEOUT, m_nTimeout);
			}

			SetStringSetting(PersonalSettingNames.OPEN_DOC_NEW_WINDOW, m_strOpenWin);

			SetStringSetting(PersonalSettingNames.ACCESS_STYLE, m_strAccess);

			SetIntSetting(PersonalSettingNames.MY_PAGE_REFRESH_RATE,
				XPConvert.ToInteger(m_strRefreshRate));
			
			if (m_bEnableRulesDebugMode) {
				SetIntSetting(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE, 1);
			} else {
				SetIntSetting(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE, 0);
			}
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, null,
					
				m_asOwner.GetString(1000, "ptmsgs_portalbrowsingmsgs"),
					
				m_asOwner.GetString(1000, "ptmsgs_portalbrowsingmsgs"));
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetAccessibilityStyle()
	{
		return m_strAccess;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetGreeting()
	{
		return m_strGreeting;
	}
	
	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetRulesDebugMode() {
		return m_bEnableRulesDebugMode;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetTimeout()
	{
		return m_nTimeout;
	}

	public boolean IsRefreshRate(String strRate)
	{
		return m_strRefreshRate.equals(strRate);
	}

	/**
	 * 
	 *
	 * @param strType 
	 *
	 * @return 
	 */
	public boolean IsViewChecked(String strType)
	{
		return m_strAccess.equals(strType);
	}

	/**
	 * 
	 */
	public void LoadSettings()
	{
		try
		{
			m_ptSession     = (IPTSession) m_asOwner.GetUserSession();

			m_strGreeting		 = GetStringSetting(PersonalSettingNames.GREETING);
			m_nTimeout			 = GetIntSetting(PersonalSettingNames.PORTLET_TIMEOUT) / 1000;
			m_nTimeout			 = (m_nTimeout == 0) ? (-1) : m_nTimeout;
			m_strRefreshRate     = XPConvert.ToString(GetIntSetting(PersonalSettingNames.MY_PAGE_REFRESH_RATE));
			m_strOpenWin		 = GetStringSetting(PersonalSettingNames.OPEN_DOC_NEW_WINDOW);
			m_strAccess			 = GetStringSetting(PersonalSettingNames.ACCESS_STYLE);

			if (m_strOpenWin.equals(""))
			{
				m_strOpenWin = "0";
			}

			if (m_strAccess.equals(""))
			{
				m_strAccess = "3";
			}
			
			if (GetIntSetting(PersonalSettingNames.ENABLE_RULES_DEBUG_MODE) == 1) {
				m_bEnableRulesDebugMode = true;
			}
		}
		catch (Exception e)
		{			
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
				UIErrorScope.CURRENT_USER, e,
				m_asOwner.GetString(1000, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1000, "ptmsgs_portalbrowsingmsgs"));
				
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
	}

	/**
	 * 
	 *
	 * @param _sPageName 
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int result = RepostControl.PAGE_STATUS_VALID;

		if (_sPageName.equals(MainDP.STR_MVC_CLASS_NAME))
		{
			if (RepostControl.PAGE_STATUS_INVALID == SaveDisplayOptions(
						_htFormData))
			{
				result = RepostControl.PAGE_STATUS_INVALID;
			}

			if (RepostControl.PAGE_STATUS_INVALID == SaveGreeting(_htFormData))
			{
				result = RepostControl.PAGE_STATUS_INVALID;
			}

			if (RepostControl.PAGE_STATUS_INVALID == SaveTimeout(_htFormData))
			{
				result = RepostControl.PAGE_STATUS_INVALID;
			}

			if (RepostControl.PAGE_STATUS_INVALID == SaveAccessibility(
						_htFormData))
			{
				result = RepostControl.PAGE_STATUS_INVALID;
			}
		}
		
		if (_sPageName.equals(AdvancedSettingsDP.STR_MVC_CLASS_NAME)) {
			if (RepostControl.PAGE_STATUS_INVALID == SaveEnableRulesDebugMode(
					_htFormData))
			{
				result = RepostControl.PAGE_STATUS_INVALID;
			}
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean ShouldOpenNewWindow()
	{
		return m_strOpenWin.equals("1");
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	protected int SaveAccessibility(XPHashtable _htFormData)
	{
		String strErrorMsgs = "";
		int result		    = RepostControl.PAGE_STATUS_VALID;

		String[] data = (String[]) _htFormData.GetElement(AccessibilityView.HTMLRADIO_PORTALSTYLE);

		if ((null != data) && !(0 == data.length))
		{
			m_strAccess = data[0];
		}
		else
		{
			
				log.Warn("DisplayOptModel::SaveMainPage Accessibility view was not in Query String.");
			
		}

		// Report Errors if any
		if (strErrorMsgs.length() > 0)
		{
			result = RepostControl.PAGE_STATUS_INVALID;

			String msg	    = m_asOwner.GetString(999,
					"ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, msg, msg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return result;
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	protected int SaveDisplayOptions(XPHashtable _htFormData)
	{
		String strErrorMsgs = "";
		int result		    = RepostControl.PAGE_STATUS_VALID;

		// Folder Description Type
		String[] data = (String[]) _htFormData.GetElement(DisplayOptView.HTMLRADIO_OPENDOC);

		if ((null != data) && !(0 == data.length))
		{
			m_strOpenWin = data[0];
		}

		// Report Errors if any
		if (strErrorMsgs.length() > 0)
		{
			result = RepostControl.PAGE_STATUS_INVALID;

			String msg	    = m_asOwner.GetString(999,
					"ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, msg, msg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return result;
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	protected int SaveGreeting(XPHashtable _htFormData)
	{
		String strErrorMsgs = "";
		int result		    = RepostControl.PAGE_STATUS_VALID;

		String[] data = (String[]) _htFormData.GetElement(GreetingView.HTMLINPUT_GREETING);

		if ((null != data) && !(0 == data.length))
		{
			m_strGreeting = data[0];
		}
		else
		{
			
				log.Warn("DisplayOptModel::SaveMainPage Greeting was not in Query String.");
			
		}

		data = (String[]) _htFormData.GetElement(TimeoutView.HTMLSELECT_REFRESH);

		if ((null != data) && !(0 == data.length))
		{
			m_strRefreshRate = data[0];
		}
		else
		{
			
				log.Warn("DisplayOptModel::SaveMainPage Refresh Rate was not in Query String.");
			
		}

		// Report Errors if any
		if (strErrorMsgs.length() > 0)
		{
			result = RepostControl.PAGE_STATUS_INVALID;

			String msg	    = m_asOwner.GetString(999,
					"ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, msg, msg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return result;
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	protected int SaveTimeout(XPHashtable _htFormData)
	{
		String strErrorMsgs = "";
		int result		    = RepostControl.PAGE_STATUS_VALID;
		String[] data	    = (String[]) _htFormData.GetElement(TimeoutView.HTMLRADIO_ADMIN);

		if ((null != data) && !(0 == data.length))
		{
			String strChoice = data[0];

			if (strChoice.equals("admin"))
			{
				m_nTimeout = -1;
			}
			else
			{
				data = (String[]) _htFormData.GetElement(TimeoutView.HTMLSELECT_TIMEOUT);

				if ((null != data) && !(0 == data.length))
				{
					try
					{
						m_nTimeout = XPConvert.ToInteger(data[0]);
					}
					catch(Exception e)
					{
						m_nTimeout = -1;
					}
					if (m_nTimeout < 1)
						m_nTimeout = -1;
				}
				else
				{
					
						log.Warn("DisplayOptModel::SaveMainPage Timeout number was not in Query String.");
					
				}
			}
		}
		else
		{
			
				log.Warn("DisplayOptModel::SaveMainPage Admin default timeout was not in Query String.");
			
		}

		// Report Errors if any
		if (strErrorMsgs.length() > 0)
		{
			result = RepostControl.PAGE_STATUS_INVALID;

			String msg	    = m_asOwner.GetString(999,
					"ptmsgs_portalbrowsingmsgs") + strErrorMsgs;
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, msg, msg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return result;
	}
	
	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	protected int SaveEnableRulesDebugMode(XPHashtable _htFormData)
	{
		String strErrorMsgs = "";
		int result		    = RepostControl.PAGE_STATUS_VALID;

		String[] data = (String[]) _htFormData.GetElement(RulesDebugModeView.HTMLINPUT_ENABLE_DEBUG_MODE);
		
		if (data != null)
		{
			m_bEnableRulesDebugMode = XPConvert.ToBoolean(data[0]);
		}
		else
		{
			m_bEnableRulesDebugMode = false;
		}

		return result;
	}

	/**
	 * 
	 *
	 * @param strSetting 
	 *
	 * @return 
	 */
	private int GetIntSetting(String strSetting)
	{
		Object ret		 = PTPersonalSettingsHelper.GetPersonalSettingValue(strSetting,
				m_asOwner);
		int iReturnValue = 0;

		if (ret != null)
		{
			iReturnValue = XPConvert.ToInteger(ret);
		}

		return iReturnValue;
	}

	/**
	 * 
	 *
	 * @param strSetting 
	 *
	 * @return 
	 */
	private String GetStringSetting(String strSetting)
	{
		String ret = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(strSetting,
				m_asOwner);

		//JD- if it's null, set it to an empty string 														 
		if (ret == null)
		{
			ret = "";
		}

		return ret;
	}

	/**
	 * 
	 *
	 * @param strSettingName 
	 * @param intSettingValue 
	 */
	private void SetIntSetting(String strSettingName, int intSettingValue)
	{
		Object iSettingValue = new Integer(intSettingValue);
		PTPersonalSettingsHelper.SetAndCachePersonalSetting(strSettingName,
			iSettingValue, m_asOwner);
	}

	/**
	 * 
	 *
	 * @param strSettingName 
	 * @param strSettingValue 
	 */
	private void SetStringSetting(String strSettingName, String strSettingValue)
	{
		PTPersonalSettingsHelper.SetAndCachePersonalSetting(strSettingName,
			(Object) strSettingValue, m_asOwner);
	}
}

