package com.plumtree.portalpages.browsing.portalsettings.displayoptions;


// Plumtree Server
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * This DP displays the Views for the Display Options page.
 *
 * @author Julie Fournier
 */
public class MainDP extends EditorDP
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "DisplayOptionsMainDP";

	/** Localized String: Display Options */

	

	/**
	 * Returns the String to display on the left navigation menu,
	 * linking to that page.
	 *
	 * @return String
	 */
	public String GetLeftNavString()
	{
		return (m_asOwner.GetString(1286, "ptmsgs_portalbrowsingmsgs"));
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}



	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init( parent );
		
		parent.SetHelpTopic( "PT_DisplayOptions_MainSettings" );	
	}



	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement((m_asOwner.GetView(
				AccessibilityView.STR_MVC_CLASS_NAME)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement((m_asOwner.GetView(
				GreetingView.STR_MVC_CLASS_NAME)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement((m_asOwner.GetView(
				DisplayOptView.STR_MVC_CLASS_NAME)).Display());

		views.AddInnerHTMLElement(EditorView.GetSpacerTable());

		views.AddInnerHTMLElement((m_asOwner.GetView(
				TimeoutView.STR_MVC_CLASS_NAME)).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	* Implement this method to add HTML below the sub header.
	*
	* @return HTMLElement
	*
	* @throws HTMLException
	*/
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		return HTMLConstructHelpers.GetSubHeader(
			m_asOwner.GetString(1449, "ptmsgs_portalbrowsingmsgs"),
			this.m_asOwner);
	}
}

