package com.plumtree.portalpages.browsing.portalsettings.password;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * This control simply marks the user as a guest and redirects to the change
 * password editor.
 */
public class ExpiredPasswordMarkAsGuestControl implements IControl
{
	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "ExpiredPasswordMarkAsGuest";

	protected AActivitySpace m_asOwner;

	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		// We are supposed to mark this user as a guest and redirect to the editor.
		// This needs to happen in a separate request so that it will be set on the
		// new user subsession instead of the old one (and therefore lost).
		m_asOwner.GetSubSession().SetAttribute(Interpreter.USERSESSIONVALID, Boolean.FALSE); 

		Redirect rReturn = new Redirect();
		// Create a new space so the editor is initialized for the new user.
		rReturn.SetLinkCreateNewSpace(PasswordAS.STR_MVC_CLASS_NAME, m_asOwner);
		rReturn.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		rReturn.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);
		rReturn.AddControlArgument(PasswordModel.PASSWORD_EXPIRED, true);

		return rReturn;

	}

	public void Init(IModel _model, AActivitySpace _space) 
	{
		m_asOwner = _space;
	}

	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}

	public Object Create() {
		return new ExpiredPasswordMarkAsGuestControl();
	}
}