package com.plumtree.portalpages.browsing.portalsettings.password;

import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.passwordvalidation.PasswordValidationHelper;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.login.*;

/**
 * @author DonH
 *
 * This activity space lets you change your password.
 */
public class PasswordAS extends PTEditorAS
{
	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "ChangePassword";

	/**
	 * The user session for the change password page - either the normal one stored
	 * on the HTTP session or an expired one stored separately.
	 */
	protected IPTSession m_ptPasswordUserSession = null;

	/**
	 * Whether or not the current user session is an expired one.
	 */
	protected boolean m_bExpiredSession = false;

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorAS#GetEditorTitle()
	 */
	public String GetEditorTitle()
	{
		return GetString(1305, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PasswordAS();
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = PasswordModel.STR_MVC_CLASS_NAME;

		super.Init();

		IModel myModel = GetModel(m_strModelName);

		// Register DisplayPages
		PasswordDP passwordDP = new PasswordDP();
		RegisterPage(passwordDP);

		// Default page
		SetCurrentPage(PasswordDP.STR_MVC_CLASS_NAME);

		// Register Views
		RegisterView(PasswordView.STR_MVC_CLASS_NAME, myModel);

		// Register Controls
		RegisterControl(ExpiredPasswordControl.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(ExpiredPasswordMarkAsGuestControl.STR_MVC_CLASS_NAME, myModel);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(1305, "ptmsgs_portalbrowsingmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID,
			PasswordDP.STR_MVC_CLASS_NAME);
			
		this.SetHelpTopic( "PT_ChangePassword_MainSettings" );
		
		// register the javascript handler for password validation
		passwordDP.AddToValidationFunction(PasswordValidationHelper.STR_JS_CHECK_PASSWORD);
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		// This checks for non-guest native users, and handles expired password users as well.
		return CheckValidUser();
	}

	/**
	 * @return whether or not the user session is an expired session that needs to
	 * change it's password.
	 */
	public boolean GetIsExpiredSession()
	{
		return m_bExpiredSession;
	}

	/**
	 * Return the user's Session.  This is a generic Object that
	 * can be used for different kinds of sessions.  This will
	 * have to be cast to the correct type of session (IPTSession
	 * for the portal).
	 *
	 * This special version of this method for PasswordAS will either
	 * return the normal user session, or the cached expired user session
	 * if it is being hidden by a guest user.
	 * 
	 * @return Object the user's session
	 */
	public Object GetUserSession()
	{
		// If we have already looked up the user session
		if (m_ptPasswordUserSession != null)
		{
			return m_ptPasswordUserSession;
		}

		m_ptPasswordUserSession = (IPTSession) super.GetUserSession();

		if (LoginHelper.INSTANCE.GetIsGuestUser(m_ptPasswordUserSession))
		{
			// If this is a guest user, then there should be an expired user in the cache.
			IPTSession expiredSession = (IPTSession) GetPersistentSubSession().GetAttribute(ExpiredPasswordControl.SESSION);

			if (expiredSession != null)
			{
				m_ptPasswordUserSession = expiredSession;
				m_bExpiredSession = true;
			}
		}

		return m_ptPasswordUserSession;
	}

	/**
	 * This helper method checks that we are a valid logged in native user,
	 * or a valid user with an expired password.
	 *  
	 * @param _space the current space
	 * @return true means the user is valid, false means they are not.
	 */
	public boolean CheckValidUser()
	{
		IPTSession ptUserSession = (IPTSession) GetUserSession();

		// Only allow password change if not guest
		if (LoginHelper.INSTANCE.GetIsGuestUser(ptUserSession))
		{
			// If this is a guest user, and there isn't an expired session to process, fail.
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null, GetString(1295, ResourceConstants.PORTALBROWSINGMSGS), "");
			UIErrorHandler.RaiseError(myError, GetSubSession(), GetApplication());

			return false;
		}

		// Only allow password change if user is not synced to an auth source
		if (ptUserSession.GetUser().GetAuthenticationSourceID() != PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, null, GetString(1294, ResourceConstants.PORTALBROWSINGMSGS), "");
			UIErrorHandler.RaiseError(myError, GetSubSession(), GetApplication());

			return false;
		}

		return true;
	}
}