package com.plumtree.portalpages.browsing.portalsettings.password;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalpages.common.constants.ResourceConstants;
import com.plumtree.portalpages.common.passwordvalidation.PasswordValidationHelper;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author DonH
 *
 * This page displays the basic change password page.
 */
public class PasswordDP extends EditorDP
{
	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "ChangePassword";

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorDP#GetLeftNavString()
	 */
	public String GetLeftNavString()
	{
		return m_asOwner.GetString(1305, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the HTML for the General Info page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay(HTMLTableRow)
	 *
	 * @return HTMLElement
	 */
	public HTMLElement PageDisplay()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		// Insert super class HTML
		result.AddInnerHTMLElement(super.PageDisplay());

		HTMLElementCollection views = new HTMLElementCollection();

		views.AddInnerHTMLElement(m_asOwner.GetView(
				PasswordView.STR_MVC_CLASS_NAME).Display());

		result.AddInnerHTMLElement(CreateLeftNavBar(views));

		return result;
	}

	/**
	* Display the Javascripts for the Views.
	*
	* @return HTMLScriptCollection
	* @throws HTMLException
	*/
	protected HTMLScriptCollection DisplayJavaScriptFromChild()

	{
		HTMLScriptCollection myScripts = null;
		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			myScripts = super.DisplayJavaScriptFromChild();
			myScripts.AddInnerHTMLElement(m_asOwner.GetView(
				PasswordView.STR_MVC_CLASS_NAME).DisplayJavascript());
		}

		return myScripts;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLElement GetHTMLBelowSubHeader()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;

		myTable = new HTMLTable();
		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");
		myTable.SetSummary(m_asOwner.GetString( 1611, "ptmsgs_portalbrowsingmsgs"));

		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		// display sub header message
		myCell = new HTMLTableCell();
		myCell.SetColSpan("2");
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

		IPTServerConfigSettings config = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(
			PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);
		int nMinimumLength = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_LENGTH);
		boolean bIncludeNumbers = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_NUMBERS);
		boolean bIncludeCasing = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_CASING);
		boolean bIncludePunctuation = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_PUNCTUATION);
		boolean bNoUserIds = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_NO_USER_IDS);
		int nReuseHistory = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_REUSE_HISTORY);

		String strRuleCellHeight = "28px";	
		String validIconURL = PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner) + PasswordValidationHelper.STR_VALID_ICON_FILENAME;
		String invalidIconURL = PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner) + PasswordValidationHelper.STR_INVALID_ICON_FILENAME;
		String warningIconURL = PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner) + PasswordValidationHelper.STR_WARNING_ICON_FILENAME;
		String imgValidIconHTML = "<img src='" + validIconURL + "' border='0'/>";
		String imgInvalidIconHTML = "<img src='" + invalidIconURL + "' border='0'/>";
		String imgWarningIconHTML = "<img src='" + warningIconURL + "' border='0'/>";
		
		mySpan.AddInnerHTMLString(m_asOwner.GetString( 1289, "ptmsgs_portalbrowsingmsgs"));
		
		// display password restrictions message
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		
		myCell = new HTMLTableCell();
		myCell.SetColSpan("2");
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		
		mySpan.AddInnerHTMLString(m_asOwner.GetString( 2000, "ptmsgs_portalbrowsingmsgs"));
		
		// Display all the required Password Management Rules
		myRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myRow);
		myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		myCell = new HTMLTableCell();
		myCell.SetWidth("5%");
		myCell.SetHeight(strRuleCellHeight);
		myCell.SetAlign(CommonHTMLStrings.RIGHT);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();
		// Set a section to display "X" or checkmark icon for reporting feedback.
		mySpan.SetID(PasswordValidationHelper.STR_MIN_MAX_LENGTH_STATUS_NAME);
		// Add valid/invalid icon for rule
		mySpan.AddInnerHTMLString(imgInvalidIconHTML);
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		
		myCell = new HTMLTableCell();
		myCell.SetWidth("95%");
		myCell.SetHeight(strRuleCellHeight);
		myRow.AddInnerHTMLElement(myCell);
		mySpan = new HTMLSpan();		
		myCell.AddInnerHTMLElement(mySpan);
		mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		// Password must be between X and 20 chars
		mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(
			m_asOwner.GetString(1999, ResourceConstants.PORTALBROWSINGMSGS), nMinimumLength));
		
		if (bIncludeNumbers)
		{
			// Display Include Numbers Status Icon and Rule
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell = new HTMLTableCell();
			myCell.SetWidth("5%");
			myCell.SetHeight(strRuleCellHeight);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			// Set a section to display "X" or checkmark icon for reporting feedback.
			mySpan.SetID(PasswordValidationHelper.STR_NUMBER_STATUS_NAME);
			// Add valid/invalid icon for rule
			mySpan.AddInnerHTMLString(imgInvalidIconHTML);
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			myCell = new HTMLTableCell();
			myCell.SetWidth("95%");
			myCell.SetHeight(strRuleCellHeight);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();		
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			// Password must contain a number
			mySpan.AddInnerHTMLString(m_asOwner.GetString(1984, ResourceConstants.PORTALBROWSINGMSGS));			
		}
		
		if (bIncludeCasing)
		{
			// Display Include Uppper and Lower Case Status Icon and Rule
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell = new HTMLTableCell();
			myCell.SetWidth("5%");
			myCell.SetHeight(strRuleCellHeight);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			// Set a section to display "X" or checkmark icon for reporting feedback.
			mySpan.SetID(PasswordValidationHelper.STR_LOWER_UPPER_CASE_STATUS_NAME);
			// Add valid/invalid icon for rule
			mySpan.AddInnerHTMLString(imgInvalidIconHTML);
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			myCell = new HTMLTableCell();
			myCell.SetWidth("95%");
			myCell.SetHeight(strRuleCellHeight);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();		
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			// Password must contain upper and lower case letters
			mySpan.AddInnerHTMLString(m_asOwner.GetString(1983, ResourceConstants.PORTALBROWSINGMSGS));			
		}
		
		if (bIncludePunctuation)
		{
			// Display Include Punctuation Status Icon and Rule
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell = new HTMLTableCell();
			myCell.SetWidth("5%");
			myCell.SetHeight(strRuleCellHeight);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			// Set a section to display "X" or checkmark icon for reporting feedback.
			mySpan.SetID(PasswordValidationHelper.STR_PUNCTUATION_STATUS_NAME);
			// Add valid/invalid icon for rule
			mySpan.AddInnerHTMLString(imgInvalidIconHTML);
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			myCell = new HTMLTableCell();
			myCell.SetWidth("95%");
			myCell.SetHeight(strRuleCellHeight);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();		
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			// Password must contain a punctuation mark
			mySpan.AddInnerHTMLString(m_asOwner.GetString(1985, ResourceConstants.PORTALBROWSINGMSGS));			
		}
		
		if (bNoUserIds)
		{
			// Display Cannot Contain UserId Status Icon and Rule
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell = new HTMLTableCell();
			myCell.SetWidth("5%");
			myCell.SetHeight(strRuleCellHeight);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			// Set a section to display "X" or checkmark icon for reporting feedback.
			mySpan.SetID(PasswordValidationHelper.STR_USERNAME_STATUS_NAME);
			// Add valid/invalid icon for rule
			mySpan.AddInnerHTMLString(imgInvalidIconHTML);
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			myCell = new HTMLTableCell();
			myCell.SetWidth("95%");
			myCell.SetHeight(strRuleCellHeight);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();		
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			// Password must contain userid
			mySpan.AddInnerHTMLString(m_asOwner.GetString(1982, ResourceConstants.PORTALBROWSINGMSGS));			
		}		
		
		if (nReuseHistory > 0)
		{
			// Display Password Reuse Rule
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			myCell = new HTMLTableCell();
			myCell.SetWidth("5%");
			myCell.SetHeight(strRuleCellHeight);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			// Add warning icon for rule
			mySpan.AddInnerHTMLString(imgWarningIconHTML);
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			myCell = new HTMLTableCell();
			myCell.SetWidth("95%");
			myCell.SetHeight(strRuleCellHeight);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			// Number of password changes before a password can be reused.
			mySpan.AddInnerHTMLString(XPResourceManager.FormatMessage(
					m_asOwner.GetString(2007, ResourceConstants.PORTALBROWSINGMSGS), nReuseHistory));
		}
		
		return myTable;
	}
}
