package com.plumtree.portalpages.browsing.portalsettings.password;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.common.passwordvalidation.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.utils.BrowserType;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author DonH
 *
 * This view displays the change password box.
 */
public class PasswordView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.password.PasswordView");

	/** MVC object name */
	public static final String STR_MVC_CLASS_NAME = "ChangePassword";

	/** HTML input constants */
	public static final String HTML_INPUT_OLD_PASSWORD = "in_pw_OldPassword";
	public static final String HTML_INPUT_NEW_PASSWORD = "in_pw_NewPassword";
	public static final String HTML_INPUT_CONFIRM_NEW_PASSWORD = "in_pw_ConfirmNewPassword";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PasswordView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLScript myPasswordValidationScript;
		BrowserType bt = new BrowserType(m_asOwner.GetCurrentHTTPRequest());

		try
		{
			result.AddInnerHTMLElement(new HTMLComment("Begin: Change Password View"));

			// Include the javascript file needed for client-side password validation
			myPasswordValidationScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			myPasswordValidationScript.SetSrc(PasswordValidationHelper.GetPasswordValidationJSURL(m_asOwner));			
			result.AddInnerHTMLElement(myPasswordValidationScript);
			
			// Add change password header
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(1306, "ptmsgs_portalbrowsingmsgs")));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");
			myTable.SetSummary(m_asOwner.GetString( 1611, "ptmsgs_portalbrowsingmsgs"));

			// Old Password
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("40%");
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			myCell.AddInnerHTMLString(m_asOwner.GetString(1296, "ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myCell.SetWidth("10%");
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.PASSWORD_TYPE,
					HTML_INPUT_OLD_PASSWORD, 
					HTML_INPUT_OLD_PASSWORD,
					"");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(40);
			myInput.SetSize(40);
			
			// Special Case for IE Browsers. We need to detect backspace key
			// on the OnKeyDown event instead of the OnKeyPress.
			if (bt.IsIE())
			{
				myInput.SetOnKeyDown("return "+ PasswordValidationHelper.STR_JS_HANDLE_BACKSPACE_INPUT + "(event, this);");
			}
			// Call key input handler from ptpasswordvalidation.js to provide input feedback.
			myInput.SetOnKeyPress("return " + PasswordValidationHelper.STR_JS_HANDLE_USER_INPUT + "(event, this);");
			
			// Add hidden status field
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			
			myCell.SetWidth("50%");
			myCell.SetAlign(CommonHTMLStrings.LEFT);
			myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
			myCell.SetID(PasswordValidationHelper.STR_OLD_PASSWORD_VALIDATION_STATUS_NAME);			

			// New Password
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("40%");
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			myCell.AddInnerHTMLString(m_asOwner.GetString(1297, "ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myCell.SetWidth("10%");
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.PASSWORD_TYPE,
					HTML_INPUT_NEW_PASSWORD, 
					HTML_INPUT_NEW_PASSWORD, 
					"");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(40);
			myInput.SetSize(40);
			
			// Special Case for IE Browsers. We need to detect backspace key
			// on the OnKeyDown event instead of the OnKeyPress.
			if (bt.IsIE())
			{
				myInput.SetOnKeyDown("return "+ PasswordValidationHelper.STR_JS_HANDLE_BACKSPACE_INPUT + "(event, this);");
			}
			myInput.SetOnKeyPress("return " + PasswordValidationHelper.STR_JS_HANDLE_USER_INPUT + "(event, this);");
			
			// Add hidden status field
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			
			myCell.SetWidth("50%");
			myCell.SetAlign(CommonHTMLStrings.LEFT);
			myCell.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
			myCell.SetID(PasswordValidationHelper.STR_PASSWORD_VALIDATION_STATUS_NAME);

			// Confirm New Password
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("40%");
			myCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			myCell.AddInnerHTMLString(m_asOwner.GetString(1298, "ptmsgs_portalbrowsingmsgs"));

			myCell = new HTMLTableCell();
			myCell.SetWidth("60%");
			myCell.SetColSpan("2");
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.PASSWORD_TYPE,
					HTML_INPUT_CONFIRM_NEW_PASSWORD, 
					HTML_INPUT_CONFIRM_NEW_PASSWORD,
					"");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(40);
			myInput.SetSize(40);
			
			result.AddInnerHTMLElement(new HTMLComment("End: Change Password View"));
		}
		catch (HTMLException he)
		{
			log.Error(he, STR_MVC_CLASS_NAME +
				"::Display An error occured when trying to display the HTML.");
		}

		return result;
	}
	
	
	/**
	 * Generates Javascript constants that are used in ptpasswordvalidation.js for
	 * all validation. When user hits "Finish" on the editor page, it will check that
	 * the password is at least the minimum length required.
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		
		IPTServerConfigSettings config = (IPTServerConfigSettings) ((IPTSession) m_asOwner.GetUserSession()).OpenGlobalObject(
				PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);
		int nMinimumLength = config.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_LENGTH);
		boolean bIncludeNumbers = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_NUMBERS);
		boolean bIncludeCasing = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_CASING);
		boolean bIncludePunctuation = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_INCLUDE_PUNCTUATION);
		boolean bNoUserIds = config.GetSettingAsBoolean(PT_SERVER_CONFIG_SETTINGNAME.PT_PASSWORD_NO_USER_IDS);
		String strUserID = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserLoginName();
		
		// Generate Javascript constants and i18n strings to be used in client-side validation.
		XPStringBuilder sb  = new XPStringBuilder();
		
		sb.Append("var ").Append(PasswordValidationHelper.STR_PASSWORD_VALIDATION_JS_NAMESPACE).Append(" = function() {\n");
		sb.Append("    return {\n");
		
		// Current settings for Password Management
		sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_MIN_LENGTH).Append(" : '").Append(nMinimumLength).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_MAX_LENGTH).Append(" : '20',\n");		
		sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_INCLUDE_NUMBERS).Append(" : '").Append(bIncludeNumbers).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_INCLUDE_CASING).Append(" : '").Append(bIncludeCasing).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_INCLUDE_PUNCTUATION).Append(" : '").Append(bIncludePunctuation).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_PASSWORD_NO_USER_IDS).Append(" : '").Append(bNoUserIds).Append("',\n");
		
		// i18n Strings
		sb.Append("        ").Append(PasswordValidationHelper.PASSWORDS_MUST_BE_SAME_I18N).Append(" : '").
							Append(m_asOwner.GetString(2001, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.PASSWORDS_MIN_LENGTH_I18N).Append(" : '").
							Append(XPResourceManager.FormatMessage(m_asOwner.GetString(2002, ResourceConstants.PORTALBROWSINGMSGS), nMinimumLength)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.ENTER_USERNAME_I18N).Append(" : '").
							Append(m_asOwner.GetString(2003, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.ENTER_OLD_PASSWORD_I18N).Append(" : '").
							Append(m_asOwner.GetString(2004, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.PASSWORD_TOO_SHORT_I18N).Append(" : '").
							Append(XPResourceManager.FormatMessage(m_asOwner.GetString(1628, ResourceConstants.PORTALBROWSINGMSGS), nMinimumLength)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.PASSWORD_TOO_LONG_I18N).Append(" : '").
							Append(m_asOwner.GetString(1291, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.NO_BLANK_SPACES_I18N).Append(" : '").
							Append(m_asOwner.GetString(2005, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.MUST_CONTAIN_UPPER_LOWER_CASE_I18N).Append(" : '").
							Append(m_asOwner.GetString(1983, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.MUST_CONTAIN_NUMBER_I18N).Append(" : '").
							Append(m_asOwner.GetString(1984, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.MUST_CONTAIN_PUNCTUATION_I18N).Append(" : '").
							Append(m_asOwner.GetString(1985, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.CANNOT_CONTAIN_USER_ID_I18N).Append(" : '").
							Append(m_asOwner.GetString(1982, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.PASSWORD_VALID_I18N).Append(" : '").
							Append(m_asOwner.GetString(2006, ResourceConstants.PORTALBROWSINGMSGS)).Append("',\n");
		
		// Current Username
		sb.Append("        ").Append(PasswordValidationHelper.STR_CURRENT_USERNAME).Append(" : '").Append(strUserID).Append("',\n");
		
		// Password Input Field Element Id Constants
		sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_OLD_PASSWORD_ID).Append(" : '").
							Append(HTML_INPUT_OLD_PASSWORD).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_NEW_PASSWSORD_ID).Append(" : '").
							Append(HTML_INPUT_NEW_PASSWORD).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_CONFIRM_PASSWORD_ID).Append(" : '").
							Append(HTML_INPUT_CONFIRM_NEW_PASSWORD).Append("',\n");
		
		// Password Validation Status Field Element Id Constants
		sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_OLD_PASSWORD_VALIDATION_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_OLD_PASSWORD_VALIDATION_STATUS_NAME).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_INPUT_PASSWORD_VALIDATION_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_PASSWORD_VALIDATION_STATUS_NAME).Append("',\n");	

		// Icon Element Ids for each of the Client-Side Password Validation Rules
		sb.Append("        ").Append(PasswordValidationHelper.STR_MIN_MAX_LENGTH_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_MIN_MAX_LENGTH_STATUS_NAME).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_NUMBER_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_NUMBER_STATUS_NAME).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_LOWER_UPPER_CASE_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_LOWER_UPPER_CASE_STATUS_NAME).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_PUNCTUATION_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_PUNCTUATION_STATUS_NAME).Append("',\n");
		sb.Append("        ").Append(PasswordValidationHelper.STR_USERNAME_STATUS_ID).Append(" : '").
							Append(PasswordValidationHelper.STR_USERNAME_STATUS_NAME).Append("',\n");
		
		// URLs to validation icons for displaying feedback to user
		sb.Append("        ").Append(PasswordValidationHelper.STR_VALID_ICON_URL).Append(" : '").Append(PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner)).
							Append(PasswordValidationHelper.STR_VALID_ICON_FILENAME).Append("',\n");		
		sb.Append("        ").Append(PasswordValidationHelper.STR_INVALID_ICON_URL).Append(" : '").Append(PasswordValidationHelper.GetPortalImageServerFolderURL(m_asOwner)).
							Append(PasswordValidationHelper.STR_INVALID_ICON_FILENAME).Append("'\n");		
		sb.Append("    };\n");
		sb.Append("}();\n");
		
		myScript.AddInnerHTMLString(sb.ToString());

		return myScript;
	}
}