package com.plumtree.portalpages.browsing.portalsettings.passwordmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 *
 *	@author jennifersu
 *
 */
public class LockboxView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.passwordmanager.LockboxView");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "LockboxView";
	
	public static final String HTMLINPUT_USERNAME = "in_tx_username";

	public static final String HTMLINPUT_PASSWORD = "in_pw_password";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LockboxView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * JavaScript for opening tree selectors and retrieving values on return
	 * from tree.
	 *
	 * @return JavaScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript result = super.DisplayJavascript();

		return result;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorView#Display()
	 */
	public HTMLElement Display() {
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLSpan mySpan;

		try
		{
			IPasswordManagerSectionModelRO myModel = (IPasswordManagerSectionModelRO)m_model;

			result.AddInnerHTMLElement(super.GetHeaderView(myModel.GetLockboxName()));

			result.AddInnerHTMLString("\n<!-- Begin: Display " + STR_MVC_CLASS_NAME + " -->\n");

			HTMLTable myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);

			HTMLTableRow myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			HTMLTableCell myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetWidth("150");
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(myModel.GetUsernamePropName());
			myCell.AddInnerHTMLElement(mySpan);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.LEFT);

			HTMLInput nameInput;
			HTMLAnchor propAnchor;
			
			nameInput = new HTMLInput(HTMLInputTypes.TEXT, HTMLINPUT_USERNAME + myModel.GetUsernamePropID(), "");
			myCell.AddInnerHTMLElement(nameInput);
			nameInput.SetSize(50);
			nameInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			nameInput.SetValue(myModel.GetUsernameValue());

			// Second row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myCell.SetWidth("150");
			mySpan = new HTMLSpan();
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			
			mySpan.AddInnerHTMLString(myModel.GetPasswordPropName());
			myCell.AddInnerHTMLElement(mySpan);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetAlign(CommonHTMLStrings.LEFT);

			nameInput = new HTMLInput(HTMLInputTypes.PASSWORD, HTMLINPUT_PASSWORD + myModel.GetPasswordPropID(), "");
			myCell.AddInnerHTMLElement(nameInput);
			nameInput.SetSize(50);
			nameInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			nameInput.SetValue(myModel.GetPasswordValue());
			
			result.AddInnerHTMLString("\n<!-- End: Display " + STR_MVC_CLASS_NAME + " -->\n");
		}
		catch (Exception e)
		{
			log.Error(e, STR_MVC_CLASS_NAME + "::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(62, "ptmsgs_portalinfrastructure"), e);
		}

		return result;
	}
}

