package com.plumtree.portalpages.browsing.portalsettings.passwordmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.userprofile.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.common.constants.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * @author JenniferSu
 */
public class PasswordManagerAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerAS");

	private static final String sClassName = "com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerAS";

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "PasswordManagerAS";

	/** member variable describing the lockbox object editor **/
	public static final String m_strLockboxObjEdit = "ObjectEditor";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PasswordManagerAS();
	}

	/**
	 * Sets the Editor title.
	 *
	 */
	public String GetEditorTitle()
	{
		return GetString(1835, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (UserProfileRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes for this Activity Space.
	 */
	public void Init()
	{
		m_strModelName = PasswordManagerModel.STR_MVC_CLASS_NAME;

		super.Init();
		
		PasswordManagerModel myModel = (PasswordManagerModel)GetModel(m_strModelName);

		RegisterControl(UserProfileRepostControl.STR_MVC_CLASS_NAME, myModel);

		XPArrayList alPages = myModel.GetProfilePages();
		if (alPages != null && alPages.GetSize() > 0)
		{
			IPTProfilePage page = (IPTProfilePage)alPages.GetElement(0);
            Object[] arSections = page.GetChildSections();

            String subHeaderText = null;
            if(arSections.length == 0)
            {
                subHeaderText = GetString(1898, ResourceConstants.PORTALBROWSINGMSGS);
            }
            else
            {
                subHeaderText = GetString(1837, ResourceConstants.PORTALBROWSINGMSGS);
            }
            GeneralProfileDP passwordManagerDP
                = new GeneralProfileDP(
                    page,
                    0,
                    "MainDP",
                    GetString(1836, ResourceConstants.PORTALBROWSINGMSGS),
                    subHeaderText);
			RegisterPage(passwordManagerDP);

			IPTObjectManager profileSectionObjMgr = ((IPTSession)GetUserSession()).GetProfileSections();

			((PasswordManagerModel) GetModel(m_strModelName)).SetNumProfileSectionsTable(0, arSections.length);

            // mel: Fix for bug# 45118, XPNullPointerException was thrown
            // when Password Manager initialized because no model
            // was registered if no lockboxes were configured.
            if(arSections.length == 0)
            {
                RegisterModel(UserProfileObjEditModel.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "00");
            }
            else
            {
    			for (int indLockbox = 0; indLockbox < arSections.length; indLockbox++)
    			{
    				int nSectionID = XPConvert.ToInteger(arSections[indLockbox]);
    				IPTProfileSection profileSection = (IPTProfileSection)profileSectionObjMgr.Open(nSectionID, false);
    				RegisterModel(UserProfileObjEditModel.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "0" + indLockbox);

    				// Get back the Model we just registered because we need it to register the Section
    				UserProfileObjEditModel myObjEditorModel = (UserProfileObjEditModel) GetModel(m_strLockboxObjEdit + "0" + indLockbox);
    				myObjEditorModel.Init(profileSection);
    				RegisterView(GeneralInfoView.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "0" + indLockbox, myObjEditorModel);
    				RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, m_strLockboxObjEdit + "0" + indLockbox, myObjEditorModel);
    			}
            }
		}
		else
		{
			log.Error(STR_MVC_CLASS_NAME + "::Init Unable to load PTProfilePage for the PasswordManager.");
			String sMessage = "Unable to load PTProfilePage for the PasswordManager";
			String sExceptionMessage = "Unable to load PTProfilePage for the PasswordManager";

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
				UIErrorScope.CURRENT_USER, null, 
				sMessage, null);
			UIErrorHandler.RaiseError(myError,
				GetSubSession(), GetApplication());

			throw new XPException(sExceptionMessage);			
		}
			
		SetCurrentPage("MainDP");
		
		this.SetHelpTopic("PT_PasswordManager");
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		// make sure this is not the guest user
		boolean isGuest = PlumtreeHelpers.IsGuestSession(this);
		if (isGuest)
		{
			return false;
		}
		
		return true;
	}	
}

