package com.plumtree.portalpages.browsing.portalsettings.passwordmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.userprofile.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author jennifersu
 */
public class PasswordManagerModel extends UserProfileModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerModel");

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "PasswordManagerModel";

	private Object[] m_arLockboxes;
	
	/**
	 * Code executed when the Editor is starting. Get all of the property
	 * information for the user
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{		
		boolean bAccess;
		
		bAccess = super.CheckEditorAccessAndStart(_htFormData);
		SetHideLeftNav(true);

		IPTProfilePage ptProfilePage = (IPTProfilePage)m_alProfilePages.GetElement(0);
		m_arLockboxes = ptProfilePage.GetChildSections();

		return bAccess;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PasswordManagerModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param aspace 
	 */
	public void Init(AActivitySpace aspace)
	{
		m_asOwner = aspace;

		// Look up lockboxes.
		m_alProfilePages = new XPArrayList();
		IPTObjectManager profilePageObjMgr = ((IPTSession)m_asOwner.GetUserSession()).GetProfilePages();
		PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(profilePageObjMgr);
		Object[][] queryFilter = PlumtreeHelpers.GetQueryFilter(PT_PROPIDS.PT_PROPID_OBJECTID, PT_FILTEROPS.PT_FILTEROP_EQ, new Integer(PT_INTRINSICS.PT_PROFILE_PAGE_CREDENTIAL_VAULT));
		omqw.Query(PT_PROPIDS.PT_PROPID_OBJECTID, -1, null, queryFilter);

		if (omqw.GetCount() > 0)
		{
			IPTProfilePage page = (IPTProfilePage)profilePageObjMgr.Open(1, false);
			m_alProfilePages.Add(page);
			m_numProfilePages++;
		}

		//Load all property values into a hashtable
		m_htPropTypeTable = new XPHashtable();
		m_htPropValueTable = PutUserPropertiesIntoHashtable();
	}

	/**
	 *
	 *
	 * @param _sectionIndex
	 *
	 * @return
	 */
	public Object[] GetLockboxIDs()
	{
		return m_arLockboxes;
	}

    /**
     * We need to overwrite this method here, simply because parent implements it within
     * its own context, which fails for this specific class. Basically we are replication
     * what was implemented in EditorModel here.
     * @return
     */
    public Redirect GetRedirectAfterFinish() {
        Redirect result = new Redirect();
        if (null != m_asOwner.GetParentSpace()) {
            result.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
        } else {
            result.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
        }
        return (result);
    }
}

