package com.plumtree.portalpages.browsing.portalsettings.passwordmanager;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author jennifersu
 *
 */
public class PasswordManagerSectionModel extends EditorHelperModel implements IPasswordManagerSectionModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.passwordmanager.PasswordManagerSectionModel");

	/** object name **/
	public static final String STR_MVC_CLASS_NAME = "PasswordManagerSectionModel";

	protected int m_nUsernamePropID;
	protected int m_nPasswordPropID;
	protected IPTSession m_ptSession;
	protected IPTProperty m_objUsernameProp;
	protected IPTProperty m_objPasswordProp;
	protected String m_strUsernameValue;
	protected String m_strPasswordValue;
	protected IPTProfileSection m_ptLockbox;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PasswordManagerSectionModel();
	}

	/**
	 * Initialize member variables
	 * @param _ptLockbox - IPTProfileSection that this lockbox represents.
	 */
	public void Init(IPTProfileSection _ptLockbox)
	{
		m_ptLockbox = _ptLockbox;
		
		Object[] arPropIDs = m_ptLockbox.GetChildProperties();
		if (arPropIDs.length >= 2)
		{
			m_nUsernamePropID = XPConvert.ToInteger(arPropIDs[0]);
			m_nPasswordPropID = XPConvert.ToInteger(arPropIDs[1]);
		}
		
		m_ptSession = (IPTSession)m_asOwner.GetUserSession();

		IPTObjectManager propMgr = m_ptSession.GetProperties();
		IPTProfileManager pm = (IPTProfileManager) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_PROFILE_MANAGER, false);
		IPTObjectProperties userProps = pm.GetUserProperties(((IPTSessionInfo) m_ptSession.GetSessionInfo()).GetCurrentUserID(), true);

		// Load username
		IPTQueryResult ptQR = propMgr.QuerySingleObject(m_nUsernamePropID);
		if (ptQR.RowCount() > 0)
		{
			m_objUsernameProp = (IPTProperty)propMgr.Open(m_nUsernamePropID, false);
			ptQR = userProps.GetSinglePropertyData(m_nUsernamePropID, PT_PROPIDS.PT_PROPID_PROP_VALUE);
			if (ptQR.RowCount() > 0)
			{
				m_strUsernameValue = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);			
			}
		}

		// Load password
		ptQR = propMgr.QuerySingleObject(m_nPasswordPropID);
		if (ptQR.RowCount() > 0)
		{
			m_objPasswordProp = (IPTProperty)propMgr.Open(m_nPasswordPropID, false);			
			ptQR = userProps.GetSinglePropertyData(m_nPasswordPropID, PT_PROPIDS.PT_PROPID_PROP_VALUE);
			if (ptQR.RowCount() > 0)
			{
				m_strPasswordValue = ptQR.ItemAsString(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);			
			}
		}
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.editor.EditorHelperModel#SaveSection(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public int SaveSection(XPHashtable _htFormData) {
		int nValid = RepostControl.PAGE_STATUS_VALID;
		
		m_strUsernameValue = ModelHelper.GetFormElementString(_htFormData, LockboxView.HTMLINPUT_USERNAME + m_nUsernamePropID, m_strUsernameValue);

		m_strPasswordValue = ModelHelper.GetFormElementString(_htFormData, LockboxView.HTMLINPUT_PASSWORD + m_nPasswordPropID, m_strPasswordValue);

		return nValid;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetUsernameValue()
	 */
	public String GetUsernameValue()
	{
		return m_strUsernameValue;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetPasswordValue()
	 */
	public String GetPasswordValue()
	{
		return m_strPasswordValue;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetUsernamePropName()
	 */
	public String GetUsernamePropName()
	{
		return m_objUsernameProp.GetLocalizedName();
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetPasswordPropName()
	 */
	public String GetPasswordPropName()
	{
		return m_objPasswordProp.GetLocalizedName();
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetLockboxName()
	 */
	public String GetLockboxName()
	{
		return m_ptLockbox.GetLocalizedName();
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetUsernamePropID()
	 */
	public int GetUsernamePropID()
	{
		return m_nUsernamePropID;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.browsing.portalsettings.passwordmanager.IPasswordManagerSectionModelRO#GetPasswordPropID()
	 */
	public int GetPasswordPropID()
	{
		return m_nPasswordPropID;
	}
}

