package com.plumtree.portalpages.browsing.portalsettings.search;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS, based on JulieF template
 */
public class SearchSettingsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portalsettings.search.SearchSettingsView");

	
	public static final String STR_MVC_CLASS_NAME = "SearchSettings";

	public static final String SPACE = "&nbsp;";

	protected static final Spacer spacerNarrow		  = new Spacer("5");
	protected static final Spacer spacerWide		  = new Spacer("15");

	public static final String HTMLINPUT_LIMITBYLOCALE     = "in_ra_limitbylocale";

	public static final String HTMLINPUT_LIMITBYLOCALE_YES = "y";
	public static final String HTMLINPUT_LIMITBYLOCALE_NO = "n";
	
	public static final String HTMLINPUT_PAGESIZE = "in_se_pagesize";

	public static final String HTMLINPUT_GROUPBY     = "in_se_groupby";

	public static final String HTMLINPUT_RET_CARDS		 = "in_cb_ret_cards";
	public static final String HTMLINPUT_RET_FOLDERS     = "in_cb_ret_folders";
	public static final String HTMLINPUT_RET_USERS		 = "in_cb_ret_users";
	public static final String HTMLINPUT_RET_COMMUNITIES = "in_cb_ret_communities";
	public static final String HTMLINPUT_RET_PORTLETS = "in_cb_ret_portlets";
	public static final String HTMLINPUT_RET_COLLAB  = "in_cb_ret_collab";
	public static final String HTMLINPUT_RET_CONTENT = "in_cb_ret_content";
	public static final String HTMLINPUT_RET_PAGES = "in_cb_ret_pages";
	
	public static final String HTMLINPUT_RENAME_SS = "in_tx_ss_";

	
	public static final String HTMLINPUT_DELETE_SS = "in_cb_ss_";

	/**
	 * 
	 *
	 * @return 
	 */
	public Object Create()
	{
		return new SearchSettingsView();
	}

	/**
	 * Returns the HTML for the view.
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable table;
		HTMLTableRow row;
		HTMLTableCell cell;
		HTMLSpan span;
		HTMLInput input;
		HTMLSelect select;
		HTMLOption option;

		SearchSettingsModel model = (SearchSettingsModel) m_model;

		try
		{
			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1033,
					"ptmsgs_portalbrowsingmsgs")); // "search preferences"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerNarrow.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("center");
			cell.SetWidth("100%");
			cell.SetHeight("20");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			span.AddInnerHTMLString(m_asOwner.GetString(1041,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(SPACE);

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("5");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1041,
					"ptmsgs_portalbrowsingmsgs")); // "Object types"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerWide.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("top");
			cell.SetNoWrap(true);
			cell.SetWidth("225");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			span.AddInnerHTMLString(m_asOwner.GetString(1042,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			cell.SetWidth("100%");
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			row.AddInnerHTMLElement(cell);

			boolean[] retTypes = model.GetReturnedObjectTypes();

			input = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLINPUT_RET_CARDS,
					HTMLINPUT_RET_CARDS, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_CARDS]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1043,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(new HTMLBr());

			input = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLINPUT_RET_FOLDERS, HTMLINPUT_RET_FOLDERS, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_FOLDERS]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1044,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(new HTMLBr());

			input = new HTMLInput(HTMLInputTypes.CHECKBOX, HTMLINPUT_RET_USERS,
					HTMLINPUT_RET_USERS, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_USERS]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1045,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(new HTMLBr());

			input = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLINPUT_RET_COMMUNITIES, HTMLINPUT_RET_COMMUNITIES, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_COMMUNITIES]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1046,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(new HTMLBr());

			input = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLINPUT_RET_PAGES, HTMLINPUT_RET_PAGES, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_PAGES]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(505,
					"ptmsgs_portalinfrastructure"));
			cell.AddInnerHTMLElement(new HTMLBr());

			input = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLINPUT_RET_PORTLETS, HTMLINPUT_RET_PORTLETS, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_PORTLETS]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1047,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(new HTMLBr());

                        if (model.IsCollabInstalled()) {
                          input = new HTMLInput(HTMLInputTypes.CHECKBOX,
                                                HTMLINPUT_RET_COLLAB, HTMLINPUT_RET_COLLAB, "");
                          input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
                          input.SetChecked(retTypes[SearchSettingsModel.RETURNED_COLLAB]);
                          cell.AddInnerHTMLElement(input);

                          cell.AddInnerHTMLString(m_asOwner.GetString(1048,
                                                                      "ptmsgs_portalbrowsingmsgs"));
                          cell.AddInnerHTMLElement(new HTMLBr());
                        }

			input = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLINPUT_RET_CONTENT, HTMLINPUT_RET_CONTENT, "");
			input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
			input.SetChecked(retTypes[SearchSettingsModel.RETURNED_CONTENT]);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1049,
					"ptmsgs_portalbrowsingmsgs"));

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1050,
					"ptmsgs_portalbrowsingmsgs")); // "languages"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerNarrow.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("center");
			cell.SetWidth("100%");
			cell.SetHeight("20");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			span.AddInnerHTMLString(m_asOwner.GetString(1050,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(SPACE);

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("5");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1050,
					"ptmsgs_portalbrowsingmsgs")); // "Search in languages"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerWide.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("top");
			cell.SetNoWrap(true);
			cell.SetWidth("225");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			span.AddInnerHTMLString(m_asOwner.GetString(1051,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			cell.SetWidth("100%");
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			row.AddInnerHTMLElement(cell);

			input = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLINPUT_LIMITBYLOCALE, HTMLINPUT_LIMITBYLOCALE, "");
			input.SetStyleClass(PTStyleClass.FORM_RADIO);
			input.SetChecked(!model.IsRestrictedToDefaultLanguage());
			input.SetValue(HTMLINPUT_LIMITBYLOCALE_NO);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1052,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(new HTMLBr());

			input = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLINPUT_LIMITBYLOCALE, HTMLINPUT_LIMITBYLOCALE, "");
			input.SetStyleClass(PTStyleClass.FORM_RADIO);
			input.SetChecked(model.IsRestrictedToDefaultLanguage());
			input.SetValue(HTMLINPUT_LIMITBYLOCALE_YES);
			cell.AddInnerHTMLElement(input);

			cell.AddInnerHTMLString(m_asOwner.GetString(1053,
					"ptmsgs_portalbrowsingmsgs"));

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1055,
					"ptmsgs_portalbrowsingmsgs")); // "Results per page"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerNarrow.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("center");
			cell.SetWidth("100%");
			cell.SetHeight("20");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			span.AddInnerHTMLString(m_asOwner.GetString(1054,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(SPACE);

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("5");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1055,
					"ptmsgs_portalbrowsingmsgs")); // "Results per page"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerWide.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("top");
			cell.SetNoWrap(true);
			cell.SetWidth("225");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			span.AddInnerHTMLString(m_asOwner.GetString(1055,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);

			cell = new HTMLTableCell();
			cell.SetWidth("100%");
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			row.AddInnerHTMLElement(cell);

			select = new HTMLSelect(HTMLINPUT_PAGESIZE, "");
			select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			cell.AddInnerHTMLElement(select);

			int pageSize = model.GetPageSize();

			option = new HTMLOption("");
			select.AddInnerHTMLElement(option);

			option.AddInnerHTMLString(m_asOwner.GetString(1056,
					"ptmsgs_portalbrowsingmsgs"));

			option.SetValue(m_asOwner.GetString(1056,
					"ptmsgs_portalbrowsingmsgs"));
			option.SetSelected(pageSize == 10);

			option = new HTMLOption("");
			select.AddInnerHTMLElement(option);

			option.AddInnerHTMLString(m_asOwner.GetString(1057,
					"ptmsgs_portalbrowsingmsgs"));

			option.SetValue(m_asOwner.GetString(1057,
					"ptmsgs_portalbrowsingmsgs"));
			option.SetSelected(pageSize == 20);

			option = new HTMLOption("");
			select.AddInnerHTMLElement(option);

			option.AddInnerHTMLString(m_asOwner.GetString(1058,
					"ptmsgs_portalbrowsingmsgs"));

			option.SetValue(m_asOwner.GetString(1058,
					"ptmsgs_portalbrowsingmsgs"));
			option.SetSelected(pageSize == 50);

			option = new HTMLOption("");
			select.AddInnerHTMLElement(option);

			option.AddInnerHTMLString(m_asOwner.GetString(1059,
					"ptmsgs_portalbrowsingmsgs"));

			option.SetValue(m_asOwner.GetString(1059,
					"ptmsgs_portalbrowsingmsgs"));
			option.SetSelected(pageSize == 100);

                        // begin preferred group-by
			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1826,   // "Sorting"
					"ptmsgs_portalbrowsingmsgs")); 
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerNarrow.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("center");
			cell.SetWidth("100%");
			cell.SetHeight("20");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			span.AddInnerHTMLString(m_asOwner.GetString(1826,   // "Sorting"
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(SPACE);

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("5");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1825,
					"ptmsgs_portalbrowsingmsgs")); // "Sort results by:"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerWide.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("top");
			cell.SetNoWrap(true);
			cell.SetWidth("225");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			span.AddInnerHTMLString(m_asOwner.GetString(1825,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);

			cell = new HTMLTableCell();
			cell.SetWidth("100%");
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			row.AddInnerHTMLElement(cell);

			select = new HTMLSelect(HTMLINPUT_GROUPBY, "");
			select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			cell.AddInnerHTMLElement(select);

                        String groupBy = model.GetPreferredGroupBy();

                        // first, add the "relevance" setting
			option = new HTMLOption("");
			select.AddInnerHTMLElement(option);
                        option.SetValue("");
                        option.AddInnerHTMLString(m_asOwner.GetString(819, "ptmsgs_portalbrowsingmsgs"));
                        option.SetSelected(groupBy == null);

                        // next, add all other possible group-by settings
                        String[][] possibleGroupBy = model.GetPossibleGroupBy();
                        for (int j = 0; j < possibleGroupBy.length; j++) {
                          option = new HTMLOption("");
                          select.AddInnerHTMLElement(option);
                          option.SetValue(possibleGroupBy[j][0]);
                          option.AddInnerHTMLString(possibleGroupBy[j][1]);
                          option.SetSelected((groupBy != null) && (groupBy.equals(possibleGroupBy[j][0])));
                        }
                        // end group-by

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("0");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1060,
					"ptmsgs_portalbrowsingmsgs")); // "Saved searches"
			result.AddInnerHTMLElement(table);

			if (!is508())
			{
				spacerNarrow.display(result);
			}

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("center");
			cell.SetWidth("100%");
			cell.SetHeight("20");

			span = new HTMLSpan();
			span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

			span.AddInnerHTMLString(m_asOwner.GetString(1060,
					"ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span);
			cell.SetNoWrap(true);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(SPACE);

			table = new HTMLTable();
			table.SetCellSpacing("0");
			table.SetCellPadding("5");
			table.SetWidth("100%");
			table.SetSummary(m_asOwner.GetString(1060,
					"ptmsgs_portalbrowsingmsgs")); // "Saved searches"
			result.AddInnerHTMLElement(table);

			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);
			row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			cell.SetVAlign("top");
			cell.SetNoWrap(true);

			Object[][] saved = model.GetSavedSearches();

			if ((null == saved) || (null == saved[0]) ||
					(0 == saved[0].length))
			{
				cell.SetColSpan("2");
				cell.SetWidth("100%");

				cell.AddInnerHTMLString(m_asOwner.GetString(1061,
						"ptmsgs_portalbrowsingmsgs"));
			}
			else
			{
				cell.SetWidth("225");

				span = new HTMLSpan();
				span.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

				span.AddInnerHTMLString(m_asOwner.GetString(1062,
						"ptmsgs_portalbrowsingmsgs"));
				cell.AddInnerHTMLElement(span);
				cell.SetNoWrap(true);

				cell = new HTMLTableCell();
				cell.SetWidth("100%");
				cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				cell.SetNoWrap(true);
				row.AddInnerHTMLElement(cell);

				for (int j = 0; j < saved[0].length; j++)
				{
					input = new HTMLInput(HTMLInputTypes.TEXT,
							HTMLINPUT_RENAME_SS + j, "");
					input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
					input.SetSize("30");
					input.SetValue((String) (saved[0][j]));
					cell.AddInnerHTMLElement(input);

					cell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");

					input = new HTMLInput(HTMLInputTypes.CHECKBOX,
							HTMLINPUT_DELETE_SS + j, "");
					input.SetChecked(false);
					input.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
					cell.AddInnerHTMLElement(input);

					cell.AddInnerHTMLString(m_asOwner.GetString(1063,
							"ptmsgs_portalbrowsingmsgs"));
					cell.AddInnerHTMLElement(new HTMLBr());
				}
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "SearchSettingsView.Display.");
			

			throw new XPException(m_asOwner.GetString(1040,
					"ptmsgs_portalbrowsingmsgs"), e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript("text/javaScript");

		return script;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	private boolean is508()
	{
		return (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD);
	}
}

