package com.plumtree.portalpages.browsing.portalsettings.settings;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.portalpages.browsing.portalsettings.*;
import com.plumtree.portalpages.browsing.portalsettings.password.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.uiinfrastructure.login.*;

/**
 * @author DonH
 *
 * This describes a link to the change password space.
 */
public class PasswordPortalSetting implements IPortalSettings
{

	/**
	 * @see com.plumtree.portalpages.browsing.portalsettings.IPortalSettings#GetDescription(String)
	 */
	public String GetDescription(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
		return rm.GetString(1815, "ptmsgs_portalbrowsingmsgs", _strLangID);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.portalsettings.IPortalSettings#GetImageLocation()
	 */
	public String GetImageLocation()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.portalsettings.IPortalSettings#GetDisplaySetting(Object)
	 */
	public boolean GetDisplaySetting(Object session)
	{
		IPTSession ptSession = (IPTSession) session;

		// Only display if not guest
		// WilliamA - Change guest user detection for multiple-guest-user support
		/*
		if (ptSession.GetSessionInfo().GetCurrentUserID() == PT_INTRINSICS.PT_USER_GUEST)
		{
			return false;
		}
		*/

		if (LoginHelper.INSTANCE.GetIsGuestUser(ptSession))
		{
			return false;
		}

		// Need to catch -- bug where user could not see own account... not OK
		try
		{
			// Only display setting if user is not synced to an auth source
			if (ptSession.GetUser().GetAuthenticationSourceID() != PT_INTRINSICS.PT_AUTHSOURCE_PLUMTREE)
			{
				return false;
			}
		}
		catch (Exception e)
		{
			//SS - If the server throws an error we assume that the setting should not 
			//be displayed.
			return false;
		}

		return true;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#GetASControlName()
	 */
	public String GetASControlName()
	{
		return EditorStartControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#GetASDPName()
	 */
	public String GetASDPName()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#GetASName()
	 */
	public String GetASName()
	{
		return PasswordAS.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#GetASQueryString()
	 */
	public String GetASQueryString()
	{
		return LinkConstants.AMPERSAND + EditorStartControl.QS_EDITOR_TYPE + LinkConstants.EQUALS + EditorStartControl.EDITOR_START_FLAG_MISC;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#GetLinkText(String)
	 */
	public String GetLinkText(String _strLangID)
	{
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
		return rm.GetString(1305, "ptmsgs_portalbrowsingmsgs", _strLangID);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#IsStandardPortalOption()
	 */
	public boolean IsStandardPortalOption()
	{
		return true;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.settings.ISettings#IsViewable()
	 */
	public boolean IsViewable()
	{
		return true;
	}
	
	public int GetActivityRightRestriction()
	{
		return PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_NONE;
	}
}

