package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * File: AddPortletControl.java
 * ---------------------------
 * Control for adding gadget via gadget invitation
 *
 * @author NaveenP/DustinA
 */
public class AddPortletControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.AddPortletControl");

	
	public static final String STR_MVC_CLASS_NAME = "AddGadget";

	/** QueryString Parameter for Page ID*/
	public static final String strPageParam = "in_se_pageMenu";

	/** Logging */
	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private PreviewPortletModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		Redirect objRedirect = new Redirect();
		objRedirect.SetLinkGetCachedSpace(m_asOwner);

		objRedirect.SetDisplayPage(PortletInvitationJoinDP.STR_MVC_CLASS_NAME);

		String[] sValues = (String[]) arguments.GetElement(strPageParam);

		if (sValues == null)
		{
		    // DCA - Fix to bug #27785: since this is merely a preview of the portlet,
			// repost functionality will be ignored
			log.Warn("Could not find page ID in query string. Cannot handle portlet reposting in preview mode.");
			return null;
		}

		String[] sHostPageURIs = (String[]) arguments.GetElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL);

		if ((null != sHostPageURIs) && (sHostPageURIs.length > 0))
		{
			m_asModel.SetHostPageURI(sHostPageURIs[0]);
		}

		String[] sHeaders = (String[]) arguments.GetElement(HttpUtils.HASHTABLE_CONTROL_KEY_HTTP_HEADERS);

		if ((null != sHeaders) && (sHeaders.length > 0))
		{
			m_asModel.SetRawHeaders(sHeaders[0]);
		}

		m_asModel.SetPageID(XPConvert.ToInteger(sValues[0]));

		if (m_asModel.IsPortletInPage())
		{
			m_asModel.SetErrorPage(true);
		}
		else
		{
			m_asModel.SetErrorPage(false);
			if(m_asOwner.GetAccessStyle() == AccessStyles.STANDARD) 
			{
				m_asModel.AddPortletInPage();	
			} else {
				if(arguments.GetElement(RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH) != null)
				{
					m_asModel.AddPortletInPage();
				}	
			}
			
		}

		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			return objRedirect;
		}
		else
		{
			if(m_asModel.IsErrorPage() && arguments.GetElement(RepostControl.HTMLSUBMIT_508_POSTTOSELF + RepostControl.POSTTOSELF_ACTION_FINISH) != null)
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, 
							XPResourceManager.FormatMessage(m_asOwner.GetString(591, "ptmsgs_portalbrowsingmsgs"), 
									XPHttpUtility.HtmlEncode(m_asModel.GetPortletName())),
							XPResourceManager.FormatMessage(m_asOwner.GetString(591, "ptmsgs_portalbrowsingmsgs"), 
									XPHttpUtility.HtmlEncode(m_asModel.GetPortletName())));
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
				
				Redirect obj508Redirect = new Redirect();
				obj508Redirect.SetLinkGetCachedSpace(m_asOwner);
				obj508Redirect.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
	
				return obj508Redirect;
			}
			else
			{
				Redirect obj508Redirect = new Redirect();
				obj508Redirect.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);				
	
				return obj508Redirect;
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new AddPortletControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		super.Init(model, space);
		m_asModel     = (PreviewPortletModel) model;
		m_asOwner     = space;
	}
}

