package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * File: IPreviewPortletModelRO
 * ---------------------------
 * Read Only Interface for the PreviewPortletModel.
 *
 * @author NaveenP/DustinA
 * @author DavidP
 */
public interface IPreviewPortletModelRO extends IModelRO
{
	/**
	 * AddPortletInPage - adds gadget to the specified user's page
	 *
	 * @param int nPageID
	 */
	public void AddPortletInPage();

	/**
	 * Get Default MyPage URL
	 *
	 * @return String
	 */
	public String GetDefaultMyPageURL();

	/**
	 * Get the gadget alignment
	 *
	 * @return String
	 */
	public int GetPortletAlignment();

	/**
	 * Get the gadget HTML Text
	 *
	 * @return String
	 */
	public Object[][] GetPortletHTMLText();

	/**
	 * Get the gadget id
	 *
	 * @return int
	 */
	public int GetPortletID();

	/**
	 * Get the gadget index for selection page
	 *
	 * @return int
	 */
	public int GetPortletIndex();

	/**
	 * Get the gadget name
	 *
	 * @return String
	 */
	public String GetPortletName();
	
	/**
	 * Get the gadget name
	 *
	 * @return String
	 */
	public String GetPortletDescription();

	/**
	 * Get Preview Portlet URL
	 *
	 * @return String
	 */
	public String GetPortletPreviewURL();

	/**
	 * Returns the gadget type
	 *
	 * @return Portlet type
	 */
	public int GetPortletType();

	/**
	 * Returns true if the community preview mode should be used even if the portlet is not community-only
	 *
	 * @return True if the community preview mode should be used even if the portlet is not community-only
	 */
	public boolean GetAlwaysUseCommunityPreview();

	/**
	 * Get MyPage URL
	 *
	 * @return String
	 */
	public String GetMyPageURL();

	/**
	* Get My Pages
	*
	* @return boolean
	*/
	public IASQueryResult GetMyPages();

	/**
	 * Get the page id
	 *
	 * @return int
	 */
	public int GetPageID();
	
	/**
	 * Get the page name
	 *
	 * @return String
	 */
	public String GetPageName();
	
	/**
	 * Returns the user session
	 *
	 * @return IPTSession
	 */
	public IPTSession GetSession();

	/**
	 * Returns the user ID
	 *
	 * @return User ID
	 */
	public int GetUserID();

	/**
	 * IsErrorPage
	 *
	 * @param boolean
	 */
	public boolean IsErrorPage();

	/**
	* Is Portlet Checked
	*
	* @return boolean
	*/
	public boolean IsPortletChecked();

	/**
	 * IsPortletInPage - checks to if the gadget is already in
	 * the user's page thatt's specified
	 *
	 * @param int nPageID
	 */
	public boolean IsPortletInPage();

	/**
	 * Is Portlet Invite Page
	 *
	 * @return boolean
	 */
	public boolean IsPortletInvitePage();

	/**
	 * Is Search Preview Portlet
	 *
	 * @return boolean
	 */
	public boolean IsPortletSearchPreviewPage();

	/**
	 * Is Portlet Selection Preview Page
	 *
	 * @return boolean
	 */
	public boolean IsPortletSelectionPreviewPage();

	/**
	 * Is Portlet Narrow
	 *
	 * @return boolean
	 */
	public boolean IsNarrow();

	/**
	 * User Has Read Access
	 *
	 * @return boolean
	 */
	public boolean UserHasReadAccess();

	/**
	 * User Has Select Access
	 *
	 * @return boolean
	 */
	public boolean UserHasSelectAccess();
	
	/**
	 * User Has My Page Access
	 * 
	 * @return boolean
	 */
	public boolean UserHasMyPageAccess();
	
	/**
	 * List of Communities Containing This Portlet 
	 *
	 * @return boolean
	 */
	public XPArrayList GetAllCommunitiesUsingPortlet();
	
	/**
	 * Is Portlet Enabled
	 *
	 * @return boolean
	 */
	public boolean IsPortletEnabled();
	
	/**
	 * Get Disabled Message if portlet is disabled
	 *
	 * @return String
	 */
	public String GetPortletDisabledMessage();

	/**
	 * Get Add Portlet Javascript override.
	 * 
	 * This javascript should be the name of the javascript function to be
	 * used in the onclick attribute of the add button.  The function should
	 * take 2 arguments: the portlet ID, and a reference to the popup window.
	 * (i.e. If the name is "addPortlet", then the function will look like
	 * this: "addPortlet(portletID, self)").  This function name can also
	 * include an optional window reference (i.e. "opener.addPortlet").
	 *
	 * @return String the name of the javascript function to use when adding the portlet.
	 * This string will be null if there is no override.
	 */
	public String GetAddPortletJavaScriptOverride();
}