package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: PortletInvitationPopupDP.java
 * ----------------------------------
 * Display Page for the Portlet Invitation Popup
 * that appears from the "Send To Others" link in the Portlet
 * Selection Page.
 *
 * @author NaveenP/DustinA
 */
public class InvitationOpenerRedirectDP implements IDisplayPage
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.InvitationOpenerRedirectDP");

	
	public static final String STR_MVC_CLASS_NAME = "InvitationOpenerRedirect";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** Logging */
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#display()
	 */
	public void Display(IWebData pageData)
	{
		ASURL asurl = new ASURL(m_asOwner);
		asurl.SetLinkGetCachedSpace(m_asOwner);
		asurl.SetDisplayPage(PortletInvitationJoinDP.STR_MVC_CLASS_NAME);

		HTMLPage page     = new HTMLPage();
		HTMLHead head     = new HTMLHead();
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			script.AddInnerHTMLString("window.opener.location='" +
				asurl.GetURLAsString() + "';\n");
			script.AddInnerHTMLString("self.close();\n");
			head.AddInnerHTMLElement(script);
			page.SetHead(head);
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		pageData.SetData(page);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.ui.framework.IDisplayPage#GetParent()
	 */
	public AActivitySpace GetOwner()
	{
		return m_asOwner;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
	}
}

