package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: InvitePortletJSView.java
 * -----------------------------
 * Section for Portlet Invitation JavaScript.  This is a blank page
 * that simply popups up the Portlet Invitation.
 *
 * @author NaveenP/DustinA
 */
public class InvitePortletJSView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.InvitePortletJSView");

	
	public static final String STR_MVC_CLASS_NAME = "InvitePortletJS";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private IPreviewPortletModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new InvitePortletJSView();
	}

	/** Logging */
	
	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLTable table     = new HTMLTable();
		HTMLTableRow tRow   = new HTMLTableRow();
		HTMLTableCell tCell = new HTMLTableCell();

		try
		{
			tCell.AddInnerHTMLString("<b>" +
				m_asOwner.GetString(601, "ptmsgs_portalbrowsingmsgs") + "</b>");
			tRow.AddInnerHTMLElement(tCell);
			table.AddInnerHTMLElement(tRow);
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		return table;
	}

	/**
	 * Display JavaScript - this includes the static source file
	 *
	 * return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) +
			"opennewwindow.js");

		return script;
	}

	/**
	 * Display JavaScript - this includes the static source file
	 *
	 * return HTMLScript
	 */
	public HTMLScript DisplayRedirectJavascript()
	{
		NavigationModel navModel = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
		ASURL defaultURL		 = navModel.GetDefaultSubportalURL();

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			if (m_asModel.IsNarrow())
			{
				script.AddInnerHTMLString("OpenNarrowGadgetPreviewWindow('" +
					m_asModel.GetPortletPreviewURL() + "');\n");
				script.AddInnerHTMLString("window.history.go(-1);");
			}
			else
			{
				script.AddInnerHTMLString("OpenWideGadgetPreviewWindow('" +
					m_asModel.GetPortletPreviewURL() + "');\n");
				script.AddInnerHTMLString("window.history.go(-1);");
			}

			if (m_asModel.IsPortletInvitePage())
			{
				script.AddInnerHTMLString("window.location='" +
					defaultURL.GetURLAsString() + "';");
			}
			
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		return script;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IPreviewPortletModelRO) model;
		m_asOwner     = parent;
	}
}

