package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: GagdetInvitationPopupView.java
 * ------------------------------------
 * Section for Portlet Invitation Popup that appears
 * from the "Send To Others" link in the Portlet Selection
 * Page.
 *
 * @author NaveenP/DustinA
 */
public class PortletInvitationPopupView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.PortletInvitationPopupView");

	
	public static final String STR_MVC_CLASS_NAME = "PortletInvitationPopup";
	private AActivitySpace m_asOwner;
	private ObjectSelectionModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PortletInvitationPopupView();
	}

	/** Logging */
	
	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement page = null;

		try
		{
			page = InviteURLPopup();
		}
		catch (HTMLException e)
		{
			log.Error(e, e.getMessage());
		}

		return page;
	}

	/**
	 * Display JavaScript
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (ObjectSelectionModel) model;
		m_asOwner     = parent;
	}

	/**
	 * Method inviteURL- displays popup of email message with url to join the
	 * community specified
	 *
	 * @return HTMLElement
	 *
	 * @throws HTMLException
	 */
	public HTMLElement InviteURLPopup()

	{
		//mainPage components
		HTMLPage mainPage	    = new HTMLPage();
		HTMLHead pageHead	    = new HTMLHead();

		HTMLTitle pageTitle = new HTMLTitle(m_asOwner.GetString(1654,
					"ptmsgs_portalbrowsingmsgs"));
		pageHead.AddInnerHTMLElement(pageTitle);

		HTMLBody pageBody = new HTMLBody();
		pageBody.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

		//mainTable components
		HTMLTable mainTable		   = new HTMLTable();
		HTMLTableRow mainRow1	   = new HTMLTableRow();
		HTMLTableRow mainRow2	   = new HTMLTableRow();
		HTMLTableRow mainRow3	   = new HTMLTableRow();
		HTMLTableRow mainRow4	   = new HTMLTableRow();
		HTMLTableCell mainRow1Cell = new HTMLTableCell();
		HTMLTableCell mainRow2Cell = new HTMLTableCell();
		HTMLTableCell mainRow3Cell = new HTMLTableCell();
		HTMLTableCell mainRow4Cell = new HTMLTableCell();

		//closeButton
		HTMLInput closeButton = new HTMLInput(1, "in_bu_close",
				m_asOwner.GetString(594, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(594, "ptmsgs_portalbrowsingmsgs"));
		closeButton.SetValue(m_asOwner.GetString(17, "ptmsgs_portalbrowsingmsgs"));
		closeButton.SetOnClick("self.close()");
		closeButton.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

		// Portlet Name
		String strPortletName = m_asModel.GetTemporaryInvitationName();
		int nPortletID		 = m_asModel.GetTemporaryInvitationID();

		//email message to be sent
		HTMLTextArea message = new HTMLTextArea("100", "8");
		message.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		
		boolean bIsInviteURLSecure = (1 == PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.INVITATIONS_SECTION, PTConfigConstants.IS_INVITATION_URL_SECURE,
																				"value", m_asOwner));

		ASURL urlInvite = new ASURL(m_asOwner);
		urlInvite.SetUseMainServerURL(true, bIsInviteURLSecure);
		urlInvite.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME, m_asOwner);
		urlInvite.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
		urlInvite.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
		urlInvite.AddControlArgument(PreviewPortletControl.m_PreviewType,
			XPConvert.ToString(PreviewPortletModel.INVITEHEADER));
		urlInvite.AddControlArgument(PreviewPortletControl.m_strPortletParam,
			XPConvert.ToString(nPortletID));
			
		message.AddInnerHTMLString("\n" +
			XPResourceManager.FormatMessage(m_asOwner.GetString(595,
					"ptmsgs_portalbrowsingmsgs"), XPHttpUtility.HtmlEncode(strPortletName)) + 
			"\n\n" + urlInvite.GetURLAsString() + "\n\n" +
			m_asOwner.GetString(597, "ptmsgs_portalbrowsingmsgs"));

		//Specifying mainTable attributes
		//border="0" cellpadding="4" width="100%"
		mainTable.SetBorder("0");
		mainTable.SetCellPadding("4");
		mainTable.SetWidth("100%");
		mainTable.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

		//Setting up mainTable
		mainRow1Cell.SetStyleClass(PTStyleClass.DIR_TEXT);

		mainRow1Cell.AddInnerHTMLString(m_asOwner.GetString(598,
				"ptmsgs_portalbrowsingmsgs"));
		mainRow2Cell.SetStyleClass(PTStyleClass.DIR_TEXT);
		mainRow2Cell.AddInnerHTMLElement(message);
		mainRow3Cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		mainRow4Cell.SetStyleClass(PTStyleClass.BAN_TEXT);
		mainRow4Cell.SetAlign("center");
		mainRow4Cell.AddInnerHTMLElement(closeButton);

		PreviewCommunityView.addRowCell(mainTable, mainRow1, mainRow1Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow2, mainRow2Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow3, mainRow3Cell);
		PreviewCommunityView.addRowCell(mainTable, mainRow4, mainRow4Cell);
		pageBody.AddInnerHTMLElement(mainTable);

		try
		{
			pageHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());
		}
		catch (Exception e)
		{
			log.Error(e.getMessage());
		}

		mainPage.SetHead(pageHead);
		mainPage.SetBody(pageBody);

		return mainPage;
	}
}

