package com.plumtree.portalpages.browsing.portletpreview;

//import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Displays a list of URLs to communities that contain the portlet being
 * previewed.
 * 
 * @author DavidP
 */
public class PreviewCommPortletListView implements IView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.PreviewCommPortletListView");

	public static final String STR_MVC_CLASS_NAME = "PreviewCommPortletList";
	
	public static final String HTMLINPUT_ADD 			= "in_bu_add";
	public static final String HTMLINPUT_CLOSE 			= "in_bu_close";
	public static final String HTMLINPUT_DESCRIPTION	= "in_bu_description";
	public static final String HTMLSELECT_PAGEMENU		= "in_se_pageMenu";
	
	public static final String JSFUNCTION_SETURLANDFOCUS = "SetUrlAndFocus";

	/** Javascript Function: previewPortlet */
	public static final String JAVASCRIPT_PREVIEW_COMMUNITY = "previewCommunity";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private PreviewPortletModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewCommPortletListView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLTable mainTable = new HTMLTable();
		HTMLTableRow row1   = new HTMLTableRow();
		HTMLTableCell cell1 = new HTMLTableCell();
		HTMLTableRow row2   = new HTMLTableRow();
		HTMLTableCell cell2 = new HTMLTableCell();

		mainTable.SetBorder("0");
		mainTable.SetCellPadding("4");
		mainTable.SetCellSpacing("0");
		mainTable.SetWidth("100%");

		try
		{
			cell1.AddInnerHTMLElement(DisplayBar());
			cell2.AddInnerHTMLElement(showLinks());

			row1.AddInnerHTMLElement(cell1);
			row2.AddInnerHTMLElement(cell2);

			mainTable.AddInnerHTMLElement(row1);
			mainTable.AddInnerHTMLElement(row2);
		}
		catch (Exception e)
		{
			log.Error(e, "PreviewCommPortletListView.Display()");

			HTMLTable errorTable    = new HTMLTable();
			HTMLTableRow errorRow   = new HTMLTableRow();
			HTMLTableCell errorCell = new HTMLTableCell();
			HTMLBr errorBr		    = new HTMLBr();

			try
			{
				errorTable.AddInnerHTMLElement(errorRow);
				errorRow.AddInnerHTMLElement(errorCell);

				errorCell.AddInnerHTMLString(m_asOwner.GetString(1322, "ptmsgs_portalbrowsingmsgs"));
				errorCell.AddInnerHTMLElement(errorBr);
				errorCell.AddInnerHTMLString(e.getMessage());
			}
			catch (HTMLException he)
			{
				log.Error(he, "Error displaying error.");
			}

			return errorTable;
		}

		return mainTable;
	}

	/**
	 * Display JavaScript
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		XPStringBuilder sb = new XPStringBuilder(100);
		
		sb.Append("\n function " + JSFUNCTION_SETURLANDFOCUS + "(strURL) {\n");
		sb.Append("	window.opener.location=strURL;\n");
		//sb.Append(" window.focus();\n");
		sb.Append(" return false;\n");
		sb.Append("}\n");
		
		script.AddInnerHTMLString(sb.ToString());
		
		return script;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (PreviewPortletModel) model;
		m_asOwner     = parent;
	}

	/**
	 * Method DisplayBar - returns an HTMLTable containing the preview bar
	 *
	 * @return HTMLTable
	 *
	 * @throws HTMLException
	 */
	private HTMLTable DisplayBar()

	{
		HTMLTable table = new HTMLTable();

		//mainTable components
		HTMLTableRow mainRow    = new HTMLTableRow();
		HTMLTableCell mainCell1 = new HTMLTableCell();
		HTMLTableCell mainCell2 = new HTMLTableCell();

		// inputs
		HTMLInput close;

		close = new HTMLInput(1, HTMLINPUT_CLOSE,
				m_asOwner.GetString(612, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(612, "ptmsgs_portalbrowsingmsgs"));
		String cancelString = "self.close()";
		close.SetValue(m_asOwner.GetString(17, "ptmsgs_portalbrowsingmsgs"));
		close.SetOnClick(cancelString);
		close.SetStyleClass(PTStyleClass.FORM_EDITOR_BTN_TEXT);

		// Specifying the mainTable attributes
		table.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
		table.SetBorder("0");
		table.SetCellPadding("4");
		table.SetCellSpacing("0");
		table.SetWidth("100%");
		table.SetHeight("40");
		table.SetBGColor("#D6D3CE");

		// bar with close button and title
		mainCell1.SetAlign(CommonHTMLStrings.LEFT);
		mainCell1.SetStyleClass(PTStyleClass.BAN_GREETING_TEXT);
		mainCell1.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		
		
		// TODO make this a n approipriate white span
		mainCell1.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1651, "ptmsgs_portalbrowsingmsgs"),
			XPHttpUtility.HtmlEncode(m_asModel.GetPortletName())));
		
		
		
		mainRow.AddInnerHTMLElement(mainCell1);
		
		mainCell2.SetAlign(CommonHTMLStrings.RIGHT);
		mainCell2.SetStyleClass(PTStyleClass.BAN_TEXT);
		mainCell2.AddInnerHTMLElement(close);
		mainCell2.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		PreviewCommunityView.addRowCell(table, mainRow, mainCell2);
		
		return table;
	}

	/**
	 * Method showLinks - returns an HTMLTable containing links to previews of
	 * communities.  Note: Because we're using the mediator, this automatically
	 * handles 508 mode
	 *
	 * @return HTMLTable
	 *
	 * @throws HTMLException
	 */
	private HTMLTable showLinks()

	{
		// Outermost master table
		HTMLTable masterBar = new HTMLTable();		
		masterBar.SetCellPadding(CommonHTMLStrings.ZERO);		
		masterBar.SetBorder(CommonHTMLStrings.ZERO);
		masterBar.SetCellSpacing("10");
		masterBar.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		masterBar.SetSummary(m_asOwner.GetString(1319, "ptmsgs_portalbrowsingmsgs"));
		
		HTMLTableRow masterBarRow = new HTMLTableRow();
		HTMLTableCell masterBarCell = new HTMLTableCell();
		masterBar.AddInnerHTMLElement(masterBarRow);
		masterBarRow.AddInnerHTMLElement(masterBarCell);
		
		// Description bar at top
		HTMLTable descBar = new HTMLTable();
		descBar.SetCellPadding(CommonHTMLStrings.ZERO);		
		descBar.SetBorder(CommonHTMLStrings.ZERO);
		descBar.SetCellSpacing(CommonHTMLStrings.ZERO);
		descBar.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		descBar.SetSummary(m_asOwner.GetString(1319, "ptmsgs_portalbrowsingmsgs"));

		HTMLTableRow descBarRow = new HTMLTableRow();
		HTMLTableCell descBarCell = new HTMLTableCell();
		descBar.AddInnerHTMLElement(descBarRow);
		descBarRow.AddInnerHTMLElement(descBarCell);
		descBarRow.SetStyleClass(PTStyleClass.PLATPORTLET_HEADER_BG);
		
		descBarCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		descBarCell.SetHeight("18");
		descBarCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		descBarCell.SetStyleClass(PTStyleClass.CUSTOMAPP_TEXT);
		descBarCell.SetNoWrap(true);
		
		HTMLSpan span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.PLATPORTLET_NARROW_HEADER);
		span.AddInnerHTMLString(m_asOwner.GetString(1658, "ptmsgs_portalbrowsingmsgs"));
		descBarCell.AddInnerHTMLElement(span);
		
		// Add the desc bar to the master table
		masterBarCell.AddInnerHTMLElement(descBar);
		
		// Nested Inner table #1
		HTMLTable inner1 = new HTMLTable();
		inner1.SetCellPadding(CommonHTMLStrings.ZERO);		
		inner1.SetBorder(CommonHTMLStrings.ZERO);
		inner1.SetCellSpacing(CommonHTMLStrings.ZERO);
		inner1.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		inner1.SetSummary(m_asOwner.GetString(1319, "ptmsgs_portalbrowsingmsgs"));
		inner1.SetStyleClass(PTStyleClass.PLATPORTLET_BORDER);
		
		HTMLTableRow inner1BarRow = new HTMLTableRow();
		HTMLTableCell inner1BarCell = new HTMLTableCell();
		inner1.AddInnerHTMLElement(inner1BarRow);
		inner1BarRow.AddInnerHTMLElement(inner1BarCell);
		
		// Add the nested table to the master table
		masterBarCell.AddInnerHTMLElement(inner1);
				
		// Nested Inner Table #2
		HTMLTable inner2 = new HTMLTable();
		inner2.SetCellPadding(CommonHTMLStrings.ZERO);		
		inner2.SetBorder(CommonHTMLStrings.ZERO);
		inner2.SetCellSpacing(CommonHTMLStrings.FIVE);
		inner2.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		inner2.SetSummary(m_asOwner.GetString(1319, "ptmsgs_portalbrowsingmsgs"));
		
		HTMLTableRow inner2BarRow = new HTMLTableRow();
		HTMLTableCell inner2BarCell = new HTMLTableCell();
		inner2.AddInnerHTMLElement(inner2BarRow);
		inner2BarRow.AddInnerHTMLElement(inner2BarCell);
		
		// Add inner 2 to inner 1
		inner1BarCell.AddInnerHTMLElement(inner2);
							
		// Form innermost table with rows
		HTMLTable inner3 = new HTMLTable();
		inner3.SetCellPadding(CommonHTMLStrings.TWO);		
		inner3.SetBorder(CommonHTMLStrings.ZERO);
		inner3.SetCellSpacing(CommonHTMLStrings.TWO);
		inner3.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		inner3.SetSummary(m_asOwner.GetString(1325, "ptmsgs_portalbrowsingmsgs"));
						
		// Add inner 3 to inner 2
		inner2BarCell.AddInnerHTMLElement(inner3);
		int count = 0;
		
		if (m_asModel.UserHasReadAccess())
		{
			// Check the gadget type
			if ((PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY == m_asModel.GetPortletType()) ||
			    (m_asModel.GetAlwaysUseCommunityPreview()))
			{
				// Nested SORTED LIST OF COMMUNITIES rows

				XPArrayList list = null;

				try
				{
					list = m_asModel.GetAllCommunitiesUsingPortlet();
					
					// Roll through list and create links
					if (list.GetSize() > 0)
					{
						// ASURL based approach links directly to invite receipt using full URLs (508 compliant)
						IXPEnumerator iter = list.GetEnumerator();
						while( iter.MoveNext() )
						{
							CommunityInviteItem item = (CommunityInviteItem)iter.GetCurrent();	
							
							// Generate a popup URL to invite people to this community
							ASURL urlInvite = new ASURL(m_asOwner);
						//	urlInvite.SetUseMainServerURL(true);
							urlInvite.SetLinkCreateNewSpace(PreviewCommunityControl.STR_MVC_CLASS_NAME,m_asOwner);
							urlInvite.SetControl(PreviewCommunityControl.STR_MVC_CLASS_NAME);
							//urlInvite.SetDisplayPage(PreviewCommunityDP.STR_MVC_CLASS_NAME);
							urlInvite.AddControlArgument(PreviewCommunityControl.m_PreviewType, XPConvert.ToString(PreviewCommunityModel.INVITEHEADER));
							urlInvite.AddControlArgument(PreviewCommunityControl.m_CommunityID, XPConvert.ToString(item.GetCommunityID()));
							
							HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
							myAnchor.SetOnClick("return " + JSFUNCTION_SETURLANDFOCUS + "('" + urlInvite.GetURLAsString() + "');");
							myAnchor.AddInnerHTMLEncodedString(item.GetCommunityName());
							
							// Feed the link to the row; should not throw exception
							AddPreviewListRow( count++, inner3, myAnchor );
						}
					}
					else // gadget not used in any communities
					{
						HTMLTableRow inner3BarRow = new HTMLTableRow();
						HTMLTableCell inner3BarCell = new HTMLTableCell();
						inner3.AddInnerHTMLElement(inner3BarRow);
						inner3BarRow.AddInnerHTMLElement(inner3BarCell);

						if (count%2 == 0)
							inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
						else
							inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			
						inner3BarCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
						inner3BarCell.SetStyleClass(PTStyleClass.LIST_TEXT);
						inner3BarCell.SetNoWrap(true);
						inner3BarCell.AddInnerHTMLString(m_asOwner.GetString(1320, "ptmsgs_portalbrowsingmsgs"));
						count++;
					}
					
				}
				catch (Exception e)
				{
					log.Error(e, "Error Getting List of Communities Using This Portlet");
					throw new XPException(m_asOwner.GetString(1322, "ptmsgs_portalbrowsingmsgs"));
				}
			}
			else
			{
				// You shouldn't be here; should be using other preview
				HTMLTableRow inner3BarRow = new HTMLTableRow();
				HTMLTableCell inner3BarCell = new HTMLTableCell();
				inner3.AddInnerHTMLElement(inner3BarRow);
				inner3BarRow.AddInnerHTMLElement(inner3BarCell);

				if (count%2 == 0)
					inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
				else
					inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			
				inner3BarCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				inner3BarCell.SetStyleClass(PTStyleClass.LIST_TEXT);
				inner3BarCell.SetNoWrap(true);
				inner3BarCell.AddInnerHTMLString(m_asOwner.GetString(1323, "ptmsgs_portalbrowsingmsgs"));
				count++;
			}
		}
		else
		{
			// You shouldn't be here; should be using other preview
			HTMLTableRow inner3BarRow = new HTMLTableRow();
			HTMLTableCell inner3BarCell = new HTMLTableCell();
			inner3.AddInnerHTMLElement(inner3BarRow);
			inner3BarRow.AddInnerHTMLElement(inner3BarCell);

			if (count%2 == 0)
				inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
			else
				inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			
			inner3BarCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			inner3BarCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			inner3BarCell.SetNoWrap(true);
			inner3BarCell.AddInnerHTMLString(m_asOwner.GetString(614,"ptmsgs_portalbrowsingmsgs"));
			count++;
		}

		return masterBar;
	}

	/**
	 *  DAP -  Creating HTML for community links
	 *
	 * @param table 
	 * @param asURL 
	 *
	 * @throws HTMLException 
	 */
	protected static void AddPreviewListRow(int count, HTMLTable table, HTMLAnchor anchor)

	{
		if (null == anchor)
		{
			return;
		}
		
		HTMLTableRow inner3BarRow = new HTMLTableRow();
		HTMLTableCell inner3BarCell = new HTMLTableCell();
		table.AddInnerHTMLElement(inner3BarRow);
		inner3BarRow.AddInnerHTMLElement(inner3BarCell);

		if (count%2 == 0)
			inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
		else
			inner3BarRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			
		inner3BarCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		inner3BarCell.SetStyleClass(PTStyleClass.LIST_TEXT);
		inner3BarCell.SetNoWrap(true);
		inner3BarCell.AddInnerHTMLElement(anchor);
	}
}

