package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * File: PreviewPortletControl.java
 * -------------------------------
 * Control for determining which gadget is being previewedd
 * and what type of preview is desired (selection preview, invitation,
 * or preview from editor).
 *
 * @author NaveenP/DustinA
 */
public class PreviewPortletControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.PreviewPortletControl");

	
	public static final String STR_MVC_CLASS_NAME = "PreviewGadget";

	/** QueryString Parameter for Portlet Index*/
	public static final String m_strPortletParam = "GadgetID";

	/** Preview Type Query String Param */
	public static final String m_PreviewType = "PreviewType";

	/** QueryString Parameter for Index*/
	public static final String m_strPortletIndex = "GadgetIndex";

	/** QueryString Parameter for Selected*/
	public static final String m_strPortletChecked = "GadgetChecked";

	/** QueryString Parameter for Community Portlet Preview Handling */
	public static final String m_strCommunityPortletPreview = "CommunityGadgetPreview";

	/** QueryString Parameter for always using Community mode */
	public static final String m_strAlwaysCommunity = "AlwaysCommunity";

	/** QueryString Parameter for the Add Portlet Javascript override */
	public static final String m_strAddPortletJavascriptOverride = "AddPortletJS";

	/** Logging */
	/** model */
	private PreviewPortletModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{	
		// First, load the gadget so we can determine if it is a community gadget or not
		int nPortletID    = -1;
		int nPortletIndex = -1;

		String[] sValues = (String[]) arguments.GetElement(m_strPortletParam);
		String[] sControlDispatch = (String[]) arguments.GetElement(m_strCommunityPortletPreview);
		
		String[] sHostPageURIs = (String[]) arguments.GetElement(HttpUtils.HASHTABLE_CONTROL_KEY_URL);
		if ((null != sHostPageURIs) && (sHostPageURIs.length > 0))
		{
			m_asModel.SetHostPageURI(sHostPageURIs[0]);
		}
	
		String[] sHeaders = (String[]) arguments.GetElement(HttpUtils.HASHTABLE_CONTROL_KEY_HTTP_HEADERS);
		if ((null != sHeaders) && (sHeaders.length > 0))
		{
			m_asModel.SetRawHeaders(sHeaders[0]);
		}
	
		if (sValues != null)
		{
			try
			{
				nPortletID = XPConvert.ToInteger(sValues[0]);
			}
			catch (XPFormatException e)
			{
				
					log.Error("could not parse gadget ID data in query string: " +
						sValues[0]);
				
				
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"));
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				return null;
			}

			// DCA - checking if logged in
			// WilliamA - Change guest user detection for multiple-guest-user support
			// -- if (m_Session.GetSessionInfo().GetCurrentUserID() == PT_INTRINSICS.PT_USER_GUEST)
			if (TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))			
			{
				Redirect previewURL = new Redirect();
				previewURL.SetLinkGetCachedSpace(m_asOwner);
				previewURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
				previewURL.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
				previewURL.AddControlArgument(PreviewPortletControl.m_PreviewType,
					(XPConvert.ToString(PreviewPortletModel.INVITEHEADER)));
				previewURL.AddControlArgument(PreviewPortletControl.m_strPortletParam,
					(XPConvert.ToString(nPortletID)));
				previewURL.SetIsErrorRedirect(true);

				return previewURL;
			}

			try
			{
				m_asModel.SetPortletID(nPortletID);
			}
			catch (Exception e)
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, e, e.getMessage(),
						e.getMessage());
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());

				Redirect redirect = new Redirect();
				redirect.SetLinkGetSpaceIfCached(PreviewPortletAS.STR_MVC_CLASS_NAME,
					m_asOwner);
				redirect.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
				 redirect.AddControlArgument(PreviewPortletControl.m_PreviewType, PreviewPortletModel.PREVIEWHEADER);

				return redirect;
			}
		}

		// Check for a Javascript override for the AddPortlet function
		sValues = (String[]) arguments.GetElement(m_strAddPortletJavascriptOverride);
		if ((sValues != null) && (sValues[0] != null) && (sValues[0].length() > 0))
		{
			m_asModel.SetAddPortletJavaScriptOverride(sValues[0]);
		}

		// Check whether we want "always community" mode
		sValues = (String[]) arguments.GetElement(m_strAlwaysCommunity);
		boolean alwaysCommunity = false;
		if (sValues != null)
		{
			if (sValues[0].equals("y"))
			{
				m_asModel.SetAlwaysUseCommunityPreview(true);
				alwaysCommunity = true;
			}
		}

		// Now check to see if the gadget is community, header, footer, personal, freeform
		if (sControlDispatch != null)
		{
			if (sControlDispatch[0].equals("y"))
			{
				// community gadget preview, which is a list of communities with that gadget
				return null;
			}
		}
		
		// fall through for normal control dispatch handling
		if (alwaysCommunity || (m_asModel.GetPortletType() == PT_GADGET_TYPES.PT_GADGETTYPE_COMMUNITY))
		{
			// special community preview: list of links to communities that contain this gadget
			// have the model query the database for all communities		
			// have the view form ASURLs for those communities
			// have the dp paint the page
			Redirect previewURL = new Redirect();
			previewURL.SetLinkGetCachedSpace(m_asOwner);
			previewURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
			previewURL.SetDisplayPage(PreviewCommPortletListDP.STR_MVC_CLASS_NAME);
			previewURL.AddControlArgument(PreviewPortletControl.m_strPortletParam,
				(XPConvert.ToString(nPortletID)));
			previewURL.AddControlArgument(PreviewPortletControl.m_strCommunityPortletPreview,
				"y");
			return previewURL;
		}
		else // normal mypage gadget preview
		{		
			// DCA - checking if logged in
			if (TaskAPIUIUser.IsCurrentUserGuestUser(m_asOwner))
			{
				Redirect previewURL = new Redirect();
				previewURL.SetLinkGetCachedSpace(m_asOwner);
				previewURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
				previewURL.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
				previewURL.AddControlArgument(PreviewPortletControl.m_PreviewType,
					(XPConvert.ToString(PreviewPortletModel.INVITEHEADER)));
				previewURL.AddControlArgument(PreviewPortletControl.m_strPortletParam,
					(XPConvert.ToString(nPortletID)));
				previewURL.SetIsErrorRedirect(true);

				return previewURL;
			}
			
			// Then do standard case redirects for page acess errors, guest login, and so forth
	
			// Index
			sValues = (String[]) arguments.GetElement(m_strPortletIndex);
	
			if (sValues != null)
			{
				try
				{
					nPortletIndex = XPConvert.ToInteger(sValues[0]);
				}
				catch (XPFormatException e)
				{
					
						log.Error("could not parse gadget index data in query string: " +
							sValues[0]);
					
	
					UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"),
						m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"));
					myError.SetDisplayOnSeparatePage(false);
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
						m_asOwner.GetApplication());
					
					return null;
				}
	
				if (nPortletIndex != -1)
				{
					m_asModel.SetPortletIndex(nPortletIndex);
				}
			}
	
			if ((nPortletID < 0) && (nPortletIndex < 0))
			{
				
					log.Error("could not parse gadget index or gadget id data in query string: " +
						sValues[0]);
						
					UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"),
						m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"));
					myError.SetDisplayOnSeparatePage(false);
					UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
						m_asOwner.GetApplication());
				
	
				return null;
			}
	
			sValues = (String[]) arguments.GetElement(m_strPortletChecked);
	
			if (sValues != null)
			{
				boolean bPortletChecked = XPConvert.ToBoolean(sValues[0]);
				m_asModel.SetPortletChecked(bPortletChecked);
			}
	
			// Preview type
			sValues = (String[]) arguments.GetElement(m_PreviewType);
	
			if (sValues == null)
			{
				
					log.Error("could not find preview type in query string.");
				
	
				return null;
			}
	
			int nPreviewType;
	
			try
			{
				nPreviewType = XPConvert.ToInteger(sValues[0]);
			}
			catch (XPFormatException e)
			{
				
					log.Error("could not parse preview type data in query string: " +
						sValues[0]);
				
				
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(1623, "ptmsgs_portalbrowsingmsgs"));
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
	
				return null;
			}
	
			if (nPreviewType == PreviewPortletModel.SELECTIONPREVIEWHEADER)
			{
				m_asModel.SetPortletToSelectionPreviewPage();
			}
			else if (nPreviewType == PreviewPortletModel.INVITEHEADER)
			{
				m_asModel.SetPortletToInvitePage();
			}
			else if (nPreviewType == PreviewPortletModel.SEARCHHEADER)
			{
				m_asModel.SetPortletToSearchPreviewPage();
			}
			else
			{
				m_asModel.SetPortletToPreviewPage();
			}
		}
		
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewPortletControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (PreviewPortletModel) model;
		m_asOwner     = space;
	}
}