package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 * File: PreviewPortletDP.java
 * --------------------------
 * The Display Page for the Preview Portlet.
 * Simply calls into the PreviewPortletView and
 * gets the javascript to display on this page.
 *
 * @author NaveenP/DustinA
 */
public class PreviewPortletDP extends AFormDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.PreviewPortletDP");

	public static final String STR_MVC_CLASS_NAME = "PreviewGadget";

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()
	 */
	public String GetFormTitle()
	{
		return m_asOwner.GetString(1330, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Init(AActivitySpace)
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#display()
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		result.AddInnerHTMLElement(m_asOwner.GetView(PreviewPortletView.STR_MVC_CLASS_NAME).Display());

		return result;
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#DisplayHTMLAfterForm()
	 */
	public HTMLElementCollection DisplayHTMLAfterForm()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		result.AddInnerHTMLElement(((PreviewPortletView) m_asOwner.GetView(PreviewPortletView.STR_MVC_CLASS_NAME)).DisplayPortlet());

		return result;
	}

	/**
	 * Display Java Script From Child
	 *
	 * @return HTMLScriptCollection
	 *
	 * @throws HTMLException
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		HTMLScriptCollection scripts = new HTMLScriptCollection();
		scripts.AddInnerHTMLElement(m_asOwner.GetView(PreviewPortletView.STR_MVC_CLASS_NAME).DisplayJavascript());

		AggregateJavaScriptFromIntrinsicPortletView(scripts);

		return scripts;
	}

	/**
	 * Aggregate JavaScript for intrinsic portlet views.  The intrinsic portlet views
	 * must already be registered with the activity space. 
	 *
	 * @param scripts HTML script collection to append JavaScript to
	 */
	private void AggregateJavaScriptFromIntrinsicPortletView(HTMLScriptCollection scripts)
	{
		// Aggregate all of the intrinsic portlet Javascript. Now iterate through intrinsic
		// portlet views and call DisplayJavascript for each.
		IXPEnumerator enumViews = m_asOwner.GetViewsEnumerator();

		while (enumViews.MoveNext())
		{
			IView currentView = (IView) enumViews.GetCurrent();

			if (currentView instanceof IntrinsicPortletView)
			{
				IntrinsicPortletView iPortletView = (IntrinsicPortletView) currentView;

				HTMLScript portletJavascript = iPortletView.DisplayJavascript();

				if (null != portletJavascript)
				{
					scripts.AddInnerHTMLElement(portletJavascript);
				}
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IDisplayPage#Display()
	 *
	 * Warning: PlumtreeDP overrides this, so if you change things here, you probably
	 * need to change it there as well.
	 */
	public void Display(IWebData pageData)
	{
		boolean bNoJavascript = (GetOwner().GetAccessStyle() != AccessStyles.STANDARD);

		HTMLPage myPage = new HTMLPage();

		// Set the HTMLPage as the data to be sent to the browser.
		pageData.SetData(myPage);

		if (bNoJavascript)
		{
			myPage.SetDo508Checking(true);
		}

		HTMLHead myHead = new HTMLHead();
		myPage.SetHead(myHead);

		// GetFormTitle should already be encoded.
		HTMLTitle myTitle = new HTMLTitle(GetFormTitle());

		HTMLBody myBody = new HTMLBody();
		myPage.SetBody(myBody);
		myBody.SetMarginHeight("0");
		myBody.SetMarginWidth("0");
		myBody.SetLeftMargin("0");
		myBody.SetTopMargin("0");

		if (!bNoJavascript)
		{
			String strPCCfunction = "document.PCC.RaiseWindowEvent(event);";
			myBody.SetOnActivate(strPCCfunction);
			myBody.SetOnAfterPrint(strPCCfunction);
			myBody.SetOnBeforeActivate(strPCCfunction);
			myBody.SetOnBeforeUnload(strPCCfunction);
			myBody.SetOnBlur(strPCCfunction);
			myBody.SetOnControlSet(strPCCfunction);
			myBody.SetOnDeactivate(strPCCfunction);
			myBody.SetOnError(strPCCfunction);
			myBody.SetOnFocus(strPCCfunction);
			myBody.SetOnHelp(strPCCfunction);
			myBody.SetOnLoad(strPCCfunction);
			myBody.SetOnResize(strPCCfunction);
			myBody.SetOnResizeEnd(strPCCfunction);
			myBody.SetOnResizeStart(strPCCfunction);
			myBody.SetOnUnload(strPCCfunction);
		}

		try
		{
			// This is commented out because this form does not have access to m_bShowFormFooter. -jic

			/*
			   // Set to dark background color if this is a small form.
			   if (m_bShowFormFooter)
			   {
			       myBody.SetStyleClass(PTStyleClass.DIALOGUE_BG);
			   }
			 */
			myHead.AddInnerHTMLElement(myTitle);

			myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());

			// PAI - Helper method so that Activity Spaces can add HTML after the form
			// tag and before the form tag (like for pages with other forms).
			// We need to call DisplayHTMLAfterForm() before calling DisplayJavaScriptFromChild()
			// because intrinsic portlet views get registered only when DisplayHTMLAfterForm() is
			// called, and DisplayJavaScriptFromChild() can only find the JavaScript for each
			// intrinsic portlet view AFTER they are registered with the activity space. Although
			// we are generating the HTML that goes after the form right now, we won't actually
			// add it to the HTML for the page until later. -jic
			HTMLElementCollection myHTMLAfterForm = DisplayHTMLAfterForm();

			// Add javascript if we are in standard access style (i.e. not 508)
			if (!bNoJavascript)
			{
				// Add javascript if we are in standard access style (i.e. not 508)
				String strOnLoad = GetOnLoad();

				// Display the common javascript first so it can be used in child javascript onLoads.
				myHead.AddInnerHTMLElement(((IFormAS) GetOwner()).DisplayCommonJavaScript());

				String strLangID = (String) PersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE, GetOwner());

				HTMLScriptCollection jsxmlScript = new HTMLScriptCollection();
				jsxmlScript.AddInnerHTMLElement( ConfigHelper.GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTLET, GetOwner()) );
				myHead.AddInnerHTMLElement(jsxmlScript);
				
				

				HTMLScript scriptPCCHelper = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
				scriptPCCHelper.AddInnerHTMLString("var windowOnloadFunction = (window.onload) ? window.onload : new Function;\n" + "document.PCC.RegisterForWindowEvent(\"onload\", windowOnloadFunction);\n" + "var windowOnBlurFunction = (window.onblur) ? window.onblur : new Function;\n" + "document.PCC.RegisterForWindowEvent(\"onblur\", windowOnBlurFunction);\n" + "var windowOnFocusFunction = (window.onfocus) ? window.onfocus : new Function;\n" + "document.PCC.RegisterForWindowEvent(\"onfocus\", windowOnFocusFunction);\n");

				// MJD - Leave the commented out code below in, until we know for sure which events we need to get prior functions from.

				/*                    scriptPCCHelper.AddInnerHTMLString
				   ("var windowOnActivateFunction = (window.onactivate) ? window.onactivate : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onactivate\", windowOnActivateFunction);\n" +
				   "var windowOnAfterPrintFunction = (window.onafterprint) ? window.onafterprint : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onafterprint\", windowOnAfterPrintFunction);\n" +
				   "var windowOnBeforeActivateFunction = (window.onbeforeactivate) ? window.onbeforeactivate : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onbeforeactivate\", windowOnBeforeActivateFunction);\n" +
				   "var windowOnBeforeUnloadFunction = (window.onbeforeunload) ? window.onbeforeunload : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onbeforeunload\", windowOnBeforeUnloadFunction);\n" +
				   "var windowOnControlSetFunction = (window.oncontrolset) ? window.oncontrolset : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"oncontrolset\", windowOnControlSetFunction);\n" +
				   "var windowOnDeactivateFunction = (window.ondeactivate) ? window.ondeactivate : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"ondeactivate\", windowOnDeactivateFunction);\n" +
				   "var windowOnErrorFunction = (window.onerror) ? window.onerror : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onerror\", windowOnErrorFunction);\n" +
				   "var windowOnHelpFunction = (window.onhelp) ? window.onhelp : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onhelp\", windowOnHelpFunction);\n" +
				   "var windowOnResizeFunction = (window.onresize) ? window.onresize : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onresize\", windowOnResizeFunction);\n" +
				   "var windowOnResizeEndFunction = (window.onresizeend) ? window.onresizeend : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onresizeend\", windowOnResizeEndFunction);\n" +
				   "var windowOnResizeStartFunction = (window.onresizestart) ? window.onresizestart : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onresizestart\", windowOnResizeStartFunction);\n" +
				   "var windowOnUnloadFunction = (window.onunload) ? window.onunload : new Function;\n" +
				   "document.PCC.RegisterForWindowEvent(\"onunload\", windowOnUnloadFunction);\n"); */
				if (null != strOnLoad)
				{
					scriptPCCHelper.AddInnerHTMLString("document.PCC.RegisterForWindowEvent(\"onload\", " + strOnLoad + ");\n");
				}

				myHead.AddInnerHTMLElement(scriptPCCHelper);
				myHead.AddInnerHTMLElement(DisplayJavascript());
				myHead.AddInnerHTMLElement(DisplayJavaScriptFromChild());
			}

			// JF- Helper method so that Activity Spaces can add HTML into the head
			// (like meta and link tags for example).           
			HTMLElementCollection myHTMLinHead = DisplayHTMLinHEAD();

			if (null != myHTMLinHead)
			{
				myHead.AddInnerHTMLElement(myHTMLinHead);
			}

			// JF- Helper method so that Activity Spaces can add HTML after the body 
			// tag and before the form tag (like div tags for example).            
			HTMLElementCollection myHTMLBeforeForm = DisplayHTMLBeforeForm();

			if (null != myHTMLBeforeForm)
			{
				myBody.AddInnerHTMLElement(myHTMLBeforeForm);
			}

			myBody.AddInnerHTMLElement(DisplayForm());

			// Add HTML after the form tag.  The HTML after the form had to be generated before
			// the DisplayJavaScriptFromChild() method was called. -jic
			if (null != myHTMLAfterForm)
			{
				myBody.AddInnerHTMLElement(myHTMLAfterForm);
			}

			BrowserType browser = (BrowserType) GetOwner().GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);

			if (!bNoJavascript && browser.IsJSPortletCompliant())
			{
				HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
				script.AddInnerHTMLString("InitializeEvents();"); //InitializeEvents is defined in "jsportlet" code included above
				myBody.AddInnerHTMLElement(script);
			}
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Display: The following HTML error occured when trying to display the HTML:");
			

			throw new XPException(he);
		}
		catch (Exception e)
		{
			
				log.Error(e, "Display: The following error occured when trying to display the HTML:");
			

			throw XPException.GetInstance(e);
		}
	}
}

