package com.plumtree.portalpages.browsing.portletpreview;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * File: PreviewPortletModel.java
 * -----------------------------
 * Model for entire preview/invitation (and invitation join) functionality.
 *
 * @author NaveenP/DustinA
 */
public class PreviewPortletModel extends AClearModel implements IRepostModel, IModel,
	IPreviewPortletModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.portletpreview.PreviewPortletModel");

	
	public static final String STR_MVC_CLASS_NAME = "PreviewGadget";
	
	/** Constant: Preview Header Bar for Selection Page*/
	public static final int SELECTIONPREVIEWHEADER = 1;

	/** Constant: Invite Header Bar */
	public static final int INVITEHEADER = 2;

	/** Constant: Preview Header Bar for preview only (as in Portlet Editor)*/
	public static final int PREVIEWHEADER = 3;

	/** Constant: Invite Header Bar */
	public static final int SEARCHHEADER = 4;


	/** Whether to always use community preview mode */
	public boolean m_bAlwaysCommunity;

	/** Portlet ID */
	public int m_nPortletID;
	
	/** Preview Status */
	public int m_nPreviewStatus;
	
	/** Is it an Error Page */
	public boolean m_bErrorPage;
	
	/** Portlet Checked on selection page (for checkbox) */
	public boolean m_bPortletChecked = false;
	
	/** Portlet Index on selection page (for checkbox) */
	public int m_nPortletIndex;

	/** Host Page URI */
	public String m_strHostPageURI = "url_not_set";
	public String m_strRawHeaders = "";

	/** Page ID */
	public int m_nPageID;

	/** Activity Space */
	public AActivitySpace m_asOwner = null;
	
	/** Session */
	public IPTSession m_ptSession;
	
	/** Localized Portlet Name **/
	public String m_strPortletName = "";
	
	/** Localized Portlet Description **/
	public String m_strPortletDesc = "";
	
	/** Portlet Alignment **/
	public int m_nPortletAlignment = 0;
	
	/** Is Portlet Enabled **/
	public boolean m_bPortletEnabled = true;
	
	/** Disabled Message **/
	public String m_strDisabledMessage = "";

	/** Add Portlet Javascript override **/
	public String m_strJavascriptOverride = null;
	
	/** temp object */
	static class PreviewPortletModelTempData
	{
	
		/** Portlet */
		public IPTGadget m_objPortlet;
		
		/** App Data State */
		public IPTState m_objAppDataState;
		
		/** Page Name */
		public String m_strPageName;
		
		/** XPHashtable for saving data */
		public XPHashtable m_htFormData = null;

	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#GetNewm_TempData()
	 */
	public Object GetNewTempData()
	{
		PreviewPortletModelTempData tempData = new PreviewPortletModelTempData();

		tempData.m_htFormData = new XPHashtable();
		m_strHostPageURI = PTConfigHelper.GetApplicationBaseURL(m_asOwner);
		
		tempData.m_objAppDataState = AppDataObject.GetAppDataObject(0, m_nPageID,
			m_strHostPageURI, m_asOwner);
		// tempData.m_objAppDataState.Add(PlumtreeExtensibility.PT_HEADERS_KEY, m_strRawHeaders, 0, true);
		HttpUtils.SetReturnURI(m_strHostPageURI, m_asOwner.GetSubSession());

		if (UserHasReadAccess())
		{
			try
			{
				tempData.m_objPortlet = (IPTGadget)m_ptSession.GetGadgets().Open(m_nPortletID, false);
				// Fix to bug #28941, this is needed by other Views after the model is cleared
				m_strPortletName = tempData.m_objPortlet.GetLocalizedName();
				m_strPortletDesc = tempData.m_objPortlet.GetLocalizedDescription();
				m_nPortletAlignment = tempData.m_objPortlet.GetAlignment();
				
				IPTWebService ptWebService = (IPTWebService) m_ptSession.GetWebServices().Open(tempData.m_objPortlet.GetWebServiceID(), false);
				m_bPortletEnabled = ptWebService.GetEnabled();
				m_strDisabledMessage = ptWebService.GetDisabledMessage();
			}
			catch (Exception e)
			{
				log.Error(e, "Error opening portlet.");
				
				throw XPException.GetInstance(e);
			}
		}
		else
		{
			throw new XPException(m_asOwner.GetString(614,
					"ptmsgs_portalbrowsingmsgs"));
		}
	
		return tempData;
	}

	public PreviewPortletModel()
	{

	}
	
	private PreviewPortletModelTempData GetMyTempData()
	{
		return (PreviewPortletModelTempData)GetTempData();
	}

	/**
	 * Add Portlet In Page - adds gadget to the specified user's page
	 *
	 * @param int nPageID
	 */
	public void AddPortletInPage()
	{
		if (!IsPortletInPage())
		{
			IPTPage myPage = (IPTPage)m_ptSession.GetPages().Open(m_nPageID, false);

			// add the gadget to the correct column in the page
			int nPageType		 = myPage.GetPageType();
			int nColumnForPortlet = 0;

			if (IsNarrow())
			{
				nColumnForPortlet = PortletColumnConstants.NARROW_ONE.ToInt();

				if (nPageType == PageTypeConstants.ONE_COLUMN)
				{
					nColumnForPortlet = PortletColumnConstants.WIDE_ONE.ToInt();
				}
			}
			else
			{
				nColumnForPortlet = PortletColumnConstants.WIDE_ONE.ToInt();
			}

			myPage.AddPortlet(m_nPortletID, nColumnForPortlet);
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PreviewPortletModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#Finish()
	 */
	public void Finish()
	{
	}

	/**
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModelRO#GetAddPortletJavaScriptOverride()
	 */
	public String GetAddPortletJavaScriptOverride()
	{
		return m_strJavascriptOverride;
	}

	/**
	 * Get Default MyPage URL
	 *
	 * @return String
	 */
	public String GetDefaultMyPageURL()
	{
		ASURL urlmypage = new ASURL(m_asOwner);
		urlmypage.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
		urlmypage.SetDisplayPage(MyPortalDP.STR_MVC_CLASS_NAME);
		urlmypage.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
		urlmypage.AddControlArgument(SetPageControl.STR_PAGE_ID, 	0);

		return urlmypage.GetURLAsString();
	}

	
	/** Logging */
	/**
	 * Get Portlet Alignment
	 *
	 * @return int
	 */
	public int GetPortletAlignment()
	{
		return GetMyTempData().m_objPortlet.GetAlignment();
	}

	/**
	 * Get Portlet HTML Text
	 *
	 * @return String
	 */
	public Object[][] GetPortletHTMLText()

	{
		Object[][] HTMLText = null;

		try
		{
			HTMLText = (Object[][]) GetMyTempData().m_objPortlet.GetHTMLText(GetMyTempData().m_objAppDataState);
		}
		catch (Exception e)
		{
			//pkd extracted:     		throw new Exception(_ui_CouldNotDisplayGadget + e);	
			throw new XPException(m_asOwner.GetString(607,
					"ptmsgs_portalbrowsingmsgs") + e);
		}

		return HTMLText;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModelRO#GetPortletID()
	 */
	public int GetPortletID()
	{
		return m_nPortletID;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModelRO#GetPortletIndex()
	 */
	public int GetPortletIndex()
	{
		return m_nPortletIndex;
	}

	/**
	 * Get Portlet Name
	 *
	 * @return String
	 */
	public String GetPortletName()
	{
		//return GetMyTempData().m_objPortlet.GetLocalizedName();
		// Fix for #28941
		return m_strPortletName;
	}

	/**
	 * Get Portlet Description
	 *
	 * @return String
	 */
	public String GetPortletDescription()
	{
		//return GetMyTempData().m_objPortlet.GetLocalizedDescription();
		// Fix for #28941
		return m_strPortletDesc;
	}

	/**
	 * Is Portlet Enabled
	 *
	 * @return boolean
	 */
	public boolean IsPortletEnabled()
	{
		return m_bPortletEnabled;
	}
	
	/**
	 * Get Disabled Message if portlet is disabled
	 *
	 * @return boolean
	 */
	public String GetPortletDisabledMessage()
	{
		return m_strDisabledMessage;
	}
	
	/**
	 * Get Preview Portlet URL
	 *
	 * @return String
	 */
	public String GetPortletPreviewURL()
	{

		ASURL urlPreview = new ASURL(m_asOwner);
		urlPreview.SetLinkGetCachedSpace(m_asOwner);
		urlPreview.SetDisplayPage(PreviewPortletDP.STR_MVC_CLASS_NAME);
		urlPreview.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
		urlPreview.AddControlArgument(PreviewPortletControl.m_strPortletParam,
			(XPConvert.ToString(m_nPortletID)));
		urlPreview.AddControlArgument(PreviewPortletControl.m_PreviewType,
			(XPConvert.ToString(PreviewPortletModel.INVITEHEADER)));

		return urlPreview.GetURLAsString();
	}

	/**
	 * Returns true if the community preview mode should be used even if the portlet is not community-only
	 *
	 * @return True if the community preview mode should be used even if the portlet is not community-only
	 */
	public boolean GetAlwaysUseCommunityPreview()
	{
		return m_bAlwaysCommunity;
	}

	/**
	 * Tells the model that community preview mode should always be used, even if the portlet is not community-only
	 */
	public void SetAlwaysUseCommunityPreview(boolean b)
	{
		m_bAlwaysCommunity = b;
	}

	/**
	 * Returns the gadget type
	 *
	 * @return Portlet type
	 */
	public int GetPortletType()
	{

		return GetMyTempData().m_objPortlet.GetGadgetType();
	}

	/**
	 * Get MyPage URL
	 *
	 * @return String
	 */
	public String GetMyPageURL()
	{
		ASURL urlmypage = new ASURL(m_asOwner);
		urlmypage.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);
		urlmypage.SetDisplayPage(MyPortalDP.STR_MVC_CLASS_NAME);
		urlmypage.SetControl(SetPageControl.STR_MVC_CLASS_NAME);
		urlmypage.AddControlArgument(SetPageControl.STR_PAGE_ID, 	m_nPageID);

		return urlmypage.GetURLAsString();
	}

	/**
	* Get My Pages
	*
	* @return boolean
	*/
	public IASQueryResult GetMyPages()
	{

		IPTMyPages myPages		 = m_ptSession.GetMyPages();
		IPTQueryResult userPages = myPages.QueryPages(0);
		IASQueryResult asQR		 = null;

		try
		{
			asQR = new ASQueryResultWrapper(userPages);
		}
		catch (Exception e)
		{
			log.Error(e, e.getMessage());
		}

		return asQR;
	}

	/**
	 * Get Object Name
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModel#GetPageID()
	 */
	public int GetPageID()
	{
		return m_nPageID;
	}
	
	/**
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModel#GetPageID()
	 */
	public String GetPageName()
	{
		return GetMyTempData().m_strPageName;
	}

	/**
	 * Get AS Parent
	 *
	 * @return AActivitySpace
	 */
	public AActivitySpace GetParent()
	{
		return m_asOwner;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			return null;
		}
		else
		{
			Redirect redirect = new Redirect();
			redirect.SetLinkGetSpaceIfCached(MyPageAS.STR_MVC_CLASS_NAME, m_asOwner);

			return redirect;
		}
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModelRO#GetSession()
	 */
	public IPTSession GetSession()
	{
		return m_ptSession;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModelRO#GetUserID()
	 */
	public int GetUserID()
	{
		return m_ptSession.GetSessionInfo().GetCurrentUserID();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner	    = parent;
		m_ptSession     = (IPTSession) m_asOwner.GetUserSession();

		m_bAlwaysCommunity = false;
	}

	/**
	 * IsErrorPage
	 *
	 * @param boolean
	 */
	public boolean IsErrorPage()
	{
		return m_bErrorPage;
	}

	/**
	* Is Portlet Footer
	*
	* @return boolean
	*/
	public boolean IsFooter()
	{
		return (m_nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FOOTER);
	}

	/**
	* Is Portlet FreeForm
	*
	* @return boolean
	*/
	public boolean IsFreeForm()
	{
		return (m_nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM);
	}

	/**
	 * Check if Portlet is already selected
	 */
	public boolean IsPortletChecked()
	{
		return m_bPortletChecked;
	}

	/**
	 * Is Portlet In Page - checks to if the gadget is already in
	 * the user's page that's specified
	 *
	 * @param int nPageID
	 */
	public boolean IsPortletInPage()
	{
		IPTPage myPage		 = (IPTPage)m_ptSession.GetPages().Open(m_nPageID, false);
		IPTQueryResult gadgetsInPage = myPage.QueryPortlets(); //list of gadgets in the portal

		//Variant Portlet;
		int intPortlet;
		boolean bIsInPage = false;

		for (int i = 0; i < gadgetsInPage.RowCount(); i++)
		{
			intPortlet = gadgetsInPage.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);

			if (intPortlet == m_nPortletID)
			{
				bIsInPage = true;
				GetMyTempData().m_strPageName = myPage.GetName();

				break;
			}
		}

		return bIsInPage;
	}

	/**
	* Is Portlet Invite Page
	*
	* @return boolean
	*/
	public boolean IsPortletInvitePage()
	{
		return (m_nPreviewStatus == INVITEHEADER);
	}



	/**
	* Is Portlet Search Preview Page
	*
	* @return boolean
	*/
	public boolean IsPortletSearchPreviewPage()
	{
		return (m_nPreviewStatus == SEARCHHEADER);
	}

	/**
	 * Is Portlet Selection Preview Page
	 *
	 * @return boolean
	 */
	public boolean IsPortletSelectionPreviewPage()
	{
		return (m_nPreviewStatus == SELECTIONPREVIEWHEADER);
	}

	/**
	* Is Portlet Header
	*
	* @return boolean
	*/
	public boolean IsHeader()
	{
		return (m_nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_HEADER);
	}

	/**
	* Is Portlet Narrow
	*
	* @return boolean
	*/
	public boolean IsNarrow()
	{
		return (m_nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NARROW);
	}

	/**
	* Is Portlet None
	*
	* @return boolean
	*/
	public boolean IsNone()
	{
		return (m_nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_NONE);
	}

	/**
	* Is Portlet Wide
	*
	* @return boolean
	*/
	public boolean IsWide()
	{
		return (m_nPortletAlignment == PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_WIDE);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String, XPHashtable)
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		PreviewPortletModelTempData tempData = (PreviewPortletModelTempData)GetTempData();
		int nSize				 = _htFormData.GetSize();
		IXPEnumerator xpKeys     = _htFormData.GetKeys();
		IXPEnumerator xpElements = _htFormData.GetElements();

		for (int i = 0; i < nSize; i++)
		{
			xpKeys.MoveNext();
			xpElements.MoveNext();
			tempData.m_htFormData.PutElement((String) xpKeys.GetCurrent(),
				(String[]) xpElements.GetCurrent());
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * Set the Add Portlet Javascript override.
	 * 
	 * This javascript should be the name of the javascript function to be
	 * used in the onclick attribute of the add button.  The function should
	 * take 2 arguments: the portlet ID, and a reference to the popup window.
	 * (i.e. If the name is "addPortlet", then the function will look like
	 * this: "addPortlet(portletID, self)").  This function name can also
	 * include an optional window reference (i.e. "opener.addPortlet").
	 *
	 * Null means to use the default javascript.
	 */
	public void SetAddPortletJavaScriptOverride(String _strOverride)
	{
		m_strJavascriptOverride = _strOverride;
	}

	/**
	 * SetErrorPage
	 *
	 * @param boolean
	 */
	public void SetErrorPage(boolean bSetErrorPage)
	{
		m_bErrorPage = bSetErrorPage;
	}

	/**
	 *
	 * @param sPortletChecked
	 */
	public void SetPortletChecked(boolean bPortletChecked)
	{
		m_bPortletChecked = bPortletChecked;
	}

	/**
	 * Set Portlet ID
	 *
	 * @param int nPortletID
	 */
	public void SetPortletID(int nPortletID)
	{
		m_nPortletID = nPortletID;
		// DCA - calling GetMyTempData() to make sure nPortletID is valid
		GetMyTempData();
	}
	
	/**
	 *
	 * @param nPortletIndex
	 */
	public void SetPortletIndex(int nPortletIndex)
	{
		m_nPortletIndex = nPortletIndex;
	}

	/**
	* Set to use Invite Header
	*/
	public void SetPortletToInvitePage()
	{
		m_nPreviewStatus = INVITEHEADER;
	}

	/**
	 * Set to use Preview Header
	 */
	public void SetPortletToPreviewPage()
	{
		m_nPreviewStatus = PREVIEWHEADER;
	}

	/**
	* Set to use Search Preview Header
	*/
	public void SetPortletToSearchPreviewPage()
	{
		m_nPreviewStatus = SEARCHHEADER;
	}

	/**
	 * Set to use Selection Preview Header
	 */
	public void SetPortletToSelectionPreviewPage()
	{
		m_nPreviewStatus = SELECTIONPREVIEWHEADER;
	}

	/**
	 * Sets the host page URI that is later used to initialize the AppDataObject
	 *
	 * @param strHostPageURI strHostPageURI
	 */
	public void SetHostPageURI(String strHostPageURI)
	{
		m_strHostPageURI = strHostPageURI;
	}

	/**
	 * Set The Page ID
	 *
	 * @param int
	 */
	public void SetPageID(int nPageID)
	{
		m_nPageID = nPageID;
	}

	/**
	 * 
	 *
	 * @param strRawHeaders 
	 */
	public void SetRawHeaders(String strRawHeaders)
	{
		m_strRawHeaders = strRawHeaders;
	}

	/**
	 * Register model, view, and control for intrinsic portlet.  Initialize
	 * portlet with the portletID, the IPTMyPortal object, and the
	 * AppDataState object.
	 *
	 * @param _strPortletClass Class identifier for portlet
	 * @param _strStorageName Storage name for portlet
	 *
	 * @throws XPException Exception thrown if model, view, or control is not
	 *         registered successfully.
	 */
	public void SetupIntrinsicPortlet(String _strPortletClass,
		String _strStorageName)
	{
		// Register Model
		if (!m_asOwner.GetModelExists(_strStorageName))
		{
			boolean bModelRegistered = m_asOwner.RegisterModel(_strPortletClass,
					_strStorageName);

			if (!bModelRegistered)
			{
				
					log.Error("PreviewPortletModel::SetupIntrinsicPortlet. " +
						m_asOwner.GetString(605, "ptmsgs_portalbrowsingmsgs"));
				

				throw new XPException(m_asOwner.GetString(605,
						"ptmsgs_portalbrowsingmsgs"));
			}
		}

		IntrinsicPortletModel iPortletModel = (IntrinsicPortletModel) m_asOwner.GetModel(_strStorageName);

		// Register Section
		if (!m_asOwner.GetViewExists(_strStorageName))
		{
			boolean bViewRegistered = m_asOwner.RegisterView(_strPortletClass,
					_strStorageName, iPortletModel);

			if (!bViewRegistered)
			{
				
					log.Error("PreviewPortletModel::SetupIntrinsicPortlet. " +
						m_asOwner.GetString(606, "ptmsgs_portalbrowsingmsgs"));
				

				throw new XPException(m_asOwner.GetString(606,
						"ptmsgs_portalbrowsingmsgs"));
			}
		}

		// Register Control
		if (iPortletModel.ControlExists())
		{
			if (!m_asOwner.GetControlExists(_strStorageName))
			{
				boolean bControlRegistered = m_asOwner.RegisterControl(_strPortletClass,
						_strStorageName, iPortletModel);

				if (!bControlRegistered)
				{
					
						log.Error("PreviewPortletModel::SetupIntrinsicPortlet. " +
							m_asOwner.GetString(604, "ptmsgs_portalbrowsingmsgs"));
					

					throw new XPException(m_asOwner.GetString(604,
							"ptmsgs_portalbrowsingmsgs"));
				}
			}
		}

		PreviewPortletModelTempData tempData = GetMyTempData();

		// Initialize portlet model
		iPortletModel.InitPortlet(null, tempData.m_objAppDataState, tempData.m_objPortlet,
		m_nPortletID);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModel#UserHasReadAccess()
	 */
	public boolean UserHasReadAccess()
	{
		return m_ptSession.GetGadgets().IsObjectAccessible(m_nPortletID,
			m_ptSession.GetSessionInfo().GetCurrentUserID(),
				PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ);
	}

	/**
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModel#UserHasSelectAccess()
	 */
	public boolean UserHasSelectAccess()
	{
		return m_ptSession.GetGadgets().IsObjectAccessible(m_nPortletID,
			m_ptSession.GetSessionInfo().GetCurrentUserID(),
				PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.browsing.portletpreview.IPreviewPortletModelRO#UserHasMyPageAccess()
	 */
	public boolean UserHasMyPageAccess() 
	{
		IPTSubPortalInfo subPortalInfo = m_ptSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo();
		int nBool = subPortalInfo.GetAccessType() & PT_SUBPORTAL_ACCESS_TYPES.PT_SUBPORTAL_MYPAGES_ACCESS;
		
		return nBool != 0;		
	}
	
	/**
	 * Method GetAllCommunitiesUsingPortlet.  Gets a compound list suitable for
	 * URL constrcution for communities preview links.
	 * @return ASCompoundList
	 */
	public XPArrayList GetAllCommunitiesUsingPortlet()
	{
		XPArrayList list = new XPArrayList();

		try
		{
			IPTCommunityManager ptCommOM = (IPTCommunityManager) m_ptSession.GetCommunities();
			if (ptCommOM == null)
			{
				return list;
			}
			
			IPTQueryResult ptQRCommunities = ptCommOM.QueryCommunitiesForGadget(m_nPortletID);
			if (ptQRCommunities == null)
			{
				return list;
			}
		
			// form list of objects to be used to form URLs to community preview (invite)
			for (int i = 0; i < ptQRCommunities.RowCount(); i++)
			{
				int iCommID    = ptQRCommunities.ItemAsInt(i,
						PT_PROPIDS.PT_PROPID_OBJECTID);
				String strCommName = ptQRCommunities.ItemAsString(i,
						PT_PROPIDS.PT_PROPID_NAME);

				list.Add(new CommunityInviteItem( iCommID, strCommName ));
			}
		}
		catch (Exception e)
		{
			
				log.Error(e, "Exception getting Related Communities.");
			
		}

		return list;	
	}
}

