package com.plumtree.portalpages.browsing.search.advanced;


// Plumtree Server Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.search.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;
//Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;

/**
 *  ActivitySpace for advanced search.
 *  @author CraigS
 */
public class AdvancedSearchAS extends PlumtreeAS implements IFormAS
{
	
	public static final String STR_MVC_CLASS_NAME = "AdvancedSearch";

	/**
	 * 
	 *
	 * @return 
	 */
	public Object Create()
	{
		return new AdvancedSearchAS();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the name of the repost control class.
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return AdvancedSearchRepostControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 */
	public void Init()
	{
		super.Init();
		ISessionManager subsession = GetSubSession();

		BrowserType browser = (BrowserType) subsession.GetAttribute(Interpreter.BROWSERTYPE);
		boolean bNS4 = browser.IsNetscape4();

		// In 508 mode, we actually want to use the "power search" model and view,
		// which use no javascript.
		if (GetAccessStyle() != AccessStyles.STANDARD || bNS4)
		{
			RegisterModel(PowerSearchModel.STR_MVC_CLASS_NAME);

			PowerSearchModel powerModel = (PowerSearchModel) GetModel(PowerSearchModel.STR_MVC_CLASS_NAME);

			powerModel.Setup( /* propertyConstraints= */
				new int[]
				{
					1, /* name */
				2, /* description */
				50, /* content */
				3, /* created */
				4, /* last modified */
				101, /* keywords */
				103, /* author */
				106
				}, 
			/* supportTextSearch= */ true, 
			/* supportedClassIDs= */ new int[] { PT_CLASSIDS.PT_CATALOGCARD_ID, 
                                           PT_CLASSIDS.PT_CATALOGFOLDER_ID,
                                           PT_CLASSIDS.PT_COMMUNITY_ID,
                                           PT_CLASSIDS.PT_GADGET_ID,
                                           PT_CLASSIDS.PT_USER_ID },
			/* makeClassIDsSelectable= */ true, 
			/* showAbstractTypeSelector= */ false,
			/* showApplicationSelector= */ true);

			RegisterControl(PowerSearchControl.STR_MVC_CLASS_NAME, powerModel);
			RegisterView(PowerSearchView.STR_MVC_CLASS_NAME, powerModel);
			RegisterPage(new PowerSearchDP());

			if (ObjMgrAS.STR_MVC_CLASS_NAME.equals(GetParentSpaceName()))
			{
				// If we came from the ObjMgr page (admin), then we must be
				// doing an admin advanced search and need the appropriate
				// help.
				SetHelpTopic("PT_AdvancedAdministrativeSearch");
			} else
			{
				// Otherwise just use the normal advanced search help.
				SetHelpTopic("PT_AdvancedSearch");
			}

			return;
		}

		// Register and init model
		RegisterModel(AdvancedSearchModel.STR_MVC_CLASS_NAME);

		IAdvancedSearchModelRO model = (IAdvancedSearchModelRO) GetModel(AdvancedSearchModel.STR_MVC_CLASS_NAME);

		// Register DisplayPages
		RegisterPage(new AdvancedSearchDP());

		// Register views and give them access to the model
		
		//ASFilterView adds the property search criteria to the advanced search page 
		RegisterView(ASFilterView.STR_MVC_CLASS_NAME, model);
		//ASButtonView adds and handles the Search button on advanced search page
		RegisterView(ASButtonView.STR_MVC_CLASS_NAME, model);
		//ASFooterView adds the clear button on the advanced search page
		RegisterView(ASFooterView.STR_MVC_CLASS_NAME, model);

		// Register controls
		RegisterControl(AdvancedSearchRepostControl.STR_MVC_CLASS_NAME,
			(IModel) model);
		RegisterControl(EditorStartControl.STR_MVC_CLASS_NAME, (IModel) model);

		// Register the language plugin model.
		RegisterModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME);

		IModel languageModel = GetModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME);

		// Register the language plugin views and controls.
		RegisterView(CardLanguagePlugInView.STR_MVC_CLASS_NAME, languageModel);
		RegisterControl(CardLanguagePlugInRepostControl.STR_MVC_CLASS_NAME,
			languageModel);

		// Register the number-of-results model.
		RegisterModel(SimpleSelectorModel.STR_MVC_CLASS_NAME);

		IModel nrModel = GetModel(SimpleSelectorModel.STR_MVC_CLASS_NAME);

		// Register the number-of-results plugin view.
		RegisterView(SimpleSelectorView.STR_MVC_CLASS_NAME, nrModel);

		// Register the folder selection plugin model.
		RegisterModel(FolderSelectorModel.STR_MVC_CLASS_NAME);

		IModel foldersModel = GetModel(FolderSelectorModel.STR_MVC_CLASS_NAME);

		// Register folder selection views and controls.
		RegisterView(ASFoldersView.STR_MVC_CLASS_NAME, foldersModel);
		RegisterControl(FolderSelectorRepostControl.STR_MVC_CLASS_NAME,
			foldersModel);

		// Register the type selection plugin model.
		RegisterModel(TypeSelectorModel.STR_MVC_CLASS_NAME);

		IModel typeModel = GetModel(TypeSelectorModel.STR_MVC_CLASS_NAME);

		// Register type selection views and controls.
		RegisterView(ASTypesView.STR_MVC_CLASS_NAME, typeModel);
		RegisterControl(TypeSelectorRepostControl.STR_MVC_CLASS_NAME, typeModel);

		if (ObjMgrAS.STR_MVC_CLASS_NAME.equals(GetParentSpaceName()))
		{
			// If we came from the ObjMgr page (admin), then we must be
			// doing an admin advanced search and need the appropriate
			// help.
			SetHelpTopic("PT_AdvancedAdministrativeSearch");
		} else
		{
			// Otherwise just use the normal advanced search help.
			SetHelpTopic("PT_AdvancedSearch");
		}
	}
}

