package com.plumtree.portalpages.browsing.search.advanced;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.search.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.IPTSession;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.AccessStyles;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public class AdvancedSearchDP extends PlumtreeDP
{
  
  public static final String STR_MVC_CLASS_NAME = "AdvancedSearch";

  public static final String TABLE_WIDTH = "95%";
  public static final String NARROW_SPACER = "10";
  public static final String WIDE_SPACER = "15";
  
  private static final String PORTAL_BROWSING_MSGS = "ptmsgs_portalbrowsingmsgs";

  
  /**
  * Displays some HTML after the body tag and before the form tag.
  * For example this is used by pages using a DHTML calendar to display the div tag.
  * The function is optional.  If it exists, it will be called by the framework, and
  * the resulting HTMLElement will be added in the right place.
  *
  * @return HTMLElement
  */
  public HTMLElementCollection DisplayHTMLBeforeForm()
  {
    return FilterView.GetPagePreFormContent(m_asOwner);
  }

  /**
   * 
   *
   * @return 
   */
  public String GetName()
  {
    return STR_MVC_CLASS_NAME;
  }

  /**
   * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
   */
  public String GetSubtitleForBanner()
  {
    return "";
  }

  /**
   * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
   */
  public String GetTitleForBanner()
  {
    return m_asOwner.GetString(748, PORTAL_BROWSING_MSGS);
  }

  /**
   * 
   *
   * @param parent 
   */
  public void Init(AActivitySpace parent)
  {
    super.Init(parent);
    SetAddMainForm(true);
  }

  /**
   * 
   *
   * @return 
   *
   * @throws HTMLException 
   */
  public HTMLElement PageDisplay()
  {	  
	  // try to use the XML page layout to display this page.
	  // If page layout is not enabled, the DisplayLayout method will return null.
	  //
	  if ( IsAdaptiveLayoutMode() )
	  {
		  HTMLElement element = DisplayLayout(Layouts.ADVANCED_SEARCH);
		  if (null != element) {
			  return element;
		  }
	  }

	HTMLElementCollection result = new HTMLElementCollection();
    
    AddHiddenModeInput(result);
    
    result.AddInnerHTMLElement(makeSpacer(WIDE_SPACER, m_asOwner));

    // Query header outer table
    HTMLTable table = new HTMLTable();
    result.AddInnerHTMLElement(table);
    table.SetCellSpacing(CommonHTMLStrings.FIVE);
    table.SetCellPadding(CommonHTMLStrings.FIVE);
    table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

    HTMLTableRow row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
    table.AddInnerHTMLElement(row);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.DIR_HEADER);

    // Query header inner table
    table = new HTMLTable();
    cell.AddInnerHTMLElement(table);
    table.SetCellSpacing(CommonHTMLStrings.ZERO);
    table.SetCellPadding(CommonHTMLStrings.ZERO);
    table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

    row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
    table.AddInnerHTMLElement(row);

    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.DIR_TEXT);
    cell.SetHeight("25");
    cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
    cell.SetVAlign(CommonHTMLStrings.MIDDLE);
    cell.SetNoWrap(true);
    HTMLSpan span = new HTMLSpan();
    span.SetStyleClass(PTStyleClass.DIR_HEADER);
    cell.AddInnerHTMLElement(span);

    span.AddInnerHTMLString(m_asOwner.GetString(750,PORTAL_BROWSING_MSGS));

    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetNoWrap(true);
    cell.SetAlign(CommonHTMLStrings.RIGHT);
    cell.SetWidth("300");
    cell.SetStyleClass(PTStyleClass.BAN_TEXT);
	
	cell.AddInnerHTMLElement(m_asOwner.GetView(ASButtonView.STR_MVC_CLASS_NAME).Display());
	cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
    cell.AddInnerHTMLElement(m_asOwner.GetView(ASFooterView.STR_MVC_CLASS_NAME).Display());
   // cell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");
    cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

	

    // Query filter table
    table = new HTMLTable();
    result.AddInnerHTMLElement(table);
    table.SetCellSpacing(CommonHTMLStrings.FIVE);//lll
    table.SetCellPadding(CommonHTMLStrings.ZERO);
    table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
    
    // Settings table
    HTMLTable settingsTable = new HTMLTable();
    result.AddInnerHTMLElement(settingsTable);
    settingsTable.SetCellSpacing(CommonHTMLStrings.FIVE);
    settingsTable.SetCellPadding(CommonHTMLStrings.ZERO);
    settingsTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

    // Single row for settings table
    HTMLTableRow settingsRow = new HTMLTableRow();
    settingsTable.AddInnerHTMLElement(settingsRow);

    // Cells for settings table
    HTMLTableCell leftSettingsCell = new HTMLTableCell();
    settingsRow.AddInnerHTMLElement(leftSettingsCell);
    leftSettingsCell.SetVAlign(CommonHTMLStrings.TOP);
    leftSettingsCell.SetWidth("74%");
    
    

    // Spacer cell between left and right side
    HTMLTableCell spacerCell = new HTMLTableCell();
    settingsRow.AddInnerHTMLElement(spacerCell);
    spacerCell.SetWidth(CommonHTMLStrings.ZERO);
    spacerCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

    HTMLTableCell rightSettingsCell = new HTMLTableCell();
    settingsRow.AddInnerHTMLElement(rightSettingsCell);
    rightSettingsCell.SetVAlign(CommonHTMLStrings.TOP);
	leftSettingsCell.AddInnerHTMLElement(m_asOwner.GetView(
		ASFilterView.STR_MVC_CLASS_NAME).Display());
	leftSettingsCell.AddInnerHTMLElement(makeSpacer(NARROW_SPACER, m_asOwner));
    // CS: is this right?  it seems like it is deliberately misaligning the left and right cells?
    //	rightSettingsCell.AddInnerHTMLElement(makeSpacer("1", m_asOwner));
    leftSettingsCell.AddInnerHTMLElement(m_asOwner.GetView(
        ASFoldersView.STR_MVC_CLASS_NAME).Display());
    //leftSettingsCell.AddInnerHTMLElement(makeSpacer(NARROW_SPACER, m_asOwner));
    
    // Ravi Tunuguntla - Moved Search Help Text to Left setting cell so that
    // it shows up just underneath the Search Filters rather than way down at the 
    // footer of the Page.
    leftSettingsCell.AddInnerHTMLElement(makeSpacer(NARROW_SPACER, m_asOwner));
    leftSettingsCell.AddInnerHTMLElement(MakeSearchHelpText(m_asOwner));
	
    rightSettingsCell.AddInnerHTMLElement(m_asOwner.GetView(
        SimpleSelectorView.STR_MVC_CLASS_NAME).Display());
	rightSettingsCell.AddInnerHTMLElement(makeSpacer(NARROW_SPACER, m_asOwner));
	CardLanguagePlugInModel languageModel = (CardLanguagePlugInModel)m_asOwner.GetModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME);
	languageModel.SetInstructionLabel(m_asOwner.GetString(1664, PORTAL_BROWSING_MSGS));

	rightSettingsCell.AddInnerHTMLElement(((CardLanguagePlugInView)m_asOwner.GetView(
		CardLanguagePlugInView.STR_MVC_CLASS_NAME)).Display());
	rightSettingsCell.AddInnerHTMLElement(makeSpacer(NARROW_SPACER, m_asOwner));

    rightSettingsCell.AddInnerHTMLElement(m_asOwner.GetView(
        ASTypesView.STR_MVC_CLASS_NAME).Display());

    return result;

  }

  /**
   * 
   *
   * @param height 
   *
   * @return 
   *
   * @throws HTMLException 
   */
  public static HTMLElement makeSpacer(String height, AActivitySpace owner)
  {
    HTMLTable table = new HTMLTable();
    table.SetCellSpacing(CommonHTMLStrings.ZERO);
    table.SetCellPadding(CommonHTMLStrings.ZERO);
    table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

    HTMLTableRow row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);

    HTMLImg img = null;

    try
    {
      img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
          true, owner).GetHTMLElement();
    }
    catch (Exception e)
    {
      throw XPException.GetInstance(e);
    }

    cell.AddInnerHTMLElement(img);
    img.SetHeight(height);
    img.SetWidth(CommonHTMLStrings.ONE);
    img.SetBorder(CommonHTMLStrings.ZERO);
    img.SetAlign(CommonHTMLStrings.ABSMIDDLE);

    return table;
  }

  /**
   * 
   *
   * @return 
   *
   * @throws HTMLException 
   */
  protected HTMLScriptCollection DisplayJavaScriptFromChild()
  {
    HTMLScriptCollection scripts = super.DisplayJavaScriptFromChild();
    scripts.AddInnerHTMLElement(m_asOwner.GetView(
        ASFoldersView.STR_MVC_CLASS_NAME).DisplayJavascript());
    scripts.AddInnerHTMLElement(m_asOwner.GetView(
        ASTypesView.STR_MVC_CLASS_NAME).DisplayJavascript());
    scripts.AddInnerHTMLElement(m_asOwner.GetView(
        ASFilterView.STR_MVC_CLASS_NAME).DisplayJavascript());

    return scripts;
  }

  /**
   * display code to create the search help text added in the advanced search settings page.
   *
   * @return 
   *
   * @throws HTMLException 
   */
  public static HTMLTable MakeSearchHelpText(AActivitySpace m_asOwner)
  {
    HTMLTable outerTable = new HTMLTable();
    outerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

    HTMLTableRow row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
    outerTable.AddInnerHTMLElement(row);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);

    cell.AddInnerHTMLString(m_asOwner.GetString(751,
        PORTAL_BROWSING_MSGS));

    cell.AddInnerHTMLElement(new HTMLBr());
    cell.AddInnerHTMLElement(new HTMLBr());

    HTMLTable table = new HTMLTable();
    cell.AddInnerHTMLElement(table);
    table.SetCellSpacing(CommonHTMLStrings.TWO);
    table.SetCellPadding(CommonHTMLStrings.THREE);

    row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(752,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(753,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(754,
        PORTAL_BROWSING_MSGS));

    row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(755,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(756,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(757,
        PORTAL_BROWSING_MSGS));

    row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(758,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(759,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(760,
        PORTAL_BROWSING_MSGS));

    row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(761,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(762,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(763,
        PORTAL_BROWSING_MSGS));

    row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(764,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(765,
        PORTAL_BROWSING_MSGS));
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(766,
        PORTAL_BROWSING_MSGS));

    return outerTable;
  }
  
  protected void AddHiddenModeInput(HTMLElement result)
  {
  	// The idea here is to pass along the mode we come in with, if it wasn't the default, BROWSE_MODE.
	if(! SearchPageModeHelper.UserHasEditModeAccess(m_asOwner))
		return;
	AdvancedSearchModel m = (AdvancedSearchModel)m_asOwner.GetModel(AdvancedSearchModel.STR_MVC_CLASS_NAME);
	String mode = m.GetMode();
  	if (null != mode)
  	{
		HTMLInput inp = new HTMLInput(HTMLInputTypes.HIDDEN,SearchResultModel.MODEL_MODE_INPUT,SearchResultModel.MODEL_MODE_INPUT);
		inp.SetValue(mode);
		result.AddInnerHTMLElement(inp);
  	}
  }
  
  public static ASURL GetAdvancedSearchURL(AActivitySpace m_asOwner)
  {
	ASURL url = new ASURL(m_asOwner);
	url.SetLinkCreateNewSpace(AdvancedSearchAS.STR_MVC_CLASS_NAME,m_asOwner);
	url.SetControl("EditorStart");
	url.AddControlArgument("editorType", "10");
	url.AddInnerHTMLString(m_asOwner.GetString(1702, "ptmsgs_portalbrowsingmsgs"));
	return url;

  }
  
  //this function is checking if the current access style is STANDARD and the layout mode is enabled, if true
  //adaptive layouts are supported.  If either one is false, then we're not in adaptive layout mode.
	private boolean IsAdaptiveLayoutMode()
	{
		boolean standardStyle = m_asOwner.GetIsAccessStyleStandard();
		boolean isLayoutMode = LayoutService.getChooserInstance().GetPageLayoutsEnabled(m_asOwner);
		IPTSession userSess = (IPTSession)m_asOwner.GetUserSession();
		boolean isExpLayoutMode = userSess.GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetLayoutEnabled();
		return (standardStyle && isLayoutMode && isExpLayoutMode);
	}
}

