package com.plumtree.portalpages.browsing.search.advanced;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portalpages.common.documentlanguage.*;
import com.plumtree.portalpages.common.search.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author CraigS
 */
public class AdvancedSearchModel extends EditorModel
	implements IAdvancedSearchModelRO
{
	public static final String STR_MVC_CLASS_NAME = "AdvancedSearchModel";

	public static final String HTML_SELECT_NUMRESULTS = "in_se_numresults";
	private CardLanguagePlugInModel _languageModel;

	// Passthru IFilterIteratorIO methods
	private FilterIterator _filterIterator;
	private FolderSelectorModel _foldersModel;
	private IPTFilter _filter;
	private IPTSession _session;
	private SimpleSelectorModel _numResultsModel;
	private TypeSelectorModel _typeModel;
	private boolean _showErrorsOnPage;
	protected String _mode = SearchPageModeHelper.BROWSE_MODE;

	/**
	 * 
	 *
	 * @return 
	 */
	public IPTFilter GetFilter()
	{
		return _filter;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public IPTSession GetSession()
	{
		return _session;
	}

  /**
   *  Returns the current filter iterator.
   *  @return the current filter iterator
   */
  public IFilterIteratorRO GetFilterIterator() {
    return _filterIterator;
  }

	/**
	 * Implements some actions to perform on start.
	 * @param _htFormData
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		// We may be coming from a page that already has a results mode selected. In that
		// case we need to be sure that the mode gets passed on to our results.
		if (SearchPageModeHelper.UserHasEditModeAccess(m_asOwner))
			_mode = GetModelMode(_htFormData);

		_session     = (IPTSession) m_asOwner.GetUserSession();

		// Create a temporary filter
		try
		{
			_filter = FilterForm.BuildFilterFromForm(m_asOwner,
			_htFormData,
			"");
		}
		catch(Exception e)
		{
		}
		if(_filter == null)
			_filter			    = PortalObjectsFactory.CreateSearchFilter();
		
		_filterIterator     = new FilterIterator(_session, _filter, m_asOwner);

		// Initialize the language plugin
		_languageModel = (CardLanguagePlugInModel) m_asOwner.GetModel(CardLanguagePlugInModel.STR_MVC_CLASS_NAME);
		String lastLang = _languageModel.GetLangFromFormData(_htFormData);
		if(lastLang == null || lastLang.equals(""))
			lastLang = CardLanguagePlugInView.s_AllLanguagesOptionCode;
			
		_languageModel.InitializePlugIn( /* defaultlanguage= */
		lastLang, 
		m_asOwner.GetString(767, "ptmsgs_portalbrowsingmsgs"),
			
		m_asOwner.GetString(768, "ptmsgs_portalbrowsingmsgs"), 
		/* includeAllLangs= */ true);

		// Initialize the number-of-results plugin
		_numResultsModel = (SimpleSelectorModel) m_asOwner.GetModel(SimpleSelectorModel.STR_MVC_CLASS_NAME);
		_numResultsModel.InitializePlugIn(new String[] { "10", "20", "50", "100" },
			
		/* initialSelection= */ 0, 
		m_asOwner.GetString(769, "ptmsgs_portalbrowsingmsgs"),
			
		m_asOwner.GetString(770, "ptmsgs_portalbrowsingmsgs"),
			HTML_SELECT_NUMRESULTS);
		_numResultsModel.SetSelectionFromFormData(_htFormData);

		// Initialize the folders plugin
		_foldersModel = (FolderSelectorModel) m_asOwner.GetModel(FolderSelectorModel.STR_MVC_CLASS_NAME);
		_foldersModel.InitializePlugIn( /* multiselect= */ true);
		_foldersModel.InitFromFormData(_htFormData);

		boolean adminMode = (null != _mode) && (_mode.equals(SearchPageModeHelper.ADMIN_MODE));
		
		// Initialize the types plugin
		_typeModel = (TypeSelectorModel) m_asOwner.GetModel(TypeSelectorModel.STR_MVC_CLASS_NAME);
		_typeModel.InitializePlugIn(/* showAbstractTypes= */ false, /*noTypesSelected */ adminMode);
		_typeModel.InitFromFormData(_htFormData);

		// Don't show potential errors until the user first attempts to submit
		_showErrorsOnPage = false;

		return true;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Object Create()
	{
		return new AdvancedSearchModel();
	}

	/**
	 * 
	 */
	public void Finish()
	{
		// nothing needed here
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetShowPotentialErrors()
	{
		return _showErrorsOnPage;
	}

	/**
	 * Calls the right save function according to the page name passed in argument.
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String pageName, XPHashtable formData)
	{
    _filter = FilterForm.BuildFilterFromForm(m_asOwner, formData);

		// Reinitialize filter iterator
		_filterIterator.InitFromFilter(_filter);

		// Passthru to save plugin models as well
		_languageModel.SaveSection(formData);
		_numResultsModel.SaveSection(formData);
		_foldersModel.SaveSection(formData);
		_typeModel.SaveSection(formData);

		// Page may now be redisplayed from saved model
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 */
	public void SetShowPotentialErrors()
	{
		_showErrorsOnPage = true;
	}
	
	protected String GetModelMode(XPHashtable formdata)
	{
		String[] val = (String[])formdata.GetElement(SearchResultModel.MODEL_MODE_INPUT);
		if(val == null || val.length == 0)
			return SearchPageModeHelper.BROWSE_MODE;
		else
		    return val[0];
	}
	
	public String GetMode()
	{
		return _mode;
	}
}

