package com.plumtree.portalpages.browsing.search.advanced;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.datepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 *  @author CraigS
 */
public class PowerSearchModel implements IModelRO, IModel
{
	
	public static final String STR_MVC_CLASS_NAME = "PowerSearch";

	/**
	 *  Owning ActivitySpace
	 */
	private AActivitySpace m_asOwner;

	/**
	 *  Our cache of property IDs, names, and types
	 */
	private IASQueryResult _propertyCache = null;

	/**
	 *  Owning session
	 */
	private IPTSession _session;
	private int[] _propertyConstraints;
	private int[] _supportedClassIDs;
	private boolean _makeClassIDsSelectable;
	private boolean _showAbstractTypeSelector;
	private boolean _showApplicationSelector;
	private boolean _supportTextSearch;

	/** Page manager, needed by date-time picker */
	protected PageMgr m_ptPageMgr;

	/** Our own cache of datepicker objects that we've created.  Needed
	 *  because PageMgr is not so good at handling duplicate datepickers
	 *  with the same name - if we simply ask for the same one back again,
	 *  we sometimes get a new one, and thereafter, calls through PageMgr
	 *  will end up altering one or the other but not both.
	 *
	 *  Map of String -> ADatePickerComponent.
	 */
	private XPHashtable _datePickerCache = null;

	/**
	 * 
	 */
	public void CleanupTempData()
	{
		_propertyCache = null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Object Create()
	{
		return new PowerSearchModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetMakeClassIDsSelectable()
	{
		return _makeClassIDsSelectable;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumPropertyConstraints()
	{
		return _propertyConstraints.length;
	}

	/**
	 * 
	 *
	 * @param idx 
	 *
	 * @return 
	 */
	public int GetPropertyID(int idx)
	{
		return _propertyConstraints[idx];
	}

	/**
	 * 
	 *
	 * @param idx 
	 *
	 * @return 
	 */
	public String GetPropertyName(int idx)
	{
		initPropertyCache();

		int propID = GetPropertyID(idx);

		for (int j = 0; j < _propertyCache.GetCount(); j++)
		{
			if (XPConvert.ToInteger(_propertyCache.GetFields(j,
						PT_PROPIDS.PT_PROPID_OBJECTID)) == propID)
			{
				// found it
				try
				{
					return ((String) _propertyCache.GetFields(j,
						PT_PROPIDS.PT_PROPID_NAME));
				}
				catch (Exception e)
				{
					throw XPException.GetInstance(e);
				}
			}
		}

		return "";
	}

	/**
	 * 
	 *
	 * @param idx 
	 *
	 * @return 
	 */
	public int GetPropertyType(int idx)
	{
		initPropertyCache();

		int propID = GetPropertyID(idx);

		int propType = -1;

		for (int j = 0; j < _propertyCache.GetCount(); j++)
		{
			if (XPConvert.ToInteger(_propertyCache.GetFields(j,
						PT_PROPIDS.PT_PROPID_OBJECTID)) == propID)
			{
				// found it
				try
				{
					propType = XPConvert.ToInteger(_propertyCache.GetFields(j,
							PT_PROPIDS.PT_PROPID_PROP_VALUETYPE));
				}
				catch (Exception e)
				{
					throw XPException.GetInstance(e);
				}

				return propType;
			}
		}

		throw new XPException("unknown property ID " + propID);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetShowAbstractTypeSelector()
	{
		return _showAbstractTypeSelector;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetShowApplicationSelector()
	{
		return _showApplicationSelector;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetSupportTextSearch()
	{
		return _supportTextSearch;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int[] GetSupportedClassIDs()
	{
		return _supportedClassIDs;
	}

	/**
	 * 
	 *
	 * @param parent 
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner     = parent;
		_session	  = (IPTSession) m_asOwner.GetUserSession();
	}

	public void MakeAndCacheDateTimePicker(int propID)
	{
		// Just call the Get method, which caches it for us.
		GetDateTimePicker(propID);
	}

	public ADatePickerComponent GetDateTimePicker(int propID)
	{
		if (null == m_ptPageMgr)
		{
			String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
			m_ptPageMgr = new PageMgr(m_asOwner.GetAccessStyle(),
						  PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner),
						  PTPersonalSettingsHelper.GetPersonalSettingValue_TimeZone(m_asOwner),
						  strImageServerBaseURL,
						  ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));
		}

		// Initialize our datepicker cache if we haven't already
		if (null == _datePickerCache)
		{
			_datePickerCache = new XPHashtable();
		}

		final String KEY_PREFIX = "powersearch";
		String dtpKey = KEY_PREFIX + XPConvert.ToString(propID);

		Object cacheValue = _datePickerCache.GetElement(dtpKey);
		ADatePickerComponent dtPicker = null;

		if (null != cacheValue)
		{
			dtPicker = (ADatePickerComponent) cacheValue;
		}
		else
		{
			// Make a new one
			dtPicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DateTimePicker");
			_datePickerCache.PutElement(dtpKey, dtPicker);

			dtPicker.Init(PowerSearchView.FORMNAME, m_ptPageMgr, dtpKey);
		}

		return dtPicker;
	}

	public int StoreAllDateInputs(XPHashtable args)
	{
		if (null != m_ptPageMgr)
		{
			return m_ptPageMgr.StoreAllUserInput(args);
		}
		return RepostControl.PAGE_STATUS_VALID;
	}

	public String GetPageManagerErrors()
	{
		if (null != m_ptPageMgr)
		{
			return m_ptPageMgr.GetErrorMessages(m_asOwner);
		}
		return null;
	}

	/**
	 * 
	 *
	 * @param propertyConstraints 
	 * @param supportTextSearch 
	 * @param supportedClassIDs 
	 * @param makeClassIDsSelectable 
	 * @param showAbstractTypeSelector 
	 * @param showApplicationSelector 
	 */
	public void Setup(int[] propertyConstraints, boolean supportTextSearch,
                    int[] supportedClassIDs, boolean makeClassIDsSelectable,
                    boolean showAbstractTypeSelector,
                    boolean showApplicationSelector)
	{
		_propertyConstraints	    = propertyConstraints;
		_supportTextSearch		    = supportTextSearch;
		_supportedClassIDs		    = supportedClassIDs;
		_makeClassIDsSelectable     = makeClassIDsSelectable;

		// If the abstract type selector is visible, does it make any
		// sense to also restrict class IDs?
		_showAbstractTypeSelector = showAbstractTypeSelector;

		_showApplicationSelector = showApplicationSelector;

		initPropertyCache();
	}

	/**
	 * 
	 */
	private void initPropertyCache()
	{
		if (null == _propertyCache)
		{
			int fields = PT_PROPIDS.PT_PROPID_OBJECTID |
				PT_PROPIDS.PT_PROPID_NAME |
				PT_PROPIDS.PT_PROPID_PROP_VALUETYPE;

			PTObjectManagerQueryWrapper omqw = new PTObjectManagerQueryWrapper(_session.GetProperties());

			Object[][] ptqf = new Object[3][1];
			ptqf[0][0]     = new Integer(PT_PROPIDS.PT_PROPID_PROP_SEARCHABLE);
			ptqf[1][0]     = new Integer(PT_FILTEROPS.PT_FILTEROP_GT);
			ptqf[2][0]     = new Integer(0);

			omqw.Query(fields, -1, null, ptqf);
			_propertyCache = (IASQueryResult) omqw;
		}
	}
}
