package com.plumtree.portalpages.browsing.search.basic;

import com.plumtree.portalpages.browsing.portalsettings.search.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author MatthewF
 */
public class BasicSearchView implements IView
{
  
	public static final String STR_MVC_CLASS_NAME = "BasicSearchView";
	
	private static final String PORTAL_BROWSING_MSGS = "ptmsgs_portalbrowsingmsgs";

	protected AActivitySpace _parent;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new BasicSearchView();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		SearchFormFactory factory = new SearchFormFactory("basicsearch", "basicsearch", _parent, 
		/* completeForm= */ true);
		factory.ForceBannerSearchDefaults();

		HTMLElementCollection result = new HTMLElementCollection();
		
		result.AddInnerHTMLElement(AdvancedSearchDP.makeSpacer("10",_parent));

		// Query header outer table
		HTMLTable table = new HTMLTable();
		result.AddInnerHTMLElement(table);
		table.SetCellSpacing(CommonHTMLStrings.FIVE);
		table.SetCellPadding(CommonHTMLStrings.FIVE);
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.DIR_HEADER);

		// Query header inner table
		table = new HTMLTable();
		cell.AddInnerHTMLElement(table);
		table.SetCellSpacing(CommonHTMLStrings.ZERO);
		table.SetCellPadding(CommonHTMLStrings.ZERO);
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

		row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
		table.AddInnerHTMLElement(row);

		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.DIR_TEXT);
		cell.SetHeight("25");
		cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		cell.SetVAlign(CommonHTMLStrings.MIDDLE);
		cell.SetNoWrap(true);
		HTMLSpan span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.DIR_HEADER);
		cell.AddInnerHTMLElement(span);

		span.AddInnerHTMLString(_parent.GetString(1701,PORTAL_BROWSING_MSGS));

		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetNoWrap(true);
		cell.SetAlign(CommonHTMLStrings.RIGHT);
		cell.SetWidth("300");
		cell.SetStyleClass(PTStyleClass.BAN_TEXT);
		BasicSearchButtonView bsbv = (BasicSearchButtonView)_parent.GetView(BasicSearchButtonView.STR_MVC_CLASS_NAME);
		bsbv.SetFactory(factory);
		cell.AddInnerHTMLElement(bsbv.Display());
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		result.AddInnerHTMLElement(AdvancedSearchDP.makeSpacer("5",_parent));

		HTMLTable wrapperTable = new HTMLTable();
		result.AddInnerHTMLElement(wrapperTable);

		wrapperTable.SetCellSpacing(CommonHTMLStrings.FIVE);
		wrapperTable.SetCellPadding(CommonHTMLStrings.FIVE);
		wrapperTable.SetBorder("0");
		wrapperTable.SetWidth("100%");

		HTMLTableRow wrapperRow = new HTMLTableRow();
		HTMLTableCell wrapperCell = new HTMLTableCell();
		wrapperRow.AddInnerHTMLElement(wrapperCell);
		wrapperTable.AddInnerHTMLElement(wrapperRow);

		HTMLForm form = factory.GetForm();

		wrapperCell.AddInnerHTMLElement(form);

		table = new HTMLTable();
		table.SetCellSpacing("0");
		table.SetCellPadding("3");

		form.AddInnerHTMLElement(table);

		row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.DIR_CONTENT_BG);
		table.AddInnerHTMLElement(row);

		cell = new HTMLTableCell();
		cell.SetHeight("25");
		cell.SetVAlign("middle");
		row.AddInnerHTMLElement(cell);
		cell.SetStyleClass(PTStyleClass.DIR_CONTENT_TEXT);
		cell.SetNoWrap(true);
		cell.AddInnerHTMLString(_parent.GetString(1703, "ptmsgs_portalbrowsingmsgs"));

		cell = new HTMLTableCell();
		cell.SetHeight("25");
		cell.SetVAlign("middle");

		HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT, factory.GetInputBoxName(), "portletsearchbox");
		String keyDown = factory.GetInputBoxOnKeyDown();

		if (null != keyDown)
		{
			input.SetOnKeyDown(keyDown);
		}

		input.SetSize("32");
		input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		cell.AddInnerHTMLElement(new HTMLGenericElement(" "));
		cell.AddInnerHTMLElement(input);
		row.AddInnerHTMLElement(cell);

		cell = new HTMLTableCell();
		cell.SetHeight("25");
		cell.SetVAlign("middle");
		cell.SetAlign("right");
		cell.SetWidth("100%");
		cell.SetNoWrap(true);
		cell.AddInnerHTMLString(" ");
		ASURL url = GetSearchPrefsURL(_parent);

		cell.AddInnerHTMLElement(url.GetURLAsHTMLElement());
		row.AddInnerHTMLElement(cell); 

		result.AddInnerHTMLElement(AdvancedSearchDP.makeSpacer("30",_parent));
		result.AddInnerHTMLElement(AdvancedSearchDP.MakeSearchHelpText(_parent));
		return result;

	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		_parent = parent;
	}
	
	public static ASURL GetBasicSearchURL(AActivitySpace space)
	{
		ASURL url = new ASURL(space);
		url.SetLinkCreateNewSpace(com.plumtree.portalpages.browsing.search.basic.BasicSearchAS.STR_MVC_CLASS_NAME,
			space);
		url.AddInnerHTMLString(space.GetString(1700, "ptmsgs_portalbrowsingmsgs"));
		return url;
	}
	
	public static ASURL GetSearchPrefsURL(AActivitySpace space)
	{
		ASURL url = new ASURL(space);
		url.SetLinkCreateNewSpace(SearchSettingsAS.STR_MVC_CLASS_NAME, space);
		url.SetControl("EditorStart");
		url.AddControlArgument("editorType", "10");
		url.AddInnerHTMLString(space.GetString(1704, "ptmsgs_portalbrowsingmsgs"));
		return url;
	}
}

