package com.plumtree.portalpages.browsing.search.network;

import com.plumtree.openfoundation.util.*;

/**
 * This object will allow for the retrieval and setting of two objects that are used
 * when processing a network search. This object has primarily been defined to be used
 * when implementing a INetworkActions interface.
 * 
 * Created: April 27, 2003
 * @author Brian C. Harrison
 */
public class NetworkSearchArguments
{
	//Member String variable that will represent a Network Search String
	private String m_NETWORK_SEARCH_STRING = "";
	
	//Member XPList variable that will represent a list of Network Search Sources.
	private IXPList m_NETWORK_SEARCH_SOURCES = null;
	
	/**
	 * Retrieve the Network Search String that will be used for processing.
	 * 
	 * @return - String variable containing the Search parameter that can be returned 
	 * to the Network Search process.
	 */
	public String GetNetworkSearch()
	{
		return m_NETWORK_SEARCH_STRING;
	}
	
	/**
	 * Retrieve the Network Search sources that will be used for processing.
	 *  
	 * @return - XPList variable containing the list of Network Search Sources that can
	 * be returned to the Network Search process.
	 */
	public IXPList GetNetworkSources()
	{
		return m_NETWORK_SEARCH_SOURCES;
	}
	
	/**
	 * Set the Search String of the NetworkSearchArguments.
	 * 
	 * @param _strSearchString - String variable that will contain the value of the
	 * String used to perform a valid Network Search.
	 */
	public void SetNetworkSearch(String _strSearchString)
	{
		m_NETWORK_SEARCH_STRING = _strSearchString;
	}
	
	/**
	 * Set the XPList value for the NetworkSearchArguments object.
	 * 
	 * @param _xplSearchSources - XPList variable that will contain the list of valid
	 * Network Search sources that will be used when processing a valid Network Search.
	 */
	public void SetNetworkSources(IXPList _xplSearchSources)
	{
		m_NETWORK_SEARCH_SOURCES = _xplSearchSources;
	}
}
