 package com.plumtree.portalpages.browsing.search.network;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * @author JosephSi
 *
 */
public class NetworkSearchControl implements IControl
{
	
	public static final String STR_MVC_CLASS_NAME = "NetworkSearch";

	
	public static final String m_strHELLO_WORLD_DATA = "NetworkSearch";

	
	public static final String SOURCE_DATA		 = "in_cb_source";

    public static final String SOURCE_DATA_HIDDEN = "in_hi_source"; 

	
	public static final String SEARCHSTRING_DATA = "in_tx_query";

    public static final String SEARCHSTRING_DATA_HIDDEN = "in_hi_query";

	
	public static final String PAGENUM_DATA		 = "in_hi_pagenum";

	
	public static final String VIEWMODE_DATA     = "in_se_viewmode";

	
	public static final String RESULTS_DATA		 = "in_hi_results";

	
	public static final String VIEWMODE_COLLATED = "collated";

	
	public static final String VIEWMODE_PARALLEL = "parallel";
	
    public static final String SAVELOCATIONS_DATA="in_cb_savelocations";

	public static final String IN_SE_NUMRESULTS = "in_se_numresults";
	public static final String IN_HI_NUMRESULTS = "in_hi_numresults";
	
	private AActivitySpace m_asOwner;
	private INetworkSearchModel m_asmModel;

    
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String[] numResults = (String[]) arguments.GetElement(NetworkSearchControl.IN_SE_NUMRESULTS);
		if(numResults == null)
		{
			numResults = (String[]) arguments.GetElement(NetworkSearchControl.IN_HI_NUMRESULTS);
		}
		if(numResults != null)
		{
			m_asmModel.SetNumberResults(XPConvert.ToInteger(numResults[0]));
			((NetworkSearchModel)m_asmModel).SaveNumberResults();
		}
		String[] sourceValues = (String[]) arguments.GetElement(SOURCE_DATA);
		// source values could be specified via the checkbox 
		// from the launch page, or in a hidden way from the search
		// box on the results page. The ui forces us to use different
		// prefixes for checkbox and hidden inputs, so we have to 
		// check arguments for the hidden version as well
		if (sourceValues==null) {
		    sourceValues= (String[]) arguments.GetElement(SOURCE_DATA_HIDDEN);
		}

		XPArrayList sourceIDs = new XPArrayList();

		if (sourceValues != null)
		{
			for (int i = 0; i < sourceValues.length; i++)
			{
				sourceIDs.Add(new Integer(XPConvert.ToInteger(sourceValues[i])));
			}
		}

		String[] searchStringValues = (String[]) arguments.GetElement(SEARCHSTRING_DATA);
		if (searchStringValues==null) {
		    searchStringValues=(String[]) arguments.GetElement(SEARCHSTRING_DATA_HIDDEN);
		}

		String searchString		    = null;

		if (searchStringValues != null)
		{
		    if (searchStringValues[0].length() > 
			NetworkSearchModel.MAX_SEARCHSTRING_LENGTH) {
			searchString=
			    searchStringValues[0].substring(0,
							    NetworkSearchModel.MAX_SEARCHSTRING_LENGTH); 
			m_asmModel.SetSearchStringTruncated(true); 
		    }
		    else {
			searchString = searchStringValues[0];
			m_asmModel.SetSearchStringTruncated(false); 
		    }
			
		}

		// if not specified, then we assume it's the first page
		// of results
		int pageNum			   = 0;
		String[] pageNumValues = (String[]) arguments.GetElement(PAGENUM_DATA);

		if (pageNumValues != null)
		{
			//		    m_asmModel.SetPageNum(XPConvert.ToInteger(pageNumValues[0]));
			pageNum = XPConvert.ToInteger(pageNumValues[0]);
		}

		String[] viewModeValues = (String[]) arguments.GetElement(VIEWMODE_DATA);

		if (viewModeValues != null)
		{
			m_asmModel.SetViewMode(viewModeValues[0]);
		}

		// if the user checked "always check these locations", then
		// here's where we make sure that's saved as a preference
		String[] saveLocationsValues=(String[]) arguments.GetElement(SAVELOCATIONS_DATA);
		if (saveLocationsValues != null && sourceValues!=null) {
		    m_asmModel.SaveLocationPreferences(sourceValues);
		}

		// simple argument - if not null, then this is a request
		// for the results page. We don't want to infer a results page
		// from the setting of sourceValues and searchString because
		// in 508 mode we have to do server-side validation (i.e., 
		// in 508 we can't guarantee via javascript that these values 
		// will have been set when the user launches a search, so even 
		// if they're not, we pass along the request for results and
		// let the results page give the error message
		String[] resultsValues = (String[]) arguments.GetElement(RESULTS_DATA);

		if (resultsValues != null)
		{
		    m_asmModel.ClearSearchedSourceList();
		    // Prepare is where the actual searching is performed
		    m_asmModel.Prepare(searchString, sourceIDs, pageNum);

			// redirect to results page
			Redirect redirect = new Redirect();
			redirect.SetLinkGetCachedSpace(m_asOwner);

			if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
			{
				redirect.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
			}
			else
			{
				redirect.SetDisplayPage(NetworkSearchResultsDP_D.STR_MVC_CLASS_NAME);
			}

			// Moved from NetworkSearchResultsView_D.  This is still a funny place to make this check,
			// but it's a minimal change from the previous release.
			// If the search string or locations are blank, create the UIError here, not
			// in the View code.  This makes the error page display correctly.  The old code
			// created the UIError in the view, and then threw a generic XPException to forcibly
			// redirect the portal to an error page - and the resulting page had some problems
			// (incorrect help link, etc).
			INetworkSearchModelRO modelRO = (INetworkSearchModelRO) m_asmModel;

			if (modelRO.GetSearchString().length() == 0)
			{
				String msg = m_asOwner.GetString(1864,
				"ptmsgs_portalbrowsingmsgs");

				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, msg, msg);
				myError.SetImmediateClear(true);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}

			if (modelRO.GetSearchedSources().GetSize() == 0)
			{
				String msg = m_asOwner.GetString(1865, "ptmsgs_portalbrowsingmsgs");
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, msg, msg);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
				myError.SetImmediateClear(true);
			}

			return redirect;
		}
		else
		{
			return null;
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NetworkSearchControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asmModel     = (INetworkSearchModel) model;
		m_asOwner	   = space;
	}
}

