package com.plumtree.portalpages.browsing.search.network;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author JosephSi
 *
 */
public class NetworkSearchResultsView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.search.network.NetworkSearchResultsView");


	
//ptmsgs_portalbrowsingmsgs 1640 //  public static final String _ui_ErrorExecuting = "Error executing search on ";
	//strings for extraction


	
	public static final String SEPARATOR = "&nbsp;|&nbsp;&nbsp;&nbsp;";

	
	public static final String STR_MVC_CLASS_NAME = "NetworkSearchResults";
	private AActivitySpace m_asOwner;
	private INetworkSearchModelRO m_asmModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NetworkSearchResultsView();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		try
		{
			if ((null == m_asmModel.GetSearchString()) ||
			    (m_asmModel.GetSearchString().length() == 0) ||
			    (m_asmModel.GetSearchedSources().GetSize() == 0))
			{
				// Show nothing.  A UIError was generated in NetworkSearchControl and has
				// already been put on the page.
				return new HTMLGenericElement("");
			}

			// figure out whether we're displaying results collated
			// (i.e., alternating results from each source one by one)
			// or in parallel (results from each source grouped together).
			boolean inCollatedMode = false;

			if (m_asmModel.GetViewMode().equals(NetworkSearchControl.VIEWMODE_COLLATED))
			{
				inCollatedMode = true;
			}

			IXPList sources = (IXPList) (m_asmModel.GetSearchedSources());


			HTMLElementCollection result = new HTMLElementCollection();

			HTMLTable table = new HTMLTable();
			result.AddInnerHTMLElement(table);
			table.SetWidth("100%");
			table.SetCellSpacing("0");
			table.SetCellPadding("7");

			HTMLTableRow row = new HTMLTableRow();
			//One cell row.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG); 
			table.AddInnerHTMLElement(row);

			HTMLTableCell outerCell = new HTMLTableCell();
			row.AddInnerHTMLElement(outerCell);

			addSearchBox(outerCell,sources); 

			addSearchResultsBar(outerCell, m_asOwner.GetString(1543, "ptmsgs_portalbrowsingmsgs"));

			HTMLElement spacer = SearchUIUtility.makeSpacer(m_asOwner, "8");
			outerCell.AddInnerHTMLElement(spacer);
			
			addSummaryInfo(outerCell,sources); 

			//outerCell.AddInnerHTMLElement(makeSpacer("1"));
			HTMLForm form = createReorgForm(sources);
			outerCell.AddInnerHTMLElement(form);

			addSearchResultsBar(form, m_asOwner.GetString(1533, "ptmsgs_portalbrowsingmsgs"));
			addSearchResults(form, sources, inCollatedMode);


			return result;
		} catch (HTMLException e)
		{
			return new HTMLGenericElement(e.getMessage());
		}
	}       

	protected void addSearchResults(HTMLElement container, IXPList sources, boolean inCollatedMode)
	{       

		HTMLTable table = new HTMLTable();
		table.SetBorder("0");
		table.SetWidth("100%");
		table.SetCellSpacing("0");
		table.SetCellPadding("5");

		container.AddInnerHTMLElement(table);

		HTMLTableRow row;
		HTMLTableCell cell;

		// only add option to toggle between parallel and 
		// collated modes if there is more than one source
		if (sources.GetSize() > 1)
		{
			addTogglingParallelandCollated(table, sources, inCollatedMode);
		}

		if (m_asmModel.GetNumResultsOverall() == 0)
		{
			row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);

			HTMLSpan span1 = new HTMLSpan();
			span1.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);

			span1.AddInnerHTMLString(m_asOwner.GetString(807,
														 "ptmsgs_portalbrowsingmsgs"));
			cell.AddInnerHTMLElement(span1);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			HTMLTable resultsTable = makeSkeletonResultsTable();
			//not result? Matt
			container.AddInnerHTMLElement(resultsTable); 

			// if there was an error from a source, we need
			// to call showResultsInParallel in order for the error
			// message to be displayed
			if (!(m_asmModel.AreAllResultSetsValid()))
			{
				showResultsInParallel(sources,
						      // this flag doesn't
						      // matter here
						      false,
						      resultsTable);
			}
		} else
		{

			HTMLTable resultsTable=makeSkeletonResultsTable();

			container.AddInnerHTMLElement(resultsTable); 

			//find out if the user prefers docs to
			//be opened in a new window or in the 
			//same window. If the preference
			//PersonalSettingNames.OPEN_DOC_NEW_WINDOW is
			//a "1", then they want new windows
			boolean preferPopupDocs=false;
			Object[][] setting=
			    (Object[][]) ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().LookupPreference(PersonalSettingNames.OPEN_DOC_NEW_WINDOW, 0);
			if (null != setting) {
			    Object o = setting[1][0];
			    if (null !=o) {
				if (((String) o).equals("1")) {
				    preferPopupDocs=true;
				}
			    }
			}
		

			if (inCollatedMode)
			{
				addCollatedTopRow(resultsTable); 
				addHeaderRow(resultsTable,inCollatedMode);
				showCollatedResults(sources, preferPopupDocs,
						    resultsTable);
			} else
			{
				addHeaderRow(resultsTable,inCollatedMode);
				showResultsInParallel(sources, 
						      preferPopupDocs,
						      resultsTable);
			}
			// show more link, but only if there are more results
			// than what's on the page
			addMoreFromEachLink(resultsTable, sources, inCollatedMode);
                }
	}
	protected void addSearchResultsBar(HTMLElement container, String text)
	{
		HTMLTable table = new HTMLTable();
		container.AddInnerHTMLElement(table);
		table.SetBorder("0");
		table.SetWidth("100%");
		table.SetCellSpacing("0");
		table.SetCellPadding("5");

		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		cell.SetColSpan("1"); 
		row.AddInnerHTMLElement(cell);
		cell.SetHeight("25");
		cell.SetStyleClass(PTStyleClass.DIR_HEADER);
		cell.AddInnerHTMLString(text);
	}
	protected HTMLTable makeSkeletonResultsTable() {
		HTMLTable resultsTable=new HTMLTable();
		resultsTable.SetBorder("0");
		resultsTable.SetWidth("100%");
		resultsTable.SetCellSpacing("1");
		resultsTable.SetCellPadding("2");

		return resultsTable;
	}

	protected void addHeaderRow(HTMLTable resultsTable, boolean collated) {
		HTMLTableRow headerRow=new HTMLTableRow();
		headerRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG); 
		resultsTable.AddInnerHTMLElement(headerRow);

		HTMLTableCell cell=new HTMLTableCell();
		cell.SetHeight("25");
		cell.SetWidth("20");
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER); 
		headerRow.AddInnerHTMLElement(cell);
		HTMLB bold = new HTMLB();
		cell.AddInnerHTMLElement(bold);
		bold.AddInnerHTMLString(m_asOwner.GetString(1536, "ptmsgs_portalbrowsingmsgs"));

		cell=new HTMLTableCell();
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		cell.SetHeight("25");
		cell.SetColSpan("2");
		headerRow.AddInnerHTMLElement(cell);
		bold = new HTMLB();
		cell.AddInnerHTMLElement(bold);
		bold.AddInnerHTMLString(m_asOwner.GetString(1538, "ptmsgs_portalbrowsingmsgs")); 

		if (collated)
		{
			cell=new HTMLTableCell();
			cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
			cell.SetHeight("25");
			headerRow.AddInnerHTMLElement(cell);
			bold = new HTMLB();
			cell.AddInnerHTMLElement(bold);
			bold.AddInnerHTMLString(m_asOwner.GetString(1539, "ptmsgs_portalbrowsingmsgs"));
		}

	}

	protected HTMLForm createReorgForm(IXPList sources)
	{       
		HTMLForm form=new HTMLForm("netSearchReorg");
		form.SetName("netSearchReorg");
		form.SetID("netSearchReorg"); 

		HTMLInput controlInput=new HTMLInput(HTMLInputTypes.HIDDEN,
											 "in_hi_control",
											 "in_hi_control");
		form.AddInnerHTMLElement(controlInput);
		controlInput.SetValue(NetworkSearchControl.STR_MVC_CLASS_NAME);

		HTMLInput spaceInput=new HTMLInput(HTMLInputTypes.HIDDEN,"in_hi_space",
										   "in_hi_space");
		form.AddInnerHTMLElement(spaceInput); 
		spaceInput.SetValue(NetworkSearchAS.STR_MVC_CLASS_NAME);

		HTMLInput searchStringInput=
		new HTMLInput(HTMLInputTypes.HIDDEN,
					  NetworkSearchControl.SEARCHSTRING_DATA_HIDDEN,
					  NetworkSearchControl.SEARCHSTRING_DATA_HIDDEN);
		form.AddInnerHTMLElement(searchStringInput); 
		searchStringInput.SetValue(m_asmModel.GetUnencodedSearchString());

		HTMLInput searchFlagInput=
		new HTMLInput(HTMLInputTypes.HIDDEN,
					  NetworkSearchControl.RESULTS_DATA,
					  NetworkSearchControl.RESULTS_DATA);
		form.AddInnerHTMLElement(searchFlagInput);
		searchFlagInput.SetValue(XPConvert.ToString(true));

		for (int i = 0; i < sources.GetSize(); i++)
		{
			HTMLInput sourceInput=
			new HTMLInput(HTMLInputTypes.HIDDEN,
						  NetworkSearchControl.SOURCE_DATA_HIDDEN,
						  NetworkSearchControl.SOURCE_DATA_HIDDEN + 
						  XPConvert.ToString(i));
			form.AddInnerHTMLElement(sourceInput); 
			sourceInput.SetValue(XPConvert.ToString(sources.GetElement(i)));
		}

		return form;
	}

	protected void addSummaryInfo(HTMLTableCell outerCell, IXPList sources) 
	{
		HTMLTable table = new HTMLTable();
		table.SetBorder("0");
		table.SetWidth("100%");
		table.SetCellSpacing("0");
		table.SetCellPadding("0");
		outerCell.AddInnerHTMLElement(table);

		HTMLTableRow row=new HTMLTableRow();
		table.AddInnerHTMLElement(row);
		HTMLTableCell cell=new HTMLTableCell();
		cell.SetColSpan("3"); 
		row.AddInnerHTMLElement(cell);

		HTMLTable summaryTable=new HTMLTable();
		summaryTable.SetWidth("100%"); 
		cell.AddInnerHTMLElement(summaryTable);
		summaryTable.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

		HTMLTableRow searchStringRow=new HTMLTableRow();
		summaryTable.AddInnerHTMLElement(searchStringRow); 
		HTMLTableCell resultsForCell=new HTMLTableCell();
		searchStringRow.AddInnerHTMLElement(resultsForCell);

		HTMLSpan span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
		span.AddInnerHTMLString(m_asOwner.GetString(1534, "ptmsgs_portalbrowsingmsgs"));
		span.AddInnerHTMLString(":&nbsp;&nbsp;");

		resultsForCell.AddInnerHTMLElement(span);


		HTMLSpan span1 = new HTMLSpan();
		span1.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		span1.AddInnerHTMLString(m_asmModel.GetSearchString());

		HTMLTableCell searchStringCell=new HTMLTableCell();
		searchStringCell.AddInnerHTMLElement(span1);
		searchStringRow.AddInnerHTMLElement(searchStringCell);

		HTMLTableCell paddingCell=new HTMLTableCell();
		searchStringRow.AddInnerHTMLElement(paddingCell);
		paddingCell.SetWidth("50%"); 

		if (m_asmModel.GetSearchStringTruncated())
		{
			span1.AddInnerHTMLString(CommonHTMLStrings.SPACE); 
			span1.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1461, "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(NetworkSearchModel.MAX_SEARCHSTRING_LENGTH)));
		}


		for (int locIndex=0; locIndex < sources.GetSize(); 
			locIndex++)
		{
			HTMLTableRow locRow=new HTMLTableRow();
			summaryTable.AddInnerHTMLElement(locRow); 
			int sourceId = XPConvert.ToInteger(sources.GetElement(locIndex));
			HTMLTableCell leftTableCell=new HTMLTableCell();
			locRow.AddInnerHTMLElement(leftTableCell);
			if (locIndex==0)
			{
				span = new HTMLSpan();
				span.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
				span.AddInnerHTMLString(m_asOwner.GetString(1370, "ptmsgs_portalbrowsingmsgs"));
				leftTableCell.AddInnerHTMLElement(span);
			}
			HTMLTableCell rightTableCell=new HTMLTableCell();
			locRow.AddInnerHTMLElement(rightTableCell);

			span1 = new HTMLSpan();
			span1.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
			span1.AddInnerHTMLString(m_asmModel.GetSourceName(sourceId));
			rightTableCell.AddInnerHTMLElement(span1);

			paddingCell=new HTMLTableCell();
			locRow.AddInnerHTMLElement(paddingCell);
			paddingCell.SetWidth("50%");
		}

		// num results
		HTMLTableRow numResultsRow=new HTMLTableRow();
		summaryTable.AddInnerHTMLElement(numResultsRow); 
		HTMLTableCell leftCell=new HTMLTableCell();
		numResultsRow.AddInnerHTMLElement(leftCell);
		span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
		span.AddInnerHTMLString(m_asOwner.GetString(1535, "ptmsgs_portalbrowsingmsgs") + ":&nbsp;");
		leftCell.AddInnerHTMLElement(span);

		HTMLTableCell rightCell=new HTMLTableCell();
		numResultsRow.AddInnerHTMLElement(rightCell);
		span1 = new HTMLSpan();
		span1.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		span1.AddInnerHTMLString(XPConvert.ToString(m_asmModel.GetNumResultsOverall())); 
		rightCell.AddInnerHTMLElement(span1);

		paddingCell=new HTMLTableCell();
		numResultsRow.AddInnerHTMLElement(paddingCell);
		paddingCell.SetWidth("50%");

	}
	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 * Note: this javascript is not the same javascript as the one on the
	 * launch page, despite how it may look at first glance. The launch
	 * page checks to see that at least one location is checked. Here,
	 * the search box assumes you want the same locations, so that 
	 * validation is not performed
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		try
		{
			XPStringBuilder sb=new XPStringBuilder(""); 
			sb.Append("\n function DoSearch() {\n");

			sb.Append("   if (document.networksearch." +
					  NetworkSearchControl.SEARCHSTRING_DATA + ".value == '')\n");
			sb.Append("   {\n");
			sb.Append("      alert(\"Enter text to search for.\");\n");
			sb.Append("      return false;\n");
			sb.Append("   }\n");

			sb.Append("     return true;\n"); 
			sb.Append("}\n"); 

			sb.Append("function submitArrow() {\n");
			sb.Append("  var searchForm = document.networksearch;\n");
			sb.Append("  if(DoSearch()) searchForm.submit(); }\n");

			sb.Append("function submitROR() {\n");
			sb.Append("  var searchForm = document.netSearchReorg;\n");
			sb.Append("  searchForm.submit(); }\n");

			HTMLScript script = new HTMLScript("text/javaScript");
			script.AddInnerHTMLString(sb.ToString());

			return script;
		} catch (Exception e)
		{
			throw XPException.GetInstance(e);
		}

	}

	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asmModel     = (INetworkSearchModelRO) model;
		m_asOwner      = parent;
	}

	/**
	 * users can toggle between "parallel" presentation
	 * (results from each source are separated out) and "collated" view
	 * (results alternate). Here we add a pulldown option for each view
	 **/
	protected void AddOtherViewModeOption(HTMLSelect select, 
										  String viewMode,
										  String uiString, 
										  IXPList sources,
										  boolean selected)

	{
		HTMLOption option=new HTMLOption("");
		select.AddInnerHTMLElement(option); 
		option.SetValue(viewMode);
		option.AddInnerHTMLString(uiString);
		if (selected)
		{
			option.SetSelected(true); 
		}

	}

	/**
	 * 
	 *
	 * @param result 
	 * @param sources 
	 * @param inCollatedMode 
	 *
	 * @throws HTMLException 
	 */
	protected void addMoreFromEachLink(HTMLTable resultTable,
									   IXPList sources, 
									   boolean 
									   inCollatedMode)

	{
		ASURL moreFromEachURL = null;

		int numDisplayedSoFar = (m_asmModel.GetFirstDisplayedResultOverall() +
								 m_asmModel.GetNumDisplayedResultsOverall()) - 1;
		if (numDisplayedSoFar < m_asmModel.GetNumResultsOverall()) {
                moreFromEachURL = new ASURL(m_asOwner);
		moreFromEachURL.SetLinkGetCachedSpace(m_asOwner);
		moreFromEachURL.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
		moreFromEachURL.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
		moreFromEachURL.AddControlArgument(NetworkSearchControl.SEARCHSTRING_DATA,
										   m_asmModel.GetUnencodedSearchString());

		// we need this so the control knows we're requesting a results
		// page (this needs to be explicitly set in order to do server-side
		// validation in 508 mode).
		moreFromEachURL.AddControlArgument(NetworkSearchControl.RESULTS_DATA,
										   XPConvert.ToString(true));

		for (int i = 0; i < sources.GetSize(); i++)
		{
			moreFromEachURL.AddControlArgument(NetworkSearchControl.SOURCE_DATA,
											   XPConvert.ToInteger(sources.GetElement(i)));
		}

		String viewMode = NetworkSearchControl.VIEWMODE_PARALLEL;

		if (inCollatedMode)
		{
			viewMode = NetworkSearchControl.VIEWMODE_COLLATED;
		}

		moreFromEachURL.AddControlArgument(NetworkSearchControl.VIEWMODE_DATA,
										   viewMode);
		moreFromEachURL.AddControlArgument(NetworkSearchControl.PAGENUM_DATA,
										   XPConvert.ToString(m_asmModel.GetPageNum() + 1));


		if ((sources.GetSize() == 1) || inCollatedMode)
		{
			moreFromEachURL.AddInnerHTMLString(m_asOwner.GetString(803,
																   "ptmsgs_portalbrowsingmsgs"));
		} else
		{
			moreFromEachURL.AddInnerHTMLString(m_asOwner.GetString(804,
																   "ptmsgs_portalbrowsingmsgs"));
		}
                }

		ASURL previousPageURL = null;

		if (((sources.GetSize() == 1) || inCollatedMode) &&
                    (m_asmModel.GetPageNum() > 0)) {
                  previousPageURL = new ASURL(m_asOwner);
                  previousPageURL.SetLinkGetCachedSpace(m_asOwner);
                  previousPageURL.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
                  previousPageURL.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
                  previousPageURL.AddControlArgument(NetworkSearchControl.SEARCHSTRING_DATA,
                                                     m_asmModel.GetUnencodedSearchString());

                  // we need this so the control knows we're requesting a results
                  // page (this needs to be explicitly set in order to do server-side
                  // validation in 508 mode).
                  previousPageURL.AddControlArgument(NetworkSearchControl.RESULTS_DATA,
                                                     XPConvert.ToString(true));

                  for (int i = 0; i < sources.GetSize(); i++)
                  {
                    previousPageURL.AddControlArgument(NetworkSearchControl.SOURCE_DATA,
                                                       XPConvert.ToInteger(sources.GetElement(i)));
                  }

                  String viewMode = NetworkSearchControl.VIEWMODE_PARALLEL;

                  if (inCollatedMode)
                  {
                    viewMode = NetworkSearchControl.VIEWMODE_COLLATED;
                  }

                  previousPageURL.AddControlArgument(NetworkSearchControl.VIEWMODE_DATA, viewMode);
                  previousPageURL.AddControlArgument(NetworkSearchControl.PAGENUM_DATA,
                                                     XPConvert.ToString(m_asmModel.GetPageNum() - 1));
                  previousPageURL.AddInnerHTMLString(m_asOwner.GetString(1888,
                                                                         "ptmsgs_portalbrowsingmsgs"));
                }

		HTMLTableRow row=new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		resultTable.AddInnerHTMLElement(row);
		HTMLTableCell cell=new HTMLTableCell(); 
		cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		cell.SetAlign("right"); 

		if (inCollatedMode)
		{
			cell.SetColSpan("4");
		} else
		{
			cell.SetColSpan("3");
		}
		row.AddInnerHTMLElement(cell); 

                if (null != previousPageURL) {
                  cell.AddInnerHTMLElement(previousPageURL.GetURLAsHTMLElement());
                }
                if ((null != previousPageURL) && (null != moreFromEachURL)) {
                  cell.AddInnerHTMLString("&nbsp;&nbsp;|&nbsp;&nbsp");
                }
                if (null != moreFromEachURL) {
                  cell.AddInnerHTMLElement(moreFromEachURL.GetURLAsHTMLElement());
                }
	}

	/**
	* in parallel mode, user can click here and is then shown the results
	* only from this source
	**/
	protected void addMoreFromHereLink(HTMLTableCell cell, int sourceId)

	{

		ASURL moreFromHereURL = new ASURL(m_asOwner);
		moreFromHereURL.SetLinkGetCachedSpace(m_asOwner);
		moreFromHereURL.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
		moreFromHereURL.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
		moreFromHereURL.AddControlArgument(NetworkSearchControl.SEARCHSTRING_DATA,
										   m_asmModel.GetUnencodedSearchString());

		moreFromHereURL.AddControlArgument(NetworkSearchControl.SOURCE_DATA,
										   sourceId);

		// we need this so the control knows we're requesting a results
		// page (this needs to be explicitly set in order to do server-side
		// validation in 508 mode).
		moreFromHereURL.AddControlArgument(NetworkSearchControl.RESULTS_DATA,
										   XPConvert.ToString(true));

		String viewMode = NetworkSearchControl.VIEWMODE_PARALLEL;
		moreFromHereURL.AddControlArgument(NetworkSearchControl.VIEWMODE_DATA,
										   viewMode);

		// more from here link always brings the user back to the first page
		moreFromHereURL.AddControlArgument(NetworkSearchControl.PAGENUM_DATA, 0);

		moreFromHereURL.AddInnerHTMLString(m_asOwner.GetString(805,
															   "ptmsgs_portalbrowsingmsgs"));
		for (int i=0; i < 3; i++)
		{
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}
		cell.AddInnerHTMLElement(moreFromHereURL.GetURLAsHTMLElement());
	}


	protected void addSearchStringAndLocations(HTMLTableCell overallCell,
											   IXPList sources) {
		HTMLTable searchStringAndLocationsTable=new HTMLTable();
		overallCell.AddInnerHTMLElement(searchStringAndLocationsTable); 
		HTMLTableRow searchStringRow=new HTMLTableRow();
		searchStringAndLocationsTable.AddInnerHTMLElement(searchStringRow); 
		HTMLTableCell searchStringCell=new HTMLTableCell();
		searchStringRow.AddInnerHTMLElement(searchStringCell);
		searchStringCell.SetColSpan("2"); 
		//TODO Get rid of the <B>
		searchStringCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(798, "ptmsgs_portalbrowsingmsgs"),
																		   "<b>" + m_asmModel.GetSearchString() + "</b>"));

		if (m_asmModel.GetSearchStringTruncated())
		{
			searchStringCell.AddInnerHTMLString(CommonHTMLStrings.SPACE); 
			searchStringCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1461, "ptmsgs_portalbrowsingmsgs"),XPConvert.ToString(NetworkSearchModel.MAX_SEARCHSTRING_LENGTH)));
		}

		for (int locIndex=0; locIndex < sources.GetSize(); 
			locIndex++)
		{
			HTMLTableRow locRow=new HTMLTableRow();
			searchStringAndLocationsTable.AddInnerHTMLElement(locRow); 
			int sourceId = XPConvert.ToInteger(sources.GetElement(locIndex));
			HTMLTableCell leftCell=new HTMLTableCell();
			locRow.AddInnerHTMLElement(leftCell);
			if (locIndex==0)
			{
				leftCell.AddInnerHTMLString(m_asOwner.GetString(1370, "ptmsgs_portalbrowsingmsgs"));
			}
			HTMLTableCell rightCell=new HTMLTableCell();
			locRow.AddInnerHTMLElement(rightCell);
			HTMLB b = new HTMLB();
			rightCell.AddInnerHTMLElement(b);
			b.AddInnerHTMLString(m_asmModel.GetSourceName(sourceId));
		}
	}




	protected void addSearchBox(HTMLTableCell outerCell,
								IXPList sources) {
		HTMLForm form1 = new HTMLForm("networksearch");
		form1.SetMethod("post");
		form1.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(),
			m_asOwner.GetName(), m_asOwner.IsSubSpace()));
		form1.SetID("networksearch");
		form1.SetName("networksearch");
		outerCell.AddInnerHTMLElement(form1); 



		// outerCell.SetAlign("left");

		HTMLTable table=new HTMLTable(); 
		table.SetWidth("100%");
		table.SetCellPadding("5");
		table.SetCellSpacing("0");
		form1.AddInnerHTMLElement(table); 

		HTMLTableRow row=new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG); 
		table.AddInnerHTMLElement(row); 

		HTMLTableCell boxCell=new HTMLTableCell();
		boxCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER); 
		boxCell.SetHeight("25");
		boxCell.SetVAlign("middle");
		boxCell.SetNoWrap(true);
		row.AddInnerHTMLElement(boxCell); 

		//boxCell.AddInnerHTMLElement(form1); 
		boxCell.AddInnerHTMLString(m_asOwner.GetString(1531, "ptmsgs_portalbrowsingmsgs"));
		boxCell.AddInnerHTMLString(CommonHTMLStrings.SPACE); 


		// set the space and control 
		HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN,
										"in_hi_space", "in_hi_space_id");
		input.SetValue(NetworkSearchAS.STR_MVC_CLASS_NAME);
		boxCell.AddInnerHTMLElement(input);

		input = new HTMLInput(HTMLInputTypes.HIDDEN, "in_hi_control",
							  "in_hi_control_id");
		input.SetValue(NetworkSearchControl.STR_MVC_CLASS_NAME);
		boxCell.AddInnerHTMLElement(input);

		// just a simple input to make clear to the control
		// that this is a request for results
		input = new HTMLInput(HTMLInputTypes.HIDDEN,
							  NetworkSearchControl.RESULTS_DATA,
							  NetworkSearchControl.RESULTS_DATA);
		input.SetValue(XPConvert.ToString(true));

		boxCell.AddInnerHTMLElement(input);

		// keep the same number of results
		input = new HTMLInput(HTMLInputTypes.HIDDEN, NetworkSearchControl.IN_HI_NUMRESULTS, NetworkSearchControl.IN_HI_NUMRESULTS);
		input.SetValue(XPConvert.ToString(m_asmModel.GetNumberResults()));
		boxCell.AddInnerHTMLElement(input);

		for (int sourceIndex=0; sourceIndex < sources.GetSize(); sourceIndex++)
		{
			input = new HTMLInput(HTMLInputTypes.HIDDEN,
								  NetworkSearchControl.SOURCE_DATA_HIDDEN, "id" + sourceIndex);
			boxCell.AddInnerHTMLElement(input); 
			input.SetValue( XPConvert.ToString(sources.GetElement(sourceIndex)));
		}

		// search box itself
		input = new HTMLInput(HTMLInputTypes.TEXT,
							  NetworkSearchControl.SEARCHSTRING_DATA, "myID");
		// HTMLInput will encoded it for us 
		input.SetValue(m_asmModel.GetUnencodedSearchString()); 
		boxCell.AddInnerHTMLElement(input);   

		input.SetSize(31);
		input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		// input.SetOnKeyDown("handleKeyDownPTSWR(event);");


		// "Search" button

		HTMLAnchor searchButtonAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		searchButtonAnchor.SetOnClick("submitArrow(); return false;");
		searchButtonAnchor.SetPreComment(m_asOwner.GetString(293, "ptmsgs_portalinfrastructure"));

		PTConstruct searchButton = null;

		try
		{
			searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON,
														   true, this.m_asOwner);
		} catch (Exception e)
		{
		}

		if (null != searchButton)
		{
			HTMLImg searchButtonImg = (HTMLImg) searchButton.GetHTMLElement();
			searchButtonImg.SetAlt(m_asOwner.GetString(293, "ptmsgs_portalinfrastructure"));
      //			searchButtonImg.SetWidth("16");
      //			searchButtonImg.SetHeight("16");
			searchButtonAnchor.AddInnerHTMLElement(searchButtonImg);
		}

		HTMLTableCell cell2=new HTMLTableCell();

		//cell2.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER); 
		cell2.SetHeight("25");
		cell2.SetVAlign("middle");
		cell2.SetNoWrap(true);
		row.AddInnerHTMLElement(cell2); 
		cell2.AddInnerHTMLElement(searchButtonAnchor);

		HTMLTableCell returnCell=new HTMLTableCell();
		returnCell.SetHeight("25");
		returnCell.SetVAlign("middle");
		returnCell.SetNoWrap(true);
		returnCell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
		row.AddInnerHTMLElement(returnCell); 

		returnCell.AddInnerHTMLString(SEPARATOR); 

		ASURL url = new ASURL(m_asOwner);
		url.SetLinkCreateNewSpace(NetworkSearchAS.STR_MVC_CLASS_NAME,
								  m_asOwner);
		url.SetControl(com.plumtree.uiinfrastructure.editor.EditorStartControl.STR_MVC_CLASS_NAME);
		url.AddControlArgument(com.plumtree.uiinfrastructure.editor.EditorStartControl.QS_EDITOR_TYPE,
							   com.plumtree.uiinfrastructure.editor.EditorStartControl.EDITOR_START_FLAG_MISC);

		HTMLAnchor returnAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

		returnAnchor.SetHRef(url.GetURLAsString());
		returnAnchor.SetPreComment("Back To Search");
		returnAnchor.AddInnerHTMLString(m_asOwner.GetString(1532, "ptmsgs_portalbrowsingmsgs"));
		returnCell.AddInnerHTMLElement(returnAnchor);

		cell2 = new HTMLTableCell();
		cell2.SetVAlign("middle");
		cell2.SetWidth("100%");
		cell2.SetColSpan("1");
		cell2.AddInnerHTMLString("&nbsp;");
		row.AddInnerHTMLElement(cell2);
	}

	/**
	 *
	 * @param result The HTMLElementCollection that generates the 
	 * overall page
	 * @param sources Integer list of fed portals being searched
	 * @param inCollatedMode If true, results are intermingled. Otherwise,
	 * they are kept in separate groups.
	 *
	 * @throws HTMLException 
	 */
	protected void addTogglingParallelandCollated(
												 HTMLTable table, IXPList sources, boolean inCollatedMode)

	{
		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG); 
		table.AddInnerHTMLElement(row);

		//<td valign="middle" height="17" nowrap="nowrap" colspan="1" class="actionbarText"> 
		HTMLTableCell cell= new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.SetVAlign("middle");
		cell.SetHeight("17");
		cell.SetNoWrap(true);
		cell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
		cell.SetColSpan("1"); 

		HTMLSpan span1 = new HTMLSpan();
		span1.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
		span1.AddInnerHTMLString(m_asOwner.GetString(1541, "ptmsgs_portalbrowsingmsgs") + ":&nbsp;"); 
		cell.AddInnerHTMLElement(span1);

		cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
		cell.SetColSpan("1"); 

		HTMLSelect select = new HTMLSelect(NetworkSearchControl.VIEWMODE_DATA, "");
		cell.AddInnerHTMLElement(select); 
		select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
		select.SetOnChange("submitROR();"); 

		AddOtherViewModeOption(select, 
							   NetworkSearchControl.VIEWMODE_PARALLEL,

							   m_asOwner.GetString(1539, "ptmsgs_portalbrowsingmsgs"),
							   sources,
							   !inCollatedMode);

		AddOtherViewModeOption(select, 
							   NetworkSearchControl.VIEWMODE_COLLATED,

							   m_asOwner.GetString(1540, "ptmsgs_portalbrowsingmsgs"),
							   sources,
							   inCollatedMode);

	}

	protected void addCollatedTopRow(HTMLTable table) {

		// first add one row indicating that these are collated and giving
		// the number of results overall and the displayed range
		int firstDisplayedResult = m_asmModel.GetFirstDisplayedResultOverall();
		int lastDisplayedResult  = (firstDisplayedResult +
									m_asmModel.GetNumDisplayedResultsOverall()) - 1;
		int numOverallResults = m_asmModel.GetNumResultsOverall();

		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.LIST_SUBHEAD);
		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		cell.SetColSpan("3"); 
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		row.AddInnerHTMLElement(cell);
		cell.SetHeight("23");

		cell.AddInnerHTMLString(XPResourceManager.FormatMessage(
															   m_asOwner.GetString(810, "ptmsgs_portalbrowsingmsgs"),
															   XPConvert.ToString(firstDisplayedResult),
															   XPConvert.ToString(lastDisplayedResult),
															   XPConvert.ToString(numOverallResults)));

		// + " &nbsp;&nbsp;&nbsp;" + firstDisplayedResult + " &nbsp; - &nbsp; " + lastDisplayedResult + " " + _ui_of + " " +  numOverallResults + sixSpaces); 

	}


	/**
	 * present the results interleaved (e.g., if there are three sources,
	 * then we show first result from source 1, first result from source 2,
	 * first result from source 3, second result from source 1, second
	 * result from source 2, and so on.
	 **/
	protected void showCollatedResults(IXPList sources, 
					   boolean popup,
					   HTMLTable table)

	{
		int firstDisplayedResult = m_asmModel.GetFirstDisplayedResultOverall();

		boolean resultsRemaining = true;

		int numSearchedSources           = sources.GetSize();
		int overallResultCount           = 0;
		int[] numDisplayedSoFarForSource = new int[numSearchedSources];

		for (int i = 0; i < numSearchedSources; i++)
		{
			numDisplayedSoFarForSource[i] = 0;
		}

		while (resultsRemaining)
		{
			boolean nothingLeft = true;

			for (int sourceIndex = 0; sourceIndex < numSearchedSources;
				sourceIndex++)
			{
				int sourceId = XPConvert.ToInteger(sources.GetElement(sourceIndex));

				if (numDisplayedSoFarForSource[sourceIndex] < m_asmModel.GetNumDisplayedResultsFromSource(
																										 sourceId))
				{
					showResult(table, sourceId,
							   numDisplayedSoFarForSource[sourceIndex],
							   overallResultCount, 
							   firstDisplayedResult,
							   true,
						   popup);

					numDisplayedSoFarForSource[sourceIndex]++;
					overallResultCount++;

					if (numDisplayedSoFarForSource[sourceIndex] < m_asmModel.GetNumDisplayedResultsFromSource(
																											 sourceId))
					{
						nothingLeft = false;
					}
				}
			}

			resultsRemaining = !nothingLeft;
		}
	}

	/**
	 * 
	 *
	 * @param table 
	 * @param sourceId 
	 * @param withinSourceResultNum 
	 * @param overallResultNum 
	 * @param collated 
	 *
	 * @throws HTMLException 
	 */
	protected void showResult(HTMLTable table, int sourceId,
							  int withinSourceResultNum, 
							  int overallResultNum, 
							  int startIndex,
							  boolean collated,
				  boolean popup)

	{
		// row for title of result
		HTMLTableRow row = new HTMLTableRow();

		if ((overallResultNum % 2) == 0)
		{
			row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
		} else
		{
			row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
		}

		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		cell.SetAlign("center");
		cell.SetVAlign("top");
		cell.SetWidth("1%");
		cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		int rank=0;
		if (collated)
		{
			rank=startIndex + overallResultNum;
		} else
		{
			rank=startIndex + withinSourceResultNum;
		}

		row.AddInnerHTMLElement(cell); 
		cell.AddInnerHTMLString(XPConvert.ToString(rank));

		cell = new HTMLTableCell();
		cell.SetAlign("center");
		cell.SetVAlign("top");
		cell.SetWidth("1%");
		row.AddInnerHTMLElement(cell);

		HTMLImg resultGif = m_asmModel.GetImageForResultFromSource(sourceId,
																   withinSourceResultNum);

		if (resultGif == null)
		{
			resultGif = new HTMLImg(null, "");
		}

		cell.AddInnerHTMLElement(resultGif);
		cell.AddInnerHTMLString("&nbsp;&nbsp;");

		cell=new HTMLTableCell();
		cell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
		cell.SetVAlign("top");
		row.AddInnerHTMLElement(cell); 
		HTMLAnchor clickThruLink = null;
		try
		{
			clickThruLink =
				m_asmModel.GetURLForResultFromSource(sourceId, withinSourceResultNum, popup);
		}
		catch(Exception e)
		{
			XPException exp = new XPException(e);
			String msg = exp.GetMessage();
			HTMLSpan span1 = new HTMLSpan();
			span1.SetStyle("color=red");
			span1.SetStyleClass(PTStyleClass.ALERT_ERROR_DESCRIPTION);
			span1.AddInnerHTMLString(msg + " ");
			cell.AddInnerHTMLElement(span1);
		}

		String resultTitle=
		m_asmModel.GetTitleForResultFromSource(sourceId,
											   withinSourceResultNum); 

		// if we didn't get a url back, then don't make a link
		if (clickThruLink == null)
		{
			cell.AddInnerHTMLString(resultTitle);
		}
		else
		{
			clickThruLink.AddInnerHTMLString(resultTitle); 
			cell.AddInnerHTMLElement(clickThruLink);
		}

		String descriptionOrBlank=m_asmModel.GetDescriptionForResultFromSource(sourceId,withinSourceResultNum); 
		if (descriptionOrBlank==null)
		{
			descriptionOrBlank="";
		}
		cell.AddInnerHTMLElement(new HTMLBr());
		HTMLSpan span = new HTMLSpan();
		span.SetStyleClass(PTStyleClass.LIST_TEXT);
		span.AddInnerHTMLString(descriptionOrBlank);
		cell.AddInnerHTMLElement(span);

		if (collated)
		{
			cell = new HTMLTableCell();  
			cell.SetVAlign("top");   
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			row.AddInnerHTMLElement(cell);
			cell.AddInnerHTMLString(m_asmModel.GetSourceName(sourceId));

		}


		if (collated)
		{
			cell=new HTMLTableCell();  
			cell.SetVAlign("top"); 
			row.AddInnerHTMLElement(cell);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		}


	}
 
	/**
	 * 
	 *
	 * @param sources 
	 * @param table 
	 *
	 * @throws HTMLException 
	 */
	protected void showResultsInParallel(IXPList sources, 
					     boolean popup,
					     HTMLTable table)

	{
		for (int i = 0; i < sources.GetSize(); i++)
		{
			int sourceId = XPConvert.ToInteger(sources.GetElement(i));

			if (!(m_asmModel.isResultSetValid(sourceId)))
			{

				if (m_asmModel.GetPageNum() == 0)
				{
					HTMLTableRow row = new HTMLTableRow();
					row.SetStyleClass(PTStyleClass.LIST_SUBHEAD);
					table.AddInnerHTMLElement(row);

					HTMLTableCell cell = new HTMLTableCell();
					cell.SetColSpan("3"); 
					cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
					row.AddInnerHTMLElement(cell);
					HTMLElement errorLink=m_asmModel.GetErrorLinkFromSource(sourceId);
					if (errorLink != null)
					{
						cell.AddInnerHTMLElement(errorLink);
					} else
					{
						String msg = m_asmModel.GetFormattedError(sourceId);
						cell.AddInnerHTMLString(msg);
						log.Error("Fed search error: " + msg);


					}
				}
			} else
			{
				int numDisplayedResults = m_asmModel.GetNumDisplayedResultsFromSource(sourceId);
				int numTotalResults = m_asmModel.GetNumResultsFromSource(sourceId);

				int firstDisplayedResult = m_asmModel.GetFirstDisplayedResultFromSource(sourceId);

				int lastDisplayedResult = (firstDisplayedResult +
										   numDisplayedResults) - 1;

				if (numDisplayedResults > 0)
				{
					HTMLTableRow row = new HTMLTableRow();
					row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
					table.AddInnerHTMLElement(row);

					HTMLTableCell cell = new HTMLTableCell();
					cell.SetColSpan("3"); 
					cell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
					row.AddInnerHTMLElement(cell);
					cell.SetHeight("23");

					cell.AddInnerHTMLString(XPResourceManager.FormatMessage(
																		   m_asOwner.GetString(809, "ptmsgs_portalbrowsingmsgs"),
																		   m_asmModel.GetSourceName(sourceId),
																		   XPConvert.ToString(firstDisplayedResult),
																		   XPConvert.ToString(lastDisplayedResult),
																		   XPConvert.ToString(numTotalResults)));

					int numDisplayedSoFar = (m_asmModel.GetFirstDisplayedResultFromSource(sourceId) +
											 m_asmModel.GetNumDisplayedResultsFromSource(sourceId)) -
											1;

					if ((sources.GetSize() > 1) &&
						(numDisplayedSoFar < m_asmModel.GetNumResultsFromSource(
																			   sourceId)))
					{
						addMoreFromHereLink(cell, sourceId);
					}

					for (int j = 0; j < numDisplayedResults; j++)
					{
						showResult(table, sourceId, j, j,firstDisplayedResult, false,popup);
					}
				}
			}
		}
	}
}

