package com.plumtree.portalpages.browsing.search.network;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author JosephSi
 *
 */
public class NetworkSearchResultsView_D implements IView
{	
	public static final String STR_MVC_CLASS_NAME = "NetworkSearchResults_D";
	private AActivitySpace m_asOwner;
	private INetworkSearchModelRO m_asmModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NetworkSearchResultsView_D();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		try
		{
			if ((null == m_asmModel.GetSearchString()) ||
			    (m_asmModel.GetSearchString().length() == 0) ||
			    (m_asmModel.GetSearchedSources().GetSize() == 0))
			{
				// Show nothing.  A UIError was generated in NetworkSearchControl and has
				// already been put on the page.
				return new HTMLGenericElement("");
			}

			// figure out whether we're displaying results collated
			// (i.e., alternating results from each source one by one)
			// or in parallel (results from each source grouped together).
			boolean inCollatedMode = false;

			if (m_asmModel.GetViewMode().equals(NetworkSearchControl.VIEWMODE_COLLATED))
			{
				inCollatedMode = true;
			}

			IXPList sources = (IXPList) (m_asmModel.GetSearchedSources());

			HTMLElementCollection result = new HTMLElementCollection();

			HTMLTable table = new HTMLTable();
			result.AddInnerHTMLElement(table);
			table.SetWidth("100%");
			table.SetCellSpacing("0");

			HTMLTableRow row = new HTMLTableRow();
			table.AddInnerHTMLElement(row);

			HTMLTableCell cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetAlign("left");
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);

			addSearchStringAndLocations(cell,sources);
		 			    
			cell = new HTMLTableCell();
			addSearchBox(cell,sources); 
			row.AddInnerHTMLElement(cell);
		

			// this is surely not the right way to center a block of html-
			// fix this later	
			
			//addSearchBox(result,sources); 

			//result.AddInnerHTMLString("<center>");


		
			// only add option to toggle between parallel and 
			// collated modes if there is more than one source
			result.AddInnerHTMLElement(new HTMLBr()); 
			if (sources.GetSize() > 1)
			{
				addTogglingParallelandCollated(result, sources, inCollatedMode);
			}

			//result.AddInnerHTMLString("</center>");

			int numDisplayedSoFar = (m_asmModel.GetFirstDisplayedResultOverall() +
				m_asmModel.GetNumDisplayedResultsOverall()) - 1;


			addReturnToLaunchAndMoreFromEachLink(result, 
							     sources, 
							     inCollatedMode,
							     numDisplayedSoFar);

 
			// results table 
			table = new HTMLTable();
			result.AddInnerHTMLElement(table);
			table.SetBorder("0");
			table.SetWidth("100%");
			table.SetCellSpacing("0");
			table.SetCellPadding("2");

			row = new HTMLTableRow();
			row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
			table.AddInnerHTMLElement(row);
			cell = new HTMLTableCell();
                        cell.SetStyleClass(PTStyleClass.DIR_HEADER);
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			cell = new HTMLTableCell();
                        cell.SetStyleClass(PTStyleClass.DIR_HEADER);
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("23");

			cell.AddInnerHTMLString(m_asOwner.GetString(806,
					"ptmsgs_portalbrowsingmsgs"));
			cell = new HTMLTableCell();
                        cell.SetStyleClass(PTStyleClass.DIR_HEADER);
			row.AddInnerHTMLElement(cell);
			cell.SetWidth("10");
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

			if (m_asmModel.GetNumResultsOverall() == 0)
			{
				row = new HTMLTableRow();
                                row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
				table.AddInnerHTMLElement(row);

				cell = new HTMLTableCell();
                                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
				row.AddInnerHTMLElement(cell);
				cell.SetWidth("10");
				cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

				cell = new HTMLTableCell();
                                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
				row.AddInnerHTMLElement(cell);

				cell.AddInnerHTMLString(m_asOwner.GetString(807,
						"ptmsgs_portalbrowsingmsgs"));

				cell = new HTMLTableCell();
                                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
				row.AddInnerHTMLElement(cell);
				cell.SetWidth("10");
				cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

				// if there was an error from a source, we need
				// to call showResultsInParallel in order for the error
				// message to be displayed
				if (!(m_asmModel.AreAllResultSetsValid()))
				{
					showResultsInParallel(sources, table);
				}
			}
			else
			{
				if (inCollatedMode)
				{
					showCollatedResults(sources, table);
				}
				else
				{
					showResultsInParallel(sources, table);
				}
			}

			// I am not quite enough of a javascript guru to understand
			// why this script tag is needed with the body, but it 
			// seems that it is. I've copied this from the 4.5ws 
			// network search page, and verified that it's necessary
			// (in addition to the IsCR() function and the keydown=IsCR
			// attribute of the search box) in order for client-side
			// validation to occur when the user hits return in addition
			// to when they press the "Search" button
			// TODO - bug 19255: move all scripts into DisplayJavascript
			// TODO - bug 19255: use HTMLScript element, writing out tags is not permitted
			/*if (m_asOwner.GetAccessStyle() != AccessStyles.SECTION_508)
				result.AddInnerHTMLString(
					"<script>document.networksearch.in_tx_query.onkeydown = IsCR;</script>");
*/
			return result;
		}
		catch (HTMLException e)
		{
			return new HTMLGenericElement(e.getMessage());
		}
	}

	/*
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
          return null;
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asmModel     = (INetworkSearchModelRO) model;
		m_asOwner	   = parent;
		
		parent.SetHelpTopic( "PT_FederatedSearchResults" );
	}

	/**
	 * users can toggle between "parallel" presentation
	 * (results from each source are separated out) and "collated" view
	 * (results alternate). Here we add a link that displays whichever
	 * view is not currently being shown
	 **/
	protected void AddOtherViewModeLink(HTMLTableCell cell, String viewMode,
		String uiString, IXPList sources)

	{
		ASURL otherViewResultsURL = new ASURL(m_asOwner);
		otherViewResultsURL.SetLinkGetCachedSpace(m_asOwner);
		otherViewResultsURL.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
		otherViewResultsURL.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
		otherViewResultsURL.AddControlArgument(NetworkSearchControl.SEARCHSTRING_DATA,
			m_asmModel.GetUnencodedSearchString());

		for (int i = 0; i < sources.GetSize(); i++)
		{
			otherViewResultsURL.AddControlArgument(NetworkSearchControl.SOURCE_DATA,
				(XPConvert.ToInteger(sources.GetElement(i))));
		}

		otherViewResultsURL.AddControlArgument(NetworkSearchControl.VIEWMODE_DATA,
			viewMode);

		otherViewResultsURL.AddInnerHTMLString(uiString);

		HTMLElement urlAsElement = otherViewResultsURL.GetURLAsHTMLElement();
		cell.AddInnerHTMLElement(urlAsElement);
	}

	/**
	 * 
	 *
	 * @param result 
	 * @param sources 
	 * @param inCollatedMode 
	 *
	 * @throws HTMLException 
	 */
	protected void addReturnToLaunchAndMoreFromEachLink(HTMLElementCollection result,
							    IXPList sources, 
							    boolean 
							    inCollatedMode,
							    int numDisplayedSoFar)

	{
		// "more from each" link
		HTMLTable table = new HTMLTable();
		result.AddInnerHTMLElement(table);
		table.SetWidth("100%");
		table.SetCellSpacing("10");

		HTMLTableRow row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);
                row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		cell.SetWidth("10");
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		cell = new HTMLTableCell();
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	
		// link to go back to launch page
		ASURL netsearchlaunchurl = new ASURL(m_asOwner);
		netsearchlaunchurl.SetLinkCreateNewSpace("NetworkSearch", m_asOwner);
		netsearchlaunchurl.AddInnerHTMLString(m_asOwner.GetString(1372, "ptmsgs_portalbrowsingmsgs"));
		netsearchlaunchurl.SetControl("NetworkSearch");

		cell.SetAlign("left"); 
		cell.AddInnerHTMLElement(netsearchlaunchurl.GetURLAsHTMLElement());
		row.AddInnerHTMLElement(cell);
		cell.SetAlign("left");


		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		cell.SetAlign("right");

		if (numDisplayedSoFar < m_asmModel.GetNumResultsOverall())
		    {
			ASURL moreFromEachURL = new ASURL(m_asOwner);
			moreFromEachURL.SetLinkGetCachedSpace(m_asOwner);
			moreFromEachURL.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
			moreFromEachURL.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
			moreFromEachURL.AddControlArgument(NetworkSearchControl.SEARCHSTRING_DATA,
							   m_asmModel.GetUnencodedSearchString());
			
			// we need this so the control knows we're requesting a results
			// page (this needs to be explicitly set in order to do server-side
			// validation in 508 mode).
			moreFromEachURL.AddControlArgument(NetworkSearchControl.RESULTS_DATA,
							   XPConvert.ToString(true));
			
			for (int i = 0; i < sources.GetSize(); i++)
			    {
				moreFromEachURL.AddControlArgument(NetworkSearchControl.SOURCE_DATA,
								   (XPConvert.ToInteger(sources.GetElement(i))));
			    }
			
			String viewMode = NetworkSearchControl.VIEWMODE_PARALLEL;
			
			if (inCollatedMode)
			    {
				viewMode = NetworkSearchControl.VIEWMODE_COLLATED;
			    }
			
			moreFromEachURL.AddControlArgument(NetworkSearchControl.VIEWMODE_DATA,
							   viewMode);
			moreFromEachURL.AddControlArgument(NetworkSearchControl.PAGENUM_DATA,
							   XPConvert.ToString(m_asmModel.GetPageNum() + 1));
			
			// show more link, but only if there are more results
			// than what's on the page
			if ((sources.GetSize() == 1) || inCollatedMode)
			    {
				moreFromEachURL.AddInnerHTMLString(m_asOwner.GetString(803,
										       "ptmsgs_portalbrowsingmsgs"));
			    }
			else
			    {
				moreFromEachURL.AddInnerHTMLString(m_asOwner.GetString(804,
										       "ptmsgs_portalbrowsingmsgs"));
			    }
			
			cell.AddInnerHTMLElement(moreFromEachURL.GetURLAsHTMLElement());
		    }
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		cell.SetWidth("10");
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}

	/**
	* in parallel mode, user can click here and is then shown the results
	* only from this source
	**/
	protected void addMoreFromHereLink(HTMLTableRow row, int sourceId)

	{
		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);

		ASURL moreFromHereURL = new ASURL(m_asOwner);
		moreFromHereURL.SetLinkGetCachedSpace(m_asOwner);
		moreFromHereURL.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);
		moreFromHereURL.SetDisplayPage(NetworkSearchResultsDP.STR_MVC_CLASS_NAME);
		moreFromHereURL.AddControlArgument(NetworkSearchControl.SEARCHSTRING_DATA,
			m_asmModel.GetUnencodedSearchString());

		moreFromHereURL.AddControlArgument(NetworkSearchControl.SOURCE_DATA,
			sourceId);

		// we need this so the control knows we're requesting a results
		// page (this needs to be explicitly set in order to do server-side
		// validation in 508 mode).
		moreFromHereURL.AddControlArgument(NetworkSearchControl.RESULTS_DATA,
			XPConvert.ToString(true));

		String viewMode = NetworkSearchControl.VIEWMODE_PARALLEL;
		moreFromHereURL.AddControlArgument(NetworkSearchControl.VIEWMODE_DATA,
			viewMode);

		// more from here link always brings the user back to the first page
		moreFromHereURL.AddControlArgument(NetworkSearchControl.PAGENUM_DATA, 0);

		moreFromHereURL.AddInnerHTMLString(m_asOwner.GetString(805,
				"ptmsgs_portalbrowsingmsgs"));

		cell.AddInnerHTMLElement(moreFromHereURL.GetURLAsHTMLElement());
	}

  
    protected void addSearchStringAndLocations(HTMLTableCell overallCell,
					       IXPList sources) {
	HTMLTable searchStringAndLocationsTable=new HTMLTable();
	overallCell.AddInnerHTMLElement(searchStringAndLocationsTable); 
	HTMLTableRow searchStringRow=new HTMLTableRow();
	searchStringAndLocationsTable.AddInnerHTMLElement(searchStringRow); 
	HTMLTableCell searchStringCell=new HTMLTableCell();
	searchStringRow.AddInnerHTMLElement(searchStringCell);
        searchStringRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
        searchStringCell.SetStyleClass(PTStyleClass.LIST_TEXT);
	searchStringCell.SetColSpan("2"); 
	searchStringCell.AddInnerHTMLString(XPResourceManager.FormatMessage(
									    m_asOwner.GetString(798, "ptmsgs_portalbrowsingmsgs"),
									    "<b>" + m_asmModel.GetSearchString() + "</b>"));
	

	if (m_asmModel.GetSearchStringTruncated()) {
	    searchStringCell.AddInnerHTMLString(CommonHTMLStrings.SPACE); 
	    searchStringCell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1462, "ptmsgs_portalbrowsingmsgs"),XPConvert.ToString(NetworkSearchModel.MAX_SEARCHSTRING_LENGTH)));
	}

	for (int locIndex=0; locIndex < sources.GetSize(); 
	     locIndex++) {
	    HTMLTableRow locRow=new HTMLTableRow();
	    searchStringAndLocationsTable.AddInnerHTMLElement(locRow); 
		int sourceId = XPConvert.ToInteger(sources.GetElement(locIndex));
	    HTMLTableCell leftCell=new HTMLTableCell();
	    locRow.AddInnerHTMLElement(leftCell);
            locRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
            leftCell.SetStyleClass(PTStyleClass.LIST_TEXT);
	    if (locIndex==0) {
		leftCell.AddInnerHTMLString(m_asOwner.GetString(1373, "ptmsgs_portalbrowsingmsgs"));
	    }
	    HTMLTableCell rightCell=new HTMLTableCell();
	    locRow.AddInnerHTMLElement(rightCell);
	    rightCell.AddInnerHTMLString("<b>" + m_asmModel.GetSourceName(sourceId) + "</b>");
            rightCell.SetStyleClass(PTStyleClass.LIST_TEXT);
	}
    }
    
    protected void addSearchBox(HTMLTableCell overallCell,
				IXPList sources) {

	HTMLTable table= new HTMLTable();
	overallCell.AddInnerHTMLElement(table); 
	HTMLTableRow row=new HTMLTableRow();
	table.AddInnerHTMLElement(row); 
	HTMLTableCell cell= new HTMLTableCell();
        row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
        cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	cell.SetAlign("left");
	cell.AddInnerHTMLString(m_asOwner.GetString(1371, "ptmsgs_portalbrowsingmsgs")); 
	row.AddInnerHTMLElement(cell); 
       
	row = new HTMLTableRow();
	table.AddInnerHTMLElement(row); 
	cell=new HTMLTableCell(); 
	row.AddInnerHTMLElement(cell); 
        row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
        cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	HTMLForm form1 = new HTMLForm("networksearch");
	cell.AddInnerHTMLElement(form1); 

	form1.SetMethod("post");
	form1.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(), 
		m_asOwner.GetName(), m_asOwner.IsSubSpace()));
	form1.SetID("networksearch");
	form1.SetName("networksearch");

	// set the space and control 
	HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN,
					"in_hi_space", "in_hi_space_id");
	input.SetValue(NetworkSearchAS.STR_MVC_CLASS_NAME);
	form1.AddInnerHTMLElement(input);

	input = new HTMLInput(HTMLInputTypes.HIDDEN, "in_hi_control",
			      "in_hi_control_id");
	input.SetValue(NetworkSearchControl.STR_MVC_CLASS_NAME);
	form1.AddInnerHTMLElement(input);

	// just a simple input to make clear to the control
	// that this is a request for results
	input = new HTMLInput(HTMLInputTypes.HIDDEN,
			      NetworkSearchControl.RESULTS_DATA,
			      NetworkSearchControl.RESULTS_DATA);
	input.SetValue(XPConvert.ToString(true));
	form1.AddInnerHTMLElement(input);
	
	// keep the same number of results
	input = new HTMLInput(HTMLInputTypes.HIDDEN, NetworkSearchControl.IN_HI_NUMRESULTS, NetworkSearchControl.IN_HI_NUMRESULTS);
	input.SetValue(XPConvert.ToString(m_asmModel.GetNumberResults()));
	form1.AddInnerHTMLElement(input);
	
	for (int sourceIndex=0; sourceIndex < sources.GetSize(); sourceIndex++) {
	    input = new HTMLInput(HTMLInputTypes.HIDDEN,
				  NetworkSearchControl.SOURCE_DATA_HIDDEN, "id" + sourceIndex);
	    form1.AddInnerHTMLElement(input); 
	    input.SetValue(XPConvert.ToString(sources.GetElement(sourceIndex)));
	}

	// search box itself
	input = new HTMLInput(HTMLInputTypes.TEXT,
			      NetworkSearchControl.SEARCHSTRING_DATA, "myID");
	//HTMLInput will encode the search string for us
	input.SetValue(m_asmModel.GetUnencodedSearchString()); 
        input.SetTitle(m_asOwner.GetString(1371, "ptmsgs_portalbrowsingmsgs"));
        input.SetAlt(m_asOwner.GetString(1371, "ptmsgs_portalbrowsingmsgs"));
	form1.AddInnerHTMLElement(input); 	
	input.SetSize(31);
	 
	
		input = new HTMLInput(HTMLInputTypes.SUBMIT, "in_su_b1", "in_su_b1");
		form1.AddInnerHTMLElement(input); 
		input.SetValue(m_asOwner.GetString(788, "ptmsgs_portalbrowsingmsgs"));	
		input.SetTitle(m_asOwner.GetString(788, "ptmsgs_portalbrowsingmsgs"));	
		input.SetAlt(m_asOwner.GetString(43, "ptmsgs_portal508quickkeymsgs"));	
		input.SetAccessKey(m_asOwner.GetString(45, "ptmsgs_portal508quickkeymsgs"));	
	}
	/**
	 *
	 * @param result The HTMLElementCollection that generates the 
	 * overall page
	 * @param sources Integer list of fed portals being searched
	 * @param inCollatedMode If true, results are intermingled. Otherwise,
	 * they are kept in separate groups.
	 *
	 * @throws HTMLException 
	 */
	protected void addTogglingParallelandCollated(
		HTMLElementCollection result, IXPList sources, boolean inCollatedMode)

	{
		HTMLTable table = new HTMLTable();
		result.AddInnerHTMLElement(table);
		table.SetWidth("40%");
		table.SetCellSpacing("5");
		table.SetBorder("0");

		HTMLTableRow row = new HTMLTableRow();
                row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
		table.AddInnerHTMLElement(row);

		HTMLTableCell cell;

		if (inCollatedMode)
		{
			cell = new HTMLTableCell();
                        cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			cell.SetAlign("left");
			cell.SetWidth("50%");
			row.AddInnerHTMLElement(cell);

			// add link for option to view results in parallel
			AddOtherViewModeLink(cell, NetworkSearchControl.VIEWMODE_PARALLEL,
				
			m_asOwner.GetString(799, "ptmsgs_portalbrowsingmsgs"), sources);

			cell = new HTMLTableCell();
			cell.SetAlign("right");
			cell.SetWidth("50%");
			row.AddInnerHTMLElement(cell);

			cell.AddInnerHTMLString(m_asOwner.GetString(802,
					"ptmsgs_portalbrowsingmsgs"));
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		}
		else
		{
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetAlign("left");
			cell.SetWidth("50%");
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);

			cell.AddInnerHTMLString(m_asOwner.GetString(800,
					"ptmsgs_portalbrowsingmsgs"));
			cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetAlign("right");
			cell.SetWidth("50%");
			cell.SetStyleClass(PTStyleClass.LIST_TEXT);
			AddOtherViewModeLink(cell, NetworkSearchControl.VIEWMODE_COLLATED,
				
			m_asOwner.GetString(801, "ptmsgs_portalbrowsingmsgs"), sources);
		}
	}

	/**
	 * present the results interleaved (e.g., if there are three sources,
	 * then we show first result from source 1, first result from source 2,
	 * first result from source 3, second result from source 1, second
	 * result from source 2, and so on.
	 **/
	protected void showCollatedResults(IXPList sources, HTMLTable table)

	{
		// first add one row indicating that these are collated and giving
		// the number of results overall and the displayed range
		int firstDisplayedResult = m_asmModel.GetFirstDisplayedResultOverall();
		int lastDisplayedResult  = (firstDisplayedResult +
			m_asmModel.GetNumDisplayedResultsOverall()) - 1;
		int numOverallResults = m_asmModel.GetNumResultsOverall();

		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.LIST_SUBHEAD);
		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		cell = new HTMLTableCell();
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		row.AddInnerHTMLElement(cell);
		cell.SetHeight("23");

		cell.AddInnerHTMLString(XPResourceManager.FormatMessage(
				m_asOwner.GetString(810, "ptmsgs_portalbrowsingmsgs"),
				XPConvert.ToString(firstDisplayedResult),
				XPConvert.ToString(lastDisplayedResult),
				XPConvert.ToString(numOverallResults)));

		// + " &nbsp;&nbsp;&nbsp;" + firstDisplayedResult + " &nbsp; - &nbsp; " + lastDisplayedResult + " " + _ui_of + " " +  numOverallResults + sixSpaces); 
		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		boolean resultsRemaining = true;

		int numSearchedSources			 = sources.GetSize();
		int overallResultCount			 = 0;
		int[] numDisplayedSoFarForSource = new int[numSearchedSources];

		for (int i = 0; i < numSearchedSources; i++)
		{
			numDisplayedSoFarForSource[i] = 0;
		}

		while (resultsRemaining)
		{
			boolean nothingLeft = true;

			for (int sourceIndex = 0; sourceIndex < numSearchedSources;
					sourceIndex++)
			{
				int sourceId = XPConvert.ToInteger(sources.GetElement(sourceIndex));

				if (numDisplayedSoFarForSource[sourceIndex] < m_asmModel.GetNumDisplayedResultsFromSource(
							sourceId))
				{
					showResult(table, sourceId,
						numDisplayedSoFarForSource[sourceIndex],
						overallResultCount, true);

					numDisplayedSoFarForSource[sourceIndex]++;
					overallResultCount++;

					if (numDisplayedSoFarForSource[sourceIndex] < m_asmModel.GetNumDisplayedResultsFromSource(
								sourceId))
					{
						nothingLeft = false;
					}
				}
			}

			resultsRemaining = !nothingLeft;
		}
	}

	/**
	 * 
	 *
	 * @param table 
	 * @param sourceId 
	 * @param withinSourceResultNum 
	 * @param overallResultNum 
	 * @param collated 
	 *
	 * @throws HTMLException 
	 */
	protected void showResult(HTMLTable table, int sourceId,
		int withinSourceResultNum, int overallResultNum, boolean collated)

	{
		// row for title of result
		HTMLTableRow row = new HTMLTableRow();

		if ((overallResultNum % 2) == 0)
		{
			row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
		}
		else
		{
			row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
		}

		table.AddInnerHTMLElement(row);

		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);

		cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);

		HTMLImg resultGif = m_asmModel.GetImageForResultFromSource(sourceId,
				withinSourceResultNum);

		if (resultGif == null)
		{
			resultGif = new HTMLImg(null, "search result");
		}

		cell.AddInnerHTMLElement(resultGif);
		cell.AddInnerHTMLString("&nbsp;&nbsp;");
		
		HTMLAnchor clickThruLink =
		    m_asmModel.GetURLForResultFromSource(sourceId, withinSourceResultNum, false);
		String resultTitle=
		    m_asmModel.GetTitleForResultFromSource(sourceId,
							   withinSourceResultNum); 
		
		// if we didn't get a url back, then don't make a link
		if (clickThruLink == null)
		{
		    cell.AddInnerHTMLString(resultTitle);
		}
		else
		{
		    clickThruLink.AddInnerHTMLString(resultTitle); 
		    cell.AddInnerHTMLElement(clickThruLink);
		}

 
		cell = new HTMLTableCell();
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		row.AddInnerHTMLElement(cell);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		// row for result description
		row = new HTMLTableRow();

		if ((overallResultNum % 2) == 0)
		{
			row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
		}
		else
		{
			row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
		}

		table.AddInnerHTMLElement(row);

		cell = new HTMLTableCell();
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		row.AddInnerHTMLElement(cell);
		cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

		cell = new HTMLTableCell();
                cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		cell.SetColSpan("2");
		row.AddInnerHTMLElement(cell);
		// I wonder if I should just leave out the row if there's 
		// no description, rather than leaving the row blank?
		String descriptionOrBlank=m_asmModel.GetDescriptionForResultFromSource(sourceId,withinSourceResultNum); 
		if (descriptionOrBlank==null) {
		    descriptionOrBlank="";
		}
		cell.AddInnerHTMLString(descriptionOrBlank);

		if (collated)
		{
			cell.AddInnerHTMLString("<i>");

			cell.AddInnerHTMLString(XPResourceManager.FormatMessage(
					m_asOwner.GetString(808, "ptmsgs_portalbrowsingmsgs"),
					m_asmModel.GetSourceName(sourceId)));
			cell.AddInnerHTMLString("</i>");
		}
	}

	/**
	 * 
	 *
	 * @param sources 
	 * @param table 
	 *
	 * @throws HTMLException 
	 */
	protected void showResultsInParallel(IXPList sources, HTMLTable table)

	{
		for (int i = 0; i < sources.GetSize(); i++)
		{
			int sourceId = XPConvert.ToInteger(sources.GetElement(i));

			if (!(m_asmModel.isResultSetValid(sourceId)))
			{
				// temporary hack
				if (m_asmModel.GetPageNum() == 0)
				{
					HTMLTableRow row = new HTMLTableRow();
					row.SetStyleClass(PTStyleClass.LIST_SUBHEAD);
					table.AddInnerHTMLElement(row);

					HTMLTableCell cell = new HTMLTableCell();
					row.AddInnerHTMLElement(cell);
					cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

					cell = new HTMLTableCell();
					cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
					row.AddInnerHTMLElement(cell);
					HTMLElement errorLink=m_asmModel.GetErrorLinkFromSource(sourceId);
					if (errorLink != null)
					{
						cell.AddInnerHTMLElement(errorLink);
					} else {
					cell.AddInnerHTMLString(XPResourceManager.FormatMessage(m_asOwner.GetString(1640, "ptmsgs_portalbrowsingmsgs"), 
												m_asmModel.GetSourceName(sourceId) + " : " + m_asmModel.GetErrorFromSource(sourceId))); 
					}
				}
			}
			else
			{ 
				int numDisplayedResults = m_asmModel.GetNumDisplayedResultsFromSource(sourceId);
				int numTotalResults = m_asmModel.GetNumResultsFromSource(sourceId);

				int firstDisplayedResult = m_asmModel.GetFirstDisplayedResultFromSource(sourceId);

				int lastDisplayedResult = (firstDisplayedResult +
					numDisplayedResults) - 1;

				if (numDisplayedResults > 0)
				{
					HTMLTableRow row = new HTMLTableRow();
					row.SetStyleClass(PTStyleClass.LIST_SUBHEAD);
					table.AddInnerHTMLElement(row);

					HTMLTableCell cell = new HTMLTableCell();
					row.AddInnerHTMLElement(cell);
					cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);

					cell = new HTMLTableCell();
					cell.SetStyleClass(PTStyleClass.LIST_TEXT);
					row.AddInnerHTMLElement(cell);
					cell.SetHeight("23");

					cell.AddInnerHTMLString(XPResourceManager.FormatMessage(
							m_asOwner.GetString(809, "ptmsgs_portalbrowsingmsgs"),
							m_asmModel.GetSourceName(sourceId),
							XPConvert.ToString(firstDisplayedResult),
							XPConvert.ToString(lastDisplayedResult),
							XPConvert.ToString(numTotalResults)));

					int numDisplayedSoFar = (m_asmModel.GetFirstDisplayedResultFromSource(sourceId) +
						m_asmModel.GetNumDisplayedResultsFromSource(sourceId)) -
						1;

					if ((sources.GetSize() > 1) &&
							(numDisplayedSoFar < m_asmModel.GetNumResultsFromSource(
								sourceId)))
					{
						addMoreFromHereLink(row, sourceId);
					}

					for (int j = 0; j < numDisplayedResults; j++)
					{
						showResult(table, sourceId, j, j, false);
					}
				}
			}
		}
	}
}

