package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author CraigS
 */
public class FollowupSearchView extends SearchResultView
{
  public static final String STR_MVC_CLASS_NAME = "FollowupSearch";

  public static final int MIN_RESULTS_TO_DISPLAY_SWR = 10;

  public static final String SEPARATOR = "&nbsp;|&nbsp;&nbsp;&nbsp;";

  protected SearchPageModeHelper _pageMode = null;
  public void SetPageModeHelper(SearchPageModeHelper pageMode)
  {
    _pageMode = pageMode;
  }
	
  /**
   *  This method generates the 508-mode version of the "search again:" form.
   * 
   *  @param form the HTMLForm where the "search again:" form should go.
   */
  public void Add508InterfaceToForm(HTMLForm form)
  {
    HTMLTable table = new HTMLTable();
    form.AddInnerHTMLElement(table);

    table.SetCellPadding("6");
    table.SetCellSpacing("0");
    table.SetWidth("100%");

    HTMLTableRow row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    row.SetStyleClass(PTStyleClass.ALERT_BG);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetNoWrap(true);

    // Add the "search again" prompt, pulldown, searchbox, and button
    {
      // "Search Again:"
      cell.AddInnerHTMLString("<b>");
      cell.AddInnerHTMLString(m_asOwner.GetString(812, "ptmsgs_portalbrowsingmsgs"));
      cell.AddInnerHTMLString("</b>");

      cell.AddInnerHTMLString(SPACE);

      // Call helper to make the "within results / entire portal" pulldown menu (contents depend on context)
      HTMLSelect select = MakeWithinResultsSelect(_model, m_asOwner);

      // If we got a pulldown menu, add it
      if (null != select) {
        select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

        cell.AddInnerHTMLElement(select);
        cell.AddInnerHTMLString(SPACE);
      } else {
        // Otherwise, add a hidden input so that anything typed in the "search again" box will result in a brand-new search
        HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN,
                                        SearchWithinResultsControl.WITHIN_RESULTS_DATA_HI,
                                        SearchWithinResultsControl.WITHIN_RESULTS_DATA_HI, "");
        input.SetValue(SearchWithinResultsControl.ENTIRE_PORTAL_VALUE);
        cell.AddInnerHTMLElement(input);
      }

      // Add text box for search text
      HTMLInput textBox = null;
      if (! _model.isAdvancedSearch()) {
        // Target is search-within-results control
        textBox = new HTMLInput(HTMLInputTypes.TEXT,
                                SearchWithinResultsControl.ADDITIONAL_QUERY_DATA, "");
      } else {
        // Target is brand new banner search
        textBox = new HTMLInput(HTMLInputTypes.TEXT, StartSearchControl.USER_QUERY, "");
      }
      textBox.SetSize(31);
      textBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
      textBox.SetAlt(m_asOwner.GetString(1531, "ptmsgs_portalbrowsingmsgs"));
      textBox.SetTitle(m_asOwner.GetString(1531, "ptmsgs_portalbrowsingmsgs"));
      textBox.SetValue(_model.GetSearchString());
      cell.AddInnerHTMLElement(textBox);
      cell.AddInnerHTMLString(SPACE);

      // Make the search button
      HTMLInput button = new HTMLInput(HTMLInputTypes.SUBMIT,
                                       "in_su_PTSWR", "in_su_PTSWR");
      button.SetValue(m_asOwner.GetString(774, "ptmsgs_portalbrowsingmsgs"));
      button.SetTitle(m_asOwner.GetString(774, "ptmsgs_portalbrowsingmsgs"));
      button.SetAccessKey(m_asOwner.GetString(4, "ptmsgs_portal508quickkeymsgs"));
      button.SetAlt(m_asOwner.GetString(42, "ptmsgs_portal508quickkeymsgs"));
      button.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
      cell.AddInnerHTMLElement(button);
    }  // end "search again" prompt, pulldown, searchbox, and button

    // Add a spacer cell
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetNoWrap(true);
    cell.AddInnerHTMLString("&nbsp;");

    // Add cell for Advanced Search link
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetNoWrap(true);

    // Make the "advanced search" link
    ASURL url = new ASURL(m_asOwner);
    url.SetLinkCreateNewSpace(com.plumtree.portalpages.browsing.search.advanced.AdvancedSearchAS.STR_MVC_CLASS_NAME,
                              m_asOwner);
    url.SetControl(com.plumtree.uiinfrastructure.editor.EditorStartControl.STR_MVC_CLASS_NAME);
    url.AddControlArgument(com.plumtree.uiinfrastructure.editor.EditorStartControl.QS_EDITOR_TYPE,
                           com.plumtree.uiinfrastructure.editor.EditorStartControl.EDITOR_START_FLAG_MISC);

    if (_model.isAdvancedSearch()) {
      // "New Advanced Search"
      url.AddInnerHTMLString(m_asOwner.GetString(1379, "ptmsgs_portalbrowsingmsgs"));
    } else {
      // if current search is not advanced search, show the "Go to advanced search" icon

      HTMLImg icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED, 
                                                               true, m_asOwner).GetHTMLElement();
      icon.SetAlign("absmiddle");
      icon.SetBorder("0");
      url.AddInnerHTMLElement(icon);

      url.AddInnerHTMLString(m_asOwner.GetString(815, "ptmsgs_portalbrowsingmsgs"));
    }

    // Add the "advanced search" link
    cell.AddInnerHTMLElement(url.GetURLAsHTMLElement());

    // Add "save this search" URL if the user has not already saved the search
    // and has not drilled down
    // .. and is not a guest
    if ((! PlumtreeHelpers.IsGuestSession(m_asOwner)) && (1 == _model.GetDrilldownDepth())) {

      // first, add separator cell
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      cell.SetNoWrap(true);
      cell.AddInnerHTMLString("|");

      // .. and cell for save-this-search link
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
      cell.SetNoWrap(true);

      // If not already saved..
      if (!_model.GetHasBeenSaved()) {
        // make a link that will save the search

        ASURL saveSearch = new ASURL(m_asOwner);
        saveSearch.SetLinkGetCachedSpace(m_asOwner);
        saveSearch.SetDisplayPage(SaveSearch508DP.STR_MVC_CLASS_NAME);

        HTMLImg icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SAVE, 
                                                                 true, m_asOwner).GetHTMLElement();
        icon.SetAlign("absmiddle");
        icon.SetBorder("0");
        saveSearch.AddInnerHTMLElement(icon);

        // "Save this Search"
        saveSearch.AddInnerHTMLString(m_asOwner.GetString(816, "ptmsgs_portalbrowsingmsgs"));

        cell.AddInnerHTMLElement(saveSearch.GetURLAsHTMLElement());
      } else {
        // If search already saved, show text "Search has been saved as:"
        cell.AddInnerHTMLString(m_asOwner.GetString(817, "ptmsgs_portalbrowsingmsgs"));
        cell.AddInnerHTMLString("<b>");
        cell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(_model.GetSavedSearchName()));
        cell.AddInnerHTMLString("</b>");
      }
    }

    // Add final 100%-width cell to left-justify the entire row
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetWidth("100%");
  }

  /**
   *  This method generates the standard version of the "search again:" form.
   * 
   *  @param form the HTMLForm where the "search again:" form should go.
   */
  public void AddStandardInterfaceToForm(HTMLForm form)
  {
    // Add the hidden model mode input if one is present
    if ((null != _pageMode) && (_pageMode.UserHasEditModeAccess())) {
      HTMLInput modeInput = new HTMLInput(HTMLInputTypes.HIDDEN,
                                          SearchResultModel.MODEL_MODE_INPUT,
                                          SearchResultModel.MODEL_MODE_INPUT);
      modeInput.SetValue(_model.GetPageMode());
      form.AddInnerHTMLElement(modeInput);
    }

    // Create a table for the search-again form
    HTMLTable table = new HTMLTable();
    table.SetWidth("100%");
    table.SetCellSpacing("0");
    table.SetCellPadding("5");
    form.AddInnerHTMLElement(table);

    // Add a single table row
    HTMLTableRow row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.OBJECTSEARCH_BG);
    table.AddInnerHTMLElement(row);

    // Add "Search Again" message
    HTMLTableCell cell = new HTMLTableCell();
    cell.SetHeight("25");
    cell.SetNoWrap(true);
    cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(812, "ptmsgs_portalbrowsingmsgs"));
    cell.AddInnerHTMLString(SPACE);

    // Call helper to make the "within results / entire portal" pulldown menu (contents depend on context)
    HTMLSelect select = MakeWithinResultsSelect(_model, m_asOwner);

    // If we got a valid pulldown
    if (null != select)
    {
      // add it to the table cell
      cell = new HTMLTableCell();
      cell.SetVAlign("middle");
      cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
      row.AddInnerHTMLElement(cell);

      select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
      cell.AddInnerHTMLElement(select);

      cell.AddInnerHTMLString(SPACE);
    }
    else
    {
      // Add a hidden input indicating this should be a brand-new search
      HTMLInput input = new HTMLInput(HTMLInputTypes.HIDDEN,
                                      SearchWithinResultsControl.WITHIN_RESULTS_DATA_HI,
                                      SearchWithinResultsControl.WITHIN_RESULTS_DATA_HI, "");
      input.SetValue(SearchWithinResultsControl.ENTIRE_PORTAL_VALUE);
      cell.AddInnerHTMLElement(input);
    }

    // Add a cell for the text box
    cell = new HTMLTableCell();
    cell.SetHeight("25");
    cell.SetVAlign("middle");
    cell.SetNoWrap(true);
    cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_HEADER);
    row.AddInnerHTMLElement(cell);

    // Make the text box itself

    // Text box name depends on whether we are issuing a real search-within-results or a brand new search
    String textBoxName = null;
    if (! _model.isAdvancedSearch()) {
      // Target is search-within-results control
      textBoxName = SearchWithinResultsControl.ADDITIONAL_QUERY_DATA;
    } else {
      // Target is brand new banner search
      textBoxName = StartSearchControl.USER_QUERY;
    }
    HTMLInput textBox = new HTMLInput(HTMLInputTypes.TEXT, textBoxName, "");
    textBox.SetSize(31);
    textBox.SetOnKeyDown("handleKeyDownPTSWR(event);");
    textBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

    // Default text box to current search string
    textBox.SetValue(_model.GetSearchString());
    cell.AddInnerHTMLElement(textBox);
    cell.AddInnerHTMLString(SPACE);

    // Make the search button
    cell = new HTMLTableCell();
    cell.SetHeight("25");
    cell.SetVAlign("middle");
    row.AddInnerHTMLElement(cell);

    HTMLAnchor searchButtonAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
    searchButtonAnchor.SetOnClick("submitSearchPTSWR(); return false;");
    searchButtonAnchor.SetPreComment(m_asOwner.GetString(293, "ptmsgs_portalinfrastructure"));

    PTConstruct searchButton = null;

    try
    {
      searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON,
                                                     true, this.m_asOwner);
    }
    catch (Exception e)
    {
    }

    if (null != searchButton)
    {
      HTMLImg searchButtonImg = (HTMLImg) searchButton.GetHTMLElement();
      searchButtonImg.SetAlt(m_asOwner.GetString(293, "ptmsgs_portalinfrastructure"));
      searchButtonAnchor.AddInnerHTMLElement(searchButtonImg);
    }

    cell.AddInnerHTMLElement(searchButtonAnchor);

    // Add Javascript to validate and submit the input string
    HTMLScript script = SearchFormFactory.MakeSearchFormJavascript("PTSWR", m_asOwner, textBoxName);
    cell.AddInnerHTMLElement(script);

    // Add a cell for the "advanced search" link
    cell = new HTMLTableCell();
    cell.SetNoWrap(true);
    cell.SetStyleClass(PTStyleClass.OBJECTSEARCH_TEXT);
    row.AddInnerHTMLElement(cell);

    ASURL url = new ASURL(m_asOwner);
    url.SetLinkCreateNewSpace(com.plumtree.portalpages.browsing.search.advanced.AdvancedSearchAS.STR_MVC_CLASS_NAME,
                              m_asOwner);
    url.SetControl(com.plumtree.uiinfrastructure.editor.EditorStartControl.STR_MVC_CLASS_NAME);
    url.AddControlArgument(com.plumtree.uiinfrastructure.editor.EditorStartControl.QS_EDITOR_TYPE,
                           com.plumtree.uiinfrastructure.editor.EditorStartControl.EDITOR_START_FLAG_MISC);

    FollowupSearchView.AddReconstructionArgs(_model, url);

    url.AddControlArgument(SearchResultModel.MODEL_MODE_INPUT, _model.GetPageMode());

    HTMLImg icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED, 
                                                             true, m_asOwner).GetHTMLElement();
    icon.SetAlign("absmiddle");
    icon.SetBorder("0");
    url.AddInnerHTMLElement(icon);
    url.AddInnerHTMLString("   ");
    if (_model.isAdvancedSearch())
    {
      cell.AddInnerHTMLString(SPACE2);
      cell.SetHeight("25");
      //Back to Advanced
      url.AddInnerHTMLString(m_asOwner.GetString(1699, "ptmsgs_portalbrowsingmsgs"));
    }
    else
    {
      //Advanced		
      url.AddInnerHTMLString(m_asOwner.GetString(815, "ptmsgs_portalbrowsingmsgs"));
    }

    cell.AddInnerHTMLString(SEPARATOR);
    cell.AddInnerHTMLElement(url.GetURLAsHTMLElement());

    // Add "save this search" URL if the user has not already saved the search
    // and has not drilled down
    // .. and is not a guest
    if ((! PlumtreeHelpers.IsGuestSession(m_asOwner)) && (1 == _model.GetDrilldownDepth()))
    {
      cell.AddInnerHTMLString(SPACE3);
      cell.AddInnerHTMLString("|");
      cell.AddInnerHTMLString(SPACE3);

      if (!_model.GetHasBeenSaved())
      {
        ASURL saveSearch = new ASURL(m_asOwner);
        saveSearch.SetLinkGetCachedSpace(m_asOwner);
        saveSearch.SetDisplayPage(SaveSearchPopupDP.STR_MVC_CLASS_NAME);

        HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);

        /*  Uncomment me to open the popup with a border, for debugging
            anchor.SetOnClick("window.open('" + saveSearch.GetURLAsString() +
            "','" + SaveSearchPopupDP.STR_MVC_CLASS_NAME +
            "');");
        */
        anchor.SetOnClick("window.open('" +
                          saveSearch.GetURLAsString() + "','" +
                          SaveSearchPopupDP.STR_MVC_CLASS_NAME +
                          "','location=no,menubar=no,height=220,width=475');");

        icon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SAVE, 
                                                         true, m_asOwner).GetHTMLElement();
        icon.SetAlign("absmiddle");
        icon.SetBorder("0");

        anchor.AddInnerHTMLElement(icon);
        anchor.AddInnerHTMLString("   ");

        // "Save this Search"
        anchor.AddInnerHTMLString(m_asOwner.GetString(816, "ptmsgs_portalbrowsingmsgs"));

        cell.AddInnerHTMLElement(anchor);
      }
      else
      {
        // If search already saved, show text "Search has been saved as:"

        cell.AddInnerHTMLString(m_asOwner.GetString(817, "ptmsgs_portalbrowsingmsgs"));
        cell.AddInnerHTMLString("<b>");
        cell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(_model.GetSavedSearchName()));
        cell.AddInnerHTMLString("</b>");
      }
    }

    // Add an empty cell to force all the rest to the left side of the page
    cell = new HTMLTableCell();
    cell.SetWidth("100%");
    cell.SetVAlign("middle");
    row.AddInnerHTMLElement(cell);
    cell.AddInnerHTMLString(SPACE);
  }

  /**
   * required by UI framework; simply instantiates this class.
   * @return instance of FollowupSearchView.
   */
  public Object Create()
  {
    return new FollowupSearchView();
  }

  /**
   * @see com.plumtree.portalpages.search.SearchResultView#DisplaySearchView()
   */
  public HTMLElement DisplaySearchView()
  {
    // Make the enclosing HTMLForm and add hidden inputs to it

    HTMLForm form = GetSWRForm();

    // If in 508 mode
    if (is508())
    {
      // call helper to handle the 508 case
      Add508InterfaceToForm(form);
    }
    else
    {
      // Otherwise create the standard form
      AddStandardInterfaceToForm(form);
    }

    return form;
  }

  /**
   *  required by UI framework; returns name of this class
   * @return name of this class.
   */
  public String GetName()
  {
    return STR_MVC_CLASS_NAME;
  }

  /**
   * Makes the HTMLForm that the "search again" box will go into.
   * This method makes the part that is used in both standard and 508 UIs -
   * the HTMLForm itself and hidden inputs.
   */
  public HTMLForm GetSWRForm()
  {
    // Create search-within-results form.
    // This is different enough from an initial search form that using
    // SearchFormFactory is probably not worth the trouble..
    HTMLForm form = new HTMLForm("PTSWR");

    form.SetMethod("get");
    form.SetName("PTSWR");

    form.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(), 
                                                          m_asOwner.GetName(), m_asOwner.IsSubSpace()));

    if (!is508())
    {
      form.SetOnSubmit("return checkSearchPTSWR();");
    }

    // Add target space
    HTMLInput targetSpace = new HTMLInput(HTMLInputTypes.HIDDEN,
                                          ASConstants.SPACENAME_INPUT, ASConstants.SPACENAME_INPUT, "");
    if (! _model.isAdvancedSearch()) {
      // Stay in the same space to allow search-within-results
      targetSpace.SetValue(m_asOwner.GetName());
    } else {
      // Brand new banner search
      targetSpace.SetValue(SearchResultAS.STR_MVC_CLASS_NAME);
    }
    form.AddInnerHTMLElement(targetSpace);

    // Add our current space ID, so the framework doesn't create
    // another instance of the space
    if (! _model.isAdvancedSearch()) {
      HTMLInput targetSpID = new HTMLInput(HTMLInputTypes.HIDDEN,
                                           ASConstants.SPACEID_INPUT, ASConstants.SPACEID_INPUT, "");
      targetSpID.SetValue(m_asOwner.GetSpaceID());
      form.AddInnerHTMLElement(targetSpID);
    }

    HTMLInput targetControl = new HTMLInput(HTMLInputTypes.HIDDEN,
                                            ASConstants.CONTROL_INPUT, ASConstants.CONTROL_INPUT, "");
    if (! _model.isAdvancedSearch()) {
      // Set target as SearchWithinResultsControl
      targetControl.SetValue(SearchWithinResultsControl.STR_MVC_CLASS_NAME);
    } else {
      // Brand new banner search
      targetControl.SetValue(BannerStartSearchControl.STR_MVC_CLASS_NAME);
    }
    form.AddInnerHTMLElement(targetControl);

    // Add a hidden input for the current model key
    if (! _model.isAdvancedSearch()) {
      HTMLInput depth = new HTMLInput(HTMLInputTypes.HIDDEN,
                                      SearchWithinResultsControl.KEY_DATA,
                                      SearchWithinResultsControl.KEY_DATA, "");
      depth.SetValue(_model.GetCurrentKey());
      form.AddInnerHTMLElement(depth);
    }

    return form;
  }

  /**
   *  Helper that makes the "within results" / "entire portal" / etc.
   *  pulldown menu.  Exact contents of the menu depend on context (i.e. what
   *  restrictions were on the previous search performed).
   *
   *  Is public static for use by followupsearchform display tag.
   *  
   *  @return HTMLSelect that may be added to the "search again" form, or null if no pulldown menu should appear.
   */
  public static HTMLSelect MakeWithinResultsSelect(ISearchResultModelRO model, AActivitySpace asOwner)
  {
    // After an advanced search, only option is to search the entire portal
    if (model.isAdvancedSearch()) {
      return null;
    }

    // else, start building our HTMLSelect
    HTMLSelect select = new HTMLSelect(SearchWithinResultsControl.WITHIN_RESULTS_DATA_SE, "");
    IXPList optionsList = GetWithinResultsOptions(model, asOwner);

    int numOptions = optionsList.GetSize();
    for (int i=0; i<optionsList.GetSize(); i++) {
    	HTMLOption option = (HTMLOption) optionsList.GetElement(i);
    	if (SearchWithinResultsControl.WITHIN_RESULTS_VALUE != option.GetValue() || model.GetTotalItems() >= MIN_RESULTS_TO_DISPLAY_SWR) {
    		select.AddInnerHTMLElement(option);
    	} else {
    		numOptions--;
    	}
    }
    
    // If we put at least two options into the HTMLSelect, return it
    if (numOptions > 1)
    {
      return select;
    }

    // if "Entire Portal" is only option, don't bother showing the select
    return null;
  }
  
  	public static IXPList GetWithinResultsOptions(ISearchResultModelRO model, AActivitySpace asOwner) 
  	{
  		IXPList optionsList = new XPArrayList();
  		// Get the set of options that the model considers to be "removable", given the current
  	    // context.  For example, if the search was originally restricted to a folder, then we
  	    // could "remove" the folder restriction and thereby expand the search to the "entire portal".
  	    SearchSettingCollection removableSettings = model.GetRemovableSettings();
  		HTMLOption option;

	    // Show "Entire Portal" or "Same Portlet" option
	    option = new HTMLOption(SearchWithinResultsControl.ENTIRE_PORTAL_VALUE);

	    // if we were restricted to a portlet and to Content Server..
	    if ((null != model.GetPortletRestrictions()) &&
	        (PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT == model.GetApplicationRestrictions())) {

	      // this is a bit of a hack.. Content Server's search URLs don't look like
	      // banner searches, so SearchResultModel doesn't consider the portlet restriction
	      // to be "removable".  A followup search will apply the same restrictions.
	      // Hence only two options appear, and the broader option is more accurately called
	      // "Same Portlet" in this case.
	      option.AddInnerHTMLString(asOwner.GetString(1668, "ptmsgs_portalbrowsingmsgs"));
	    } else {
	      // show the "Entire Portal" option
	      option.AddInnerHTMLString(asOwner.GetString(814, "ptmsgs_portalbrowsingmsgs"));
	    }

	    // always make "Entire Portal" (or "Same Portlet") the default
	    option.SetSelected(true);
	    optionsList.Add(option);

	    // If there was some "removable" restriction, then add a
	    // "Same folder", "Same community", or other restrictions option
	    if (null != removableSettings)
	    {
	      option = new HTMLOption(SearchWithinResultsControl.SAME_RESTRICTIONS_VALUE);

	      // Add "same community", "same folder", etc depending on context
	      if (removableSettings.IsSimpleCommunityRestriction())
	      {
	        // "Same Community"
	        option.AddInnerHTMLString(asOwner.GetString(1377, "ptmsgs_portalbrowsingmsgs"));
	      }
	      else if (removableSettings.IsSimpleFolderRestriction())
	      {
	        // "Same Folder"
	        option.AddInnerHTMLString(asOwner.GetString(1376, "ptmsgs_portalbrowsingmsgs"));
	      }
	      else
	      {
	        // Generic option for the case where we can't tell what removing the restriction will do: "Same Restrictions"
	        option.AddInnerHTMLString(asOwner.GetString(1375, "ptmsgs_portalbrowsingmsgs"));
	      }
	      optionsList.Add(option);
	    }

	    if (!model.isAdvancedSearch()) {
	    	option = new HTMLOption(SearchWithinResultsControl.WITHIN_RESULTS_VALUE);
	    	option.AddInnerHTMLString(asOwner.GetString(813, "ptmsgs_portalbrowsingmsgs"));
	    	optionsList.Add(option);
	    }
	    
	    return optionsList;
  	}

  /**
   *  This method adds arguments to the "go to advanced search" URL so that the
   *  advanced search page will be initialized with the parameters of the current search..
   *  it seems poorly implemented, but works in some cases
   *  
   *  SM - Making public static so that this can be called by the follow up
   *       search data tag.
   */
  public static void AddReconstructionArgs(ISearchResultModelRO model, ASURL url)
  {
    boolean subsInc = model.GetIncludeSubfolders();
    // Use the NON_INPUT_PREFIX to pass back the include subfolders value. This
    // will work if the value is false.
    String key = StartSearchControl.NON_INPUT_PREFIX +
      SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S;
    if(! subsInc)
      url.AddControlArgument(key, "0");
    else
      url.AddControlArgument(key, "1");

    String searchString = model.GetSearchString();
    if (null != searchString) {
      url.AddControlArgument(FilterForm.TOP_OPERATOR, "0");
      url.AddControlArgument(FilterForm.FULL_TEXT, searchString);
    }

    boolean foundAppsSetting = false;

    XPHashtable args = model.GetReconstructionArgs("", false);
    IXPEnumerator keys = args.GetKeys();
    IXPEnumerator elements = args.GetElements();
    while(keys.MoveNext())
    {
      elements.MoveNext();
      key = XPConvert.ToString(keys.GetCurrent());
      String[] element = (String[])elements.GetCurrent();
      if(element != null)
      {
        if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_APPS_S))
        {
          foundAppsSetting = true;
          int appsVal = XPConvert.ToInteger(element[0]);
          if((0 == appsVal) ||
             ((appsVal & XPConvert.ToInteger(PT_SEARCH_APPS.PT_SEARCH_APPS_CONTENT)) != 0))
          {	 
            String k = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S;
            String val = XPConvert.ToString(SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE);
            url.AddControlArgument(k,val);
          }

          if((0 == appsVal) ||
             ((appsVal & XPConvert.ToInteger(PT_SEARCH_APPS.PT_SEARCH_APPS_COLLAB)) != 0))
          {	 
            String k = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S;
            String val = XPConvert.ToString(SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE);
            url.AddControlArgument(k,val);
          }
        }
        else 
        {
          // Note that this will be missing if include subfolders is false.
          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S))
            key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
              SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S;

          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_MAXRESULTS_S))
            key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
              SearchSettingCollection.PT_SEARCHSETTING_MAXRESULTS_S;

          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_LANGUAGE_S))
            {
              key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
                SearchSettingCollection.PT_SEARCHSETTING_LANGUAGE_S;
            }	
          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_LIMITBYLOCALE_S))
            key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX	+ key;

          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S))
            key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + key;

          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_DDFOLDERS_S))
            key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
              SearchSettingCollection.PT_SEARCHSETTING_DDFOLDERS_S;

          if(key.equals(SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S))
            key = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
              SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S;

          for(int i = 0; i < element.length; i++)
          {
            url.AddControlArgument(key,element[i]);
          }
        }
      }
    }

    if (! foundAppsSetting) {
      // If we didn't find the "apps" setting, the default is all apps, including collab/content.
      // But the advanced search page needs to be explicitly told to include collab/content
      String k = StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S;
      String val = XPConvert.ToString(SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE);
      url.AddControlArgument(k,val);

      val = XPConvert.ToString(SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE);
      url.AddControlArgument(k,val);
    }
  }
}
