package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public class GroupedResults508ViewHelper implements IGroupedResultsViewHelper
{
  protected AActivitySpace m_asOwner = null;
  protected ISearchResultModelRO _model = null;
  protected GroupedResultsView _view = null;
  protected SearchPageModeHelper _pageMode = null;

  public static final String DOT         = ".";
  public static final String COLON       = ":";
  public static final String SPACE       = " ";
  public static final String LEFT_PAREN  = "(";
  public static final String RIGHT_PAREN = ")";
  protected XPDateFormat _dateFormat = null;

  protected HTMLElement[] _resultRows = null;

  public GroupedResults508ViewHelper(SearchPageModeHelper pageMode)
  {
    _pageMode = pageMode;
  }

  public void Init(AActivitySpace owner,
                   ISearchResultModelRO model,
                   GroupedResultsView view) {
    m_asOwner = owner;
    _model = model;
    _view = view;

    _dateFormat = Get508DateFormat(m_asOwner);
  }

  protected XPDateFormat Get508DateFormat(AActivitySpace owner) {
    String locale = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE, owner);
    String timezone = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE, owner);

    XPLocale xpLocale = null;
    XPTimeZone xpTimeZone = null;

    if (null != locale) {
      xpLocale = new XPLocale(locale);
    } else {
      xpLocale = XPLocale.GetDefault();
    }

    if (null != timezone) {
      xpTimeZone = XPTimeZone.GetTimeZone(timezone);
    } else {
      xpTimeZone = XPTimeZone.GetCurrentTimeZone();
    }

    return XPDateFormat.GetDateInstance(XPDateFormat.LONG,
                                        xpLocale, xpTimeZone);
  }

  /**
   *  Helper method to format path string in a friendly way
   *  In 508 mode, we simply show the parent folder name, since reading
   *  off a lengthy (and truncated) path takes a lot of time.  The user
   *  can see the full path in View Properties.
   */
  public String formatPath(String path)
  {
    int lastSlash = XPStringUtility.LastIndexOf(path, '\\');

    if ((-1 != lastSlash) && (lastSlash != path.length())) {
      return XPStringUtility.Substring(path, lastSlash+1);
    } else {
      return path;
    }
  }

  /**
   *  Returns javascript for the view.
   */
  public HTMLScript DisplayJavascript() {
    return null;
  }

  /**
   *  Returns the element that all other elements will be added to,
   *  such as an HTMLTable.  If null is returned, a generic
   *  HTMLElementCollection will be used.
   */
  public HTMLElement DisplayCollection()
  {
    // Initialize the _resultRows array we'll use to accumulate results.  See comments in
    // DisplaySingleResult for an explanation of why we do this.
    int displayableItems = _model.GetNumDisplayableItems();
    if (0 < displayableItems) {
      _resultRows = new HTMLElement[displayableItems];
    }

    HTMLTable resultTable = new HTMLTable();

    resultTable.SetCellSpacing("0");
    resultTable.SetCellPadding("3");
    resultTable.SetWidth("100%");

    return resultTable;
  }

  /**
   *  Returns an element that will appear before all results, whether
   *  or not the results are grouped.
   */
  public HTMLElement DisplayHeader()
  {
    HTMLElementCollection collection = new HTMLElementCollection();

    // FIRST ROW: "Search Results" header

    HTMLTableRow row = new HTMLTableRow();
    collection.AddInnerHTMLElement(row);
    row.SetStyleClass(PTStyleClass.DIR_HEADER_BG);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.DIR_TEXT);
    cell.SetColSpan("3");
    cell.SetHeight("30");
    cell.SetAlign("left");
    cell.SetNoWrap(true);

    String banner;

    if (_pageMode.IsAdminMode()) {
      // Use a different message to clue the user in that clickthrough behaves
      // differently
      banner = m_asOwner.GetString(1396, "ptmsgs_portalbrowsingmsgs");
    } else {
      banner = m_asOwner.GetString(844, "ptmsgs_portalbrowsingmsgs");
    }

    cell.AddInnerHTMLString("<b>");
    cell.AddInnerHTMLString(banner);
    cell.AddInnerHTMLString("</b>");

    // Add hidden "." so screenreader will pause after reading banner
    HTMLSpan span = new HTMLSpan();
    cell.AddInnerHTMLElement(span);
    span.SetStyleClass(PTStyleClass.D_HIDDEN_BLACK_TEXT);
    span.AddInnerHTMLString(DOT);

    // SECOND ROW: Number of results and number displayed
    row = new HTMLTableRow();
    collection.AddInnerHTMLElement(row);

    row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);

    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetColSpan("3");
    cell.SetAlign("left");
    cell.SetHeight("30");
    cell.SetWidth("100%");
    cell.SetNoWrap(true);

    SearchSummaryView.ShowNumberOfResults(m_asOwner, cell, _model);

    return collection;
  }

  /**
   *  Returns an element that will appear after all results regardless
   *  of whether the results are grouped.
   */
  public HTMLElement DisplayFooter()
  {
    if (null == _resultRows) {
      return null;
    }

    // Display all the results we've accumulated in _resultRows

    HTMLElementCollection c = new HTMLElementCollection();

    for (int j = 0; j < _resultRows.length; j++) {
      if (null != _resultRows[j]) {
        c.AddInnerHTMLElement(_resultRows[j]);
      }
    }

    return c;
  }

  /**
   *  Returns the header element (e.g. an HTMLTableRow containing column
   *  headings) that will be used if the results are not grouped.  Not called
   *  if the results are grouped.
   */
  public HTMLElement DisplayHeaderIfUngrouped()
  {
    // Not needed
    return null;
  }

  /**
   *  Returns an element that will appear after all results if the results
   *  are not grouped.  Not called if the results are grouped.
   */
  public HTMLElement DisplayFooterIfUngrouped()
  {
    // Not needed
    return null;
  }

  /**
   *  Returns the header element (e.g. an HTMLTableRow containing column
   *  headings) that will be used if the results are grouped.  Not called
   *  if the results are ungrouped.
   */
  public HTMLElement DisplayGroupHeader(int groupNum)
  {
    // Not needed
    return null;
  }

  /**
   *  Returns an element that will appear after all results in a single group.
   *  Not called if the results are ungrouped.
   */
  public HTMLElement DisplayGroupFooter(int groupNum)
  {
    // Not needed
    return null;
  }

  /**
   *  Returns the element (e.g. an HTMLTableRow) for a single
   *  search result.
   */
  public HTMLElement DisplaySingleResult(int overallRank, boolean oddRow, int groupNum)
  {
    HTMLSpan span = null;

    // What's going on here?
    // As of the 5.0.3/508 hotfix, 508 mode never displays grouped results, even if
    // grouping was turned on for the query.  However, GroupedResultsView is going to
    // call this method in grouped order in this case.  I could add another method to
    // the interface that would indicate whether the helper class wants to be called
    // in grouped or ungrouped order, but that would break compatibility with any
    // customer-written IGroupedResultsViewHelper implementations, and I don't want
    // to do that in a hotfix.
    // So what we do here is construct each result row, then add it to a locally
    // maintained hashtable instead of returning it.  Then in DisplayFooter(), we
    // sort and return all result rows as the "footer" for the table.

    HTMLTableRow row = new HTMLTableRow();
    _resultRows[overallRank] = row;

    PTStyleClass hiddenStyle = null;

    if (0 == (overallRank % 2)) {
      row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
      hiddenStyle = PTStyleClass.D_HIDDEN_WHITE_TEXT;
    } else {
      row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
      hiddenStyle = PTStyleClass.D_HIDDEN_LTGRAY_TEXT;
    }

    // LANGUAGE ISSUES

    // What's the user's default language?  We'll need this for tagging any strings
    // that we think are in another language.
    String defaultLang = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE, m_asOwner);

    // What language is this item in?
    String itemLang = null;

    // If a portal document
    if ((SearchResultModel.PORTAL_APP.equals(_model.GetResultApp(overallRank))) &&
        (PT_CLASSIDS.PT_CATALOGCARD_ID == _model.GetResultClassID(overallRank))) {
      // What language did the portal assign to the card?

      itemLang = _model.GetResultEODField(overallRank, PT_INTRINSICS.PT_PROPERTY_CONTENTLANGUAGE);
      if ((null != itemLang) && (0 == itemLang.length())) {
        // Ignore empty strings
        itemLang = null;
      }
      if (null != itemLang) {
        itemLang = XPStringUtility.ToLowerCase(itemLang);

        if (itemLang.equals(defaultLang)) {
          // If the item is in the user's default language, don't bother marking it with
          // special tags.
          itemLang = null;
        }
      }
    }

    // FIRST CELL: rank
    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);

    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetAlign("center");
    cell.SetVAlign("top");

    cell.AddInnerHTMLString(XPConvert.ToString(overallRank + _model.GetFirstDisplayableItem()));
    cell.AddInnerHTMLString(DOT);

    // SECOND CELL: icon
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);

    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetAlign("center");
    cell.SetVAlign("top");
    cell.SetWidth("20");

    // type icon and alt-tag, note this icon comes with the alt-tag set
    HTMLImg icon = (HTMLImg) _model.GetResultIcon(overallRank);
    if (null != icon) {
      icon.SetAlign("absmiddle");
      icon.SetBorder("0");
      cell.AddInnerHTMLElement(icon);
    }

    // THIRD CELL: everything else
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);

    cell.SetStyleClass(PTStyleClass.LIST_TEXT);

    // FIRST LINE: Clickthru link.

    String resultName = XPHttpUtility.HtmlEncode(_model.GetResultName(overallRank));

    String extraClickthroughParams = null;
    //RaviT - bug 8602119 - If Friendly URLs for search are enabled then we don't add qid and rank to search result 
    // item url. Since this would disrupt Friendly url format and also doing a search triggers a qid by Analytics api and
    // it gets tracked by Analytics but not clicking through a Search Result Item, So both rank and qid are not needed,
    // in search result url.
    if(!TaskAPIUICommon.UseFriendlyURLS(FriendlyURLConstants.FRIENDLY_SEARCH_ID)){
    	String loggingID = _LookupLoggingID();
        if (null != loggingID) {
          extraClickthroughParams = "qid=" + loggingID + "&rank=" + XPConvert.ToString(overallRank+1);
        }
    }
    

    String app = _model.GetResultApp(overallRank);
    HTMLAnchor clickthru = null;

    if ((app.equals(SearchResultModel.TEMPLATING_APP)) &&
        (! _pageMode.GetMakeEditLinks())) {
      // Special case: for Branding items, clickthrough should go to
      // a popup with a list of communities on which the associated portlet is
      // used, as in portlet preview.
      // .. BUT, portlet preview (which supplies this popup list) doesn't work
      // in 508 mode.  So we can't support branding clickthroughs.

      clickthru = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
    } else {
      // Otherwise, just use the standard clickthrough
      clickthru = _model.GetResultClickthroughURL(overallRank, /*popup=*/ false, /* editMode= */ false, extraClickthroughParams);
    }

    {
      HTMLElement clickthruContainer = cell;
      if (null != itemLang) {
        HTMLSpan langSpan = new HTMLSpan();
        clickthruContainer = langSpan;
        langSpan.SetLangLocal(itemLang);
		cell.AddInnerHTMLElement(langSpan);
      }

      if ((app.equals(SearchResultModel.TEMPLATING_APP)) ||
          ((app.equals(SearchResultModel.PORTAL_APP) && (_model.GetResultClassID(overallRank) == PT_CLASSIDS.PT_GADGET_ID)))) {
        // Portlet preview doesn't work in 508 mode.  Unfortunately, this means we
        // can't support clickthroughs for these types of items.
        clickthruContainer.AddInnerHTMLString("<b>" + resultName + "</b>");
      } else {
        clickthru.AddInnerHTMLString("<b>" + resultName + "</b>");
        clickthru.SetTitle(resultName);
        clickthruContainer.AddInnerHTMLElement(clickthru);
      }

      // Add a hidden period so screenreaders will pause
      span = new HTMLSpan();
      clickthruContainer.AddInnerHTMLElement(span);
      span.SetStyleClass(hiddenStyle);
      span.AddInnerHTMLString(DOT);
    }

    cell.AddInnerHTMLElement(new HTMLBr());

    // SECOND LINE: Last modified date, "is best bet", and view properties link.

    // modified date
    cell.AddInnerHTMLString("<b>");
    cell.AddInnerHTMLString(m_asOwner.GetString(1761, "ptmsgs_portalbrowsingmsgs")); // "Last modified", with that capitalization
    cell.AddInnerHTMLString("</b>");
    cell.AddInnerHTMLString(SPACE);
    cell.AddInnerHTMLString(_dateFormat.Format(_model.GetResultLastModified(overallRank)));
    cell.AddInnerHTMLString(DOT);
    cell.AddInnerHTMLString(SPACE);

    // "best bet" flag
    if (_model.isResultBestBet(overallRank)) {
      cell.AddInnerHTMLString("<b>");
      cell.AddInnerHTMLString(m_asOwner.GetString(828, "ptmsgs_portalbrowsingmsgs"));
      cell.AddInnerHTMLString(DOT);
      cell.AddInnerHTMLString("</b>");
      cell.AddInnerHTMLString(SPACE);

      row.SetStyleClass(PTStyleClass.ALERT_BG);
    }

    // properties link
    if (!_pageMode.GetMakeEditLinks()) {
      HTMLAnchor propertiesURL = _model.GetResultPropertiesURL(overallRank, /*popup=*/false);

      if (null != propertiesURL) {
        // "View Properties"
        propertiesURL.AddInnerHTMLString(m_asOwner.GetString(1762, "ptmsgs_portalbrowsingmsgs"));

	if ((null != resultName) && (0 < resultName.length())) {
          // "View properties of {name}"
          propertiesURL.SetTitle(XPResourceManager.FormatMessage(m_asOwner.GetString(1792, "ptmsgs_portalbrowsingmsgs"), resultName));
        } else {
          // "View this results' properties"
          propertiesURL.SetTitle(m_asOwner.GetString(1657, "ptmsgs_portalbrowsingmsgs"));
        }

        cell.AddInnerHTMLElement(propertiesURL);
        cell.AddInnerHTMLString(DOT);
        cell.AddInnerHTMLString(SPACE);
      }
    }

    cell.AddInnerHTMLElement(new HTMLBr());

    // THIRD LINE: Parent folder, "go to project" link, etc.

    // Add the path, if:
    //  - this is a portal item, AND
    //    - we're making edit links (make the path a link to the ObjectManager,
    //      displaying the folder in which the item appears), OR
    //    - this is a catalog card or folder; if the user can see a card, he or
    //      she definitely can see its folder as well
    // Change from standard-mode behavior: Don't show the path for folders in 508
    // mode. Since all we show is a link to the folder (not the full path) anyway,
    // this ends up being the same as the clickthrough link, and is not useful.
    if (app.equals(SearchResultModel.PORTAL_APP)) {
      int subtype = _model.GetResultClassID(overallRank);
      boolean isDocDirItem = (subtype == PT_CLASSIDS.PT_CATALOGCARD_ID);

      if (isDocDirItem || _pageMode.GetMakeEditLinks()) {
        String path  = _model.GetResultPath(overallRank);
        int folderID = _model.GetResultFolderID(overallRank);

        if ((PT_CLASSIDS.PT_CATALOGFOLDER_ID == subtype) ||
            (PT_CLASSIDS.PT_ADMIN_FOLDER_ID == subtype)) {
          // for folders, the folder ID for path clickthru is just the object ID
          folderID = _model.GetResultObjectID(overallRank);
        }

        if ((null != path) && (path.length() > 0) && (folderID > 0)) {
          path = formatPath(path);

          ASURL pathURL = new ASURL(m_asOwner);

          if (isDocDirItem) {
            pathURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME, m_asOwner);
            pathURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
            pathURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
                                       XPConvert.ToString(folderID));
            pathURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
                                       XPConvert.ToString(DirConstants.BROWSE_MODE));
          } else {
            pathURL.SetLinkCreateNewSpace(ObjMgrAS.STR_MVC_CLASS_NAME, m_asOwner);
            pathURL.SetControl(ObjMgrSettingsControl.STR_MVC_CLASS_NAME);
            pathURL.AddControlArgument(ObjMgrSettingsControl.FOLDER_ID, XPConvert.ToString(folderID));
            pathURL.AddControlArgument(ObjMgrSettingsControl.OBJECT_IDS, XPConvert.ToString(subtype));
          }

          pathURL.AddInnerHTMLString(XPHttpUtility.HtmlEncode(path));

          cell.AddInnerHTMLString("<b>");
          cell.AddInnerHTMLString(m_asOwner.GetString(1388, "ptmsgs_portalbrowsingmsgs"));
          cell.AddInnerHTMLString(DOT);
          cell.AddInnerHTMLString("</b>");
          cell.AddInnerHTMLString(SPACE);
          cell.AddInnerHTMLElement(pathURL.GetURLAsHTMLElement());

          // Add a hidden period so screenreaders will pause
          span = new HTMLSpan();
          cell.AddInnerHTMLElement(span);
          span.SetStyleClass(hiddenStyle);
          span.AddInnerHTMLString(DOT);

          cell.AddInnerHTMLElement(new HTMLBr());
        }  // end if this result's path is known
      }  // end if we think we should show the path for this result type and display mode
    }  // end if portal result

    else if (app.equals(SearchResultModel.COLLAB_APP)) {
      // For Collab items, add a "Go to project" link
      String projectURL = _model.GetResultCollabProjectURL(overallRank);

      if (null != projectURL) {
        HTMLAnchor proj = new HTMLAnchor(projectURL);

        String projName = _model.GetResultCollabProjectName(overallRank);

        if (null == projName) {
          // if project name unknown, use "Go to Project" as the link
          proj.AddInnerHTMLString(m_asOwner.GetString(1384, "ptmsgs_portalbrowsingmsgs"));
          proj.SetTitle(m_asOwner.GetString(1384, "ptmsgs_portalbrowsingmsgs"));
          cell.AddInnerHTMLElement(proj);
        } else {
          // if we do know the project name, show "<b>Project</b> <name>" where <name> is the link

          proj.AddInnerHTMLString(projName);
          proj.SetTitle(projName);

          cell.AddInnerHTMLString("<b>");
          cell.AddInnerHTMLString(m_asOwner.GetString(1830, "ptmsgs_portalbrowsingmsgs"));
          cell.AddInnerHTMLString("</b>");
          cell.AddInnerHTMLString(SPACE);
          cell.AddInnerHTMLElement(proj);
        }

        // Add a hidden period so screenreaders will pause
        span = new HTMLSpan();
        cell.AddInnerHTMLElement(span);
        span.SetStyleClass(hiddenStyle);
        span.AddInnerHTMLString(DOT);

        cell.AddInnerHTMLElement(new HTMLBr());
      }  // end if project URL is known
    }  // end if Collab result

    else if (app.equals(SearchResultModel.CONTENT_APP)) {

      boolean addedSomething = false;

      // For Content items, add "last published by"
      String pubByUser = _model.GetResultContentLastPubUser(overallRank);

      if (null != pubByUser) {
        cell.AddInnerHTMLString(m_asOwner.GetString(1385, "ptmsgs_portalbrowsingmsgs"));
        cell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(pubByUser));
        cell.AddInnerHTMLString(DOT);
        cell.AddInnerHTMLString(SPACE);
        addedSomething = true;
      }

      // Unlike the non-508 case, we can't show the "go to portlet" or "go to communities" links,
      // since those require Portlet Preview.

      if (addedSomething) {
        cell.AddInnerHTMLElement(new HTMLBr());
      }
    }

    // FOURTH LINE: Description or keyword-in-context (excerpts).
    String kwic = _model.GetKWIC(overallRank);
    if ((null != kwic) && (0 < kwic.length())) {
      cell.AddInnerHTMLElement(formatKWIC(kwic, hiddenStyle, itemLang));
    }

    // Return nothing yet.  See comments at the top of this method.
    return null;
  }

  /** 
   *  Helper method to reformat the KWIC string into a 508 and screenreader-friendly version.
   */
  protected HTMLElement formatKWIC(String kwic, PTStyleClass hiddenStyle, String kwicLang) {

    HTMLElementCollection coll = new HTMLElementCollection();

    final String THREE_DOTS = " ... ";
    final String HELLIP = "&hellip;";

    HTMLSpan langSpan = null;
    if (null != kwicLang) {
      langSpan = new HTMLSpan();
      langSpan.SetLangLocal(kwicLang);
    }

    // If the KWIC appears to be simply the description field, not excerpts from the content field
    if (! XPStringUtility.StartsWith(kwic, THREE_DOTS)) {
      // then we show:
      //  <b>Description</b>.  Description text here.

      coll.AddInnerHTMLString("<b>");
      coll.AddInnerHTMLString(m_asOwner.GetString(1763, "ptmsgs_portalbrowsingmsgs"));   // Description
      coll.AddInnerHTMLString(DOT);
      coll.AddInnerHTMLString("</b>");
      coll.AddInnerHTMLString(SPACE);
      if (null != langSpan) {
        langSpan.AddInnerHTMLString(kwic);
        coll.AddInnerHTMLElement(langSpan);
      } else {
        coll.AddInnerHTMLString(kwic);
      }

      if (! XPStringUtility.EndsWith(kwic, DOT)) {
        // Add a hidden dot so the screenreader will pause
        HTMLSpan span = new HTMLSpan();
        coll.AddInnerHTMLElement(span);
        span.SetStyleClass(hiddenStyle);
        span.AddInnerHTMLString(DOT);
      }
    } else {
      // We turn text like
      //   ... blah blah blah ... blah de blah de blah ...
      // into:
      //   Excerpts.  &hellip;&quot;. blah blah blah .&quot;.&hellip;&quot;. blah de blah de blah &hellip;.&quot;.
      // where the .&quot; bits are in a hidden style (the same color as the background).
      // This is to make the excerpt more screenreader-friendly.. this text gets read as:
      //   "excerpts.  quote.  blah blah blah.  quote.  quote.  blah de blah de blah.  quote."
      // instead of the original, which is much harder to understand aurally:
      //   "dot dot dot blah blah blah dot dot dot blah de blah de blah dot dot dot"

      coll.AddInnerHTMLString("<b>");
      coll.AddInnerHTMLString(m_asOwner.GetString(1764, "ptmsgs_portalbrowsingmsgs"));
      coll.AddInnerHTMLString(DOT);
      coll.AddInnerHTMLString("</b>");
      coll.AddInnerHTMLString(SPACE);

      HTMLElementCollection innerColl = new HTMLElementCollection();

      innerColl.AddInnerHTMLString(HELLIP);
      HTMLSpan span = new HTMLSpan();
      span.SetStyleClass(hiddenStyle);
      span.AddInnerHTMLString("&quot;.");
      innerColl.AddInnerHTMLElement(span);
      innerColl.AddInnerHTMLString(SPACE);

      int pos = 0;
      final int endPos = kwic.length() - THREE_DOTS.length();

      while ((-1 != pos) &&
             (pos < endPos)) {
        pos += THREE_DOTS.length();

        int nextPos = XPStringUtility.IndexOf(kwic, THREE_DOTS, pos);

        if (-1 == nextPos) {
          innerColl.AddInnerHTMLString(XPStringUtility.Substring(kwic, pos));
        } else {
          innerColl.AddInnerHTMLString(XPStringUtility.Substring(kwic, pos, nextPos));
        }

        if (nextPos < endPos) {
          span = new HTMLSpan();
          span.SetStyleClass(hiddenStyle);
          span.AddInnerHTMLString(".&quot;.");
          innerColl.AddInnerHTMLElement(span);
          innerColl.AddInnerHTMLString(HELLIP);
          span = new HTMLSpan();
          span.SetStyleClass(hiddenStyle);
          span.AddInnerHTMLString("&quot;.");
          innerColl.AddInnerHTMLElement(span);
          innerColl.AddInnerHTMLString(SPACE);
        } else {
          innerColl.AddInnerHTMLString(SPACE);
          innerColl.AddInnerHTMLString(HELLIP);
          span = new HTMLSpan();
          span.SetStyleClass(hiddenStyle);
          span.AddInnerHTMLString(".&quot;.");
          innerColl.AddInnerHTMLElement(span);
        }

        pos = nextPos;
      }

      if (null != langSpan) {
        langSpan.AddInnerHTMLElement(innerColl);
        coll.AddInnerHTMLElement(langSpan);
      } else {
        coll.AddInnerHTMLElement(innerColl);
      }
    }

    return coll;
  }

  public void InitDisplayResults()
  {
  }

  private String _LookupLoggingID() {

    if (! (m_asOwner.GetModelExists(LoggingHelperModel.STR_MVC_CLASS_NAME))) {
      return null;
    }

    LoggingHelperModel logHelper = (LoggingHelperModel) m_asOwner.GetModel(LoggingHelperModel.STR_MVC_CLASS_NAME);

    if (null == logHelper) {
      return null;
    }

    return logHelper.GetLoggingID();
  }
}

