package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.admin.objsearch.AdminSearchDP;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.editors.document.*;
import com.plumtree.portalpages.browsing.editors.folder.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.browsing.search.results.assocobjects.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 */
public class GroupedResultsViewHelper implements IGroupedResultsViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.search.results.GroupedResultsViewHelper");

  protected AActivitySpace m_asOwner = null;
  protected ISearchResultModelRO _model = null;
  protected GroupedResultsView _view = null;
  protected SearchPageModeHelper _pageMode = null;

  protected static final String CELL_HEIGHT     = "25";
  protected static final String LOW_CELL_HEIGHT = "20";
  
  private boolean _showSize = false;
  private boolean _allowAnyPopups = false;
  private boolean _preferPopupDocs = false;
  private int _groupsDisplayed = 0;

  protected XPDateFormat _dateFormat = null;
  public static final String HTMLFORM_NAME = "ReorganizeResults";
  public static final String IN_CB_MASTER = "in_cb_master";
  public static final String DOC_FOLDER_INPUT = "in_cb_folder";
  public static final String DOC_INPUT = "in_cb_document";
  public static final int MULTIFOLDER_CODE = -2;

  
  protected XPStringBuilder checkBoxScriptBuilder;
  

	/*
	 */
	public GroupedResultsViewHelper(SearchPageModeHelper pageMode)
	{
	    _pageMode = pageMode;
	}

  public void Init(AActivitySpace owner,
                   ISearchResultModelRO model,
                   GroupedResultsView view) {
    m_asOwner = owner;
    _model = model;
    _view = view;

    _dateFormat = _model.GetDateFormat(m_asOwner);
  }

  /**
   *  Helper method to format path string in a friendly way
   */
  public String formatPath(String path)
  {
    final int MAX_LENGTH = 100;
    int len         = path.length();

    if (len < MAX_LENGTH)
    {
      return path;
    }
    else
    {
      return "... " + path.substring(len - MAX_LENGTH);
    }
  }

  /**
   *  Helper method to format size string in a friendly way
   */
  public String formatSize(int sizeInBytes)
  {
    if (sizeInBytes < 500)
    {
      return XPConvert.ToString(sizeInBytes);
    }

    double kb = sizeInBytes / 1024;

    if (kb < 500)
    {
      kb = ((int) (kb * 10)) / 10;

      return XPResourceManager.FormatMessage(m_asOwner.GetString(833,
          "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(kb));
    }

    double mb = kb / 1024;

    mb = ((int) (mb * 10)) / 10;

    return XPResourceManager.FormatMessage(m_asOwner.GetString(834,
        "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(mb));
  }

  /**
   *  Returns javascript for the view.
   */
  public HTMLScript DisplayJavascript() {
    if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD) return null;

    HTMLScript s = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

    XPStringBuilder collabSB = new XPStringBuilder(1024);

    collabSB.Append("function collabPopUpHelper (url, width, height, properties, windowName) {\n");
    collabSB.Append("\n");
    collabSB.Append("    width = (width) ? new String(width) : '90%';\n");
    collabSB.Append("    height = (height) ? new String(height) : '85%';\n");
    collabSB.Append("\n");
    collabSB.Append("    var idealWidth = 1200;\n");
    collabSB.Append("    var idealHeight = 870;\n");
    collabSB.Append("\n");
    collabSB.Append("    if (width.indexOf('%') > 0) {\n");
    collabSB.Append("        var percentValue = width.substring(0,width.indexOf('%'));\n");
    collabSB.Append("        var percentWidth = Math.floor(screen.availWidth * (percentValue / 100));\n");
    collabSB.Append("\n");
    collabSB.Append("        // Use idealWidth unless user has a small monitor, in which case use percentWidth\n");
    collabSB.Append("        width = Math.min(percentWidth, idealWidth);\n");
    collabSB.Append("    }\n");
    collabSB.Append("\n");
    collabSB.Append("    if (height.indexOf('%') > 0) {\n");
    collabSB.Append("        var percentValue = height.substring(0,height.indexOf('%'));\n");
    collabSB.Append("        var percentHeight = Math.floor(screen.availHeight * (percentValue / 100));\n");
    collabSB.Append("\n");
    collabSB.Append("        // Use idealHeight unless user has a small monitor, in which case use percentHeight\n");
    collabSB.Append("        height = Math.min(percentHeight, idealHeight);\n");
    collabSB.Append("    }\n");
    collabSB.Append("\n");
    collabSB.Append("    var x = (screen.availWidth - parseInt(width)) / 2;\n");
    collabSB.Append("    var y = (screen.availHeight - parseInt(height)) / 2;\n");
    collabSB.Append("\n");
    collabSB.Append("    windowName = (windowName) ? windowName : '_blank';\n");
    collabSB.Append("\n");
    collabSB.Append("    var browserProperties = (properties) ? properties : 'status=no,toolbar=no,location=no,menu=no,resizable=yes,scrollbars=yes';\n");
    collabSB.Append("    browserProperties += ',width=' + width + ',left=' + x + ',height=' + height + ',top=' + y;\n");
    collabSB.Append("\n");
    collabSB.Append("    window.open(url,windowName,browserProperties);\n");
    collabSB.Append("\n");
    collabSB.Append("    return false;\n");
    collabSB.Append("}\n");
    collabSB.Append("\n");
    collabSB.Append("function collabPopUp(url) {\n");
    collabSB.Append("    var properties = 'status=no,toolbar=no,location=no,menu=no,resizable=yes,scrollbars=yes';\n");
    collabSB.Append("    collabPopUpHelper(url, '90%', '85%', properties, 'appViewWindow');\n");
    collabSB.Append("    return false;\n");
    collabSB.Append("}\n");

    s.AddInnerHTMLString(collabSB.ToString());

    s.AddInnerHTMLString("function contentPopUp(url) { var dummy = window.open(url,'contentPopupWindow','status=no,toolbar=no,location=no,menu=no,resizable=yes,scrollbars=yes,width=600,height=550'); return false;  }\n");

	// Bug fix 10269455 - SEARCH RESULTS PAGE(EDIT MODE), TOP LEVEL CHECKBOX FUNCTIONALITY NOT FINE
    // Delaying the DoToggleAll js function from being written into the code before the page fully loads,
    // one exception to this is if we are conducting an admin search with a subportal that doesn't support
    // adaptive layouts, in this case, the js function will be added to the HTMLElement.

    IPTSession currentSession = (IPTSession) m_asOwner.GetUserSession();

    // Check to see if we're coming from the Admin search and make sure layouts aren't enabled
    if ( m_asOwner.GetCurrentPage().GetName().equals(AdminSearchDP.STR_MVC_CLASS_NAME) 
    		&& !(currentSession.GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetLayoutEnabled()))
    {
    	if(_pageMode.ShowToolbar())
    	{
    		XPStringBuilder sb = new XPStringBuilder(200);
    		sb.Append("function DoToggleAll(group)\n");
    		sb.Append("{\n");			
    		sb.Append("    var fElem = document.mainform;\n");
    		sb.Append("    var feLen = fElem.elements.length;\n");
    		sb.Append("    var checkVal = false;\n");
    		sb.Append("    for (var i = 0; i < feLen; i++) {\n");
    		sb.Append("        if (fElem.elements[i].name == '" + IN_CB_MASTER + "' && fElem.elements[i].value == group) {\n");
    		sb.Append("            checkVal = fElem.elements[i].checked;\n");
    		sb.Append("        }\n");
    		sb.Append("    }\n");
    		sb.Append("    for (var i = 0; i < feLen; i++) {\n");
    		sb.Append(GetCheckBoxScriptBuilder().ToString());
    		//sb.Append("    	   if (fElem.elements[i].name == '" + ObjMgrFolderViewHelper.QS_CHECKBOX + "') {\n");
    		//sb.Append("            fElem.elements[i].checked = checkVal;\n");
    		//sb.Append("        }\n");
    		//sb.Append("    	   if (fElem.elements[i].name.indexOf('" + ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + "') != -1) {\n");
    		//sb.Append("            fElem.elements[i].checked = checkVal;\n");
    		//sb.Append("        }\n");
    		sb.Append("    }\n");
    		sb.Append("    return true;\n"); 
    		sb.Append("}\n"); 
    		s.AddInnerHTMLString(sb.ToString());
    	}
    }

    return s;
  }

  /**
   *  Returns the element that all other elements will be added to,
   *  such as an HTMLTable.  If null is returned, a generic
   *  HTMLElementCollection will be used.
   */
  public HTMLElement DisplayCollection()
  {

    // If no results were returned, don't display anything.
    if (0 == _model.GetTotalItems()) {
      return null;
    }

    // Initialize some member variables..

    _groupsDisplayed = 0;

    // Don't allow popups if we're making editor links; we don't want
    // editors to come up in a popup.
    _allowAnyPopups = (! _pageMode.GetMakeEditLinks());

    // Initialize _preferPopupDocs from the preference PersonalSettingNames.OPEN_DOC_NEW_WINDOW.
    // If it's "1", then we want to open docs in a new window.
    {
      Object[][] setting =
        (Object[][]) ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().LookupPreference(PersonalSettingNames.OPEN_DOC_NEW_WINDOW, 0);
      if (null != setting) {
        Object o = setting[1][0];
        if (null != o) {
          if ((XPConvert.ToString(o)).equals("1")) {
            _preferPopupDocs = true;
          }
        }
      }
    }

    // Check whether we need to show the "size" column.
    int numGroups = _model.GetNumResultGroups();
    if (numGroups > 0)
    {
      for (int grp = 0; grp < numGroups; grp++)
      {
        int numDisplayed = _model.GetReturnedResultsInGroup(grp);

        for (int j = 0; j < numDisplayed; j++)
        {
          int rank = _model.GetResultRank(grp, j);

          if (_model.GetResultSize(rank) > 0)
          {
            _showSize = true;
            break;
          }
        }
      }
    }
    else
    {
      int numResults = _model.GetNumDisplayableItems();

      for (int j = 0; j < numResults; j++)
      {
        if (_model.GetResultSize(j) > 0)
        {
          _showSize = true;

          break;
        }
      }
    }

    // Finally, construct the table in which the results will go
    HTMLTable resultTable = new HTMLTable();

    resultTable.SetCellSpacing("2");
    resultTable.SetCellPadding("3");
    resultTable.SetWidth("100%");

    return resultTable;
  }

  /**
   *  Returns an element that will appear before all results, whether
   *  or not the results are grouped.
   */
  public HTMLElement DisplayHeader()
  {
    // Not needed
    return null;
  }

  /**
   *  Returns an element that will appear after all results regardless
   *  of whether the results are grouped.
   */
  public HTMLElement DisplayFooter()
  {
    // Not needed
    return null;
  }

  /**
   *  Returns the header element (e.g. an HTMLTableRow containing column
   *  headings) that will be used if the results are not grouped.  Not called
   *  if the results are grouped.
   */
  public HTMLElement DisplayHeaderIfUngrouped()
  {
    return GetHeaderRow(0);
  }

  /**
   *  Returns an element that will appear after all results if the results
   *  are not grouped.  Not called if the results are grouped.
   */
  public HTMLElement DisplayFooterIfUngrouped()
  {
    // Not needed
    return null;
  }

  /**
   *  Returns the header element (e.g. an HTMLTableRow containing column
   *  headings) that will be used if the results are grouped.  Not called
   *  if the results are ungrouped.
   */
  public HTMLElement DisplayGroupHeader(int groupNum)
  {
	int colSpan = 5;
	if(_showSize) 
		colSpan++;
	if(_pageMode.IsAdminMode()) 
		colSpan++;
	if(_pageMode.IsEditMode())
		colSpan++;
	
    HTMLElement he = _view.DisplayStandardGroupHeaderRow(groupNum,
                                                         CELL_HEIGHT,
                                                         XPConvert.ToString(colSpan), false);

    if (null == he) {
      // Nothing in this group
      return null;
    }

    HTMLElementCollection c = new HTMLElementCollection();

    {
      // Add a blank row to separate groups

      HTMLTableRow row = new HTMLTableRow();
      HTMLTableCell cell = new HTMLTableCell();
      cell.SetColSpan(_showSize ? "5" : "4");
      if (0 == _groupsDisplayed) {
        cell.SetHeight("5");
      } else {
        cell.SetHeight("15");
      }
      row.AddInnerHTMLElement(cell);
      c.AddInnerHTMLElement(row);
    }

    c.AddInnerHTMLElement(he);

    // Add the column headings for this group too
    c.AddInnerHTMLElement(GetHeaderRow(groupNum));

    _groupsDisplayed += 1;

    return c;
  }

  /**
   *  Returns an element that will appear after all results in a single group.
   *  Not called if the results are ungrouped.
   */
  public HTMLElement DisplayGroupFooter(int groupNum)
  {
    // Not needed
    return null;
  }
  
  public static final String FELEM_ELEMENTS = "fElem.elements[i]";
  
  protected void AddCheckBoxScript(String value, String name, int groupNum, XPStringBuilder script)
  {
	script.Append("        if (group == " + groupNum + " && " + FELEM_ELEMENTS + ".value == '" + value + "' && " + FELEM_ELEMENTS + ".name == '" + name + "') {\n");
	script.Append("             " + FELEM_ELEMENTS + ".checked = checkVal;\n");
	script.Append("        }\n");

  }
  /**
   *  Returns the header element (e.g. an HTMLTableRow) headings) for a single
   *  search result.
   */
  public HTMLElement DisplaySingleResult(int resultNum, boolean oddRow, int groupNum)
  {

    // Create a table row
    HTMLTableRow row = new HTMLTableRow();

    if (oddRow)
    {
      row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
    }
    else
    {
      row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
    }

    // Add cells for the rank, type, name, last-modified, size, and action list
    // rank
    // (note PTSearch ranks are 0-based)
    HTMLTableCell cell;
    boolean objectIsAdminFolder = false;
    boolean suppressNameLink = false;

    String app2  = _model.GetResultApp(resultNum);

    // We will need to know if the card has more than one folder
    // in several places further down in this call, so calculating
    // it only once to improve performance.
    boolean bIsCardAndHasMoreThanOneFolder = false;
	if(app2.equals(SearchResultModel.PORTAL_APP) && _model.GetResultClassID(resultNum) == PT_CLASSIDS.PT_CATALOGCARD_ID)
		bIsCardAndHasMoreThanOneFolder = CardHasMoreThanOneFolder(resultNum);

    boolean objectDeleted = false;
    // Only check if the object has been deleted if we're in the portal and we're
    // in edit mode.  Browse mode results don't change based on deletion, so we
    // don't need to query.  Actually, the object link should be disabled, but it wasn't,
    // and if we don't query we won't know to suppress the object properties link.
    // This is acceptable, so we are removing the query in browse mode.  I also fixed it
    // so that if we did query, it would disable the object link.
    if (app2.equals(SearchResultModel.PORTAL_APP) && (!_pageMode.IsBrowseMode())) {
    	// This causes 1 DB query to be made per object (10 per page), so we should avoid
    	// calling this method if we can.
      objectDeleted = ObjectHasBeenDeleted(_model.GetResultObjectID(resultNum),
                                           _model.GetResultClassID(resultNum),
                                           _model.GetResultFolderID(resultNum));
    }

	//TODO: Get rid of this once we have auto-index on delete.
	suppressNameLink = objectDeleted;

    // TODO: When admin folder and card's get reindexed automatically, get rid of this var.
	String calculatedFolderPath = null;
	if(_pageMode.ShowToolbar())
	{
		cell = new HTMLTableCell();
		cell.SetWidth("25");
		cell.SetVAlign("top");
		cell.SetAlign("middle");
		// Add check-all checkbox
		HTMLInput cb;
		int objID = _model.GetResultObjectID(resultNum);
		int folderID = _model.GetResultFolderID(resultNum);
		int classID = _model.GetResultClassID(resultNum);
		String app =  _model.GetResultApp(resultNum);
		boolean nonPortalObject = (! app.equalsIgnoreCase("ptportal"));

		String cb_name;
		if(ObjectIsFolder(classID))
		{
			objectIsAdminFolder = ObjectIsAdminFolder(classID);
			if(objectIsAdminFolder)
				calculatedFolderPath = GetAdminFolderPath(objID);
			else
				calculatedFolderPath = GetFolderPath(objID);

			cb_name = (objectIsAdminFolder)? ObjMgrFolderViewHelper.QS_CHECKBOX : DOC_FOLDER_INPUT;
			cb = new HTMLInput(HTMLInputTypes.CHECKBOX,cb_name,"","");
			String value = XPConvert.ToString(objID);
			cb.SetValue(value);
			AddCheckBoxScript(value, cb_name, groupNum, GetCheckBoxScriptBuilder());
		}
		else if (classID == PT_CLASSIDS.PT_CATALOGCARD_ID)
		{
			cb_name = DOC_INPUT;
			int realFolderID = bIsCardAndHasMoreThanOneFolder ? MULTIFOLDER_CODE : GetFolderIDForCard(objID);

			calculatedFolderPath = GetFolderPath(realFolderID);

			// Cards
			cb = new HTMLInput(HTMLInputTypes.CHECKBOX,cb_name,"","");
			String value = XPConvert.ToString(objID) + "," + XPConvert.ToString(realFolderID);
			cb.SetValue(value);
			AddCheckBoxScript(value, cb_name, groupNum, GetCheckBoxScriptBuilder());
		}
		else if (classID == PT_CLASSIDS.PT_COMMUNITY_ID)
                {
                  // Any operation on a community actually needs to be done on its community folder instead;
                  // this is always just the folder we've got in folderID now.  See bug 31385.
                  cb_name = ObjMgrFolderViewHelper.QS_CHECKBOX;
                  cb = new HTMLInput(HTMLInputTypes.CHECKBOX, cb_name, "", "");
                  String value = XPConvert.ToString(folderID);
                  cb.SetValue(value);
                  cb.SetOnClick(ObjMgrHeaderView.JAVASCRIPT_COMMUNITY_SELECTED 
				   				+ "(this, 1); return true;");
                  AddCheckBoxScript(value, cb_name, groupNum, GetCheckBoxScriptBuilder());
                }
		else
		{
			cb_name = ObjMgrViewHelper.HTML_OBJECT_CHECKBOX_PREFIX + XPConvert.ToString(classID) + "_ID";
			cb = new HTMLInput(HTMLInputTypes.CHECKBOX,cb_name,"","");
			String value = XPConvert.ToString(objID) + "," + XPConvert.ToString(folderID);
			cb.SetValue(value);
			AddCheckBoxScript(value, cb_name, groupNum, GetCheckBoxScriptBuilder());
		}

		//TODO: Get rid of this once we have auto-index on delete.
		suppressNameLink = suppressNameLink || SuppressEditLinkForClass(classID);

		cb.SetDisabled(objectDeleted || nonPortalObject);		
		cb.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		cell.AddInnerHTMLElement(cb);
		row.AddInnerHTMLElement(cell);
	}
	cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetHeight(CELL_HEIGHT);
    cell.SetAlign("center");
    cell.SetVAlign("top");

    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(XPConvert.ToString(resultNum + _model.GetFirstDisplayableItem()));

    // Add the "is best bet" flag under the rank
    if (_model.isResultBestBet(resultNum))
    {
      cell.AddInnerHTMLElement(new HTMLBr());

      HTMLSpan mySpan = new HTMLSpan();
      mySpan.SetStyleClass(PTStyleClass.LIST_TEXT);
      mySpan.AddInnerHTMLString("<i>");

      mySpan.AddInnerHTMLString(m_asOwner.GetString(828,
          "ptmsgs_portalbrowsingmsgs"));
      mySpan.AddInnerHTMLString("</i>");
      cell.AddInnerHTMLElement(mySpan);

      // Also, turn the row background yellow for Best Bets
      row.SetStyleClass(PTStyleClass.ALERT_BG);
    }

    // type icon
    cell = new HTMLTableCell();
    cell.SetAlign("center");
	cell.SetVAlign("top");
	cell.SetWidth("20");
    row.AddInnerHTMLElement(cell);

    HTMLImg icon = (HTMLImg) _model.GetResultIcon(resultNum);

    if (null != icon)
    {
      icon.SetAlign("absmiddle");
      icon.SetBorder("0");
      cell.AddInnerHTMLElement(icon);
    }
    else
    {
      cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
    }

    // name
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
	cell.SetVAlign("top");

    //    cell.SetNoWrap(true);
    row.AddInnerHTMLElement(cell);

    // Make a clickthru URL.

    String resultName    = XPHttpUtility.HtmlEncode(_model.GetResultName(
          resultNum));

    String extraClickthroughParams = null;
    
    //RaviT - bug 8602119 - If Friendly URLs for search are enabled then we don't add qid and rank to search result 
    // item url. Since this would disrupt Friendly url format and also doing a search triggers a qid by Analytics api and
    // it gets tracked by Analytics but not clicking through a Search Result Item, So both rank and qid are not needed,
    // in search result url.
    if(!TaskAPIUICommon.UseFriendlyURLS(FriendlyURLConstants.FRIENDLY_SEARCH_ID)){
    	String loggingID = _LookupLoggingID();
        if (null != loggingID) {
          extraClickthroughParams = "qid=" + loggingID + "&rank=" + XPConvert.ToString(resultNum+1);
        }
    }
    

    HTMLAnchor clickthru = null;
	HTMLB resultNameBold = new HTMLB();
	resultNameBold.AddInnerHTMLString(resultName);
	
	if(!suppressNameLink)
	{

	    if ((app2.equals(SearchResultModel.TEMPLATING_APP)) &&
	        (! _pageMode.GetMakeEditLinks())) {
	      // Special case: for Community Templating items, clickthrough should go to
	      // a popup with a list of communities on which the associated portlet is
	      // used, as in portlet preview.

              int[] portletIDs = _model.GetResultContentPortletIDs(resultNum);

              int portletId = 0;

              // "Templating" items were only indexed by pre-6.0 versions of Content Server
              // (although they could potentially still be in a search index), which would
              // associate only one portlet with each item.  So, we're basically guaranteed
              // to have exactly one item in the portletIDs array, but we might as well
              // be safe:
              if ((null != portletIDs) && (portletIDs.length > 0)) {
                portletId = portletIDs[0];
              }
	
	      ASURL templatingURL = new ASURL(m_asOwner);
	      templatingURL.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME,
	                                          m_asOwner);
	      templatingURL.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
	      templatingURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
	      templatingURL.AddControlArgument(PreviewPortletControl.m_PreviewType,
	          PreviewPortletModel.SEARCHHEADER);
	      templatingURL.AddControlArgument(PreviewPortletControl.m_strPortletParam,
	          XPConvert.ToString(portletId));
	      templatingURL.AddControlArgument(PreviewPortletControl.m_strAlwaysCommunity, "y");
	
	      clickthru = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
	      clickthru.SetOnClick("contentPopUp('" +	// mj: removed 'javascript:' from function name
	                           templatingURL.GetURLAsString() + "'); return false;");
	    } 
	    else 
	    {
              // Otherwise, just use the standard clickthrough
              clickthru = _model.GetResultClickthroughURL(resultNum, _allowAnyPopups, _pageMode.GetMakeEditLinks(), extraClickthroughParams);
	    }
    	clickthru.AddInnerHTMLElement(resultNameBold);
    	clickthru.SetTitle(resultName);
    	cell.AddInnerHTMLElement(clickthru);
		String absType = _model.GetResultAbsType(resultNum);

		// Collab documents always appear in a new window.
		// Other docs appear in a popup if a preference is set (we've already
		// initialized _preferPopupDocs with the value of this pref).

		// If it's a document
		if ((null != absType) && 
			(absType.equals(SearchResultModel.DOCUMENT_ABSTYPE))) {

		  if (_preferPopupDocs ||
			  app2.equals(SearchResultModel.COLLAB_APP)) {

			// set target=_blank

			clickthru.SetTarget("_blank");
		  }
		} else {
		  if (app2.equals(SearchResultModel.COLLAB_APP)) {

			// For non-document Collab items, use javascript to open a popup

			// Get the original gatewayed href
			String clickthruURL = clickthru.GetHRef();
			clickthru.SetHRef(ConstructStaticHelpers.BLANK_URL);
			clickthru.SetOnClick("collabPopUp('" + clickthruURL + "'); return false;");	// mj: removed 'javascript:' from function name
		  }
		}
	}
	else
	{
			// Suppressing the link entirely, just include the name.
		cell.AddInnerHTMLElement(resultNameBold);
	}

    // Add the keyword-in-context (KWIC) information to the same cell
    String kwic = _model.GetKWIC(resultNum);

    if ((null == kwic) || (0 == kwic.length()))
    {
        kwic = "<i>" + m_asOwner.GetString(832, "ptmsgs_portalbrowsingmsgs") + "</i>";
    }

    cell.AddInnerHTMLElement(new HTMLBr());

    HTMLSpan span = new HTMLSpan();
    span.SetStyleClass(PTStyleClass.LIST_TEXT);

    // Note that the Search server htmlencodes the KWIC for us
    span.AddInnerHTMLString(kwic);

    // If available, add the "Properties" link within the same span
    if ((!_pageMode.GetMakeEditLinks()) && (! objectDeleted))
    {
      HTMLAnchor propertiesURL = _model.GetResultPropertiesURL(resultNum, /*popup=*/ true);

      if (null != propertiesURL)
      {
        if (!kwic.endsWith(" "))
        {
          span.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        }

        // If a card that has more than one folder
        if (bIsCardAndHasMoreThanOneFolder)
        {
          // use the string "Properties and Folders" for the properties popup clickthru
          propertiesURL.AddInnerHTMLString(m_asOwner.GetString(1666, "ptmsgs_portalbrowsingmsgs"));
        } 
        else 
        {
          // else just use the string "Properties"
          propertiesURL.AddInnerHTMLString(m_asOwner.GetString(829, "ptmsgs_portalbrowsingmsgs"));
        }

        propertiesURL.SetTitle(m_asOwner.GetString(1657,
            "ptmsgs_portalbrowsingmsgs"));
        span.AddInnerHTMLElement(propertiesURL);
      }
    }

    cell.AddInnerHTMLElement(span);

    cell.AddInnerHTMLElement(new HTMLBr());

    // Add the path to the same cell, if:
    //  - this is a portal item, AND
    //    - we're making edit links (make the path a link to the ObjectManager,
    //      displaying the folder in which the item appears), OR
    //    - this is a catalog card or folder; if the user can see a card, he or
    //      she definitely can see its folder as well
    if (app2.equals(SearchResultModel.PORTAL_APP))
    {
      int subtype       = _model.GetResultClassID(resultNum);
      boolean isCard = (subtype == PT_CLASSIDS.PT_CATALOGCARD_ID);
      boolean isDocDirItem = ( isCard || (subtype == PT_CLASSIDS.PT_CATALOGFOLDER_ID));

      if (isDocDirItem || _pageMode.GetMakeEditLinks())
      {
        String path  = (calculatedFolderPath != null) ? calculatedFolderPath : _model.GetResultPath(resultNum);
        int folderID = _model.GetResultFolderID(resultNum);
        if(isCard && folderID != 0 && bIsCardAndHasMoreThanOneFolder)
        	folderID = 0;

        if ((PT_CLASSIDS.PT_CATALOGFOLDER_ID == subtype) ||
            (PT_CLASSIDS.PT_ADMIN_FOLDER_ID == subtype))
        {
          // for folders, the folder ID for path clickthru is just the object ID
          folderID = _model.GetResultObjectID(resultNum);
        }

        if ((null != path) && (path.length() > 0) && (folderID > 0))
        {
          path = formatPath(path);

          ASURL pathURL = new ASURL(m_asOwner);

          if (isDocDirItem)
          {
            pathURL.SetLinkCreateNewSpace(DirAS.STR_MVC_CLASS_NAME,
              m_asOwner);
            pathURL.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
            pathURL.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
              XPConvert.ToString(folderID));
              if(_pageMode.IsEditMode())
            	pathURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
              		XPConvert.ToString(DirConstants.EDIT_MODE));
              else
				pathURL.AddControlArgument(DirConstants.QS_DIRECTORY_MODE,
					XPConvert.ToString(DirConstants.BROWSE_MODE));
             
          }
          else
          {
            pathURL.SetLinkCreateNewSpace(ObjMgrAS.STR_MVC_CLASS_NAME,
              m_asOwner);
            pathURL.SetControl(ObjMgrSettingsControl.STR_MVC_CLASS_NAME);
            pathURL.AddControlArgument(ObjMgrSettingsControl.FOLDER_ID,
              XPConvert.ToString(folderID));
            pathURL.AddControlArgument(ObjMgrSettingsControl.OBJECT_IDS,
              XPConvert.ToString(subtype));
          }

          pathURL.AddInnerHTMLString(XPHttpUtility.HtmlEncode(path));

          span = new HTMLSpan();
          span.SetStyleClass(PTStyleClass.LIST_TEXT);
          span.AddInnerHTMLElement(pathURL.GetURLAsHTMLElement());
          cell.AddInnerHTMLElement(span);
        }
      }
    }
    else if (app2.equals(SearchResultModel.COLLAB_APP))
    {
      // For Collab items, add a "Go to project" link
      String projectURL = _model.GetResultCollabProjectURL(resultNum);

      if (null != projectURL)
      {
        // make a span for the project link
        span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.LIST_TEXT);
        cell.AddInnerHTMLElement(span);

        HTMLAnchor proj = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        proj.SetOnClick("collabPopUp('" + projectURL + "'); return false;");	// mj: removed 'javascript:' from function name

        String projName = _model.GetResultCollabProjectName(resultNum);

        if (null == projName) {
          // if project name unknown, use "Go to Project" as the link
          proj.AddInnerHTMLString(m_asOwner.GetString(1380, "ptmsgs_portalbrowsingmsgs"));
          proj.SetTitle(m_asOwner.GetString(1380, "ptmsgs_portalbrowsingmsgs"));

          span.AddInnerHTMLElement(proj);
        } else {
          // if we do know the project name, show "Project: <name>" where <name> is a link

          proj.AddInnerHTMLString(projName);
          proj.SetTitle(projName);

          span.AddInnerHTMLString(m_asOwner.GetString(1830, "ptmsgs_portalbrowsingmsgs"));
          span.AddInnerHTMLString(": ");
          span.AddInnerHTMLElement(proj);
        }
      }
    }
    else if (app2.equals(SearchResultModel.CONTENT_APP))
    {
      // For Content items, add "last published by" and "view associated objects"
      String pubByUser = _model.GetResultContentLastPubUser(resultNum);

      if (null != pubByUser)
      {
        span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.LIST_TEXT);

        span.AddInnerHTMLString(m_asOwner.GetString(1381, "ptmsgs_portalbrowsingmsgs"));
        span.AddInnerHTMLString(XPHttpUtility.HtmlEncode(pubByUser));
        cell.AddInnerHTMLElement(span);

        cell.AddInnerHTMLElement(new HTMLBr());
      }

      int portletIds[] = _model.GetResultContentPortletIDs(resultNum);
      if ((null != portletIds) && (0 < portletIds.length)) {

        HTMLAnchor associatedObjects = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        associatedObjects.AddInnerHTMLString(m_asOwner.GetString(1867, "ptmsgs_portalbrowsingmsgs"));

        ASURL assocObjectsURL = new ASURL(m_asOwner);
        assocObjectsURL.SetLinkCreateNewSpace(AssociatedObjectsAS.STR_MVC_CLASS_NAME, m_asOwner);
        assocObjectsURL.SetDisplayPage(AssociatedObjectsPopupDP.STR_MVC_CLASS_NAME);
        assocObjectsURL.SetControl(AssociatedObjectsControl.STR_MVC_CLASS_NAME);
        assocObjectsURL.AddControlArgument(AssociatedObjectsControl.ITEM_NAME_ARGNAME,
                                           _model.GetResultName(resultNum));

        String[] strPortletIds = new String[portletIds.length];
        for (int j = 0; j < portletIds.length; j++) {
          strPortletIds[j] = XPConvert.ToString(portletIds[j]);
        }
        assocObjectsURL.AddControlArgument(AssociatedObjectsControl.PORTLET_LIST_ARGNAME, strPortletIds);

        associatedObjects.SetOnClick("contentPopUp('" + assocObjectsURL.GetURLAsString() + "'); return false;");

        span = new HTMLSpan();
        span.SetStyleClass(PTStyleClass.LIST_TEXT);
        span.AddInnerHTMLElement(associatedObjects);
        cell.AddInnerHTMLElement(span);
      }
    }

    // modified date
    cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.LIST_TEXT);
    cell.SetNoWrap(true);
	cell.SetVAlign("top");
    row.AddInnerHTMLElement(cell);
    cell.AddInnerHTMLString(_dateFormat.Format(_model.GetResultLastModified(
          resultNum)));

    // size
    if (_showSize)
    {
      cell = new HTMLTableCell();
      cell.SetStyleClass(PTStyleClass.LIST_TEXT);
	  cell.SetVAlign("top");
      row.AddInnerHTMLElement(cell);

      int resultSize        = _model.GetResultSize(resultNum);
      String resultSizeString = "";

      if (resultSize >= 0)
      {
        resultSizeString = formatSize(resultSize);
      }

      cell.AddInnerHTMLString(resultSizeString);
    }
	if(_pageMode.IsAdminMode())
	{
		cell = new HTMLTableCell();
		cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		cell.SetNoWrap(true);
		cell.SetVAlign("top");
		row.AddInnerHTMLElement(cell);
		cell.AddInnerHTMLString(_dateFormat.Format(_model.GetResultCreated(resultNum)));
	}
	
	// Add pencil (edit) icon links to last cell.
	if(_pageMode.IsEditMode())
	{
		cell = new HTMLTableCell();
		cell.SetStyleClass(PTStyleClass.LIST_TEXT);
		cell.SetNoWrap(true);
		cell.SetVAlign("top");
		cell.SetWidth("25");
		
		int classID = _model.GetResultClassID(resultNum);
		int objID = _model.GetResultObjectID(resultNum);
		if(classID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
		{		
			ASURL url = new ASURL(m_asOwner);
			url.SetLinkCreateNewSpace(FolderEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
			url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID));
			url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
				XPConvert.ToString(objID));
			HTMLAnchor a = new HTMLAnchor(url.GetURLAsString());
			HTMLImg myEditItemImg = (HTMLImg) PTImageType.ICON_EDIT.GetHTMLElement();
			myEditItemImg.SetAlt(m_asOwner.GetString(111,"ptmsgs_portalbrowsingmsgs"));
			a.AddInnerHTMLElement(myEditItemImg);
			cell.AddInnerHTMLElement(a);
		}
		else if (classID == PT_CLASSIDS.PT_CATALOGCARD_ID)
		{
			ASURL url = new ASURL(m_asOwner);
			url.SetLinkCreateNewSpace(CardEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
			url.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			url.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				XPConvert.ToString(EditorStartControl.EDITOR_START_FLAG_EDIT));
			url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID));
			url.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_OBJECT_ID,
				XPConvert.ToString(objID));
			HTMLAnchor a = new HTMLAnchor(url.GetURLAsString());
			HTMLImg myEditItemImg = (HTMLImg) PTImageType.ICON_EDIT.GetHTMLElement();
			myEditItemImg.SetAlt(m_asOwner.GetString(111,"ptmsgs_portalbrowsingmsgs"));
			a.AddInnerHTMLElement(myEditItemImg);
			cell.AddInnerHTMLElement(a);
			
		}
		else
		{
			HTMLAnchor a = _model.GetResultEditLink(resultNum, false); //_allowAnyPopups); 
			HTMLImg myEditItemImg = (HTMLImg) PTImageType.ICON_EDIT.GetHTMLElement();
			myEditItemImg.SetAlt(m_asOwner.GetString(111,"ptmsgs_portalbrowsingmsgs"));
			a.AddInnerHTMLElement(myEditItemImg);
			cell.AddInnerHTMLElement(a);

		}
		row.AddInnerHTMLElement(cell);		
	}


    return row;
  }

  /**
   *  Helper function, returns the standard column headings
   */
  private HTMLTableRow GetHeaderRow(int group)
    throws SearchModelException, HTMLException {

    // Column headers
    HTMLTableRow row = new HTMLTableRow();
    row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);

    // "Rank"
    HTMLTableCell cell;
    
	if(_pageMode.ShowToolbar())
	{
		cell = new HTMLTableCell();
		// Add check-all checkbox
		HTMLInput masterCheck = new HTMLInput(HTMLInputTypes.CHECKBOX,IN_CB_MASTER,"","");
		masterCheck.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		
		int numResults = _model.GetReturnedResultsInGroup(group);
		int numComm = 0;
		for (int j = 0; j < numResults; j++) {
			int overallRank = (group > 0) ? _model.GetResultRank(group, j) : j;
			if (_model.GetResultClassID(overallRank) == PT_CLASSIDS.PT_COMMUNITY_ID) {
				numComm++;
			}
		}
		masterCheck.SetOnClick("DoToggleAll(" + group + "); " + ObjMgrHeaderView.JAVASCRIPT_COMMUNITY_SELECTED 
			+ "(this, " + numComm + ");");
		masterCheck.SetValue(XPConvert.ToString(group));
		cell.AddInnerHTMLElement(masterCheck);
		row.AddInnerHTMLElement(cell);
	}
	cell = new HTMLTableCell();
    cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
    cell.SetHeight(LOW_CELL_HEIGHT);
    cell.SetAlign("center");
    //cell.SetWidth("20");
    cell.SetNoWrap(true);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(823,
        "ptmsgs_portalbrowsingmsgs"));

    cell = new HTMLTableCell();
	cell.SetNoWrap(true);
    cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
    cell.SetColSpan("2");
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(825,
        "ptmsgs_portalbrowsingmsgs"));

    cell = new HTMLTableCell();
	cell.SetNoWrap(true);
    cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
    row.AddInnerHTMLElement(cell);

    cell.AddInnerHTMLString(m_asOwner.GetString(826,
        "ptmsgs_portalbrowsingmsgs"));

    if (_showSize)
    {
      cell = new HTMLTableCell();
	  cell.SetNoWrap(true);
      cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
      row.AddInnerHTMLElement(cell);

      cell.AddInnerHTMLString(m_asOwner.GetString(827,
          "ptmsgs_portalbrowsingmsgs"));
    }
    
	if(_pageMode.IsAdminMode())
	{
		cell = new HTMLTableCell();
		cell.SetNoWrap(true);
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		row.AddInnerHTMLElement(cell);

		cell.AddInnerHTMLString(m_asOwner.GetString(2551,
			"ptmsgs_portaladminmsgs"));

	}
	if(_pageMode.IsEditMode())
	{
		cell = new HTMLTableCell();
		cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		row.AddInnerHTMLElement(cell);		
	}

    return row;
  }
    
  public void InitDisplayResults()
  {
	GetCheckBoxScriptBuilder().SetLength(0);
  }
  
  public XPStringBuilder GetCheckBoxScriptBuilder()
  {
	if(checkBoxScriptBuilder == null)
		checkBoxScriptBuilder = new XPStringBuilder();
	return 	checkBoxScriptBuilder;
  }
  
  public boolean ObjectIsFolder(int classID)
  {
	return ((classID == PT_CLASSIDS.PT_ADMIN_FOLDER_ID ||
  			 classID == PT_CLASSIDS.PT_CATALOGFOLDER_ID) || 
			 classID == PT_CLASSIDS.PT_SITEMAPFOLDER_ID);
  }
  
  public boolean ObjectIsAdminFolder(int classID)
  {
	return (classID == PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
  }
  
  public boolean SuppressEditLinkForClass(int classID)
  {
  	return ((classID == PT_CLASSIDS.PT_SITEMAPFOLDER_ID));
  }
  
  public boolean ObjectHasBeenDeleted(int objID, int classID, int folderID)
  {
	  // NOTE: This method catches the case where an object
	  // has been deleted from the DB but search hasn't been updated yet (or
	  // the acl has been changed).  This situation will allow the object
	  // to show up in the search results, but the link will be broken when
	  // you try to open the object.  We only use this method to avoid this
	  // case for edit/admin mode search results, and allow this to happen
	  // for browse mode results (saving 1 db query per object).  This should
	  // probably be acceptable to most customers, since this period is only
	  // 10 minutes or so before a search update is run.
	  // However, super paranoid customers may not find this acceptable, and
	  // the current workaround that they do is to either turn off the portal
	  // or immediately run search update in the case of sensitive data leaks.
  	try
  	{
  		if(!ObjectIsFolder(classID))
  		{
  			IPTSession session = ((IPTSession) m_asOwner.GetUserSession());
  			if(classID == PT_CLASSIDS.PT_CATALOGCARD_ID)
  			{
  				// If the object has just been deleted or had it's ACL changed,
  				// and search hasn't been updated, we can get here and this will
  				// return no access.
  				// This code previously opened the card and caught an exception
  				// to see if it had been deleted, but that causes 3 DB queries,
  				// whereas checking access only calls one. 
				return (!session.GetCatalog().QueryCardIsVisible(objID));
  			}
  			else
  			{
  				// NOTE: This could just check if the object exists and
  				// that the user still has read access on it.  There's no need to
  				// actually open the object, but opening an admin object is
  				// only a single query, so we can't really optimize it much further.
				// We may be able to replace it with a simpler query, but that's about it.
  				// We could just check security and that would enable us to remove this
				// unnecessary try/catch block. Bug#67465
				IPTObjectManager manager = session.GetObjectManagers(classID);
				IPTQueryResult result = manager.QuerySingleObject(objID);
				boolean retval = (result.RowCount() == 0);
				return retval;
			}
		}
		else
		{
			if(classID == PT_CLASSIDS.PT_ADMIN_FOLDER_ID)
			{
				IPTAdminCatalog m_ptCatalog	= ((IPTSession) m_asOwner.GetUserSession()).GetAdminCatalog();
				try
				{
	  				// NOTE: This could just check if the folder exists and
	  				// that the user still has read access on it.  There's no need to
	  				// actually open the folder, but opening an admin folder is
	  				// only a single query, so we can't really optimize it much further.
					// We may be able to replace it with a simpler query, but that's about it.
	  				// We could just check security and that would enable us to remove this
					// unnecessary try/catch block. Bug#67465
					IPTAdminFolder folder = m_ptCatalog.OpenAdminFolder(objID,false);
					return (folder == null);
				}
				catch(Exception e)
				{
					log.Error(e, "Got exception checking deleted folder ");
					return true;
				}
			}
			else if (classID == PT_CLASSIDS.PT_CATALOGFOLDER_ID)
			{
				try
				{
	  				// NOTE: This could just check if the folder exists and
	  				// that the user still has read access on it.  There's no need to
	  				// actually open the folder, but opening a document folder is
	  				// only a single query, so we can't really optimize it much further.
					// We may be able to replace it with a simpler query, but that's about it.
	  				// We could just check security and that would enable us to remove this
					// unnecessary try/catch block. Bug#67465
					IPTCatalog catalog = ((IPTSession) m_asOwner.GetUserSession()).GetCatalog();
					catalog.OpenFolder(objID,false);
					return false;
				}
				catch(Exception e)
				{
					return true;
				}
			}
			return false;
		}
	}
	catch(Exception e)
	{
		log.Error(e, "In ObjectHasBeenDeleted for object " + objID + " class  = " + classID + " Got exception ");
	}
	return false;
  }
  
  public String GetAdminFolderPath(int folderID)
  {						
	try
	{
		IPTAdminCatalog m_ptCatalog	= ((IPTSession) m_asOwner.GetUserSession()).GetAdminCatalog();
		IPTAdminFolder folder = m_ptCatalog.OpenAdminFolder(folderID, false);
		String retval = folder.GetPath();
		return retval;

	}
	catch(Exception e)
	{
	}
	return null;
  }
  
  public String GetFolderPath(int folderID)
  {			
	if( folderID == MULTIFOLDER_CODE)
		return null;		
	try
	{
		IPTCatalog m_ptCatalog	= ((IPTSession) m_asOwner.GetUserSession()).GetCatalog();
		IPTFolder folder = m_ptCatalog.OpenFolder(folderID, false);
		String retval = folder.GetPath();
		return retval;

	}
	catch(Exception e)
	{
	}
	return null;
  }
  
  public String GetFolderPathForCard(int cardID)
  {
	try
	{
		IPTCatalog cat	= ((IPTSession) m_asOwner.GetUserSession()).GetCatalog();
		IPTQueryResult res = cat.QueryCardPaths(cardID, true, true);
		int folderID = res.ItemAsInt(0, PT_PROPIDS.PT_PROPID_CARD_PARENTFOLDERID);
		IPTFolder folder = cat.OpenFolder(folderID, false);
		String retval = folder.GetPath();

		return retval;
	}
	catch(Exception e)
	{
	}
	return null; 	
  }
  
  public int GetFolderIDForCard(int cardID)
  {
	try
	{
		IPTCatalog cat	= ((IPTSession) m_asOwner.GetUserSession()).GetCatalog();
		IPTQueryResult res = cat.QueryCardPaths(cardID, true, true);
		int folderID = res.ItemAsInt(0, PT_PROPIDS.PT_PROPID_CARD_PARENTFOLDERID);
		return folderID;
	}
	catch(Exception e)
	{
	}
	return -1; 	
  }
  
  protected boolean CheckBoxForMode(int objID, int classID, int folderID)
  {
  	if(ObjectIsFolder(classID))
  	{
  		boolean adminFolder = ObjectIsAdminFolder(objID);
  		if(adminFolder)
  		{
  			return _pageMode.IsAdminMode();
  		}
  		else
  		{
  			return _pageMode.IsEditMode();
		}
  	}
  	else
  	{	
  		boolean isCard = (classID == PT_CLASSIDS.PT_CATALOGCARD_ID);
  		if(isCard)
  			return _pageMode.IsEditMode();
  		else
  			return _pageMode.IsAdminMode();
  	}
  }
  
  protected boolean CardHasMoreThanOneFolder(int resultNum)
  {
  	if(_pageMode.ShowToolbar())
  	{
    	int cardId = _model.GetResultObjectID(resultNum);
      	IPTCatalog cat	= ((IPTSession) m_asOwner.GetUserSession()).GetCatalog();
      	IPTQueryResult res = cat.QueryCardPaths(cardId, true, true);
      	return (res.RowCount() > 1);
  	}
  	else
  	{
	  	// GetResultFolderID will return 0 if there is more than
	  	// one parent, but also when no parent can be found.
	  	// Assumption is that all cards will have at least one
	  	// parent folder so we don't need to worry about the
	  	// "no parent" case. 
	  	int nParentFolderId = _model.GetResultFolderID(resultNum);
	  	return (nParentFolderId == 0);
  	}
  }

  private String _LookupLoggingID() {

    if (! (m_asOwner.GetModelExists(LoggingHelperModel.STR_MVC_CLASS_NAME))) {
      return null;
    }

    LoggingHelperModel logHelper = (LoggingHelperModel) m_asOwner.GetModel(LoggingHelperModel.STR_MVC_CLASS_NAME);

    if (null == logHelper) {
      return null;
    }

    return logHelper.GetLoggingID();
  }

}

