package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.server.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.analytics.openusage.*;

public class LoggingHelperModel implements IModel
{
  /** Name of this class */
  public static final String STR_MVC_CLASS_NAME = "SearchLogHelper";

  /** Search type - Banner search */
  public static final String SEARCH_TYPE_BANNER = "banner";

  /** Search type - Advanced search */
  public static final String SEARCH_TYPE_ADVANCED = "advanced";

  /** Owning session */
  private IPTSession _session;

  /** Owning activityspace */
  private AActivitySpace m_asOwner;

  /**
   * Query logging id, set to non-null when this is a banner search (in ).
   */
  protected String _queryLoggingId = null;

  public void Init(AActivitySpace parent)
  {
    m_asOwner = parent;
    _session = (IPTSession) m_asOwner.GetUserSession();

    _queryLoggingId = null;
  }

  public void CleanupTempData()
  {
  }

  public void CleanupAllData()
  {
    _queryLoggingId = null;
  }

  public Object Create()
  {
    return new LoggingHelperModel();
  }

  public String GetName()
  {
    return STR_MVC_CLASS_NAME;
  }

  public String GetLoggingID() {
    return _queryLoggingId;
  }

  public void LogStartSearchEvent(String searchString, String searchType)
  {
      _queryLoggingId = _GenerateNewSearchId();

      ISearchEvent searchEvent = ASEventFactory.createSearchEvent();
      
      searchEvent.setSearchString(searchString);
 
      int nUserId = _session.GetSessionInfo().GetCurrentUserID();

      searchEvent.setUserId(new Integer(nUserId));
      
      searchEvent.setQueryId(_queryLoggingId);

      // No need to set timestamp
      //XPDateTime dateTime = new XPDateTime();
      //long nTimeStamp = dateTime.GetTimeInMilliSeconds();
      //searchEvent.setTimestamp(new Long(nTimeStamp));
      // Set the search type (advanced or banner)
      searchEvent.setSearchType(searchType);

      // Log the event...
      searchEvent.sendEvent();
  }

  public void LogSearchResultsEvent(int nNumTotalMatches,
                                    int nResultStartRange,
                                    int nResultEndRange,
                                    String drilldownKey)
  {
    if (null == _queryLoggingId) {
      // If initial search wasn't logged, then no need to log results
      return;
    }
    
    ISearchResultEvent searchResultEvent = ASEventFactory.createSearchResultEvent();
    
    searchResultEvent.setQueryId(_queryLoggingId);
    searchResultEvent.setTotalMatches(new Integer(nNumTotalMatches));
    searchResultEvent.setStartRange(new Integer(nResultStartRange));
    searchResultEvent.setEndRange(new Integer(nResultEndRange));
    if(drilldownKey != null)
    {
        searchResultEvent.setCategoryFilter(drilldownKey);
    }
    // DCA - no longer needed
    //searchResultEvent.setSpellCorrect(bWasSpellCorrected);
    //searchResultEvent.setBestBets(bHasBestBets);

    int nUserId = _session.GetSessionInfo().GetCurrentUserID();

    searchResultEvent.setUserId(new Integer(nUserId));
    // No need to set timestamp
    //XPDateTime dateTime = new XPDateTime();
    //long nTimeStamp = dateTime.GetTimeInMilliSeconds();
    //searchResultEvent.setTimestamp(new Long(nTimeStamp));

    // Log the event...
    searchResultEvent.sendEvent();
  }

  private String _GenerateNewSearchId()
  {
    long lTime = XPSystem.GetCurrentTimeMilliSec();
    // Used the cached user ID - don't go to the DB for something as
    // useless as this.
    int nUserId = _session.GetSessionInfo().GetCurrentUserID();
    int nKey = (int)lTime + nUserId;
    String strId = XPConvert.ToString(nKey);
    if(strId.length() > 8)
    {
      strId =  strId.substring(strId.length()-8);
    }
    return strId;
  }

}
