package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.search.exceptions.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 *
 */
public class SaveSearchView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.search.results.SaveSearchView");

	
	public static final String STR_MVC_CLASS_NAME = "SaveSearch";

	
	public static final String FORM_NAME = STR_MVC_CLASS_NAME;

	
	public static final String HI_TEXTBOX    = "in_tx_ss_name";

	
	public static final String HI_SAVE		 = "in_bu_ss_save";

	
	public static final String HI_CANCEL     = "in_bu_ss_cancel";

	
	public static final String HI_CLOSE   = "in_bu_ss_close";
	protected AActivitySpace m_asOwner;
	protected ISearchResultModelRO _model;

	/**
	 * 
	 *
	 * @return 
	 */
	public Object Create()
	{
		return new SaveSearchView();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLElement Display()
	{
    if (! _model.IsInitialized()) {
      // The activityspace cache must have been flushed.  Show the
      // "your search is no longer available" message.

      throw new CacheFlushedException(m_asOwner);
    }

		HTMLForm form = null;
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;

		try
		{
			myTable = new HTMLTable();
			myTable.SetBorder("0");
			myTable.SetWidth("100%");
			myTable.SetCellPadding("0");
			myTable.SetCellSpacing("10");
        myTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);

			// If we've successfully saved the search
			if (_model.GetHasBeenSaved())
			{
				// ROW: Search has been saved
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
				myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(1391, "ptmsgs_portalbrowsingmsgs"));
				
				// ROW: If you have not done so already, you will need to add the Portal	Search Portlet to your MyPage.
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
				myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(1392, "ptmsgs_portalbrowsingmsgs"));

				// Offer to go to gadget preview for the search portlet
				ASURL addPortletURL = new ASURL(m_asOwner);
				addPortletURL.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME,
					m_asOwner);
				addPortletURL.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
				addPortletURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
				addPortletURL.AddControlArgument(PreviewPortletControl.m_PreviewType,
					PreviewPortletModel.SEARCHHEADER);

				// the portal search portlet always has ID=4
				addPortletURL.AddControlArgument(PreviewPortletControl.m_strPortletParam,
					"4");

				XPStringBuilder sb = new XPStringBuilder(200);
				sb.Append("opener.location.href='")
				.Append(addPortletURL.GetURLAsString()).Append("'; window.close();");

				HTMLAnchor addPortletLink = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
				addPortletLink.SetOnClick(sb.ToString());
				addPortletLink.SetTitle(m_asOwner.GetString(1394, "ptmsgs_portalbrowsingmsgs"));
				addPortletLink.AddInnerHTMLString(m_asOwner.GetString(1394, "ptmsgs_portalbrowsingmsgs"));

				// ROW: Add portlet link
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
				myCell.AddInnerHTMLElement(addPortletLink);

				myTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(1, 10));


				// offer a link to just close the window
				ASURL parentReload = new ASURL(m_asOwner);
				parentReload.SetLinkGetCachedSpace(m_asOwner);
				parentReload.SetDisplayPage(SearchResultDP.STR_MVC_CLASS_NAME);

				sb = new XPStringBuilder(200);
				sb.Append("opener.location.href='")
				.Append(parentReload.GetURLAsString()).Append("'; window.close();");

				HTMLInput closeButton = new HTMLInput(HTMLInputTypes.BUTTON,
						HI_CLOSE, "");
				closeButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
				closeButton.SetValue(m_asOwner.GetString(1395, "ptmsgs_portalbrowsingmsgs"));
				closeButton.SetOnClick(sb.ToString());

				// ROW: Close button
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
				myCell.AddInnerHTMLElement(closeButton);

				myTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(1, 100));

				return myTable;
			}

			// else, if search has not yet been saved, show a dialog box for the name
			form = new HTMLForm(FORM_NAME);
			form.SetName(FORM_NAME);
			form.SetID(FORM_NAME);
			form.SetAction(ConfigHelper.GetApplicationBaseURLToAS(m_asOwner.GetCurrentNormalizedBaseURL(), 
				m_asOwner.GetName(), m_asOwner.IsSubSpace()));
      		form.SetStyleClass(PTStyleClass.DIALOGUE_BG);

      		form.AddInnerHTMLElement(myTable);

			// Add hidden inputs for the current space, ID, page, and SaveSearchControl
			// Stay in the same space
			HTMLInput targetSpace = new HTMLInput(HTMLInputTypes.HIDDEN,
					ASConstants.SPACENAME_INPUT, ASConstants.SPACENAME_INPUT, "");
			targetSpace.SetValue(m_asOwner.GetName());
			form.AddInnerHTMLElement(targetSpace);

			// Add our current space ID, so the framework doesn't create
			// another instance of the space
			HTMLInput targetSpID = new HTMLInput(HTMLInputTypes.HIDDEN,
					ASConstants.SPACEID_INPUT, ASConstants.SPACEID_INPUT, "");
			targetSpID.SetValue(m_asOwner.GetSpaceID());
			form.AddInnerHTMLElement(targetSpID);

			// Set target as SaveSearchControl
			HTMLInput targetControl = new HTMLInput(HTMLInputTypes.HIDDEN,
					ASConstants.CONTROL_INPUT, ASConstants.CONTROL_INPUT, "");
			targetControl.SetValue(SaveSearchControl.STR_MVC_CLASS_NAME);
			form.AddInnerHTMLElement(targetControl);

			// Now, add the form 
			boolean somethingVeryBadHappened = false;

			// Check if there were any errors the last time the user clicked Save
			int errorCode = _model.GetSavedSearchErrorCode();

			if (0 != errorCode)
			{
				// ROW: report error
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);

				if (SaveSearchControl.ERRORCODE_NO_NAME_ENTERED == errorCode)
				{
					myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(841, "ptmsgs_portalbrowsingmsgs"));
				}
				else if (SaveSearchControl.ERRORCODE_ALREADY_EXISTS == errorCode)
				{
					myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(842, "ptmsgs_portalbrowsingmsgs"));
				}
				else
				{
					somethingVeryBadHappened = true;
					myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(843, "ptmsgs_portalbrowsingmsgs"));
				}
			}

			if (!somethingVeryBadHappened)
			{
				// ROW: You are saving this search in the Portal Search Portlet.
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
				myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(836, "ptmsgs_portalbrowsingmsgs"));

				// ROW: To see your Saved Searches, you will need to add the Portal Search Portlet to your My Page. You can do this on the next page.
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

				myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(1389, "ptmsgs_portalbrowsingmsgs"));

				// ROW: name
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
				myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(838, "ptmsgs_portalbrowsingmsgs"));

				// ROW: textbox
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

				HTMLInput textBox = new HTMLInput(HTMLInputTypes.TEXT,
						HI_TEXTBOX, "");
				textBox.SetSize(31);
				textBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
				textBox.SetValue(_model.GetSearchString());
				myCell.AddInnerHTMLElement(textBox);

				// ROW: save button
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);

				// make a fancy submit button with javascript
				HTMLInput saveButton = new HTMLInput(HTMLInputTypes.BUTTON,
						HI_SAVE, "");
				saveButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

				saveButton.SetValue(m_asOwner.GetString(839,
						"ptmsgs_portalbrowsingmsgs"));
				saveButton.SetOnClick("document." + FORM_NAME +
					".submit();");
				myCell.AddInnerHTMLElement(saveButton);

				myCell.AddInnerHTMLElement(DirConstants.CreateSpacerImage(1,10));
			} else {
				// create a row for the cancel button
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);
				myCell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
			}

			// always show the cancel button, even if a bad error happened, like
			// the portal going down
			HTMLInput cancelButton = new HTMLInput(HTMLInputTypes.BUTTON,
					HI_CANCEL, "");
			cancelButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

			cancelButton.SetValue(m_asOwner.GetString(840,
					"ptmsgs_portalbrowsingmsgs"));
			cancelButton.SetOnClick("window.close();");
			myCell.AddInnerHTMLElement(cancelButton);

			myTable.AddInnerHTMLElement(DirConstants.CreateSpacerRow(1,150));
		}
		catch (XPException e)
		{
      // Just display the exception.
      
        log.Error(e, e.getMessage());
      

      // Let the framework catch this exception and show a generic message,
      // with the underlying stack trace hidden in a comment
      throw e;
		}
		catch (Exception e)
		{
      // Let the framework catch this exception and show a generic message,
      // with the underlying stack trace hidden in a comment
      throw XPException.GetInstance(e);
		}

		return form;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param model 
	 * @param parent 
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		_model		  = (ISearchResultModelRO) model;
		m_asOwner     = parent;
	}
}

