package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author CraigS
 */
public class SearchPageModeHelper
{
  private ISearchResultModelRO _model = null;
  private AActivitySpace _asOwner = null;

  public void Init(SearchResultModel model, AActivitySpace asOwner)
  {
    _model = model;
    _asOwner = asOwner;

    if (null == _model.GetPageMode()) {
      model.SetPageMode(BROWSE_MODE);
    }
  }

  public static final String BROWSE_MODE = "browse";
  public static final String EDIT_MODE = "edit";
  public static final String ADMIN_MODE = "admin";

  public boolean IsBrowseMode()
  {
    return _model.GetPageMode().equals(BROWSE_MODE);
  }

  public boolean IsEditMode()
  {
    return _model.GetPageMode().equals(EDIT_MODE);
  }

  public boolean IsAdminMode()
  {
    return _model.GetPageMode().equals(ADMIN_MODE);
  }

  public boolean ShowToolbar()
  {
    return (! IsBrowseMode());
  }

  public boolean GetMakeEditLinks()
  {
    return IsAdminMode();
  }

  public boolean UserHasEditModeAccess()
  {
	  // DCA - display edit URL if there is no type restriction and user has admin and KD edit access,
	  // or search is restricted to KD items and user has KD edit access,
	  // or search is restricted to some admin objects and user has admin access
	  int selectedFilter = _model.GetSelectedTypeFilter();
	  if ((selectedFilter < 0 && UserHasAdminAccess(_asOwner) && UserHasEditDocumentAccess(_asOwner)) ||
		  ((selectedFilter == SearchObjectTypes.CLASSID_00 || selectedFilter == SearchObjectTypes.CLASSID_01) && UserHasEditDocumentAccess(_asOwner)) ||
		  (selectedFilter > 0 && selectedFilter != SearchObjectTypes.CLASSID_00 && selectedFilter != SearchObjectTypes.CLASSID_01 && UserHasAdminAccess(_asOwner))) {
		  return true;
	  } else {
		  return false;
	  }
  }
  
  public boolean UserHasAdminAccess(AActivitySpace asOwner) 
  {
	  IPTSession ptSession = (IPTSession) (asOwner.GetUserSession());
	  IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
	  return ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);
  }
  
  public boolean UserHasEditDocumentAccess(AActivitySpace asOwner) 
  {
	  IPTSession ptSession = (IPTSession) (asOwner.GetUserSession());
	  IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
	  return ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY);
  }
  
  public static boolean UserHasEditModeAccess(AActivitySpace asOwner)
  {
    IPTSession ptSession = (IPTSession) (asOwner.GetUserSession());
    IPTSessionInfo ptSessionInfo = ptSession.GetSessionInfo();
    return
      (ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION) &&
       ptSessionInfo.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_EDIT_DOCUMENT_DIRECTORY));
  }
}
