package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.portalpages.admin.objmgr.*;
import com.plumtree.portalpages.admin.objmgr.popups.*;
import com.plumtree.portalpages.admin.objsearch.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.pathways.tagging.TaggingControl;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 *
 */
public class SearchResultAS extends PlumtreeAS
{
	public static final String STR_MVC_CLASS_NAME = "SearchResult";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SearchResultAS();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();
		IntegratedSearchAS.RegisterSearchClasses(this);

		// Get the search model that was registered by IntegratedSearchAS
		IModel model = GetModel(SearchResultModel.STR_MVC_CLASS_NAME);

		// Initialize helper class that holds info about whether we're in browse vs. edit mode
		SearchPageModeHelper pageMode = new SearchPageModeHelper();
		pageMode.Init((SearchResultModel) model, this);

                // Register helper model that handles logging to the Analytics Server
                RegisterModel(LoggingHelperModel.STR_MVC_CLASS_NAME);

		// Register controls that initiate a search
		RegisterControl(BannerStartSearchControl.STR_MVC_CLASS_NAME, model);
		RegisterControl(AdvancedStartSearchControl.STR_MVC_CLASS_NAME, model);

		// Register control that saves a search
		RegisterControl(SaveSearchControl.STR_MVC_CLASS_NAME, model);

		// Register "search again" control
		RegisterControl(SearchWithinResultsControl.STR_MVC_CLASS_NAME, model);

		// Pathways Tags Control
		RegisterControl(TaggingControl.STR_MVC_CLASS_NAME, model);
		
		// Register main DisplayPage
		SearchResultDP dp = new SearchResultDP();
		RegisterPage(dp);
		dp.SetPageModeHelper(pageMode);

		// Register views
		RegisterView(FollowupSearchView.STR_MVC_CLASS_NAME, model);
		RegisterView(SearchBannerView.STR_MVC_CLASS_NAME, model);
		RegisterView(OrganizationView.STR_MVC_CLASS_NAME, model);
		RegisterView(DrilldownView.STR_MVC_CLASS_NAME, model);
		RegisterView(SearchSummaryView.STR_MVC_CLASS_NAME, model);
		RegisterView(GroupedResultsView.STR_MVC_CLASS_NAME, model);
		RegisterView(SearchFooterView.STR_MVC_CLASS_NAME, model);

		RegisterPage(new ObjMgrDeleteWarningsDP());
		RegisterControl(SearchBrowseEditModeControl.STR_MVC_CLASS_NAME,model);
		
		// ObjMgr Model
		RegisterModel(AdminSearchModel.STR_MVC_CLASS_NAME);
	
		IModel myModel = (AdminSearchModel)GetModel(AdminSearchModel.STR_MVC_CLASS_NAME);
			
		((IAdminSearchModelRO)myModel).SetSearchModel((ISearchResultModelRO)model);
			
		// ObjMgr Views
		RegisterView(ToolbarView.STR_MVC_CLASS_NAME, myModel);
	
		// Obj Mgr popup Views
		RegisterView(ObjMgrDeleteWarningsView.STR_MVC_CLASS_NAME, myModel);
	
		// ObjMgr Controls
		RegisterControl(AdminSearchRepostControl.STR_MVC_CLASS_NAME, myModel);
			
		// Obj Mgr popup Controls
		RegisterControl(CheckDeleteControl.STR_MVC_CLASS_NAME, myModel);

	    // Set the view helper for the grouped results view
	    GroupedResultsView grv = (GroupedResultsView) GetView(GroupedResultsView.STR_MVC_CLASS_NAME);
	
	    if (GetAccessStyle() == AccessStyles.STANDARD) 
	    {
	      	grv.SetHelper(new GroupedResultsViewHelper(pageMode));
	    } 
	    else 
	    {
	    	grv.SetHelper(new GroupedResults508ViewHelper(pageMode));
	    }

	    ((FollowupSearchView) GetView(FollowupSearchView.STR_MVC_CLASS_NAME)).SetPageModeHelper(pageMode);
	    ((SearchSummaryView) GetView(SearchSummaryView.STR_MVC_CLASS_NAME)).SetPageModeHelper(pageMode);
	    ((SearchBannerView) GetView(SearchBannerView.STR_MVC_CLASS_NAME)).SetPageModeHelper(pageMode);

		// Register popup "save this search" DisplayPage and view
		RegisterPage(new SaveSearchPopupDP());
		RegisterPage(new SaveSearch508DP());
		RegisterView(SaveSearchView.STR_MVC_CLASS_NAME, model);
		RegisterView(SaveSearch508View.STR_MVC_CLASS_NAME, model);
		
		this.SetHelpTopic( "PT_SearchResults" );
		
	}
	
	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#GetStyleSheetLinks()
	 */
	public HTMLElementCollection GetStyleSheetLinks()
	{
		String settingLanguage = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
				this);

		SearchResultModel _model				  = (SearchResultModel) GetModel(SearchResultModel.STR_MVC_CLASS_NAME);
	    if ((null == _model) || (! _model.IsInitialized())) 
	    {
				return super.GetStyleSheetLinks();	
	    }

		int [] nCommunityIDs				  	  = _model.GetCommunityRestrictions();
		
		HTMLElementCollection pCollection = null;
		if(nCommunityIDs == null || nCommunityIDs.length == 0 || nCommunityIDs.length > 1)
		{
			pCollection = super.GetStyleSheetLinks();
		} 
		else 
		{
			int nHeaderID						  = _model.GetHeaderID(nCommunityIDs[0]);
			String strStyleSheet				  = "";
	
			if (nHeaderID > 0)
			{
				strStyleSheet = _model.GetStyleSheet(nCommunityIDs[0]);
			}
	
			if (!("").equals(strStyleSheet) && (strStyleSheet != null))
			{
				if (GetIsAccessStyleNonStandard())
				{
					strStyleSheet = PlumtreeHelpers.STYLE_PREFIX_508 + strStyleSheet;
				}

				PTStyleSheetLink ptStyleSheetLink = new PTStyleSheetLink(strStyleSheet,
						settingLanguage);
				pCollection = new HTMLElementCollection();
	
				try
				{
					pCollection.AddInnerHTMLElement(ptStyleSheetLink.GetLinkAsHTMLElement(ConfigHelper.GetStyleSheetsBaseURL(this)));
				}
				catch (HTMLException e)
				{
				}
				catch (Exception e)
				{
				}
			}
			else
			{
				// use the default subportal stylesheet
				pCollection = super.GetStyleSheetLinks();
			}
		}
		return pCollection;
	}
}

