package com.plumtree.portalpages.browsing.search.results;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 *
 */
public abstract class SearchResultView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.search.results.SearchResultView");

  //
  // The rest of this file is useful helpers for subclasses
  //

  
  public static final String SPACE    = "&nbsp;";

  
  public static final String SPACE2     = "&nbsp;&nbsp;";

  
  public static final String SPACE3     = "&nbsp;&nbsp;&nbsp;";

  
  public static final String SPACE4     = "&nbsp;&nbsp;&nbsp;&nbsp;";
  
  
  protected AActivitySpace m_asOwner;
  protected ISearchResultModelRO _model;

  /**
    * This method is used by the ASManager to return new instances of managed
    * objects.
    *
    * @return A new instance of the managed class (i.e. return new Foo();)
    */
  public abstract Object Create();

  /**
   * DisplaySearchView() should be implemented by all subclasses and
   * should perform the same function as the regular Display() method,
   * but is allowed to throw a SearchModelException or an HTMLException.
   *
   * SearchModelException indicates a problem with usage of the
   * portalinfrastructure classes, not a problem with the search itself
   * (which are SearchExecutionExceptions; call ISearchResultModelRO.GetError()).
   */
  abstract public HTMLElement DisplaySearchView();

  /**
   * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Display()
   */
  public HTMLElement Display()
  {
    HTMLElement he = null;

    // If the last search failed..
    if (null != _model.GetError())
    {
    	// Usually this is null. Sometimes it is an un-internationalized error message.
    	return _model.GetError().GetComment();
    }

    try
    {
      // display the view
      he = DisplaySearchView();
    }
    catch (SearchModelException e)
    {
      // Just display the exception.
      
        log.Error(e, "Unable to display search results view due to problem in search model.");
      

      // Let the framework catch this exception and show a generic message,
      // with the underlying stack trace hidden in a comment
      throw e;

      //he = new HTMLGenericElement(e.getMessage());
    }
    catch (HTMLException e)
    {
      // Same.
      
        log.Error(e, "Unable to display search results view.");
      

      throw XPException.GetInstance(e);
    }

    return he;
  }

  /**
   * @see com.plumtree.portaluiinfrastructure.activityspace.IView#DisplayJavascript()
   */
  public HTMLScript DisplayJavascript()
  {
    // by default, return nothing
    return null;
  }

  /**
   * 
   *
   * @return 
   */
  public abstract String GetName();

  /**
   * @see com.plumtree.portaluiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
   */
  public void Init(IModelRO model, AActivitySpace parent)
  {
    _model      = (ISearchResultModelRO) model;
    m_asOwner     = parent;
  }

  /**
   * 
   *
   * @return 
   */
  protected boolean is508()
  {
    return (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD);
  }
}

