package com.plumtree.portalpages.browsing.search.results.assocobjects;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.server.*;
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.portletpreview.*;
import com.plumtree.portalpages.browsing.search.results.*;

/**
 * @author CraigS
 */
public class AssociatedObjectsView implements IView
{
  public static final String STR_MVC_CLASS_NAME = "SRAssociatedObjects";

  public String GetName()
  {
    return STR_MVC_CLASS_NAME;
  }

  public Object Create()
  {
    return new AssociatedObjectsView();
  }

  protected AActivitySpace m_asOwner;
  protected AssociatedObjectsModel _model;

  public void Init(IModelRO model, AActivitySpace parent)
  {
    _model = (AssociatedObjectsModel) model;
    m_asOwner = parent;
  }

  public HTMLElement Display()
  {
    XPStringBuilder sb = null;

    HTMLTable outerTable = new HTMLTable();
    HTMLTableRow outerRow = new HTMLTableRow();
    HTMLTableCell outerCell = new HTMLTableCell();

    outerTable.SetBorder("0");
    outerTable.SetWidth("100%");
    outerTable.SetCellPadding("0");
    outerTable.SetCellSpacing("10");
    outerTable.SetStyleClass(PTStyleClass.DIALOGUE_BG);
    outerTable.AddInnerHTMLElement(outerRow);
    outerRow.AddInnerHTMLElement(outerCell);

    HTMLTable table = null;
    HTMLTableRow row = null;
    HTMLTableCell cell = null;

    table = new HTMLTable();
    outerCell.AddInnerHTMLElement(table);

    table.SetBorder("0");
    table.SetWidth("100%");
    table.SetCellPadding("0");
    table.SetCellSpacing("0");
    table.SetStyleClass(PTStyleClass.DIALOGUE_BG);

    // Title row with item name

    row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
    cell.SetColSpan("2");

    String itemName = _model.GetItemName();
    // let's be super safe:
    if (null == itemName) {
      itemName = "";
    }
    // "Associated portlets and communities for item: "
    cell.AddInnerHTMLEncodedString(XPResourceManager.FormatMessage(m_asOwner.GetString(1868, "ptmsgs_portalbrowsingmsgs"),
                                                                   itemName));

    // Spacer row
    row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
    cell.SetColSpan("2");
    cell.SetHeight("15");

    int numPortlets = _model.GetNumPortlets();
    int numCommunities = _model.GetNumCommunities();

    if (0 == numPortlets) {
      row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
      cell.SetColSpan("2");

      // "No portlets or communities found"
      cell.AddInnerHTMLEncodedString(m_asOwner.GetString(1869, "ptmsgs_portalbrowsingmsgs"));

      row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      cell = new HTMLTableCell();
      row.AddInnerHTMLElement(cell);
      cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
      cell.SetColSpan("2");

      // "item's portlet may have been deleted recently"
      cell.AddInnerHTMLEncodedString(m_asOwner.GetString(1872, "ptmsgs_portalbrowsingmsgs"));
    }
    else {
      for (int j = 0; j < numPortlets; j++) {
        row = new HTMLTableRow();
        table.AddInnerHTMLElement(row);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);

        // put "Portlets:" next to the first portlet
        if (0 == j) {
          cell.AddInnerHTMLString(m_asOwner.GetString(1870, "ptmsgs_portalbrowsingmsgs"));
          cell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");
        }

        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        cell.SetWidth("100%");

        ASURL portletURL = new ASURL(m_asOwner);
        portletURL.SetLinkCreateNewSpace(PreviewPortletAS.STR_MVC_CLASS_NAME, m_asOwner);
        portletURL.SetDisplayPage(InvitePortletJSDP.STR_MVC_CLASS_NAME);
        portletURL.SetControl(PreviewPortletControl.STR_MVC_CLASS_NAME);
        portletURL.AddControlArgument(PreviewPortletControl.m_PreviewType, PreviewPortletModel.SEARCHHEADER);

        portletURL.AddControlArgument(PreviewPortletControl.m_strPortletParam, XPConvert.ToString(_model.GetPortletID(j)));

        sb = new XPStringBuilder(200);
        sb.Append("opener.location.href='")
          .Append(portletURL.GetURLAsString())
          .Append("'; window.close();");

        HTMLAnchor a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        a.SetOnClick(sb.ToString());

        String portletName = XPHttpUtility.HtmlEncode(_model.GetPortletName(j));

        a.SetTitle(portletName);
        a.AddInnerHTMLString(portletName);

        cell.AddInnerHTMLElement(a);
      }

      if (0 < numCommunities) {
        // Another spacer row
        row = new HTMLTableRow();
        table.AddInnerHTMLElement(row);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
        cell.SetColSpan("2");
        cell.SetHeight("12");
      }

      for (int j = 0; j < numCommunities; j++) {
        row = new HTMLTableRow();
        table.AddInnerHTMLElement(row);
        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);

        // put "Communities:" next to the first community
        if (0 == j) {
          cell.AddInnerHTMLString(m_asOwner.GetString(1871, "ptmsgs_portalbrowsingmsgs"));
          cell.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");
        }

        cell = new HTMLTableCell();
        row.AddInnerHTMLElement(cell);
        cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
        cell.SetWidth("100%");

        HTMLAnchor a = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        a.AddInnerHTMLString(XPHttpUtility.HtmlEncode(_model.GetCommunityName(j)));

        a.SetOnClick("opener.location.href='" +
                     PTOpenerLinks.GetOpenerURLOpenObjID(PT_CLASSIDS.PT_COMMUNITY_ID,
                                                         _model.GetCommunityID(j),
                                                         IPTOpenerConstants.OPENER_MODE_VIEW,
                                                         m_asOwner) +
                     "'; window.close();");

        cell.AddInnerHTMLElement(a);
      }
    }

    // Wide spacer row
    row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TITLE);
    cell.SetColSpan("2");
    cell.SetHeight("30");

    // Final row with a "close window" button

    row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetStyleClass(PTStyleClass.ALERT_DIALOG_TEXT);
    cell.SetColSpan("2");

    ASURL parentReload = new ASURL(m_asOwner);
    parentReload.SetLinkGetCachedSpace(m_asOwner.GetParentSpace());
    parentReload.SetDisplayPage(SearchResultDP.STR_MVC_CLASS_NAME);

    sb = new XPStringBuilder(200);
    sb.Append("opener.location.href='")
      .Append(parentReload.GetURLAsString())
      .Append("'; window.close();");

    HTMLInput closeButton = new HTMLInput(HTMLInputTypes.BUTTON, "in_bu_close", "");
    closeButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
    closeButton.SetValue(m_asOwner.GetString(1395, "ptmsgs_portalbrowsingmsgs"));  // "Close Window"
    closeButton.SetOnClick(sb.ToString());
    cell.AddInnerHTMLElement(closeButton);

    // add a final row to fill the popup window with the background color
    row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);
    cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);
    cell.SetColSpan("2");
    cell.SetHeight("500");

    return outerTable;
  }

  public HTMLScript DisplayJavascript()
  {
    return null;
  }
}
