package com.plumtree.portalpages.browsing.sitemap.editweblink;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: EditWebLinkModel.java
 * ---------------------------
 *
 * @author NaveenP
 */
public class EditWebLinkModel implements IRepostModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.editweblink.EditWebLinkModel");

	/** Activity space name */
	public static final String STR_MVC_CLASS_NAME = "EditWebLink";

	/** Store session and catalog to retrieve data */
	protected IPTSession m_ptSession;

	
	/** Logger */
	private AActivitySpace m_asOwner = null;

	/** Link ID */
	private IPTSiteMapLink m_objSiteMapLink = null;

	/** Link Description */
	private String m_strLinkDesc = "";

	/** Link Name */
	private String m_strLinkName = "";

	/** Link URL */
	private String m_strLinkURL = "";

	/** Folder ID */
	private int m_nFolderID = -1;

	/** Link ID */
	private int m_nLinkID = -1;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.
	 * IManagedObject#Create()
	 */
	public Object Create()
	{
		return new EditWebLinkModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		if (null != m_objSiteMapLink)
		{
			m_objSiteMapLink.SetName(m_strLinkName);
			m_objSiteMapLink.SetDescription(m_strLinkDesc);
			m_objSiteMapLink.SetLinkURL(m_strLinkURL);
			m_objSiteMapLink.Store();
		}

		m_objSiteMapLink     = null;
		m_strLinkName		 = null;
		m_strLinkDesc		 = null;
		m_strLinkURL		 = null;
		m_nFolderID			 = -1;
		m_nLinkID			 = -1;
	}

	////////////////////////
	/// IModel         /////
	////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 *
	 * @return String
	 */
	public String GetOriginalDescription()
	{
		return m_objSiteMapLink.GetDescription();
	}

	/**
	 *
	 * @return String
	 */
	public String GetOriginalName()
	{
		return m_objSiteMapLink.GetName();
	}

	/**
	 *
	 * @return String
	 */
	public String GetOriginalURL()
	{
		return m_objSiteMapLink.GetLinkURL();
	}

	/**
	 * Returns the Redirect object
	 * (this is were we need to go at the end of the Editor).
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		ClosePopUpDP closeDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
		HTMLScript script    = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		try
		{
			script.AddInnerHTMLString(
					"window.opener.postToSelf(" + RepostControl.POSTTOSELF_ACTION_SIMPLEREPOST + ");"); //location.reload(true);");
					//DCA - changed to get rid of page refresh warning
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		closeDP.SetScript(script);

		Redirect redirectClose = new Redirect();
		redirectClose.SetLinkGetCachedSpace(m_asOwner);
		redirectClose.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

		return redirectClose;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner	    = parent;
		m_ptSession     = (IPTSession) m_asOwner.GetUserSession();
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String, XPHashtable)
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		String[] sValues = (String[]) _htFormData.GetElement(EditWebLinkView.HTMLINPUT_LINKNAME);

		if (sValues == null)
		{
			
				log.Info("could not find link name in query string.");
			

			m_strLinkName = "";

			return RepostControl.PAGE_STATUS_INVALID;
		}
		else
		{
			m_strLinkName = sValues[0];
		}

		sValues = (String[]) _htFormData.GetElement(EditWebLinkView.HTMLINPUT_LINKDESC);

		if (sValues == null)
		{
			log.Info("could not find link desc in query string.");

			m_strLinkDesc = "";

			return RepostControl.PAGE_STATUS_INVALID;
		}
		else
		{
			m_strLinkDesc = sValues[0];
		}

		sValues = (String[]) _htFormData.GetElement(EditWebLinkView.HTMLINPUT_LINKURL);

		if (sValues == null)
		{
			
				log.Info("could not find link url in query string.");
			

			m_strLinkURL = "";

			return RepostControl.PAGE_STATUS_INVALID;
		}
		else
		{
			m_strLinkURL = sValues[0];
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 *
	 * @param nLinkID
	 * @param nFolderID
	 * @throws Exception
	 */
	public void SetLinkAndFolderIDs(int nLinkID, int nFolderID)
	{
		m_nLinkID	    = nLinkID;
		m_nFolderID     = nFolderID;

		if ((m_nFolderID != -1) && (m_nLinkID != -1))
		{
			IPTObjectManager objMan = m_ptSession.GetSiteMapFolders();

			if (objMan.IsObjectAccessible(m_nFolderID,
						m_ptSession.GetSessionInfo().GetCurrentUserID(),
						PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT))
			{
				try
				{
					IPTSiteMapFolder objFolder = (IPTSiteMapFolder) objMan.Open(m_nFolderID, false);
					m_objSiteMapLink = objFolder.OpenLink(m_nLinkID);
				}
				catch (Exception e)
				{
					log.Error(e, "Could not open Community Knowledge Directory Folder or Link:" +
						e.getMessage());
					throw new XPException(
						"Could not open Community Knowledge Directory Folder or Link:" +
						e);
				}
			}
			else
			{
				//pkd extracted: 				throw new Exception(_ui_AccessError);
				throw new XPException(m_asOwner.GetString(877,
						"ptmsgs_portalbrowsingmsgs"));
			}
		}
	}
}

