package com.plumtree.portalpages.browsing.sitemap.editweblink;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * File: SetLinkControl.java
 * -------------------------
 *
 * @author NaveenP
 */
public class SetLinkControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.editweblink.SetLinkControl");

	
	public static final String STR_MVC_CLASS_NAME = "SetLink";

	/** Community ID Query String Param */
	public static final String m_LinkID = "LinkID";

	/** Community ID Query String Param */
	public static final String m_FolderID = "FolderID";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private EditWebLinkModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String[] sValues = (String[]) arguments.GetElement(m_LinkID);
		int nLinkID		 = -1;

		if (sValues == null)
		{
			
				log.Info("could not find link ID in query string.");
			

			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, "Invalid Link ID",
					"Invalid Link ID");
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
		else
		{
			nLinkID = XPConvert.ToInteger(sValues[0]);
		}

		sValues = (String[]) arguments.GetElement(m_FolderID);

		int nFolderID = -1;

		if (sValues == null)
		{
			
				log.Info("could not find folder ID in query string.");
			

			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, "Invalid Folder ID",
					"Invalid Folder ID");
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}
		else
		{
			nFolderID = XPConvert.ToInteger(sValues[0]);
		}

		try
		{
			m_asModel.SetLinkAndFolderIDs(nLinkID, nFolderID);
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, e.getMessage(),
					e.getMessage());
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.
	 * IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetLinkControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (EditWebLinkModel) model;
		m_asOwner     = space;
	}
}

