package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: MembersAndSubCommunitiesView.java
 * ---------------------------------------
 *
 * @author NaveenP
 */
public class MemberAndSubCommunitiesView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.MemberAndSubCommunitiesView");

	
	public static final String STR_MVC_CLASS_NAME = "MemberAndSubCommunities";

	// Query parameter name for the checkbox
	public static final String HTMLINPUT_SELECTION_INVALID = "in_cb_invalid";
	protected AActivitySpace m_asOwner;

	// Logger
	// Client-specific variables
	protected ISiteMapModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MemberAndSubCommunitiesView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		if (m_asModel.GetCurrentFolderID() == m_asModel.GetParentFolderID())
		{
			try
			{
				HTMLTable table = new HTMLTable();
				table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

				HTMLTableRow row = new HTMLTableRow();
				row.SetVAlign(CommonHTMLStrings.TOP);
				table.AddInnerHTMLElement(row);

				HTMLTableCell tCell;

				// start members display
				ASURL asurl = new ASURL(m_asOwner);
				asurl.SetLinkGetCachedSpace(m_asOwner);
				asurl.SetDisplayPage(MembersDP.STR_MVC_CLASS_NAME);
				asurl.SetControl(SetGroupControl.STR_MVC_CLASS_NAME);
				asurl.AddControlArgument(SetSiteMapControl.m_CommunityID, m_asModel.GetCommunityID());

				tCell = new HTMLTableCell();
				tCell.SetVAlign(CommonHTMLStrings.TOP);
				tCell.SetWidth("50%");
				row.AddInnerHTMLElement(tCell);

				UIListItem itemConstruct = new UIListItem(XPHttpUtility.HtmlEncode(
							m_asOwner.GetString(943, "ptmsgs_portalbrowsingmsgs") + "*"),
						asurl.GetURLAsString(), this.m_asOwner );

				itemConstruct.SetItemTypeImage(PTImageType.ICON_MEMBER, 
					m_asOwner.GetString(1648, "ptmsgs_portalbrowsingmsgs"));

				if (m_asModel.IsEditMode())
				{
					itemConstruct.SetCellHeight("20");
				}
				itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
				

				// check if there's a checkbox item

				if (m_asModel.GetShowCheckbox()) {
				    itemConstruct.EnableSelectionInput(HTMLInputTypes.CHECKBOX_TYPE, HTMLINPUT_SELECTION_INVALID, "", "", false);
				    HTMLInput myInput = itemConstruct.GetSelectionInput();
				    myInput.SetDisabled(true);
				}
				HTMLTable folderTable = itemConstruct.GetItemAsTable();
				tCell.AddInnerHTMLElement(folderTable);

				if (m_asModel.IsEditMode())
				{
					row = new HTMLTableRow();
					row.SetVAlign(CommonHTMLStrings.TOP);
					table.AddInnerHTMLElement(row);
				}

				// start subcommunities display
				asurl = new ASURL(m_asOwner);
				asurl.SetLinkGetCachedSpace(m_asOwner);
				asurl.SetDisplayPage(SubCommunitiesDP.STR_MVC_CLASS_NAME);

				tCell = new HTMLTableCell();
				tCell.SetVAlign(CommonHTMLStrings.TOP);
				tCell.SetWidth("50%");
				row.AddInnerHTMLElement(tCell);

				itemConstruct = new UIListItem(XPHttpUtility.HtmlEncode(
							m_asOwner.GetString(944, "ptmsgs_portalbrowsingmsgs") + "*"),
						asurl.GetURLAsString(), this.m_asOwner);

				itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_COMMUNITY,
					m_asOwner.GetString(1649, "ptmsgs_portalbrowsingmsgs"));
				itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

				if (m_asModel.IsEditMode())
				{
					itemConstruct.SetCellHeight("20");
					itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
				}

				// check if there's a checkbox item
				if (m_asModel.GetShowCheckbox()) {
				    itemConstruct.EnableSelectionInput(HTMLInputTypes.CHECKBOX_TYPE, HTMLINPUT_SELECTION_INVALID, "", "", false);
					HTMLInput myInput = itemConstruct.GetSelectionInput();
					myInput.SetDisabled(true);
				}
				folderTable = itemConstruct.GetItemAsTable();
				tCell.AddInnerHTMLElement(folderTable);

				result.AddInnerHTMLElement(table);
			}
			catch (HTMLException he)
			{
				log.Error(he, he.getMessage());
			}
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		return script;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (ISiteMapModelRO) model;
		m_asOwner     = parent;
	}
}

