package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: MembersView.java
 * ----------------------
 *
 * @author NaveenP
 */
public class MembersView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.MembersView");

	
	public static final String STR_MVC_CLASS_NAME = "Members";
	protected AActivitySpace m_asOwner;

	// Logger
	// Client-specific variables
	protected SiteMapModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MembersView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			if(!m_asModel.SiteMapDisabled()) 
			{
				result.AddInnerHTMLElement(DisplayBreadCrumbs());	
			}
			result.AddInnerHTMLElement(DisplayBanner());
			result.AddInnerHTMLElement(DisplayGroups());
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		return script;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (SiteMapModel) model;
		m_asOwner     = parent;
	}

	/**
	 *
	 * @return HTMLElement
	 */
	private HTMLElement DisplayBanner()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		ASURL asurl;
		HTMLAnchor anchor;
		ElementName elementName;

		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
					true, this.m_asOwner);

			PTConstruct myImage = 	UIConstructFactory.GetConstruct(PTImageType.ICON_MEMBER,
								true, this.m_asOwner);		
			myConstruct.ReplaceNestedElementsWithElement(PTBannerType.FOLDER.FOLDER_IMG_CONTAINER_ELEMENT_NAME,
				myImage.GetHTMLElement());
				
		 	ElementName eNameBanner = PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE);
			myConstruct.ReplaceNestedElementsWithHTMLString(eNameBanner,
				XPResourceManager.FormatMessage(m_asOwner.GetString(1624, "ptmsgs_portalbrowsingmsgs"),
												"\"" + XPHttpUtility.HtmlEncode(m_asModel.GetCurrentGroupName()) + "\" "));

			if(!m_asModel.SiteMapDisabled())
			{
				//	Get a button construct
				PTConstruct myButtonConstruct;
	
				//Go up button
				myButtonConstruct     = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
						true, this.m_asOwner);
				elementName			  = PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE);
	
				myButtonConstruct.ReplaceNestedElementsWithHTMLString(elementName,
					m_asOwner.GetString(949, "ptmsgs_portalbrowsingmsgs"));
				ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(949,
					"ptmsgs_portalbrowsingmsgs"));
				ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(949,
					"ptmsgs_portalbrowsingmsgs"));
				
				asurl	   = m_asModel.GetGroupGoUpURL();
				anchor     = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.GetElementName(
							PTButtonType.ELEMENT_NAME_ID_ANCHOR));
				anchor.SetHRef(asurl.GetURLAsString());
	
				myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.GetElementName(
						PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
					myButtonConstruct.GetHTMLElement());
			}
			
			result.AddInnerHTMLElement(myConstruct.GetHTMLElement());
		}
		catch (Exception e)
		{
			log.Error(e, e.getMessage());
		}

		return result;
	}

	/**
	 *
	 * @return HTMLElement
	 */
	private HTMLElement DisplayBreadCrumbs()
	{
		//Display the Breadcrumb path, flush left to the margin
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;

		try
		{
			// Bread crumb path
			myGroup.AddInnerHTMLElement(GetBreadcrumbPath()
				.GetPathAsHTMLElement());
			myGroup.AddInnerHTMLElement(new HTMLBr());
		}
		catch (Exception e)
		{
			log.Error(e, "Error creating " + STR_MVC_CLASS_NAME + " Section: " +
				e.getMessage());
		}

		return result;
	}

	/**
	 *
	 * @return HTMLElement
	 */
	private HTMLElement DisplayGroups()
	{
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;
		HTMLBr br					  = new HTMLBr();
		ASURL asurl;

		//Determine how many subfolders are one level deeper than the current folder
		int nSubGroupCount = 0;
		try
		{
			nSubGroupCount = m_asModel.GetSubGroupCount();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, e.getMessage(),
					e.getMessage());
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		int nNumCols = m_asModel.GetFolderColumnCount();

		try
		{
			// no subfolders to display
			if (nSubGroupCount == 0)
			{
				HTMLSpan mySpan = new HTMLSpan();

				mySpan.AddInnerHTMLString(m_asOwner.GetString(950,
						"ptmsgs_portalbrowsingmsgs"));
				mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				myGroup.AddInnerHTMLElement(mySpan);
				myGroup.AddInnerHTMLElement(br);
	
			}
			else
			{
				//Retrieve the current folder's subfolders.
				IASQueryResult asqrSubGroups = null;

				try
				{
					asqrSubGroups = m_asModel.GetSubGroups();
				}
				catch (Exception e)
				{
					UIError myError = new UIError(UIErrorLevel.FRIENDLY,
							UIErrorScope.CURRENT_USER, null, e.getMessage(),
							e.getMessage());
					UIErrorHandler.RaiseError(myError,
						m_asOwner.GetSubSession(), m_asOwner.GetApplication());
				}

				//Get the number of folders at all levels in the hierachy
				//int nTotalFolderCount = asqrSubGroups.GetCount();
				//Write the table of folders
				HTMLTable groupTable = new HTMLTable();
				groupTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
				groupTable.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);

				HTMLTableRow row = new HTMLTableRow();
				groupTable.AddInnerHTMLElement(row);
				row.SetVAlign(CommonHTMLStrings.TOP);

				//Figure out how many folders to show in each column
				int nRowCount = nSubGroupCount / nNumCols;

				if ((nSubGroupCount % nNumCols) != 0)
				{
					nRowCount++;
				}

				// keep track of the index we're at in the query result
				int nFolderIndexRef = 0;
				int count		    = 0;

				// write out folders, one column at a time
				for (int i = 0; i < nNumCols; i++)
				{
					HTMLTableCell cell = new HTMLTableCell();
					cell.SetVAlign(CommonHTMLStrings.TOP);
					cell.SetWidth("50%");
					row.AddInnerHTMLElement(cell);

					//int nWidth = 100/nNumCols;
					//int nColSpan = 1;
					for (int j = 0; j < nRowCount; j++)
					{
						//if all the subfolders have been printed out, span the cell to fill out the rest of the row
						if (count >= nSubGroupCount)
						{
							cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
						}
						else
						{
							if (m_asModel.IsGroupAccessible(XPConvert.ToInteger(asqrSubGroups.GetFields(
									nFolderIndexRef,PT_PROPIDS.PT_PROPID_OBJECTID)))) {
								//Display one folder and advance the index reference to the next folder to display
								asurl = new ASURL(m_asOwner);
								asurl.SetLinkGetCachedSpace(m_asOwner);
								asurl.SetDisplayPage(MembersDP.STR_MVC_CLASS_NAME);
								asurl.SetControl(SetGroupControl.STR_MVC_CLASS_NAME);
								asurl.AddControlArgument(SetGroupControl.m_GroupID,
									XPConvert.ToString(asqrSubGroups.GetFields(
											nFolderIndexRef,
											PT_PROPIDS.PT_PROPID_OBJECTID)));
								asurl.AddControlArgument(SetSiteMapControl.m_CommunityID, m_asModel.GetCommunityID());
	
								UIListItem itemConstruct = new UIListItem(XPHttpUtility.HtmlEncode(
											(String) asqrSubGroups.GetFields(
												nFolderIndexRef,
												PT_PROPIDS.PT_PROPID_NAME)),
										asurl.GetURLAsString(), this.m_asOwner );
	
								itemConstruct.SetItemTypeImage(PTImageType.ICON_GROUP,
									m_asOwner.GetString(1650,
										"ptmsgs_portalbrowsingmsgs"));
								itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
	
								cell.AddInnerHTMLElement(itemConstruct.GetItemAsTable());
							} else {
								// DCA - display as text
								HTMLTable itemTable = new HTMLTable();
								cell.AddInnerHTMLElement(itemTable);
								itemTable.SetCellPadding("3");
								itemTable.SetCellSpacing("0");
								itemTable.SetWidth("100%");
								
								HTMLTableRow itemRow = new HTMLTableRow();
								itemTable.AddInnerHTMLElement(itemRow);
								itemRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
								
								HTMLTableCell itemCell = new HTMLTableCell();
								itemRow.AddInnerHTMLElement(itemCell);
								itemCell.SetColSpan("1");
								itemCell.SetAlign("center");
								itemCell.SetHeight("30");
								itemCell.SetVAlign("top");
								itemCell.SetWidth("0%");
								itemCell.SetStyleClass(PTStyleClass.LIST_TEXT);
								
								PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.ICON_GROUP, true, this.m_asOwner);
								HTMLImg itemImg = (HTMLImg) myConstruct.GetHTMLElement();
								itemCell.AddInnerHTMLElement(itemImg);
								itemImg.SetAlt(m_asOwner.GetString(1650, "ptmsgs_portalbrowsingmsgs"));
								itemImg.SetBorder("0");
								itemImg.SetWidth("16");
								itemImg.SetHeight("20");

								itemCell = new HTMLTableCell();
								itemRow.AddInnerHTMLElement(itemCell);
								itemCell.SetColSpan("1");
								itemCell.SetVAlign("middle");
								itemCell.SetHeight("30");
								itemCell.SetWidth("100%");
								
								HTMLSpan itemSpan = new HTMLSpan();
								itemCell.AddInnerHTMLElement(itemSpan);
								itemSpan.SetStyleClass(PTStyleClass.LIST_SUBTITLE);
								itemSpan.AddInnerHTMLEncodedString((String) asqrSubGroups.GetFields(
										nFolderIndexRef,PT_PROPIDS.PT_PROPID_NAME));
								
								myConstruct = UIConstructFactory.GetConstruct(PTImageType.SPACER, true, this.m_asOwner);
								itemImg	= (HTMLImg) myConstruct.GetHTMLElement();
								itemCell.AddInnerHTMLElement(itemImg);
								itemImg.SetWidth("1");
								itemImg.SetHeight("13");
								itemImg.SetBorder("0");
								
								itemCell.AddInnerHTMLElement(new HTMLBr());
								
								itemImg	= (HTMLImg) myConstruct.GetHTMLElement();
								itemCell.AddInnerHTMLElement(itemImg);
								itemImg.SetWidth("1");
								itemImg.SetHeight("1");
								itemImg.SetBorder("0");
							}

							nFolderIndexRef++;
							count++;
						}
					}
				}

				// display the folders, if there are any
				if (nSubGroupCount > 0)
				{
					myGroup.AddInnerHTMLElement(groupTable);
				}
			}
		}
		catch (HTMLException he)
		{
			log.Error(he, "Error in " + STR_MVC_CLASS_NAME +
				" Section creating groups table.");
		}

		return result;
	}

	/**
	 *
	 * @return PTBreadcrumbPath
	 * @throws HTMLException
	 */
	private PTBreadcrumbPath GetBreadcrumbPath()
	{
		PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();

		XPStringTokenizer strPath = new XPStringTokenizer(m_asModel.GetGroupPath(),
				"\\");
		Object[] oIDs			  = m_asModel.GetParentGroupIDs();

		ASURL myURL = new ASURL(m_asOwner);
		myURL.SetLinkGetCachedSpace(m_asOwner);
		myURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
		myURL.SetDisplayPage(SiteMapDP.STR_MVC_CLASS_NAME);
		myURL.AddControlArgument(SetSiteMapControl.m_CommunityID,
			XPConvert.ToString(m_asModel.GetCommunityID()));
		myURL.AddControlArgument(SetSiteMapControl.m_Mode,
			XPConvert.ToString(m_asModel.GetMode()));

		myURL.AddInnerHTMLString(m_asModel.GetSiteMapRootName());
		myCrumbs.appendAnchorItem((HTMLAnchor) myURL.GetURLAsHTMLElement());

		if (0 != oIDs.length)
		{
			myURL = new ASURL(m_asOwner);
			myURL.SetLinkGetCachedSpace(m_asOwner);
			myURL.SetDisplayPage(MembersDP.STR_MVC_CLASS_NAME);
			myURL.SetControl(SetGroupControl.STR_MVC_CLASS_NAME);

			myURL.AddInnerHTMLString(m_asOwner.GetString(948,
					"ptmsgs_portalbrowsingmsgs"));
			myCrumbs.appendAnchorItem((HTMLAnchor) myURL.GetURLAsHTMLElement());
		}
		else
		{
			myCrumbs.appendTextItem(m_asOwner.GetString(948,
					"ptmsgs_portalbrowsingmsgs"));
		}

		int i   = 0;
		int end = strPath.GetTokenCount();

		while (strPath.HasMoreTokens())
		{
			if (i < (end - 1))
			{
				String strName = XPHttpUtility.UrlDecode(strPath.GetNextToken(), LinkConstants.UTF_8_ENCODING); 
				
				myURL = new ASURL(m_asOwner);
				myURL.SetLinkGetCachedSpace(m_asOwner);
				myURL.SetControl(SetGroupControl.STR_MVC_CLASS_NAME);
				myURL.AddControlArgument(SetGroupControl.m_GroupID,
					XPConvert.ToString(oIDs[i]));
				myURL.AddInnerHTMLEncodedString(strName);

				myCrumbs.appendAnchorItem((HTMLAnchor) myURL.GetURLAsHTMLElement());
			}
			else
			{
				String strName = XPHttpUtility.UrlDecode(strPath.GetNextToken(), LinkConstants.UTF_8_ENCODING);
				
				myCrumbs.appendTextItem(XPHttpUtility.HtmlEncode(strName));

				// Probably not necessary -- should break out of loop after this.
			}

			i++;
		}

		return myCrumbs;
	}
}

