package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.error.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * File: SetGroupControl.java
 * --------------------------
 *
 * @author NaveenP
 */
public class SetGroupControl implements IControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SetGroupControl");

	
	public static final String STR_MVC_CLASS_NAME = "SetGroup";

	/** Community ID Query String Param */
	public static final int BROWSE = 0;

	/** Community ID Query String Param */
	public static final int EDIT = 1;

	/** Community ID Query String Param */
	public static final String m_GroupID = "GroupID";

	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private SiteMapModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		String[] sValues = (String[]) arguments.GetElement(SetSiteMapControl.m_CommunityID);
		int nCommunityID = -1;

		if (sValues != null)
		{
			try
			{
				nCommunityID = XPConvert.ToInteger(sValues[0]);
				m_asModel.SetCommunityID(nCommunityID);
			}
			catch (Exception e)
			{
				log.Error(e, "Server Error");

				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, e.getMessage(),
						e.getMessage());
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
		}

		sValues = (String[]) arguments.GetElement(SetSiteMapControl.PREVIEW);

		if(sValues != null)
		{
			m_asModel.SetToPreviewPage();
		}

		sValues = (String[]) arguments.GetElement(m_GroupID);
		int nGroupID;

		if (sValues == null)
		{
			log.Info("could not find group ID in query string.");

			nGroupID = 0;
			m_asModel.ClearGroups();
		}
		else
		{
			nGroupID = XPConvert.ToInteger(sValues[0]);
			if (!m_asModel.SetGroupID(nGroupID))
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, m_asOwner.GetString(602,"ptmsgs_portalbrowsingmsgs"),
					m_asOwner.GetString(602,"ptmsgs_portalbrowsingmsgs"));
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
		}

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetGroupControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (SiteMapModel) model;
		m_asOwner     = space;
	}
}