package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * File: SetSiteMapControl.java
 * ----------------------------------
 *
 * @author NaveenP
 */
public class SetSiteMapControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SetSiteMapControl");

	
	public static final String STR_MVC_CLASS_NAME = "SetSiteMap";

	/** Community ID Query String Param */
	public static final int BROWSE = 0;

	/** Community ID Query String Param */
	public static final int EDIT = 1;

	/** Community ID Query String Param */
	public static final String m_CommunityID = "CommunityID";

	/** Community ID Query String Param */
	public static final String m_FolderID = "FolderID";

	/** Community ID Query String Param */
	public static final String m_Mode = "Mode";
	
	/** Is Preview? */
	public static final String PREVIEW = "Preview";

	
	/** Activity Space */
	private AActivitySpace m_asOwner;

	/** model */
	private SiteMapModel m_asModel;

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Execute()
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		try
		{
			String[] sValues = (String[]) arguments.GetElement(m_CommunityID);
			int nCommunityID = -1;

			if (sValues == null)
			{
				
					log.Error("could not find community ID in query string.");
				

				throw new Exception(m_asOwner.GetString(955,
						"ptmsgs_portalbrowsingmsgs"));
			}
			else
			{
				nCommunityID = XPConvert.ToInteger(sValues[0]);
			}

			sValues = (String[]) arguments.GetElement(m_FolderID);

			int nFolderID = -1;

			if (sValues == null)
			{
				
					log.Info("could not find folder ID in query string.");
				
			}
			else
			{
				nFolderID = XPConvert.ToInteger(sValues[0]);
			}

			sValues = (String[]) arguments.GetElement(m_Mode);

			int nMode = -1;

			if (sValues == null)
			{
				
					log.Error("could not find mode in query string.");
				

				throw new Exception(m_asOwner.GetString(954,
						"ptmsgs_portalbrowsingmsgs"));
			}
			else
			{
				nMode = XPConvert.ToInteger(sValues[0]);
			}

			m_asModel.SetCommunityID(nCommunityID);
			m_asModel.OpenSubFolder(nFolderID);

			if (nMode == BROWSE)
			{
				m_asModel.SetBrowseMode();
			}
			else if (nMode == EDIT)
			{
				m_asModel.SetEditMode();
			}
			
			sValues = (String[]) arguments.GetElement(PREVIEW);

			if(sValues != null)
			{
				m_asModel.SetToPreviewPage();
			}
		}
		catch (Exception e)
		{
			log.Error(e, "Server Error");

			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, e.getMessage(),
					e.getMessage());
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SetSiteMapControl();
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IControl#Init(IModel,
	 *      AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_asModel     = (SiteMapModel) model;
		m_asOwner     = space;
	}
}

