package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.common.createfolder.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.form.pagination.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapAS.java
 * --------------------
 *
 * @author NaveenP
 */
public class SiteMapAS extends PlumtreeAS
{
	
	public static final String STR_MVC_CLASS_NAME = "SiteMap";

	
	public static final String s_strCommSelectionFolderView = "CommSelectionFolderView";

	
	public static final String s_strMembersObjectView = "MembersObjectView";

	
	public static final String s_strSubCommunitiesObjectView = "SubCommunitiesObjectView";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapAS();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IActivitySpace#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 * AS that extends PlumtreeAS must call this super method if overridden to check for changed navigation scheme
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		// If it's a guest user, check if the sitemap is enabled for guests.
		if (((IPTSession) this.GetUserSession()).GetSessionInfo().CheckCurrentUserIsGuest())
		{
			// Get the string value first, since getasint will throw an exception if it's not present.
			String strValue = PTConfigHelper.GetConfigVariableAsString(PTConfigConstants.COMMUNITIES_SECTION,
				PTConfigConstants.SITE_MAP_ENABLED_FOR_GUEST_SUBSECTION,
				PTConfigConstants.VALUE_ATTRIBUTE, this);
	
			if ((null != strValue) && (!"".equals(strValue)))
			{
				int nEnabled = PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.COMMUNITIES_SECTION,
					PTConfigConstants.SITE_MAP_ENABLED_FOR_GUEST_SUBSECTION,
					PTConfigConstants.VALUE_ATTRIBUTE, this);
	
				return (nEnabled == 1);
			} else
			{
				// Missing config section, assume disabled for security purposes.
				return false;
			}
		}

		// Logged in users can access the sitemap.
		return true;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetRepostControlName()
	{
		return SiteMapRepostControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();

		SetTrackCurrentPage(true);

		// SiteMap DisplayPages
		SiteMapDP smDP = new SiteMapDP();
		smDP.SetAddMainForm(true);
		RegisterPage(smDP);

		RegisterPage(new DisplayInPortletDP());
		RegisterPage(new CreateFolderDP());
		RegisterPage(new ClosePopUpDP());
		
		MembersDP membersDP = new MembersDP();
		membersDP.SetAddMainForm(true);
		RegisterPage(membersDP);
		
		SubCommunitiesDP subCommDP = new SubCommunitiesDP();
		RegisterPage(subCommDP);

		// SiteMap Model
		RegisterModel(SiteMapModel.STR_MVC_CLASS_NAME);
		RegisterModel(ObjectSelectionModel.STR_MVC_CLASS_NAME);

		IModel sitemapModel = GetModel(SiteMapModel.STR_MVC_CLASS_NAME);

		// SiteMap Views
		RegisterView(SiteMapBreadcrumbView.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterView(SiteMapBannerView.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterView(FolderView.STR_MVC_CLASS_NAME, sitemapModel);

		RegisterView(ObjectView.STR_MVC_CLASS_NAME, sitemapModel);

		IObjectViewHelper objHelper = new SiteMapLinkViewHelper();
		((ObjectView) GetView(ObjectView.STR_MVC_CLASS_NAME)).SetObjectViewHelper(objHelper);

		RegisterView(SiteMapCreateFolderView.STR_MVC_CLASS_NAME, CreateFolderView.STR_VIEW_STORAGE_NAME, sitemapModel);
		RegisterView(DisplayInPortletView.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterView(MemberAndSubCommunitiesView.STR_MVC_CLASS_NAME,
			sitemapModel);
		RegisterView(MembersView.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterView(SubCommunitiesView.STR_MVC_CLASS_NAME, sitemapModel);

		RegisterView(ObjectView.STR_MVC_CLASS_NAME, s_strMembersObjectView,
			sitemapModel);
		objHelper = new MembersViewHelper();
		((ObjectView) GetView(s_strMembersObjectView)).SetObjectViewHelper(objHelper);

		RegisterView(ObjectView.STR_MVC_CLASS_NAME,
			s_strSubCommunitiesObjectView, sitemapModel);
		objHelper = new SubCommunitiesViewHelper();
		((ObjectView) GetView(s_strSubCommunitiesObjectView)).SetObjectViewHelper(objHelper);

		// SiteMap Controls
		RegisterControl(SetSiteMapControl.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterControl(DisplayInPortletControl.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterControl(SiteMapRepostControl.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterControl(SetGroupControl.STR_MVC_CLASS_NAME, sitemapModel);
		
		RegisterControl(DefaultSiteMapPageControl.STR_MVC_CLASS_NAME, "", sitemapModel);
		
		RegisterModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);

		IModel mySiteMapPluginModel = GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
		//Register the display page
		RegisterPage(new SiteMapCreateWebLinkDP());
		//The Site map folder views
		RegisterView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		RegisterView(SiteMapCreateWebLinkView.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		//The site map folder control
		RegisterControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME, mySiteMapPluginModel);
		
		// Pagination Control
		RegisterControl(PaginationControl.STR_MVC_CLASS_NAME, sitemapModel);
		RegisterControl(PassthruControl.STR_MVC_CLASS_NAME, sitemapModel);

		((AActivitySpace) this).SetOverWriteSubSpaces(true);
	}
	
	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#GetStyleSheetLinks()
	 */
	public HTMLElementCollection GetStyleSheetLinks()
	{
		String settingLanguage = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LANGUAGE,
				this);

		SiteMapModel myModel				  = (SiteMapModel) GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
		int nHeaderID						  = myModel.GetHeaderID(myModel.GetCommunityID());
		String strStyleSheet				  = "";

		if (nHeaderID > 0)
		{
			strStyleSheet = myModel.GetStyleSheet(myModel.GetCommunityID());
		}

		HTMLElementCollection pCollection = null;

		if (!("").equals(strStyleSheet) && (strStyleSheet != null))
		{
			if (GetIsAccessStyleNonStandard())
			{
				strStyleSheet = PlumtreeHelpers.STYLE_PREFIX_508 + strStyleSheet;
			}

			PTStyleSheetLink ptStyleSheetLink = new PTStyleSheetLink(strStyleSheet,
					settingLanguage);
			pCollection = new HTMLElementCollection();

			try
			{
				pCollection.AddInnerHTMLElement(ptStyleSheetLink.GetLinkAsHTMLElement(ConfigHelper.GetStyleSheetsBaseURL(this)));
			}
			catch (HTMLException e)
			{
			}
			catch (Exception e)
			{
			}
		}
		else
		{
			// use the default subportal stylesheet
			pCollection = super.GetStyleSheetLinks();
		}

		return pCollection;
	}	
}