package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapBreadcrumbView.java
 * --------------------------------
 *
 * @author NaveenP
 */
public class SiteMapBreadcrumbView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapBreadcrumbView");

	
	public static final String STR_MVC_CLASS_NAME = "SiteMapBreadcrumb";
	private AActivitySpace m_asOwner;
	private IFolderModelRO m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapBreadcrumbView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		//Display the Breadcrumb path, flush left to the margin
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;

		try
		{
			// Bread crumb path
			myGroup.AddInnerHTMLElement(GetBreadcrumbPath()
				.GetPathAsHTMLElement());
			myGroup.AddInnerHTMLElement(new HTMLBr());
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating " +
					STR_MVC_CLASS_NAME + " Section: " + e.getMessage() +
					"<BR>");
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#getName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IFolderModelRO) model;
		m_asOwner     = parent;
	}

	/**
	 *
	 * @return PTBreadcrumbPath
	 * @throws HTMLException
	 */
	private PTBreadcrumbPath GetBreadcrumbPath()

	{
		PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();

		XPStringTokenizer stPath = new XPStringTokenizer(m_asModel.GetPath(),
				"\\");
		Object[] oIDs			 = m_asModel.GetParentFolderIDs();

		// In the case of the root folder, there will be two oIDs even though there
		// is only one folder in stPath.  Otherwise there will be an equal number of
		// IDs and folder names.		
		if (oIDs.length < stPath.GetTokenCount())
		{
			
				log.Error("There are more parent names (" + stPath.GetTokenCount() +
					"than ids (" + oIDs.length + ").");
			

			return myCrumbs;
		}

		SiteMapModel model = (SiteMapModel) m_asModel;
		ASURL myURL;
		int i			   = 0;
		int end			   = stPath.GetTokenCount();

		while (stPath.HasMoreTokens())
		{
			if (i < (end - 1))
			{
				myURL = new ASURL(m_asOwner);
				myURL.SetLinkGetCachedSpace(m_asOwner);
				myURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
				myURL.AddControlArgument(SetSiteMapControl.m_CommunityID,
					model.GetCommunityID());
				myURL.AddControlArgument(SetSiteMapControl.m_FolderID,
				XPConvert.ToInteger(oIDs[i++]));
				myURL.AddControlArgument(SetSiteMapControl.m_Mode,
					model.GetMode());
				myURL.AddInnerHTMLEncodedString(
						stPath.GetNextToken());

				myCrumbs.appendAnchorItem((HTMLAnchor) myURL.GetURLAsHTMLElement());
			}
			else
			{
				myCrumbs.appendTextItem(XPHttpUtility.HtmlEncode(stPath.GetNextToken()));

				// Probably not necessary -- should break out of loop after this.
				i++;
			}
		}

		return myCrumbs;
	}
}

