package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapDP.java
 * --------------------
 *
 * @author NaveenP
 */
public class SiteMapDP extends PlumtreeDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapDP");

	
	public static final String STR_MVC_CLASS_NAME = "SiteMap";
	
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		return m_asOwner.GetString(971, "ptmsgs_portalbrowsingmsgs");
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		NavigationModel modelNavigation = (NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME);

		return modelNavigation.GetCurCommunityName();
	}

	/**
	 * helper display method for PlumtreeDP
	 *
	 * Fill in the body argument with HTML to display in the page.
	 */
	public HTMLElement PageDisplay()
	{
		// rob: we need to get the model here, can't set it in the init method since it hasn't been created at that time
		// (don't know why)
		SiteMapModel m_asModel= (SiteMapModel) m_asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);

		if ( m_asModel == null ) {
			throw new XPIllegalStateException("Unable to display the SiteMap page, the SiteMap Model has not been initialized.");
		}
		
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable table = new HTMLTable();
		table.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		table.SetBorder(CommonHTMLStrings.ZERO);
		//table.SetCellSpacing("10");
		table.SetCellSpacing(CommonHTMLStrings.ZERO);
		table.SetCellPadding(CommonHTMLStrings.ZERO);
		
		HTMLTableRow row = new HTMLTableRow();
		table.AddInnerHTMLElement(row);
		HTMLTableCell cell = new HTMLTableCell();
		row.AddInnerHTMLElement(cell);		

		try
		{	
			//Breadcrumbs
			if (!m_asModel.InRootFolder())
			{
				result.AddInnerHTMLElement(m_asOwner.GetView(
						SiteMapBreadcrumbView.STR_MVC_CLASS_NAME).Display());
			}

			// browse or edit bar	
			result.AddInnerHTMLElement(m_asOwner.GetView(
					SiteMapBannerView.STR_MVC_CLASS_NAME).Display());

			// members and subcommunities	
			result.AddInnerHTMLElement(m_asOwner.GetView(
					MemberAndSubCommunitiesView.STR_MVC_CLASS_NAME).Display());

			//Folders
			FolderView folderView = (FolderView) m_asOwner.GetView(FolderView.STR_MVC_CLASS_NAME);

			if (m_asModel.InRootFolder())
			{
				// Don't show "No Subfolders in this folder" message in root because we have members and subcomms
				folderView.SetShowNoFolderMessage(false);
			}
			else
			{
				folderView.SetShowNoFolderMessage(true);
			}

			result.AddInnerHTMLElement(m_asOwner.GetView(
					FolderView.STR_MVC_CLASS_NAME).Display());

			result.AddInnerHTMLElement(DirConstants.CreateSpacerTable(15,1));

			// links - display if not in root folder
			if (!m_asModel.InRootFolder())
			{
				result.AddInnerHTMLElement(m_asOwner.GetView(
						ObjectView.STR_MVC_CLASS_NAME).Display());
			}
			cell.AddInnerHTMLElement(result);
		}
		catch (HTMLException he)
		{
			log.Error(he, "Error in SiteMapDP::Display.");
		}

		return table;
	}

	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLScriptCollection DisplayJavaScriptFromChild()
	{
		// rob: we need to get the model here, can't set it in the init method since it hasn't been created at that time
		// (don't know why)
		SiteMapModel m_asModel = (SiteMapModel) m_asOwner.GetModel(SiteMapModel.STR_MVC_CLASS_NAME);
		
		if ( m_asModel == null ) {
			throw new XPIllegalStateException("Unable to display the SiteMap page, the SiteMap Model has not been initialized.");
		}
		
		HTMLScriptCollection scripts = new HTMLScriptCollection();

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		script.SetSrc(ConfigHelper.GetPortalImageServerJavaScriptURL(m_asOwner) +
			"opennewwindow.js");

		scripts.AddInnerHTMLElement(script);
		scripts.AddInnerHTMLElement(m_asOwner.GetView(
				SiteMapBannerView.STR_MVC_CLASS_NAME).DisplayJavascript());
		
		if(!m_asModel.InRootFolder()) {		
			scripts.AddInnerHTMLElement(m_asOwner.GetView(
							ObjectView.STR_MVC_CLASS_NAME).DisplayJavascript());
		}
				
		SiteMapFolderPlugInView plugInView = (SiteMapFolderPlugInView)
			m_asOwner.GetView(SiteMapFolderPlugInView.STR_MVC_CLASS_NAME);
		
		if(m_asModel.IsEditMode()) {	
			scripts.AddInnerHTMLElement(plugInView.DisplayJavascript());
		}

		return scripts;
	}
}

