package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.sitemap.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portaluiinfrastructure.editor.commonpages.localizednames.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapFolderViewHelper
 * -----------------------------
 *
 * @author NaveenP
 */
public class SiteMapFolderViewHelper implements IFolderViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapFolderViewHelper");

	// Query parameter name for the checkbox

	
	public static final String HTMLINPUT_SELECTION_FOLDER = "in_cb_Folder";
	
	public static final int CONSTANT_NUM_SUBFOLDERS_TO_DISPLAY = 5;

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayObject(int, HTMLTable, IFolderModelRO)
	 */
	public int DisplayFolder(int nFolderQueryIndex, HTMLTableCell tableCell,
		IFolderModelRO model, AActivitySpace asOwner)
	{
		try
		{
			SiteMapModel smModel = (SiteMapModel) model;

			// get the folder query
			//IASQueryResult qrFolders = model.GetFolderQueryResult();
			PTSortedArrayWrapper arrSortedSubFolders = smModel.GetSortedSubFolders();

			// get name, folder ID, and folder URL from query
			log.Info("index is " + nFolderQueryIndex);

			int intFolderID = XPConvert.ToInteger(arrSortedSubFolders.GetItem(nFolderQueryIndex,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String strName	    = (String) arrSortedSubFolders.GetItem(nFolderQueryIndex,
					PT_PROPIDS.PT_PROPID_NAME);
			String strFolderID  = XPConvert.ToString(intFolderID);

			//int nRelativeFolderLevel = XPConvert.ToInteger(arrSortedSubFolders.GetItem(nFolderQueryIndex, PT_PROPIDS.PT_PROPID_FOLDER_LEVEL));
			// Open folder URL
			ASURL url = new ASURL(asOwner);
			url.SetLinkGetCachedSpace(asOwner);
			url.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
			url.AddControlArgument(SetSiteMapControl.m_CommunityID,
				smModel.GetCommunityID());
			url.AddControlArgument(SetSiteMapControl.m_FolderID, strFolderID);
			url.AddControlArgument(SetSiteMapControl.m_Mode,
				XPConvert.ToString(smModel.GetMode()));

			String strURL = url.GetURLAsString();

			// use list item construct
			UIListItem itemConstruct = new UIListItem(XPHttpUtility.HtmlEncode(
						strName), strURL, asOwner);

			itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER,
				asOwner.GetString(973, "ptmsgs_portalbrowsingmsgs"));
			itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			itemConstruct.SetMaxNumSubLinksDisplayed(CONSTANT_NUM_SUBFOLDERS_TO_DISPLAY);

			// check if there's a checkbox item and set style
			if (smModel.IsEditMode())
			{
				itemConstruct.EnableCheckbox(HTMLINPUT_SELECTION_FOLDER,
					strFolderID, strURL,
					model.GetIsFolderSelected(intFolderID));
				itemConstruct.SetCellHeight("20");

				if ((nFolderQueryIndex % 2) == 0)
				{
					itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
				}
				else
				{
					itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
				}
				
				ASURL editNameURL = new ASURL(asOwner);
				editNameURL.SetLinkCreateNewSpace(SiteMapFolderEditorAS.STR_MVC_CLASS_NAME,
					asOwner);
				editNameURL.SetDisplayPage(LocNamesDP.STR_MVC_CLASS_NAME);
				editNameURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
				editNameURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
					EditorStartControl.EDITOR_START_FLAG_EDIT);
				editNameURL.AddControlArgument(SiteMapFolderModel.EDITOR_QS_INT_CLASS_ID,
					PT_CLASSIDS.PT_SITEMAPFOLDER_ID);
				editNameURL.AddControlArgument(SiteMapFolderModel.QS_NAMEORSECURITY,
					SiteMapFolderModel.EDIT_TYPE_NAME_DESC);
				editNameURL.AddControlArgument(SiteMapFolderModel.QS_STARTEDINSITEMAP,
					1);
				editNameURL.AddControlArgument(SiteMapFolderModel.EDITOR_QS_INT_QS_OBJECT_ID,
					strFolderID);
				
				itemConstruct.SetItemEditButton(PTImageType.ICON_EDIT, asOwner.GetString(965,
					"ptmsgs_portalbrowsingmsgs"), "#");
				HTMLAnchor editItem = itemConstruct.GetEditAnchor();
				editItem.SetTitle(asOwner.GetString(965, "ptmsgs_portalbrowsingmsgs"));
				editItem.SetOnClick("OpenLargePreviewWindow('" + editNameURL.GetURLAsString() + "');"); 
			}
			else
			{
				PTSortedArrayWrapper arrCurrSortedSubSubFolders = smModel.GetSortedSubSubFoldersFromParentID(intFolderID);
				int nSubSubFolderCount						    = arrCurrSortedSubSubFolders.GetCount();

				for (int i = 0; i < nSubSubFolderCount; i++)
				{
					if (i >= CONSTANT_NUM_SUBFOLDERS_TO_DISPLAY)
					{ 
						break;
					}

					// get sub-subfolder ids
					int intCurrFolderID = XPConvert.ToInteger(arrCurrSortedSubSubFolders.GetItem(i,
							PT_PROPIDS.PT_PROPID_OBJECTID));

					// folder name
					strName     = (String) arrCurrSortedSubSubFolders.GetItem(i,
							PT_PROPIDS.PT_PROPID_NAME);
							
					int intParentFolderID = XPConvert.ToInteger(arrCurrSortedSubSubFolders.GetItem(i, PT_PROPIDS.PT_PROPID_FOLDER_PARENTFOLDERID));
					
					//check if the subfolder is within the current folder.
					if (intParentFolderID == intFolderID){
						//construct sub-subfolder URL
						url = new ASURL(asOwner);
						url.SetLinkGetCachedSpace(asOwner);
						url.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
						url.AddControlArgument(SetSiteMapControl.m_CommunityID,
							smModel.GetCommunityID());
						url.AddControlArgument(SetSiteMapControl.m_FolderID,
							intCurrFolderID);
						url.AddControlArgument(SetSiteMapControl.m_Mode,
							smModel.GetMode());

						HTMLAnchor a = (HTMLAnchor) url.GetURLAsHTMLElement();
						a.SetTitle(strName);
						a.AddInnerHTMLEncodedString(strName);
					
						itemConstruct.AddSubLink(a, false, false);
					}
				}
			}

			// convert the construct to table
			try
			{
				HTMLTable folderTable = itemConstruct.GetItemAsTable();
				tableCell.AddInnerHTMLElement(folderTable);
			}
			catch (Exception e)
			{
									
					log.Error(e, "Error in SiteMapFolderViewHelper::DisplayFolder: ");
				
			}

			nFolderQueryIndex++;
		}
		catch (Exception e)
		{
			log.Error("Couldn't retrieve folder at " + nFolderQueryIndex);
		}

		return nFolderQueryIndex;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int)
	 */
	public void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID, IFolderModelRO _model, AActivitySpace _space)
	{
		ASURL url = new ASURL(_space);
		url.SetLinkGetCachedSpace(_space);
		url.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
		url.AddControlArgument(SetSiteMapControl.m_CommunityID,
			((SiteMapModel)_model).GetCommunityID());
		url.AddControlArgument(SetSiteMapControl.m_FolderID, _nFolderID);
		url.AddControlArgument(SetSiteMapControl.m_Mode,
			((SiteMapModel)_model).GetMode());

		_anchor.SetHRef(url.GetURLAsString());
	}
}

