package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.sitemap.editweblink.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portalpages.common.objects.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapLinkViewHelper.java
 * --------------------------------
 *
 * @author NaveenP
 */
public class SiteMapLinkViewHelper implements IObjectViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapLinkViewHelper");

	
	public static final String HTMLINPUT_SELECTION_OBJECT = "in_cb_Object";

	
	public static final String HTMLINPUT_SELECTED_OBJECT = "in_hi_SelectedObject";

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#AddObjectViewHTML()
	 */
	public HTMLElement AddObjectViewHTML(IObjectModelRO model)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.
	 * IObjectViewHelper#GetThereAreNoItemsString(AActivitySpace)
	 */
	public String GetThereAreNoItemsString(AActivitySpace asOwner)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#Display508Object(int, HTMLTable, IObjectModelRO, AActivitySpace)
	 */
	public void Display508Object(int nObjectIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace parent)
	{
		DisplayObject(nObjectIndex, 0, tableObjects, model, parent);
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayJavascriptCollection(AActivitySpace)
	 */
	public HTMLScriptCollection DisplayJavascriptCollection(
		AActivitySpace asOwner, IObjectModelRO model)
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#DisplayObject(int,
	 *      HTMLTable, IObjectModelRO)
	 */
	public void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace asOwner)
	{
		SiteMapModel siteMapModel = (SiteMapModel) model;

		ICPListEntryIterator cpList = siteMapModel.GetListIterator();
		CListURLMediator mediator   = new CListURLMediator(asOwner, cpList);
		mediator.SetLabelMaxLength(50);
		mediator.SetShowImages(false);

		HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntryAtIndex(nObjectIndex);
		ListEntry objEntry = cpList.GetEntryAtIndex(nObjectIndex);

		HTMLTableRow row = null;

		int iObjectID = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_OBJECTID));

		//String strLinkName = (String) model.GetObjectFields(nObjectIndex, PT_PROPIDS.PT_PROPID_NAME);
		String strLinkDesc = (String) model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_DESCRIPTION);
		int nType		   = XPConvert.ToInteger(model.GetObjectFields(nObjectIndex,
				PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID));

		if (DirConstants.DESCRIPTION_ABBR_LENGTH < strLinkDesc.length())
		{
			strLinkDesc = strLinkDesc.substring(0,
					DirConstants.DESCRIPTION_ABBR_LENGTH) + "...";
		}

		try
		{
			// use list item construct
			UIListItem itemConstruct = new UIListItem(anchor, asOwner); // label is HTMLEncoded in the ASURLContainer
			itemConstruct.SetDescription(XPHttpUtility.HtmlEncode(strLinkDesc));

			String strImageAlt = objEntry.GetImageAltTextEncoded();
			if(strImageAlt == null || strImageAlt.equals(""))
			{
				strImageAlt = "";
			} 

			itemConstruct.SetItemTypeImage(GetIcon(nType),
				strImageAlt);

			if (((SiteMapModel) model).IsEditMode())
			{
				itemConstruct.EnableCheckbox(HTMLINPUT_SELECTION_OBJECT,
					XPConvert.ToString(iObjectID), strLinkDesc,
					model.GetIsObjectSelected(iObjectID));
			}

			row = new HTMLTableRow();

			if (0 == (nRowIndex % 2))
			{
				row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			} 
			else
			{
				row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
			}

			if (siteMapModel.IsEditMode())
			{
				if (nType == PT_CLASSIDS.PT_SITEMAPWEBLINK_ID)
				{
					//Edit Card URL
					String strFolderID = XPConvert.ToString(siteMapModel.GetCurrentFolderID());

					ASURL url = new ASURL(asOwner);
					url.SetLinkCreateNewSpace(EditWebLinkAS.STR_MVC_CLASS_NAME,
						asOwner);
					url.SetDisplayPage(EditWebLinkDP.STR_MVC_CLASS_NAME);
					url.SetControl(SetLinkControl.STR_MVC_CLASS_NAME);
					url.AddControlArgument(SetLinkControl.m_FolderID,
						strFolderID);
					url.AddControlArgument(SetLinkControl.m_LinkID,
						XPConvert.ToString(iObjectID));

					itemConstruct.SetItemEditButton(PTImageType.ACTION_EDIT,
						asOwner.GetString(974, "ptmsgs_portalbrowsingmsgs"),
						"#");
						
					HTMLAnchor anchor2 = itemConstruct.GetEditAnchor();
					anchor2.SetHRef("#");
					anchor2.SetTitle(asOwner.GetString(974, "ptmsgs_portalbrowsingmsgs"));
					anchor2.SetOnClick("OpenPreviewWindow('" + url.GetURLAsString() + "');return false;");
				}
				else
				{
					itemConstruct.SetAlwaysDrawEditItemCell(true);
				}
			}

			itemConstruct.AddItemCellsToRow(row);
			tableObjects.AddInnerHTMLElement(row);
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectViewHelper#SetExpandButton(HTMLAnchor, IObjectModelRO)
	 */
	public void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model)
	{
	}

	/**
	 * 
	 *
	 * @param nType 
	 *
	 * @return 
	 */
	private static PTImageType GetIcon(int nType)
	{
		PTImageType type;

		switch (nType)
		{
		case PT_CLASSIDS.PT_PAGE_ID:
			type = PTImageType.ICON_COMMUNITY;

			break;

		case PT_CLASSIDS.PT_USER_ID:
			type = PTImageType.ICON_USER;

			break;

		case PT_CLASSIDS.PT_CATALOGCARD_ID:
			type = PTImageType.ICON_DOCUMENT;

			break;

		case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
			type = PTImageType.ICON_FOLDER;

			break;

		case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
			type = PTImageType.ICON_DOCUMENT_URL;

			break;

		default:
			type = PTImageType.ICON_ERROR;
		}

		return type;
	}
}

