package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.portlets.sitemap.prefs.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.form.pagination.*;
import com.plumtree.uiinfrastructure.form.sort.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapModel.java
 * -----------------------
 *
 * This model contains data for the Site Map.
 *
 * @author NaveenP
 */
public class SiteMapModel extends AClearModel implements ISiteMapModelRO,
	IFolderModel, IRepostModel, ISortModel, IPaginationModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapModel");

	/** Activity space name */
	public static final String STR_MVC_CLASS_NAME = "SiteMap";

	
	public static final int NO_FOLDER_SELECTED = -1;

	
	public static final int FOLDERID_NOT_INITIALIZED = -2;
	
	private static final String m_userInterface508 = "http://www.plumtree.com/uis/section508";


	
	public int m_nObjectType = -1;


	/** Store session and catalog to retrieve data */
	protected IPTSession m_ptSession;

	/** Logger */
	private AActivitySpace m_asOwner = null;

	/** Group IDs */
	private XPArrayList m_arrGroupIDs;

	/** community iD */
	private int m_nCommunityID = -1;

	/** Current Folder ID */
	private int m_nCurrentFolderID = -1;

	/** Mode - browse or edit */
	private int m_nMode;

	/** community iD */
	private int m_nSiteMapRootID;
	
	private String m_strSitemapRootName;
	
	private boolean m_bIsPreviewPage = false;
	
	public int m_nFirstLinkObjectCount = -1;
		
	public int m_nLastLinkObjectCount = -1;

	public int m_nFirstMemberObjectCount = -1;
	
	public int m_nLastMemberObjectCount = -1;

	public SiteMapModel()
	{
		super();
		m_nCurrentFolderID = SiteMapModel.FOLDERID_NOT_INITIALIZED;
		m_nObjectType = PT_CLASSIDS.PT_SITEMAPLINK_ID;
	}

	/**
	 *
	 */
	public void ClearGroups()
	{
		m_arrGroupIDs.Clear();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapModel();
	}

	/**
	 *
	 */
	public void CreateSortedSubFolders()
	{
		int nTotalSize = GetMyTempData().m_asqrSubFolders.GetCount();

		int nNumParents							   = GetNumParents();
		XPArrayList xparrSubFolders				   = new XPArrayList();
		GetMyTempData().m_tableSortedSubSubFolders = new XPHashtable();

		XPArrayList xparrAllSubSubFolders		   = new XPArrayList(nNumParents);

		for (int i = 0; i < nNumParents; i++)
		{
			XPArrayList xparrCurrSubSubFolders = new XPArrayList();
			xparrAllSubSubFolders.Add(xparrCurrSubSubFolders);
		}

		int nCurrParentIndex = -1;

		for (int i = 0; i < nTotalSize; i++)
		{
			XPArrayList folderProperties = new XPArrayList(5);
			Object intAccessLevel		 = GetMyTempData().m_asqrSubFolders.GetFields(i,
					PT_PROPIDS.PT_PROPID_ACCESSLEVEL);
			Object intFolderID			 = GetMyTempData().m_asqrSubFolders.GetFields(i,
					PT_PROPIDS.PT_PROPID_OBJECTID);
			String strFolderName		 = (String) GetMyTempData().m_asqrSubFolders.GetFields(i,
					PT_PROPIDS.PT_PROPID_NAME);
			Object intParentID			 = GetMyTempData().m_asqrSubFolders.GetFields(i,
					PT_PROPIDS.PT_PROPID_FOLDER_PARENTFOLDERID);
			Object intFolderDepth		 = GetMyTempData().m_asqrSubFolders.GetFields(i,
					PT_PROPIDS.PT_PROPID_FOLDER_LEVEL);

			folderProperties.Add(intAccessLevel);
			folderProperties.Add(intFolderID);
			folderProperties.Add(strFolderName);
			folderProperties.Add(intParentID);
			folderProperties.Add(intFolderDepth);

			if (1 == XPConvert.ToInteger(intFolderDepth))
			{
				xparrSubFolders.Add(folderProperties);
				nCurrParentIndex++;
			}
			else
			{
			    if (-1 != nCurrParentIndex) {
					XPArrayList currSubSubFolders = (XPArrayList) xparrAllSubSubFolders.GetElement(nCurrParentIndex);
					currSubSubFolders.Add(folderProperties);
			    }
			}
		}

		int[] arrColIDs = new int[5];
		arrColIDs[0]     = PT_PROPIDS.PT_PROPID_ACCESSLEVEL;
		arrColIDs[1]     = PT_PROPIDS.PT_PROPID_OBJECTID;
		arrColIDs[2]     = PT_PROPIDS.PT_PROPID_NAME; // we're setting this to the gadget title bar state
		arrColIDs[3]     = PT_PROPIDS.PT_PROPID_FOLDER_PARENTFOLDERID; // we're setting this to true if there are comm prefs
		arrColIDs[4]     = PT_PROPIDS.PT_PROPID_FOLDER_LEVEL;

		int[][] arrSort  = new int[1][2];
		arrSort[0][0]    = PT_PROPIDS.PT_PROPID_NAME;
		arrSort[0][1]    = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		int nNumSubFolders = xparrSubFolders.GetSize();
		Object[][] arrSubFolders = new Object[5][nNumSubFolders];

		for (int j = 0; j < nNumParents; j++)
		{
			arrSubFolders[0][j]     = ((XPArrayList) xparrSubFolders.GetElement(j)).GetElement(0);
			arrSubFolders[1][j]     = ((XPArrayList) xparrSubFolders.GetElement(j)).GetElement(1);
			arrSubFolders[2][j]     = ((XPArrayList) xparrSubFolders.GetElement(j)).GetElement(2);
			arrSubFolders[3][j]     = ((XPArrayList) xparrSubFolders.GetElement(j)).GetElement(3);
			arrSubFolders[4][j]     = ((XPArrayList) xparrSubFolders.GetElement(j)).GetElement(4);

			Object intCurrFolderID = ((XPArrayList) xparrSubFolders.GetElement(j)).GetElement(1);

			XPArrayList currSubSubFolders   = (XPArrayList) xparrAllSubSubFolders.GetElement(j);
			int nCurrNumSubSubFolders	    = currSubSubFolders.GetSize();
			Object[][] arrCurrSubSubFolders = new Object[5][nCurrNumSubSubFolders];

			for (int k = 0; k < nCurrNumSubSubFolders; k++)
			{
				arrCurrSubSubFolders[0][k]     = ((XPArrayList) currSubSubFolders.GetElement(k)).GetElement(0);
				arrCurrSubSubFolders[1][k]     = ((XPArrayList) currSubSubFolders.GetElement(k)).GetElement(1);
				arrCurrSubSubFolders[2][k]     = ((XPArrayList) currSubSubFolders.GetElement(k)).GetElement(2);
				arrCurrSubSubFolders[3][k]     = ((XPArrayList) currSubSubFolders.GetElement(k)).GetElement(3);
				arrCurrSubSubFolders[4][k]     = ((XPArrayList) currSubSubFolders.GetElement(k)).GetElement(4);
			}

			PTSortedArrayWrapper arrSortedCurrSubSubFolders = new PTSortedArrayWrapper();
			arrSortedCurrSubSubFolders.Initialize(arrColIDs,
				arrCurrSubSubFolders, arrSort, true);
			GetMyTempData().m_tableSortedSubSubFolders.PutElement(intCurrFolderID,
				arrSortedCurrSubSubFolders);
		}

		GetMyTempData().m_arrSortedSubFolders = new PTSortedArrayWrapper();
		GetMyTempData().m_arrSortedSubFolders.Initialize(arrColIDs,
			arrSubFolders, arrSort, true);
	}

	/**
	 *
	 * @throws Exception
	 */
	public void Delete()
	{
		for (int i = 0; i < GetMyTempData().m_arrSelectedLinks.length; i++)
		{
			try
			{
				GetCurrSiteMapFolder().DeleteLink(GetMyTempData().m_arrSelectedLinks[i]);
			}
			catch (Exception e)
			{
				throw new XPException(m_asOwner.GetString(1619, "ptmsgs_portalbrowsingmsgs") + e);
			}
		}

		GetMyTempData().m_arrSelectedLinks = new int[0];

		IPTSiteMapFolderManager ptOM = (IPTSiteMapFolderManager) GetMyTempData().m_objOMSiteMapFolders.GetInterfaces(
				"IPTSiteMapFolderManager");

		for (int i = 0; i < GetMyTempData().m_arrSelectedFolders.length; i++)
		{			
			Object[] deleteResults = ptOM.RecursiveDelete(GetMyTempData().m_arrSelectedFolders[i]);
			//The first and only object in the array is the return code
			if (XPConvert.ToInteger(deleteResults[0]) != PT_RESULTCODES.PT_S_OK)
			{
				throw new XPException(m_asOwner.GetString(1620, "ptmsgs_portalbrowsingmsgs"));
			}
		
		}

		GetMyTempData().m_arrSelectedFolders = new int[0];
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#DoNotShowObject(int)
	 */
	public boolean DoNotShowObject(int nIndex)
	{
		return false;
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#Finish()
	 */
	public void Finish()
	{
	}

	/**
	 *
	 * @param ptSiteMapFolderInfo
	 * @param cpList
	 */
	public static void GetASCompoundListForSiteMapFolder(
		IPTSiteMapFolderInfo ptSiteMapFolderInfo, ASCompoundList cpList)
	{
		IPTQueryResult qrLinks = ptSiteMapFolderInfo.QueryLinks();
		int lNumLinks		   = qrLinks.RowCount();

		for (int i = 0; i < lNumLinks; i++)
		{
			String strName		  = qrLinks.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
			String strDescription = qrLinks.ItemAsString(i, PT_PROPIDS.PT_PROPID_DESCRIPTION);
			String strLinkURL     = qrLinks.ItemAsString(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKURL);
			int lLinkClassID	  = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID);
			int lLinkObjectID     = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);
			int lLinkCommID		  = qrLinks.ItemAsInt(i, PT_PROPIDS.PT_PROPID_SITEMAP_LINKPAGEID);

			switch (lLinkClassID)
			{
			case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
				cpList.AddFullURL(strName, strLinkURL, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_URL, strName);
 
				break;

			case PT_CLASSIDS.PT_PAGE_ID:
				cpList.AddCommPageURL(strName,
					lLinkCommID, lLinkObjectID, strDescription, -1);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_COMMUNITY,
					strName);

				break;

			case PT_CLASSIDS.PT_USER_ID:
				cpList.AddUserProfileURL(strName, lLinkObjectID, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_USER, strName);

				break; 

			case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
				cpList.AddDirectoryURL(strName, DirConstants.BROWSE_MODE,
					lLinkObjectID, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_FOLDER,
					strName);

				break;

			case PT_CLASSIDS.PT_CATALOGCARD_ID:
				cpList.AddDocumentURL(strName, lLinkObjectID, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_DOCUMENT,
					strName);

				break;
			}
		}
	}

	/**
	 *
	 * @param arrSortedLinks
	 * @param cpList
	 */
	public static void GetASCompoundListForSiteMapFolder(
		PTSortedArrayWrapper arrSortedLinks, ASCompoundList cpList, AActivitySpace owner)
	{
		int lNumLinks = arrSortedLinks.GetCount();

		for (int i = 0; i < lNumLinks; i++)
		{
			String strName		  = (String)arrSortedLinks.GetItem(i,
					PT_PROPIDS.PT_PROPID_NAME);
			String strDescription = (String)arrSortedLinks.GetItem(i,
					PT_PROPIDS.PT_PROPID_DESCRIPTION);
			String strLinkURL     = (String)arrSortedLinks.GetItem(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKURL);
			int lLinkClassID	  = XPConvert.ToInteger(arrSortedLinks.GetItem(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID));
			int lLinkObjectID     = XPConvert.ToInteger(arrSortedLinks.GetItem(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID));
			int lLinkCommID		  = XPConvert.ToInteger(arrSortedLinks.GetItem(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKPAGEID));

			switch (lLinkClassID)
			{
			case PT_CLASSIDS.PT_SITEMAPWEBLINK_ID:
				cpList.AddFullURL(strName, strLinkURL, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_URL, 
					owner.GetString(1790, "ptmsgs_portalbrowsingmsgs"));

				break;

			case PT_CLASSIDS.PT_PAGE_ID:
				cpList.AddCommPageURL(strName,
					lLinkCommID, lLinkObjectID, strDescription, -1);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_COMMUNITY,
					owner.GetString(1787, "ptmsgs_portalbrowsingmsgs"));
				break;

			case PT_CLASSIDS.PT_USER_ID:
				cpList.AddUserProfileURL(strName, lLinkObjectID, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_USER, 
					owner.GetString(1789, "ptmsgs_portalbrowsingmsgs"));

				break;

			case PT_CLASSIDS.PT_CATALOGFOLDER_ID:
				cpList.AddDirectoryURL(strName, DirConstants.BROWSE_MODE,
					lLinkObjectID, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_FOLDER,
					owner.GetString(1791, "ptmsgs_portalbrowsingmsgs"));

				break;

			case PT_CLASSIDS.PT_CATALOGCARD_ID:
				cpList.AddDocumentURL(strName, lLinkObjectID, strDescription);
				cpList.SetImageForLastAddedURL(PTImageType.ICON_DOCUMENT,
					owner.GetString(1788, "ptmsgs_portalbrowsingmsgs"));

				break;
			}
		}
	}
	
	/**
	 *
	 */
	public static int CreateSortedLinks(
		IPTSiteMapFolderInfo ptSiteMapFolderInfo, ASCompoundList cpList,
		String strLinkOrder, AActivitySpace owner)
	{
		IPTQueryResult qrMandLinks = ptSiteMapFolderInfo.QueryLinks();
		
		PTSortedArrayWrapper arrSortedLinks = TaskAPIUISubPortal.CreateSortedArray(qrMandLinks, strLinkOrder, owner);
		
		int nNumLinks = arrSortedLinks.GetCount();
		SiteMapModel.GetASCompoundListForSiteMapFolder(arrSortedLinks, cpList, owner);
		
		return nNumLinks;
	}

	////////////////////////
	/// ISiteMapModelRO ////
	////////////////////////

	/**
	 * @see com.plumtree.portalpages.browsing.sitemap.ISiteMapModelRO#GetCommunityID()
	 */
	public int GetCommunityID()
	{
		return m_nCommunityID;
	}

	/**
	 *
	 * @return ASQueryResultWrapper
	 */
	public PTSortedArrayWrapper GetCommunityPages()
	{
		IPTQueryResult pages = null;
		try {
			pages = GetCurrCommunity().QueryPages(0);
		} catch (Exception e) {
			log.Error(e, "Could not open community pages. ");
			
			return null;	
		}

		XPArrayList xparrPages = new XPArrayList(50);

		for (int j = 0; j < pages.RowCount(); j++)
		{ // go through each gadget in the page and check if they have preferences

			String strPageName = pages.ItemAsString(j, PT_PROPIDS.PT_PROPID_NAME);

			XPArrayList pageNameID = new XPArrayList(3);
			int nPageID			   = pages.ItemAsInt(j, PT_PROPIDS.PT_PROPID_OBJECTID);
			int nTopicPos		   = pages.ItemAsInt(j,	PT_PROPIDS.PT_PROPID_PAGES_TOPICPOS);

			pageNameID.Add(strPageName);
			pageNameID.Add(new Integer(nPageID));
			pageNameID.Add(new Integer(nTopicPos));

			xparrPages.Add(pageNameID);
		}

		// slight hack below -- we have to put propids into the sorted array, but we're not using flags & personalization
		// exactly as they are in the DB.  We basically shove gadget title bar state into the sorted array and call it
		// FLAGS, even though it's a slight variation of flags.
		int[] arrColIDs = new int[3];
		arrColIDs[0]     = PT_PROPIDS.PT_PROPID_NAME;
		arrColIDs[1]     = PT_PROPIDS.PT_PROPID_OBJECTID;
		arrColIDs[2]     = PT_PROPIDS.PT_PROPID_PAGES_TOPICPOS;

		int[][] arrSort  = new int[1][2];
		arrSort[0][0]    = PT_PROPIDS.PT_PROPID_PAGES_TOPICPOS;
		arrSort[0][1]    = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		int iNumPages    = xparrPages.GetSize();
		Object[][] arrPagesObjectArray = new Object[3][iNumPages];

		for (int k = 0; k < iNumPages; k++)
		{
			arrPagesObjectArray[0][k]     = ((XPArrayList) xparrPages.GetElement(k)).GetElement(0);
			arrPagesObjectArray[1][k]     = ((XPArrayList) xparrPages.GetElement(k)).GetElement(1);
			arrPagesObjectArray[2][k]     = ((XPArrayList) xparrPages.GetElement(k)).GetElement(2);
		}

		PTSortedArrayWrapper arrSortedPages = new PTSortedArrayWrapper();
		arrSortedPages.Initialize(arrColIDs, arrPagesObjectArray, arrSort, true);

		return arrSortedPages;
	}

	////////////////////////
	/// IFolderModelRO /////
	////////////////////////

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetCurrentFolderID()
	 */
	public int GetCurrentFolderID()
	{
		return m_nCurrentFolderID;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetCurrentFolderLevel()
	 */
	public int GetCurrentFolderLevel()
	{
		int nFolderLevel = 0;

		try
		{
			nFolderLevel = GetCurrSiteMapFolder().GetFolderDepth();
		}
		catch (Exception e)
		{
			log.Error(e, "Error Getting Folder Depth. ");
		}

		return nFolderLevel;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetCurrentFolderName()
	 */
	public String GetCurrentFolderName()
	{
		String strName;

		try
		{
			strName = GetCurrSiteMapFolder().GetLocalizedName();
		}
		catch (Exception e)
		{
			log.Error(e, "Error getting Community Knowledge Directory Name. ");

			strName = m_asOwner.GetString(981, "ptmsgs_portalbrowsingmsgs");
		}

		return strName;
	}

	/**
	 *
	 * @return int
	 */
	public int GetCurrentGroupMemberCount()
	{
		int nGroupMemberCount = 0;

		try
		{
			nGroupMemberCount = GetCurrentGroupMembers().GetCount();
		}
		catch (Exception e)
		{
			log.Error(e, "Error Getting Group Member Count. ");
		}

		return nGroupMemberCount;
	}

	/**
	 *
	 * @return IASQueryResult
	 */
	public IASQueryResult GetCurrentGroupMembers()

	{
		int nGroupLen = m_arrGroupIDs.GetSize();

		if (nGroupLen == 0)
		{
			return GetSingleMembers();
		}
		else
		{
			if (null == GetMyTempData().m_objCurrUsers)
			{
				GetMyTempData().m_objCurrUsers = new ASQueryResultWrapper(GetCurrentGroup()
						.QueryUsers());
			}

			return GetMyTempData().m_objCurrUsers;
		}
	}

	/**
	 *
	 * @return String
	 */
	public String GetCurrentGroupName()
	{
		if (m_arrGroupIDs.GetSize() == 0)
		{
			return m_asOwner.GetString(976, "ptmsgs_portalbrowsingmsgs");
		}
		else
		{
			return GetCurrentGroup().GetLocalizedName();
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IPaginationModelRO#GetCurrentLowerObjectIndex()
	 */
	public int GetCurrentLowerObjectCount()
	{
		// Default start at beginning
		int nResult = 1;
		
		if (MembersDP.STR_MVC_CLASS_NAME.equals(
							m_asOwner.GetCurrentPage().GetName()))
		{
			if (m_nFirstMemberObjectCount != -1)
			{
				// use the pagination setting if it has been set.
				nResult = (m_nFirstMemberObjectCount >= 1) ? m_nFirstMemberObjectCount : 1;
				
				IASQueryResult asQR;
				
				try {
					asQR = GetCurrentGroupMembers();
				} catch (Exception e) {
					return 1;	
				}
				
				if (nResult > asQR.GetCount())
				{
					nResult = 1;
				}
			}
		}
		else
		{
			if (m_nFirstLinkObjectCount != -1)
			{
				// use the pagination setting if it has been set.
				nResult = (m_nFirstLinkObjectCount >= 1) ? m_nFirstLinkObjectCount : 1;
	
				if (nResult > GetMyTempData().m_asclLinks.GetTotalCount())
				{
					nResult = 1;
				}
			}
		}
		
		return nResult;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IPaginationModelRO#GetCurrentUpperObjectIndex()
	 */
	public int GetCurrentUpperObjectCount()
	{
		// Default use the object count or the user's pagination preference
		int nResult = 1;

		if (MembersDP.STR_MVC_CLASS_NAME.equals(
									m_asOwner.GetCurrentPage().GetName()))
		{
			IASQueryResult asQR;
				
			try {
				asQR = GetCurrentGroupMembers();
			} catch (Exception e) {
				return 1;	
			}
			
			nResult = (asQR.GetCount() <= GetPaginationSize()) ? asQR.GetCount() : GetPaginationSize();
			
			if (m_nLastMemberObjectCount != -1)
			{
				// use the pagination setting if it has been set and is not
				// greater than the number of objects.
				nResult = (m_nLastMemberObjectCount <= asQR.GetCount()) ? m_nLastMemberObjectCount : asQR.GetCount();
			}
		} 
		else
		{
			nResult = (GetMyTempData().m_asclLinks.GetTotalCount() <= GetPaginationSize()) ? GetMyTempData().m_asclLinks.GetTotalCount() : GetPaginationSize();
			
			if (m_nLastLinkObjectCount != -1)
			{
				// use the pagination setting if it has been set and is not
				// greater than the number of objects.
				nResult = (m_nLastLinkObjectCount <= GetMyTempData().m_asclLinks.GetTotalCount()) ? m_nLastLinkObjectCount : GetMyTempData().m_asclLinks.GetTotalCount();
			}
			
		}

		return nResult;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetDisplayPaginationHiddenInputs()
	 */
	public boolean GetDisplayPaginationHiddenInputs()
	{
		return true;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetDisplaySortHiddenInputs()
	 */
	public boolean GetDisplaySortHiddenInputs()
	{
		// This will eventually return true after the framework is set up
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFirstFolderIndex()
	 */
	public int GetFirstFolderIndex()
	{
		return GetMyTempData().m_nStartAt;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderColumnCount()
	 */
	public int GetFolderColumnCount()
	{
		return GetMyTempData().m_nNumFoldCol;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderObjectCount()
	 */
	public IASQueryResult GetFolderObjectCount()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderData()
	 */
	public IASQueryResult GetFolderQueryResult()
	{
		return GetMyTempData().m_asqrSubFolders;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderViewHelper()
	 */
	public IFolderViewHelper GetFolderViewHelper()
	{
		return GetMyTempData().m_folderViewHelper;
	}

	/**
	 *
	 * @return ASURL
	 */
	public ASURL GetGroupGoUpURL()
	{
		ASURL url     = new ASURL(m_asOwner);
		int nGroupLen = m_arrGroupIDs.GetSize();

		if (nGroupLen == 0)
		{
			url.SetLinkGetCachedSpace(m_asOwner);
			url.SetDisplayPage(SiteMapDP.STR_MVC_CLASS_NAME);
			url.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
			url.AddControlArgument(SetSiteMapControl.m_CommunityID,
				XPConvert.ToString(GetCommunityID()));
			url.AddControlArgument(SetSiteMapControl.m_Mode,
				XPConvert.ToString(GetMode()));
		}
		else if (nGroupLen == 1)
		{
			url.SetLinkGetCachedSpace(m_asOwner);
			url.SetDisplayPage(MembersDP.STR_MVC_CLASS_NAME);
			url.SetControl(SetGroupControl.STR_MVC_CLASS_NAME);
		}
		else
		{
			int nParentID = XPConvert.ToInteger(m_arrGroupIDs.GetElement(nGroupLen - 2));
			url.SetLinkGetCachedSpace(m_asOwner);
			url.SetControl(SetGroupControl.STR_MVC_CLASS_NAME);
			url.AddControlArgument(SetGroupControl.m_GroupID,
				XPConvert.ToString(nParentID));
		}

		return url;
	}

	/**
	 *
	 * @return String
	 */
	public String GetGroupPath()
	{
		String strGroupPath = "";

		IPTObjectManager objOMGroups = m_ptSession.GetUserGroups();
		IPTUserGroup currGroup;

		for (int i = 0; i < m_arrGroupIDs.GetSize(); i++)
		{
			try
			{
				currGroup		 = (IPTUserGroup) objOMGroups.Open(XPConvert.ToInteger(m_arrGroupIDs.GetElement(
							i)), false);
				strGroupPath     = strGroupPath + "\\";
				strGroupPath     = strGroupPath + XPHttpUtility.UrlEncode(currGroup.GetLocalizedName(), LinkConstants.UTF_8_ENCODING);
			}
			catch (Exception e)
			{
				log.Error(e, "Could not open UserGroup. ");
			}
		}

		return strGroupPath;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetHasEditAccessToFolder()
	{
		IPTSiteMapFolder objFolder = null;

		try
		{
			objFolder = GetCurrSiteMapFolder();
		}
		catch (Exception e)
		{
			log.Error(e, "Unable to get current site map folder. ");

			return false;
		}

		IPTServerContext objSC = (IPTServerContext) objFolder.GetInterfaces(
				"IPTServerContext");

		return (objSC.GetAccessLevel() >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderCount()
	 */
	public int GetHeaderCount()
	{
		if (IsEditMode() && m_asOwner.GetCurrentPage().GetName() == SiteMapDP.STR_MVC_CLASS_NAME) {
			return 3;
		} else {
			return 1;	
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderHasCheckbox()
	 */
	public boolean GetHeaderHasCheckbox()
	{
		if (IsEditMode() && m_asOwner.GetCurrentPage().GetName() == SiteMapDP.STR_MVC_CLASS_NAME) {
			return true;
		} else {
			return false;	
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderRow()
	 */
	public HTMLTableRow GetHeaderRow()
	{
		return null;
	}

	////////////////////////
	/// IObjectModelRO /////
	////////////////////////

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetHeaderText(int)
	 */
	public String GetHeaderText(int nHeaderIndex)
	{
		if (nHeaderIndex == 0 && IsEditMode() && m_asOwner.GetCurrentPage().GetName() == SiteMapDP.STR_MVC_CLASS_NAME) {
			return SiteMapLinkViewHelper.HTMLINPUT_SELECTION_OBJECT;
		} 
		else if (nHeaderIndex == 0 || nHeaderIndex == 1 && IsEditMode()) {
			return m_asOwner.GetString(203,
				"ptmsgs_portalbrowsingmsgs");
		} 
		else {
			return m_asOwner.GetString(974, "ptmsgs_portalbrowsingmsgs");	
		}
					
		//return "";
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetIsCollapsable()
	 */
	public boolean GetIsCollapsable()
	{
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetShowCheckbox()
	 */
	public boolean GetIsFolderSelected(int nFolderID)
	{
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetIsObjectSelected(int)
	 */
	public boolean GetIsObjectSelected(int nObjectID)
	{
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetLastFolderIndex()
	 */
	public int GetLastFolderIndex()
	{
		return GetMyTempData().m_nShowMax;
	}

	/**
	 *
	 * @return ICPListEntryIterator
	 */
	public ICPListEntryIterator GetListIterator()
	{
		return GetMyTempData().m_asclLinks;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.sitemap.ISiteMapModelRO#GetMode()
	 */
	public int GetMode()
	{
		return m_nMode;
	}

	////////////////////////
	/// IModel         /////
	////////////////////////

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AClearModel#GetNewm_TempData()
	 */
	public Object GetNewTempData()
	{
		SiteMapModelTempData tempData = new SiteMapModelTempData();
		tempData.m_folderViewHelper		   = new SiteMapFolderViewHelper();
		tempData.m_objOMSiteMapFolders     = m_ptSession.GetSiteMapFolders();

		return tempData;
	}

	///////////////////////////////////////////
	// Read only method from IPaginationModelRO
	///////////////////////////////////////////

	/**
	 * @see com.plumtree.portalpages.common.objects.IPaginationModelRO#GetNumObjects()
	 */
	public int GetNumObjects()
	{
		// This will eventually return a useful value after the framework is set up
		return GetMyTempData().m_asclLinks.GetTotalCount();
	}
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.form.pagination.IPaginationModelRO#GetPaginationSize()
	 */
	public int GetPaginationSize()
	{
		return PTConfigHelper.GetConfigVariableAsInt(PTConfigConstants.COMMUNITIES_SECTION,
			PTConfigConstants.COMM_KD_LINKS_PER_PAGE_SUBSECTION,
			PTConfigConstants.VALUE_ATTRIBUTE, m_asOwner);
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetNumSubSubFolders()
	 */
	public int GetNumSubSubFoldersToDisplay()
	{
		return 0;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectBannerText()
	 */

	/*    public String GetObjectBannerText()
	    {
	        int nDocumentCount;
	        if(MembersDP.STR_MVC_CLASS_NAME.equals(m_asOwner.GetCurrentPage().GetName())) {
	            try {
	                nDocumentCount = GetCurrentGroupMemberCount();
	            } catch(Exception e) {
	                log.Error("Error Getting Object Banner Text: " + e.getMessage());
	                return m_asOwner.GetString(982, "ptmsgs_portalbrowsingmsgs");
	            }
	        } else if (SubCommunitiesDP.STR_MVC_CLASS_NAME.equals(m_asOwner.GetCurrentPage().GetName())) {
	            nDocumentCount = GetSubCommunities().GetCount();
	        } else {
	            nDocumentCount = GetObjectCount();
	        }

	        if (nDocumentCount == 0)
	        {
	            return "";
	        }
	        else
	        {
	            return "(" + XPResourceManager.FormatMessage(_m_asOwner.GetString(1470, "ptmsgs_portalbrowsingmsgs"), new Integer(nDocumentCount), new Integer(nDocumentCount)) + ")";
	        }
	    }
	*/

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectBannerTitle()
	 */
	public String GetObjectBannerTitle()
	{
		if(MembersDP.STR_MVC_CLASS_NAME.equals(m_asOwner.GetCurrentPage().GetName())) 
		{
			return XPResourceManager.FormatMessage(m_asOwner.GetString(1555,
						"ptmsgs_portalbrowsingmsgs"),
				 		XPHttpUtility.HtmlEncode(GetCurrentGroupName()));
		} else if (SubCommunitiesDP.STR_MVC_CLASS_NAME.equals(m_asOwner.GetCurrentPage().GetName())) {
			return m_asOwner.GetString(1556,
								"ptmsgs_portalbrowsingmsgs");
		} else {	
			return XPResourceManager.FormatMessage(m_asOwner.GetString(983,
					"ptmsgs_portalbrowsingmsgs"),
				 	XPHttpUtility.HtmlEncode(GetMyTempData().m_objSMCurrentFolder.GetLocalizedName()));
		}		 
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectColumnCount()
	 */
	public int GetObjectColumnCount()
	{
		return GetMyTempData().m_nNumDocCol;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectCount()
	 */
	public int GetObjectCount()
	{
		if (MembersDP.STR_MVC_CLASS_NAME.equals(
					m_asOwner.GetCurrentPage().GetName()))
		{
			try
			{
				return GetCurrentGroupMemberCount();
			}
			catch (Exception e)
			{
				log.Error(e, "Error Getting Object Count. ");

				return 0;
			}
		}
		else if (SubCommunitiesDP.STR_MVC_CLASS_NAME.equals(
					m_asOwner.GetCurrentPage().GetName()))
		{
			return GetSubCommunities().GetCount();
		}
		else
		{
			return GetMyTempData().m_arrSortedLinks.GetCount();
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectFields(int,
	 *      int)
	 */
	public Object GetObjectFields(int nIndex, int nPropID)
	{
		if (MembersDP.STR_MVC_CLASS_NAME.equals(
					m_asOwner.GetCurrentPage().GetName()))
		{
			IASQueryResult asQR;

			try
			{
				asQR = GetCurrentGroupMembers();

				return asQR.GetFields(nIndex, nPropID);
			}
			catch (Exception e)
			{
				log.Error(e, "Error getting object fields. ");

				return null;
			}
		}
		else if (SubCommunitiesDP.STR_MVC_CLASS_NAME.equals(
					m_asOwner.GetCurrentPage().GetName()))
		{
			return GetSubCommunities().GetFields(nIndex, nPropID);
		}
		else
		{
			return GetMyTempData().m_arrSortedLinks.GetItem(nIndex, nPropID);
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IObjectModelRO#GetObjectType()
	 */
	public int GetObjectType()
	{
		return m_nObjectType;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectSubType()
	 */
	public int GetObjectSubType(int nIndex) 
	{
		return -1;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetObjectViewIsCollapsed()
	 */
	public boolean GetObjectViewIsCollapsed()
	{
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetParentFolderID()
	 */
	public int GetParentFolderID()
	{
		Object[] objArrIDs = GetParentFolderIDs();
		int length		   = objArrIDs.length;

		if (length > 1)
		{
			return XPConvert.ToInteger(objArrIDs[length - 2]);
		}
		else
		{
			return m_nCurrentFolderID;
		}
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetParentFolderIDs()
	 */
	public Object[] GetParentFolderIDs()
	{
		Object[] objArrIDs = new Object[0];

		try
		{
			String strGID			   = GetCurrSiteMapFolder().GetGID();
			XPStringTokenizer xpStrTok = new XPStringTokenizer(strGID, "/",
					false);
			objArrIDs				   = new Object[xpStrTok.GetTokenCount()];

			// TokenCount because we want to include this folder in parent folder IDs
			int i = 0;

			while (xpStrTok.HasMoreElements())
			{
				objArrIDs[i] = new Integer(XPConvert.ToInteger(xpStrTok.GetNextElement()));
				i++;
			}
		}
		catch (Exception e)
		{
			log.Error(e, "Error Getting Parent Folder IDs. ");
		}

		return objArrIDs;
	}

	/**
	 *
	 * @return Object[]
	 */
	public Object[] GetParentGroupIDs()
	{
		return m_arrGroupIDs.ToArray();
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetPath()
	 */
	public String GetPath()
	{
		/*String path		   = "";
		Object[] objectIDs = GetParentFolderIDs();

		for (int i = 0; i < objectIDs.length; i++)
		{
			int nObjectID = XPConvert.ToInteger(objectIDs[i]);

			try
			{
				IPTSiteMapFolder currFolder = (IPTSiteMapFolder) GetMyTempData().m_objOMSiteMapFolders.Open(nObjectID,
						0);
				path     = path.concat("\\");
				path     = path.concat(currFolder.GetName());
			}
			catch (Exception e)
			{
				log.Error(e.getMessage());
			}
		}

		return path;*/
		
		String strPath = "";
		try {
			strPath = GetCurrSiteMapFolder().GetPath();	
		} catch (Exception e) {
			log.Error(e, "Unable to get site map folder path.");
		}
		
		return strPath;
	}

	/**
	 *
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetShowCheckbox()
	 */
	public boolean GetShowCheckbox()
	{
		return (IsEditMode());
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetShowBanner()
	 */
	public boolean GetShowFolderBanner()
	{
		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetShowPagination()
	 */
	public boolean GetShowPagination()
	{
		if (MembersDP.STR_MVC_CLASS_NAME.equals(
					m_asOwner.GetCurrentPage().GetName()))
		{
			return true;
		}
		else if (SubCommunitiesDP.STR_MVC_CLASS_NAME.equals(
					m_asOwner.GetCurrentPage().GetName()))
		{
			return false;
		}
		else
		{
			return true;
		}
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.sitemap.ISiteMapModelRO#GetSiteMapRootID()
	 */
	public int GetSiteMapRootID()
	{
		return m_nSiteMapRootID;
	}
	
	public String GetSiteMapRootName()
	{
		// DCA - always try to get in case the name has been changed 
		//if(m_strSitemapRootName == null || ("".equals(m_strSitemapRootName)))
		//{
			try
			{
				IPTSiteMapFolderManager smFolderMan = (IPTSiteMapFolderManager) GetMyTempData().m_objOMSiteMapFolders.GetInterfaces("IPTSiteMapFolderManager");
				m_strSitemapRootName = smFolderMan.CachedOpenSiteMapFolderInfo(m_nSiteMapRootID).GetName();
			}
			catch (Exception e)
			{
				log.Error(e, "Could not open current folder. ");
				throw new XPException(
					"Could not open Community Knowledge Directory Folder. ", e);
			}	
			
		//}
		
		return m_strSitemapRootName;	
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetSortDirection()
	 */
	public int GetSortDirection()
	{
		// This will eventually return a useful value after the framework is set up
		return PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetSortable()
	 */
	public boolean GetSortable()
	{
		// This will eventually return true after the framework is set up
		return false;
	}

	///////////////
	// ISortModelRO
	///////////////

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#GetSortedHeader()
	 */
	public int GetSortedHeader()
	{
		// This will eventually return a useful value after the framework is set up
		return 1;
	}

	/**
	 *
	 * @return PTSortedArrayWrapper
	 */
	public PTSortedArrayWrapper GetSortedSubFolders()
	{
		return GetMyTempData().m_arrSortedSubFolders;
	}

	/**
	 *
	 * @param intFolderID
	 * @return PTSortedArrayWrapper
	 */
	public PTSortedArrayWrapper GetSortedSubSubFoldersFromParentID(
		int intFolderID)
	{
		return (PTSortedArrayWrapper) GetMyTempData().m_tableSortedSubSubFolders.GetElement(new Integer(intFolderID));
	}

	/**
	 * Get the SpaceID of the parent Activity Space
	 *
	 * @return int m_asOwner.GetSpaceID();
	 */
	public String GetSpaceID()
	{
		return m_asOwner.GetSpaceID();
	}

	/**
	 *
	 * @return ASQueryResultWrapper
	 */
	public ASQueryResultWrapper GetSubCommunities()
	{
		if (null == GetMyTempData().m_objSubCommunities)
		{
			IPTCommunityManager ptOM		    = (IPTCommunityManager) m_ptSession.GetCommunities()
				.GetInterfaces("IPTCommunityManager");
			IPTCommunityInfo ptCommunityInfo    = ptOM.CachedOpenCommunityInfo(m_nCommunityID, false);
			GetMyTempData().m_objSubCommunities = new ASQueryResultWrapper(ptCommunityInfo.GetSubcommunities());
		}

		return GetMyTempData().m_objSubCommunities;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderCount()
	 */
	public int GetSubFolderCount(int nLevel)
	{
		return GetSubFolderCount();

		//return GetMyTempData().m_asqrSubFolders.GetCount();
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#GetFolderCount()
	 */
	public int GetSubFolderCount()
	{
		return GetMyTempData().m_arrSortedSubFolders.GetCount();
	}

	/**
	 *
	 * @return int
	 */
	public int GetSubGroupCount()

	{
		if (m_arrGroupIDs.GetSize() != 0)
		{
			return GetSubGroups().GetCount();
		}
		else
		{
			return GetTopLevelGroups().GetCount();
		}
	}

	/**
	 *
	 * @return IASQueryResult
	 */
	public IASQueryResult GetSubGroups()

	{
		if (m_arrGroupIDs.GetSize() != 0)
		{
			if (null == GetMyTempData().m_objDirectChildGroups)
			{
				GetMyTempData().m_objDirectChildGroups = new ASQueryResultWrapper(GetCurrentGroup()
						.QueryDirectChildGroups());
			}

			return GetMyTempData().m_objDirectChildGroups;
		}
		else
		{
			return GetTopLevelGroups();
		}
	}

	/**
	 *
	 * @return ASQueryResultWrapper
	 */
	public ASQueryResultWrapper GetTopLevelGroups()

	{
		if (null == GetMyTempData().m_objQRTopLevelGroups)
		{
			GetMyTempData().m_objQRTopLevelGroups = new ASQueryResultWrapper(GetCurrCommunity()
					.QueryMembers(PT_CLASSIDS.PT_USERGROUP_ID));
		}

		return GetMyTempData().m_objQRTopLevelGroups;
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.sitemap.ISiteMapModelRO#HasEditAccessToCommunity()
	 */
	/*public boolean HasEditAccessToCommunity()
	{
		IPTCommunity objCommunity = null;

		try
		{
			objCommunity = GetCurrCommunity();
		}
		catch (Exception e)
		{
			log.Error(e.getMessage());
		}

		boolean bHasEditAccess = false;

		if (objCommunity != null)
		{
			IPTServerContext objSC = (IPTServerContext) objCommunity.GetInterfaces(
					"IPTServerContext");

			return (objSC.GetAccessLevel() >= PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);
		}

		return bHasEditAccess;
	}*/

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModelRO#InRootFolder()
	 */
	public boolean InRootFolder()
	{
		return (m_nCurrentFolderID == GetParentFolderID());
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IModel#Init()
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner		  = parent;
		m_ptSession		  = (IPTSession) m_asOwner.GetUserSession();
		m_arrGroupIDs     = new XPArrayList();
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.sitemap.ISiteMapModelRO#IsBrowseMode()
	 */
	public boolean IsBrowseMode()
	{
		return (m_nMode == SetSiteMapControl.BROWSE);
	}

	/**
	 *
	 * @see com.plumtree.portalpages.browsing.sitemap.ISiteMapModelRO#IsEditMode()
	 */
	public boolean IsEditMode()
	{
		return (m_nMode == SetSiteMapControl.EDIT);
	}

	/**
	 * Return the headerID for the community; used when processing the style
	 * sheet.
	 */
	public int GetHeaderID(int nCommunityID)
	{
		try
		{
			return (GetCurrCommunityInfo()).GetHeaderID();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, e,
				m_asOwner.GetString(1520, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1521, "ptmsgs_portalbrowsingmsgs"));

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return 0;
	}
	
	
	/**
	 * Return the stylesheet for the community; used when processing the style
	 * sheet.
	 */
	public String GetStyleSheet(int nCommunityID)
	{
		try
		{
			return (GetCurrCommunityInfo()).GetStyleSheet();
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
				UIErrorScope.CURRENT_USER, e,
				m_asOwner.GetString(1522, "ptmsgs_portalbrowsingmsgs"),
				m_asOwner.GetString(1523, "ptmsgs_portalbrowsingmsgs"));

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return "";
	}

	

	/**
	 *
	 * @throws Exception
	 */
	public void Move()
	{
		if (NO_FOLDER_SELECTED != GetMyTempData().m_nMoveToFolderID)
		{
			for (int i = 0; i < GetMyTempData().m_arrSelectedLinks.length;
					i++)
			{
				try
				{
					IPTSiteMapLink currLink = GetCurrSiteMapFolder().OpenLink(GetMyTempData().m_arrSelectedLinks[i]);
					currLink.SetParentFolderID(GetMyTempData().m_nMoveToFolderID);
					currLink.Store();
				}
				catch (Exception e)
				{
					//pkd extracted: 					throw new Exception(_ui_LinkMoveException);	
					throw new XPException(m_asOwner.GetString(978,
							"ptmsgs_portalbrowsingmsgs"));
				}
			}

			IPTSiteMapFolderManager ptOM = (IPTSiteMapFolderManager) GetMyTempData().m_objOMSiteMapFolders.GetInterfaces(
					"IPTSiteMapFolderManager");

			for (int i = 0; i < GetMyTempData().m_arrSelectedFolders.length;
					i++)
			{
				try
				{
					ptOM.MoveFolder(GetMyTempData().m_arrSelectedFolders[i],
						GetMyTempData().m_nMoveToFolderID);
				}
				catch (Exception e)
				{
					//pkd extracted: 					throw new Exception(_ui_FolderMoveException);	
					throw new XPException(XPResourceManager.FormatMessage(
						m_asOwner.GetString(1736, "ptmsgs_portalbrowsingmsgs"), 
						XPConvert.ToString(GetMyTempData().m_arrSelectedFolders[i])));
				}
			}
		}

		GetMyTempData().m_arrSelectedLinks		 = new int[0];
		GetMyTempData().m_arrSelectedFolders     = new int[0];
		GetMyTempData().m_nMoveToFolderID		 = NO_FOLDER_SELECTED;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModel#OpenSubFolder(int)
	 */
	public void OpenSubFolder(int ID)
	{
		if (ID == -1)
		{
			m_nCurrentFolderID = m_nSiteMapRootID;
		}
		else
		{
			m_nCurrentFolderID = ID;
		}
	}

	////////////////////////
	/// IRepostModel    ////
	////////////////////////

	/**
	 *
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		String[] sValues;

		if (_sPageName.equals(SiteMapDP.STR_MVC_CLASS_NAME))
		{
			// if community page selection
			sValues = (String[]) _htFormData.GetElement(SiteMapLinkViewHelper.HTMLINPUT_SELECTION_OBJECT);

			if (sValues == null)
			{
				
					log.Debug("could not find link id(s) in query string.");
				

				GetMyTempData().m_arrSelectedLinks = new int[0];
			}
			else
			{
				GetMyTempData().m_arrSelectedLinks = new int[sValues.length];

				for (int i = 0; i < sValues.length; i++)
				{
					GetMyTempData().m_arrSelectedLinks[i] = XPConvert.ToInteger(sValues[i]);
				}
			}

			sValues = (String[]) _htFormData.GetElement(SiteMapFolderViewHelper.HTMLINPUT_SELECTION_FOLDER);

			if (sValues == null)
			{
				
					log.Debug("could not find folder id(s) in query string.");
				

				GetMyTempData().m_arrSelectedFolders = new int[0];
			}
			else
			{
				GetMyTempData().m_arrSelectedFolders = new int[sValues.length];

				for (int i = 0; i < sValues.length; i++)
				{
					GetMyTempData().m_arrSelectedFolders[i] = XPConvert.ToInteger(sValues[i]);
				}
			}

			ProcessMovePost(_htFormData);
		}

		if (_sPageName.equals(DisplayInPortletDP.STR_MVC_CLASS_NAME))
		{
			try
			{
				String[] sPages			  = (String[]) _htFormData.GetElement(DisplayInPortletView.HTMLCHECKBOX_SELECTION_PAGE);
				int nFolderID			  = GetCurrentFolderID();
				IPTSiteMapFolder ptFolder = GetCurrSiteMapFolder();

				if ((sPages != null) && (sPages.length > 0))
				{
					// get the community
					IPTCommunity ptCommunity = GetCurrCommunity();

					if ((ptCommunity) == null)
					{
						UIError myError = new UIError(UIErrorLevel.FRIENDLY,
								
							UIErrorScope.CURRENT_USER, null,
								m_asOwner.GetString(979,
									"ptmsgs_portalbrowsingmsgs"),
								
							m_asOwner.GetString(980, "ptmsgs_portalbrowsingmsgs"));

						UIErrorHandler.RaiseError(myError,
							m_asOwner.GetSubSession(),
							m_asOwner.GetApplication());
					}

					// make the gadget
					IPTGadgetTemplate ptSiteMapFolderPortletTemplate = (IPTGadgetTemplate) m_ptSession.GetGadgetTemplates()
						.Open(PT_INTRINSICS.PT_GADGET_COMMUNITYLINKS, false);
					IPTGadget ptNewPortlet						    = ptSiteMapFolderPortletTemplate.CreateGadgetInstance(m_ptSession,
							ptCommunity.GetAdminFolderID(), m_nCommunityID);
					//MES- NOTE:  We are NOT getting the localized strings in the
					//	following two lines, since we'll call GetLocalizedNames, etc., in a
					//	moment.
					ptNewPortlet.SetName(ptFolder.GetName());
					ptNewPortlet.SetDescription(ptFolder.GetDescription());

					// deal with localization
					ptNewPortlet.SetIsLocalized(ptFolder.GetIsLocalized());
					ptNewPortlet.SetLocalizedDescriptions(ptFolder.GetLocalizedDescriptions());
					ptNewPortlet.SetLocalizedNames(ptFolder.GetLocalizedNames());
					ptNewPortlet.SetPrimaryLang(ptFolder.GetPrimaryLang());

					IPTServerContext ptSC = (IPTServerContext) ptNewPortlet.GetInterfaces(
							"IPTServerContext");
					ptSC.Store();
					ptSC.UnlockObject();

					int nPortletID = ptSC.GetObjectID();

					// put together the community pref that holds the folder ID
					Object[][] aSettings = new Object[2][1];
					aSettings[0][0]     = SiteMapPortletPrefsModel.SETTING_NAME_FOLDERID;
					aSettings[1][0]     = new Integer(nFolderID);

					ptCommunity.AssignPreferences(aSettings, false, nPortletID, PT_PREF_TYPES.PT_PREFTYPE_ALL_USERS);

					// add the gadget to the pages
					if (nPortletID != 0)
					{
						for (int i = 0; i < sPages.length; i++)
						{
							int nPageID = XPConvert.ToInteger(sPages[i]);

							if (nPageID != 0)
							{
								IPTPage ptPage = (IPTPage)m_ptSession.GetPages().Open(nPageID, false);

								if ((ptPage) == null)
								{
									UIError myError = new UIError(UIErrorLevel.FRIENDLY,
											
										UIErrorScope.CURRENT_USER, null,
											m_asOwner.GetString(979,
												"ptmsgs_portalbrowsingmsgs"),
											
										m_asOwner.GetString(980,
												"ptmsgs_portalbrowsingmsgs"));

									UIErrorHandler.RaiseError(myError,
										m_asOwner.GetSubSession(),
										m_asOwner.GetApplication());
								}
								else
								{
									// find out which column to add it to.  
									int nPageType		 = ptPage.GetPageType();
									int nColumnForPortlet = PortletColumnConstants.NARROW_ONE.ToInt();

									if (nPageType == PageTypeConstants.ONE_COLUMN ||
										nPageType == PageTypeConstants.ONE_COLUMN_WITH_FREE_FORM_CONTENT)
									{
										nColumnForPortlet = (PortletColumnConstants.WIDE_ONE).ToInt();
									}

									ptPage.AddPortlet(nPortletID,
										nColumnForPortlet);
								}
							}
						}
					}
				}
			}
			catch (Exception e)
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						
					UIErrorScope.CURRENT_USER, null,
						m_asOwner.GetString(979, "ptmsgs_portalbrowsingmsgs"),
						
					m_asOwner.GetString(980, "ptmsgs_portalbrowsingmsgs"));

				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 *
	 */
	public void SetBrowseMode()

	{
		m_nMode = SetSiteMapControl.BROWSE;

		IPTSiteMapFolderManager ptOM     = (IPTSiteMapFolderManager) m_ptSession.GetSiteMapFolders()
			.GetInterfaces("IPTSiteMapFolderManager");
		IPTSiteMapFolderInfo folderInfo  = ptOM.CachedOpenSiteMapFolderInfo(m_nCurrentFolderID);
		GetMyTempData().m_asqrLinks		 = new ASQueryResultWrapper(folderInfo.QueryLinks());
		GetMyTempData().m_asqrSubFolders = new ASQueryResultWrapper(GetCurrSiteMapFolder().QuerySubfolders(true));
		CreateSortedSubFolders();
		CreateSortedLinks();
		GetMyTempData().m_nNumFoldCol = 2;
		m_asOwner.SetCurrentPage(m_asOwner.GetPage(SiteMapDP.STR_MVC_CLASS_NAME));
		
		m_asOwner.SetHelpTopic( "pt_communityknowledgedirectory_browsing" );
	}

	/**
	 * Set Community ID
	 *
	 * @param int
	 */
	public void SetCommunityID(int nCommunityID)

	{
		m_nCommunityID = nCommunityID;

		m_nSiteMapRootID = GetCurrCommunityInfo().GetSiteMapRootID();
	}

	/**
	 *
	 */
	public void SetEditMode()
	{
		IPTServerContext objSC = (IPTServerContext) GetCurrSiteMapFolder()
			.GetInterfaces("IPTServerContext");
		boolean bObjectIsAccessible			   = GetMyTempData().m_objOMSiteMapFolders.IsObjectAccessible(objSC.GetObjectID(),
				m_ptSession.GetSessionInfo().GetCurrentUserID(),
				PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_EDIT);

		if (bObjectIsAccessible &&
				(m_asOwner.GetAccessStyle() == AccessStyles.STANDARD))
		{
			m_nMode								 = SetSiteMapControl.EDIT;
			GetMyTempData().m_asqrLinks			 = new ASQueryResultWrapper(GetCurrSiteMapFolder()
					.QueryLinks());
			GetMyTempData().m_asqrSubFolders     = new ASQueryResultWrapper(GetCurrSiteMapFolder()
					.QuerySubfolders(false));
			CreateSortedSubFolders();
			CreateSortedLinks();
			GetMyTempData().m_nNumFoldCol = 1;
			
			SiteMapFolderPlugInModel plugInModel = (SiteMapFolderPlugInModel)
				m_asOwner.GetModel(SiteMapFolderPlugInModel.STR_MVC_CLASS_NAME);
				
			plugInModel.InitializePlugIn(GetCurrSiteMapFolder());
			m_asOwner.SetCurrentPage(m_asOwner.GetPage(SiteMapDP.STR_MVC_CLASS_NAME));
			
			m_asOwner.SetHelpTopic(" pt_communityknowledgedirectory_editfolders" );
		}
		else
		{
			SetBrowseMode();
		}
	}

	/////////////////////////////////////////
	// Write methods from IFolderModel
	/////////////////////////////////////////

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModel#SetFirstItemIndex(int)
	 */
	public void SetFirstItemIndex(int nFirstItemIndex)
	{
		GetMyTempData().m_nStartAt = nFirstItemIndex;
	}

	/**
	 * 
	 * @return int
	 */
	public int GetCurrentGroupID()
	{
		int nGroupLen				 = m_arrGroupIDs.GetSize();
		int nCurrGroupID = 0;
		if(nGroupLen > 0) {
			nCurrGroupID = XPConvert.ToInteger(m_arrGroupIDs.GetElement(nGroupLen - 1));
		}
		
		return nCurrGroupID;	
	}

	/**
	 * Refresh the current group ID.  This is the
	 * same as setting the group ID to the current
	 * group ID, but bypasses any security checks.
	 */
	public void RefreshCurrentGroupID()
	{
		SetGroupIDHelper(GetCurrentGroupID());
	}

	/**
	 * This sets the group ID after checking if the group
	 * is accessible to the current user.
	 * 
	 * NOTE: This method calls IsGroupAccessible to check security.
	 * 
	 * @param nGroupID
	 * @return true if the group ID was set.  False if the group
	 * is not accessible.
	 */
	public boolean SetGroupID(int nGroupID)
	{
		if (IsGroupAccessible(nGroupID))
		{
			SetGroupIDHelper(nGroupID);
			return true;
		}
		return false;
	}

	private void SetGroupIDHelper(int nGroupID)
	{
		Object intGroupID = new Integer(nGroupID);

		if (m_arrGroupIDs == null)
		{
			m_arrGroupIDs = new XPArrayList();
		}

		if (m_arrGroupIDs.Contains(intGroupID))
		{
			int index = m_arrGroupIDs.IndexOf(intGroupID);

			for (int i = m_arrGroupIDs.GetSize() - 1; i >= (index + 1); i--)
			{
				m_arrGroupIDs.RemoveAt(i);
			}
		}
		else
		{
			m_arrGroupIDs.Add(intGroupID);
		}
	}

	public boolean IsGroupAccessible(int nGroupID)
	{
		// The community ID must be set before we can view
		// groups, and the community must have site map
		// enabled. Bug#46753
		if ((m_nCommunityID > 0) && (!GetCurrCommunityInfo().GetSiteMapDisabled())) 
		{
			IPTObjectManager om = m_ptSession.GetUserGroups();
			boolean bAccessible = om.IsObjectAccessible(XPConvert.ToInteger(nGroupID), 
					m_ptSession.GetSessionInfo().GetCurrentUserID(), PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);
			return bAccessible;
		}

		return false;
	}

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderModel#SetLastItemIndex(int)
	 */
	public void SetLastItemIndex(int nLastItemIndex)
	{
		GetMyTempData().m_nShowMax = nLastItemIndex;
	}

	/**
	 * This activity space holds only cards, so no need to change the type.
	 *
	 * @param ID     not used
	 */
	public void SetObjectType(int nNewObjectType)
	{
		m_nObjectType = nNewObjectType;
	}

	/////////////////////////////////////
	// Write methods for IPaginationModel
	/////////////////////////////////////

	/**
	 * @see com.plumtree.portalpages.common.objects.IPaginationModel#SetPagination(int, int, int)
	 */
	public void SetPagination(int nPaginationID, int nPaginationLowerBound,
		int nPaginationUpperBound)
	{
		if (MembersDP.STR_MVC_CLASS_NAME.equals(
									m_asOwner.GetCurrentPage().GetName()))
		{
			m_nFirstMemberObjectCount = nPaginationLowerBound;
			m_nLastMemberObjectCount = nPaginationUpperBound;
		}
		else
		{
			m_nFirstLinkObjectCount = nPaginationLowerBound;
			m_nLastLinkObjectCount = nPaginationUpperBound;	
		}
	}

	///////////////////////////////
	// Write methods for ISortModel
	///////////////////////////////

	/**
	 * @see com.plumtree.portalpages.common.objects.ISortModel#SetSort(int, int, int)
	 */
	public void SetSort(int nSortID, int nSortHeader, int nSortDirection)
	{
		// Not implementing this for 5.0
	}

	/**
	 * @see com.plumtree.portalpages.common.objects.IObjectModelRO#ShowObjectBanner()
	 */
	public boolean ShowObjectBanner()
	{
		return true;
	}

	public boolean SiteMapDisabled()
	{
		if(GetMyTempData().m_objCommunityInfo != null)
		{
			return GetMyTempData().m_objCommunityInfo.GetSiteMapDisabled();		
		} 
		else 
		{
			return true;	
		}	
	}

	public void CreateFolder(String strName, String strDesc)
	{
		GetCurrSiteMapFolder().CreateSubfolder(strName, strDesc);
	}

	/**
	 *
	 */
	private void CreateSortedLinks()
	{
		int nNumLinks = GetMyTempData().m_asqrLinks.GetCount();

		XPArrayList xparrLinks = new XPArrayList(nNumLinks);

		for (int i = 0; i < nNumLinks; i++)
		{
			XPArrayList linkProperties = new XPArrayList(8);
			Object intObjectID		   = GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_OBJECTID);
			String strGID			   = (String) GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_GID);
			String strName			   = (String) GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_NAME);
			String strDesc			   = (String) GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_DESCRIPTION);
			String strURL			   = (String) GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKURL);
			Object intClassID		   = GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID);
			Object intLinkObjectID    = GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID);
			Object intLinkCommID	   = GetMyTempData().m_asqrLinks.GetFields(i,
					PT_PROPIDS.PT_PROPID_SITEMAP_LINKPAGEID);

			linkProperties.Add(intObjectID);
			linkProperties.Add(strGID);
			linkProperties.Add(strName);
			linkProperties.Add(strDesc);
			linkProperties.Add(strURL);
			linkProperties.Add(intClassID);
			linkProperties.Add(intLinkObjectID);
			linkProperties.Add(intLinkCommID);

			xparrLinks.Add(linkProperties);
		}

		int[] arrColIDs = new int[8];
		arrColIDs[0]     = PT_PROPIDS.PT_PROPID_OBJECTID;
		arrColIDs[1]     = PT_PROPIDS.PT_PROPID_SITEMAP_GID;
		arrColIDs[2]     = PT_PROPIDS.PT_PROPID_NAME; // we're setting this to the gadget title bar state
		arrColIDs[3]     = PT_PROPIDS.PT_PROPID_DESCRIPTION; // we're setting this to true if there are comm prefs
		arrColIDs[4]     = PT_PROPIDS.PT_PROPID_SITEMAP_LINKURL;
		arrColIDs[5]     = PT_PROPIDS.PT_PROPID_SITEMAP_LINKCLASSID;
		arrColIDs[6]     = PT_PROPIDS.PT_PROPID_SITEMAP_LINKOBJECTID;
		arrColIDs[7]     = PT_PROPIDS.PT_PROPID_SITEMAP_LINKPAGEID;

		int[][] arrSort  = new int[1][2];
		arrSort[0][0]    = PT_PROPIDS.PT_PROPID_NAME;
		arrSort[0][1]    = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		Object[][] arrLinks = new Object[8][nNumLinks];

		for (int j = 0; j < nNumLinks; j++)
		{
			arrLinks[0][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(0);
			arrLinks[1][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(1);
			arrLinks[2][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(2);
			arrLinks[3][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(3);
			arrLinks[4][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(4);
			arrLinks[5][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(5);
			arrLinks[6][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(6);
			arrLinks[7][j]     = ((XPArrayList) xparrLinks.GetElement(j)).GetElement(7);
		}

		GetMyTempData().m_arrSortedLinks = new PTSortedArrayWrapper();
		GetMyTempData().m_arrSortedLinks.Initialize(arrColIDs, arrLinks,
			arrSort, true);
		GetMyTempData().m_asclLinks = new ASCompoundList();
		GetASCompoundListForSiteMapFolder(GetMyTempData().m_arrSortedLinks,
			GetMyTempData().m_asclLinks, m_asOwner);
	}

	private IPTCommunityInfo GetCurrCommunityInfo()

	{
		if (GetMyTempData().m_objCommunityInfo == null)
		{
			try
			{
				IPTCommunityManager ptOM     = (IPTCommunityManager) m_ptSession.GetCommunities()
					.GetInterfaces("IPTCommunityManager");
				GetMyTempData().m_objCommunityInfo  = ptOM.CachedOpenCommunityInfo(m_nCommunityID, false);
			}
			catch (Exception e)
			{
				log.Error(e, "Could not open current community. ");
				throw new XPException(
					"Could not open CommunityInfo on Community Knowledge Directory Page. ", e);
			}
		}

		return GetMyTempData().m_objCommunityInfo;
	}
	
	/**
	 * Only use this for members and making portlets!!
	 */
	private IPTCommunity GetCurrCommunity()

	{
		if (GetMyTempData().m_objCommunity == null)
		{
			try
			{
				GetMyTempData().m_objCommunity 
					= (IPTCommunity) m_ptSession.GetCommunities().Open(m_nCommunityID, false);
			}
			catch (Exception e)
			{
				log.Error(e, "Could not open current community. ");
				throw new XPException(
					"Could not open Community on Community Knowledge Directory Page. ", e);
			}
		}

		return GetMyTempData().m_objCommunity;
	}

	/**
	 * Get Current SiteMap Folder
	 *
	 * @return IPTSiteMapFolder
	 * -------------------------
	 * Private method to return current SiteMapFolder from TempDataObject.
	 * If the current folder is not set (in the case when and HTTPRequest is done, and the
	 * temp object is blown away), it will reset the current folder using the cached ID.
	 *
	 */

	private IPTSiteMapFolder GetCurrSiteMapFolder()

	{
		if (GetMyTempData().m_objSMCurrentFolder == null)
		{
			if (m_nCurrentFolderID == SiteMapModel.FOLDERID_NOT_INITIALIZED)
			{
				m_nCurrentFolderID = m_nSiteMapRootID;
			}

			try
			{
				GetMyTempData().m_objSMCurrentFolder = (IPTSiteMapFolder) GetMyTempData().m_objOMSiteMapFolders.Open(m_nCurrentFolderID, false);
			}
			catch (Exception e)
			{
				log.Error(e, "Could not open current folder. ");
				GeneralHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_ADMIN), 
		                "GetCurrSiteMapFolder ", e, true, UIErrorLevel.SERIOUS, 
		                XPResourceManager.FormatMessage(m_asOwner.GetString(1887, "ptmsgs_portalbrowsingmsgs"), XPConvert.ToString(m_nCurrentFolderID)));
			}
		}

		return GetMyTempData().m_objSMCurrentFolder;
	}

	/**
	 *
	 * @return IPTUserGroup
	 */
	private IPTUserGroup GetCurrentGroup()
	{
		if (null == GetMyTempData().m_objCurrUserGroup)
		{
			int nGroupLen				 = m_arrGroupIDs.GetSize();
			int nCurrGroupID			 = XPConvert.ToInteger(m_arrGroupIDs.GetElement(nGroupLen -
					1));
			IPTObjectManager objOMGroups = m_ptSession.GetUserGroups();

			try
			{
				GetMyTempData().m_objCurrUserGroup = (IPTUserGroup) objOMGroups.Open(nCurrGroupID, false);
			}
			catch (Exception e)
			{
				log.Error(e, "Could not open UserGroup. ");
			}
		}

		return GetMyTempData().m_objCurrUserGroup;
	}

	/**
	 *
	 * @return SiteMapModelTempData
	 */
	private SiteMapModelTempData GetMyTempData()
	{
		return (SiteMapModelTempData) GetTempData();
	}

	/**
	 *
	 * @return int
	 */
	private int GetNumParents()
	{
		int nTotalSize  = GetMyTempData().m_asqrSubFolders.GetCount();
		int nNumParents = 0;
		int nDepth;

		for (int i = 0; i < nTotalSize; i++)
		{
			nDepth = XPConvert.ToInteger(GetMyTempData().m_asqrSubFolders.GetFields(i,
					PT_PROPIDS.PT_PROPID_FOLDER_LEVEL));

			if (1 == nDepth)
			{
				nNumParents++;
			}
		}

		return nNumParents;
	}

	/**
	 *
	 * @return ASQueryResultWrapper
	 */
	private ASQueryResultWrapper GetSingleMembers()

	{
		if (null == GetMyTempData().m_objQRSingleMembers)
		{
			GetMyTempData().m_objQRSingleMembers = new ASQueryResultWrapper(GetCurrCommunity()
					.QueryMembers(PT_CLASSIDS.PT_USER_ID));
		}

		return GetMyTempData().m_objQRSingleMembers;
	}
	
	public boolean IsPreviewPage()
	{
		return m_bIsPreviewPage;
	}

	public void SetToPreviewPage()
	{
		m_bIsPreviewPage = true;
	}


	/**
	 *
	 * @param _htFormData
	 */
	private void ProcessMovePost(XPHashtable _htFormData)
	{
		if (m_asOwner.GetSubSpaceExists("SiteMapFolderTree"))
		{
			ATreeAS asUserTree				  = (ATreeAS) m_asOwner.GetSubSpace(
					"SiteMapFolderTree");
			ITreeModelRO myTree				  = (ITreeModelRO) asUserTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected			  = myTree.GetSelectedItems();
			GetMyTempData().m_nMoveToFolderID = NO_FOLDER_SELECTED;

			//GetMyTempData().m_arrUserNames = new String[mySelected.GetSize()];
			for (int i = 0; i < mySelected.GetSize(); i++)
			{
				GetMyTempData().m_nMoveToFolderID = XPConvert.ToInteger(((TreeLeafNode) mySelected.GetElement(
							i)).m_strLocation);
			}

			m_asOwner.DeleteSubSpace("SiteMapFolderTree");

			log.Debug("move folder id: " + GetMyTempData().m_nMoveToFolderID);
		}
	}

	/** temp object */
	static class SiteMapModelTempData
	{
		
		public ASCompoundList m_asclLinks;

		
		public ASQueryResultWrapper m_objCurrUsers;

		
		public ASQueryResultWrapper m_objDirectChildGroups;

		
		public ASQueryResultWrapper m_objQRSingleMembers;

		
		public ASQueryResultWrapper m_objQRTopLevelGroups;

		
		public ASQueryResultWrapper m_objSubCommunities;

		
		public IASQueryResult m_asqrLinks;

		
		public IASQueryResult m_asqrSubFolders;

		
		public IPTCommunityInfo m_objCommunityInfo;
		
		/** Community Object - only use for members and creating Comm links portlet */
		public IPTCommunity m_objCommunity;

		/** Site Map Manager */
		public IPTObjectManager m_objOMSiteMapFolders;

		/** Current folder info */
		public IPTSiteMapFolder m_objSMCurrentFolder;

		
		public IPTUserGroup m_objCurrUserGroup;

		
		public PTSortedArrayWrapper m_arrSortedLinks;

		
		public PTSortedArrayWrapper m_arrSortedSubFolders;

		
		public XPHashtable m_tableSortedSubSubFolders;

		
		public int[] m_arrSelectedFolders;

		
		public int[] m_arrSelectedLinks;

		
		public int[] m_arrSubSubOrderedIndices;

		
		public int m_nCurrentChildIndexForIterating;

		
		public int m_nCurrentParentFolderIDForIterating;

		
		public int m_nCurrentParentIndexForIterating;

		
		public int m_nMoveToFolderID;

		
		public int m_nNumDocCol    = 1;

		
		public int m_nNumDocOnPage = 20;

		
		public int m_nNumFoldCol = 2;

		/** Index of the last document to show */
		public int m_nShowMax = 20;

		/** Index of the first document to show  Default is the first document */
		public int m_nStartAt = 0;

		/** FolderViewHelper - controls display of one folder item */
		public IFolderViewHelper m_folderViewHelper;
	}
}

