package com.plumtree.portalpages.browsing.sitemap.sitemappage;


// Framework Imports
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.editors.sitemap.sitemapfolderplugin.*;
import com.plumtree.portalpages.common.createfolder.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SiteMapRepostControl.java
 * -------------------------------
 *
 * @author NaveenP
 */
public class SiteMapRepostControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SiteMapRepostControl");

	
	public static final String STR_MVC_CLASS_NAME = "SiteMapRepost";

	
	public final static int POSTTOSELF_ACTION_DELETE = 81;

	
	public final static int POSTTOSELF_ACTION_MOVE = 82;
	
	
	public final static int POSTTOSELF_ACTION_CREATE_FOLDER = 83;
	
	
	public final static int POSTTOSELF_ACTION_OPEN_CREATE_FOLDER = 84;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SiteMapRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);
		
		SiteMapFolderPlugInControl plugInControl = (SiteMapFolderPlugInControl)
			m_asOwner.GetControl(SiteMapFolderPlugInControl.STR_MVC_CLASS_NAME);
			
		plugInControl.PerformRepostAction(_nAction, m_htFormData); 
	

		SiteMapModel smModel = (SiteMapModel) m_model;
		Redirect redirect    = new Redirect();
		redirect.SetLinkGetCachedSpace(m_asOwner);
		redirect.SetDisplayPage(SiteMapDP.STR_MVC_CLASS_NAME);
		redirect.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
		redirect.AddControlArgument(SetSiteMapControl.m_CommunityID,
			smModel.GetCommunityID());
		redirect.AddControlArgument(SetSiteMapControl.m_FolderID,
			smModel.GetCurrentFolderID());
		redirect.AddControlArgument(SetSiteMapControl.m_Mode, smModel.GetMode());
		

		switch (_nAction)
		{
		case POSTTOSELF_ACTION_SIMPLEREPOST:
			SetRedirect(redirect);
			break;

		case POSTTOSELF_ACTION_DELETE:

			try
			{
				((SiteMapModel) m_model).Delete();
			}
			catch (Exception e)
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, e.getMessage(),
						e.getMessage());
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
			SetRedirect(redirect);

			break;

		case POSTTOSELF_ACTION_MOVE:

			try
			{
				((SiteMapModel) m_model).Move();
				SetRedirect(redirect);
			}
			catch (Exception e)
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, e.getMessage(),
						e.getMessage());
				myError.SetDisplayOnSeparatePage(false);
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
			SetRedirect(redirect);
			
			break;
			
		case POSTTOSELF_ACTION_CREATE_FOLDER:
			String sName = null;
			String[] sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERNAME);
	
			if (sValues == null)
			{
				
					log.Error("Could not get folder name.");
				
			}
			else
			{
				sName = sValues[0];
			}
	
			String sDesc = null;
			sValues = (String[]) m_htFormData.GetElement(CreateFolderView.HTMLINPUT_FOLDERDESCRIPTION);
	
			if (sValues == null)
			{
				
					log.Error("Could not get folder description.");
				
			}
			else
			{
				sDesc = sValues[0];
			}
			
			try {
				smModel.CreateFolder(sName, sDesc);
			} catch (Exception e) {
				
					log.Error(e, "Could not create folder.");
				
				
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, e.getMessage(),
						e.getMessage());
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
			ASURL asurl = new ASURL(m_asOwner);
			asurl.SetLinkGetCachedSpace(m_asOwner);
			asurl.SetDisplayPage(SiteMapDP.STR_MVC_CLASS_NAME);
			asurl.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(SetSiteMapControl.m_CommunityID,
				smModel.GetCommunityID());
			asurl.AddControlArgument(SetSiteMapControl.m_FolderID,
				smModel.GetCurrentFolderID());
			asurl.AddControlArgument(SetSiteMapControl.m_Mode, smModel.GetMode());			
			
			ClosePopUpDP closeDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			script.AddInnerHTMLString("window.opener.location='" + asurl.GetURLAsString() + "';");
			closeDP.SetScript(script);
			closeDP.SetToClose(true);
			
			redirect = new Redirect();
			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
				
			SetRedirect(redirect);
			break;
			
		case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_SAVELINKS:
			ClosePopUpDP closeWebLinkDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			HTMLScript scriptWebLink = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			scriptWebLink.AddInnerHTMLString("window.opener.document." + AFormDP.HTMLFORM_NAME + ".submit();\n");
			closeWebLinkDP.SetScript(scriptWebLink);
			closeWebLinkDP.SetToClose(true);
			
			redirect = new Redirect();
			redirect.SetLinkGetCachedSpace(m_asOwner);
			redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
			
			SetRedirect(redirect);
			break;
		case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_COMMPAGETREESUBMIT:
		case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_DOCUMENTTREESUBMIT:
		case SiteMapFolderPlugInControl.POSTTOSELF_ACTION_EXPERTTREESUBMIT:
		case -1: // AGC- -1 is considered an expression in C# and doesn't jump to a constant value. POSTTOSELF_ACTION_UNDEFINED:
			if(!MembersDP.STR_MVC_CLASS_NAME.equals(m_asOwner.GetCurrentPage().GetName()))
			{
				SetRedirect(redirect);
			}
			break;
		case POSTTOSELF_ACTION_OPEN_CREATE_FOLDER:
			break;
		case POSTTOSELF_ACTION_PASSTHRU:
			try {
				if(MembersDP.STR_MVC_CLASS_NAME.equals(m_asOwner.GetCurrentPage().GetName()))
				{
					smModel.SetCommunityID(smModel.GetCommunityID());
					int nGroupID = smModel.GetCurrentGroupID();
					if(nGroupID != 0) {
						smModel.SetGroupID(nGroupID);
					}
				}
				else 
				{
					smModel.SetCommunityID(smModel.GetCommunityID());
					smModel.OpenSubFolder(smModel.GetCurrentFolderID());
					if(smModel.IsEditMode()) {
						smModel.SetEditMode();
					} else {
						smModel.SetBrowseMode();
					}
				}
	
			} catch(Exception e) {
			
				log.Error(e, "Server Error");
	
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
						UIErrorScope.CURRENT_USER, null, e.getMessage(),
						e.getMessage());
				UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
					m_asOwner.GetApplication());
			}
			break;
		}
	}
}

