package com.plumtree.portalpages.browsing.sitemap.sitemappage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * File: SubCommunitiesView.java
 * -----------------------------
 *
 * @author NaveenP
 */
public class SubCommunitiesView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.sitemap.sitemappage.SubCommunitiesView");

	
	public static final String STR_MVC_CLASS_NAME = "SubCommunities";
	protected AActivitySpace m_asOwner;



	// Logger
	// Client-specific variables
	protected SiteMapModel m_asModel;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SubCommunitiesView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			result.AddInnerHTMLElement(DisplayBreadCrumbs());
			result.AddInnerHTMLElement(DisplayBanner());
		}
		catch (HTMLException he)
		{
			log.Error(he, he.getMessage());
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		//script.SetSrc("opennewwindow.js");
		return script;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (SiteMapModel) model;
		m_asOwner     = parent;
	}

	/**
	 *
	 * @return HTMLElement
	 */
	private HTMLElement DisplayBanner()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		ASURL asurl;
		HTMLAnchor anchor;
		ElementName elementName;

		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
					true, this.m_asOwner);

			PTConstruct myImage = 	UIConstructFactory.GetConstruct(PTImageType.ICON_FOLDER_COMMUNITY_OPEN,
								true, this.m_asOwner);
			myConstruct.ReplaceNestedElementsWithElement(PTBannerType.FOLDER.FOLDER_IMG_CONTAINER_ELEMENT_NAME,
				myImage.GetHTMLElement());
	 			
			ElementName eNameBanner = PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE);

			myConstruct.ReplaceNestedElementsWithHTMLString(eNameBanner,
				m_asOwner.GetString(986, "ptmsgs_portalbrowsingmsgs"));

			//	Get a button construct
			PTConstruct myButtonConstruct;

			//Go up button
			myButtonConstruct     = UIConstructFactory.GetConstruct(PTButtonType.GO_UP,
					true, this.m_asOwner);
			elementName			  = PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE);

			myButtonConstruct.ReplaceNestedElementsWithHTMLString(elementName,
				m_asOwner.GetString(987, "ptmsgs_portalbrowsingmsgs"));
			ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(987,
					"ptmsgs_portalbrowsingmsgs"));
			ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(987,
					"ptmsgs_portalbrowsingmsgs"));
			asurl = new ASURL(m_asOwner);
			asurl.SetLinkGetCachedSpace(m_asOwner);
			asurl.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
			asurl.SetDisplayPage(SiteMapDP.STR_MVC_CLASS_NAME);
			asurl.AddControlArgument(SetSiteMapControl.m_CommunityID,
				XPConvert.ToString(m_asModel.GetCommunityID()));
			asurl.AddControlArgument(SetSiteMapControl.m_Mode,
				XPConvert.ToString(m_asModel.GetMode()));
			anchor = (HTMLAnchor) myButtonConstruct.GetNestedElement(PTButtonType.GO_UP.GetElementName(
						PTButtonType.ELEMENT_NAME_ID_ANCHOR));
			anchor.SetHRef(asurl.GetURLAsString());

			myButtonConstruct.ReplaceNestedElementsWithHTMLString(elementName,
				m_asOwner.GetString(987, "ptmsgs_portalbrowsingmsgs"));
			myConstruct.AddElementToNestedElement(PTBannerType.FOLDER.GetElementName(
					PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL),
				myButtonConstruct.GetHTMLElement());

			result.AddInnerHTMLElement(myConstruct.GetHTMLElement());
		}
		catch (Exception e)
		{
			log.Error(e, e.getMessage());
		}

		return result;
	}

	/**
	 *
	 * @return HTMLElement
	 */
	private HTMLElement DisplayBreadCrumbs()
	{
		//Display the Breadcrumb path, flush left to the margin
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;

		try
		{
			// Bread crumb path
			myGroup.AddInnerHTMLElement(GetBreadcrumbPath()
				.GetPathAsHTMLElement());
			myGroup.AddInnerHTMLElement(new HTMLBr());
		}
		catch (Exception e)
		{
			log.Error(e, "Error creating " + STR_MVC_CLASS_NAME + " Section.");
		}

		return result;
	}

	/**
	 *
	 * @return PTBreadcrumbPath
	 * @throws HTMLException
	 */
	private PTBreadcrumbPath GetBreadcrumbPath()

	{
		PTBreadcrumbPath myCrumbs = new PTBreadcrumbPath();

		ASURL myURL = new ASURL(m_asOwner);
		myURL.SetLinkGetCachedSpace(m_asOwner);
		myURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
		myURL.SetDisplayPage(SiteMapDP.STR_MVC_CLASS_NAME);
		myURL.AddControlArgument(SetSiteMapControl.m_CommunityID,
			XPConvert.ToString(m_asModel.GetCommunityID()));
		myURL.AddControlArgument(SetSiteMapControl.m_Mode,
			XPConvert.ToString(m_asModel.GetMode()));

		myURL.AddInnerHTMLString(m_asModel.GetSiteMapRootName());
		myCrumbs.appendAnchorItem((HTMLAnchor) myURL.GetURLAsHTMLElement());

		myCrumbs.appendTextItem(m_asOwner.GetString(986,
				"ptmsgs_portalbrowsingmsgs"));

		return myCrumbs;
	}
}

