/**
 * 
 */
package com.plumtree.portalpages.browsing.sso.ensemble;

import com.plumtree.openfoundation.security.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.helpers.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.impl.core.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This is helper class that has common functions used for 
 * Ensemble SSO Propagation and consumption.
 * @author Ravi Tunuguntla
 */
public class EnsembleHandlerTasks {
	
	public static String STR_TOKEN_DELIMITER = "|";
	public static String STR_CONTEXT_APPEND = "/";
	public static String STR_QS_PREFIX = "?";
	public static String STR_QS_ASSIGN= "=";
	public static String STR_QS_APPEND = "&";
	private static String strEnURL;
	
	/** This session is used for getting server config settings, since real session is not guaranteed to exist*/
	private static IPTSession session = PortalObjectsFactory.GetGuestReadOnlySession();
	
	
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
			"com.plumtree.portalpages.browsing.sso.ensemble.EnsembleHandlerTasks");
	
	private static IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
	

	/**
	 * Gets the ensemble base url from the ensemble remote server object
	 * @return
	 */
	public static String GetEnsembleBaseUrl()
	{
		if (null != strEnURL){
			return strEnURL;
		}
				
		try {
			int ensembleServiceId = EnsembleHelperService.getInstance().GetRemoteServerID(session);
			IPTObjectManager spServers = session.GetGadgetContentServers();
			IPTGadgetContentServer server = (IPTGadgetContentServer)spServers.Open(ensembleServiceId, false);
			strEnURL = server.GetURL();
		} catch( XPException ex){
			log.Error(ex, "Failed to get Ensemble Base URL from the configuration, Check Ensemble Configuration");
		}
		
		return strEnURL;
	}
	
	
	/**
	 * Should take an url with either:
	 * 	in)  http://www.foobar.com/something?a=v1&b=v2
	 *  out) http://www.foobar.com/something?a=v1&b=v2&newParam=value
	 * ...or
	 *  in)  http://www.foobar.com/something
	 *  out) http://www.foobar.com/something?newParam=value
	 * 
	 * @param origRequestUrl  	-- the original request url, including or excluding query string
	 * @param newParam 			-- the new parameter name
	 * @param value				-- the new parameter value
	 * @return
	 */
	public static String AddQueryStringParam(String origRequestUrl, String newParam, String value){
		String queryString = null;
		
		int indexOfQuestionMark = origRequestUrl.indexOf(STR_QS_PREFIX);

		
    	if ( -1 != indexOfQuestionMark){
    		//RaviT:  queryString will be something like ?abc=123&p2=af.  
    		queryString = origRequestUrl.substring(indexOfQuestionMark);
    	}
    	
        //no pre-existing queryString
    	if (queryString == null){
    		return origRequestUrl + STR_QS_PREFIX + newParam + STR_QS_ASSIGN + value;
    	} else {
    		return origRequestUrl + STR_QS_APPEND+ newParam + STR_QS_ASSIGN + value;
    	}
	}
	
	/**
	 * Should take an url with either:
	 * 	in)  http://www.foobar.com/something?a=v1&param=value&b=v2
	 *  out) http://www.foobar.com/something?a=v1&b=v2
	 * ...or
	 *  in)  http://www.foobar.com/something?param=value
	 *  out) http://www.foobar.com/something
	 * 
	 * @param origRequestUrl  	-- the original request url, including query string
	 * @param param 			-- the parameter name to be removed
	 * @return newRequestUrl with param removed from querystring
	 */
	public static String RemoveQueryStringParam(String origRequestUrl, String param){
		
		String queryString = null;
		int indexOfQuestionMark = XPStringUtility.IndexOf(origRequestUrl, STR_QS_PREFIX);
	
		if ( -1 != indexOfQuestionMark){
			queryString = XPStringUtility.Substring(origRequestUrl, indexOfQuestionMark + 1);
			origRequestUrl = XPStringUtility.Substring(origRequestUrl, 0, indexOfQuestionMark);
		}
		
		if(queryString != null ){
			if(XPStringUtility.IndexOf(queryString, param) >= 0){
				// The Parameter exists in query string and we need to remove it.
				
				XPStringTokenizer qsTokenizer = new XPStringTokenizer(queryString, STR_QS_APPEND);
				XPStringBuilder qsBuilder = new XPStringBuilder();

				boolean isFirstParam = true;
				while(qsTokenizer.HasMoreTokens()){
					String qsParam = qsTokenizer.GetNextToken();
					if(!XPStringUtility.StartsWith(qsParam, param)){
						
						if(isFirstParam){
							qsBuilder.Append(qsParam);
							isFirstParam = false;
						}else {
							qsBuilder.Append(STR_QS_APPEND + qsParam);
						}
					}
				}
				if(qsBuilder.GetLength() > 0){
					origRequestUrl = origRequestUrl + STR_QS_PREFIX + qsBuilder.ToString();
				}				 
			}
		}
		return origRequestUrl;
	}
	
	/**
	 * Processes LoginToken and returns the userid part of the login token
	 * @param strToken valid login token input
	 * @return user id part of the login token
	 */
	public static int GetTokenUserID(String strToken)
	{
		// the user id is the first element before the delimiter
		XPStringTokenizer strTokenizer = new XPStringTokenizer(strToken, STR_TOKEN_DELIMITER);
		return XPConvert.ToInteger(strTokenizer.GetNextToken());
	}
	
	/**
	 * Decrypts the chiperText with seed as seed Token
	 * @param cipherText
	 * @return PlainText that is decrypted using seed Token.
	 */
	public static String DecryptUsingSeedToken(String cipherText ){
		if(null == cipherText || XPStringUtility.EqualsIgnoreCase(cipherText, "")){
			return null;
		}
		InternalSession iSession = ((PTSession)session).GetInternalSession();
		//Get seed value from Server Config				
		String strSeedKey = XPConvert.ToString(iSession.GetServerConfigParameter(PT_SERVER_CONFIG_SETTINGNAME.PT_TOKEN_PASSWORD));
		
		XPAESCrypto crypto = new XPAESCrypto(XPCryptoType.AES_128);
		
		String plainText = crypto.Decrypt(cipherText, strSeedKey);
		return plainText;
		
	}
	
	/**
	 * Encrypts the plain text using seed Token
	 * @param plainText
	 * @return chiperText that is encrypted using seed token.
	 */
	public static String EncryptUsingSeedToken(String plainText ){
		if(null == plainText || XPStringUtility.EqualsIgnoreCase(plainText, "")){
			return null;
		}
		
		InternalSession iSession = ((PTSession)session).GetInternalSession();
		//Get seed value from Server Config				
		String strSeedKey = XPConvert.ToString(iSession.GetServerConfigParameter(PT_SERVER_CONFIG_SETTINGNAME.PT_TOKEN_PASSWORD));
		
		XPAESCrypto crypto = new XPAESCrypto(XPCryptoType.AES_128);
		
		String cipherText = crypto.Encrypt(plainText, strSeedKey);
		cipherText = XPHttpUtility.UrlEncode(cipherText, LinkConstants.UTF_8_ENCODING);
		return cipherText;
		
	}
	/**
	 * Gets the timeout configuration setting value for Ensemble SSO. 
	 * @return Timeout value if it is Positive the token is valid for that many minutes. Negative or zero value means SSO feature is turned off.
	 * 
	 */	
	public static int GetSSOTimeout(){
		try {
			 
			ConfigVarPack vpConfig = (ConfigVarPack) application.GetVarPackManager().GetVariablePackage(ConfigVarPack.VARPACK_ID);
			return vpConfig.GetConfigValueAsInt(ConfigConstants.MAIN_URLS_SECTION,
	                ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, ConfigConstants.VALUE_ATTRIBUTE);
		} catch (XPException ex) {
			log.Warn("Failed to get " + ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT + " from configuration, so returning  0 (disabled) value. ");
			return 0;
		}
	}
	/**
	 * 
	 * @param owner
	 * @param inRedirect The redirect that Login control generates when user login/logout happens.
	 * @param bLogin True if Login is being performed on WCI, false if logout is performed by WCI
	 * @return
	 */
	public static Redirect ProcessRedirect(AActivitySpace owner, Redirect inRedirect, boolean bLogin) {
		
		ConfigVarPack vpConfig = (ConfigVarPack) application.GetVarPackManager().GetVariablePackage(ConfigVarPack.VARPACK_ID);			
		int tokenTimeout = vpConfig.GetConfigValueAsInt(ConfigConstants.MAIN_URLS_SECTION,
                ConfigConstants.INTERNAL_SSO_TOKEN_TIMEOUT, ConfigConstants.VALUE_ATTRIBUTE);
		
		if(tokenTimeout <= 0) {
			return inRedirect;
		} else {

			
			if(null == inRedirect) {
				return null;
			}
			
			if (inRedirect.GetIsErrorRedirect()) {
				return inRedirect;
			}
				
			String responseURL;
			
			// Change Redirect to Ensemble with original as  QS param
			Redirect outRedirect = new Redirect();
			
			IPTSession session = (IPTSession)owner.GetUserSession();
			outRedirect.SetLinkToExternalURL(GetEnsembleBaseUrl());
			
			if (inRedirect.GetIsExternalURL()) {
				responseURL = inRedirect.GetExternalURL() + STR_QS_PREFIX + inRedirect.GetQueryString();
				
			} else {
				// Get Portal URL
				responseURL = TaskAPIUIPortalConfig.GetApplicationBaseURL(owner) + STR_QS_PREFIX + inRedirect.GetQueryString();
			}	
				
			
			// Encrypting the return URL using seed Token
			InternalSession iSession = ((IInternalPTSession)session).GetInternalSession();
			responseURL = EncryptUsingSeedToken(responseURL);
			
			// Adding portal return url as querystring
			outRedirect.AddControlArgument(EnsembleHandlerControl.ES_POST_REDIRECT_URL, responseURL);
			
			// Adding qs to let ensemble know that it is a logout/login
			
			outRedirect.AddControlArgument(EnsembleHandlerControl.SSO_ACTION, 
					(bLogin ? EnsembleHandlerControl.LOGIN_VALUE : EnsembleHandlerControl.LOGOUT_VALUE));
			
			return outRedirect;
		}
	}
}
