package com.plumtree.portalpages.browsing.topbestbethandler;

import com.plumtree.openfoundation.util.XPHashtable;
import com.plumtree.portalpages.browsing.search.results.BannerStartSearchControl;
import com.plumtree.portalpages.browsing.search.results.SearchResultAS;
import com.plumtree.portaluiinfrastructure.opener.IPTOpenerConstants;
import com.plumtree.portaluiinfrastructure.search.SearchResultControl;
import com.plumtree.portaluiinfrastructure.search.SearchSettingCollection;
import com.plumtree.portaluiinfrastructure.search.StartSearchControl;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

public class TopBestBetHandlerCT implements IControl
{
    // DCD: The name of this control
    public static final String CLASS_NAME = "TopBestBetHandlerCT";
    
    // DCD: These fields define form element names which are rendered by
    // the top best bet tag.
    public static final String FIELDS_TBB 		= "in_hi_tbbsearch";
    public static final String FIELDS_SEARCH 	= "in_tx_query";
    
    // DCD: Used for calculating normalized base URLs for redirect
    private AActivitySpace m_asOwner;
    
    // DCD: IMVCObject interface
    public String GetName()
    {
        return TopBestBetHandlerCT.CLASS_NAME;
    }
    
    // DCD: IManagedObject interface
    public Object Create()
    {
        return new TopBestBetHandlerCT();
    }
    
    // DCD: IControl interface
    public void Init(IModel model, AActivitySpace space)
    {
        // DCD: We'll need a reference to the owning AS to construct the normalized URL for
        //		TBB redirects.
        m_asOwner = space;
    }
    
    // DCD: IControl interface
    // DCD: This redirect first checks to see if it was received via user input button
    //		FIELDS_TBB or user button FIELDS_SEARCH, corresponding to a top best bet search
    //		request or normal search request, respectively.  If a top best bet, then set
    //		the name/value querystring for the tbb's common opener URL.  If a normal search,
    //		set the appropriate search input fields and post to the search URL.
    public Redirect CheckActionSecurityAndExecute(XPHashtable args)
    {
        // DCD: Grab the search expression, we'll need that no matter what we do
        //		it come from the search banner form input in_tx_query
        String[] asSearchExpression = (String[]) args.GetElement(SearchResultControl.USER_QUERY);
        String sSearchExpression = asSearchExpression[0];
        
        // DCD: Determine which kind of search is being executed
        boolean bIsTBBSearch = false;
        
        // DCD: If the first element here is = "tbb_search", else it's normal
        String[] asInputKeyTBB 	= (String[]) args.GetElement(TopBestBetHandlerCT.FIELDS_TBB);
        

        // DCD TODO: Find a way to redirect under 508, where TopBestBetHandlerCT.FIELDS_TBB is not set, but the image was clicked
        //String[] asInputKeySearch	= (String) args.GetElement(TopBestBetHandlerCT.FIELDS_SEARCH);
                
        // DCD: Check if the TBB button was selected, otherwise we're just doing a normal search
        if (0 == XPStringUtility.Compare(asInputKeyTBB[0],"tbb_search"))
        {
            bIsTBBSearch = true;
        }
        else
        {
            if(checkTBBSimpleFormSubmit(args))
            {
                bIsTBBSearch = true;
            }
            else
            {
                bIsTBBSearch = false;            
            }
        }
        
        // DCD: Execute a TBB redirect if it's a TBB search
        if(bIsTBBSearch)
        {
            // DCD: Construct the TBB URL explicitly
            String sTBBURL = m_asOwner.GetCurrentNormalizedBaseURL() + IPTOpenerConstants.QS_KEYWORD + CONTROL.URL_EQUALS + sSearchExpression;
            
            // DCD: Build our redirect and return
            Redirect rTBB = new Redirect();
            rTBB.SetIsHTTPRedirect(true);
            rTBB.SetLinkToExternalURL(sTBBURL);
            
            return rTBB;
        }
        // DCD: If it's a normal search, redirect to the usual search activity space.
        else
        {
            // DCD: Build a redirect to a basic search result
            Redirect rBasicSearch = new Redirect();
            rBasicSearch.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, m_asOwner);
            rBasicSearch.SetControl(BannerStartSearchControl.STR_MVC_CLASS_NAME);            
            rBasicSearch.SetIsHTTPRedirect(true);
            
            // DCD: Include the original form post args ("This never happened...")
            rBasicSearch.AddControlArguments(args);
       
            return rBasicSearch;
        }
    }
    
    private boolean checkTBBSimpleFormSubmit(XPHashtable args)
    {
        boolean bIsTBB = false;
        IXPEnumerator e = args.GetKeys();
        while(e.MoveNext())
        {
            String sKey = (String) e.GetCurrent();
            if(0 <= XPStringUtility.IndexOf(sKey, "in_im_tbb"))
            {
                bIsTBB = true;
            }
        }
        return bIsTBB; 
    }
    
    private static class CONTROL
    {
        public static final String URL_TOKEN_REPLACE 	= "_";
        public static final String URL_TOKEN_ORINGINAL = " ";
        public static final String URL_EQUALS 			= "=";
    }
}
