package com.plumtree.portalpages.browsing.unsubscribe.communities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author dustina
 *
 * To change this generated comment edit the template variable "typecomment":
 * Window>Preferences>Java>Templates.
 * To enable and disable the creation of type comments go to
 * Window>Preferences>Java>Code Generation.
 */
public class MyCommunitiesListModel extends ExpListModel implements IMyCommunitiesListModelRO
{
	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "MyCommunitiesListModel";
	
	
	
	public static final int COMMLIST_COL_MAX	    		= 3;

	
	public static final int COMMLIST_COL_NAME     		= 0;

	
	public static final int COMMLIST_COL_ID 				= 1;

	
	public static final int COMMLIST_COL_MEMBERSHIPTYPE	= 2;
	
	/**
	 * Default initial size for the sorted array.
	 */
	public static final int COMMLIST_DEFAULT_INITIAL_SIZE = 50;
	
	private boolean m_bDisplayAllMandatoryAlert = false;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new MyCommunitiesListModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		int[] arrColumns = new int[]
			{
				COMMLIST_COL_NAME, COMMLIST_COL_ID,
				COMMLIST_COL_MEMBERSHIPTYPE
			};

		// The growable array will always be sorted by the String column (the one displayed).
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = COMMLIST_COL_NAME;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		_saData.Initialize(arrColumns, null, arrSort, true,
			COMMLIST_DEFAULT_INITIAL_SIZE);
	}
	
	/**
	 * Will be called each time the add action is performed.
	 * Should take care of adding the row(s) to the list.
	 * Use the GetItems() method to get the list.
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		// DCA - not used
	}

	/**
	 * Will be called each ime there is a repost to save
	 * the data on the list.
	 * Should contain the code to update the data on the
	 * row _nRowIndex.Use the SetItem method to update _saData and
	 * use _htFormData to retrieve the posted data.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 * @param _htFormData
	 * @param _nListKey
	 *
	 * @return int
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitCommExpList(String _sSectionTitle,
		String _sSectionSubTitle, String _sUnsubscribeLabel)
	{
		Object[][] arrExpListColInfo = new Object[1][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(COMMLIST_COL_NAME);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;
		
		InitializeExpandableList(_sSectionTitle, 
			arrExpListColInfo, PTImageType.ACTION_DELETE, _sUnsubscribeLabel, 1);
		
		DisableAddButton();
		SetEmptyListMessages(m_asOwner.GetString(1544, "ptmsgs_portalbrowsingmsgs"), "");	
	}
	/**
	 * 
	 *
	 * @param _nRowIndex 
	 *
	 * @return 
	 */
	public boolean IsFreeMembership(int _nRowIndex)
	{
		if ( XPConvert.ToInteger(m_saData.GetItem(_nRowIndex, COMMLIST_COL_MEMBERSHIPTYPE))
				== PT_COMMUNITY_MEMBERSHIPTYPE.PT_COMMUNITYMEMBER_FREE )
			return true;
		else
			return false;

	}
	
	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public void Unsubscribe(XPHashtable _htFormData, UnsubscribeCommunitiesModel _model) 
	{
		int[] aRowsToUnsubscribe = null; 
		try {
			aRowsToUnsubscribe = GetArrayOfObjToDelete(_htFormData);
		} catch (Exception e) {
			// DCA - no communities to unsubscribe... must be all mandatory communities. Just return.
			m_bDisplayAllMandatoryAlert = true;
			return; 
		}
		
		for (int i=0; i < aRowsToUnsubscribe.length; i++) {
			_model.AddCommToDelete(m_saData.GetItem(aRowsToUnsubscribe[i],
							COMMLIST_COL_ID));
		}
		m_saData.RemoveRows(aRowsToUnsubscribe);
	}
	
	/**
	 * 
	 *
	 *
	 * @return 
	 */
	public void Unsubscribe508(int _nRowIndex, UnsubscribeCommunitiesModel _model) 
	{
		_model.AddCommToDelete(m_saData.GetItem(_nRowIndex,
							COMMLIST_COL_ID));

		m_saData.RemoveRow(_nRowIndex);
	}		
	/**
	 * Returns the m_bDisplayAllMandatoryAlert.
	 * @return boolean
	 */
	public boolean displayAllMandatoryAlert() {
		return m_bDisplayAllMandatoryAlert;
	}

}

