package com.plumtree.portalpages.browsing.unsubscribe.communities;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.pei.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author dustina
 *
 * To change this generated comment edit the template variable "typecomment":
 * Window>Preferences>Java>Templates.
 * To enable and disable the creation of type comments go to
 * Window>Preferences>Java>Code Generation.
 */
public class UnsubscribeCommunitiesModel extends EditorModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		"com.plumtree.portalpages.browsing.unsubscribe.communities.UnsubscribeCommunitiesModel");

	public static final String STR_MVC_CLASS_NAME = "UnsubscribeCommunities";
	
	
	protected IPTSession m_Session;
	protected XPArrayList m_alCommunitiesToDelete;
	private Object[][] m_objCommunities  = null;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new UnsubscribeCommunitiesModel();
	}
	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}
	
	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 *
	 */
	public void Finish()
	{
		// Setup PEI variables
		IApplication application = m_asOwner.GetApplication();
		Object[] oa = (Object[]) application.GetCachingManager().GetEntry("CommunityActions");
		int[] anCommIDs = new int[m_alCommunitiesToDelete.GetSize()];
		// End setup of PEI variables
					
		int commID;
		IPTCommunityManager ptCommManager = ((IPTCommunityManager)m_Session.GetCommunities());
		for (int i = 0; i < m_alCommunitiesToDelete.GetSize(); i++) {
			commID = XPConvert.ToInteger(m_alCommunitiesToDelete.GetElement(i));
			ptCommManager.QuitCommunity(commID);
			
			if (oa != null && oa.length > 0)
			{
				anCommIDs[i] = commID;
			}
		}

		try
		{
			//PEI : CommunityActions
			// MJD: All of the following code will load all of the available CommunityAction
			// PEIs and process through them.
			if (oa != null)
			{
				for (int iCommAction = 0; iCommAction < oa.length; iCommAction++)
				{
					Object o = oa[iCommAction];
	
					if(o != null)
					{
						ICommunityActions iActions = (ICommunityActions) o;
						iActions.OnAfterUserQuitsCommunity(m_asOwner, 
							(IPTSession) m_asOwner.GetUserSession(), anCommIDs);
					}
				}
			}
			//PEI : CommunityActions : END
		}
		catch (Exception ex)
		{
			
				log.Error(ex, "OnAfterUserQuitsCommunity PEI failed.");
			
		}
	}
	
	/**
	 * Returns the Redirect object
	 * (this is were we need to go at the end).
	 * This is going to the previous AS
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		if(m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
		{
			return super.GetRedirectAfterFinish();	
		}
		
		// PAI - this is a hack.  we set the location using 
		// javascript to keep the page from closing if the parent space is
		// the gateway
		
		Redirect redirect = new Redirect();

		ASURL asurl = new ASURL(m_asOwner);

		ASCache myCache			   = (ASCache) m_asOwner.GetSubSession()
		.GetAttribute(ASConstants.SANDBOXASCACHE);
		AActivitySpace parentSpace = myCache.GetSpace(m_asOwner.GetParentSpaceName(),
		m_asOwner.GetParentSpaceID());

		if(parentSpace != null) {
			asurl.SetLinkGetCachedSpace(parentSpace);
		} else {
			asurl.SetLinkCreateNewSpace(m_asOwner.GetParentSpaceName(), m_asOwner);
		}

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		script.AddInnerHTMLString("window.location='" + asurl.GetURLAsString() + "';");

		ClosePopUpDP closeDP = (ClosePopUpDP) m_asOwner.GetPage(ClosePopUpDP.STR_MVC_CLASS_NAME);
		closeDP.SetScript(script);
		closeDP.SetToClose(false);

		redirect.SetLinkGetCachedSpace(m_asOwner);
		redirect.SetDisplayPage(ClosePopUpDP.STR_MVC_CLASS_NAME);

		return redirect;
	}
	
	/**
	 * Inits the Model with the IPTSession.
	 *
	 * @param parent
	 * /
	public void Init(AActivitySpace parent)
	{
		m_asOwner     = parent;
		
	}
	
	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		m_Session = (IPTSession) m_asOwner.GetUserSession();
		m_alCommunitiesToDelete = new XPArrayList();
		
		StartSelectPTObject();
		
		return true;
	}
	
	/**
	 * Returns the Session associated with user.
	 *
	 * @return void
	 */
	public void AddCommToDelete(Object _commID)
	{
		m_alCommunitiesToDelete.Add(_commID);
	}
	
	/**
	 * Calls the right save function according to the page name passed in argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	
	/**
	 * Helper method to start the Select PTObject List.
	 *
	 */
	public void StartSelectPTObject()
	{
		MyCommunitiesListModel myCommunitiesObjectModel = (MyCommunitiesListModel) 
			m_asOwner.GetModel(MyCommunitiesListModel.STR_MVC_CLASS_NAME);
		
		myCommunitiesObjectModel.InitCommExpList(m_asOwner.GetString(1549, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1550, "ptmsgs_portalbrowsingmsgs"), m_asOwner.GetString(1551, "ptmsgs_portalbrowsingmsgs"));
			
		//IPTQueryResult qrMyCommunities = m_Session.GetSessionInfo().GetCurrentCommunityMembership();
		IPTQueryResult qrMyCommunities = ((IPTCommunityManager)m_Session.GetCommunities()).QueryMemberships();
		
		m_objCommunities = new Object[qrMyCommunities.RowCount()][];
		Object[] objCommunity;

		for (int i = 0; i < qrMyCommunities.RowCount(); i++)
		{
			objCommunity = new Object[MyCommunitiesListModel.COMMLIST_COL_MAX];
			objCommunity[MyCommunitiesListModel.COMMLIST_COL_NAME] = qrMyCommunities.ItemAsString(i,
					PT_PROPIDS.PT_PROPID_NAME);
			objCommunity[MyCommunitiesListModel.COMMLIST_COL_ID]  = qrMyCommunities.ItemAsObject(i,
					PT_PROPIDS.PT_PROPID_OBJECTID);
			objCommunity[MyCommunitiesListModel.COMMLIST_COL_MEMBERSHIPTYPE] = qrMyCommunities.ItemAsObject(i, 
					PT_PROPIDS.PT_PROPID_MEMBERSHIP_TYPE);
			
			m_objCommunities[i] = objCommunity;
			
		}
		
		if (m_objCommunities != null)
		{
			myCommunitiesObjectModel.GetItems().AddRows(m_objCommunities);
		}
		
		if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
		{
			myCommunitiesObjectModel.SetIsListReadOnly(true);
		}
				
	}	

}

