package com.plumtree.portalpages.common.browsingpropchooser;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the implementation of the Expandable List for editing properties displayed when browsing
 *
 * @author stephenc
 */
public class PropChooserView extends ExpListView
{
	/** Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "PropChooser";

	
	public static final String HTMLINPUT_SELECT_NEW_PROP	   = "in_se_NewProperty";

	
	public static final String HTMLINPUT_SELECT_NEW_PROP_TAGID = "NewPropTagID";

	/** Used to set the style of the row */
	private PTStyleClass rowStyleClass;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PropChooserView();
	}

	/**
	 * Returns the HTML for the row _nRowIndex. Each row contains just an icon
	 * and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 *
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();

		result.AddInnerHTMLElement(GetHTMLForName(_saData, _nRowIndex));

		if (((IExpListModelRO) m_model).GetEnableMoveRowActions())
		{
			result.AddInnerHTMLElement(super.GetHTMLForMoveRowActions(
					_nRowIndex));
		}

		return result;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param _nRowIndex 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLTableCell GetHTMLForCheckBox(int _nRowIndex)

	{
		IPropChooserModelRO iECPModel = (IPropChooserModelRO) m_model;

		HTMLTableCell myCell;
		HTMLInput myInput;

		myCell = new HTMLTableCell();
		myCell.SetWidth("20");
		myCell.SetHeight("30");
		myCell.SetAlign("center");
		myCell.SetVAlign("middle");
		myCell.SetStyleClass(PTStyleClass.LIST_TEXT);

		// checkbox
		myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
				iECPModel.GetUniqueString(HTMLCHECKBOX_DELROW),
				iECPModel.GetDeleteIconAlt());
		myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
		myInput.SetValue(XPConvert.ToString(_nRowIndex));
		myCell.AddInnerHTMLElement(myInput);

		return myCell;
	}

	/**
	 * 
	 *
	 * @param _saData 
	 * @param _nRowIndex 
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLTableCell GetHTMLForName(
		IPTGrowableSortedArrayWrapperRO _saData, int _nRowIndex)

	{
		IPropChooserModelRO iECPModel = (IPropChooserModelRO) m_model;

		HTMLTableCell myCell = new HTMLTableCell();
		myCell.SetWidth("100%");
		myCell.SetHeight("30");
		myCell.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

		String strName = iECPModel.GetRowName(_nRowIndex);
		int nStatus    = iECPModel.GetRowStatus(_nRowIndex);

		// Display name
		if (PropChooserModel.COL_STATUS_ADDED_NEW == nStatus)
		{
			myCell.AddInnerHTMLElement(GetUnusedPropertiesHTMLSelect());
		}
		else
		{
			myCell.AddInnerHTMLString("<B>" +
				XPHttpUtility.HtmlEncode(strName) + "</B>");
		}

		return myCell;
	}

	/**
	 * Generates a list of properties to be added.  Only card props that have not been chosen are offered
	 *
	 * @return 
	 *
	 * @throws HTMLException 
	 */
	protected HTMLSelect GetUnusedPropertiesHTMLSelect()

	{
		IPropChooserModelRO iECPModel = (IPropChooserModelRO) m_model;

		HTMLSelect mySelect = new HTMLSelect(HTMLINPUT_SELECT_NEW_PROP,
				HTMLINPUT_SELECT_NEW_PROP_TAGID);

		XPSortedDictionary xpUnusedProperties = iECPModel.GetUnusedProperties();

		IXPEnumerator xpEnum;
		IXPEnumerator xpKeys;

		xpEnum     = xpUnusedProperties.GetElements();
		xpKeys     = xpUnusedProperties.GetKeys();

		int nNewlySelectedPropertyID = iECPModel.GetNewlySelectedPropertyID();

		while (xpEnum.MoveNext() && xpKeys.MoveNext())
		{
			String strPropName = (String) xpKeys.GetCurrent();
			int nPropID		   = XPConvert.ToInteger(xpEnum.GetCurrent());

			HTMLOption optionVal = new HTMLOption(XPConvert.ToString(nPropID));

			if (nNewlySelectedPropertyID == nPropID)
			{
				optionVal.SetSelected(true);
			}

			mySelect.AddInnerHTMLElement(optionVal);
			optionVal.AddInnerHTMLString(XPHttpUtility.HtmlEncode(strPropName));
		}

		return mySelect;
	}

	/**
	  * Helper method to set the style of a row.  This method is used by
	  * Display(). Overrides the ExpListView::SetExpListRowStyle().
	  *
	  * @param _myRow
	  * @param _nRowIndex
	  * @param _nLastVisibleRow
	  *
	  * @throws HTMLException
	  *
	  * @see com.plumtree.uiinfrastructure.expandablelist.ExpListView#SetExpListRowStyle(HTMLTableRow,
	  *      int, int)
	 */
	protected void SetRowStyle(HTMLTableRow _myRow, int _nRowIndex,
		int _nLastVisibleRow)

	{
		IPropChooserModelRO iOPModel = (IPropChooserModelRO) m_model;

		// Get current property ID
		int nPropertyID = iOPModel.GetRowPropertyID(_nRowIndex);

		// Get last visible property ID
		int nLastVisiblePropertyID = PT_INTRINSICS.PT_NULL_OBJECTID;

		if (-1 != _nLastVisibleRow)
		{
			nLastVisiblePropertyID = iOPModel.GetRowPropertyID(_nLastVisibleRow);
		}

		// Check if we have moved on to a new property
		if (nPropertyID != nLastVisiblePropertyID)
		{
			// Toggle style index if we have a new property
			if (PTStyleClass.LIST_ITEM_ONE_BG == rowStyleClass)
			{
				rowStyleClass = PTStyleClass.LIST_ITEM_TWO_BG;
			}
			else
			{
				rowStyleClass = PTStyleClass.LIST_ITEM_ONE_BG;
			}
		}

		_myRow.SetStyleClass(rowStyleClass);
	}
}

