package com.plumtree.portalpages.common.dirprefs;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.browsingpropchooser.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tips.*;
import com.plumtree.xpshared.htmlelements.*;
/**
 * @author StephenC
 */
public class DirPrefsAS extends PTEditorAS
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.dirprefs.DirPrefsAS");

	
	private static final String sClassName = "com.plumtree.portalpages.common.dirprefs.DirPrefsAS";

	
	public static final String STR_MVC_CLASS_NAME = "DirPrefs";

	
	public static final String strBrowsingPropertiesPlugInKey = "BrowsingPropertiesPlugIn";

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirPrefsAS();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetEditorTitle()
	{
		return(GetString(499, "ptmsgs_portalcommonmsgs"));
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (DirPrefsRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		if (!((IPTSession) GetUserSession()).GetSessionInfo()
			.CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_UTILITIES))
		{
			return false;
		}

		return super.CheckBasicAccess(strPage, strControl, bSameSpace);
	}

	/**
	 * 
	 */
	public void Init()
	{
		m_strModelName = DirPrefsModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(m_strModelName);
		RegisterPage(new DirPrefsDP());
		RegisterView(DirPrefsView.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(DirPrefsRepostControl.STR_MVC_CLASS_NAME, myModel);

		// Register Plug-In: Browsing Properties
		RegisterModel(PropChooserModel.STR_MVC_CLASS_NAME,
			strBrowsingPropertiesPlugInKey);

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myPropChooserPlugInModel = GetModel(strBrowsingPropertiesPlugInKey);
		RegisterView(PropChooserView.STR_MVC_CLASS_NAME,
			strBrowsingPropertiesPlugInKey, myPropChooserPlugInModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME,
			strBrowsingPropertiesPlugInKey, myPropChooserPlugInModel);

		SetCurrentPage(DirPrefsDP.STR_MVC_CLASS_NAME);

		// This editor only has one page so we can set the help here
		this.SetHelpTopic( "PT_KnowledgeDirectoryPreferences_MainSettings" );                           

		// Set left nav menu
		// BEGIN Sub menu "General Settings"
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(500, "ptmsgs_portalcommonmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, DirPrefsDP.STR_MVC_CLASS_NAME);

		// END Sub menu "General Settings"
		
		

		//	TIPS
		TipsModel tm = (TipsModel) GetModel(TipsModel.STR_MVC_CLASS_NAME);

		if (tm != null)
		{
			try
			{
				tm.SetGeneratingClass( sClassName );
				
				
				int iTitleId = 117;
				int iTipId = 118;
				int iSecondaryTipId = 119;
								
				tm.SetTipTitle( this.GetString( iTitleId, ResourceConstants.TIPS) );

				HTMLGenericElement e = new HTMLGenericElement( this.GetString( iTipId, ResourceConstants.TIPS) );

				tm.SetTip( e );
				
				String sSecondary = this.GetString( iSecondaryTipId, ResourceConstants.TIPS);
				
				if( !("none_do_not_translate".equals( sSecondary )) )
				{
									
					e = new HTMLGenericElement( sSecondary );
				
					tm.SetSecondarTip( e );
				}

								

			}
			catch (Exception ex)
			{
				
					log.Error(ex, "Couldn't generate tip.");
				
			}
		}
		 //	Got the tips model
		 
		 				
		
	}

}

