package com.plumtree.portalpages.common.dirprefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.common.browsingpropchooser.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * 
 *
 * @author StephenC
 */
public class DirPrefsModel extends EditorModel implements IDirPrefsModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.dirprefs.DirPrefsModel");

	
	public static final String STR_MVC_CLASS_NAME = "DirPrefs";

	
	public String m_strDocDescriptionType = "DF"; // DF, DA, DN

	
	public String m_strFolderDescriptionType = "FF"; // FF, FA, FN

	
	public int m_nBrowseBy = 1; // 1,2 (search, db)

	
	public int m_nDefaultDocType = 107;

	
	public int m_nNumDocsPerPage = 20; // 1-99999

	
	public int m_nNumFolderColumns = 3; // 1 to 8

	
	public int m_nNumSubSubFolders = 5; // 1 to 5

	
	public int m_nRelatedResourcesPlacement = 1; // 1,2,3,4 (left, right, top, bottom)

	
	protected IPTServerConfigSettings m_SCS;

	
	private IPTSession m_ptSession;

	
	public DirPrefsModel()
	{
		super();
		m_strDocDescriptionType = DirConstants.DIR_DOC_DESC_ABBR;
		m_strFolderDescriptionType = DirConstants.DIR_FOLD_DESC_NONE;		
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetBrowseBy()
	{
		return m_nBrowseBy;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetDefaultDocType()
	{
		return m_nDefaultDocType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetDocDescriptionType()
	{
		return m_strDocDescriptionType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetFolderDescriptionType()
	{
		return m_strFolderDescriptionType;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumDocsPerPage()
	{
		return m_nNumDocsPerPage;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumFolderColumns()
	{
		return m_nNumFolderColumns;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumSubSubFolders()
	{
		return m_nNumSubSubFolders;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetRelatedResourcesPlacement()
	{
		return m_nRelatedResourcesPlacement;
	}

	/**
	 * 
	 *
	 * @param strErrorMsgs 
	 * @param strNewMessage 
	 *
	 * @return 
	 */
	public String AddToErrorString(String strErrorMsgs, String strNewMessage)
	{
		if (strErrorMsgs.length() > 0)
		{
			return strErrorMsgs + ", " + strNewMessage;
		}
		else
		{
			return strNewMessage;
		}
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		if (!((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().CheckCurrentUserIsAdmin())
		{
			UIError myError = new UIError(UIErrorLevel.WARNING,
			
			UIErrorScope.CURRENT_USER, null,
				m_asOwner.GetString(157, "ptmsgs_portalinfrastructure"), "");

			myError.SetActivitySpace(m_asOwner.GetName());

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());

			m_bIsEditorReadOnly = true;
		}


		LoadSettings();

		StartBrowsingProperties();

		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirPrefsModel();
	}

	/**
	 * 
	 */
	public void Finish()
	{
		try
		{
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE,
				m_strFolderDescriptionType);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS,
				m_nNumSubSubFolders);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS,
				m_nNumFolderColumns);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE,
				m_nNumDocsPerPage);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE,
				m_strDocDescriptionType);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE,
				m_nRelatedResourcesPlacement);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY,
				m_nBrowseBy);
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE,
				m_nDefaultDocType);

			String strSelectedProperties = ((PropChooserModel) m_asOwner.GetModel(DirPrefsAS.strBrowsingPropertiesPlugInKey)).GetSelectedProperties();
			m_SCS.SetSetting(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PROP_COLUMNS,
				strSelectedProperties);
		}
		catch (Exception e)
		{
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, null,
					
				m_asOwner.GetString(504, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(504, "ptmsgs_portalcommonmsgs")); 
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		// Reload the cached version
		IApplication application	   = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		PTDirPrefsVarPack vpPTDirPrefs = (PTDirPrefsVarPack) application.GetVarPackManager()
			.GetVariablePackage(PTDirPrefsVarPack.VARPACK_ID);
		vpPTDirPrefs.LoadVarPack(vpPTDirPrefs.GetConfigPath());
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public IASQueryResult GetDocTypes()
	{
		try
		{
			IPTQueryResult ptQR = m_ptSession.GetDocumentTypes().Query(PT_PROPIDS.PT_PROPID_OBJECTID |
					PT_PROPIDS.PT_PROPID_NAME, -1,
					PT_PROPIDS.PT_PROPID_NAME, 0,
					-1, null);

			return new ASQueryResultWrapper(ptQR);
		}
		catch (Exception e)
		{
			log.Error("Couldn't retrieve document types");
		}

		return null;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 */
	public void LoadSettings()
	{
		m_ptSession     = (IPTSession) m_asOwner.GetUserSession();
		m_SCS		    = (IPTServerConfigSettings) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
				false);

		// Load Current Settings
		Object oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_FOLD_DESC_TYPE);

		if (null != oValue)
		{
			m_strFolderDescriptionType = (String) oValue;
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_SUB_SUB_FOLDERS);

		if (null != oValue)
		{
			m_nNumSubSubFolders = XPConvert.ToInteger(oValue);
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_FOLD_COLUMNS);

		if (null != oValue)
		{
			m_nNumFolderColumns = XPConvert.ToInteger(oValue);
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_NUM_DOCS_PER_PAGE);

		if (null != oValue)
		{
			m_nNumDocsPerPage = XPConvert.ToInteger(oValue);
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DOC_DESC_TYPE);

		if (null != oValue)
		{
			m_strDocDescriptionType = (String) oValue;
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_PLACE_RELATED_RESOURCE);

		if (null != oValue)
		{
			m_nRelatedResourcesPlacement = XPConvert.ToInteger(oValue);
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_BROWSEBY);

		if (null != oValue)
		{
			m_nBrowseBy = XPConvert.ToInteger(oValue);
		}

		oValue = m_SCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_DIRECTORY_DEFAULT_DOCTYPE);

		if (null != oValue)
		{
			m_nDefaultDocType = XPConvert.ToInteger(oValue);
		}
	}

	/**
	 * 
	 *
	 * @param _sPageName 
	 * @param _htFormData 
	 *
	 * @return 
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int result = RepostControl.PAGE_STATUS_VALID;

		if (_sPageName.equals(DirPrefsDP.STR_MVC_CLASS_NAME))
		{
			result = SaveMainPage(_htFormData);

			// Save Card Properties
			int nSectionRetVal = ((PropChooserModel) m_asOwner.GetModel(DirPrefsAS.strBrowsingPropertiesPlugInKey)).SaveSection(_htFormData);

			if (RepostControl.PAGE_STATUS_VALID != nSectionRetVal)
			{
				result = nSectionRetVal;
			}
		}

		return result;
	}

	/**
	 * 
	 *
	 * @param _htFormData 
	 *
	 * @return 
	 */
	protected int SaveMainPage(XPHashtable _htFormData)
	{
		String strErrorMsgs = "";
		int result		    = RepostControl.PAGE_STATUS_VALID;

		// Folder Description Type
		String[] data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_FolderDescriptionType);

		if ((null != data) && !(0 == data.length))
		{
			m_strFolderDescriptionType = data[0];
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Folder Description Type was not in Query String.");
			
		}

		// Number of Sub Sub Folders
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_NumSubSubFolders);

		if ((null != data) && !(0 == data.length))
		{
			m_nNumSubSubFolders = XPConvert.ToInteger(data[0]);
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Number of Sub Sub Folders was not in Query String.");
			
		}

		// Number of Folder Columns
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_NumFolderColumns);

		if ((null != data) && !(0 == data.length))
		{
			m_nNumFolderColumns = XPConvert.ToInteger(data[0]);
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Number of Folder Columns was not in Query String.");
			
		}

		// Number of Docs Per Page
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLINPUT_NumDocsPerPage);

		if ((null != data) && !(0 == data.length))
		{
			m_nNumDocsPerPage = XPConvert.ToInteger(data[0]);

			if (0 > m_nNumDocsPerPage)
			{
				strErrorMsgs = AddToErrorString(strErrorMsgs, m_asOwner.GetString(503, "ptmsgs_portalcommonmsgs"));
			}
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Number of Docs Per Page was not in Query String.");
			
		}

		// Document Description Type
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_DocDescriptionType);

		if ((null != data) && !(0 == data.length))
		{
			m_strDocDescriptionType = data[0];
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Document Description Type was not in Query String.");
			
		}

		// Related Resources Placement
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_RelatedResourcesPlacement);

		if ((null != data) && !(0 == data.length))
		{
			m_nRelatedResourcesPlacement = XPConvert.ToInteger(data[0]);
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Related Resources Placement was not in Query String.");
			
		}

		// Browse By
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_BrowseBy);

		if ((null != data) && !(0 == data.length))
		{
			m_nBrowseBy = XPConvert.ToInteger(data[0]);
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Browse By option was not in Query String.");
			
		}

		// Default DocType
		data = (String[]) _htFormData.GetElement(DirPrefsView.HTMLSELECT_DefaultDocType);

		if ((null != data) && !(0 == data.length))
		{
			m_nDefaultDocType = XPConvert.ToInteger(data[0]);
		}
		else
		{
			
				log.Warn("DirPrefsModel::SaveMainPage Default Doc Type was not in Query String.");
			
		}

		// Report Errors if any
		if (strErrorMsgs.length() > 0)
		{
			result = RepostControl.PAGE_STATUS_INVALID;

			String msg = m_asOwner.GetString(502, "ptmsgs_portalcommonmsgs") + strErrorMsgs;
			UIError myError = new UIError(UIErrorLevel.FRIENDLY,
					UIErrorScope.CURRENT_USER, null, msg, msg);
			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),
				m_asOwner.GetApplication());
		}

		return result;
	}

	/**
	 * 
	 */
	private void StartBrowsingProperties()
	{
		((PropChooserModel) m_asOwner.GetModel(DirPrefsAS.strBrowsingPropertiesPlugInKey)).InitializeSelectedProperties(m_ptSession);
	}
}

