package com.plumtree.portalpages.common.dirprefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 */
public class DirPrefsView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.dirprefs.DirPrefsView");

	
	public static final String STR_MVC_CLASS_NAME = "DirPrefs";

	// HTML Object names.

	
	public static final String HTMLSELECT_FolderDescriptionType     = "in_se_FolderDescriptionType";

	
	public static final String HTMLSELECT_NumSubSubFolders		    = "in_se_NumSubSubFolders";

	
	public static final String HTMLSELECT_NumFolderColumns		    = "in_se_NumFolderColumns";

	
	public static final String HTMLINPUT_NumDocsPerPage			    = "in_tx_NumDocsPerPage";

	
	public static final String HTMLSELECT_DocDescriptionType	    = "in_se_DocDescriptionType";

	
	public static final String HTMLSELECT_RelatedResourcesPlacement = "in_se_RelatedResourcesPlacement";

	
	public static final String HTMLSELECT_BrowseBy		 = "in_se_BrowseBy";

	
	public static final String HTMLSELECT_DefaultDocType = "in_se_DefaultDocType";

	
	public static final String HTMLBUTTON_RELOAD = "in_bu_reload";

	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DirPrefsView();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLSpan mySpan;
		HTMLSelect mySelect;
		HTMLOption myOption;

		try
		{
			result.AddInnerHTMLElement(new HTMLComment("Begin: Display DirPrefsView MainView"));

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(505, "ptmsgs_portalcommonmsgs")));

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// BEGIN Folder Description Type Label ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(506, "ptmsgs_portalcommonmsgs") + ":");

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			String strFolderDescriptionType = ((IDirPrefsModelRO) m_model).GetFolderDescriptionType();

			mySelect = new HTMLSelect(HTMLSELECT_FolderDescriptionType,
					"select1");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			myCell.AddInnerHTMLElement(mySelect);

			myOption     = new HTMLOption(DirConstants.DIR_FOLD_DESC_NONE);
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(519, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_FOLD_DESC_NONE, strFolderDescriptionType))
			{
				myOption.SetSelected(true);
			}

			myOption     = new HTMLOption(DirConstants.DIR_FOLD_DESC_ABBR);
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(520, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_FOLD_DESC_ABBR, strFolderDescriptionType))
			{
				myOption.SetSelected(true);
			}

			myOption     = new HTMLOption(DirConstants.DIR_FOLD_DESC_FULL);
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(521, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_FOLD_DESC_FULL, strFolderDescriptionType))
			{
				myOption.SetSelected(true);
			}

			// END Folder Description Type Label ROW
			// BEGIN Num Sub Sub Folders ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(507, "ptmsgs_portalcommonmsgs") + ":");
			mySpan.AddInnerHTMLElement(new HTMLBr());
			HTMLSpan myOtherSpan = new HTMLSpan();
			myOtherSpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myOtherSpan.AddInnerHTMLString(m_asOwner.GetString(801, "ptmsgs_portalcommonmsgs"));
			myCell.AddInnerHTMLElement(myOtherSpan);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nNumSubSubFolders = ((IDirPrefsModelRO) m_model).GetNumSubSubFolders();

			mySelect = new HTMLSelect(HTMLSELECT_NumSubSubFolders, "select2");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			for (int i = 0;
					i <= DirConstants.MAX_NUM_SUB_SUB_FOLDERS_TO_DISPLAY;
					i++)
			{
				myOption     = new HTMLOption(XPConvert.ToString(i));
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.AddInnerHTMLString(XPConvert.ToString(i));
				mySelect.AddInnerHTMLElement(myOption);

				if (i == nNumSubSubFolders)
				{
					myOption.SetSelected(true);
				}
			}

			// END Num Sub Sub Folders ROW
			// BEGIN Number of Subfolder Columns ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(508, "ptmsgs_portalcommonmsgs") + ":");
			mySpan.AddInnerHTMLElement(new HTMLBr());
			myOtherSpan = new HTMLSpan();
			myOtherSpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			myOtherSpan.AddInnerHTMLString(m_asOwner.GetString(801, "ptmsgs_portalcommonmsgs"));
			myCell.AddInnerHTMLElement(myOtherSpan);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nNumFolderColumns = ((IDirPrefsModelRO) m_model).GetNumFolderColumns();

			mySelect = new HTMLSelect(HTMLSELECT_NumFolderColumns, "select3");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			for (int i = 1; i <= DirConstants.MAX_NUM_FOLDER_COLUMNS; i++)
			{
				myOption     = new HTMLOption(XPConvert.ToString(i));
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.AddInnerHTMLString(XPConvert.ToString(i));
				mySelect.AddInnerHTMLElement(myOption);

				if (i == nNumFolderColumns)
				{
					myOption.SetSelected(true);
				}
			}

			// END Number of Subfolder Columns ROW
			// BEGIN Number of Docs Per Page ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(509, "ptmsgs_portalcommonmsgs") + ":");

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nNumDocsPerPage = ((IDirPrefsModelRO) m_model).GetNumDocsPerPage();

			myInput = new HTMLInput(HTMLInputTypes.TEXT,
					HTMLINPUT_NumDocsPerPage, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetValue(XPConvert.ToString(nNumDocsPerPage));
			myInput.SetMaxLength(5);
			myInput.SetSize(10);

			// END Number of Docs Per Page ROW
			// BEGIN Document Description Type Label ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(510, "ptmsgs_portalcommonmsgs") + ":");

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			String strDocDescriptionType = ((IDirPrefsModelRO) m_model).GetDocDescriptionType();

			mySelect = new HTMLSelect(HTMLSELECT_DocDescriptionType, "select4");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			myCell.AddInnerHTMLElement(mySelect);

			myOption     = new HTMLOption(DirConstants.DIR_DOC_DESC_NONE);
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(519, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_NONE, strDocDescriptionType))
			{
				myOption.SetSelected(true);
			}

			myOption     = new HTMLOption(DirConstants.DIR_DOC_DESC_ABBR);
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(520, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_ABBR, strDocDescriptionType))
			{
				myOption.SetSelected(true);
			}

			myOption     = new HTMLOption(DirConstants.DIR_DOC_DESC_FULL);
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(521, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (XPStringUtility.EqualsIgnoreCase(DirConstants.DIR_DOC_DESC_FULL, strDocDescriptionType))
			{
				myOption.SetSelected(true);
			}

			// END Document Description Type Label ROW
			// BEGIN Related Resources Placement ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(511, "ptmsgs_portalcommonmsgs") + ":");

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nRelatedResourcesPlacement = ((IDirPrefsModelRO) m_model).GetRelatedResourcesPlacement();

			mySelect = new HTMLSelect(HTMLSELECT_RelatedResourcesPlacement,
					"select5");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// Left
			myOption     = new HTMLOption(XPConvert.ToString(
						DirConstants.RELATED_RESOURCE_LOCATION_LEFT));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(513, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (DirConstants.RELATED_RESOURCE_LOCATION_LEFT == nRelatedResourcesPlacement)
			{
				myOption.SetSelected(true);
			}

			// Right
			myOption     = new HTMLOption(XPConvert.ToString(
						DirConstants.RELATED_RESOURCE_LOCATION_RIGHT));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(514, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (DirConstants.RELATED_RESOURCE_LOCATION_RIGHT == nRelatedResourcesPlacement)
			{
				myOption.SetSelected(true);
			}

			// Top
			myOption     = new HTMLOption(XPConvert.ToString(
						DirConstants.RELATED_RESOURCE_LOCATION_TOP));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(515, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (DirConstants.RELATED_RESOURCE_LOCATION_TOP == nRelatedResourcesPlacement)
			{
				myOption.SetSelected(true);
			}

			// Bottom
			myOption     = new HTMLOption(XPConvert.ToString(
						DirConstants.RELATED_RESOURCE_LOCATION_BOTTOM));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(516, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (DirConstants.RELATED_RESOURCE_LOCATION_BOTTOM == nRelatedResourcesPlacement)
			{
				myOption.SetSelected(true);
			}

			// END Related Resources Placement ROW
			// BEGIN Browse By ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(512, "ptmsgs_portalcommonmsgs") + ":");

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nBrowseBy = ((IDirPrefsModelRO) m_model).GetBrowseBy();

			mySelect = new HTMLSelect(HTMLSELECT_BrowseBy, "select6");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// Left
			myOption     = new HTMLOption(XPConvert.ToString(
						DirConstants.BROWSE_BY_SEARCH));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(517, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (DirConstants.BROWSE_BY_SEARCH == nBrowseBy)
			{
				myOption.SetSelected(true);
			}

			// Right
			myOption     = new HTMLOption(XPConvert.ToString(
						DirConstants.BROWSE_BY_DATABASE));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(518, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (DirConstants.BROWSE_BY_DATABASE == nBrowseBy)
			{
				myOption.SetSelected(true);
			}

			// END Browse By ROW
			// BEGIN Default DocType ROW
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(524, "ptmsgs_portalcommonmsgs") + ":");

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			int nDefaultDocType = ((IDirPrefsModelRO) m_model).GetDefaultDocType();
			IASQueryResult asQR = ((IDirPrefsModelRO) m_model).GetDocTypes();

			mySelect		    = new HTMLSelect(HTMLSELECT_DefaultDocType,
					"select7");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			// None option
			myOption     = new HTMLOption(XPConvert.ToString(0));
			mySpan		 = new HTMLSpan();
			myOption.AddInnerHTMLElement(mySpan);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(525, "ptmsgs_portalcommonmsgs"));
			mySelect.AddInnerHTMLElement(myOption);

			if (0 == nDefaultDocType)
			{
				myOption.SetSelected(true);
			}

			int nNumDocTypes = asQR.GetCount();

			for (int i = 0; i < nNumDocTypes; i++)
			{
				int nDocTypeID		  = XPConvert.ToInteger(asQR.GetFields(i,
						PT_PROPIDS.PT_PROPID_OBJECTID));
				String strDocTypeName = (String) asQR.GetFields(i,
						PT_PROPIDS.PT_PROPID_NAME);

				myOption			  = new HTMLOption(XPConvert.ToString(
							nDocTypeID));
				mySpan				  = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.AddInnerHTMLEncodedString(strDocTypeName);
				mySelect.AddInnerHTMLElement(myOption);

				if (nDocTypeID == nDefaultDocType)
				{
					myOption.SetSelected(true);
				}
			}

			// END Default DocType ROW

			// SCC: removing this button.  It does not pull the values from the database.  Rather, it just reloads from memory.
//			// BEGIN Reload Button ROW
//			myRow = new HTMLTableRow();
//			myTable.AddInnerHTMLElement(myRow);
//			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
//
//			myCell = new HTMLTableCell();
//			myRow.AddInnerHTMLElement(myCell);
//			myCell = new HTMLTableCell();
//			myRow.AddInnerHTMLElement(myCell);
//			myCell.SetNoWrap(true);
//
//			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_RELOAD, m_asOwner.GetString(523, "ptmsgs_portalcommonmsgs"));
//			myCell.AddInnerHTMLElement(myInput);
//
//			myInput.SetValue(m_asOwner.GetString(522, "ptmsgs_portalcommonmsgs"));
//			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
//			myInput.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
//				DirPrefsRepostControl.POSTTOSELF_ACTION_RELOAD + ");");
//
//			// END Reload Button ROW

			HTMLComment myComment = new HTMLComment( "End: Display DirPrefsView");
			result.AddInnerHTMLElement(myComment);
			
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME +
					"::MainView::Display The following error occured when trying to display the HTML: " +
					he.getMessage());
			

			throw new XPException(m_asOwner.GetString(526, "ptmsgs_portalcommonmsgs"), he);
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

}

