package com.plumtree.portalpages.common.documentlanguage;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This Model contains the state of the CardLanguage plug-in section.
 *
 * @author StephenC
 */
public class CardLanguagePlugInModel extends EditorHelperModel
	implements ICardLanguagePlugInModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.documentlanguage.CardLanguagePlugInModel");

	
	public static final String STR_MVC_CLASS_NAME = "CardLanguagePlugIn";

	
	public static final String ENGLISH_LOCALE_CODE = "en";	// This should never be needed.

	public static final String CHINESE_LANGUAGE_CODE			 = "zh";
	public static final String CHINESE_LOCALE_CODE_CN			 = "CN";
	public static final String CHINESE_LOCALE_CODE_TW			 = "TW";
	public static final String CHINESE_LOCALE_CODE_HK			 = "HK";
	public static final String CHINESE_LOCALE_CODE_MO			 = "MO";
	public static final String CHINESE_LOCALE_CODE_SG			 = "SG";
	private boolean m_bIsChineseLocale = false;
	
	public boolean m_bIncludeAllLanguagesOption = false;


	private PTSearchLocaleVarPack m_vpPTSearchLocales;
	private String m_strCardLanguageCode	    = "";
	private String m_strDefaultLanguage  = "";
	private String m_strInstructionLabel = "";
	private String m_strViewTitle		 = "";
	private boolean m_bDisplayPopularOnly = false;

	// END ***************** repost action methods ***************** 

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new CardLanguagePlugInModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String[] GetAllLanguageCodes()
	{
		return m_vpPTSearchLocales.GetAllLanguageCodes();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String[] GetAllLanguageNames()
	{
		if (m_bIsChineseLocale)
		{
			return m_vpPTSearchLocales.GetAllLanguageNames(CHINESE_LANGUAGE_CODE);
		}
		else
		{
			return m_vpPTSearchLocales.GetAllLanguageNames(m_strDefaultLanguage);
		}
	}

	// BEGIN ***************** helper methods ***************** 
	public String GetCardLanguageCode()
	{
		return m_strCardLanguageCode;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetDisplayOnlyPopularLanguages()
	{
		return m_bDisplayPopularOnly;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetInstructionLabel()
	{
		return m_strInstructionLabel;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public void SetInstructionLabel(String label)
	{
	    m_strInstructionLabel = label;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String[] GetPopularLanguageCodes()
	{
		return m_vpPTSearchLocales.GetPopularLanguageCodes();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String[] GetPopularLanguageNames()
	{
		if (m_bIsChineseLocale)
		{
			return m_vpPTSearchLocales.GetPopularLanguageNames(CHINESE_LANGUAGE_CODE);
		}
		else
		{
			return m_vpPTSearchLocales.GetPopularLanguageNames(m_strDefaultLanguage);
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetViewTitle()
	{
		return m_strViewTitle;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public void SetViewTitle(String title)
	{
		m_strViewTitle = title;
	}
	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IncludeAllLanguagesOption()
	{
		return m_bIncludeAllLanguagesOption;
	}

	// END ***************** helper methods ***************** 

	/**
	 * To initialize this plug-in you need to set the DP name
	 * and the default value of the plug-in setting.
	 *
	 * @param _sPlugInSetting
	 */
	public void InitializePlugIn(String strCardLanguage, String strViewTitle,
		String strInstructionLabel, boolean bIncludeAllLanguagesOption)
	{
		m_strDefaultLanguage = XPLocale.GetDefault().GetLanguage();
		
		IApplication application = ApplicationManager.GetInstance()
			.GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		m_vpPTSearchLocales = (PTSearchLocaleVarPack) application.GetVarPackManager()
			.GetVariablePackage(PTSearchLocaleVarPack.VARPACK_ID);

		// Set Default Language (from server config)
		LoadDefaultLanguage();

		m_bIncludeAllLanguagesOption = bIncludeAllLanguagesOption;

		if (true == m_bIncludeAllLanguagesOption)
		{
			m_bDisplayPopularOnly     = true;
			m_strCardLanguageCode     = (null == strCardLanguage)
										? m_strDefaultLanguage
										: strCardLanguage;
			
		}
		else
		{
			// Set the Selected Card Language
			// If null, assign a default language
			if (null == strCardLanguage)
			{
				m_strCardLanguageCode = m_strDefaultLanguage;
			}
			else
			{
				if (true == m_vpPTSearchLocales.IsValidLanguage(strCardLanguage))
				{
					m_strCardLanguageCode = strCardLanguage;
				}
				else
				{
					m_strCardLanguageCode = m_strDefaultLanguage;
				}
			}

			m_bDisplayPopularOnly = m_vpPTSearchLocales.IsPopularLanguage(m_strCardLanguageCode);
		}

		// Set Section Title and instructions:
		if (null == strViewTitle)
		{
			m_strViewTitle = m_asOwner.GetString(26, "ptmsgs_portalcommonmsgs");
		}
		else
		{
			m_strViewTitle = strViewTitle;
		}

		if (null == strViewTitle)
		{
			m_strInstructionLabel = m_asOwner.GetString(27,
					"ptmsgs_portalcommonmsgs");
		}
		else
		{
			m_strInstructionLabel = strInstructionLabel;
		}
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 * @return int Status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		String[] data = (String[]) _htFormData.GetElement(CardLanguagePlugInView.HTMLSELECT_CARDLANGUAGE);

		//Checking for Pathways
	    IPathwaysRestAPIService pathwaysHelper = PathwaysRestAPIService.GetInstance(m_asOwner);
	    boolean isPathwaysEnabled = pathwaysHelper.IsPathwaysEnabled();
	    //check if this page is the advanced search page
	    boolean isAdvancedSearchPage = m_asOwner.GetCurrentPage().GetName().equals(AdvancedSearchDP.STR_MVC_CLASS_NAME);
	    boolean isAdaptiveLayoutMode = pathwaysHelper.IsAdaptiveLayoutMode();

	    // First check, if pathways is enabled, adaptive layout mode is supported, the cardlanguage value is null 
	    // and we're in advanced search
	    if (isPathwaysEnabled && isAdaptiveLayoutMode && (null == data) && isAdvancedSearchPage)
	    {
	    	// Setting default data for language filter, the default is set to all languages.
			data = new String[]{CardLanguagePlugInView.s_AllLanguagesOptionCode};
	    }
	    // Second check, if adaptive layout mode is supported, card language value is null, and we're in advanced search
	    // Pathways does NOT need to be enabled.
	    else if (isAdaptiveLayoutMode && (null == data) && isAdvancedSearchPage)
	    {
	    	// Setting default data for language filter, the default is set to all languages.
			data = new String[]{CardLanguagePlugInView.s_AllLanguagesOptionCode};
	    }
	    
		try
		{
			m_strCardLanguageCode = data[0];
		}
		catch (Exception e)
		{
			
				log.Error(e, "CardLanguagePlugInModel::SaveSection The following error occured when trying to retrieve the selected language " +
					e.getMessage());
			
		}

		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @param bValue 
	 */
	public void SetDisplayOnlyPopularLanguages(boolean bValue)
	{
		m_bDisplayPopularOnly = bValue;
	}

	/**
	 * 
	 */
	private void LoadDefaultLanguage()
	{
		// Create a guest session to log in
		IPTSession ptGuestSession = PortalObjectsFactory.CreateSession();

		// Guest login -- The guest user password check is bypassed,
		// so we don't need to pass in the password.
		ptGuestSession.Connect(PT_INTRINSICS.PT_USER_GUEST, null, null);
		
		String strLang = PTPersonalSettingsHelper.GetPersonalSettingValue_Locale(m_asOwner).GetLanguage();
		
		// JHQ 020204 - bug 27552: special case for chinese languages
		// search supports zh_cn and zh_tw
		if (CHINESE_LANGUAGE_CODE.equals(strLang))
		{
			String strTempLocaleCode = (String) PTPersonalSettingsHelper.
				GetPersonalSettingValue(PersonalSettingNames.LOCALE, m_asOwner);
			
			// uppercase in case locale was returned in all lowercase or mixed
			// case because are ending locales need to be uppercase 
			strTempLocaleCode = XPStringUtility.ToUpperCase(strTempLocaleCode);
			
			// check the ending locale code and map to appropriate chinese locale
			if (XPStringUtility.EndsWith(strTempLocaleCode,CHINESE_LOCALE_CODE_HK))
			{
				strLang = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_TW;
			}
			else if (XPStringUtility.EndsWith(strTempLocaleCode,CHINESE_LOCALE_CODE_MO))
			{
				strLang = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_TW;
			}
			else if (XPStringUtility.EndsWith(strTempLocaleCode,CHINESE_LOCALE_CODE_CN))
			{
				strLang = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_CN;
			}
			else if (XPStringUtility.EndsWith(strTempLocaleCode,CHINESE_LOCALE_CODE_SG))
			{
				strLang = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_CN;
			}
			else if (XPStringUtility.EndsWith(strTempLocaleCode,CHINESE_LOCALE_CODE_TW))
			{
				strLang = CHINESE_LANGUAGE_CODE + "_" + CHINESE_LOCALE_CODE_TW;
			}
			
			m_bIsChineseLocale = true;
		}
		
		// strLang should never be null
		if(null != strLang)
		{
			m_strDefaultLanguage = strLang; 
		} 
		else
		{
			// Since strLang should never be null, this code should never run.
			IPTServerConfigSettings ptSCS = (IPTServerConfigSettings) ptGuestSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS,
					false);
	
			Object oSetting = ptSCS.GetSettingAsObject(PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_DEFAULT_LOCALE);
	
			if (null == oSetting)
			{
				m_strDefaultLanguage = ENGLISH_LOCALE_CODE;
			}
			else
			{
				m_strDefaultLanguage = (String) oSetting;
			}
	
			if (false == m_vpPTSearchLocales.IsValidLanguage(m_strDefaultLanguage))
			{
				m_strDefaultLanguage = ENGLISH_LOCALE_CODE;
			}
		}
	}
	
	public String GetLangFromFormData(XPHashtable formData)
	{
		if(formData == null)
			return null;
			
		String[] lang = (String[]) formData.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
								SearchSettingCollection.PT_SEARCHSETTING_LANGUAGE_S);
		String[] lbl = (String[]) formData.GetElement(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX +
								SearchSettingCollection.PT_SEARCHSETTING_LIMITBYLOCALE_S);

		if ((lbl != null) && (lbl.length > 0) && (null != lang) && (lang.length > 0))
		{
			return lang[0];
		}
		else
			return null;
	}
}

