package com.plumtree.portalpages.common.editpage;


/**
 * Interface IPageLayoutModelRO.
 * This is the interface used by PageLayoutView.
 *
 * @author michaeld
 */
public interface IPageLayoutModelRO
{
	/**
	 * Method GetCanChangeLayout.
	 * If this editor can choose the page layout type for this page,
	 * then this will return true.
	 *
	 * @return boolean
	 */
	public boolean GetCanChangeLayout();

	/**
	 * Method GetCanChooseFreeForm.
	 * If this editor can choose a free form gadget for this page,
	 * then this will return true.
	 *
	 * @return boolean
	 */
	public boolean GetCanChooseFreeForm();

	/**
	 * Method GetCanCreatePortlet.
	 * If this editor can create a gadget from a gadget template,
	 * then this will return true.
	 *
	 * @return boolean
	 */
	public boolean GetCanCreatePortlet();

	/**
	 * Method GetPortletAlignment.
	 * Gets the gadget alignment for the gadget at the given index.
	 *
	 * @param nPortletIndex
	 * @return int
	 */
	public int GetPortletAlignment(int nPortletIndex);

	/**
	 * Method GetPortletColumn.
	 * Gets the gadget column for the gadget at the given index.
	 *
	 * @param nPortletIndex
	 * @return int
	 */
	public int GetPortletColumn(int nPortletIndex);

	/**
	 * Method GetPortletCount.
	 * Gets the count of the gadgets on the page.
	 *
	 * @return int
	 */
	public int GetPortletCount();

	/**
	 * Method GetPortletDescription.
	 * Gets the gadget description for the gadget at the given index.
	 *
	 * @param nPortletIndex
	 * @return String
	 */
	public String GetPortletDescription(int nPortletIndex);

	/**
	 * Method GetPortletID.
	 * Gets the gadget ID for the gadget at the given index.
	 *
	 * @param nPortletIndex
	 * @return int
	 */
	public int GetPortletID(int nPortletIndex);

	/**
	 * Method GetPortletIsCommunityType.
	 * Gets whether the gadget at the given index is of type community or not.
	 *
	 * @param nPortletIndex
	 * @return boolean
	 */
	public boolean GetPortletIsCommunityType(int nPortletIndex);

	/**
	 * Method GetPortletIsFromPT.
	 * Returns true if the gadget is from the page template.
	 *
	 * @param nPortletIndex
	 * @return boolean
	 */
	public boolean GetPortletIsFromPT(int nPortletIndex);

	/**
	 * Method GetPortletName.
	 * Gets the gadget name for the gadget at the given index.
	 *
	 * @param nPortletIndex
	 * @return String
	 */
	public String GetPortletName(int nPortletIndex);

	/**
	 * Method GetHasFreeFormPortlet.
	 * Return true if the page has a free form portlet selected.
	 *
	 * @return boolean
	 */
	public boolean GetHasFreeFormPortlet();

	/**
	 * Method GetInputValue.
	 * Get the value for the given input.
	 *
	 * @param strName
	 * @return String
	 */
	public String GetInputValue(String strName);

	/**
	 * Method IsFreeFormLayoutAllowed.
	 * Returns whether free form layouts can be selected.
	 *
	 * @return boolean
	 */
	public boolean IsFreeFormLayoutAllowed();

	/**
	 * Method GetClassID.
	 * Gets the class ID of the object that opened this layout page.
	 *
	 * @return int
	 */
	public int GetClassID();

	/**
	 * Method GetFolderID.
	 * Gets the Folder ID of the page that opened this layout page.
	 *
	 * @return int
	 */
	public int GetFolderID();

	/**
	 * Method GetObjectID.
	 * Gets the Object ID of the object that opened this layout page.
	 *
	 * @return int
	 */
	public int GetObjectID();

	/**
	 * Method GetPageType.
	 * Gets the page type of the page we are editing.
	 *
	 * @return int
	 */
	public int GetPageType();

	/**
	 * Method GetTableHeight.
	 * Gets the height of the drag and drop table.
	 *
	 * @return int
	 */
	public int GetTableHeight();
	
	/**
	 * Method GetUseDragDropLayout.
	 * Gets wether to use the drag drop layout or the alternate layout based upon which browser is being used.
	 * 
	 * @return boolean
	 */
	public boolean GetUseDragDropLayout();
}

