/**
 * 
 */
package com.plumtree.portalpages.common.editpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.web.*;

/**
 * This class manages getting and setting portlet columns count for adaptive layouts 
 * 
 * @author rozhang
 */
public class LayoutColumnStore
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_BROWSING),
		LayoutColumnStore.class);
	
	//protected static final String APP_CACHEMAN_KEY = "PortletLayoutColumns";
	
	protected static final String CACHEKEY_PREFIX = "LAYOUTCOLENTRY";
	
	protected static final String DISABLE_DRAGDROPLAYOUTEDITOR = "DISABLE_DRAGDROPLAYOUTEDITOR";
	
	/**
	 * Get number of portlet columns for specified layout (should be a negative value for adaptive layout)
	 * @param layoutId
	 * @return 0 if the adaptive layout for the specified id was not found  
	 */
	public int GetLayoutColumnCount(int layoutId)
	{
		CachingManager cacheMan = GetCacheStore();
		int storeCount = LookupColumnCount(cacheMan, layoutId);
		
		return storeCount;
		
	}
	
	/**
	 * Helper method to get container to store layout id/column count pairs 
	 * @return
	 */
	protected CachingManager GetCacheStore()
	{
		IApplication app = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		CachingManager cacheMan = app.GetCachingManager();
		
		return cacheMan;
		
	}

	
	/**
	 * Create cache key from layout id
	 */
	protected String CreateCacheKey(int layoutId)
	{
		return CACHEKEY_PREFIX+layoutId;
	}
	
	/**
	 * Gets the number of columns assigned to specified layout id
	 * @param colStore
	 * @param layoutId
	 * @return 0 if the layout was not found
	 */
	protected int LookupColumnCount(CachingManager colStore, int layoutId)
	{
		Object val = colStore.GetEntry(CreateCacheKey(layoutId));
		if ( val != null && val instanceof Integer  ) {
			return XPConvert.ToInteger(val);
		} else {
			return 0;
		}
		
	}
	
	/**
	 * Updates column count for specified layout. New value is stored only
	 * if column count for layout is not stored before or if stored value 
	 * is different from new value 
	 * @param layoutId
	 * @param colCount
	 * @return true if column count was updated, false if the value already was set
	 */
	public boolean SetLayoutColumnCount(int layoutId, int newCount)
	{
		CachingManager cache = GetCacheStore();
		int storedCount = LookupColumnCount(cache, layoutId);
		
		if ( storedCount == newCount ) {
			// don't do anything, no need to update
			return false;
		} else {
			cache.SetEntry(CreateCacheKey(layoutId), new Integer(newCount));
			return true;
		}
	}

	/**
	 * Sets flag on Application to disable Portlet layout editor used for IE browsers
	 * Called by LayoutMetaDataTag to resolve bug 9862302. Made optional for existing 
	 * customers who want to keep the drag and drop layout editor 
	 */
	public void SetDisableDragDropLayoutEditor()
	{
		CachingManager cache = GetCacheStore();
		cache.SetEntry(DISABLE_DRAGDROPLAYOUTEDITOR, "true");
	}
	
	/**
	 * Checks whether drag drop layout editor for IE is disabled or not
	 * @return
	 */
	public boolean IsDragDropLayoutEditorDisabled() 
	{
		CachingManager cache = GetCacheStore();
		return ( null != cache.GetEntry(DISABLE_DRAGDROPLAYOUTEDITOR) );
		
	}
	
}
