package com.plumtree.portalpages.common.editpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.portlet.*;
import com.plumtree.portalpages.browsing.layoutselection.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.objectselection.*;
import com.plumtree.portalpages.browsing.objectselection.portlets.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author MichaelD
 */
public class PageLayoutHeaderView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.editpage.PageLayoutHeaderView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "EditPageLayoutHeader";

	/** Form Input: Page Layout Type */
	public static final String HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE = "in_hi_pagelayouttype";

	/** Form Input: Portlet ID to Delete */
	public static final String HTMLINPUT_DELETE_GADGETID = "in_hi_deleteID";

	/** Add Portlets Space ID */
	public static final String HTMLINPUT_ADDGADGETASID = "in_hi_AddGadgetSpaceID";

	/** New Portlet Space ID */
	public static final String HTMLINPUT_NEWGADGETASID = "in_hi_NewGadgetSpaceID";

	/** Add Free Form Space ID */
	public static final String HTMLINPUT_ADDFREEFORMASID = "in_hi_AddFreeFormSpaceID";

	/** Select Layout Space ID */
	public static final String HTMLINPUT_SELECTLAYOUTASID = "in_hi_SelectLayoutSpaceID";

	/** Javascript function names - do not need to localize **/
	public static final String JAVASCRIPT_DELETE_GADGET			= "deletePortlet";
	private static final String JAVASCRIPT_SELECT_LAYOUT			= "selectLayout";
	private static final String JAVASCRIPT_ADD_GADGETS			= "addPortlets";
	private static final String JAVASCRIPT_ADD_FREEFORM			= "addFreeForm";
	private static final String JAVASCRIPT_ONRETURN_SELECT_LAYOUT	= "oRSelectLayout";
	private static final String JAVASCRIPT_ONRETURN_ADD_GADGETS	= "oRAddPortlets";
	private static final String JAVASCRIPT_ONRETURN_ADD_FREEFORM	= "oRAddFreeForm";
	private static final String JAVASCRIPT_CHECK_LAYOUTTYPE		= "checkLayoutType";
	public static final String JAVASCRIPT_REPOST_LAYOUT = "repostLayout";

	/** String for Subspace */
	public static final String SUBSPACE_NAME_CREATEPORTLET = "PageLayoutCreatePortlet";

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PageLayoutHeaderView();
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection collection = new HTMLElementCollection();
		HTMLElement result = collection;
		
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSpan mySpan;
		PTConstruct myConstruct;
		HTMLInput myInput;
		
		myTable = new HTMLTable();
		if ( ((IPageLayoutModelRO)m_model).GetUseDragDropLayout() )
		{
			myTable.SetWidth(XPConvert.ToString(PageLayoutView.LAYOUTTABLE_WIDTH + 4));
		}
		else
		{
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		}
		myTable.SetCellPadding(CommonHTMLStrings.ZERO);
		myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
		try
		{
			collection.AddInnerHTMLElement(myTable);
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.AddInnerHTMLElement(super.GetHeaderView(
					m_asOwner.GetString(42, "ptmsgs_portalcommonmsgs")));
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Display: Failed to display header for page content and layout. " +
					he.getMessage());
			
		}

		if (PT_INTRINSICS.PT_BLANK_PAGETEMPLATEID == ((IPageLayoutModelRO) m_model).GetObjectID()
			&& PT_CLASSIDS.PT_PAGETEMPLATE_ID == ((IPageLayoutModelRO) m_model).GetClassID())
		{
			mySpan = new HTMLSpan();

			try
			{
				collection.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				collection.AddInnerHTMLElement(mySpan);
				mySpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TITLE);

				mySpan.AddInnerHTMLString(m_asOwner.GetString(46,
						"ptmsgs_portalcommonmsgs"));
				collection.AddInnerHTMLElement(new HTMLBr());
				mySpan = new HTMLSpan();
				mySpan.SetStyleClass(PTStyleClass.ALERT_TEXT);
				
				collection.AddInnerHTMLElement(mySpan);
				mySpan.AddInnerHTMLString(m_asOwner.GetString(645, "ptmsgs_portalcommonmsgs"));
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "Display: Failed to display custom page template's layout message. " +
						he.getMessage());
				
			}
		}
		else
		{
			try
			{
				// 3rd row begins
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell);

				// 3rd row ends
				// 4th row begins
				myConstruct = UIConstructFactory.GetConstruct(PTBannerType.OBJECT_ACTION_BAR);

				HTMLAnchor myAnchor;
				PTConstruct myButton;

				try
				{
					// ***Add Portlets Action*** begins here
					myButton = UIConstructFactory.GetConstruct(PTButtonType.ADD_PORTLET,
							true, this.m_asOwner);

					ConstructFactory.SetAltOnButtonImages( myButton, m_asOwner.GetString(35, "ptmsgs_portalcommonmsgs") );
					ConstructFactory.SetTitleOnButtonImages( myButton, m_asOwner.GetString(35, "ptmsgs_portalcommonmsgs") );

					myButton.ReplaceNestedElementsWithHTMLString(PTButtonType.ADD_PORTLET.GetElementName(
							PTButtonType.ELEMENT_NAME_ID_TITLE),
						CommonHTMLStrings.SPACE +
						m_asOwner.GetString(35, "ptmsgs_portalcommonmsgs") +
						CommonHTMLStrings.SPACE);
					myAnchor = (HTMLAnchor) myButton.GetNestedElement(PTButtonType.ADD_PORTLET.GetElementName(
								PTButtonType.ELEMENT_NAME_ID_ANCHOR));
					myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
					myAnchor.SetOnClick(JAVASCRIPT_ADD_GADGETS + "(document." +
						AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_ADDGADGETASID +
						");return false;");

					myConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.GetElementName(
							PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL), myButton.GetHTMLElement());

					if (((IPageLayoutModelRO) m_model).GetCanCreatePortlet())
					{
						// ***Create Portlet Action*** begins here
						myButton = UIConstructFactory.GetConstruct(PTButtonType.CREATE_PORTLET,
								true, this.m_asOwner);

						ConstructFactory.SetAltOnButtonImages( myButton, m_asOwner.GetString(38, "ptmsgs_portalcommonmsgs") );
						ConstructFactory.SetTitleOnButtonImages( myButton, m_asOwner.GetString(38, "ptmsgs_portalcommonmsgs") );
						
						myButton.ReplaceNestedElementsWithHTMLString(PTButtonType.CREATE_PORTLET.GetElementName(
								PTButtonType.ELEMENT_NAME_ID_TITLE),
							CommonHTMLStrings.SPACE +
							m_asOwner.GetString(38, "ptmsgs_portalcommonmsgs") +
							CommonHTMLStrings.SPACE);
						myAnchor = (HTMLAnchor) myButton.GetNestedElement(PTButtonType.CREATE_PORTLET.GetElementName(
									PTButtonType.ELEMENT_NAME_ID_ANCHOR));
						myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
						myAnchor.SetOnClick("createPortlet();return false;");

						myConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.GetElementName(
								PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL_2), myButton.GetHTMLElement());
					}

					if (((IPageLayoutModelRO) m_model).GetCanChooseFreeForm())
					{
						// ***Add Free Form Action*** begins here
						myButton = UIConstructFactory.GetConstruct(PTButtonType.ADD_PORTLET,
								true, this.m_asOwner);
								
						ConstructFactory.SetAltOnButtonImages( myButton, m_asOwner.GetString(39, "ptmsgs_portalcommonmsgs") );
						ConstructFactory.SetTitleOnButtonImages( myButton, m_asOwner.GetString(39, "ptmsgs_portalcommonmsgs") );

						myButton.ReplaceNestedElementsWithHTMLString(PTButtonType.ADD_PORTLET.GetElementName(
								PTButtonType.ELEMENT_NAME_ID_TITLE),
							CommonHTMLStrings.SPACE +
							m_asOwner.GetString(39, "ptmsgs_portalcommonmsgs") +
							CommonHTMLStrings.SPACE);
						myAnchor = (HTMLAnchor) myButton.GetNestedElement(PTButtonType.ADD_PORTLET.GetElementName(
									PTButtonType.ELEMENT_NAME_ID_ANCHOR));
						myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
						myAnchor.SetOnClick(JAVASCRIPT_ADD_FREEFORM +
							"(document." + AFormDP.HTMLFORM_NAME + "." +
							HTMLINPUT_ADDFREEFORMASID + ");return false;");

						myConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.GetElementName(
								PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL_2), myButton.GetHTMLElement());
					}

					if (((IPageLayoutModelRO) m_model).GetCanChangeLayout())
					{
						// ***Select Layout Action*** begins here
						myButton = UIConstructFactory.GetConstruct(PTButtonType.SELECT_LAYOUT,
								true, this.m_asOwner);
								
						ConstructFactory.SetAltOnButtonImages( myButton, m_asOwner.GetString(44, "ptmsgs_portalcommonmsgs") );
						ConstructFactory.SetTitleOnButtonImages( myButton, m_asOwner.GetString(44, "ptmsgs_portalcommonmsgs") );

						myButton.ReplaceNestedElementsWithHTMLString(PTButtonType.SELECT_LAYOUT.GetElementName(
								PTButtonType.ELEMENT_NAME_ID_TITLE),
							CommonHTMLStrings.SPACE +
							m_asOwner.GetString(44, "ptmsgs_portalcommonmsgs") +
							CommonHTMLStrings.SPACE);
						myAnchor = (HTMLAnchor) myButton.GetNestedElement(PTButtonType.SELECT_LAYOUT.GetElementName(
									PTButtonType.ELEMENT_NAME_ID_ANCHOR));
						myAnchor.SetHRef(CommonHTMLStrings.POUND_SYMBOL);
						myAnchor.SetOnClick(JAVASCRIPT_SELECT_LAYOUT +
							"(document." + AFormDP.HTMLFORM_NAME + "." +
							HTMLINPUT_SELECTLAYOUTASID + ");return false;");

						myConstruct.AddElementToNestedElement(PTBannerType.OBJECT_ACTION_BAR.GetElementName(
								PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL_2), myButton.GetHTMLElement());
					}
				}
				catch (Exception e)
				{
					
						log.Error(e, "Display: Failed to add action buttons to action bar, for the following reason. " +
							e.getMessage());
					
				}

				// 4th row ends
				myCell.AddInnerHTMLElement(myConstruct.GetHTMLElement());
				myCell.AddInnerHTMLElement(EditorView.GetSpacerTable());

				// Hidden input for space of gadget selection control
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_ADDGADGETASID, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetValue(((IPageLayoutModelRO) m_model).GetInputValue(
						HTMLINPUT_ADDGADGETASID));

				// Hidden input for space of layout selection control
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_SELECTLAYOUTASID, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetValue(((IPageLayoutModelRO) m_model).GetInputValue(
						HTMLINPUT_SELECTLAYOUTASID));

				// Hidden input for space of gadget creation control
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_NEWGADGETASID, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetValue(((IPageLayoutModelRO) m_model).GetInputValue(
						HTMLINPUT_NEWGADGETASID));

				// Hidden input for space of free form selection control
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_ADDFREEFORMASID, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetValue(((IPageLayoutModelRO) m_model).GetInputValue(
						HTMLINPUT_ADDFREEFORMASID));

				// Page Type
				int nPageType = ((IPageLayoutModelRO) m_model).GetPageType();
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetID(HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE);
				myInput.SetValue(XPConvert.ToString(nPageType));

				// Portlet To Delete
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						HTMLINPUT_DELETE_GADGETID, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetID(HTMLINPUT_DELETE_GADGETID);

				// Portlets in Column 1
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
						PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER0, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetID(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER0);

				// Portlets in Column 2
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER1, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetID(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER1);

				// Portlets in Column 3
				myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER2, "");
				collection.AddInnerHTMLElement(myInput);
				myInput.SetID(PageLayoutView.HTMLINPUT_EDITPAGE_GADGETORDER2);
			}
			catch (Exception e)
			{
				log.Error(e, "PageLayoutHeaderView::Display: The following error occured when trying to display the HTML: " +
					e.getMessage());
			}
		}

		return result;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		ASURL myNewSelector;
		ASURL myOldSelector;
		XPStringBuilder sb;

		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);

		// The URL to add gadgets
		myNewSelector = new ASURL(m_asOwner);
		myNewSelector.SetLinkCreateNewSpace(PortletSelectionEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
		myNewSelector.SetSubSpaceKey(PageLayoutPlugInModel.SUBSPACE_NAME_ADDGADGETS);
		myNewSelector.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		myNewSelector.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE, EditorStartControl.EDITOR_START_FLAG_MISC);

		if (0 != ((IPageLayoutModelRO) m_model).GetClassID())
		{
			myNewSelector.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORCLASSID,
				((IPageLayoutModelRO) m_model).GetClassID());
			myNewSelector.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTOROBJECTID,
				((IPageLayoutModelRO) m_model).GetObjectID());
		}
		else
		{
			myNewSelector.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORPAGEID,
				((IPageLayoutModelRO) m_model).GetObjectID());
		}
		
		myNewSelector.AddControlArgument(ObjSelQueryArguments.HTMLINPUT_OBJECTSELECTION_SELECTORFOLDERID,
			((IPageLayoutModelRO) m_model).GetFolderID());

		myNewSelector.AddControlArgument(ObjectSelectionRepostControl.strPARENT_FORM_NAME,
			AFormDP.HTMLFORM_NAME);
		myNewSelector.AddControlArgument(ObjectSelectionRepostControl.strPARENT_FORM_SPACE_ID,
			HTMLINPUT_ADDGADGETASID);
		myNewSelector.AddControlArgument(ObjectSelectionRepostControl.strPARENT_SUBMIT_CALL,
			JAVASCRIPT_ONRETURN_ADD_GADGETS);

		// The url to open a previously opened server user tree
		// This needs to have the SpaceID added to it.
		myOldSelector = new ASURL(m_asOwner);
		myOldSelector.SetLinkCreateNewSpace(PortletSelectionEditorAS.STR_MVC_CLASS_NAME, m_asOwner);
		myOldSelector.SetControl(RefreshObjSelControl.STR_MVC_CLASS_NAME);
		myOldSelector.SetDisplayPage(ObjSelFrameSetDP.STR_MVC_CLASS_NAME);

		try
		{
			// Open Tree function
			sb = new XPStringBuilder(200);
			sb.Append("\n" + "function ").Append(JAVASCRIPT_ADD_GADGETS).Append("(myInput)\n")
			.Append("{\n")
			.Append("	var myInputArg = '';\n")
			.Append("  if (myInput.value == '') {\n")
			.Append("  		myInputArg = '").Append(myNewSelector.GetURLAsString()).Append("';\n")
			.Append("  } else {\n")
			.Append("    	myInputArg = '").Append(myOldSelector.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value;\n")
			.Append("  }\n")
			.Append("  window.open(myInputArg, 'Portlets', 'location=no,menubar=no,height=450,width=650,resizable=yes,scrollbars=yes');\n")
			.Append("}\n");

			script.AddInnerHTMLString(sb.ToString());

			// On return from Tree function
			sb = new XPStringBuilder(200);
			sb.Append(" function ").Append(JAVASCRIPT_ONRETURN_ADD_GADGETS)
			.Append("()\n").Append(" {\n")
			.Append("		").Append(JAVASCRIPT_REPOST_LAYOUT).Append("();\n")
			.Append(" 		postToSelf('").Append(PageLayoutControl.POSTTOSELF_ACTION_ADDGADGETS).Append("');\n")
			.Append(" }\n");

			script.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "PageListView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		if (((IPageLayoutModelRO) m_model).GetCanChangeLayout())
		{
			// The url to open a previously opened select layout page
			// This needs to have the SpaceID added to it within the javascript function
			myOldSelector = new ASURL(m_asOwner);
			myOldSelector.SetLinkCreateNewSpace(LayoutSelectionEditorAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			myOldSelector.SetControl(RefreshLayoutSelectControl.STR_MVC_CLASS_NAME);
			myOldSelector.AddControlArgument(LayoutSelectionRepostControl.STR_HAS_FREE_FORM,
				((IPageLayoutModelRO) m_model).GetHasFreeFormPortlet());

			// The URL to open a new select layout page
			myNewSelector = new ASURL(m_asOwner);
			myNewSelector.SetLinkCreateNewSpace(LayoutSelectionEditorAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			myNewSelector.SetSubSpaceKey(PageLayoutPlugInModel.SUBSPACE_NAME_SELECTLAYOUT);
			myNewSelector.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			myNewSelector.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				EditorStartControl.EDITOR_START_FLAG_MISC);
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_PARENT_FORM_NAME,
				AFormDP.HTMLFORM_NAME);
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_PARENT_FORM_SPACE_ID,
				HTMLINPUT_SELECTLAYOUTASID);
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_PARENT_SUBMIT_CALL,
				JAVASCRIPT_ONRETURN_SELECT_LAYOUT);
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_SELECTED_ITEM,
				((IPageLayoutModelRO) m_model).GetPageType());
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_PARENT_FORM_SELECTED_INPUT,
				HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE);
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_HAS_FREE_FORM,
				((IPageLayoutModelRO) m_model).GetHasFreeFormPortlet());
			myNewSelector.AddControlArgument(LayoutSelectionRepostControl.STR_FREE_FROM_LAYOUT_ALLOWED,
				((IPageLayoutModelRO) m_model).IsFreeFormLayoutAllowed());

			try
			{
				// Select Layout javascript function
				sb = new XPStringBuilder(200);
				sb.Append("function ").Append(JAVASCRIPT_SELECT_LAYOUT).Append("(myInput)\n")
				.Append("{\n")
				.Append("  if (myInput.value == '') {\n")
				.Append("    window.open('").Append(myNewSelector.GetURLAsString())
				.Append("', 'SelectLayout', 'location=no,menubar=no,height=600,width=600,resizable=yes,scrollbars=yes');\n")
				.Append("  } else {\n")
				.Append("    window.open('").Append(myOldSelector.GetURLAsString()).Append("&").Append(ASConstants.SPACEID).Append("=' + myInput.value")
				.Append(", 'SelectLayout', 'location=no,menubar=no,height=600,width=600,resizable=yes,scrollbars=yes');\n")
				.Append("  }\n")
				.Append("}\n");

				script.AddInnerHTMLString(sb.ToString());

				// On return from Tree function
				sb = new XPStringBuilder(200);
				sb.Append(" function ").Append(JAVASCRIPT_ONRETURN_SELECT_LAYOUT).Append("()\n")
				.Append(" {\n")
				.Append(" 		ChangePageType(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE).Append(".value);\n")
				.Append("		").Append(JAVASCRIPT_REPOST_LAYOUT).Append("();\n")
				.Append(" 		postToSelf('").Append(PageLayoutControl.POSTTOSELF_ACTION_SELECTLAYOUT).Append("');\n")
				.Append(" }\n");

				script.AddInnerHTMLString(sb.ToString());

				sb = new XPStringBuilder(200);
				sb.Append(" function ChangePageTypeAlert(iOldPageType, iNewPageType)\n")
				.Append(" {\n");
				if (PT_CLASSIDS.PT_PAGETEMPLATE_ID == ((IPageLayoutModelRO) m_model).GetClassID())
				{
					sb.Append(" 		if (iOldPageType >= PAGETYPE_ONECOLUMN_FFC && iNewPageType < PAGETYPE_ONECOLUMN_FFC){\n")
					.Append("			alert('").Append(m_asOwner.GetString(690, "ptmsgs_portalcommonmsgs")).Append("');\n")
					.Append(" 		}\n");
				}
				sb.Append(" }\n");

				script.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "PageListView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
						he.getMessage());
				
			}
		}

		// Add Free Form content
		if (((IPageLayoutModelRO) m_model).GetCanChooseFreeForm())
		{
			// The URL to open a new user Folder tree
			myNewSelector = new ASURL(m_asOwner);
			myNewSelector.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
			myNewSelector.SetSubSpaceKey(PageLayoutPlugInModel.SUBSPACE_NAME_ADDFREEFORM);
			myNewSelector.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
			myNewSelector.AddControlArgument(StartTreeControl.ROOT_ID,
				XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
			myNewSelector.AddControlArgument(StartTreeControl.MULTI_SELECT,
				XPConvert.ToString(false));
			myNewSelector.AddControlArgument(StartTreeControl.SELECT_MODE,
				TreeConstants.N_LEAFSELECT);
			myNewSelector.AddControlArgument(StartTreeControl.SUBMIT_MODE,
				TreeConstants.N_JAVASCRIPTSUBMIT);
			myNewSelector.AddControlArgument(StartTreeControl.PARENT_FORM_NAME,
				AFormDP.HTMLFORM_NAME);
			myNewSelector.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
				HTMLINPUT_ADDFREEFORMASID);
			myNewSelector.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
				JAVASCRIPT_ONRETURN_ADD_FREEFORM);
			myNewSelector.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
				PT_CLASSIDS.PT_GADGET_ID);
			myNewSelector.AddControlArgument(StartTreeControl.QUERY_FILTER,
				PT_CLASSIDS.PT_GADGET_ID + "," +
				PT_PROPIDS.PT_PROPID_GADGET_ALIGNMENT + "," +
				PT_GADGET_ALIGNMENTS.PT_GADGETALIGN_FREEFORM);
			myNewSelector.AddControlArgument(StartTreeControl.COMMUNITY_MODE,
				AObjectTreeModel.THISCOMMUNITY);
			myNewSelector.AddControlArgument(StartTreeControl.COMMUNITY_FOLDER_ID,
				((IPageLayoutModelRO) m_model).GetFolderID());
			myNewSelector.AddControlArgument(StartTreeControl.TITLE,
				m_asOwner.GetString(40, "ptmsgs_portalcommonmsgs"));
			myNewSelector.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,
				m_asOwner.GetString(41, "ptmsgs_portalcommonmsgs"));

			// The url to open a previously opened server user tree
			// This needs to have the SpaceID added to it.
			myOldSelector = new ASURL(m_asOwner);
			myOldSelector.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, m_asOwner);
			myOldSelector.IsSubSpace();

			try
			{
				// Select Free Form function
				sb = new XPStringBuilder(200);
				sb.Append("function ").Append(JAVASCRIPT_ADD_FREEFORM)
				.Append("(myInput)\n").Append("{\n")
				.Append("	if ( " + JAVASCRIPT_CHECK_LAYOUTTYPE + "() )\n")
				.Append("	{\n").Append("  	if (myInput.value == '') {\n")
				.Append("    		window.open('")
				.Append(myNewSelector.GetURLAsString())
				.Append("', 'FreeForm', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append(",scrollbars=yes');\n")
				.Append("  	} else {\n").Append("    		window.open('")
				.Append(myOldSelector.GetURLAsString()).Append("&")
				.Append(ASConstants.SPACEID).Append("=' + myInput.value")
				.Append(", 'FreeForm', '")
			.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append(",scrollbars=yes');\n")
				.Append("  	}\n").Append("	}\n").Append("}\n");

				script.AddInnerHTMLString(sb.ToString());

				// On return from Tree function
				sb = new XPStringBuilder(200);
				sb.Append("function ").Append(JAVASCRIPT_ONRETURN_ADD_FREEFORM).Append("()\n")
				.Append("{\n")
				.Append("		").Append(JAVASCRIPT_REPOST_LAYOUT).Append("();\n")
				.Append(" 		postToSelf('").Append(PageLayoutControl.POSTTOSELF_ACTION_ADDFREEFORM).Append("');\n")
				.Append("}\n");

				script.AddInnerHTMLString(sb.ToString());
				sb = new XPStringBuilder(200);

				sb.Append("function ").Append(JAVASCRIPT_CHECK_LAYOUTTYPE).Append("()\n")
				.Append("{\n")
				.Append("		if ( ").Append(PageTypeConstants.ONE_COLUMN_WITH_FREE_FORM_CONTENT)
				.Append(" > document.").Append(AFormDP.HTMLFORM_NAME).Append(".")
				.Append(HTMLINPUT_EDITPAGE_PAGELAYOUTTYPE).Append(".").Append("value )\n")
				.Append("		{\n")
				.Append("			alert('").Append(m_asOwner.GetString(49, "ptmsgs_portalcommonmsgs")).Append("');\n")
				.Append("			return false;\n")
				.Append("		}\n")
				.Append("		return true;\n")
				.Append("}\n");

				script.AddInnerHTMLString(sb.ToString());
			}
			catch (HTMLException he)
			{
				
					log.Error(he, "PageListView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
						he.getMessage());
				
			}
		}

		if (((IPageLayoutModelRO) m_model).GetCanCreatePortlet())
		{
			ASURL myASURL = new ASURL(m_asOwner);
			myASURL.SetLinkCreateNewSpace(PortMainPortletEditorAS.STR_MVC_CLASS_NAME,
				m_asOwner);
			myASURL.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
			myASURL.AddControlArgument(EditorStartControl.QS_EDITOR_TYPE,
				EditorStartControl.EDITOR_START_FLAG_CREATE);
			myASURL.SetSubSpaceKey(SUBSPACE_NAME_CREATEPORTLET);
			myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_QS_FOLDER_ID,
				((IPageLayoutModelRO) m_model).GetFolderID());
			myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_BOL_QS_FORCESAVEINFOLDER,
				true);
			myASURL.AddControlArgument(ObjEditorModel.EDITOR_QS_INT_CLASS_ID,
				XPConvert.ToString(PT_CLASSIDS.PT_GADGET_ID));
			myASURL.AddControlArgument(PTPortlets.PORTLET_EDITOR_QS_BOOL_FOR_COMMUNITY, 1);
			if ( ((IPageLayoutModelRO) m_model).GetCanChooseFreeForm() ) {
				myASURL.AddControlArgument(PortletModel.QS_SHOWFREEFORM, 1);
			}

			sb = new XPStringBuilder(400);
			sb.Append("function createPortlet()\n").Append("{\n")
			.Append("		").Append(JAVASCRIPT_REPOST_LAYOUT).Append("();\n").Append("		window.open('")
			.Append(myASURL.GetURLAsString())
			.Append("', 'PopUpCreateMode', 'location=no,menubar=no,resizable=yes,scrollbars=yes,height=600,width=800');\n")
			.Append("}\n");

			script.AddInnerHTMLString(sb.ToString());
		}

		try
		{
			// On delete function
			sb = new XPStringBuilder(200);
			sb.Append("function ").Append(JAVASCRIPT_DELETE_GADGET).Append("(gadgetID)\n")
			.Append("{\n")
			.Append("		").Append(JAVASCRIPT_REPOST_LAYOUT).Append("();\n")
			.Append("		document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_DELETE_GADGETID).Append(".value = gadgetID;\n")
			.Append(" 		postToSelf('").Append(PageLayoutControl.POSTTOSELF_ACTION_DELETEPORTLET).Append("');\n")
			.Append("}\n");

			script.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "PageListView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return script;
	}

}

