package com.plumtree.portalpages.common.editpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This Model contains the state of the page name plug-in section.
 *
 * @author MichaelD
 */

// ***CHANGE_HERE*** Change the name of the class.
// ***COMMENT_1*** Delete the comments prefixed by CHANGE_HERE and COMMENT
// when you are done.
public class PageNamePlugInModel extends EditorHelperModel
	implements IPageNameModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.editpage.PageNamePlugInModel");

	
	public static final String STR_MVC_CLASS_NAME = "PageNamePlugIn";

	/** Name Label */
	private String m_strNameLabel = "";

	/** Page Name */
	private String m_strPageName = "";

	/** Opener Object ID : Only used by page template editor. */
	private int m_nOpenerObjectID;
	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PageNamePlugInModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.editpage.IPageNameModelRO#GetNameLabel()
	 */
	public String GetNameLabel()
	{
		return m_strNameLabel;
	}

	// BEGIN ***************** helper methods ***************** 

	/**
	 * @see com.plumtree.portalpages.common.editpage.IPageNameModelRO#GetOpenerObjectID()
	 */
	public int GetOpenerObjectID()
	{
		return m_nOpenerObjectID;
	}

	/**
	 * Returns the value of the page name.
	 *
	 * @return String strPageName
	 */
	public String GetPageName()
	{
		return (m_strPageName);
	}

	// END ***************** helper methods ***************** 

	/**
	 * To initialize this plug-in you need to set the DP name
	 * and the default value of the plug-in setting.
	 *
	 * @param _dpName This is the name of the DP that will display SamplePlugInView.
	 * @param String _strPageName
	 */
	public void InitializePlugIn(String _strPageName, String _strNameLabel,
		int _nOpenerObjectID)
	{
		m_strPageName		  = _strPageName;
		m_strNameLabel		  = _strNameLabel;
		m_nOpenerObjectID     = _nOpenerObjectID;
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 * @return int Status for server side validation
	 */
	public int SaveSection(XPHashtable _htFormData)
	{
		String[] data;
		data = (String[]) _htFormData.GetElement(PageNameView.HTMLINPUT_EDITPAGE_PAGENAME);

		// Set page name
		if ((null != data) && !(0 == data.length))
		{
			if (IsValidPageName(data[0]))
			{
				SetPageName(data[0]);
			}
			else
			{
				UIError myError = new UIError(UIErrorLevel.FRIENDLY,
											UIErrorScope.CURRENT_USER,
											m_asOwner.GetString(527, "ptmsgs_portalcommonmsgs"),
											m_asOwner.GetString(528, "ptmsgs_portalcommonmsgs"));

				UIErrorHandler.RaiseError(myError,
					m_asOwner.GetSubSession(), m_asOwner.GetApplication());

				return RepostControl.PAGE_STATUS_INVALID;
			}
		}
		else
		{
			
				log.Warn("PageNamePlugInModel::SaveSection page name parameter was not in Query String.");
			
		}

		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * Method IsValidPageName.
	 * Checks to see if the page name is valid.
	 * @param _strPageName
	 * @return boolean
	 */
	public boolean IsValidPageName(String _strPageName)
	{
		if ( ("").equals(_strPageName) )
		{
			return false;
		}

		for (int i = 0; i < _strPageName.length(); ++i)
		{
			if ( !(XPConvert.ToString(_strPageName.charAt(i))).equals(" ") )// && (_strPageName.charCodeAt(i) == 9))
			{
			  	return true;
			}
		}
		
		return false;
	}

	/**
	 * Sets the value of the page name.
	 *
	 * @param String _strPageName
	 */
	public void SetPageName(String _strPageName)
	{
		m_strPageName = _strPageName;

		
			log.Debug("PageNamePlugInModel::SetPageName New page name value: " +
				_strPageName);
		
	}
}

