package com.plumtree.portalpages.common.editpage;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public class PageNameView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.editpage.PageNameView");

	/** Object Name */
	public static final String STR_MVC_CLASS_NAME = "PageName";

	/** Form Input: Page Name */
	public static final String HTMLINPUT_EDITPAGE_PAGENAME = "in_tx_PageName";
	
	/** Javascript Function: Validate Page Name */
	public static final String JS_VALIDATE_PAGENAME_FUNC = "validatePageName";
	
	/** Size of Page Name field */
	public static final int N_PAGE_NAME_INPUT_SIZE = 50;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PageNameView();
	}

	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;

		try
		{
			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						50, "ptmsgs_portalcommonmsgs")));
			//result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());

			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetBorder(CommonHTMLStrings.ZERO);
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

			// 2nd row begins
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);

			myInput = new HTMLInput(HTMLInputTypes.TEXT,
					HTMLINPUT_EDITPAGE_PAGENAME,
					((IPageNameModelRO) m_model).GetNameLabel());
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetValue(((IPageNameModelRO) m_model).GetPageName());
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
			myInput.SetMaxLength(PT_SERVERCONSTANTS.PT_MAX_NAMELENGTH);
			myInput.SetSize(N_PAGE_NAME_INPUT_SIZE);
			if(AccessStyles.STANDARD == m_asOwner.GetAccessStyle())
			{
				myInput.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");
			}

			// 2nd row ends
			log.Info("PageNameView::Display: Succesful");
		}
		catch (Exception e)
		{
			log.Error(e, "PageNameView::Display: The following error occured when trying to display the HTML: " +
				e.getMessage());
		}

		return result;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScriptCollection DisplayJavascriptCollection()
	{
		HTMLScriptCollection myScriptCollection = new HTMLScriptCollection();
		
		try
		{
			HTMLScript myScript = super.DisplayJavascript();
			if ( null != myScript )
			{
				myScriptCollection.AddInnerHTMLElement(myScript);
			}
			
			myScript = PlumtreeHelpers.GetExecuteViaEnterJScript(PageLayoutHeaderView.JAVASCRIPT_REPOST_LAYOUT);
			myScriptCollection.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException he)
		{
			log.Error(he, "PageNameView::DisplayJavascript: The following error occured when trying to display the javascript: " +
				he.getMessage());
		}
		String strJSUtilVersionPrefix = ConfigHelper.GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSUTIL);
		
		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("\n").Append
			("function ").Append(JS_VALIDATE_PAGENAME_FUNC).Append("()\n").Append
			("{\n").Append
			("	if (document." + AFormDP.HTMLFORM_NAME + "." + HTMLINPUT_EDITPAGE_PAGENAME + ")\n").Append
			("		if ("+strJSUtilVersionPrefix+"PTStringUtil.isAllWhitespace(document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(HTMLINPUT_EDITPAGE_PAGENAME).Append(".value))\n").Append
			("		{\n").Append
			("			alert(\"").Append(m_asOwner.GetString(529, "ptmsgs_portalcommonmsgs")).Append("\");\n").Append
			("			return false;\n").Append
			("		}\n").Append
			("	return true;\n").Append
			("}\n");

		try
		{
			HTMLScript myScript = super.DisplayJavascript();
			if ( null != myScript )
			{
				myScriptCollection.AddInnerHTMLElement(myScript);
			}
			
			myScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
			myScript.AddInnerHTMLString(sb.ToString());
			myScriptCollection.AddInnerHTMLElement(myScript);
		}
		catch (HTMLException he)
		{
			log.Error(he, "PageNameView::DisplayJavascript: The following error occured when trying to display the javascript: " +
				he.getMessage());
		}
		
		return myScriptCollection;
	}

}

