package com.plumtree.portalpages.common.error;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.portalpagesperf.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Core error display page
 * 
 * @author BenG
 */
public class ErrorDP extends PlumtreeDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.error.ErrorDP");

	
	public static final String STR_MVC_CLASS_NAME = "ErrorDP";

	/** for performance */
	private static final String EMPTY_STRING = "";

	
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetSubtitleForBanner()
	 */
	public String GetSubtitleForBanner()
	{
		return EMPTY_STRING;
	}

	/**
	 * @see com.plumtree.portalpages.common.uiparts.PlumtreeDP#GetTitleForBanner()
	 */
	public String GetTitleForBanner()
	{
		return m_asOwner.GetString(51, "ptmsgs_portalcommonmsgs");
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AFormDP#PageDisplay()
	 */
	public HTMLElement PageDisplay()
	{
		HTMLElementCollection myCollection = new HTMLElementCollection();
		
		// Increment the performance counters for errors	
		PerfCounters.INSTANCE.IncrementCounter( PORTALPAGESPERF_COUNTERS.PORTALPAGESPERF_ERRORS );

		try
		{
			HTMLElement element = DisplayLayout(Layouts.ERROR_PAGE);
			if (null != element) {
					return element;
			}
				
			myCollection.AddInnerHTMLElement(m_asOwner.GetView(SinglePageErrorView.STR_MVC_CLASS_NAME).Display());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Unable to display error view.");
			
		}

		return myCollection;
	}

	protected HTMLElement DisplayLayout(Layouts layout)
	{
		// Override the base version of this method so that we can add
		// additional error handling.
		try
		{
			return super.DisplayLayout(layout);
		} catch (Exception e)
		{
			log.Error(e, "Unable to display error page using layout.  Trying standard error page.");
			return null;
		}
	}
}