package com.plumtree.portalpages.common.folder;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author RupaP
 *
 */
public class FolderView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.folder.FolderView");


	/** name of this object */
	public static final String STR_MVC_CLASS_NAME = "FolderView";

	/** For SiteMap Folder */
	public boolean m_bShowNoFolderMessage = true;
	protected AActivitySpace m_asOwner;

	/** Client-specific variables */
	protected IFolderModelRO m_asModel;
	protected IFolderViewHelper m_folderViewHelper;
	

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new FolderView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection myGroup = new HTMLElementCollection();
		HTMLElement result			  = myGroup;
		HTMLBr br					  = new HTMLBr();

		//Get the current folder's level in the hierachy
		int nLevel = m_asModel.GetCurrentFolderLevel();

		//Determine how many subfolders are one level deeper than the current folder
		int nSubFolderCount = m_asModel.GetSubFolderCount(nLevel + 1);

		try
		{
			if (m_asModel.GetShowFolderBanner())
			{
				DisplayBanner(myGroup);
				myGroup.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
			}

			// no subfolders to display
			if (nSubFolderCount <= 0)
			{
				HTMLSpan mySpan = new HTMLSpan();

				if (m_bShowNoFolderMessage)
				{
					mySpan.AddInnerHTMLElement(new HTMLBr());
					mySpan.AddInnerHTMLString(m_asOwner.GetString(53,
							"ptmsgs_portalcommonmsgs"));
				}
				else
				{
					mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
				}

				mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

				myGroup.AddInnerHTMLElement(mySpan);
				myGroup.AddInnerHTMLElement(br);
			}
			else
			{
				//Get the number of folders at all levels in the hierachy
				int nTotalFolderCount = m_asModel.GetSubFolderCount();
				
				if (0 >= nTotalFolderCount)
				{
					HTMLSpan mySpan = new HTMLSpan();

					if (m_bShowNoFolderMessage)
					{
						mySpan.AddInnerHTMLString(m_asOwner.GetString(531, "ptmsgs_portalcommonmsgs"));
					}
					else
					{
						mySpan.AddInnerHTMLString(CommonHTMLStrings.SPACE);
					}

					mySpan.SetStyleClass(PTStyleClass.OBJECT_TEXT);

					myGroup.AddInnerHTMLElement(mySpan);
					myGroup.AddInnerHTMLElement(br);
				}
				else
				{
					//Write the table of folders
					HTMLTable folderTable = new HTMLTable();
					folderTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
	
					// folderTable.SetStyleClass(PTStyleClass.OBJECT_DIRECTORY_TEXT);
					HTMLTableRow row;
					HTMLTableCell cell;
	
					int nNumCols = m_asModel.GetFolderColumnCount();
	
					//Figure out how many folders to show in each column
					int nRowCount = nSubFolderCount / nNumCols;
	
					if ((nSubFolderCount % nNumCols) != 0)
					{
						nRowCount++;
					}
	
					// keep track of the index we're at in the query result
					int nFolderIndexRef = 0;
					int nCount		    = 0;
					int nWidth		    = 100 / nNumCols;
	
					// write out folders
					for (int j = 0; j < nRowCount; j++)
					{
						row = new HTMLTableRow();
						folderTable.AddInnerHTMLElement(row);
						row.SetVAlign(CommonHTMLStrings.TOP);
	
						for (int i = 0; i < nNumCols; i++)
						{
							cell = new HTMLTableCell();
							row.AddInnerHTMLElement(cell);
	
							cell.SetVAlign(CommonHTMLStrings.TOP);
							cell.SetWidth(nWidth + "%");
	
							// print the folder, unless we're at the end or are invalid, and then just leave an empty cell
							// The folderview needs to check this so each view helper doesn't need to.
							if ((nCount < nSubFolderCount) &&
									(nFolderIndexRef >= 0) &&
									(nFolderIndexRef < nTotalFolderCount))
							{
								//Display one folder and advance the index reference to the next folder to display
								nFolderIndexRef = m_folderViewHelper.DisplayFolder(nFolderIndexRef,
										cell, m_asModel, m_asOwner);
								nCount++;
							}
						}
					}
	
					// display the folders
					myGroup.AddInnerHTMLElement(folderTable);
				}
			}
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "Error creating folder table.");
			
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	// Logger

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asModel     = (IFolderModelRO) model;
		m_asOwner     = parent;

		m_folderViewHelper = m_asModel.GetFolderViewHelper();
	}

	/**
	 *
	 * @param _bShowMessage
	 */
	public void SetShowNoFolderMessage(boolean _bShowMessage)
	{
		m_bShowNoFolderMessage = _bShowMessage;
	}

	/**
	 * **Override this method in a subclass if you need to do one of the following: **
	 *         - Display a different banner type
	 *         - Add custom buttons
	 *
	 * @param group     the folder view element collection
	 */
	protected void DisplayBanner(HTMLElementCollection group)
	{
		try
		{
			PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTBannerType.FOLDER,
					true, this.m_asOwner);

			ElementName eName = PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_TITLE);

			myConstruct.ReplaceNestedElementsWithHTMLString(eName,
				XPResourceManager.FormatMessage(m_asOwner.GetString(54,
						"ptmsgs_portalcommonmsgs"),
					"\"" +
					XPHttpUtility.HtmlEncode(m_asModel.GetCurrentFolderName()) +
					"\""));

			if (PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER != m_asModel.GetCurrentFolderID())
			{
				PTConstruct myButtonConstruct = UIConstructFactory.GetConstruct( PTButtonType.GO_UP, true, this.m_asOwner );
				HTMLAnchor myAnchor = (HTMLAnchor) myButtonConstruct.GetNestedElement( PTButtonType.GO_UP.GetElementName(
					PTButtonType.ELEMENT_NAME_ID_ANCHOR) );
				this.m_folderViewHelper.SetupAnchorToOpenFolder(myAnchor, m_asModel.GetParentFolderID(), this.m_asModel, this.m_asOwner);
				myButtonConstruct.ReplaceNestedElementsWithHTMLString( PTButtonType.GO_UP.GetElementName(PTButtonType.ELEMENT_NAME_ID_TITLE), 
					m_asOwner.GetString(1631, "ptmsgs_portalbrowsingmsgs") );
				myAnchor.SetTitle(m_asOwner.GetString(1631, "ptmsgs_portalbrowsingmsgs"));
				ConstructFactory.SetAltOnButtonImages(myButtonConstruct, m_asOwner.GetString(1631, "ptmsgs_portalbrowsingmsgs"));
				ConstructFactory.SetTitleOnButtonImages(myButtonConstruct, m_asOwner.GetString(1631, "ptmsgs_portalbrowsingmsgs"));
							
				myConstruct.AddElementToNestedElement( 
					PTBannerType.FOLDER.GetElementName(PTBannerType.ELEMENT_NAME_ID_EXTENDABLE_CELL), 
					myButtonConstruct.GetHTMLElement() );
			}
					
			group.AddInnerHTMLElement(myConstruct.GetHTMLElement());
		}
		catch (Exception e)
		{
			
				log.Error(e, "Error displaying banner.");
			
		}
	}
}

