package com.plumtree.portalpages.common.folder;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author RupaP
 * DisplayFolder writes out one folder to the given table cell and
 * returns a reference to the next folder in the query result to
 * display.
 *
 * In this implementation, folders of all levels will be displayed.
 * The reference is incremented by 1 until the last folder in the
 * query result has been displayed.
 */
public class FolderViewHelper implements IFolderViewHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.folder.FolderViewHelper");

	// Query parameter name for the checkbox

	
	public static final String QS_CHECKBOX = "in_cb_checkbox";
	private String m_strControlName = null;

	/**
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#DisplayObject(int, HTMLTableCell, IFolderModelRO)
	 */
	public int DisplayFolder(int nFolderQueryIndex, HTMLTableCell tableCell,
		IFolderModelRO model, AActivitySpace space)
	{
		try
		{
			// get the folder query
			IASQueryResult qrFolders = model.GetFolderQueryResult();
			int nIndex				 = nFolderQueryIndex;

			// get name, folder ID, and folder URL from query
			String strName     = (String) qrFolders.GetFields(nIndex,
					PT_PROPIDS.PT_PROPID_NAME);
			int nFolderID	   = XPConvert.ToInteger(qrFolders.GetFields(nIndex,
					PT_PROPIDS.PT_PROPID_OBJECTID));
			String strFolderID = XPConvert.ToString(nFolderID);

			// Open folder URL
			ASURL url = new ASURL(space);
			url.SetLinkGetCachedSpace(space);

			if (null == m_strControlName)
			{
				url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
			}
			else
			{
				url.SetControl(m_strControlName);
			}

			url.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
				strFolderID);

			String strURL = url.GetURLAsString();

			// use list item construct
			UIListItem itemConstruct = new UIListItem(strName, strURL, space);
			itemConstruct.SetItemTypeImage(PTImageType.ICON_FOLDER_OPEN,
				"folder");
			itemConstruct.SetRowStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);

			// check if there's a checkbox item
			if (model.GetShowCheckbox())
			{
				itemConstruct.EnableCheckbox(QS_CHECKBOX + strFolderID, strURL,
					strFolderID, model.GetIsFolderSelected(nFolderID)); //to do: specify value
			}

			// convert the construct to table
			try
			{
				HTMLTable folderTable = itemConstruct.GetItemAsTable();
				tableCell.AddInnerHTMLElement(folderTable);
			}
			catch (Exception e)
			{
						
					log.Error(e, "Error in FolderViewHelper::Display: ");
				
			}

			nFolderQueryIndex++;
		}
		catch (Exception e)
		{
			log.Error("Couldn't retrieve folder at " + nFolderQueryIndex);
		}

		return nFolderQueryIndex;
	}

	/**
	 * 
	 *
	 * @param strControlName 
	 */
	public void SetControlName(String strControlName)
	{
		m_strControlName = strControlName;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portalpages.common.folder.IFolderViewHelper#SetupAnchorToOpenFolder(com.plumtree.xpshared.htmlelements.HTMLAnchor, int)
	 */
	public void SetupAnchorToOpenFolder(HTMLAnchor _anchor, int _nFolderID, IFolderModelRO _model, AActivitySpace _space)
	{
		ASURL url = new ASURL(_space);
		url.SetLinkGetCachedSpace(_space);

		if (null == m_strControlName)
		{
			url.SetControl(OpenSubFolderControl.STR_MVC_CLASS_NAME);
		}
		else
		{
			url.SetControl(m_strControlName);
		}

		url.AddControlArgument(OpenSubFolderControl.m_SubFolderID,
			_nFolderID);

		_anchor.SetHRef(url.GetURLAsString());
	}

}

