package com.plumtree.portalpages.common.folder;

import com.plumtree.portaluiinfrastructure.resultwrapper.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author Don Hayler, RupaP
 *
 */
public interface IFolderModelRO extends IModelRO
{
	/**
	 * Get the id of the current folder.
	 */
	public int GetCurrentFolderID();

	/**
	 * Get the level of the current folder
	 */
	public int GetCurrentFolderLevel();

	/**
	 * Get the name of the current folder.
	 */
	public String GetCurrentFolderName();

	/**
	 * Get the index of the first folder to display.
	 */
	public int GetFirstFolderIndex();

	/**
	 * Get the number of columns to display.
	 */
	public int GetFolderColumnCount();

	/**
	 * Get a list of object names and the number of those objects in the current
	 * folder.  The list will have PT_PROPID_CLASSID ("filter 32") and
	 * PT_PROPID_OBJECTCOUNT (12).
	 */
	public IASQueryResult GetFolderObjectCount();

	/**
	 * Get an IPTQueryResult containing all of the subfolders of the current folder.
	 */
	public IASQueryResult GetFolderQueryResult();

	/**
	 * Retrieves the folder view helper. This contains a method to implement
	 * display for one folder.
	 *
	 * FolderViewHelper is the implementation for general use, but you may need
	 * to implement your own helper.
	 */
	public IFolderViewHelper GetFolderViewHelper();

	/**
	 * This method returns whether or not the requested folder is
	 * currently selected.
	 *
	 * @return boolean true implies selected, false implies not selected
	 */
	public boolean GetIsFolderSelected(int nFolderID);

	/**
	 * Get the index of the first folder to display.
	 */
	public int GetLastFolderIndex();

	/**
	 * Set the number of sub-subfolders to display after the next page..
	 */
	public int GetNumSubSubFoldersToDisplay();

	/**
	 * Get the ID of the parent folder of the current folder.
	 */
	public int GetParentFolderID();

	/**
	 * Get an Object array containing the Integer IDs of all the parent folders
	 * (the path) of the current folder.
	 *
	 * Each element in the array must be cast to an Integer.
	 *
	 * This will return one ID per folder in the path, except for the root folder,
	 * where two IDs will be returned even though there is only one folder in the
	 * path.
	 */
	public Object[] GetParentFolderIDs();

	/**
	 * Get the path to the current folder concatenated with '\'.
	 */
	public String GetPath();

	/**
	 * Returns whether the folders should have checkboxes next to them.
	 */
	public boolean GetShowCheckbox();

	/**
	 * Returns whether the subfolder banner should be shown.
	 */
	public boolean GetShowFolderBanner();

	/**
	 * Get the number of sub folders in the current folder at the
	 * specified level.
	 */
	public int GetSubFolderCount(int nFolderLevel);

	/**
	 * Get the number of folders at all levels in the hierachy
	 */
	public int GetSubFolderCount();

	/**
	 * Returns true if the current folder is the root folder.
	 */
	public boolean InRootFolder();
}

