package com.plumtree.portalpages.common.helpers;

import com.plumtree.openfoundation.util.*;

/**
 * @author OlegS
 */
public class PropertyValue
{
	
	public static final int SRC_SERVER = 0;

	
	public static final int SRC_FORM = 1;

	
	public static final int UNKNOWN = 0;

	
	public static final int STRING = 1;

	
	public static final int INTEGER = 2;

	
	public static final int DATETIME = 3;

	
	public Object m_value = null;
	protected String m_help;
	protected String m_name;
	protected Object[] m_id = null;
	protected PropertyValidator[] m_validator;
	protected int m_srcServerIndex;

	/**
	 * Creates a new PropertyValue object.
	 *
	 * @param list 
	 * @param name 
	 * @param help 
	 * @param id 
	 * @param qryname 
	 * @param vld 
	 */
	public PropertyValue(XPArrayList list, String name, String help, int id, String qryname, PropertyValidator[] vld)
	{
		this(list, name, help, 0, id, qryname, vld);
	}

	/**
	 * Creates a new PropertyValue object.
	 *
	 * @param list 
	 * @param name 
	 * @param help 
	 * @param id 
	 * @param qryname 
	 * @param vld 
	 */
	public PropertyValue(XPArrayList list, String name, String help, Object id, String qryname, PropertyValidator[] vld)
	{
		this(list, name, help, 0, id, qryname, vld);
	}

	/**
	 * Creates a new PropertyValue object.
	 *
	 * @param list 
	 * @param name 
	 * @param help 
	 * @param srcServerIndex 
	 * @param id 
	 * @param qryname 
	 * @param vld 
	 */
	public PropertyValue(XPArrayList list, String name, String help, int srcServerIndex, int id, String qryname, PropertyValidator[] vld)
	{
		// NOTE: We can't just call
		//  this(.., new Integer(id), ..)
		// because in C# there is no distinction between int and Integer,
		// and the jump tool will simply comment out the call.
		// Instead we must duplicate the constructor here.
		list.Add(this);
		m_name				 = name;
		m_help				 = help;
		m_srcServerIndex     = srcServerIndex;
		m_id				 = new Object[2];
		m_id[SRC_SERVER]     = new Integer(id);
		m_id[SRC_FORM]		 = qryname;
		m_validator			 = vld;
	}

	/**
	 * Creates a new PropertyValue object.
	 *
	 * @param list 
	 * @param name 
	 * @param help 
	 * @param srcServerIndex 
	 * @param id 
	 * @param qryname 
	 * @param vld 
	 */
	public PropertyValue(XPArrayList list, String name, String help, int srcServerIndex, Object id, String qryname, PropertyValidator[] vld)
	{
		list.Add(this);
		m_name				 = name;
		m_help				 = help;
		m_srcServerIndex     = srcServerIndex;
		m_id				 = new Object[2];
		m_id[SRC_SERVER]     = id;
		m_id[SRC_FORM]		 = qryname;
		m_validator			 = vld;
	}

	/**
	 * Creates a new PropertyValue object skipping the id array. Called from DateTimePropertyValue constructor
	 *
	 * @param list 
	 * @param name 
	 * @param help 
	 * @param srcServerIndex 
	 * @param vld 
	 */
	protected PropertyValue(XPArrayList list, String name, String help, int srcServerIndex, PropertyValidator[] vld)
	{
		list.Add(this);
		m_name				 = name;
		m_help				 = help;
		m_srcServerIndex     = srcServerIndex;
		m_validator			 = vld;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean isMandatory()
	{
		for (int i = 0; (m_validator != null) && (i < m_validator.length);
				i++)
		{
			if (m_validator[i] instanceof MandatoryProperty)
			{
				return true;
			}
		}

		return false;
	}

	/**
	 * 
	 *
	 * @param val 
	 */
	public void SetValue(Object val)
	{
		m_value = val;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean changeTypeToDate()
	{
		boolean ok = false;

		if (m_value != null)
		{
			if (m_value instanceof String)
			{
				if (!ok)
				{
					try
					{
						XPDateTime xpdt = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT, XPDateFormat.SHORT).Parse((String) m_value);
						m_value     = xpdt;
						ok		    = true;
					}
					catch (Exception e)
					{
					}
				}

				if (!ok)
				{
					try
					{
						XPDateTime xpdt = XPDateFormat.GetDateTimeInstance(XPDateFormat.MEDIUM, XPDateFormat.SHORT).Parse((String) m_value);
						m_value     = xpdt;
						ok		    = true;
					}
					catch (Exception e)
					{
					}
				}

				if (!ok)
				{
					try
					{
						XPDateTime xpdt = XPDateFormat.GetDateTimeInstance(XPDateFormat.LONG, XPDateFormat.SHORT).Parse((String) m_value);
						m_value     = xpdt;
						ok		    = true;
					}
					catch (Exception e)
					{
					}
				}
			}
		}

		return ok;
	}

	/**
	 * 
	 */
	public void changeTypeToInteger()
	{
		if (m_value != null)
		{
			if (m_value instanceof String)
			{
				try
				{
				    String val = (String) m_value;
					m_value = new Integer(XPConvert.ToInteger(val.trim()));
				}
				catch (Exception e)
				{
				}
			}
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String controlName()
	{
		return (String) m_id[SRC_FORM];
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public XPDateTime date()
	{
		XPDateTime result = null;

		if (m_value instanceof XPDateTime)
		{
			result = (XPDateTime) m_value;
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean empty()
	{
		return ((m_value == null) || (m_value.toString().length() == 0));
	}

	/**
	 * 
	 *
	 * @param src 
	 * @param srctype 
	 *
	 * @return 
	 */
	public boolean Get(PropertySource src, int srctype)
	{
		boolean modified = false;

		if ((srctype == SRC_FORM) && (((String) m_id[srctype]).indexOf(',') >= 0))
		{
			// special case - multiple controls for single property (e.g. date and time)
			Object m_oldvalue = m_value;
			m_value = null;

			String ids = (String) m_id[srctype];

			for (XPStringTokenizer i = new XPStringTokenizer(ids, ", ");
					i.HasMoreTokens();)
			{
				String id = i.GetNextToken();

				if (id != null)
				{
					Object o = src.Get(id);

					if ((o != null) && (o.toString().length() > 0))
					{
						if (m_value == null)
						{
							m_value = o.toString();
						}
						else
						{
							m_value = m_value + " " + o.toString();
						}
					}
				}
			}

			modified |= ((m_oldvalue == null) || !m_oldvalue.equals(m_value));
		}
		else
		{
			if (m_id[srctype] != null)
			{
				Object val = src.Get(m_id[srctype]);

				if ((val != null) || (srctype != SRC_FORM))
				{
					modified |= ((m_value == null) || !m_value.equals(val));
					m_value = val;
				}

				// else the value was not in query string - leave unchanged
			}
		}

		return modified;
	}

	/**
	 * 
	 *
	 * @param srcArray 
	 * @param srctype 
	 *
	 * @return 
	 */
	public boolean Get(PropertySource[] srcArray, int srctype)
	{
		return Get(srcArray[m_srcServerIndex], srctype);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String help()
	{
		return m_help;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Object idForm()
	{
		return m_id[SRC_FORM];
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Object idServer()
	{
		return m_id[SRC_SERVER];
	}

	/**
	 * 
	 *
	 * @param c 
	 *
	 * @return 
	 */
	public boolean isClass(Class c)
	{
		return (m_value != null) && m_value.getClass().equals(c);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String name()
	{
		return m_name;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int number()
	{
		int result = 0;

		if (m_value instanceof Integer)
		{
			result = XPConvert.ToInteger(m_value);
		}

		return result;
	}

	/**
	 * 
	 *
	 * @param src 
	 * @param srctype 
	 */
	public void Set(PropertySource src, int srctype)
	{
		if (m_id[srctype] != null)
		{
			src.Set(m_id[srctype], m_value);
		}
	}

	/**
	 * 
	 *
	 * @param srcArray 
	 * @param srctype 
	 */
	public void Set(PropertySource[] srcArray, int srctype)
	{
		Set(srcArray[m_srcServerIndex], srctype);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String text()
	{
		String result = null;

		if (m_value instanceof XPDateTime)
		{
			result = XPDateFormat.GetDateTimeInstance(XPDateFormat.SHORT, XPDateFormat.SHORT).Format(date());
		}
		else
		{
			result = XPConvert.ToString(m_value);
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String textDate()
	{
		String result = null;

		if (m_value instanceof XPDateTime)
		{
			result = XPDateFormat.GetDateInstance(XPDateFormat.SHORT).Format(date());
		}
		else if (m_value instanceof String)
		{
			result = text();
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String textTime()
	{
		String result = null;

		if (m_value instanceof XPDateTime)
		{
			result = XPDateFormat.GetTimeInstance(XPDateFormat.SHORT).Format(date());
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean validate()
	{
		int result = PropertyValidator.VALIDSOFAR;

		for (int i = 0;
				(m_validator != null) && (i < m_validator.length) && (result == PropertyValidator.VALIDSOFAR);
				i++)
		{
			result = m_validator[i].validate(this);
		}

		return (result != PropertyValidator.INVALID);
	}
}

