package com.plumtree.portalpages.common.helpers;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author OlegS
 * see usage example at the end
 */
public class TreeHelper
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.helpers.TreeHelper");

	
	/**
	 * Returns an XPArrayList of selected items from the tree
	 *
	 * @param asOwner Parent of the Activity space
	 * @param subspace The subspace for the tree
	 *
	 * @return XPArrayList of selected items
	 */
	public static XPArrayList GetSelection(AActivitySpace asOwner,
		String subspace)
	{
		XPArrayList lst = new XPArrayList(10);

		if (asOwner.GetSubSpaceExists(subspace))
		{
			ATreeAS asFolderTree   = (ATreeAS) asOwner.GetSubSpace(subspace);
			ITreeModelRO myTree    = (ITreeModelRO) asFolderTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected = myTree.GetSelectedItems();

			for (int i = 0; i < mySelected.GetSize(); i++)
			{
				int id = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
				lst.Add(new Integer(id));
			}

			asOwner.DeleteSubSpace(subspace); // this is important 
		}

		return lst;
	}

	/**
	 * Constructs the anchor tag to be associated with the tree
	 *
	 * @param subspace The subspace name
	 * @param hi_spaceid The hidden subspace ID
	 * @param action The action to take
	 *
	 * @return Returns the HTMLAnchor element
	 */
	public static HTMLAnchor makeTreeAnchor(String subspace, String hi_spaceid,
		int action, String strLang)
	{
		HTMLAnchor myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
		XPStringBuilder sb  = new XPStringBuilder(200);

		try
		{
			sb.Append("open").Append(subspace).Append("(document.")
			.Append(AFormDP.HTMLFORM_NAME).Append(".").Append(hi_spaceid)
			.Append(",").Append(XPConvert.ToString(action)).Append("); return false;");
			myAnchor.SetOnClick(sb.ToString());
		}
		catch (Exception e)
		{
			
				log.Error(e, "TreeHelper::makeTreeAnchor The following error occured when trying to create the tree anchor.");
			

		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
			XPResourceManager rm     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
			throw new XPException(rm.GetString(603, "ptmsgs_portalcommonmsgs", strLang), e);
		}

		return myAnchor;
	}

	/**
	 * Constructs the URL used to open a new admin folder tree
	 *
	 * @param parent Parent activity space
	 * @param subspace Sub activity space
	 * @param hi_spaceid hidden space id field
	 * @param hi_repost hidden repost field
	 * @param title The title for the tree
	 * @param subtitle The subtitle for the tree
	 * @param classid The classid of the objects to be displayed
	 * @param rootfolder The root folder of the tree
	 * @param selectmode The select mode
	 * @param multiselect Multiselect - true or false
	 * @param showroot Show the root folder - true or false
	 * @param hideids IDs of elements to hide
	 * @param select IDs of element(s) to select
	 *
	 * @return The javascript string
	 */
	public static String makeTreeJavascript(AActivitySpace parent, String subspace,
		String hi_spaceid, String hi_repost, String title, String subtitle,
		int classid, int rootfolder, int selectmode, boolean multiselect,
		boolean showroot, String hideids, String select)
	{
		String strFormName = AFormDP.HTMLFORM_NAME;

		// The URL to open a new admin folder tree
		ASURL tree = new ASURL(parent);

		tree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, parent); // note: TreeAS is for admin only, not for catalog
		tree.SetSubSpaceKey(subspace);

		tree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		tree.AddControlArgument(StartTreeControl.TITLE, title);
		tree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE,subtitle);

		if (classid != PT_CLASSIDS.PT_ADMIN_FOLDER_ID)
		{
			tree.AddControlArgument(StartTreeControl.CLASS_IDS_TO_DISPLAY,
				XPConvert.ToString(classid));
		}

		tree.AddControlArgument(StartTreeControl.ROOT_ID,
			XPConvert.ToString(rootfolder));
		tree.AddControlArgument(StartTreeControl.SHOW_ROOT, showroot);
		tree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(multiselect));
		tree.AddControlArgument(StartTreeControl.SELECT_MODE,
			XPConvert.ToString(selectmode));
		tree.AddControlArgument(StartTreeControl.SUBMIT_MODE,
			XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		tree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, strFormName);
		tree.AddControlArgument(StartTreeControl.PARENT_FORM_SPACE_ID,
			hi_spaceid);
		tree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL,
			"submit" + subspace);
			
		if (select != null) 
		{
			tree.AddControlArgument(StartTreeControl.SELECTED_ITEMS,select);
		}

		if (hideids != null)
		{
			tree.AddControlArgument(StartTreeControl.HIDDEN_ITEMS, hideids, parent);
		}

		// Open tree function
		XPStringBuilder sb = new XPStringBuilder(200);
		sb.Append("function ").Append("open" + subspace)
		.Append("(spaceid,repostaction)\n").Append("{\n").Append("  document.")
		.Append(AFormDP.HTMLFORM_NAME).Append(".").Append(hi_repost)
		.Append(".value = repostaction;\n").Append("    window.open('")
		.Append(tree.GetURLAsString())
		.Append("', '_blank1', '")
		.Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n")
		.Append("}\n");

		// Submit function
		sb.Append("function submit" + subspace + "()\n").Append("{\n")
		.Append("  postToSelf(").Append("document.")
		.Append(AFormDP.HTMLFORM_NAME).Append(".").Append(hi_repost)
		.Append(".value").Append(");\n").Append("}\n");

		return sb.ToString();
	}
	
	public static String makeTreeJavascript(AActivitySpace parent, String subspace,
			String hi_spaceid, String hi_repost, String title, String subtitle,
			int classid, int rootfolder, int selectmode, boolean multiselect,
			boolean showroot, String hideids) {
		return makeTreeJavascript(parent,subspace,hi_spaceid,hi_repost,title,subtitle,classid,rootfolder,selectmode,multiselect,showroot,hideids,null);
	}
}


/* Usage example.

Two trees. One for user groups, another for admin folders.
The last one has multiple "inline" anchors.

public class MyView extends EditorView {

  public static final String ADMINFOLDERTREESPACE="FolderTree";
    public static final String USERGROUPTREESPACE="UserGroupTree";
    public static final String HTMLHIDDEN_TREEREPOST="in_hi_TreeRepostAction";
    public static final String HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE="in_hi_SpaceID_AF";
    public static final String HTMLHIDDEN_SPACEID_USERGROUPTREESPACE="in_hi_SpaceID_UG";

    public HTMLScript DisplayJavascript() {
        HTMLScript myScript=new HTMLScript("text/javaScript");
        try {
            myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(m_asOwner,ADMINFOLDERTREESPACE,HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,HTMLHIDDEN_TREEREPOST,_ui_ChangeFolder,_ui_Folder,PT_CLASSIDS.PT_ADMIN_FOLDER_ID,PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,ITreeModelRO.N_COMPOSITESELECT,false,true,null));
            myScript.AddInnerHTMLString(TreeHelper.makeTreeJavascript(m_asOwner,USERGROUPTREESPACE,HTMLHIDDEN_SPACEID_USERGROUPTREESPACE,HTMLHIDDEN_TREEREPOST,_ui_AddGroup,_ui_Group,PT_CLASSIDS.PT_USERGROUP_ID,PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER,ITreeModelRO.N_LEAFSELECT,true,false,model().makeListOfUnmappedGroups()));
        } catch(Exception e) {
            log.Error(e, "MyView.DisplayJavascript couldn't add javascript to the HTMLScript element: ");
            throw new XPException(_ui_DisplayHTMLError+" (Javascript)",e);
        }
        return myScript;
    }

    public HTMLElement Display()     {
      ...
      HTMLAnchor myAnchor=TreeHelper.makeTreeAnchor(ADMINFOLDERTREESPACE,HTMLHIDDEN_SPACEID_ADMINFOLDERTREESPACE,MyRepostControl.ACTION_CHANGE_FOLDER_FOR_SYNC_GROUP+id);
        myCell.AddInnerHTMLElement(myAnchor);
        HTMLImg myImg=TODO.getImage("folder.gif",_ui_Browse,"20","20"); // TODO: change to PTImageType.XXX when available
        myAnchor.AddInnerHTMLElement(myImg);
        myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myAnchor.AddInnerHTMLString(_ui_Browse);
    ...
        myAnchor=TreeHelper.makeTreeAnchor(USERGROUPTREESPACE,HTMLHIDDEN_SPACEID_USERGROUPTREESPACE,MyRepostControl.ACTION_ADD_SYNC_GROUP);
        myCell.AddInnerHTMLElement(myAnchor);
        myAnchor.AddInnerHTMLString(CommonHTMLStrings.SPACE);
        myImg=TODO.getImage("action_group_add.gif",_ui_AddGroup,"25","25"); // TODO: change to PTImageType.XXX when available
        myAnchor.AddInnerHTMLElement(myImg);
        mySpan=new HTMLSpan();
        myAnchor.AddInnerHTMLElement(mySpan);
        mySpan.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
        mySpan.AddInnerHTMLString(_ui_AddGroup+"&nbsp;&nbsp;");
        ...
    }
}

public class MyRepostControl extends ObjEditorRepostControl {

  protected void PerformAction(int _nAction) {
    switch(_nAction) {
    case ACTION_ADD_GROUP: {
            XPArrayList lst=TreeHelper.getSelection(m_asOwner,MyView.USERGROUPTREESPACE);
            for(IXPEnumerator i=lst.GetEnumerator(); i.MoveNext(); ) {
                int id=XPConvert.ToInteger(i.GetCurrent());
                getModel().onAddGroup(id);
            }
            break; }
        case ACTION_CHANGE_FOLDER: {
            XPArrayList lst=TreeHelper.getSelection(m_asOwner,MyView.ADMINFOLDERTREESPACE);
            if(!lst.IsEmpty()) {
                int id=XPConvert.ToInteger(lst.GetElement(0));
                getModel().onChangeFolder(id);
            }
            break; }
    }
  }

}

*/

