package com.plumtree.portalpages.common.joblogs;

import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class displays the HTML for the Job History action bar
 * 
 * @author JohnH
 */
public class HistoryView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.joblogs.HistoryView");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "JobHistoryView";

	/** Helper class that contains all of the implementations for getting the HTML */
	private HistoryViewHelper myViewHelper;

	/** JH- The read-only model associated with this view */
	private IJobLogModelRO m_model;
	
	/** Member variable for the parent activity space */
	private AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model = (IJobLogModelRO) model;
		m_asOwner = parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new HistoryView();
	}

	/**
	 * Displays the HTML for the view
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display HistoryView");
			result.AddInnerHTMLElement(myComment);

			result.AddInnerHTMLElement(myViewHelper.GetHeaderView(m_asOwner.GetString(
						85, "ptmsgs_portalcommonmsgs")));
			
			//Add the action bar
			result.AddInnerHTMLElement(myViewHelper.AddActionBar());

			//Add the job log detail
			result.AddInnerHTMLElement(myViewHelper.GetJobLogDetail());
			
			myComment = new HTMLComment( "End: Display HistoryView");
			result.AddInnerHTMLElement(myComment);
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Portlets"), "JobHistoryPortletView::DisplayPortlet", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(92, "ptmsgs_portalcommonmsgs"));
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");

		myViewHelper = new HistoryViewHelper((IModelRO) m_model, m_asOwner, false, AFormDP.JAVASCRIPT_SUBMIT_FORM);

		String newScript = myViewHelper.GetJavascript(AFormDP.HTMLFORM_NAME);

		myScript.AddInnerHTMLString(newScript);

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

}


