package com.plumtree.portalpages.common.joblogs;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;

/**
 * This read-only interface provides access to the member variables in the
 * JobLogModel class.  It is called by the views used to display the job
 * history and the job logs.
 *
 * @author JohnH
 */
public interface IJobLogModelRO
{
	/**
	 * Returns the log page currently being displayed.
	 * @return int
	 */
	public int GetCurrentLogPage();

	/**
	 * Returns CurrentPage setting.
	 *
	 * @return int
	 */
	public int GetCurrentPage();

	/**
	 * Returns the jobID.
	 *
	 * @return int
	 */
	public int GetJobID();

	/**
	 * Returns the jobName.
	 * @return String
	 */
	public String GetJobName();

	/**
	 * Returns the Plumtree Session object.
	 *
	 * @return IPTSession
	 */
	public IPTSession GetPTSession();

	/**
	 * Returns the job history row to display in the job log detail viewer.
	 *
	 * @return int
	 */
	public int GetRowToDisplay();

	/**
	 * Returns the runTime.
	 * @return String
	 */
	public String GetRunTime();

	/**
	 * Returns boolean indicating whether the last request was a log search.
	 *
	 * @return boolean
	 */
	public boolean IsSearchRequest();
	
	/**
	 * Returns the target string to be used for a log search.
	 *
	 * @return String
	 */
	public String GetSearchString();
	
	/**
	 * Returns the log file in byte array format
	 * 
	 * @return byte[]
	 */
	public byte[] GetLogFile();
	
	/**
	 * Get the Date picker control manager
	 *
	 * @return JSDatePickerMgr
	 */
	public JSDatePickerMgr GetDatePickerControlManager();
}

