package com.plumtree.portalpages.common.joblogs;


//Server imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * JobLogDisplayView creates the HTML for the "popup" for viewing job logs.
 *
 * @version 1.0
 * @author JohnH
 */
public class JobLogDisplayView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.joblogs.JobLogDisplayView");

	/** JH- The name of this object */
	public static final String STR_MVC_CLASS_NAME = "JobLogDisplayView";

	/** JH- The read-only model associated with this view */
	private IJobLogModelRO m_model;
	
	/** Member variable for the parent activity space */
	private AActivitySpace m_asOwner;

	/** JH- The names of various HTML elements, such as inputs */
	public static final String HTMLBUTTON_CLOSE		  = "in_bu_Close";

	/** Hidden element for the current page */
	public static final String HTMLHIDDEN_CURRENTPAGE = "in_hi_CurrentPage";

	/** Hidden element for the last page */
	public static final String HTMLHIDDEN_LASTPAGE = "in_hi_LastPage";

	/** Hidden element for the Jump To page value */
	public static final String HTMLHIDDEN_JUMPTOPAGE = "in_hi_JumpToPage";
	
	/** Text search string input box */
	public static final String HTMLINPUT_SEARCHBOX = "in_tx_SearchString";
	
	/** Conduct Search HTML button */
	public static final String HTMLBUTTON_SEARCHLOG = "in_bu_ConductSearch";
	
	/** JH- Constants for client side validation */
	public static final int CLIENT_VALIDATION_MAX_NAME		  = 255;

	/** Constant for client side validation */
	public static final int CLIENT_VALIDATION_MAX_DESCRIPTION = 255;
	
	private static final String JS_FUNC_NAME_DO_LOG_SEARCH = "doLogSearch";


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model = (IJobLogModelRO) model;
		m_asOwner = parent;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobLogDisplayView();
	}

	/**
	 * Returns the HTML for the Section.
	 *
	 * @return HTMLElement
	 * @throws XPException 
	 */
	public HTMLElement Display()
	{
		HTMLTable myTable;
		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLInput myInput;
		HTMLAnchor myAnchor;
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLImg myImage;
		HTMLH1 headerH1;
		PTConstruct myConstruct;

		try
		{
			boolean bBuildAsSearchPage = ((IJobLogModelRO) m_model).IsSearchRequest();
			String strSearchText = ((IJobLogModelRO) m_model).GetSearchString();
			
			//JH- Get the queryresult rowindex from the querystring.
			int intInstanceID = ((IJobLogModelRO) m_model).GetRowToDisplay();

			//JH- Get the current page
			int intPageNumber = ((IJobLogModelRO) m_model).GetCurrentLogPage();

			String strRunTime = ((IJobLogModelRO) m_model).GetRunTime();
			
			String strName = ((IJobLogModelRO) m_model).GetJobName();

			IPTScheduler ptScheduler = ((IJobLogModelRO) m_model).GetPTSession()
				.GetScheduler();
				
			int intPageCount = 0;
			if (bBuildAsSearchPage && !"".equals(strSearchText))
				intPageCount = ptScheduler.OpenLogForSearch(intInstanceID,
					HistoryViewHelper.DETAILPAGESIZE, strSearchText);
			else
				intPageCount = ptScheduler.OpenLogForRead(intInstanceID,
					HistoryViewHelper.DETAILPAGESIZE);

			//Now display the HTML
			HTMLComment myComment = new HTMLComment( "Begin: Display JobLogDisplayView");
			result.AddInnerHTMLElement(myComment);

			//First, hidden elements
			myInput = new HTMLInput(HTMLInputTypes.HIDDEN, HTMLHIDDEN_LASTPAGE,
					"");
			myInput.SetValue(XPConvert.ToString(intPageCount));
			result.AddInnerHTMLElement(myInput);

			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_JUMPTOPAGE, "");
			myInput.SetID(HTMLHIDDEN_JUMPTOPAGE);
			myInput.SetValue("0");
			result.AddInnerHTMLElement(myInput);			

			myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
					HTMLHIDDEN_CURRENTPAGE, "");
			myInput.SetValue(XPConvert.ToString(intPageNumber));
			result.AddInnerHTMLElement(myInput);

			//Create a table to display at the top of the page containing 3
			//columns: the job name, the job date, surrounded by previous and last log links,
			//and a Close button
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			//JH- First row, first cell: the job name
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			headerH1.AddInnerHTMLEncodedString(m_asOwner.GetString(98,
					"ptmsgs_portalcommonmsgs") + strName);
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);

			//JH- First row, second cell: the job date
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			headerH1.AddInnerHTMLString(strRunTime);
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);

			//JH- First row, third cell: return to job history Close button
			myCell = new HTMLTableCell();
			myCell.SetAlign("right");
			myRow.AddInnerHTMLElement(myCell);
			
			myInput = new HTMLInput(HTMLInputTypes.BUTTON, HTMLBUTTON_CLOSE,
					m_asOwner.GetString(96, "ptmsgs_portalcommonmsgs"));
			myInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

			myInput.SetValue(m_asOwner.GetString(96, "ptmsgs_portalcommonmsgs"));
			myInput.SetOnClick("OnDone(); return false;");
			myCell.AddInnerHTMLElement(myInput);

			//A spacer row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myConstruct     = UIConstructFactory.GetConstruct(PTImageType.SPACER);
			myImage		    = (HTMLImg) myConstruct.GetHTMLElement();
			myImage.SetAlt("");
			myImage.SetWidth("100%");
			myImage.SetBorder("0");
			myCell.AddInnerHTMLElement(myImage);

			//Add a subheader row
			myRow = new HTMLTableRow();
			myRow.SetStyleClass(PTStyleClass.DIR_HEADER_BG);
			myTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myCell.SetColSpan("3");
			myCell.SetHeight("25");
			myCell.SetStyleClass(PTStyleClass.DIR_HEADER);
			myRow.AddInnerHTMLElement(myCell);

			//If the page number is greater than the page count, we want to stop here and present a blank page
			if (intPageNumber <= intPageCount)
			{
				int intCounter = 0;
	
				Object[][] obj = (Object[][]) ptScheduler.GetPage(intPageNumber);
				
				if (!bBuildAsSearchPage)
				{
					myCell.AddInnerHTMLString(m_asOwner.GetString(631, "ptmsgs_portalcommonmsgs"));
				}
				else
				{
					myCell.AddInnerHTMLEncodedString(m_asOwner.GetString(536,
										"ptmsgs_portalcommonmsgs") + strSearchText);
					myCell.AddInnerHTMLString("<br>");
				}
	
				//Now for an action bar row
				myRow = new HTMLTableRow();
				myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
				myTable.AddInnerHTMLElement(myRow);
				myCell = new HTMLTableCell();
				myCell.SetColSpan("3");
				myCell.SetHeight("25");
				myCell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
				myRow.AddInnerHTMLElement(myCell);
	
				HTMLInput mySearchLogBox = new HTMLInput( HTMLInputTypes.TEXT, HTMLINPUT_SEARCHBOX, "" );
				mySearchLogBox.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
				mySearchLogBox.SetOnKeyPress("return " + PlumtreeHelpers.STR_JS_FUNC_NAME_EXECUTE_VIA_ENTER + "(event);");	
				
				HTMLInput mySearchButton = new HTMLInput( HTMLInputTypes.BUTTON, HTMLBUTTON_SEARCHLOG, "" );
				mySearchButton.SetValue(m_asOwner.GetString(535,
									"ptmsgs_portalcommonmsgs"));
				mySearchButton.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
					JobLogRepostControl.POSTTOSELF_ACTION_LOGSEARCH + "); return false;");
				mySearchButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
	
				myCell.AddInnerHTMLElement(mySearchLogBox);
				myCell.AddInnerHTMLString("&nbsp;&nbsp;");
				myCell.AddInnerHTMLElement(mySearchButton);
	
				if (bBuildAsSearchPage)
				{
					//The return to First page link
					
					//Set the previous cell's colspan to one fewer
					myCell.SetColSpan("2");
					//then add another cell for the return link
					myCell = new HTMLTableCell();
					myCell.SetAlign("right");
					myCell.SetStyleClass(PTStyleClass.ACTIONBAR_TEXT);
					myRow.AddInnerHTMLElement(myCell);

					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						JobLogRepostControl.POSTTOSELF_ACTION_EXITSEARCH +
						"); return false;");
	
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(537,
										"ptmsgs_portalcommonmsgs"));
					myCell.AddInnerHTMLElement(myAnchor);
				}
	
	
				if (null != obj)
				{
					int maxItems =  obj.length;
					
					for (int j = 0; j < maxItems; j++)
					{
						myRow = new HTMLTableRow();
						myTable.AddInnerHTMLElement(myRow);
	
						if ((intCounter % 2) == 1)
						{
							myRow.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);
						}
						else
						{
							myRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
						}
	
						myCell = new HTMLTableCell();
						myCell.SetColSpan("3");
						myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
						myRow.AddInnerHTMLElement(myCell);
						
						String strTempLine = (String) obj[j][2];
						
						if (bBuildAsSearchPage)
						{
							myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
							myAnchor.SetOnClick("JumpToPage(" + XPConvert.ToInteger(obj[j][0]) + "); return false;");

							strTempLine = GeneralHelpers.Replace(strTempLine, "\n", "<BR>");
							myAnchor.AddInnerHTMLString(strTempLine);
							myCell.AddInnerHTMLElement(myAnchor);
						}
						else
						{
							strTempLine = GeneralHelpers.Replace(
								XPHttpUtility.HtmlEncode(strTempLine), 
								"\n", "<BR>");
							myCell.AddInnerHTMLString(strTempLine);
						}
													
						intCounter++;
					}
				}
	
				//Now the next/previous/first/last links
				myRow = new HTMLTableRow();
				myTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				myCell = new HTMLTableCell();
				myCell.SetColSpan("3");
				myCell.SetAlign("right");
				myCell.SetStyleClass(PTStyleClass.LIST_PAGINATION_TEXT);
				myRow.AddInnerHTMLElement(myCell);
	
				boolean bIsFirstPage = (intPageNumber == 1);
				boolean bIsLastPage  = (intPageNumber == intPageCount);
	
				if (!bIsFirstPage)
				{
					//Show the First page and Previous Page links
					//The First page link
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						JobLogRepostControl.POSTTOSELF_ACTION_FIRSTLOGPAGE +
						"); return false;");
	
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(100,
							"ptmsgs_portalcommonmsgs"));
					myCell.AddInnerHTMLElement(myAnchor);
					myCell.AddInnerHTMLString(" | ");
	
					//The Previous page link
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						JobLogRepostControl.POSTTOSELF_ACTION_PREVIOUSLOGPAGE +
						"); return false;");
	
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(101,
							"ptmsgs_portalcommonmsgs"));
					myCell.AddInnerHTMLElement(myAnchor);
				}
	
				if (!bIsLastPage)
				{
					if (!bIsFirstPage)
					{
						myCell.AddInnerHTMLString("  ||  ");
					}
	
					//Show the Next page and Last Page links
					//The Next page link
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						JobLogRepostControl.POSTTOSELF_ACTION_NEXTLOGPAGE +
						"); return false;");
	
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(102,
							"ptmsgs_portalcommonmsgs"));
					myCell.AddInnerHTMLElement(myAnchor);
					myCell.AddInnerHTMLString(" | ");
	
					//The Last page link
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						JobLogRepostControl.POSTTOSELF_ACTION_LASTLOGPAGE +
						"); return false;");
	
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(103,
							"ptmsgs_portalcommonmsgs"));
					myCell.AddInnerHTMLElement(myAnchor);
	
				}
				
			}
			else //The current page number (default 1) was greater than the total page count (could be zero)
			{

				if (bBuildAsSearchPage)
				{
					// no search results
					myCell.AddInnerHTMLString(m_asOwner.GetString(563, "ptmsgs_portalcommonmsgs"));

					myRow = new HTMLTableRow();
					myTable.AddInnerHTMLElement(myRow);
					myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myCell = new HTMLTableCell();
					myCell.SetColSpan("3");
					myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myRow.AddInnerHTMLElement(myCell);

					//The First page link
					myAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
					myAnchor.SetOnClick(AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						JobLogRepostControl.POSTTOSELF_ACTION_EXITSEARCH +
						"); return false;");
	
					myAnchor.AddInnerHTMLString(m_asOwner.GetString(537,
										"ptmsgs_portalcommonmsgs"));
					myCell.AddInnerHTMLElement(myAnchor);
				}
				else
				{
					//Add the Log Events text to the subheader bar
					myCell.AddInnerHTMLString(m_asOwner.GetString(631, "ptmsgs_portalcommonmsgs"));
					//Create a new table row to display the "no log" message.				
					
					myRow = new HTMLTableRow();
					myTable.AddInnerHTMLElement(myRow);
					myRow.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myCell = new HTMLTableCell();
					myCell.SetColSpan("3");
					myCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
					myRow.AddInnerHTMLElement(myCell);
					//"There is no log file..."
					myCell.AddInnerHTMLString(m_asOwner.GetString(639, "ptmsgs_portalcommonmsgs"));
				}
			}
						
			myComment = new HTMLComment( "End: Display JobLogDisplayView");
			result.AddInnerHTMLElement(myComment);
		}
		catch (Exception e)
		{
			log.Error(e, "JobLogDisplayView::Display An error occured when trying to display the HTML.");

			throw new XPException(m_asOwner.GetString(95,
					"ptmsgs_portalcommonmsgs"), e);
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on
	 * the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = PlumtreeHelpers.GetExecuteViaEnterJScript(JS_FUNC_NAME_DO_LOG_SEARCH);

		XPStringBuilder sb;

		try
		{
			// JF- OnDone JavaScript function
			sb = new XPStringBuilder(400);
			sb.Append("function OnDone()\n");
			sb.Append("{\n");
			sb.Append("  window.close();\n");
			sb.Append("}\n");
			sb.Append("\n");
			sb.Append("\nfunction JumpToPage(pagenum)\n");
			sb.Append("{\n");
			sb.Append("\n  var jumppage = document.getElementById('" +
				HTMLHIDDEN_JUMPTOPAGE + "');\n");
			sb.Append("  jumppage.value = pagenum;\n");
			sb.Append("  " + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" +
						XPConvert.ToString(JobLogRepostControl.POSTTOSELF_ACTION_JUMPTOPAGE) + ");\n");
			sb.Append("\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(100);
			
			sb.Append("function ").Append(JS_FUNC_NAME_DO_LOG_SEARCH).Append("()\n");
			sb.Append("{\n");
			sb.Append("	" + AFormDP.JAVASCRIPT_SUBMIT_FORM + "(" + JobLogRepostControl.POSTTOSELF_ACTION_LOGSEARCH + ");\n");
			sb.Append("	return false;\n");
			sb.Append("}\n");
			
			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, "JobLogDisplayView::DisplayJavascript The following error occured when trying to display the JavaScript: " +
					he.getMessage());
			
		}

		return myScript;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
}

