package com.plumtree.portalpages.common.joblogs;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;

/**
 * This is a helper model class implemented to support the display and browsing
 * of Job histories and job logs.
 *
 * @author JohnH
 *
 */
public class JobLogModel implements IRepostModel, IJobLogModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.joblogs.JobLogModel");

	/** Unique identifier for the model */
	public static final String STR_MVC_CLASS_NAME = "JobLogModel";
	
	/** Unique identifier for filter from date picker */
	public static final String FILTER_FROM = "DP_FilterFrom";
	
	/** Unique identifier for filter to date picker */
	public static final String FILTER_TO = "DP_FilterTo";
	
	/** Unique identifier for delete through date picker */
	public static final String DELETE_THROUGH = "DP_DeleteThrough";
	
	// Member variables
	/** JobLogHistory helper model */
	private JobLogModelHelper myModelHelper;

	/** Member variable for the user's locale */
	private XPLocale m_Locale; //the user locale
	
	/** Member variable for the user's time zone */
	private XPTimeZone m_Timezone; //the user time zone

	/** Member variable for the parent activity space */
	private AActivitySpace m_asOwner;

// **********End member variables **************

	/**
	 * Inits the Model with the IPTSession.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		m_asOwner = parent;
		
		myModelHelper = new JobLogModelHelper(parent, (IPTSession) parent.GetUserSession());
		//Get the locale
		String strLocaleID =
			(String) PTPersonalSettingsHelper.GetPersonalSettingValue(
				PersonalSettingNames.LOCALE,
				parent);

		m_Locale = new XPLocale(strLocaleID);

		if (null == m_Locale) {
			m_Locale = XPLocale.GetDefault();
		}


		String strTimeZone =
			(String) PTPersonalSettingsHelper.GetPersonalSettingValue(
				PersonalSettingNames.TIMEZONE,
				parent);

		if (null != strTimeZone)
		{
			m_Timezone = XPTimeZone.GetTimeZone(strTimeZone);
		} else
		{
			m_Timezone = XPTimeZone.GetCurrentTimeZone();
		}

		myModelHelper.InitializeDatePickerMgrs(m_Locale, m_Timezone);
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobLogModel();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupTempData()
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#Finish()
	 */
	public void Finish()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#GetRedirectAfterFinish()
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}
	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

// BEGIN ***************** repost action methods *****************

	/**
	 * Delete the job history from the passed in date and earlier
	 *
	 * @param xpdtDeleteFrom
	 *
	 */
	public void DeleteJobHistory(XPDateTime xpdtDeleteFrom)
	{
		myModelHelper.DeleteJobHistory(xpdtDeleteFrom);
	}


	 /**
	  * Returns the job viewer to non-search mode.
	  * @return void
	  */
	 public void ExitSearchMode()
	 {
		 myModelHelper.ExitSearchMode();
	 }

	/**
	 * This function returns an int array of JobID's to be killed
	 *
	 * @param _htFormData
	 * @return int[]
	 */
	public int[] GetArrayOfJobsToKill(XPHashtable _htFormData)
	{
		return myModelHelper.GetArrayOfJobsToKill(_htFormData);
	}

	/**
	 * This function will send a kill message to each job that has been checked
	 * by the user.
	 * 
	 * @param _htFormData
	 */
	public void KillJobs(XPHashtable _htFormData)
	{
		myModelHelper.KillJobs(_htFormData);
	}
	
	/**
	 * Prepare the log file for download by setting it on a byte array member variable
	 *
	 * @param intInstanceID - The instance ID of the job log
	 */
	public void RetrieveFileForDownload( int intInstanceID ) 
	{
		myModelHelper.RetrieveFileForDownload(intInstanceID);
	}
	
// END ***************** repost action methods *****************


//	BEGIN ***************** Get and Set methods *****************

	 /**
	  * Returns whether the very last request is a search of the job log.
	  * @return int
	  */
	 public boolean IsSearchRequest()
	 {
		 return myModelHelper.IsSearchRequest();
	 }

	 /**
	  * Returns a string used for searching the job log.
	  * @return String
	  */
	 public String GetSearchString()
	 {
		 return myModelHelper.GetSearchString();
	 }
	 /**
	  * Returns the log page currently being displayed.
	  * @return int
	  */
	 public int GetCurrentLogPage()
	 {
		 return myModelHelper.GetCurrentLogPage();
	 }

	 /**
	  * Returns CurrentPage setting.
	  *
	  * @return int
	  */
	 public int GetCurrentPage()
	 {
		 return myModelHelper.GetCurrentPage();
	 }

	 /**
	  * Returns the jobID.
	  * @return int
	  */
	 public int GetJobID()
	 {
		 return myModelHelper.GetJobID();
	 }

	 /**
	  * Returns the jobName.
	  * @return String
	  */
	 public String GetJobName()
	 {
		 return myModelHelper.GetJobName();
	 }

	 /**
	  * Returns the Plumtree Session object.
	  * @return IPTSession
	  */
	 public IPTSession GetPTSession()
	 {
		 return myModelHelper.GetPTSession();
	 }

	 /**
	  * Returns the job history row to display in the job log detail viewer.
	  * @return int
	  */
	 public int GetRowToDisplay()
	 {
		 return myModelHelper.GetRowToDisplay();
	 }

	 /**
	  * Returns the runTime.
	  * @return String
	  */
	 public String GetRunTime()
	 {
		 return myModelHelper.GetRunTime();
	 }

	 /**
	  * Sets the the search term and indicates a result page
	  * @param SearchTerm to be applied against the log text
	  */
	 public void SetLogSearchPage(String strSearchText)
	 {
		 myModelHelper.SetLogSearchPage(strSearchText);
	 }

	 /**
	  * Sets the the log page currently being displayed.
	  * @param currentLogPage The currentLogPage to set
	  */
	 public void SetCurrentLogPage(int currentLogPage)
	 {
		 myModelHelper.SetCurrentLogPage(currentLogPage);
	 }

	 /**
	  * Sets CurrentRecord setting.
	  *
	  */
	 public void SetCurrentPage(int _intCurrentPage)
	 {
		 myModelHelper.SetCurrentPage(_intCurrentPage);
	 }

	 /**
	  * Sets the jobID.
	  * @param jobID The jobID to set
	  */
	 public void SetJobID(int jobID)
	 {
		 myModelHelper.SetJobID(jobID);
	 }

	 /**
	  * Sets the jobName.
	  * @param jobName The jobName to set
	  */
	 public void SetJobName(String jobName)
	 {
		 myModelHelper.SetJobName(jobName);
	 }

	 /**
	  * Sets the job history row to display in the job log detail viewer.
	  * @param rowToDisplay The rowToDisplay to set
	  */
	 public void SetRowToDisplay(int rowToDisplay)
	 {
		 myModelHelper.SetRowToDisplay(rowToDisplay);
	 }

	 /**
	  * Sets the runTime.
	  * @param runTime The runTime to set
	  */
	 public void SetRunTime(String runTime)
	 {
		 myModelHelper.SetRunTime(runTime);
	 }
	
	/**
	 * Returns the log file in byte array format
	 * 
	 * @return byte[]
	 */
	public byte[] GetLogFile()
	{
		return myModelHelper.GetLogFile();
	}

	/**
	 * Get the Date picker control manager
	 *
	 * @return JSDatePickerMgr
	 */
	public JSDatePickerMgr GetDatePickerControlManager()
	{
		return myModelHelper.GetDatePickerControlManager();
	}

	 // END ***************** Get and Set methods *****************

	// BEGIN ***************** save DP methods ***************** 
	/**
	 * @see com.plumtree.uiinfrastructure.form.IRepostModel#SavePage(String, XPHashtable)
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nSaveStatus = RepostControl.PAGE_STATUS_VALID;

		nSaveStatus = SaveHistoryPage(_htFormData);

		return nSaveStatus;
	}

	/**
	 * Saves the data on the History page.
	 *
	 * @param _htFormData
	 */
	private int SaveHistoryPage(XPHashtable _htFormData)
	{
		int intReturnValue = RepostControl.PAGE_STATUS_VALID;
		
		try
		{
			myModelHelper.GetPageMgr().StoreAllUserInput(_htFormData);
		}
		catch (Exception e)
		{
			intReturnValue = RepostControl.PAGE_STATUS_INVALID;
			
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Admin"), "JobLogModel::SaveHistoryPage", e, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(687, "ptmsgs_portalcommonmsgs"));
		}

		return intReturnValue;
	}
	// END ***************** save DP methods ***************** 

}


