/*
 * Created on Apr 12, 2003
 *
 * To change this generated comment go to 
 * Window>Preferences>Java>Code Generation>Code Template
 */
package com.plumtree.portalpages.common.joblogs;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.datepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.jsutil.*;

/**
 * This helper class contains the implementation of the functions that the Job Log Model
 * needs.  Those functions have been moved to the helper class so they can be shared
 * among multiple models (e.g. the intrinsic portlet model)
 *  
 * @author JohnH
 */
public class JobLogModelHelper implements IJobLogModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.joblogs.JobLogModelHelper");

//	********** Begin member variables **************
	/** Server object: Plumtree Session */
	private IPTSession m_Session;

	/** Member variable for the parent activity space */
	private AActivitySpace m_asOwner;

	/** The name of the job whose log is being displayed */
	private String m_strJobName = "";

	/** The run time of the job whose log is being displayed */
	private String m_strRunTime			  = "";
	
	/** mbs- these are used for generating a search result page */
	private boolean m_bNewSearch = false;
	
	/** mbs- Member variable for the search string */
	private String m_strSearchString;

	/** The page of the job log currently being displayed */
	private int m_intCurrentLogPage = 1;

	/** Member variable for the current job run page for history detail view (one based)  */
	private int m_intCurrentPage    = 1;

	/** The Job ID of the job whose log is being displayed. */
	private int m_intJobID		  = 0;
	
	/** The job history row to display when displaying the job log */
	private int m_intRowToDisplay = 0;

	/** Byte array containing the job log file being downloaded */
	private byte[] m_btarrLogFile;
	
	/** DateTime date picker manager */
	private JSDatePickerMgr m_ptJSDatePickerMgr;

	/** Page Manager object */
	private PageMgr m_ptPageMgr;

// **********End member variables **************

	/**
	 * The constructor for the JobLogModelHelper class.
	 * 
	 * @param parent - The activity space this is being called from
	 * @param session - The user's plumtree session
	 */
	public JobLogModelHelper(AActivitySpace parent, IPTSession session)
	{
		m_asOwner = parent;
		m_Session = session;
	}

	/**
	 * This function initializes the manager objects (Page and date) for the date pickers
	 */
	public void InitializeDatePickerMgrs(XPLocale xpLocale, XPTimeZone xpTimeZone)
	{
		// Deal with the page manager
		String strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
		m_ptPageMgr     = new PageMgr(m_asOwner.GetAccessStyle(), xpLocale, xpTimeZone, strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		// Deal with the date/time-picker
		JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		m_ptJSDatePickerMgr = new JSDatePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(), m_ptPageMgr);
		m_ptPageMgr.RegisterComponentMgr(m_ptJSDatePickerMgr);

		ADatePickerComponent ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
		ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, JobLogModel.FILTER_FROM);
		m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);

		ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
		ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, JobLogModel.FILTER_TO);
		m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);

		ptJSDatePicker = (ADatePickerComponent) m_ptPageMgr.AddPageControl("DatePicker");
		ptJSDatePicker.Init(AFormDP.HTMLFORM_NAME, m_ptPageMgr, JobLogModel.DELETE_THROUGH);
		m_ptJSDatePickerMgr.RegisterComponent(ptJSDatePicker);
	}

	
// BEGIN ***************** repost action methods *****************	
	/**
	 * Delete the job history from the passed in date and earlier
	 *
	 * @param xpdtDeleteFrom
	 *
	 */
	public void DeleteJobHistory(XPDateTime xpdtDeleteFrom)
	{
		try
		{
			IPTScheduler ptScheduler = m_Session.GetScheduler();
			ptScheduler.DeleteJobHistory(xpdtDeleteFrom);
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"), "JobLogModel::DeleteJobHistory", e, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(104, "ptmsgs_portalcommonmsgs"));
		}
	}
	
	/**
	 * This function returns the viewer to simple read mode
	 *
	 * @param none
	 * @return void
	 */
	public void ExitSearchMode()
	{
		m_bNewSearch = false;
	}

	/**
	 * This function returns an int array of JobID's to be killed
	 *
	 * @param _htFormData
	 * @return int[]
	 */
	public int[] GetArrayOfJobsToKill(XPHashtable _htFormData)
	{
		String sDataKey     = HistoryViewHelper.HTMLCHECKBOX_JOBID;
		String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);

		int[] aRowsToDelete = new int[aDataValue.length];

		for (int i = 0; i < aDataValue.length; i++)
		{
			try
			{
				aRowsToDelete[i] = XPConvert.ToInteger(aDataValue[i]);
			}
			catch (Exception e)
			{
				PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"), "JobLogModel::GetArrayOfJobsToKill", e, false, UIErrorLevel.SERIOUS, 
					m_asOwner.GetString(688, "ptmsgs_portalcommonmsgs"));
			}
		}

		return aRowsToDelete;
	}

	/**
	 * This function will send a kill message to each job that has been checked
	 * by the user.
	 * 
	 * @param _htFormData
	 */
	public void KillJobs(XPHashtable _htFormData)
	{
		String sDataKey = HistoryViewHelper.HTMLCHECKBOX_JOBID;

		try 
		{
			// JF- We get back the list of index of rows to delete.
			if (_htFormData.ContainsKey(sDataKey))
			{
				int[] aRowsToDelete = GetArrayOfJobsToKill(_htFormData);
	
				IPTScheduler ptScheduler = m_Session.GetScheduler();
				for (int i=0;i < aRowsToDelete.length; i++)
				{
					try
					{
						if (-1 != aRowsToDelete[i])
							ptScheduler.KillRunningJob(aRowsToDelete[i], 0); 
						// olegs: this is correct kill call, implementation has changed from DCOM to notification via DB
						// note that 0 soft kill timeout is ignored and hardcoded 3 min is used instead
					}
					catch (XPException e)
					{
						// Avoid exception throwing, as exceptions thrown on job kill requests
						// likely owe to simply hitting the refresh button on jobs already in 
						// the process of being killed.
					}
				}
			}
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"), "JobLogModel::KillJobs", e, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(689, "ptmsgs_portalcommonmsgs"));
		}
	}

	/**
	 * Prepare the log file for download by setting it on a byte array member variable
	 *
	 * @param intInstanceID - The instance ID of the job log
	 */
	public void RetrieveFileForDownload( int intInstanceID ) 
	{
		byte[] bytes = null;
		try 
		{
			IPTScheduler ptScheduler = GetPTSession().GetScheduler();

			int intPageCount = ptScheduler.OpenLogForRead(intInstanceID, HistoryViewHelper.DETAILPAGESIZE);
			//Assuming a max of 250 characters per line, allocate the string size based on 
			//that, number of lines per page, and number of pages
			XPStringBuilder sb = new XPStringBuilder(250 * HistoryViewHelper.DETAILPAGESIZE * intPageCount);

			for (int i=1; i<= intPageCount; i++)
			{
				Object[][] myResult = ptScheduler.GetPage(i);
				int intNumLines = myResult.length;
	
				for (int j=0; j< intNumLines; j++)
				{
					sb.Append(myResult[j][2]).Append("\r").Append("\n");
				}
			}
			//Return the byte array as UTF-8 (the default for XPStringUtility.GetBytes)
			bytes = XPStringUtility.GetBytes(sb.ToString());
		} 
		catch (Exception e) {
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Common"), "JobLogModel::RetrieveFileForDownload", e, false, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(684, "ptmsgs_portalcommonmsgs"));
		}
		
		m_btarrLogFile = bytes;
	}

// END ***************** repost action methods *****************

// BEGIN ***************** Get and Set methods *****************

	/**
	 * Returns whether the very last request is a search of the job log.
	 * @return int
	 */
	public boolean IsSearchRequest()
	{
		boolean bThisRequest = m_bNewSearch;
		return bThisRequest;
	}

	/**
	 * Returns a string used for searching the job log.
	 * @return String
	 */
	public String GetSearchString()
	{
		return m_strSearchString;
	}
	/**
	 * Returns the log page currently being displayed.
	 * @return int
	 */
	public int GetCurrentLogPage()
	{
		return m_intCurrentLogPage;
	}

	/**
	 * Returns CurrentPage setting.
	 *
	 * @return int
	 */
	public int GetCurrentPage()
	{
		return m_intCurrentPage;
	}

	/**
	 * Returns the jobID.
	 * @return int
	 */
	public int GetJobID()
	{
		return m_intJobID;
	}

	/**
	 * Returns the jobName.
	 * @return String
	 */
	public String GetJobName()
	{
		return m_strJobName;
	}

	/**
	 * Returns the Plumtree Session object.
	 * @return IPTSession
	 */
	public IPTSession GetPTSession()
	{
		return m_Session;
	}

	/**
	 * Returns the job history row to display in the job log detail viewer.
	 * @return int
	 */
	public int GetRowToDisplay()
	{
		return m_intRowToDisplay;
	}

	/**
	 * Returns the runTime.
	 * @return String
	 */
	public String GetRunTime()
	{
		return m_strRunTime;
	}

	/**
	 * Returns the log file in byte array format
	 * 
	 * @return byte[]
	 */
	public byte[] GetLogFile()
	{
		// Force the cleanup of m_btarrLogFile.  Don't want to keep it around in memory
		byte[] logfile = m_btarrLogFile;
		m_btarrLogFile = null;
		return logfile;
	}

	/**
	 * Sets the the search term and indicates a result page
	 * @param SearchTerm to be applied against the log text
	 */
	public void SetLogSearchPage(String strSearchText)
	{
		m_bNewSearch = true;
		m_strSearchString = strSearchText;	
	}

	/**
	 * Sets the the log page currently being displayed.
	 * @param currentLogPage The currentLogPage to set
	 */
	public void SetCurrentLogPage(int currentLogPage)
	{
		m_intCurrentLogPage = currentLogPage;
	}

	/**
	 * Sets CurrentRecord setting.
	 *
	 */
	public void SetCurrentPage(int _intCurrentPage)
	{
		m_intCurrentPage = _intCurrentPage;
	}

	/**
	 * Sets the jobID.
	 * @param jobID The jobID to set
	 */
	public void SetJobID(int jobID)
	{
		m_intJobID = jobID;
	}

	/**
	 * Sets the jobName.
	 * @param jobName The jobName to set
	 */
	public void SetJobName(String jobName)
	{
		m_strJobName = jobName;
	}

	/**
	 * Sets the job history row to display in the job log detail viewer.
	 * @param rowToDisplay The rowToDisplay to set
	 */
	public void SetRowToDisplay(int rowToDisplay)
	{
		m_intRowToDisplay = rowToDisplay;
	}

	/**
	 * Sets the runTime.
	 * @param runTime The runTime to set
	 */
	public void SetRunTime(String runTime)
	{
		m_strRunTime = runTime;
	}

	/**
	 * Get the Date picker control manager
	 *
	 * @return JSDatePickerMgr
	 */
	public JSDatePickerMgr GetDatePickerControlManager()
	{
		return m_ptJSDatePickerMgr;
	}

	/**
	 * @return PageMgr
	 */
	public PageMgr GetPageMgr()
	{
		return m_ptPageMgr;
	}
	// END ***************** Get and Set methods *****************

}


