package com.plumtree.portalpages.common.joblogs;


// Framework Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;

/**
 *
 * Performs repost actions for the Job history and job log helper package
 *
 * @author JohnH
 *
 */
public class JobLogRepostControl extends RepostControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.joblogs.JobLogRepostControl");

	/** The unique identifier for the class */
	public static final String STR_MVC_CLASS_NAME = "JobLogRepost";


	//Repost actions
	/** Delete history repost action */
	public final static int POSTTOSELF_ACTION_DELETEHISTORY		  = 21;

	/** Move to the first history page */
	public final static int POSTTOSELF_ACTION_FIRSTHISTORYPAGE    = 22;

	/** Move to the previous history page */
	public final static int POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE = 23;

	/** Move to the next history page */
	public final static int POSTTOSELF_ACTION_NEXTHISTORYPAGE = 24;

	/** Move to the last history page */
	public final static int POSTTOSELF_ACTION_LASTHISTORYPAGE = 25;

	/** Pop up the job detail window */
	public final static int POSTTOSELF_ACTION_JOBDETAIL_POPUP = 30;

	/** Move to the first log page */
	public final static int POSTTOSELF_ACTION_FIRSTLOGPAGE    = 31;

	/** Move to the previous log page */
	public final static int POSTTOSELF_ACTION_PREVIOUSLOGPAGE = 32;

	/** Move to the next log page */
	public final static int POSTTOSELF_ACTION_NEXTLOGPAGE = 33;

	/** Move to the last log page */
	public final static int POSTTOSELF_ACTION_LASTLOGPAGE = 34;

	/** Search the job log */
	public final static int POSTTOSELF_ACTION_LOGSEARCH = 35;

	/** Jump to a page in the job log */
	public final static int POSTTOSELF_ACTION_JUMPTOPAGE = 36;
	
	/** Abort job action */
	public final static int POSTTOSELF_ACTION_ABORT = 40;
	
	/** Download file action */
	public final static int POSTTOSELF_ACTION_DOWNLOAD = 37;
	
	/** Exit the search view */
	public final static int POSTTOSELF_ACTION_EXITSEARCH = 39;
	
	//Constant for delete vs. filter mode
	/** Filter mode */
	public final static int FILTERMODE = 1;

	protected AActivitySpace m_asOwner = null;
	protected IModel m_model = null;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(IModel, AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		super.Init(model, space);
		
		// Store these for use later.
		m_asOwner     = space;
		m_model		  = model;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobLogRepostControl();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
        
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.form.RepostControl#SetRepostAction()
     */
    protected void SetRepostAction() 
    {
        // JHQ for issue 36772: super.CheckActionSecurityAndExecute() will treate LOW_BANDWIDTH 
        // the same as 508 and therefore look for in_su508PostToSelf_ instead of PostToSelf.
        // But in LB we can execute javascript and we use PostToSelf.
		if (AccessStyles.LOW_BANDWIDTH == m_asOwner.GetAccessStyle())
		{
			if (m_htFormData.ContainsKey(HTMLINPUT_POSTTOSELF))
			{
				String[] data = (String[]) m_htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
	
				if ((0 != data.length) && (null != data[0]))
				{
					m_nAction = XPConvert.ToInteger(data[0]);
	
					log.Debug("JobLogRepostControl::SetRepostAction Repost action ID value: " +
							m_nAction);
				}
				else
				{
					log.Warn("JobLogRepostControl::SetRepostAction Repost action ID was not in Query String.");
				}
			}
		}
		else
		{
	        super.SetRepostAction();
		}
    }
    
	// AGC- Added this in order to make this jumpable - note,
	// you can't change PerformAction to be public because the
	// super method is not public.
	public void  PublicPerformAction(int _nAction)
	{
		PerformAction(_nAction);
	}

	/**
	 * Switch between the action modes and call
	 * the associated method for each action.
	 *
	 * @param _nAction
	 */
	protected void PerformAction(int _nAction)
	{
		super.PerformAction(_nAction);
		
		switch (_nAction)
		{
		case POSTTOSELF_ACTION_DELETEHISTORY:

			//Delete the job history
			JSDatePickerMgr myMgr = ((IJobLogModelRO) m_model).GetDatePickerControlManager();
			JSDatePicker myDatePicker = (JSDatePicker) myMgr.GetComponent(JobLogModel.DELETE_THROUGH);

			String strDeleteFrom = myDatePicker.GetSelectedDateAsString();

			if (!(strDeleteFrom.equals("")))
			{
				XPDateFormat myDateFormat = XPDateFormat.GetDateInstance(XPDateFormat.MEDIUM);
				((JobLogModel) m_model).DeleteJobHistory(myDateFormat.Parse(
						strDeleteFrom));
			}

			break;

		case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
			SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_FIRSTHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
			SetNewHistoryPageID(m_htFormData,
				POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
			SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_NEXTHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_LASTHISTORYPAGE:
			SetNewHistoryPageID(m_htFormData, POSTTOSELF_ACTION_LASTHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_JOBDETAIL_POPUP:
			PerformJobDetailPopupAction(m_htFormData);

			break;

		case POSTTOSELF_ACTION_FIRSTLOGPAGE:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_FIRSTLOGPAGE);

			break;

		case POSTTOSELF_ACTION_PREVIOUSLOGPAGE:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_PREVIOUSLOGPAGE);

			break;

		case POSTTOSELF_ACTION_NEXTLOGPAGE:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_NEXTLOGPAGE);

			break;

		case POSTTOSELF_ACTION_LASTLOGPAGE:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_LASTLOGPAGE);
			
			break;

		case POSTTOSELF_ACTION_LOGSEARCH:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_LOGSEARCH);
			
			break;
			
		case POSTTOSELF_ACTION_JUMPTOPAGE:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_JUMPTOPAGE);
			
			break;
			
		case POSTTOSELF_ACTION_EXITSEARCH:
			SetNewPage(m_htFormData, POSTTOSELF_ACTION_EXITSEARCH);
			
			break;
			
		case POSTTOSELF_ACTION_ABORT:
			AbortJob(m_htFormData);
			
			break;
			
		case POSTTOSELF_ACTION_DOWNLOAD:
			//First, place the appropriate log file on the model
			int intInstanceID = 0;
			
			String strInstanceID = ((String[]) m_htFormData.GetElement(
				HistoryViewHelper.HTMLHIDDEN_ACTIVEINSTANCE))[0];
			
			if (null != strInstanceID)
			{
				intInstanceID = XPConvert.ToInteger(strInstanceID);
			}
			
			if (intInstanceID > 0)
			{
				((JobLogModel) m_model).RetrieveFileForDownload(intInstanceID);
				//Then, redirect to the download display page
				Redirect repostURL = new Redirect();
				repostURL.SetLinkGetCachedSpace(m_asOwner);
				//repostURL.SetLinkGetCachedSpace(m_asOwner);
				repostURL.SetControl(STR_MVC_CLASS_NAME);
				repostURL.SetDisplayPage(JobLogDownloadDP.STR_MVC_CLASS_NAME);
				SetRedirect(repostURL);
			}
			
			break;
		}
	}
	
	public void MyPerformReadOnlyAction(int _nAction,XPHashtable m_htFormData_Copy)
	{
		switch (_nAction)
		{
		case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
		case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
		case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
		case POSTTOSELF_ACTION_LASTHISTORYPAGE:
			m_htFormData=m_htFormData_Copy;
			PerformAction(_nAction);
			m_htFormData_Copy=null;
			break;
		case POSTTOSELF_ACTION_ABORT:
		case POSTTOSELF_ACTION_SIMPLEREPOST: // refresh
		case POSTTOSELF_ACTION_DOWNLOAD:

			if(m_htFormData==null)
				m_htFormData=m_htFormData_Copy;
			PerformAction(_nAction);
			m_htFormData_Copy=null;
			break;
			
		default:
			// TODO: alert
			break;
		}
	}

	/**
	 * JH- PerformJobDetailPopupAction handles the case where a popup is being
	 * displayed
	 *
	 * @param _htFormData is a hashtable that stores the form post data and querystring
	 */
	private void PerformJobDetailPopupAction(XPHashtable _htFormData)
	{
		// MBS- Always make certain we open in read mode
		((JobLogModel) m_model).ExitSearchMode();
		//JH- Get the row number of the item we're displaying and store it in the Model, where
		//	the Form can get to it.
		((JobLogModel) m_model).SetRowToDisplay(XPConvert.ToInteger(
				((String[]) _htFormData.GetElement(
					HistoryViewHelper.POPUP_CONTROL_ARG_ROWTOVIEW))[0]));
		((JobLogModel) m_model).SetJobName(((String[]) _htFormData.GetElement(
				HistoryViewHelper.POPUP_CONTROL_ARG_JOBNAME))[0]);
		((JobLogModel) m_model).SetRunTime(((String[]) _htFormData.GetElement(
				HistoryViewHelper.POPUP_CONTROL_ARG_RUNTIME))[0]);

		//Reset the current page of the job log to display back to 1
		((JobLogModel) m_model).SetCurrentLogPage(1);
	}

	/**
	 * JH- SetNewHistoryPageID sets the History Page ID on the model so the
	 * HistoryDetailView can know which page of the job history to display
	 *
	 * @param _htFormData
	 * @param intAction - The action to take: First, Previous, Next, Last
	 */
	private void SetNewHistoryPageID(XPHashtable _htFormData, int intAction)
	{
		int intCurrentPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					HistoryViewHelper.HTMLHIDDEN_CURRENTPAGE))[0]);
		int intLastPage    = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					HistoryViewHelper.HTMLHIDDEN_LASTPAGE))[0]);

		//set the appropriate BlockID based on the action
		switch (intAction)
		{
		case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
			((JobLogModel) m_model).SetCurrentPage(1);

			break;

		case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
			((JobLogModel) m_model).SetCurrentPage(intCurrentPage - 1);

			break;

		case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
			((JobLogModel) m_model).SetCurrentPage(intCurrentPage + 1);

			break;

		case POSTTOSELF_ACTION_LASTHISTORYPAGE:
			((JobLogModel) m_model).SetCurrentPage(intLastPage);

			break;
		}
	}

	private void AbortJob(XPHashtable _htFormData)
	{
		//Send a kill message to the job or jobs
		try
		{
			((JobLogModel) m_model).KillJobs(_htFormData);
		}
		catch (Exception e)
		{
			
				log.Error("JobLogRepostModel::AbortJob " + m_asOwner.GetString(632, "ptmsgs_portalcommonmsgs")
						+ e);
			
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER,
						null,
						m_asOwner.GetString(632, "ptmsgs_portalcommonmsgs") + e,
						"");

			myError.SetActivitySpace(m_asOwner.GetName());

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),m_asOwner.GetApplication());
		}
	}

	/**
	 * JH- SetNewPage sets the page on the model so the JobLogDisplayView can
	 * know which page of the job log to display
	 *
	 * @param _htFormData
	 * @param intAction - The action to take: First, Previous, Next, Last
	 */
	private void SetNewPage(XPHashtable _htFormData, int intAction)
	{
		int intCurrentPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					JobLogDisplayView.HTMLHIDDEN_CURRENTPAGE))[0]);
		int intLastPage    = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					JobLogDisplayView.HTMLHIDDEN_LASTPAGE))[0]);

		//set the appropriate BlockID based on the action
		switch (intAction)
		{
		case POSTTOSELF_ACTION_FIRSTLOGPAGE:
			((JobLogModel) m_model).SetCurrentLogPage(1);

			break;

		case POSTTOSELF_ACTION_PREVIOUSLOGPAGE:
			((JobLogModel) m_model).SetCurrentLogPage(intCurrentPage - 1);

			break;

		case POSTTOSELF_ACTION_NEXTLOGPAGE:
			((JobLogModel) m_model).SetCurrentLogPage(intCurrentPage + 1);

			break;

		case POSTTOSELF_ACTION_LASTLOGPAGE:
			((JobLogModel) m_model).SetCurrentLogPage(intLastPage);

			break;
			
		case POSTTOSELF_ACTION_LOGSEARCH:
			((JobLogModel) m_model).SetCurrentLogPage(1);
			String strTargetText = ((String[]) _htFormData.GetElement(
					JobLogDisplayView.HTMLINPUT_SEARCHBOX))[0];
			((JobLogModel) m_model).SetLogSearchPage(strTargetText);
			
			break;
			
		case POSTTOSELF_ACTION_JUMPTOPAGE:
			((JobLogModel) m_model).ExitSearchMode();
		int intJumpToPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					JobLogDisplayView.HTMLHIDDEN_JUMPTOPAGE))[0]);
			((JobLogModel) m_model).SetCurrentLogPage(intJumpToPage);
			
			break;
			
		case POSTTOSELF_ACTION_EXITSEARCH:
			((JobLogModel) m_model).SetCurrentLogPage(1);
			((JobLogModel) m_model).ExitSearchMode();		
			break;
		}
	}
}

