package com.plumtree.portalpages.common.linksettings;


// Plumtree Server Imports
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author StephenC
 *
 * This Section represents a section of the Link Settings page
 * of the Card Editor.
 */
public class LinkSettingsPlugInView extends EditorView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.linksettings.LinkSettingsPlugInView");

	
	public static final String STR_MVC_CLASS_NAME = "LinkSettingsPlugIn";

		// HTML Object names.
	public static final String HTMLRADIO_EXPIRATION   = "in_ra_expiration";

	
	public static final String HTMLINPUT_EXPIREAFTERVALUE = "in_tx_expireaftervalue";

	
	public static final String HTMLSELECT_EXPIREAFTERUNIT = "in_se_expireafterunit";

	
	public static final String HTMLRADIO_REFRESH		   = "in_ra_refresh";

	
	public static final String HTMLINPUT_REFRESHEVERYVALUE = "in_tx_refresheveryvalue";

	
	public static final String HTMLSELECT_REFRESHEVERYUNIT = "in_se_refresheveryunit";

	
	public static final String HTMLCHECKBOX_LINKVALIDITY = "in_cb_linkvalidity";

	
	public static final String HTMLRADIO_BROKENLINKS	   = "in_ra_brokenlinks";

	
	public static final String HTMLINPUT_BROKENDELETEVALUE = "in_tx_brokendeletevalue";

	
	public static final String HTMLSELECT_BROKENDELETEUNIT = "in_se_brokendeleteunit";

	/** Unique identifier for the Run Once date picker */
	public static final String EXPIRE_ON_DATEPICKER = "DTP_ExpireOn";


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new LinkSettingsPlugInView();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		HTMLTable myTable			 = new HTMLTable();
		HTMLTable innerTable;

		HTMLTableRow myRow;
		HTMLTableCell myCell;
		HTMLSelect mySelect;
		HTMLOption myOption;
		HTMLInput myInput;
		HTMLSpan mySpan;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display CardEditorLinkSettingsView");
			result.AddInnerHTMLElement(myComment);

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						105, "ptmsgs_portalcommonmsgs")));

			boolean bMultipleCards = ((ILinkSettingsPlugInModelRO) m_model).IsMultiple();
			boolean bIsCrawler     = ((ILinkSettingsPlugInModelRO) m_model).IsCrawler();

			int[] arScheduleUnits = 
			{
				PT_SCHEDULETYPES.PT_SCHEDULETYPE_MINUTELY,
				PT_SCHEDULETYPES.PT_SCHEDULETYPE_HOURLY,
				PT_SCHEDULETYPES.PT_SCHEDULETYPE_DAILY,
				PT_SCHEDULETYPES.PT_SCHEDULETYPE_WEEKLY,
				PT_SCHEDULETYPES.PT_SCHEDULETYPE_MONTHLY,
				PT_SCHEDULETYPES.PT_SCHEDULETYPE_ANNUALY
			};

			/////////////////////////////////////
			// EXPIRATION
			/////////////////////////////////////
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// 1st Row begin
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myCell.SetWidth("25%");
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(bMultipleCards
				? m_asOwner.GetString(107, "ptmsgs_portalcommonmsgs")
				: m_asOwner.GetString(106, "ptmsgs_portalcommonmsgs"));

			myCell = new HTMLTableCell();

			// 1st Row End
			// 2nd Row begin
			boolean bExpireNever;

			if (bIsCrawler)
			{
				bExpireNever = (PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER == ((ILinkSettingsPlugInModelRO) m_model).GetExpireAfterUnits());
			}
			else
			{
				bExpireNever = ((ILinkSettingsPlugInModelRO) m_model).IsExpirationDateNull();
			}

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			
			innerTable = new HTMLTable();
			innerTable.SetWidth("100%");
			innerTable.SetBorder("0");
			innerTable.SetCellPadding("0");
			innerTable.SetCellSpacing("0");
			innerTable.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell.AddInnerHTMLElement(innerTable);

			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// ***<input radiobutton>*** begins here
			myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_EXPIRATION,
					"");
			myInput.SetValue("" + 0);
			myInput.SetChecked(true == bExpireNever);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(108,
					"ptmsgs_portalcommonmsgs"));

			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);


			myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_EXPIRATION,
					"");
			myInput.SetValue("" + 1);
			myInput.SetChecked(false == bExpireNever);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(bIsCrawler
				? m_asOwner.GetString(109, "ptmsgs_portalcommonmsgs")
				: m_asOwner.GetString(110, "ptmsgs_portalcommonmsgs"));
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);

			// ***<input radio>*** ends here
			if (bIsCrawler)
			{
				// Expire After
				int nExpireAfterValue = ((ILinkSettingsPlugInModelRO) m_model).GetExpireAfterValue();
				int nExpireAfterUnits = ((ILinkSettingsPlugInModelRO) m_model).GetExpireAfterUnits();

				myInput				  = new HTMLInput(HTMLInputTypes.TEXT,
						HTMLINPUT_EXPIREAFTERVALUE, "");
				myCell.AddInnerHTMLElement(myInput);
				myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

				myInput.SetValue("" + nExpireAfterValue);
				myInput.SetMaxLength(3);
				myInput.SetSize(8);

				// ***<input text>*** ends here
				myCell.AddInnerHTMLString(SPACE);
				myCell.AddInnerHTMLString(SPACE);

				// begin units dropdown 
				String[] arExpireUnitNames = 
				{
					m_asOwner.GetString(124, "ptmsgs_portalcommonmsgs"),
					m_asOwner.GetString(125, "ptmsgs_portalcommonmsgs"),
					m_asOwner.GetString(126, "ptmsgs_portalcommonmsgs"),
					m_asOwner.GetString(127, "ptmsgs_portalcommonmsgs"),
					m_asOwner.GetString(128, "ptmsgs_portalcommonmsgs"),
					m_asOwner.GetString(129, "ptmsgs_portalcommonmsgs"),
				};

				mySelect = new HTMLSelect(HTMLSELECT_EXPIREAFTERUNIT, "e");
				mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
				myCell.AddInnerHTMLElement(mySelect);

				for (int i = 0; i < arScheduleUnits.length; i++)
				{
					myOption     = new HTMLOption(XPConvert.ToString(arScheduleUnits[i]));
					mySpan		 = new HTMLSpan();
					myOption.AddInnerHTMLElement(mySpan);
					mySpan.AddInnerHTMLString(arExpireUnitNames[i]);
					mySelect.AddInnerHTMLElement(myOption);

					if (arScheduleUnits[i] == nExpireAfterUnits)
					{
						myOption.SetSelected(true);
					}
				}

				// end units dropdown			
			}
			else
			{
				// Expire On
				//Set the expire date for the input box
				JSDateTimePickerMgr ptDateTimePickerMgr = ((ILinkSettingsPlugInModelRO) m_model).GetDateTimePickerControlManager();
				JSDateTimePicker myDTPicker = (JSDateTimePicker) ptDateTimePickerMgr.GetComponent(LinkSettingsPlugInView.EXPIRE_ON_DATEPICKER);
				try
				{
					myCell.AddInnerHTMLElement(myDTPicker.GetComponentHTML());
				}
				catch (Exception e)
				{
					GeneralHelpers.SetUIError(m_asOwner,OpenLogService.GetComponent("Portal_Admin"),"ScheduleView::Display", e, false, UIErrorLevel.WARNING, m_asOwner.GetString(2417, "ptmsgs_portaladminmsgs"));			
				}				
			}


			// 2nd Row end

			/////////////////////////////////////
			// REFRESH SETTINGS
			/////////////////////////////////////

			result.AddInnerHTMLElement(DirConstants.CreateSpacerTable(10,1));

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						111, "ptmsgs_portalcommonmsgs")));
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// BEGIN Refresh Instructions Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myCell.SetWidth("25%");
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(bMultipleCards
				? m_asOwner.GetString(113, "ptmsgs_portalcommonmsgs")
				: m_asOwner.GetString(112, "ptmsgs_portalcommonmsgs"));

			// END Refresh Instructions Row
			// BEGIN Refresh Options Row
			int nRefreshValue = ((ILinkSettingsPlugInModelRO) m_model).GetRefreshValue();
			int nRefreshUnits = ((ILinkSettingsPlugInModelRO) m_model).GetRefreshUnits();

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
						
			innerTable = new HTMLTable();
			innerTable.SetWidth("100%");
			innerTable.SetBorder("0");
			innerTable.SetCellPadding("0");
			innerTable.SetCellSpacing("0");
			innerTable.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
			
			myCell.AddInnerHTMLElement(innerTable);
			
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// ***<input radiobutton>*** begins here
			myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_REFRESH, "");
			myInput.SetValue("" + 0);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(114,
					"ptmsgs_portalcommonmsgs"));

			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			if (PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER == nRefreshUnits)
			{
				myInput.SetChecked(true);
			}

			myInput = new HTMLInput(HTMLInputTypes.RADIO, HTMLRADIO_REFRESH, "");
			myInput.SetValue("" + 1);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(115,
					"ptmsgs_portalcommonmsgs"));
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);

			if (PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER != nRefreshUnits)
			{
				myInput.SetChecked(true);
			}

			// ***<input radio>*** ends here
			myInput = new HTMLInput(HTMLInputTypes.TEXT,
					HTMLINPUT_REFRESHEVERYVALUE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);

			myInput.SetValue("" + ( (0 >= nRefreshValue) ? 3 : nRefreshValue));  // default to value of 3
			myInput.SetMaxLength(3);
			myInput.SetSize(8);

			// ***<input text>*** ends here
			myCell.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLString(SPACE);

			// begin units dropdown 
			String[] arRefreshUnitNames = 
			{
				m_asOwner.GetString(703, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(704, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(705, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(706, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(707, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(708, "ptmsgs_portalcommonmsgs"),
			};

			
			mySelect = new HTMLSelect(HTMLSELECT_REFRESHEVERYUNIT, "e");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			for (int i = 0; i < arScheduleUnits.length; i++)
			{
				myOption     = new HTMLOption(XPConvert.ToString(arScheduleUnits[i]));
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.AddInnerHTMLString(arRefreshUnitNames[i]);
				mySelect.AddInnerHTMLElement(myOption);

				// default to months
				if ( (arScheduleUnits[i] == nRefreshUnits) || 
  					 ((0 >= nRefreshUnits) && (6 == arScheduleUnits[i])))
				{
					myOption.SetSelected(true);
				}
			}


			/* split refresh options */
			AddEmptyRowToTable(myTable);


			// end units dropdown			
			// END Refresh Options Row
			// BEGIN Check Validity Row
			boolean bCheckLinkOnlyValue = ((ILinkSettingsPlugInModelRO) m_model).GetCheckLinkOnly();

			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(bMultipleCards
				? m_asOwner.GetString(117, "ptmsgs_portalcommonmsgs")
				: m_asOwner.GetString(116, "ptmsgs_portalcommonmsgs"));

			// ***<input checkbox>*** begins here
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
					HTMLCHECKBOX_LINKVALIDITY, "");
			myCell.AddInnerHTMLElement(myInput);

			myInput.SetChecked(bCheckLinkOnlyValue);

			// ***<input checkbox>*** ends here
			// END Check Validity Row
			
			
			/////////////////////////////////////
			// BROKEN LINKS
			/////////////////////////////////////
			result.AddInnerHTMLElement(DirConstants.CreateSpacerTable(10,1));

			int nBrokenLinksDeleteValue = ((ILinkSettingsPlugInModelRO) m_model).GetBrokenLinksDeleteValue();
			int nBrokenLinksDeleteUnits = ((ILinkSettingsPlugInModelRO) m_model).GetBrokenLinksDeleteUnits();

			result.AddInnerHTMLElement(super.GetHeaderView(m_asOwner.GetString(
						118, "ptmsgs_portalcommonmsgs")));
			myTable = new HTMLTable();
			result.AddInnerHTMLElement(myTable);
			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("5");
			myTable.SetCellSpacing("0");

			// BEGIN Broken Link Instructions Row
			myRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(myRow);
			myRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell = new HTMLTableCell();
			myCell.SetWidth("25%");
			myCell.SetVAlign(CommonHTMLStrings.TOP);
			myRow.AddInnerHTMLElement(myCell);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);

			mySpan.AddInnerHTMLString(bMultipleCards
				? m_asOwner.GetString(120, "ptmsgs_portalcommonmsgs")
				: m_asOwner.GetString(119, "ptmsgs_portalcommonmsgs"));

			// END Broken Link Instructions Row
			// BEGIN Broken Link Options Left Alone Row

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			
			innerTable = new HTMLTable();
			innerTable.SetWidth("100%");
			innerTable.SetBorder("0");
			innerTable.SetCellPadding("0");
			innerTable.SetCellSpacing("0");
			innerTable.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

			myCell.AddInnerHTMLElement(innerTable);

			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			// ***<input radiobutton>*** begins here
			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_BROKENLINKS, "");
			myInput.SetValue("" + 0);

			myInput.SetChecked(true);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(121,
					"ptmsgs_portalcommonmsgs"));

			if (PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER == nBrokenLinksDeleteUnits)
			{
				myInput.SetChecked(true);
			}

			// END Broken Link Options Left Alone Row
			// BEGIN Broken Link Options Deleted Immediately Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_BROKENLINKS, "");
			myInput.SetValue("" + 1);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(122,
					"ptmsgs_portalcommonmsgs"));

			if (PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE == nBrokenLinksDeleteUnits)
			{
				myInput.SetChecked(true);
			}

			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			// END Broken Link Options Deleted Immediately Row
			// BEGIN Broken Link Options Deleted After Row
			myRow = new HTMLTableRow();
			innerTable.AddInnerHTMLElement(myRow);
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);

			myInput = new HTMLInput(HTMLInputTypes.RADIO,
					HTMLRADIO_BROKENLINKS, "");
			myInput.SetValue("" + 2);
			myCell.AddInnerHTMLElement(myInput);
			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);

			mySpan.AddInnerHTMLString(m_asOwner.GetString(123,
					"ptmsgs_portalcommonmsgs"));
			mySpan.AddInnerHTMLString(SPACE);
			mySpan.AddInnerHTMLString(SPACE);

			if ((PT_SCHEDULETYPES.PT_SCHEDULETYPE_NEVER != nBrokenLinksDeleteUnits) &&
					(PT_SCHEDULETYPES.PT_SCHEDULETYPE_ONCE != nBrokenLinksDeleteUnits))
			{
				myInput.SetChecked(true);
			}

			// ***<input radio>*** ends here
			myInput = new HTMLInput(HTMLInputTypes.TEXT,
					HTMLINPUT_BROKENDELETEVALUE, "");
			myCell.AddInnerHTMLElement(myInput);
			myInput.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);


			int nBrokenLinksDeleteValue_final = (0 == nBrokenLinksDeleteUnits || 1 == nBrokenLinksDeleteUnits) ? 2 : nBrokenLinksDeleteValue;

			myInput.SetValue("" + nBrokenLinksDeleteValue_final);
			myInput.SetMaxLength(3);
			myInput.SetSize(8);

			// ***<input text>*** ends here
			myCell.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLString(SPACE);

			// begin units dropdown 
			String[] arBrokenUnitNames = 
			{
				m_asOwner.GetString(709, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(710, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(711, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(712, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(713, "ptmsgs_portalcommonmsgs"),
				m_asOwner.GetString(714, "ptmsgs_portalcommonmsgs"),
			};

			mySelect = new HTMLSelect(HTMLSELECT_BROKENDELETEUNIT, "e");
			mySelect.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);
			myCell.AddInnerHTMLElement(mySelect);

			int nBrokenLinksDeleteUnits_final = (0 == nBrokenLinksDeleteUnits || 1 == nBrokenLinksDeleteUnits) ? 5 : nBrokenLinksDeleteUnits;

			for (int i = 0; i < arScheduleUnits.length; i++)
			{
				myOption     = new HTMLOption(XPConvert.ToString(arScheduleUnits[i]));
				mySpan		 = new HTMLSpan();
				myOption.AddInnerHTMLElement(mySpan);
				mySpan.AddInnerHTMLString(arBrokenUnitNames[i]);
				mySelect.AddInnerHTMLElement(myOption);

				if (arScheduleUnits[i] == nBrokenLinksDeleteUnits_final)
				{
					myOption.SetSelected(true);
				}
			}

			// end units dropdown			
			myCell = new HTMLTableCell();
			myRow.AddInnerHTMLElement(myCell);
			myCell.SetNoWrap(true);

			// END Broken Link Options Deleted After Row
			myComment = new HTMLComment( "End: Display CardEditorLinkSettingsView");
			result.AddInnerHTMLElement(myComment);
		}
		catch (Exception e)
		{
			
				log.Error(e, "CardEditorLinkSettingsView::Display The following error occured when trying to display the HTML: " +
					e.getMessage());
			

			throw new XPException(m_asOwner.GetString(130,
					"ptmsgs_portalcommonmsgs"), e);
		}

		return result;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = new HTMLScript("text/javaScript");
		XPStringBuilder sb;

		try
		{
			sb = new XPStringBuilder(500);

			// The JavaScript below checks if the values are numeric is empty.
			sb.Append("function IsNumeric(strString) ");
			sb.Append("   //  check for valid numeric strings	 \n");
			sb.Append("   { \n");
			sb.Append("   var strValidChars = \"0123456789\"; \n");
			sb.Append("   var strChar; \n");
			sb.Append("   var blnResult = true; \n");
			sb.Append(" \n");
			sb.Append("   if (strString.length == 0) return false; \n");
			sb.Append(" \n");
			sb.Append(
				"   //  test strString consists of valid characters listed above \n");
			sb.Append(
				"   for (i = 0; i < strString.length && blnResult == true; i++) \n");
			sb.Append("      { \n");
			sb.Append("      strChar = strString.charAt(i); \n");
			sb.Append("      if (strValidChars.indexOf(strChar) == -1) \n");
			sb.Append("         { \n");
			sb.Append("         blnResult = false; \n");
			sb.Append("         } \n");
			sb.Append("      } \n");
			sb.Append("   if (strString <= 0) return false; \n");
			sb.Append("   return blnResult; \n");
			sb.Append("   } \n");

			myScript.AddInnerHTMLString(sb.ToString());

			sb = new XPStringBuilder(250);
			sb.Append("function CheckNumericLinkValues()\n");
			sb.Append("{\n");
			sb.Append("  if (false == IsNumeric(document." + EditorDP.HTMLFORM_NAME +
				"." + HTMLINPUT_REFRESHEVERYVALUE + ".value))\n");
			sb.Append("  {\n");

			sb.Append("      alert(\"" +
				m_asOwner.GetString(131, "ptmsgs_portalcommonmsgs") + "\");\n");
			sb.Append("      return false;\n");
			sb.Append("  } else if (false == IsNumeric(document." +
				EditorDP.HTMLFORM_NAME + "." + HTMLINPUT_BROKENDELETEVALUE +
				".value))\n");
			sb.Append("  {\n");

			sb.Append("      alert(\"" +
				m_asOwner.GetString(132, "ptmsgs_portalcommonmsgs") + "\");\n");
			sb.Append("      return false;\n");
			sb.Append("  }\n");
			sb.Append("  return true;\n");
			sb.Append("}\n");

			myScript.AddInnerHTMLString(sb.ToString());
		}
		catch (HTMLException he)
		{
			
				log.Error(he, STR_MVC_CLASS_NAME +
					"::DisplayJavascript couldn't add javascript to the HTMLScript element: " +
					he.getMessage());
			
		}

		return myScript;
	}

	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}


