package com.plumtree.portalpages.common.mediator;

import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Generates HTMLAnchors with target URLs in href, display string
 * and image(s) if assigned. 
 * This class is similar to CListURLTemplateMediator, except that the HREF 
 * is used to go to the URL instead of onlick evens. Hence, it is 508 compatible
 * since no browser Javascript capability is required.
 * 
 * 
 * Example use:
 * 
 * 		ICPListIterator mediator = new CListURLFullMediator(m_asOwner, cpList1);
 *		mediator.SetLabelMaxLength(50);    //set the maximum label length to 50 characters
 *
 *		while (mediator.Next())
 *		{
 *			HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
 *			...
 *		}
 *
 * Extension of ASURL mediator that wraps links in HTMLAnchors.  
 * 508 compatible
 * 
 * @author DavidP
 */
public class CListURLFullLinkMediator extends CListURLFullMediator
	implements ICPListIterator
{
	/**
	 * Constructor for CListURLFullLinkMediator.
	 * @param aspace
	 * @param list
	 */
	public CListURLFullLinkMediator(AActivitySpace aspace,
		ICPListEntryIterator list)
	{
		super(aspace, list);
	}

	/**
	 * @see com.plumtree.portalpages.common.mediator.ICPListIterator#GetEntry()
	 *
	 * @return 						An HTMLAnchor with the target url in the href. 
	 * 								Returns null if the HTMLAnchor has an href with null value.
	 * 			
	 */
	public Object GetEntry()
	{
		HTMLAnchor arrTemplate = null;

		// Return null entry for label-only; must be a URL
		if(super.GetEntryType() != ASCompoundList.ENTRYTYPE_STRINGLABEL)
		{				
			arrTemplate = (HTMLAnchor) super.GetEntry();
		}
		
		return arrTemplate;
	}

	/**
	 * @see com.plumtree.portalpages.common.mediator.ICPListIterator#GetEntry()
	 *
	 * @return 						An HTMLAnchor with the target url in the href. 
	 * 								Returns null if the HTMLAnchor has an href with null value.
	 */
	public Object GetEntryAtIndex(int nIndex)
	{
		HTMLAnchor arrTemplate = null;

		// Return null entry for label-only; must be a URL
		if (super.GetEntryTypeAtIndex(nIndex) != ASCompoundList.ENTRYTYPE_STRINGLABEL)
		{
			arrTemplate = (HTMLAnchor) super.GetEntryAtIndex(nIndex);
		}

		return arrTemplate;
	}
	
	


	/**
	 * Not implemented
	 *
	 * @param nHeight 				Image heigh override value 
	 * @param nWidth 				Image width override value
	 */
	public void SetImageSize(int nHeight, int nWidth)
	{
		// no appropriate implementation
	}
}

