package com.plumtree.portalpages.common.objectapproval;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.approval.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.approval.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.opener.*;

/**
 * 
 *
 * @author Ben Geislinger
 */
public class ObjectApprovalModel extends AApprovalModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.objectapproval.ObjectApprovalModel");

	/** Logging */
	
	public final static String STR_MVC_CLASS_NAME = "ObjectApprovalModel";
	private boolean boAdminRights;


//	private String _ui_menuItemTextStatusPage = "View Approval Status of {0}";


	
	private IPTMigrationManager m_ptMM = null;

	
	private IPTQueryResult m_qrItemCount = null;

	
	private IPTSession m_ptSession = null;
	private boolean bDisplayStatusForRequestor = false;
	private boolean bDisplaySelectAllButton = false;

	/**
	 * Modifies the object name on repost.
	 */
	public void ActionOnRepost()
	{
	}

	
	/**
	 * 
	 *
	 * @return 
	 */
	public boolean AddColumnsHeaderForEachItem()
	{
		return true;
	}

	//////////////////////////////////////////////////
	//					EditorModel methods
	/////////////////////////////////////////////////    

	/**
	 * Implements some actions to perform on start.
	 *
	 * @param _htFormData
	 *
	 * @return boolean Is true if the current user has the rights to access
	 *         this Editor.
	 */
	public boolean CheckEditorAccessAndStart(XPHashtable _htFormData)
	{
		// ***CHANGE_HERE*** Put the code to execute when the editor starts.
		return true;
	}

	/**
	 * 
	 */
	public void ClearCache()
	{
		//	we must do some clearing of our own.
		m_qrItemCount = null;

		super.ClearCache();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new ObjectApprovalModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean DisplayDescriptionImmediatelyUnderTitle()
	{
		return true;
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish()
	{
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetAllowClearingOfApprovalRequests()
	{
		return this.bDisplayStatusForRequestor;
	}

	/**
	 * 
	 *
	 * @param item 
	 *
	 * @return 
	 */
	public boolean GetAllowClearingOfItem(AItemDescriptor item)
	{
		// minimize server calls.
		boAdminRights = this.m_ptSession.GetSessionInfo().CheckForActivityRight(PT_ACTIVITY_RIGHTS.PT_ACTIVITY_RIGHT_ACCESS_ADMINISTRATION);

		if (boAdminRights)
		{
			return true;
		}

		boolean b = true;

		if (item.GetApprove())
		{
			//	if the item has been approved, then we don't
			//	allow the user user to clear the approval request.
			b = false;
		}

		return b;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public ApprovalItemType GetDefaultItemType()
	{
		return ApprovalPortalItemType.ADMIN_FOLDER;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public static ApprovalItemType GetDefaultItemTypeStatic()
	{
		return ApprovalPortalItemType.ADMIN_FOLDER;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetDisableRadioSelection()
	{
		return this.bDisplayStatusForRequestor;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetDisplayHeadersForItemTypesWithNoItems()
	{
		return false;
	}

	/**
	 * 
	 *
	 * @param type 
	 *
	 * @return 
	 */
	public boolean GetDisplayInstances(ApprovalItemType type)
	{
		return false;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetDisplayStatusColumn()
	{
		return this.bDisplayStatusForRequestor;
	}


	public boolean GetDisplaySelectAllButton()
	{
		return this.bDisplaySelectAllButton;
	}

	public void SetDisplaySelectAllButton( boolean b )
	{
		this.bDisplaySelectAllButton = b;
	}




	/**
	 * 
	 *
	 * @param type 
	 *
	 * @return 
	 */
	public boolean GetDisplayTypeHeader(ApprovalItemType type)
	{
		return false;
	}
	

	public boolean DisplayItemTypeHeaderAboveActionbar()
	{
		return true;
	}



	/**
	 * 
	 *
	 * @param type 
	 *
	 * @return 
	 */
	public String GetEmptyTypeSectionSubTitle(ApprovalItemType type)
	{
		int iId = type.GetLocalizedNameIDPlural();

		String sLocalizedName = this.m_asOwner.GetString(iId,
				"ptmsgs_portaladminmsgs");

		String sOut = XPResourceManager.FormatMessage(m_asOwner.GetString(539, "ptmsgs_portalcommonmsgs"),
				sLocalizedName);

		return sOut;
	}

	/**
	 * 
	 *
	 * @param type 
	 *
	 * @return 
	 */
	public String GetMenuOptionText(ApprovalItemType type)
	{
		if (type == null)
		{
			String s;
			
			if( this.bDisplayStatusForRequestor )
			{
				s = this.m_asOwner.GetString(702, "ptmsgs_portalcommonmsgs");
			}
			else
			{
				s = this.m_asOwner.GetString(701, "ptmsgs_portalcommonmsgs");				
			}
			
			return s;
			
		}

		int iTypeNameIDPlural   = type.GetLocalizedNameIDPlural();

		int iCount = this.GetTypeCount(type);

		String sLocalizedName = null;

		if (iTypeNameIDPlural != -1)
		{
			sLocalizedName = this.m_asOwner.GetString(iTypeNameIDPlural,
					"ptmsgs_portaladminmsgs");
		}
		else
		{
			//	just get the type name as a last resort
			sLocalizedName = type.GetName();
		}

		String sOut;
		if( iCount == 0 )
		{
			sOut = sLocalizedName;
		}
		else
		{
			sOut = XPResourceManager.FormatMessage( this.m_asOwner.GetString( 3132, "ptmsgs_portaladminmsgs" ), sLocalizedName, new Integer(iCount));	
		}

		return sOut;
	}
	

	/**
	 * 
	 *
	 * @param type 
	 *
	 * @return 
	 */
	public String GetStatusPageMenuOptionText(ApprovalItemType type)
	{
		if (type == null)
		{
			String s;
			
			if( this.bDisplayStatusForRequestor )
			{
				s = this.m_asOwner.GetString(702, "ptmsgs_portalcommonmsgs");
			}
			else
			{
				s = this.m_asOwner.GetString(701, "ptmsgs_portalcommonmsgs");				
			}
			
			return s;
			
		}


		int iCount = this.GetTypeCount(type);
		
		int iTypeNameIDPlural   = type.GetLocalizedNameIDPlural();


		String sLocalizedName = this.m_asOwner.GetString(iTypeNameIDPlural,
					"ptmsgs_portaladminmsgs");
		
		String sOut;
		if( iCount == 0 )
		{
			sOut = sLocalizedName;
		}
		else
		{
			sOut = XPResourceManager.FormatMessage( this.m_asOwner.GetString( 3132, "ptmsgs_portaladminmsgs" ), sLocalizedName, new Integer(iCount));	
		}

		return sOut;
	}
	
		
	
	

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetSubTitle()
	{
		return "";
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public XPArrayList GetSupportedItemTypes()
	{
		XPArrayList alTemp = new XPArrayList();

		alTemp.Add(ApprovalPortalItemType.ADMIN_FOLDER);
		alTemp.Add(ApprovalPortalItemType.AUTHSOURCE);
		alTemp.Add(ApprovalPortalItemType.COMMUNITY);
		alTemp.Add(ApprovalPortalItemType.COMMUNITY_TEMPLATE);
		alTemp.Add(ApprovalPortalItemType.CRAWLER);
		alTemp.Add(ApprovalPortalItemType.DATASOURCE);
		alTemp.Add(ApprovalPortalItemType.DOCUMENT);
		alTemp.Add(ApprovalPortalItemType.DOCUMENT_FOLDER);
		alTemp.Add(ApprovalPortalItemType.DOCUMENT_TYPE);
		alTemp.Add(ApprovalPortalItemType.EXTERNAL_OPERATION);
		alTemp.Add(ApprovalPortalItemType.FEDERATED_PORTAL);
		alTemp.Add(ApprovalPortalItemType.FILTER);
		alTemp.Add(ApprovalPortalItemType.GROUP);
		alTemp.Add(ApprovalPortalItemType.INVITATION);
		alTemp.Add(ApprovalPortalItemType.JOB);
		alTemp.Add(ApprovalPortalItemType.PAGE);
		alTemp.Add(ApprovalPortalItemType.PAGE_TEMPLATE);
		alTemp.Add(ApprovalPortalItemType.PORTLET);
		alTemp.Add(ApprovalPortalItemType.PORTLET_BUNDLE);
		alTemp.Add(ApprovalPortalItemType.PORTLET_TEMPLATE);
		alTemp.Add(ApprovalPortalItemType.PROFILE_SOURCE);
		alTemp.Add(ApprovalPortalItemType.PROPERTY);
		alTemp.Add(ApprovalPortalItemType.PROPERTYMAP);
		alTemp.Add(ApprovalPortalItemType.REMOTE_SERVER);
		alTemp.Add(ApprovalPortalItemType.SAVED_SEARCH);
		alTemp.Add(ApprovalPortalItemType.SCHEDULE);
		alTemp.Add(ApprovalPortalItemType.SITE_MAP_FOLDER);
		alTemp.Add(ApprovalPortalItemType.SUBPORTAL);
		alTemp.Add(ApprovalPortalItemType.USER);
		alTemp.Add(ApprovalPortalItemType.WEB_SERVICE);

		return alTemp;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetTitle()
	{
		return m_asOwner.GetString(1208, "ptmsgs_portaladminmsgs");
	}

	/**
	 * 
	 *
	 * @param type 
	 * @param iLow 
	 * @param iHigh 
	 *
	 * @return 
	 */
	public XPArrayList InternalGetItemDescriptors(ApprovalItemType type,
		int iLow, int iHigh)
	{
		int iSkip = iLow;
		int iMax  = (iHigh - iLow) + 1;

		ApprovalPortalItemType pType = (ApprovalPortalItemType) type;

		
			log.Debug("InternalGetItemDescriptors() - type: " + type.GetName());
			log.Debug("Entering InternalGetItemDescriptors() - iLow: " + iLow);
			log.Debug("Entering InternalGetItemDescriptors() - iHigh: " + iHigh);
			log.Debug("Entering InternalGetItemDescriptors() - iSkip: " + iSkip);
			log.Debug("Entering InternalGetItemDescriptors() - iMax: " + iMax);
		

		XPArrayList alItems = new XPArrayList();

		
			log.Debug("InternalGetItemDescriptors - about to perform query.");
		

		IPTQueryResult qr	   = null;
		IPTMigrationManager mm = GetMigrationManager();

		IPTSession ptSession = this.GetSession();

		String sMe = ptSession.GetSessionInfo().GetCurrentUserName();

		try
		{
			if (bDisplayStatusForRequestor)
			{
				qr = mm.QueryStatusForMigrationRequestor(pType.GetClassID(),
						iSkip, iMax);
			}
			else
			{
				qr = mm.QueryObjectsByStatus(pType.GetClassID(),
						PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED,
						iSkip, iMax, null);
			}
		}
		catch (Exception ex)
		{
				log.Error(ex, "Couldn't make query for classid: " + pType.GetClassID());		
		}

		if (qr != null)
		{
			String sItemName;
			int itemClassID;
			int itemObjectID;
			String sDescription;
			String sComment;
			String sSubmittedBy;
			XPDateTime submittedDate;

			ObjectItemDescriptor item;

			int iCount;

			try
			{
				iCount = qr.RowCount();

				
					log.Debug("InternalGetItemDescriptors - iCount: " + iCount);
				

				for (int x = 0; x < iCount; x++)
				{
					
						log.Debug("InternalGetItemDescriptors - x: " + x);
					

					sItemName     = qr.ItemAsString(x,
							PT_PROPIDS.PT_PROPID_NAME);

					sDescription     = qr.ItemAsString(x,
							PT_PROPIDS.PT_PROPID_DESCRIPTION);

					itemClassID     = qr.ItemAsInt(x,
							PT_PROPIDS.PT_PROPID_CLASSID);

					itemObjectID	 = qr.ItemAsInt(x,
							PT_PROPIDS.PT_PROPID_OBJECTID);

					if (!bDisplayStatusForRequestor)
					{
						//	only get submitted by if we're approving objects, not
						//	if we're getting status
						
							log.Debug("InternalGetItemDescriptors - About to get submitted by.");
						

						sSubmittedBy = qr.ItemAsString(x,
								PT_PROPIDS.PT_PROPID_MIGRATION_REQUESTOR);
					}
					else
					{
						//	if we're getting status, submitted by is current user.
						sSubmittedBy = sMe;
					}

					sComment     = (String) qr.ItemAsString(x,
							PT_PROPIDS.PT_PROPID_MIGRATION_COMMENT);

					submittedDate     = qr.ItemAsXPDateTime(x, PT_PROPIDS.PT_PROPID_MIGRATION_DATE);

					item = new ObjectItemDescriptor(sItemName, sDescription,
							sSubmittedBy, submittedDate, this.m_asOwner, type);

					if (this.bDisplayStatusForRequestor)
					{
						int iStatus = qr.ItemAsInt(x,
								PT_PROPIDS.PT_PROPID_MIGRATION_STATUS);

						String sStatus = "";

						switch (iStatus)
						{
						case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED:
						{
							sStatus = m_asOwner.GetString(540, "ptmsgs_portalcommonmsgs");

							break;
						}

						case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED:
						{
							item.Approve();
							sStatus = m_asOwner.GetString(541, "ptmsgs_portalcommonmsgs");

							break;
						}

						case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_DENIED:
						{
							item.Reject();
							sStatus = m_asOwner.GetString(543, "ptmsgs_portalcommonmsgs");

							break;
						}

						case PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_MIGRATED:
						{
							sStatus = m_asOwner.GetString(542, "ptmsgs_portalcommonmsgs");

							break;
						}
						}

						item.SetStatus(sStatus);
					}
					else
					{
						item.SetStatus( m_asOwner.GetString(540, "ptmsgs_portalcommonmsgs"));
					}

					item.SetMigrationManager(mm);
					item.SetSession(ptSession);
					item.SetClassID(itemClassID);
					item.SetObjectID(itemObjectID);

					item.SetComment(sComment);

					String strEditURL = PTOpenerLinks.GetOpenerURLOpenObjID
						(itemClassID, itemObjectID,
						IOpenerConstants.OPENER_MODE_EDIT, m_asOwner);

					item.SetEditHRef(strEditURL);

					Redirect r = new Redirect();

					r.SetLinkGetSpaceIfCached(BaseOpenerAS.STR_MVC_CLASS_NAME,
						this.m_asOwner);
					r.SetControl(BaseOpenerControl.STR_MVC_CLASS_NAME);
					r.AddControlArgument(IPTOpenerConstants.STR_QS_CLASSID,
						itemClassID);
					r.AddControlArgument(IPTOpenerConstants.STR_QS_OBJECTID,
						itemObjectID);

					item.SetEditRedirect(r);

					alItems.Add(item);
				}
			}
			catch (Exception ex)
			{				
					log.Error(ex, ex.getMessage());			
			}
		}

		return alItems;
	}

	/**
	 * 
	 *
	 * @param type 
	 *
	 * @return 
	 */
	public int InternalGetTypeCount(ApprovalItemType type)
	{
		ApprovalPortalItemType pType = (ApprovalPortalItemType) type;

		if (m_qrItemCount == null)
		{
			try
			{
				IPTMigrationManager mm = GetMigrationManager();

				if (this.bDisplayStatusForRequestor)
				{
					m_qrItemCount = mm.QueryStatusForMigrationRequestorCount();
				}
				else
				{
					m_qrItemCount = mm.QueryObjectsByStatusCount(PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED,
							null);
				}
			}
			catch (Exception ex)
			{
				return 0;
			}
		}

		int iResultCount = m_qrItemCount.RowCount();
		int iClassID     = pType.GetClassID();

		int iCount = 0;

		for (int x = 0; x < iResultCount; x++)
		{
			int i = m_qrItemCount.ItemAsInt(x, PT_PROPIDS.PT_PROPID_CLASSID);

			if (i == iClassID)
			{
				//	found the correct row.
				
					log.Debug("Found count for type: " + type.GetName());
				

				iCount = m_qrItemCount.ItemAsInt(x,
						PT_PROPIDS.PT_PROPID_OBJECTCOUNT);
			}
		}

		return iCount;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsDateSortable()
	{
		return false;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsDescriptionEditable()
	{
		return false;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsNameSortable()
	{
		return false;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsSubmittedBySortable()
	{
		return false;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsTitleEditable()
	{
		return false;
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @param b 
	 */
	public void SetDisplayStatusForRequestor(boolean b)
	{
		if (bDisplayStatusForRequestor != b)
		{
			//	if it's changing, make sure we clear all cached data.
			this.ClearCache();
		}

		bDisplayStatusForRequestor = b;
	}

	// ***CHANGE_HERE*** Implement one method per DP to save it
	// BEGIN ***************** save DP methods ***************** 

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
	}

	/**
	 * 
	 *
	 * @return 
	 */
	private IPTMigrationManager GetMigrationManager()
	{
		if (m_ptMM == null)
		{
			m_ptMM = (IPTMigrationManager) GetSession().OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_MIGRATION_MANAGER,
					false);
		}

		return m_ptMM;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	private IPTSession GetSession()
	{
		if (m_ptSession == null)
		{
			m_ptSession = (IPTSession) m_asOwner.GetUserSession();
		}

		return m_ptSession;
	}
}

