package com.plumtree.portalpages.common.objectapproval;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.approval.*;
import com.plumtree.uiinfrastructure.errordisplay.*;

/**
 * @author Ben Geislinger
 *
 */
public class ObjectItemDescriptor extends AItemDescriptor
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.objectapproval.ObjectItemDescriptor");

	private IPTMigrationManager migrationManager = null;
	private IPTSession session = null;
	private String sStatus = "";
	private int iClassID   = -1;
	private int iNewStatus = 0;
	private int iObjectID  = -1;

	/**
	 * Creates a new ObjectItemDescriptor object.
	 *
	 * @param name 
	 * @param description 
	 * @param submittedBy 
	 * @param submittedDate 
	 * @param space 
	 * @param type 
	 */
	public ObjectItemDescriptor(String name, String description,
		String submittedBy, XPDateTime submittedDate, AActivitySpace space,
		ApprovalItemType type)
	{
		super(name, description, submittedBy, submittedDate, space, type);
		iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVAL_REQUESTED;
	}

	/**
	 * 
	 */
	public void Execute()
	{
		
			log.Debug("Execute() - " + this.GetName());
			log.Debug("Execute() - iNewStatus: " + iNewStatus);
			log.Debug("Execute() - classid: " + this.GetClassID());
			log.Debug("Execute() - objectid: " + this.GetObjectID());
		

		if (GetApprove())
		{
			iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_APPROVED;
		}

		if (GetReject())
		{
			iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_DENIED;
		}

		if (GetClear())
		{
			iNewStatus = PT_MIGRATION_STATUS_TYPES.PT_MIGRATION_STATUS_NONE;
		}

		if (migrationManager == null)
		{
			
				log.Error("MigrationManager is null.");
			

			return;
		}

		try
		{
			int[] iaTemp = new int[1];
			iaTemp[0] = this.GetObjectID();

			String sComment = this.GetComment();

			
				log.Debug("Execute() - About to set the status on: " +
					this.GetName());
				log.Debug("Execute() - with comment: " + sComment);
			

			migrationManager.BulkSetMigrationStatus(this.GetClassID(), iaTemp,
				iNewStatus, GetComment());
		}
		catch (Exception ex)
		{
			log.Error(ex, "Couldn't approve object.");

			UIError myError = new UIError(UIErrorLevel.SERIOUS,
					UIErrorScope.CURRENT_USER, "Couldn't execute object.",
					ex.getMessage());

			myError.SetActivitySpace(mySpace.GetName());
			myError.SetClearWithActivitySpaceChange(true);

			UIErrorHandler.RaiseError(myError, mySpace.GetSubSession(),
				mySpace.GetApplication());
		}
		
		
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetClassID()
	{
		return iClassID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetObjectID()
	{
		return iObjectID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetStatus()
	{
		return sStatus;
	}

	/**
	 * 
	 *
	 * @param i 
	 */
	public void SetClassID(int i)
	{
		iClassID = i;
	}

	/**
	 * 
	 *
	 * @param mm 
	 */
	public void SetMigrationManager(IPTMigrationManager mm)
	{
		migrationManager = mm;
	}
	
	public void SetSession( IPTSession s )
	{
		session = s;
	}

	/**
	 * 
	 *
	 * @param i 
	 */
	public void SetObjectID(int i)
	{
		iObjectID = i;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	public void SetStatus(String s)
	{
		sStatus = s;
	}
}

