package com.plumtree.portalpages.common.objects;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public interface IObjectModelRO extends IModelRO
{
	/**
	 * Get whether to show this object or not.
	 *
	 * @param int nIndex
	 * @return boolean true implies object is hidden, false implies show object
	 */
	public boolean DoNotShowObject(int nIndex);

	/**
	 * Get whether or not to display the hidden inputs needed by the PaginationControl.
	 * This is only useful if GetShowPagination() returns true.
	 *
	 * @see com.plumtree.uiinfrastructure.form.pagination.PaginationControl.
	 *
	 * @return boolean true implies display hidden inputs
	 */
	public boolean GetDisplayPaginationHiddenInputs();

	/**
	 * Get whether or not to display the hidden inputs needed by the SortControl.
	 * This is only useful if GetSortable() returns true.
	 *
	 * @see com.plumtree.uiinfrastructure.form.sort.SortControl.
	 *
	 * @return boolean true implies display hidden inputs
	 */
	public boolean GetDisplaySortHiddenInputs();

	/**
	 * Gets the count of the object headers. Returns 0 if the array is null.
	 *
	 * @return int nHeaderCount
	 */
	public int GetHeaderCount();

	/**
	 * Returns whether the header has a checkbox or not.
	 *
	 * @return boolean
	 */
	public boolean GetHeaderHasCheckbox();

	/**
	 * Returns the header row
	 *
	 * @return int nHeaderCount
	 */
	public HTMLTableRow GetHeaderRow();

	/**
	 * Gets the text of the header at the given index.
	 *
	 * @param nHeaderIndex nHeaderIndex
	 *
	 * @return String strHeaderText
	 */
	public String GetHeaderText(int nHeaderIndex);

	/**
	 * Gets whether or not the object banner should be collapsable.
	 *
	 * @return boolean true implies collapsible.
	 */
	public boolean GetIsCollapsable();

	/**
	 * This method returns whether or not the requested object ID is
	 * currently selected.
	 *
	 * @return boolean true implies selected, false implies not selected
	 */
	public boolean GetIsObjectSelected(int nObjectID);

	/**
	 * Gets the name of the current folder.
	 *
	 * @return String strCurrentFolderName
	 */
	public String GetObjectBannerTitle();

	/**
	 * Gets the number of columns of objects
	 *
	 * @return int nColumnCount
	 */
	public int GetObjectColumnCount();

	/**
	 * Gets the count of the objects in the query result.
	 *
	 * @return int nObjectCount
	 */
	public int GetObjectCount();

	/**
	 * Gets the fields from the query result.
	 *
	 * @param nIndex nIndex
	 * @param nPropID nPropID
	 *
	 * @return Object oFields
	 */
	public Object GetObjectFields(int nIndex, int nPropID);

	/**
	 * Get the Object Class ID of the type of objects we are currently viewing.
	 *
	 * @return int the class ID of the object
	 */
	public int GetObjectType();

	/**
	 * Get the subtype of the object at the given index.
	 * 
	 * @param nIndex index of the object in the list.
	 * 
	 * @return the subtype of the object, or -1 if the object has no subtype.
	 */
	public int GetObjectSubType(int nIndex) ;

	/**
	 * Get whether the object view is collapsed.
	 *
	 * This is only relevant if GetIsCollapsable() returns true.
	 *
	 * @return bObjectViewIsCollapsed
	 */
	public boolean GetObjectViewIsCollapsed();

	/**
	 * Get whether these objects should use pagination or not.  If this is true, the
	 * header will have a pagination bar.
	 *
	 * If this is true, the AActivitySpace will need to include the pagination
	 * framework (pass-thru repost control & implement pagination model interface).
	 *
	 * @see com.plumtree.uiinfrastructure.form.pagination.IPaginationModel
	 *
	 * @see com.plumtree.portalpages.common.objects.ObjectView
	 *
	 * @return boolean true implies show pagination bar
	 */
	public boolean GetShowPagination();

	/**
	 * Get whether these objects are sortable or not.  If this is true, the
	 * headers will be sortable.
	 *
	 * If this is true, the AActivitySpace will need to include the sortable
	 * framework (pass-thru repost control & implement sortable model interface).
	 *
	 * @see com.plumtree.uiinfrastructure.form.sort.ISortModel
	 *
	 * @see com.plumtree.portalpages.common.objects.ObjectView
	 *
	 * @return boolean true implies sortable
	 */
	public boolean GetSortable();

	/**
	 * Get the Space ID of this models AS
	 *
	 * @return String m_asOwner.GetSpaceID()
	 */
	public String GetSpaceID();


	/**
	 * Get whether to show the banner or not.
	 *
	 * @return boolean true implies show banner
	 */
	public boolean ShowObjectBanner();
}

