package com.plumtree.portalpages.common.objects;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * 
 *
 * @author michaeld
 */
public interface IObjectViewHelper
{
	/**
	 * Returns additional HTML as an html element for the object view to display.
	 *
	 * @param model
	 * @return HTMLElement
	 */
	public HTMLElement AddObjectViewHTML(IObjectModelRO model);

	/**
	 * Displays the object in 508 mode at the given index in the query result. This must be
	 * overridden by all subclasses.
	 *
	 * @param nObjectIndex nObjectIndex
	 * @param tableObjects tableObjects
	 * @param model 
	 */
	public void Display508Object(int nObjectIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace parent);

	/**
	 * Returns the javascript for this view helper.
	 *
	 * @param asOwner
	 * @param model
	 * @return HTMLScriptCollection
	 */
	public HTMLScriptCollection DisplayJavascriptCollection(
		AActivitySpace asOwner, IObjectModelRO model);

	/**
	 * Displays the object at the given index in the query result. This must be
	 * overridden by all subclasses. nRowIndex is used to determine which StyleClass to use.
	 *
	 * @param nObjectIndex nObjectIndex
	 * @param nObjectIndex nRowIndex	
	 * @param tableObjects tableObjects
	 * @param model 
	 */
	public void DisplayObject(int nObjectIndex, int nRowIndex, HTMLTable tableObjects,
		IObjectModelRO model, AActivitySpace parent);

	/**
	 * This method is called by the ObjectView to fill out the anchor for the
	 * expand / collapse links on the object view header.
	 *
	 * @param HTMLAnchor the anchor to be filled out.
	 * @param IObjectModelRO the model
	 */
	public void SetExpandAnchor(HTMLAnchor anchor, IObjectModelRO model);
	
	/**
	 * Return the message to display if there are no items.  Return an empty
	 * string if you want to use the default.
	 *
	 * @return String
	 */
	public String GetThereAreNoItemsString(AActivitySpace asOwner);

	
}

