package com.plumtree.portalpages.common.passwordvalidation;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.statichelpers.*;

/**
 * This class defines constants and helper methods used in the CreateAccountView and PasswordView classes. 
 * Some if not all of the constants are used to generate JS constants that will be used for the client-side 
 * password validation on the Create Account and Change Account Password pages.
 * 
 * @author BobbyT 
 */
public class PasswordValidationHelper 
{
	/** Javascript function: doCreateAccountS, function used in CreateAccountView */
	public static final String STR_JS_CREATE_ACCOUNT = "PasswordValidation.doCreateAccount";
	
	/** Javscript function: handleUserInput, function used in CreateAccountView and PasswordView */
	public static final String STR_JS_HANDLE_USER_INPUT = "PasswordValidation.handleUserInput";
	
	/** Javscript function: handleBackspaceInput, function used in CreateAccountView and PasswordView */
	public static final String STR_JS_HANDLE_BACKSPACE_INPUT = "PasswordValidation.handleBackspaceInput";
	
	/** Javscript function: checkPassword, validation function used in PasswordAS/PasswordView */
	public static final String STR_JS_CHECK_PASSWORD = "PasswordValidation.checkPassword";

	/**
	 * Javascript file that will be included on server side for client-side validation.
	 */
	public final static String STR_PW_VALIDATION_JS = "ptpasswordvalidation.js";
	
	/** 
	 * The following Javscript Constants will be used to generate JS on the server-side which 
	 * will be consumed by client-side validation on the Create Account and Change Account 
	 * Password pages. These constants will be used in ptpasswordvalidation.js. 
	 */	
	public static final String STR_PASSWORD_VALIDATION_JS_NAMESPACE = "PWValidationJSConstants";
	
	/**
	 * Current username of the user logged in. This constant is used when performing
	 * validation on the Change Password page.
	 */
	public static final String STR_CURRENT_USERNAME = "CURRENT_USERNAME";
	
	/** 
	 * Password Management Rules Settings
	 */
	public static final String STR_PASSWORD_MIN_LENGTH = "PASSWORD_MIN_LENGTH";	
	public static final String STR_PASSWORD_MAX_LENGTH = "PASSWORD_MAX_LENGTH";	
	public static final String STR_PASSWORD_INCLUDE_NUMBERS = "PASSWORD_INCLUDE_NUMBERS";	
	public static final String STR_PASSWORD_INCLUDE_CASING = "PASSWORD_INCLUDE_CASING";	
	public static final String STR_PASSWORD_INCLUDE_PUNCTUATION = "PASSWORD_INCLUDE_PUNCTUATION";	
	public static final String STR_PASSWORD_NO_USER_IDS = "PASSWORD_NO_USER_IDS";
	
	/**
	 * i18n strings used for Create Account and Change Password Pages
	 */
	public static final String PASSWORDS_MUST_BE_SAME_I18N = "PASSWORDS_MUST_BE_SAME_I18N"; /* 2001 */
	public static final String PASSWORDS_MIN_LENGTH_I18N = "PASSWORDS_MIN_LENGTH_I18N"; /* 2002 */
	public static final String ENTER_USERNAME_I18N = "ENTER_USERNAME_I18N"; /* 2003 */
	public static final String ENTER_OLD_PASSWORD_I18N = "ENTER_OLD_PASSWORD_I18N"; /* 2004 */
	public static final String PASSWORD_TOO_SHORT_I18N = "PASSWORD_TOO_SHORT_I18N"; /* 1628 */
	public static final String PASSWORD_TOO_LONG_I18N = "PASSWORD_TOO_LONG_I18N"; /* 1291 */
	public static final String NO_BLANK_SPACES_I18N = "NO_BLANK_SPACES_I18N"; /* 2005 */
	public static final String MUST_CONTAIN_UPPER_LOWER_CASE_I18N = "MUST_CONTAIN_UPPER_LOWER_CASE_I18N"; /* 1983 */
	public static final String MUST_CONTAIN_NUMBER_I18N = "MUST_CONTAIN_NUMBER_I18N"; /* 1984 */
	public static final String MUST_CONTAIN_PUNCTUATION_I18N = "MUST_CONTAIN_PUNCTUATION_I18N"; /* 1985 */
	public static final String CANNOT_CONTAIN_USER_ID_I18N = "CANNOT_CONTAIN_USER_ID_I18N"; /* 1982 */
	public static final String PASSWORD_VALID_I18N = "PASSWORD_VALID_I18N";
	
	/**
	 * UI Elements that appear on the Create Account and Change Password Views
	 */
	public static final String STR_MIN_MAX_LENGTH_STATUS_ID = "MIN_MAX_LENGTH_STATUS_ID";
	public static final String STR_MIN_MAX_LENGTH_STATUS_NAME = "minMaxLengthStatusId";
	
	public static final String STR_NUMBER_STATUS_ID = "NUMBER_STATUS_ID";
	public static final String STR_NUMBER_STATUS_NAME = "numberStatusId";
	
	public static final String STR_LOWER_UPPER_CASE_STATUS_ID = "LOWER_UPPER_CASE_STATUS_ID";
	public static final String STR_LOWER_UPPER_CASE_STATUS_NAME = "lowerUpperCaseStatusId";
	
	public static final String STR_PUNCTUATION_STATUS_ID = "PUNCTUATION_STATUS_ID";
	public static final String STR_PUNCTUATION_STATUS_NAME = "punctuationStatusId"; 
	
	public static final String STR_USERNAME_STATUS_ID = "USERNAME_STATUS_ID";
	public static final String STR_USERNAME_STATUS_NAME = "usernameStatusId";
	
	public static final String STR_INPUT_USERNAME_ID = "USERNAME_INPUT_ID";	
	public static final String STR_INPUT_OLD_PASSWORD_ID = "OLD_PASSWORD_INPUT_ID";	
	public static final String STR_INPUT_NEW_PASSWSORD_ID = "NEW_PASSWORD_INPUT_ID";	
	public static final String STR_INPUT_CONFIRM_PASSWORD_ID = "CONFIRM_PASSWORD_INPUT_ID";
	
	public static final String STR_INPUT_USERNAME_VALIDATION_STATUS_ID = "USERNAME_VALIDATION_STATUS_ID";
	public static final String STR_USERNAME_VALIDATION_STATUS_NAME = "usernameValidationStatus";
	
	public static final String STR_INPUT_PASSWORD_VALIDATION_STATUS_ID = "PASSWORD_VALIDATION_STATUS_ID";
	public static final String STR_PASSWORD_VALIDATION_STATUS_NAME = "passwordValidationStatus";
	
	public static final String STR_INPUT_OLD_PASSWORD_VALIDATION_STATUS_ID = "OLD_PASSWORD_VALIDATION_STATUS_ID";
	public static final String STR_OLD_PASSWORD_VALIDATION_STATUS_NAME = "oldPasswordValidationStatus";
	
	public static final String STR_CREATE_ACCOUNT_FORM_ID = "FORM_ID";	
	public static final String STR_INPUT_DOCREATE_ID = "DOCREATE_INPUT_ID";
	
	public static final String STR_VALID_ICON_URL = "VALID_ICON_URL";	
	public static final String STR_VALID_ICON_FILENAME = "icon_pw_rule_valid.gif";
	public static final String STR_INVALID_ICON_URL = "INVALID_ICON_URL";	
	public static final String STR_INVALID_ICON_FILENAME = "icon_pw_rule_invalid.gif";
	public static final String STR_WARNING_ICON_FILENAME = "icon_pw_rule_warning.gif";
	
	// START *************** Helper methods **********************
	/**
	 * Gets the URL of the javascript used for client-side validation.
	 * @param owner AActivitySpace
	 * @return String URL of the js file.
	 */
	public static String GetPasswordValidationJSURL(AActivitySpace owner)
	{
		// Following will generate "http://hostname:port/imageserver/plumtree/portal/private/js/ptpasswordvalidation.js" 
		String strImgSrvURL = ConfigHelper.GetPortalImageServerConnectionURL(owner);
		String strFwdSlash = "/";

		XPStringBuilder sb = new XPStringBuilder();
		sb.Append(strImgSrvURL);
		if (XPStringUtility.CharAt(strFwdSlash,0) != sb.CharAt(sb.GetLength()-1))
		{
			sb.Append(strFwdSlash);
		}
		sb.Append(ImgSvrURLHelper.STR_L1_DOMAIN_PLUMTREE);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L2_PRODUCT_NAME_PORTAL);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L3_SCOPE_PRIVATE);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L4_FILE_TYPE_JS);
		sb.Append(strFwdSlash);
		sb.Append(PasswordValidationHelper.STR_PW_VALIDATION_JS);

		return sb.ToString();
	}
	
	/**
	 * Gets the URL of the portal imageserver folder.
	 * @param owner @param owner AActivitySpace
	 * @return String URL to the portal imageserver folder.
	 */
	public static String GetPortalImageServerFolderURL(AActivitySpace owner)
	{
		String strImgSrvURL = ConfigHelper.GetPortalImageServerConnectionURL(owner);
		String strFwdSlash = "/";

		XPStringBuilder sb = new XPStringBuilder();
		sb.Append(strImgSrvURL);
		if (XPStringUtility.CharAt(strFwdSlash,0) != sb.CharAt(sb.GetLength()-1))
		{
			sb.Append(strFwdSlash);
		}
		sb.Append(ImgSvrURLHelper.STR_L1_DOMAIN_PLUMTREE);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L2_PRODUCT_NAME_PORTAL);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L3_SCOPE_PUBLIC);
		sb.Append(strFwdSlash);
		sb.Append(ImgSvrURLHelper.STR_L4_FILE_TYPE_IMG);
		sb.Append(strFwdSlash);

		return sb.ToString();
	}
	// END *************** Helper methods **********************
}
