/*
 * Created on Mar 5, 2003
 */
package com.plumtree.portalpages.common.plugnav;

import com.plumtree.portaluiinfrastructure.compoundlist.*;

/**
 * Delegates model methods only usable by community page.
 * 
 * @author DavidP
 */
public interface ICommunityNavPageRO extends INavigationPageRO
{
	/**
	 * Checks for at least read access to the specified Community,
	 * If current user lacks access, get the user's default Community and
	 * user has no default communities, return -1.
	 * @param nCommID		ID of the Community to check access to
	 * @return int			Returns an accessible Community for the current user or -1 if none can be found
	 */
	public int GetAccessibleCommunityID(int nSubPortalCommID);

	/**
	 * Gets the id of the current Community 
	 * @return Object ID of the current Community 
	 */
	public int GetCurCommunityID();

	/**
	 * Gets the name of the current Community 
	 * @return Name of the current Community
	 */
	public String GetCurCommunityName();

	/**
	 * Gets the Communities on the same level as the current community.
	 *
	 * @return Links to the the current community's related communities
	 */
	public ICPListEntryIterator GetCurRelCommunities();

	/**
	 * Gets the subcommunities of the current community.
	 *
	 * @return Links to the subcommunities of the current community
	 */
	public ICPListEntryIterator GetCurSubCommunities();

	/**
	 * Gets the default Community ID of the current user, i.e.
	 * first Community in the membership list.
	 * 
	 * @return Object ID of the default Community
	 */
	public int GetDefaultCommunity();

	/**
	 * Helper function, returns the join community link, community actions if on
	 * a community page and the list of communities.
	 *
	 * @param bListActions		True to return the community actions in the list, false otherwise
	 * @return  				Communities the current user is a member of in a ICPListEntryIterator
	 */
	public ICPListEntryIterator GetMyCommunities(boolean bListActions);

	/**
	 * Gets the parent community of the current Community
	 *
	 * @return The link to the parent community of the current Community
	 */
	public ICPListEntryIterator GetParentComm();

	/**
	 * Checks if the current user is the owner of the current Community
	 *
	 * @return True if the current user is the owner of the current Community
	 */
	public boolean IsCurCommOwner();
	
	/**
	 * Get the community ID of the community we are currently viewing.
	 *
	 * @return Object ID of the current Community
	 */
	public int GetCommunityID();
	
	/**
	 * Checks if the current user can join the current Community
	 *
	 * @return True if the current user can join the current Community
	 */
	public boolean CanJoinCurCommunity();
}

