/*
 * Created on Mar 7, 2003
 */
package com.plumtree.portalpages.common.plugnav;

import com.plumtree.portaluiinfrastructure.compoundlist.*;

/**
 * Community preview page specific functions
 * @author DavidP
 */
public interface ICommunityPreviewNavPageRO extends INavigationPageRO 
{
	/**	
	 * Unique String Name of category of object.  Critical for link blocking by pluggable nav.
	 */
	public String GetName();
	
	/**
	 * Checks for at least read access to the specified Community,
	 * If current user lacks access, get the user's default Community and
	 * user has no default communities, return -1.
	 * @param nCommID		ID of the Community to check access to
	 * @return int			Returns an accessible Community for the current user or -1 if none can be found
	 */
	public int GetAccessibleCommunityID(int nSubPortalCommID);

	/**
	 * Gets the ID of the current Community (if in one)
	 * @return Object ID of the current Community
	 */
	public int GetCurCommunityID();

	/**
	 * Gets the name of the current Community 
	 * @return Name of the current Community
	 */
	public String GetCurCommunityName();

	/**
	 * Gets the Communities on the same level as the current community.
	 *
	 * @return Links to the the current community's related communities
	 */
	public ICPListEntryIterator GetCurRelCommunities();

	/**
	 * Gets the subcommunities of the current community.
	 *
	 * @return Links to the subcommunities of the current community
	 */
	public ICPListEntryIterator GetCurSubCommunities();

	/**
	 * Gets the default Community ID of the current user, i.e.
	 * first Community in the membership list.
	 * 
	 * @return Object ID of the default Community
	 */
	public int GetDefaultCommunity();

	/**
	 * Helper function, returns the join community link, community actions if on
	 * a community page and the list of communities.
	 *
	 * @param bListActions
	 * @return ICPListEntryIterator
	 */
	public ICPListEntryIterator GetMyCommunities(boolean bListActions);

	/**
	 * Gets the parent community of the current Community
	 *
	 * @return The link to the parent community of the current Community
	 */
	public ICPListEntryIterator GetParentComm();

	/**
	 * Checks if the current user is the owner of the current Community
	 *
	 * @return True if the current user is the owner of the current Community
	 */
	public boolean IsCurCommOwner();
}

