/** Created on Feb 28, 2003
 */
package com.plumtree.portalpages.common.plugnav;

import com.plumtree.portalpages.common.uiparts.navpagetype.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This interface offers the pluggable navigation developer all the 
 * functionality they need to build pluggable navigation views.
 * 
 * @author DavidP
 */
public interface IPluggableNavModelRO extends IModelRO 
{
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create();

	/**
	 * Gets the link to the My Account settings page
	 *
	 * @return Link to My Account settings page in an ICPListEntryIterator
	 */
	public ICPListEntryIterator GetPortalSettings();

	/**
	 * Gets visibility of the specified vertical navigation section
	 * 
	 * @param nSectionIDConst	NavVisibility ID of the section to check visibility on 
	 * @return 					True if the specified section is visibile
	 * @see NavVisibility 
	 */
	public boolean GetSectionVisibility(int nSectionIDConst);
	
	/**
	 * Gets the internationalized string for the title on the category.
	 * 
	 * @param linkType  NavCategoryType  
	 * @return			Title String for the specified NavCategoryType 
	 * @see NavCategoryType
	 */
	public String GetCategoryTitle(NavCategoryType linkType);
	
	/**
	 * Get the name of the subsection title; basically, actions for mypage and communities only.
	 * 
	 * @param linkType		NavCategoryType
	 * @param 				boolean actions true or false
	 * 
	 * @return String category name for link title
	 * @see NavCategoryType
	 */
	public String GetSubsectionTitle(NavCategoryType linkType, boolean bAction);

	/**
	 * Gets the header for this page from the Subportal.  Returns 
	 * default header if no header portlet assigned.
	 * 
	 * @return HTMLElement with the footer set in the Subportal
	 */
	public HTMLElement GetSubportalBanner();

	/**
	 * Gets the footer for this page from the Subportal.  Returns 
	 * default footer if no footer portlet assigned.
	 *
	 * @return HTMLElement with the footer set in the Subportal 
	 */
	public HTMLElement GetSubportalFooter();

	/**
	 * Checks if the user has admin access rights or not.
	 * 
	 * @return True if the current user has Administrator access to the current Community
	 */
	public boolean HasAdministratorAccess();

	/**
	 * Checks if the current user has at least select access to the current Community
	 *
	 * @return boolean
	 * @see com.plumtree.server.PT_ACCESS_LEVELS
	 */
	public boolean HasSelectAccess();

	/**
	 * Checks if logged in as guest or not.
	 *
	 * @return true if guest
	 */
	public boolean IsGuestSession();

	/**
	 * Sets visibility on vertical navigation sections
	 * 
	 * @param nSectionIDConst		NavVisibility ID of the section to set visibility on
	 * @param bShow					True of the section is visible
	 * @see NavVisibility
	 */
	public void SetSectionVisibility(int nSectionIDConst, boolean bShow);
	
	/**
	 * Checks if the specified feature is enabled in the current subportal.
	 * 
	 * @param nType			NavVisibility Section ID
	 * @return boolean		True if the specified section is visible
	 * @see NavVisibility
	 */
	public boolean GetSubPortalEnabled(int nType);
	
	/**
	 * Used by pluggable navigation to access the model specific 
	 * to the page we're on (see GetCurNavPage())
	 * 
	 * @return The current NavigationPage interface
	 * @see NavigationPage
	 * @see NavPageType 
	 */
	public NavigationPage GetPageSpecificMethods();
	
	/**
	 * Gets the current page type.
	 * 
	 * @return NavPageType
	 * @see NavPageType
	 */
	public NavPageType GetCurNavPageType();

	/**
	 * Gets a user's defeault community id, (right now the first community
	 * in mycommunities)
	 * 
	 * @return The default Community ID
	 */
	public int GetDefaultCommunity();

	/**
	 * Checks for at least read access to the specified Community,
	 * If current user lacks access, get the user's default Community and
	 * user has no default communities, return -1.
	 * @param nCommID		ID of the Community to check access to
	 * @return int			Returns an accessible Community for the current user or -1 if none can be found
	 */
	public int GetAccessibleCommunityID(int nCommID);
	

	/**
	 * Get folder name for mandatory links
	 * 
	 * @return String
	 */
	//public String GetMandatoryLinksFolderName();	

	/**
	 * Get the links lists by category, with or without actions
	 * 
	 * @param linkType				NavCategoryType
	 * @param getActions			True to include actions
	 * @return 						ICPListEntryIterator with the links of the requested NavCategoryType	
	 * @see NavCategoryType
	 */
	public ICPListEntryIterator GetCategoryLinks(NavCategoryType linkType,boolean getActions);
	
	/**
	 * Checks if the current page is a Edit Default Profile Editor page
	 *
	 * @return 					boolean
	 */
	public boolean IsEditProfile();
}


