package com.plumtree.portalpages.common.search;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.admin.editors.group.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author sample
 *
 *     This class generates html necessary to construct a table
 *  containing DIVs of table rows that are revealed and
 *    hidden from the last visible row of the table.
 *
 *     A total of five calls will generate all of the necessary
 *     elements:
 *
 *     1) SetBlankQueryCondition(QueryCondition)  // defines the row template
 *  2) generateTable (numberOfRows)    // gets a table of hidden rows
 *     3) getJavaScriptFunctions() // gets necessary script elements
 *  4) getAddConditionButton(strAdd) // button to reveal a row
 *  5) getRemoveLastConditionButton(strRemove)  // button to hide last row
 *
 *     The "Add Condition" and "Remove Last Condition" buttons
 *     must be retrieved with separate calls.
 *
 */
public class DynamicQueryTable implements IFilterQueryTable
{
	private AActivitySpace m_asOwner;
	private QueryCondition m_BlankQC				  = null;
	private HTMLElement m_heExtraRow		  = null;
  private boolean m_bHideGroupHeader = false;
	private String m_strLabel;
	private String m_strName;
	private XPArrayList m_listDefinedRows = null;
	private boolean m_bAndOperator			 = true;
	private boolean m_bSuppressCheckbox		 = false;
	private boolean m_bUseVerboseTerminology = false;
	private int m_Depth = 0;
	private int m_Rows  = 0;
	

	/**
	 * Creates a new DynamicQueryTable object.
	 *
	 * @param strName 
	 * @param Depth 
	 * @param owner 
	 */
	public DynamicQueryTable(String strName, int Depth, AActivitySpace owner)
	{
		m_asOwner	   = owner;
		m_Depth		   = Depth;
		m_strName	   = strName;
		m_Rows		   = 0;
		m_strLabel     = null;
	}

	/**
	 * 
	 *
	 * @param bOperator 
	 */
	public void SetAllMustPass(boolean bOperator)
	{
		m_bAndOperator = bOperator;
	}

	/**
	 * 
	 *
	 * @param qc 
	 */
	public void SetBlankQueryCondition(QueryCondition qc)
	{
		qc.SetVisible(false);
		m_BlankQC = qc;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	public void SetExtraRowBelowGroupHeader(String s)
	{
		m_heExtraRow = new HTMLGenericElement(s);
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	public void SetExtraRowBelowGroupHeader(HTMLElement e)
	{
		m_heExtraRow = e;
	}

	public void SetHideGroupHeaderRow(boolean hide) {
		m_bHideGroupHeader = hide;
	}

	/**
	 * 
	 *
	 * @param label 
	 */
	public void SetLabel(String label)
	{
		m_strLabel = label;
	}

	/**
	 * 
	 *
	 * @param b 
	 */
	public void SetSuppressCheckbox(boolean b)
	{
		m_bSuppressCheckbox = b;
	}

	/**
	 * 
	 *
	 * @param nRows 
	 */
	public void SetTableSize(int nRows)
	{
		if ((nRows > 0) && (m_Rows == 0))
		{
			m_Rows = nRows;
		}
		else
		{
			throw new XPException(
				"Row count must be greater than zero and cannot be set more than once.");
		}
	}

	/**
	 * 
	 *
	 * @param b 
	 */
	public void SetUseVerboseTerminology(boolean b)
	{
		m_bUseVerboseTerminology = b;
	}

	/**
	 * 
	 *
	 * @param strActiveClause 
	 * @param groupCount 
	 * @param result 
	 *
	 * @throws Exception 
	 */
	public static void AddGlobalElements(String strActiveClause,
		int groupCount, HTMLElementCollection result)
	{
	    AddGlobalElements("", strActiveClause, groupCount, result);
	}

	/**
	 * 
	 *
	 * @param strActiveClause 
	 * @param groupCount 
	 * @param result 
	 *
	 * @throws Exception 
	 */
	public static void AddGlobalElements(String prefix, String strActiveClause,
		int groupCount, HTMLElementCollection result)
	{
		HTMLInput activeClause = new HTMLInput(HTMLInputTypes.HIDDEN,
				"in_hi_activeclause"+prefix, "");
		activeClause.SetID("activeclause");
		activeClause.SetValue(strActiveClause);
		result.AddInnerHTMLElement(activeClause);

		HTMLInput groupAction = new HTMLInput(HTMLInputTypes.HIDDEN,
				"in_hi_groupaction"+prefix, "");
		groupAction.SetID("groupaction");
		groupAction.SetValue("");
		result.AddInnerHTMLElement(groupAction);

		HTMLInput totalGroups = new HTMLInput(HTMLInputTypes.HIDDEN,
				"in_hi_totalgroups"+prefix, "");
		totalGroups.SetID("totalgroups");
		totalGroups.SetValue(XPConvert.ToString(groupCount));
		result.AddInnerHTMLElement(totalGroups);
		
		HTMLInput groupChooserRow = new HTMLInput(HTMLInputTypes.HIDDEN,
				QueryCondition.HTMLHIDDEN_ROWINDEX+prefix, "");
		groupChooserRow.SetID(QueryCondition.HTMLHIDDEN_ROWINDEX_ID);
		result.AddInnerHTMLElement(groupChooserRow);
	}

	/**
	 * 
	 *
	 * @param searchstring 
	 * @param AllMustPass 
	 * @param result 
	 *
	 * @throws Exception 
	 */
	public static void AddTopLevelSearchBoxAndOperator(String searchstring,
		boolean AllMustPass, HTMLElementCollection result, String strLang)
	{
		AddTopLevelSearchBoxAndOperator(searchstring, AllMustPass, false, null,
			result, strLang);
	}

	/**
	 * 
	 *
	 * @param searchstring 
	 * @param AllMustPass 
	 * @param useVerboseTerminology 
	 * @param textboxLabel 
	 * @param result 
	 *
	 * @throws Exception 
	 */
	public static void AddTopLevelSearchBoxAndOperator(String searchstring,
		boolean AllMustPass, boolean useVerboseTerminology,
		HTMLElement textboxLabel, HTMLElementCollection result, String strLang)

	{
		HTMLTable myTable = new HTMLTable();
		result.AddInnerHTMLElement(myTable);

		myTable.SetWidth("100%");
		myTable.SetBorder("0");
		myTable.SetCellPadding("5");
		myTable.SetCellSpacing("0");

		HTMLTableRow textSearchRow = new HTMLTableRow();
		//HTMLTableRow operatorRow   = new HTMLTableRow();
		myTable.AddInnerHTMLElement(textSearchRow);
		//myTable.AddInnerHTMLElement(operatorRow);
		textSearchRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);
		//operatorRow.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

		HTMLTableCell textCell = new HTMLTableCell();
		HTMLTableCell opCell   = new HTMLTableCell();
		textSearchRow.AddInnerHTMLElement(textCell);
		textSearchRow.AddInnerHTMLElement(opCell);

		if (null == textboxLabel)
		{
			textCell.SetAlign("left");
			textCell.SetNoWrap(true);
			opCell.SetAlign("left");
			opCell.SetWidth("100%");
		}

		HTMLInput input = new HTMLInput(HTMLInputTypes.TEXT_TYPE,
				"in_tx_fulltext", "");
		input.SetValue(searchstring);
		input.SetStyleClass(PTStyleClass.FORM_INPUT_BOX_TEXT);
		input.SetSize(40);
		textCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);

			IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
			XPResourceManager rm     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

		if (null != textboxLabel)
		{
			textCell.AddInnerHTMLElement(textboxLabel);
		}
		else
		{

			textCell.AddInnerHTMLString(rm.GetString(605, "ptmsgs_portalcommonmsgs", strLang));
		}

		textCell.AddInnerHTMLElement(input);

		HTMLInput andRB = new HTMLInput(HTMLInputTypes.RADIO,
				"in_ra_topoperator", "");
		andRB.SetValue("and");
		andRB.SetChecked(AllMustPass);
		opCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
		opCell.AddInnerHTMLElement(andRB);

		if (useVerboseTerminology)
		{
			opCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			opCell.AddInnerHTMLString(rm.GetString(609, "ptmsgs_portalcommonmsgs", strLang));
			opCell.AddInnerHTMLElement(new HTMLBr());
		}
		else
		{
			opCell.AddInnerHTMLString(rm.GetString(607, "ptmsgs_portalcommonmsgs", strLang));
		}

		HTMLInput orRB = new HTMLInput(HTMLInputTypes.RADIO,
				"in_ra_topoperator", "");
		orRB.SetValue("or");
		orRB.SetChecked(!AllMustPass);
		opCell.AddInnerHTMLElement(orRB);

		if (useVerboseTerminology)
		{
			opCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			opCell.AddInnerHTMLString(rm.GetString(610, "ptmsgs_portalcommonmsgs", strLang));
		}
		else
		{
			opCell.AddInnerHTMLString(rm.GetString(608, "ptmsgs_portalcommonmsgs", strLang));
		}
	}

	/**
	 * Returns an action bar style "button" (Anchor with attached image and
	 * text) for adding a search filter condition
	 *
	 * @param strLabel The label on the button
	 * @param strLang - The language to be used
	 * @param owner - The owning activity space where this will be used
	 *
	 * @return HTMLElement
	 *
	 * @throws XPException 
	 */
	public static HTMLElement GetAddConditionButton(String strLabel, String strLang, AActivitySpace owner)
	{
		if ((strLabel == null) || ("").equals(strLabel))
		{
			IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
			XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

			strLabel = rm.GetString(620, "ptmsgs_portalcommonmsgs", strLang);
		}

		PTConstruct myConstruct = ConstructFactory.GetConstruct(PTImageType.ICON_SEARCH);
		HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();

		HTMLAnchor myAnchor = HTMLConstructHelpers.GetActionBarAnchor(1, myImg, strLabel, strLabel, "adjustRow(getActiveClause(), true); return false;", owner);

		return myAnchor;
	}
	

	/**
	 * Returns an action bar style "button" (Anchor with attached image and
	 * text) for adding a search filter clause
	 *
	 * @param strLabel The label on the button
	 * @param strLang - The language to be used
	 * @param owner - The owning activity space where this will be used
	 *
	 * @return HTMLElement
	 *
	 * @throws XPException 
	 */
	public static HTMLElement GetAddNewClauseButton(String strLabel, String strLang, AActivitySpace owner)

	{
		if ((strLabel == null) || ("").equals(strLabel))
		{
			IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
			XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

			strLabel = rm.GetString(622, "ptmsgs_portalcommonmsgs", strLang);
		}

		PTConstruct myConstruct = ConstructFactory.GetConstruct(PTImageType.ICON_ROW);
		HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();

		HTMLAnchor myAnchor = HTMLConstructHelpers.GetActionBarAnchor(1, myImg, strLabel, strLabel, "adjustGroups(true); return false;", owner);

		return myAnchor;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean GetAllMustPass()
	{
		return m_bAndOperator;
	}

	/**
	 * 
	 *
	 * @param iIndex 
	 *
	 * @return 
	 */
	public QueryCondition GetDefinedQueryCondition(int iIndex)
	{
		if ((iIndex + 1) > m_listDefinedRows.GetSize())
		{
			throw new XPException("Requested condition is not yet in list");
		}

		return (QueryCondition) m_listDefinedRows.GetElement(iIndex);
	}

	/**
	 * Returns JavaScript necessary for the Dynamic Query Table to work.
	 *
	 * @param submitString  - 
	 * @param asOwner - current Activity Space
	 * @return 
	 *
	 * @throws Exception 
	 */
	public static HTMLElement GetJavaScript(String submitString, AActivitySpace asOwner)

	{
	    return GetJavaScript("", submitString, asOwner);
	}
	
	/**
	 * Returns JavaScript necessary for the Dynamic Query Table to work.
	 *
	 * @param submitString  - 
	 * @param asOwner - current Activity Space
	 * @return 
	 *
	 * @throws Exception 
	 */
	public static HTMLElement GetJavaScript(String uniqueID, String submitString, AActivitySpace asOwner)

	{
		XPStringBuilder sb = new XPStringBuilder(1024);
		HTMLScript script  = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		sb.Append(
			"\nfunction ToggleStatementInput"+uniqueID+"(TurnOff, GroupID, StatementID)\n");
		sb.Append("{\n");
		sb.Append("\n");
		sb.Append("	var dispValue = (0 == TurnOff) ? '' : 'none';\n");
		sb.Append(
			"	var compVal = document.getElementById(GroupID + '_divCompareval_' + StatementID);\n");
		sb.Append("	compVal.style.display = dispValue;\n");
		sb.Append("}\n");
		sb.Append("\n");
		
		sb.Append("function ToggleDateInput"+uniqueID+"(TurnOff, GroupID, StatementID)\n");
		sb.Append("{\n");
		sb.Append("   var dispValue = (4 == TurnOff) ? '' : 'none';\n");
		sb.Append("	  var compVal = document.getElementById(GroupID + '_divRelative_' + StatementID);\n");
		sb.Append("	  compVal.style.display = dispValue;\n");
		sb.Append("\n");
		sb.Append("   dispValue = (4 == TurnOff) ? 'none' : '';\n");
		sb.Append("	  compVal = document.getElementById(GroupID + '_divDateChooser_' + StatementID);\n");
		sb.Append("	  compVal.style.display = dispValue;\n");
		sb.Append("}\n");
		sb.Append("\n");

		sb.Append("\nfunction AdjustOperator"+uniqueID+"(GroupID, RowNumber, val)\n");
		sb.Append("{\n");
		sb.Append("\n");
		sb.Append("	var valPair = val.split(\"|\");\n");
		sb.Append(
			"	var CompVal = document.getElementById(GroupID + '_divCompareval_' + RowNumber);\n");
		sb.Append(" CompVal.style.display = '';\n");
		sb.Append(
		"	var CompMember = document.getElementById(GroupID + '_divCompareMember_' + RowNumber);\n");
		sb.Append(" CompMember.style.display = 'none';\n");
		sb.Append(
			"	var DateChooser = document.getElementById(GroupID + '_divDateChooser_' + RowNumber);\n");
		sb.Append("      DateChooser.style.display = 'none';\n");
		sb.Append("	var Type = 'Text';\n");
		sb.Append("	if (valPair[1]=='3' || valPair[1]=='5')\n");
		sb.Append("		Type = 'Number';\n");
		sb.Append("	if (valPair[1]=='73')\n");
		sb.Append("	{\n");
		sb.Append("		CompMember.style.display = '';\n");
		sb.Append("		CompVal.style.display = 'none';\n");
		sb.Append("		Type = 'Member';\n");
		sb.Append("	}\n");
		sb.Append("	if (valPair[1]=='7')\n");
		sb.Append("	{\n");
						// Create the datepicker if not already.
		
		sb.Append("	    if(null != eval('window.fxn' + GroupID + '_divDateChooser_' + RowNumber))\n");
		sb.Append("	         eval('fxn' + GroupID + '_divDateChooser_' + RowNumber + '();');\n");
		sb.Append("		DateChooser.style.display = '';\n");
		sb.Append("		CompVal.style.display = 'none';\n");
		sb.Append("		Type = 'Date';\n");
		sb.Append("	}\n");
		sb.Append("\n");
		sb.Append(
			"	// First shut all of them off, then turn on the appropriate operator drop down\n");
		sb.Append(
			"	var OpDiv = document.getElementById(GroupID + '_divText_' + RowNumber);\n");
		sb.Append("	OpDiv.style.display = 'none';\n");
		sb.Append(
			"	OpDiv = document.getElementById(GroupID + '_divNumber_' + RowNumber);\n");
		sb.Append("	OpDiv.style.display = 'none';\n");
		sb.Append(
			"	OpDiv = document.getElementById(GroupID + '_divDate_' + RowNumber);\n");
		sb.Append("	OpDiv.style.display = 'none';\n");
		sb.Append(
			"	OpDiv = document.getElementById(GroupID + '_divMember_' + RowNumber);\n");
		sb.Append("	OpDiv.style.display = 'none';\n");
		sb.Append(
			"	OpDiv = document.getElementById(GroupID + '_divRelative_' + RowNumber);\n");
		sb.Append("	OpDiv.style.display = 'none';\n");
		sb.Append("\n");
		sb.Append(
			"	OpDiv = document.getElementById(GroupID + '_div' + Type + '_' + RowNumber);\n");
		sb.Append("	OpDiv.style.display = '';\n");
		sb.Append("}\n");
		sb.Append("\n");
		sb.Append("\nfunction adjustRow(GroupID, bAdd)\n");
		sb.Append("{\n");
		sb.Append("\n");
		sb.Append("		var disp = (bAdd) ? \"\" : \"none\";\n");
		sb.Append(
			"		var maxrows = document.getElementById(GroupID + '_maxrows');\n");
		sb.Append(
			"		var rowcount = document.getElementById(GroupID + '_revealed');\n");
		sb.Append("		var current = rowcount.value;\n");
		sb.Append("		var max = maxrows.value;\n");

		//		sb.Append("		alert('COUNT = ' + current + ' MAX = ' + max);\n");
		sb.Append(
			"		if (((current == max) && bAdd) || (!bAdd && (current ==0))) return;\n");
		sb.Append("\n");
		sb.Append("		if (bAdd)\n");
		sb.Append("			current++;\n");
		sb.Append("\n");

		//		sb.Append("		alert('INCREMENT COUNT = ' + current + ' MAX = ' + max);\n");
		sb.Append(
			"		var propDiv = document.getElementById(GroupID + \"_divPropRow_\" + current);\n");
		sb.Append("		propDiv.style.display = disp;\n");
		sb.Append(
			"		var propSel = document.getElementById(GroupID +\"_PropSelect_\" + current);\n");
		sb.Append(
			"		var types = propSel.options[propSel.selectedIndex].value.split(\"|\");\n");
		sb.Append("		var OpDiv;\n");
		sb.Append("		if (types[1] == 3 || types[1] == 5)\n");
		sb.Append(
			"			OpDiv = document.getElementById(GroupID + \"_divNumber_\" + current);\n");
		sb.Append("		if (types[1] == 73)\n");
		sb.Append("		{\n");
		sb.Append(
			"			OpDiv = document.getElementById(GroupID + \"_divMember_\" + current);\n");
		sb.Append(
		"			var GroupChooser = document.getElementById(GroupID + \"_divCompareMember_\" + current);\n");
		sb.Append("			GroupChooser.style.display = disp;\n");
		sb.Append("		}\n");
		
		sb.Append("		if (types[1] == 7)\n");
		sb.Append("		{\n");
		sb.Append("			OpDiv = document.getElementById(GroupID + \"_divDate_\" + current);\n");
		sb.Append("     	var dtOp = document.getElementById(GroupID + \"_DateOpSelect_\" + current);\n");
		sb.Append(" 		if (dtOp.value != 18)\n");/* relative timedate op */ 
		sb.Append(" 		{\n");
		sb.Append("				var DatChooseDiv = document.getElementById(GroupID + \"_divDateChooser_\" + current);\n");
		sb.Append("				DatChooseDiv.style.display = disp;\n");
		sb.Append(" 		}\n");
		sb.Append(" 		else\n");
		sb.Append(" 		{\n");
		sb.Append("				var RelativeDiv = document.getElementById(GroupID + \"_divRelative_\" + current);\n");
		sb.Append("				RelativeDiv.style.display = disp;\n");
		sb.Append(" 		}\n");
		sb.Append("		}\n");
		
		sb.Append("		if (types[1] == 8 || types[1] == 72)\n");
		sb.Append(
			"			OpDiv = document.getElementById(GroupID + \"_divText_\" + current);\n");
		sb.Append("		OpDiv.style.display = disp;\n");
		sb.Append("\n");
		sb.Append("		if (types[1] != 7 && types[1] != 73) {\n");
		sb.Append(
			"		  var operator = document.getElementById(GroupID + \"_TextOpSelect_\" + current);\n");
		sb.Append("		  if (operator.value != 9) {\n");
		sb.Append(
			"		    var valueDiv = document.getElementById(GroupID + \"_divCompareval_\" + current);\n");
		sb.Append("		    valueDiv.style.display = disp;\n");
		sb.Append("		  }\n");
		sb.Append("		}\n");
		sb.Append("		if(!bAdd)\n");
		sb.Append("			current--;\n");
		sb.Append("		rowcount.value = current;\n");
		sb.Append("\n");
		sb.Append("}\n");
		sb.Append("\n\n");
		sb.Append("function getActiveClause"+uniqueID+"()\n");
		sb.Append("{\n");
		sb.Append("\n");
		sb.Append("	var clause = document.getElementById('activeclause');\n");
		sb.Append("	var groupid = clause.value;\n");
		sb.Append(" return groupid;\n");
		sb.Append("}\n");
		sb.Append("\n");
		sb.Append("\nfunction setActiveClause"+uniqueID+"(NewGroupNum, IsChecked)\n");
		sb.Append("{\n");
		sb.Append("	if (!IsChecked)\n");
		sb.Append("	{ // it doesn't make sense to uncheck a group\n");
		sb.Append(
			"		var ThisCheckBox = document.getElementById(NewGroupNum+'_checked');\n");
		sb.Append("		ThisCheckBox.checked = true;\n");
		sb.Append("		return;\n");
		sb.Append("	}\n");
		sb.Append("\n");
		sb.Append("	var clause = document.getElementById('activeclause');\n");
		sb.Append("	var oldfocus = clause.value;\n");
		sb.Append(
			" var vChecked = document.getElementById(oldfocus+'_checked');\n");
		sb.Append("	clause.value = NewGroupNum;\n");
		sb.Append("	if (!vChecked.checked)\n");
		sb.Append("		return;\n");
		sb.Append("	vChecked.checked = false;\n");
		sb.Append("}\n");
		sb.Append("\n");
		sb.Append("\nfunction adjustGroups"+uniqueID+"(bAdd)\n");
		sb.Append("{\n");
		sb.Append("	var action = document.getElementById('groupaction');\n");
		sb.Append("	if (bAdd)\n");
		sb.Append("		action.value = 'ADD';\n");
		sb.Append("	else\n");
		sb.Append("		action.value = 'REMOVE';\n");
		sb.Append(submitString);
		sb.Append("}\n");
		sb.Append("function handleOnLoad"+uniqueID+"() {\n");
		sb.Append("  var activeClause = getActiveClause"+uniqueID+"();\n");
		sb.Append(
			"  var rowCount = document.getElementById(activeClause + '_revealed');\n");
		sb.Append("  var origRowCount = rowCount.value;\n");
		sb.Append("  rowCount.value = 0;\n");
		sb.Append("  for (var j = 0; j < origRowCount; j++) {\n");
		sb.Append("    adjustRow"+uniqueID+"(activeClause, true);\n");
		sb.Append("  }\n");
		sb.Append("}\n");
		
		// aj: group chooser tree opener
		// TODO: make your functions unique incase it shows up more than once on a page
		ASURL asGroupChooserTree = GetGroupChooserURL(asOwner);

		// JavaScript function to open reference tree
		sb.Append("function ").Append(QueryCondition.JAVASCRIPT_OPEN_GROUP_CHOOSER).Append("(varClassID, varRowIndex, varTreeSelectMode, varSelectedGroup)\n");
		sb.Append("{\n");
		sb.Append("  document.").Append(AFormDP.HTMLFORM_NAME).Append(".").Append(QueryCondition.HTMLHIDDEN_ROWINDEX).Append(".value = varRowIndex;\n");
		sb.Append("  window.open('").Append(asGroupChooserTree.GetURLAsString());
		sb.Append("&").Append(StartTreeControl.CLASS_IDS_TO_DISPLAY).Append("=' + varClassID");
		sb.Append(" + '&").Append(StartTreeControl.SELECT_MODE).Append("=' + varTreeSelectMode");
		sb.Append(" + '&").Append(StartTreeControl.SELECTED_ITEMS).Append("=").Append(PT_CLASSIDS.PT_USERGROUP_ID).Append("%2C").Append("' + varSelectedGroup");
		sb.Append(", 'GroupChooserTreeWindow', '").Append(TreeConstants.GetJavascriptTreeWindowAttributes()).Append("');\n");
		sb.Append("}\n");
		
		// aj: group chooser post back function
		sb.Append("function ").Append(QueryCondition.JAVASCRIPT_GROUP_CHOOSER_GETVALUE).Append("()\n");
		sb.Append("{\n");
		// aj: I know this uses a group-specific action, but this should be fine as it will pass through
		//     other repost controls that don't have to deal with it.
		sb.Append("  ").Append(AFormDP.JAVASCRIPT_SUBMIT_FORM).Append("(").Append(GroupRepostControl.POSTTOSELF_ACTION_MODIFY_GROUP_CHOOSER_ROW).Append(");\n");
		sb.Append("}\n");

		script.AddInnerHTMLString(sb.ToString());

		return script;
	}
	
	public static HTMLElement GetTestButton(String label, String script, AActivitySpace space)
	{
		PTConstruct myConstruct = ConstructFactory.GetConstruct(PTImageType.ICON_DOCUMENT);
		HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();

		HTMLAnchor myAnchor = HTMLConstructHelpers.GetActionBarAnchor(1, myImg, label, label, script, space);
		
		return myAnchor;
	}


	/**
	 * Returns an action bar style "button" (Anchor with attached image and
	 * text) for removing a search filter clause
	 *
	 * @param strLabel The label on the button
	 * @param strLang - The language to be used
	 * @param owner - The owning activity space where this will be used
	 *
	 * @return HTMLElement
	 *
	 * @throws XPException 
	 */
	public static HTMLElement GetRemoveClauseButton(String strLabel, String strLang, AActivitySpace owner)

	{
		if ((strLabel == null) || ("").equals(strLabel))
		{
			IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
			XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
			strLabel = rm.GetString(623, "ptmsgs_portalcommonmsgs", strLang);
		}

		PTConstruct myConstruct = ConstructFactory.GetConstruct(PTImageType.ICON_ROW);
		HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();

		HTMLAnchor myAnchor = HTMLConstructHelpers.GetActionBarAnchor(0, myImg, strLabel, strLabel, "adjustGroups(false); return false;", owner);

		return myAnchor;
	}

	/**
	 * Returns an action bar style "button" (Anchor with attached image and
	 * text) for removing the last search filter condition
	 *
	 * @param strLabel The label on the button
	 * @param strLang - The language to be used
	 * @param owner - The owning activity space where this will be used
	 *
	 * @return HTMLElement
	 *
	 * @throws XPException 
	 */
	public static HTMLElement GetRemoveLastConditionButton(String strLabel, String strLang, AActivitySpace owner)

	{
		if ((strLabel == null) || ("").equals(strLabel))
		{
			IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
			XPResourceManager rm = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

			strLabel = rm.GetString(621, "ptmsgs_portalcommonmsgs", strLang);
		}

		PTConstruct myConstruct = ConstructFactory.GetConstruct(PTImageType.ICON_SEARCH);
		HTMLImg myImg = (HTMLImg) myConstruct.GetHTMLElement();

		HTMLAnchor myAnchor = HTMLConstructHelpers.GetActionBarAnchor(0, myImg, strLabel, strLabel, "adjustRow(getActiveClause(), false); return false;", owner);

		return myAnchor;
	}

	/**
	 * 
	 *
	 * @param result 
	 * @param showErrorsNextToInputs 
	 */
	public void addTableToCollection(HTMLElementCollection result,
                                   boolean showErrorsNextToInputs,
                                   JSDateTimePickerMgr jsDateTimePickerMgr, PageMgr _ptPageMgr)
	{
	    addTableToCollection("", result, showErrorsNextToInputs, jsDateTimePickerMgr, _ptPageMgr, true);
	}
	
	/**
	 * 
	 *
	 * @param result 
	 * @param showErrorsNextToInputs 
	 */
	public void addTableToCollection(String prefix, HTMLElementCollection result,
                                   boolean showErrorsNextToInputs,
                                   JSDateTimePickerMgr jsDateTimePickerMgr, PageMgr _ptPageMgr, boolean jitDatePicker)
	{
		// this spacer table is used for indenting clauses
		HTMLTable SpacerTable = new HTMLTable();
		SpacerTable.SetWidth("100%");
		SpacerTable.SetBorder("0");
		SpacerTable.SetCellPadding("0");
		SpacerTable.SetCellSpacing("0");

		HTMLTableRow SpacerRow   = new HTMLTableRow();
		HTMLTableCell SpacerCell = new HTMLTableCell();
		HTMLTableCell ClauseCell = new HTMLTableCell();

		HTMLTable myTable = new HTMLTable(); // the inner table

		if (m_listDefinedRows == null)
		{
			m_listDefinedRows = new XPArrayList();
		}

		try
		{
			if (m_Depth > 0)
			{ // IF NEEDED, add the spacer column to the spacer row

				PTConstruct construct = ConstructFactory.GetConstruct(PTImageType.SPACER,
						true);
				HTMLImg img		   = (HTMLImg) construct.GetHTMLElement();
				img.SetWidth(XPConvert.ToString(m_Depth * 50));
				SpacerCell.AddInnerHTMLElement(img);
				SpacerRow.AddInnerHTMLElement(SpacerCell);
			}

			// ATTACH SPACER TABLE TO RESULT
			// JHQ - Why are we adding this spacer table?
//			result.AddInnerHTMLElement(EditorView.GetSpacerTable());
			result.AddInnerHTMLElement(SpacerTable);

			// ATTACH ROW TO SPACER TABLE
			SpacerTable.AddInnerHTMLElement(SpacerRow);

			// ATTACH CELL TO ROW
			SpacerRow.AddInnerHTMLElement(ClauseCell);

			// ATTACH INNER TABLE TO CELL
			ClauseCell.AddInnerHTMLElement(myTable);

			if (m_BlankQC == null)
			{
				throw new XPException(
					"Blank query condition must be set before generating table");
			}

			myTable.SetWidth("100%");
			myTable.SetBorder("0");
			myTable.SetCellPadding("1"); //used to be 5
			myTable.SetCellSpacing("0");

			if (! m_bHideGroupHeader) 
			{
				HTMLTableCell titleCell = new HTMLTableCell();
				titleCell.SetWidth("100%");
				titleCell.SetHeight("20");
				titleCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
				titleCell.SetColSpan("2");
				//titleCell.SetAlign("absLeft");

				if (!m_bSuppressCheckbox)
				{
					HTMLInput checkbox = new HTMLInput(HTMLInputTypes.RADIO,
					        "in_ra_thisform", "");
					checkbox.SetValue(m_strName);
					checkbox.SetID(m_strName + "_checked");

					if (m_strName.equals("1"))
					{
						checkbox.SetChecked(true);
					}
					else
					{
						checkbox.SetChecked(false);
					}

					checkbox.SetOnClick("setActiveClause(this.value, this.checked);");
					titleCell.AddInnerHTMLElement(checkbox);
				}

				if (null == m_strLabel)
				{
					titleCell.AddInnerHTMLString(m_asOwner.GetString(606, "ptmsgs_portalcommonmsgs") + m_strName);
				}
				else
				{
					titleCell.AddInnerHTMLString(m_strLabel);
				}

				HTMLTableRow titleRow = new HTMLTableRow();
				titleRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
				titleRow.AddInnerHTMLElement(titleCell);

				// the operator selection
				HTMLTableCell GroupOps = new HTMLTableCell();
				GroupOps.SetNoWrap(true);
				
				HTMLInput andRB = new HTMLInput(HTMLInputTypes.RADIO,
				        "in_ra_groupoperator_" + m_strName, m_strName);
				andRB.SetID(m_strName + "_and");
				andRB.SetValue("and");
				andRB.SetChecked(m_bAndOperator);
				GroupOps.AddInnerHTMLElement(andRB);
				
				if (m_bUseVerboseTerminology)
				{
					GroupOps.AddInnerHTMLString(m_asOwner.GetString(612, "ptmsgs_portalcommonmsgs"));
				}
				else
				{
					GroupOps.AddInnerHTMLString(m_asOwner.GetString(607, "ptmsgs_portalcommonmsgs"));
				}

				HTMLInput orRB = new HTMLInput(HTMLInputTypes.RADIO,
				        "in_ra_groupoperator_" + m_strName, m_strName);
				orRB.SetID(m_strName + "_or");
				orRB.SetValue("or");
				orRB.SetChecked(!m_bAndOperator);
				GroupOps.AddInnerHTMLElement(orRB);
				
				if (m_bUseVerboseTerminology)
				{
					GroupOps.AddInnerHTMLString(m_asOwner.GetString(611, "ptmsgs_portalcommonmsgs"));
				}
				else
				{
					GroupOps.AddInnerHTMLString(m_asOwner.GetString(608, "ptmsgs_portalcommonmsgs"));
				}
				
				GroupOps.AddInnerHTMLString("&nbsp;&nbsp;&nbsp;&nbsp;");

				GroupOps.SetHeight("20");
				GroupOps.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				GroupOps.SetAlign("Right");

				titleRow.AddInnerHTMLElement(GroupOps);

				myTable.AddInnerHTMLElement(titleRow);
			}

			if (null != m_heExtraRow)
			{
				HTMLTableRow extraRow = new HTMLTableRow();
				extraRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
				myTable.AddInnerHTMLElement(extraRow);

				HTMLTableCell extraCell = new HTMLTableCell();
				extraCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
				extraCell.SetHeight("35");
				extraCell.SetVAlign("center");
				extraRow.AddInnerHTMLElement(extraCell);
				extraCell.SetColSpan("3");
				extraCell.AddInnerHTMLElement(m_heExtraRow);
			}

			int tableSize = m_listDefinedRows.GetSize();

			if (m_Rows == 0)
			{
				throw new XPException("Table size set before generating table");
			}

			QueryCondition qc;

			// add spacer row to force the width to be uniform
			HTMLTableRow blankRow = new HTMLTableRow();
			myTable.AddInnerHTMLElement(blankRow);
			HTMLTableCell blankCell = new HTMLTableCell();
			blankRow.AddInnerHTMLElement(blankCell);
			blankCell.SetWidth("500");
			blankCell.SetColSpan("3");
			
			// now we simply add multiple identical rows
			for (int i = 0; i < m_Rows; i++)
			{
				if (i < tableSize)
				{
					qc = (QueryCondition) m_listDefinedRows.GetElement(i);
					qc.SetVisible(true);
				}
				else
				{
					qc = m_BlankQC;
				}

				myTable.AddInnerHTMLElement(qc.GetTableRow(prefix, m_strName,
															XPConvert.ToString(i + 1), showErrorsNextToInputs,
															/* showRemovalCheckbox= */ false,
															jsDateTimePickerMgr, _ptPageMgr, 
															jitDatePicker));
			}

			// finally add a row that will be used by the 
			HTMLInput maxrows = new HTMLInput(HTMLInputTypes.HIDDEN,
			        "in_hi_maxrows_" + prefix + m_strName, "");
			maxrows.SetID(m_strName + "_maxrows");
			maxrows.SetValue(XPConvert.ToString(m_Rows));
			ClauseCell.AddInnerHTMLElement(maxrows);

			//result.AddInnerHTMLElement(maxrows);
			HTMLInput revealed = new HTMLInput(HTMLInputTypes.HIDDEN,
			        "in_hi_revealed_"  + prefix + m_strName, "");
			revealed.SetID(m_strName + "_revealed");
			revealed.SetValue(XPConvert.ToString(tableSize));
			ClauseCell.AddInnerHTMLElement(revealed);

			//result.AddInnerHTMLElement(revealed);
			HTMLInput depth = new HTMLInput(HTMLInputTypes.HIDDEN,
			        "in_hi_depth_"  + prefix + m_strName, "");
			depth.SetID(m_strName + "_depth");
			depth.SetValue(XPConvert.ToString(m_Depth));
			ClauseCell.AddInnerHTMLElement(depth);

			//result.AddInnerHTMLElement(depth);
			//result.AddInnerHTMLElement(myTable);
		}
		catch (Exception e)
		{
			throw new XPException(m_asOwner.GetString(604, "ptmsgs_portalcommonmsgs"), e);
		}
	}

	/**
	 * 
	 *
	 * @param qc 
	 */
	public void loadDefinedQueryCondition(QueryCondition qc)
	{
		if (m_listDefinedRows == null)
		{
			m_listDefinedRows = new XPArrayList();
		}

		m_listDefinedRows.Add(qc);
	}

	/**
	 * 
	 *
	 * @param iIndex 
	 */
	public void removeDefinedQueryCondition(int iIndex)
	{
		if ((iIndex + 1) > m_listDefinedRows.GetSize())
		{
			throw new XPException("Requested condition is not yet in list");
		}

		m_listDefinedRows.RemoveAt(iIndex);
	}
	
	/**
	 * Return ASURL for a Group Chooser (tree)
	 *
	 * @return ASURL for a Group Chooser (Tree)
	 */
	private static ASURL GetGroupChooserURL(AActivitySpace asOwner)
	{
		// The URL to open a new tree to select reference objects
		ASURL asURLRefTree = new ASURL(asOwner);

		asURLRefTree.SetLinkCreateNewSpace(TreeAS.STR_MVC_CLASS_NAME, asOwner);
		asURLRefTree.SetSubSpaceKey(QueryCondition.SUBSPACE_KEY_GROUP_CHOOSER);
		asURLRefTree.SetControl(StartTreeControl.STR_MVC_CLASS_NAME);
		asURLRefTree.AddControlArgument(StartTreeControl.ROOT_ID, XPConvert.ToString(PT_INTRINSICS.PT_ADMIN_FOLDER_ROOTFOLDER));
		asURLRefTree.AddControlArgument(StartTreeControl.MULTI_SELECT, XPConvert.ToString(false));
		asURLRefTree.AddControlArgument(StartTreeControl.SUBMIT_MODE, XPConvert.ToString(TreeConstants.N_SERVERSUBMIT));
		asURLRefTree.AddControlArgument(StartTreeControl.PARENT_FORM_NAME, AFormDP.HTMLFORM_NAME);
		asURLRefTree.AddControlArgument(StartTreeControl.PARENT_SUBMIT_CALL, QueryCondition.JAVASCRIPT_GROUP_CHOOSER_GETVALUE);
		asURLRefTree.AddControlArgument(StartTreeControl.TITLE, asOwner.GetString(784, "ptmsgs_portalcommonmsgs"));
		asURLRefTree.AddControlArgument(StartTreeControl.ACTIONSUBTITLE, asOwner.GetString(785, "ptmsgs_portalcommonmsgs"));
		asURLRefTree.AddControlArgument(StartTreeControl.ACCESS_LEVEL, XPConvert.ToString(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT));

		return asURLRefTree;
	}
}

