package com.plumtree.portalpages.common.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS
 *
 *  This is an abstract superclass for a view that looks like an EditorView,
 *  i.e. has the same blue striped title across the top,
 *  but may be used in any ActivitySpace, not just EditorAS subclasses.
 */
public abstract class EditorLikeView implements IView
{
	
	public static final String SPACE   = "&nbsp;";
	protected AActivitySpace m_asOwner;
	protected IModelRO m_model;

	/**
	 * 
	 *
	 * @return 
	 */
	abstract public Object Create();

	/**
	 * 
	 *
	 * @return 
	 */
	public abstract HTMLElement Display();

	/**
	 * 
	 *
	 * @return 
	 */
	public abstract String GetName();

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * Returns the header HTML and style for advanced search fitlers.
	 * This function is called by CardLanguagePlugInView, FilterView, FolderSelectorView, SimpleSelectorView, and
	 * TypeSelectorView.  It is not called by search criteria filter.
	 * 
	 * @param _sHeaderTitle 
	 *
	 * @return 
	 */
	public HTMLElement GetHeaderView(String _sHeaderTitle, boolean addSpacer)
	{
 		HTMLTable table = new HTMLTable();
 		table.SetWidth("100%");
 		table.SetCellSpacing("0");
 		table.SetCellPadding("0");
 		table.SetBorder("0");
 		HTMLTableRow row = new HTMLTableRow();
 		table.AddInnerHTMLElement(row);
 		row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
 		HTMLTableCell cell = new HTMLTableCell();
 		row.AddInnerHTMLElement(cell);
 		cell.SetWidth("100%");
 		cell.SetHeight("20");
 		cell.SetVAlign("middle");
 		cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
 		HTMLSpan span = new HTMLSpan();
 		cell.AddInnerHTMLElement(span);
 		span.AddInnerHTMLString(_sHeaderTitle);
		span.SetStyleClass(PTStyleClass.OBJECT_HEADER);

    HTMLElementCollection c = new HTMLElementCollection();

    c.AddInnerHTMLElement(table);
    if(addSpacer)
   		 c.AddInnerHTMLElement(makeSpacer("2", this.m_asOwner));

    return c;
	}

  private static HTMLElement makeSpacer(String height, AActivitySpace owner)
  {
    HTMLTable table = new HTMLTable();
    table.SetCellSpacing("0");
    table.SetCellPadding("0");
    table.SetWidth("100%");

    HTMLTableRow row = new HTMLTableRow();
    table.AddInnerHTMLElement(row);

    HTMLTableCell cell = new HTMLTableCell();
    row.AddInnerHTMLElement(cell);

    HTMLImg img = null;

    try
    {
      img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER,
          true, owner).GetHTMLElement();
    }
    catch (Exception e)
    {
      throw XPException.GetInstance(e);
    }

    cell.AddInnerHTMLElement(img);
    img.SetHeight(height);
    img.SetWidth("1");
    img.SetBorder("0");
    img.SetAlign("absMiddle");

    return table;
  }

	/**
	 * 
	 *
	 * @param model 
	 * @param parent 
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_model		  = model;
		m_asOwner     = parent;
	}
}

