package com.plumtree.portalpages.common.search;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.xpshared.jsutil.*;

/**
 * @author CraigS, based on MikeS code
 */
public abstract class FilterView extends EditorLikeView 
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.search.FilterView");

	private HTMLElement _textboxLabel = null;
	private String _addClauseLabel = null;
	private String _addConditionLabel = null;
	private String _propertyLabel = null;
	private String _removeClauseLabel = null;
	private String _removeConditionLabel = null;
	private String _viewTitle = "";
	private String _width = "100%";
	private boolean _allowSubclauses = true;
	private boolean _errorsNextToTextBoxes = false;
	private boolean _putTextSearchAboveButtons = false;
	private boolean _useJavascriptStatementButtons = true;
	private boolean _useCheckboxLayout = false;
	private boolean _addTestButton = false;
	private String _testButtonScript = "";
	private String _testButtonOnClickScript = "";
	
	// mbs- This is only used for finish validation of the filter editor,
	private boolean m_bAtLeastOneErrorOccurred = false;
	
	// aj: this should default to true since this view is
	//     primarily used for search-related activities.  
	//     only the dynamic groups chooser should
	//     need to supress this box...
	private boolean _showSearchBox = true;

	private int _repostAction;
	private int m_tablesize = 10;

	/**
	 * Displays the HTML for search criteria filter in the advanced search settings page.
	 *
	 * @return HTMLElement
	 */
	public HTMLElement Display() 
	{
		HTMLElementCollection result = new HTMLElementCollection();
		m_bAtLeastOneErrorOccurred = false;
		IFilterIteratorRO model = ((IFilterIteratorContainerRO) m_model).GetFilterIterator();

   		 // Get the user's locale and timezone
		String locale =
      		(String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.LOCALE, m_asOwner);
		String timezone =
      		(String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.TIMEZONE, m_asOwner);

		XPLocale xpLocale = null;
		XPTimeZone xpTimeZone = null;

		if (null != locale) 
		{
			xpLocale = new XPLocale(locale);
		} 
		else 
		{
			xpLocale = XPLocale.GetDefault();
		}

		if (null != timezone) 
		{
			xpTimeZone = XPTimeZone.GetTimeZone(timezone);
		}
		else
		{
			xpTimeZone = XPTimeZone.GetCurrentTimeZone();
		}

  		// Initialize the page controls and date/time picker
    	String  strImageServerBaseURL = ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
    	PageMgr pageMgr = new PageMgr(m_asOwner.GetAccessStyle(), xpLocale, xpTimeZone, strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		JSRegistry ptJSRegistry = JSRegistry.GetRegistry(strImageServerBaseURL, ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		JSDateTimePickerMgr dtPickerMgr =
				new JSDateTimePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(), pageMgr);
		pageMgr.RegisterComponentMgr(dtPickerMgr);

		try 
		{
			result.AddInnerHTMLElement(dtPickerMgr.GetJSIncludes());

			if (null != _viewTitle)
			{
				result.AddInnerHTMLElement(super.GetHeaderView(_viewTitle, false));
			}

			//Display the filter banner and buttons
			HTMLElementCollection buttons = MakeButtons();
			boolean shownButtonsYet = false;
			HTMLTable buttonTable = new HTMLTable();

			HTMLTableRow myRow = null;
			HTMLTableCell myCell = null;

			if (!_putTextSearchAboveButtons) 
			{
				if (_useJavascriptStatementButtons) 
				{
					// Add the action bar with the search filter actions
					result.AddInnerHTMLElement(HTMLConstructHelpers.GetActionBar(buttons, "FilterView", m_asOwner));
				}
				else
				{
					//TODO: this, it doesn't belong here.
					HTMLTable table = new HTMLTable();
					table.SetWidth("100%");
					table.SetBorder("0");
					table.SetCellPadding("0");
					table.SetCellSpacing("0");
					HTMLTableRow row = new HTMLTableRow();
					row.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);
					table.AddInnerHTMLElement(row);
					HTMLTableCell cell = new HTMLTableCell();
					row.AddInnerHTMLElement(cell);
					cell.SetWidth("100%");
					cell.SetHeight("20");
					cell.SetVAlign("middle");
					cell.SetStyleClass(PTStyleClass.OBJECT_HEADER);
					HTMLSpan span = new HTMLSpan();
					span.AddInnerHTMLString(m_asOwner.GetString(743, "ptmsgs_portalcommonmsgs"));
					cell.AddInnerHTMLElement(span);
					result.AddInnerHTMLElement(table);
					result.AddInnerHTMLElement(buttons);
				}
				shownButtonsYet = true;
			} 
			else 
			{
				// Build a table to hold the buttons (not in an actionbar)
				buttonTable.SetWidth(_width);
				buttonTable.SetBorder("0");
				buttonTable.SetCellPadding("5");
				buttonTable.SetCellSpacing("0");
				
				myRow = new HTMLTableRow();
				buttonTable.AddInnerHTMLElement(myRow);
				myRow.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);

				myCell = new HTMLTableCell();
				myRow.AddInnerHTMLElement(myCell); 
				HTMLBr br = new HTMLBr();
				myCell.AddInnerHTMLElement(br);
				myCell.AddInnerHTMLElement(buttons);
				br = new HTMLBr();
				myCell.AddInnerHTMLElement(br);
			}

			HTMLSpan errorSpan = new HTMLSpan();

			if (GetDoValidation() && (!_errorsNextToTextBoxes)) 
			{
				errorSpan.SetStyleClass(PTStyleClass.ALERT_ERROR_TEXT);
				result.AddInnerHTMLElement(errorSpan);
			}

			// aj: suppress the search box and "AND/OR" chooser
			if(_showSearchBox)
			{
				//Add a spacer table
				if (! _putTextSearchAboveButtons)
				{
					result.AddInnerHTMLElement(EditorView.GetShortSpacerTable());
				}
				
				String strLang = XPConvert.ToString( PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,  m_asOwner) );

				
				if (_useJavascriptStatementButtons) 
				{
					DynamicQueryTable.AddTopLevelSearchBoxAndOperator(
						model.GetTextSearchString(),
						model.GetTopLevelAllMustPass(),
						!_allowSubclauses,
						_textboxLabel,
						result,
						strLang);
				} 
				else 
				{
					RepostQueryTable.AddTopLevelSearchBoxAndOperator(
						model.GetTextSearchString(),
						model.GetTopLevelAllMustPass(),
						!_allowSubclauses,
						_textboxLabel,
						result,
						strLang,
						m_asOwner);
				}
			}
			
			// aj: originally the BuildFilterFromHashtable() function
			//     relied on the in_ra_topoperator radio to
			//     determine if it's actually processing the right
			//     form data.  since this can now be supressed
			//     we need to have a hidden element that will indicate
			//     we are on the right form data: in_he_thisIsAFilterForm
			HTMLInput he_isAFilterForm = new HTMLInput(HTMLInputTypes.HIDDEN,
					FilterForm.IS_FILTER_FORM, "");
			he_isAFilterForm.SetValue("true");
			result.AddInnerHTMLElement(he_isAFilterForm);

			
			int groupCount = 0;
			model.SetIteratorToStart();

			while (model.GetNextClausePosition()) {
				boolean Operator = model.GetCurrentClauseOperator();
				
				 int offset = model.GetCurrentClauseDepth();
				 
				// we have a clause, let's create a table for it
				groupCount++;

				IFilterQueryTable queryGroup = null;

				if (_useJavascriptStatementButtons) {
					queryGroup =
						new DynamicQueryTable(
							XPConvert.ToString(groupCount),
							offset,
							m_asOwner);
				} else {
					queryGroup =
						new RepostQueryTable(
							XPConvert.ToString(groupCount),
							offset,
							m_asOwner);
				}

				queryGroup.SetAllMustPass(Operator);
				queryGroup.SetTableSize(m_tablesize);

				// the table of queries must be seeded with a generic query used for dynamic expansion
				QueryCondition invisibleQuery =
					model.MakeQueryCondition();

				// default to name
				invisibleQuery.SetSelections(1, 
                                     (int) (PT_FILTEROPS.PT_FILTEROP_CONTAINS),
                                     "");
				queryGroup.SetBlankQueryCondition(invisibleQuery);

				QueryCondition qc = invisibleQuery.MakeDuplicate();
				qc.SetVisible(true);

				// load the appropriate statements
				int itemcounter = 0;

				while (model.GetNextStatementAndSetQC(qc)) {
					itemcounter++;

					QueryCondition next = qc.MakeDuplicate();
					boolean bSetPropertyAdded = model.AddSetProperty(next);
				    queryGroup.loadDefinedQueryCondition(next);

				    if (!next.ContainsProperty(next.GetStatementProperty()))
				    {
				        SetError(errorSpan, 
				                XPResourceManager.FormatMessage(
				                        m_asOwner.GetString(792, "ptmsgs_portalcommonmsgs"), 
				                        XPConvert.ToString(next.GetStatementProperty())), 
				                XPConvert.ToString(groupCount), 
				                XPConvert.ToString(itemcounter));
				    }
				    
					if (GetDoValidation()) 
					{
						String strWarning = next.ValidateSelections();

						if (strWarning.length() > 0) 
						{
					        SetError(errorSpan, 
					                strWarning, 
					                XPConvert.ToString(groupCount), 
					                XPConvert.ToString(itemcounter));
						}
						
						if (bSetPropertyAdded)
						{
					        SetError(errorSpan, 
					                m_asOwner.GetString(791, "ptmsgs_portalcommonmsgs"), 
					                XPConvert.ToString(groupCount), 
					                XPConvert.ToString(itemcounter));
						}
					}
				}

				if (!_allowSubclauses) {
					// if subclauses are not allowed, it makes no sense to label the single
					// group "Grouping 1"
					//queryGroup.SetLabel(m_asOwner.GetString(200,
					//		"ptmsgs_portalcommonmsgs"));
					//queryGroup.SetSuppressCheckbox(true);
					//queryGroup.SetUseVerboseTerminology(true);
					queryGroup.SetHideGroupHeaderRow(true);

					if (null != _propertyLabel) {
						HTMLElementCollection he = new HTMLElementCollection();
						he.AddInnerHTMLString(_propertyLabel);

						if (_putTextSearchAboveButtons
									&& (model.GetNumItemsInFirstClause() == 0)) 
						{
							he.AddInnerHTMLElement(buttons);
							shownButtonsYet = true;
						}
						queryGroup.SetExtraRowBelowGroupHeader(he);
					}
				}

				queryGroup.addTableToCollection(result, GetDoValidation() && _errorsNextToTextBoxes,
							dtPickerMgr, pageMgr);
			}

			// EDITOR_OBJECTID_UNKNOWN
			if (0 == groupCount) { // we must have been opened for create

				// Build the table....
				groupCount = 1;

				IFilterQueryTable querylist = null;

				if (_useJavascriptStatementButtons) {
					querylist = new DynamicQueryTable("1", 0, m_asOwner);
				} else {
					querylist = new RepostQueryTable("1", 0, m_asOwner);
				}

				querylist.SetAllMustPass(true);
				querylist.SetTableSize(m_tablesize);

				QueryCondition newQuery =
					model.MakeQueryCondition();
				newQuery.SetSelections(1,
                               (int) (PT_FILTEROPS.PT_FILTEROP_CONTAINS),
                               "");

				QueryCondition blankQuery = newQuery.MakeDuplicate();
				querylist.SetBlankQueryCondition(blankQuery);
				newQuery.SetVisible(true);

				//querylist.loadDefinedQueryCondition(newQuery);
				if (!_allowSubclauses) {
					// if subclauses are not allowed, it makes no sense to label the single
					// group "Grouping 1"
					//querylist.SetLabel(m_asOwner.GetString(200,
					//		"ptmsgs_portalcommonmsgs"));
					//querylist.SetSuppressCheckbox(true);
					//querylist.SetUseVerboseTerminology(true);
					querylist.SetHideGroupHeaderRow(true);

					if (null != _propertyLabel) {
						HTMLElementCollection he = new HTMLElementCollection();
						he.AddInnerHTMLString(_propertyLabel);

						if (_putTextSearchAboveButtons
							&& (model.GetNumItemsInFirstClause() == 0)) {
							he.AddInnerHTMLElement(buttons);
							shownButtonsYet = true;
						}

						querylist.SetExtraRowBelowGroupHeader(he);
					}
				}

				querylist.addTableToCollection(
					result,
					GetDoValidation() && _errorsNextToTextBoxes,
          dtPickerMgr, pageMgr);
			}

			if (!shownButtonsYet) {
				result.AddInnerHTMLElement(buttonTable);
			}

			DynamicQueryTable.AddGlobalElements("1" /*the active group*/
			, groupCount, result);
		} catch (Exception e) {
			log.Error(e, "FilterView::Display An error occured when trying to display the HTML.");

			throw new XPException(
				m_asOwner.GetString(199, "ptmsgs_portalcommonmsgs"),
				e);
		}

		return result;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLScript DisplayJavascript() {
		HTMLScript script = null;

		try 
		{
			String submitCommand =
				"	postToSelf(" + XPConvert.ToString(_repostAction) + ");\n";

			if (_useJavascriptStatementButtons) {
				script =
					(HTMLScript) DynamicQueryTable.GetJavaScript(submitCommand, m_asOwner);
			} else {
				script =
					(HTMLScript) RepostQueryTable.GetJavaScript(submitCommand);
			}
			if(_addTestButton && _testButtonScript != null)
			{
				script.AddInnerHTMLString(_testButtonScript);
			}
		} 
		catch (Exception e) 
		{
			log.Error(e, "FilterView::Display An error occured when trying to display the HTML.");

			throw new XPException(
				m_asOwner.GetString(199, "ptmsgs_portalcommonmsgs"),
				e);
		}

		return script;
	}
		
	/*
	 * These buttons add the "add criteria" and delete criteria buttons on the search criteria filter
	 */
	private HTMLElementCollection MakeButtons()
	{
		IFilterIteratorRO model = ((IFilterIteratorContainerRO) m_model).GetFilterIterator();
		HTMLElementCollection result = new HTMLElementCollection();

		String strLang = XPConvert.ToString( PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingsHelper.LANGUAGE,  m_asOwner) );


		if (_useJavascriptStatementButtons) 
		{

			result.AddInnerHTMLElement( 
				DynamicQueryTable.GetAddConditionButton(
					_addConditionLabel,
					strLang, m_asOwner));
			result.AddInnerHTMLElement(
				DynamicQueryTable.GetRemoveLastConditionButton(
					_removeConditionLabel,
					strLang, m_asOwner));
			if (_allowSubclauses) 
			{
				result.AddInnerHTMLElement(
					DynamicQueryTable.GetAddNewClauseButton(
						_addClauseLabel,
						strLang, m_asOwner));
				result.AddInnerHTMLElement(
					DynamicQueryTable.GetRemoveClauseButton(
						_removeClauseLabel,
						strLang, m_asOwner));
			}
			if(_addTestButton)
			{
				result.AddInnerHTMLElement(
					DynamicQueryTable.GetTestButton(
						m_asOwner.GetString(2600, "ptmsgs_portaladminmsgs"),
						_testButtonOnClickScript,						
						m_asOwner));

			}
		} 
		else 
		{
			boolean showAddStmtButton = true;
			boolean showRemoveStmtButton = true;
			
			HTMLTable table = new HTMLTable();
			table.SetBorder("0");
			table.SetCellPadding("0");
			table.SetCellSpacing("0");
			table.SetWidth("100%");
			result.AddInnerHTMLElement(table);
			HTMLTableRow row = new HTMLTableRow();
			row.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BG);
			table.AddInnerHTMLElement(row);
			HTMLTableCell cell;
					
	
			// If we allow only one clause, turn off the add or remove statement
			// buttons when that one clause satisfies certain conditions
			if (!_allowSubclauses) 
			{
				int numStmts = model.GetNumItemsInFirstClause();

				if (0 == numStmts) 
				{
					showRemoveStmtButton = false;
				}

				if (m_tablesize == numStmts) 
				{
					showAddStmtButton = false;
				}
			}

			if (showAddStmtButton) 
			{
				cell = new HTMLTableCell();
				cell.SetHeight("25");
				cell.SetNoWrap(true);
				row.AddInnerHTMLElement(cell);
				cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
				cell.AddInnerHTMLElement(
					RepostQueryTable.GetAddConditionButton(
						_addConditionLabel,
						strLang));
				cell = new HTMLTableCell();
				cell.SetHeight("25");
				cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
				row.AddInnerHTMLElement(cell);
				PTConstruct construct = ConstructFactory.GetConstruct(PTImageType.SPACER,
						true);
				HTMLImg img		   = (HTMLImg) construct.GetHTMLElement();
				img.SetWidth(XPConvert.ToString(1));
				img.SetHeight("1");
				img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
				cell.AddInnerHTMLElement(img);

			}

			if (showRemoveStmtButton) 
			{
				cell = new HTMLTableCell();
				cell.SetHeight("25");
				cell.SetNoWrap(true);
				row.AddInnerHTMLElement(cell);
				cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_BTN);
				cell.AddInnerHTMLElement(
					RepostQueryTable.GetRemoveLastConditionButton(
						_removeConditionLabel,
						strLang));
				cell = new HTMLTableCell();
				cell.SetHeight("25");
				cell.SetStyleClass(PTStyleClass.ACTIONBAR_OBJECT_DIVIDER);
				row.AddInnerHTMLElement(cell);
				PTConstruct construct = ConstructFactory.GetConstruct(PTImageType.SPACER,
						true);
				HTMLImg img		   = (HTMLImg) construct.GetHTMLElement();
				img.SetWidth(XPConvert.ToString(1));
				img.SetHeight("1");
				img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
				cell.AddInnerHTMLElement(img);

			}
			cell = new HTMLTableCell();
			cell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			cell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			row.AddInnerHTMLElement(cell);
			
			// Show the add/remove clause buttons if desired
			if (_allowSubclauses) 
			{
				result.AddInnerHTMLElement(
					RepostQueryTable.GetAddNewClauseButton(
						_addClauseLabel,
						strLang));
				result.AddInnerHTMLElement(
					RepostQueryTable.GetRemoveClauseButton(
						_removeClauseLabel,
						strLang));
			}
		}

		return result;
	}
	

	public boolean QueryContainsValidationProblemsOnRender()
	{
		return m_bAtLeastOneErrorOccurred;
	}
	
	/**
	 *  Subclasses may override to turn off the display of errors
	 *  under certain circumstances
	 */
	protected boolean GetDoValidation() {
		return true;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	protected boolean GetUseJavascriptStatementButtons() {
		return _useJavascriptStatementButtons;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetAddClauseLabel(String s) {
		_addClauseLabel = s;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetAddConditionLabel(String s) {
		_addConditionLabel = s;
	}

	/**
	 * 
	 *
	 * @param b 
	 */
	protected void SetAllowSubclauses(boolean b) {
		_allowSubclauses = b;
	}

	/**
	 * 
	 *
	 * @param b 
	 */
	protected void SetErrorsNextToTextBoxes(boolean b) {
		_errorsNextToTextBoxes = b;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetPropertyLabel(String s) {
		_propertyLabel = s;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetRemoveClauseLabel(String s) {
		_removeClauseLabel = s;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetRemoveConditionLabel(String s) {
		_removeConditionLabel = s;
	}

	/**
	 * 
	 *
	 * @param a 
	 */
	protected void SetRepostAction(int a) {
		_repostAction = a;
	}
	
	/**
	 * 
	 *
	 * @param size 
	 */
	protected void SetShowSearchBox(boolean b) {
		_showSearchBox = b;
	}	

	/**
	 * 
	 *
	 * @param size 
	 */
	protected void SetStatementCount(int size) {
		m_tablesize = size;
	}

	/**
	 * 
	 */
	protected void SetTextSearchAboveButtons() {
		_putTextSearchAboveButtons = true;
	}

	/**
	 * 
	 *
	 * @param e 
	 */
	protected void SetTextboxLabel(HTMLElement e) {
		_textboxLabel = e;
	}

	public  void SetAddTestButton() {
		_addTestButton = true;
	}
	/**
	 * 
	 *
	 * @param b 
	 */
	protected void SetUseJavascriptStatementButtons(boolean b) {
		_useJavascriptStatementButtons = b;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetViewTitle(String s) {
		_viewTitle = s;
	}

	/**
	 * 
	 *
	 * @param s 
	 */
	protected void SetWidth(String s) {
		_width = s;
	}
	
	public void SetUseCheckboxLayout() 
	{
		_useCheckboxLayout = true;
	}

	// Pass in the function definition to call when the test button is pressed.
	public void SetTestButtonScript(String script)
	{
		_testButtonScript = script;
	}
	
	// Pass in the OnClick script for the test filter button.
	public void SetTestButtonOnClickScript(String script)
	{
		_testButtonOnClickScript = script;
	}
    
 	public static HTMLElementCollection GetPagePreFormContent(AActivitySpace asOwner)
  	{
   	 	JSDateTimePickerMgr mgr = FilterForm.MakeTempDateTimePickerMgr(asOwner);
			return mgr.GetPagePreFormContent();
  	}
 	
 	private void SetError(HTMLElement _error, String _message, String _groupcnt, String _itemcnt)
 	{
	    m_bAtLeastOneErrorOccurred = true;
	    
		if (!_errorsNextToTextBoxes) 
		{
			if(_allowSubclauses)
			{
				_error.AddInnerHTMLString(XPResourceManager.FormatMessage(
						m_asOwner.GetString(201, "ptmsgs_portalcommonmsgs"),
						XPConvert.ToString(_groupcnt),
						XPConvert.ToString(_itemcnt),
						_message));
			}
			else
			{
				_error.AddInnerHTMLString(XPResourceManager.FormatMessage(
				        m_asOwner.GetString(736, "ptmsgs_portalcommonmsgs"),
				        XPConvert.ToString(_itemcnt),
				        _message));
			}
			
			_error.AddInnerHTMLElement(new HTMLBr());
		}
 	}
 	
 	/* Test function for unit tests.  There are too many objects in the original Display() function that would need to be
 	 * mocked out to test that the Display() will generate correctly via a unit test of the SearchCriteriaDisplay tag.  
 	 * This function was created to showcase that the unit test is calling Display() properly, but stubbing the data b/c it's cleaner
 	 * to do it this way than try and alter the ASFilterView.Display() method to call a modified Display() function if it's
 	 * a test instance.  There is a risk that the production code would get altered via incorrect logic which can be avoided.
 	 * @return
 	 */
 	public HTMLElement TestDisplay()
 	{
 		HTMLElement test = new HTMLElementCollection();
 		test.AddInnerHTMLString("This is test data from FilterView.TestDisplay");
 		return test;
 		
 	}
  	
}

