package com.plumtree.portalpages.common.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.tree.*;

/**
 *  @author CraigS, based on MikeS/OlegS code
 */
public class FolderSelectorRepostControl extends EditorHelperRepostControl
{
	
	public static final String STR_MVC_CLASS_NAME = "FolderSelectorRepostControl";

	// Repost actions

	
	public static final int ACTION_DEL		   = 5411;

	
	public static final int ACTION_ADD_ADMIN   = 5412;

	
	public static final int ACTION_ADD_CATALOG = 5413;

	/**
	 * 
	 *
	 * @return 
	 */
	public Object Create()
	{
		return new FolderSelectorRepostControl();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param action 
	 * @param formData 
	 */
	public void PerformRepostAction(int action, XPHashtable formData)
	{
		IFolderSelectorModel model     = (IFolderSelectorModel) m_model;
		IFolderSelectorModelRO modelRO = (IFolderSelectorModelRO) m_model;

		// If we're deleting
		if (ACTION_DEL == action)
		{
			// The folder(s) to delete are marked by HTMLCHECKBOX_FOLDER.
			String[] folders = (String[]) formData.GetElement(FolderSelectorView.HTMLCHECKBOX_FOLDER);

			if ((null != folders) && (folders.length > 0))
			{
				int admCount = 0;
				int catCount = 0;

				for (int j = 0; j < folders.length; j++)
				{
					if (folders[j].startsWith(FolderSelectorView.FOLDER_PFX_ADM))
					{
						admCount += 1;
					}
					else
					{
						catCount += 1;
					}
				}

				// Delete admin folders, if any
				if (admCount > 0)
				{
					int[] folderIDs = new int[admCount];
					int k		    = 0;

					for (int j = 0; j < folders.length; j++)
					{
						if (folders[j].startsWith(
									FolderSelectorView.FOLDER_PFX_ADM))
						{
							try
							{
								folderIDs[k] = XPConvert.ToInteger(folders[j].substring(
											2));
							}
							catch (Exception e)
							{
								throw XPException.GetInstance(e);
							}

							k++;
						}
					}

					model.DeleteFolders( /* isAdmin= */
						true, folderIDs);
				}

				// Delete catalog folders, if any
				if (catCount > 0)
				{
					int[] folderIDs = new int[catCount];
					int k		    = 0;

					for (int j = 0; j < folders.length; j++)
					{
						if (folders[j].startsWith(
									FolderSelectorView.FOLDER_PFX_CAT))
						{
							try
							{
								folderIDs[k] = XPConvert.ToInteger(folders[j].substring(
											2));
							}
							catch (Exception e)
							{
								throw XPException.GetInstance(e);
							}

							k++;
						}
					}

					model.DeleteFolders( /* isAdmin= */
						false, folderIDs);
				}
			}

			return;
		}

		// If we're adding
		else if ((ACTION_ADD_ADMIN == action) ||
				(ACTION_ADD_CATALOG == action))
		{
			boolean isAdminChecked = (ACTION_ADD_ADMIN == action);

			// We need to get the selected items out of the tree popup.
			String treeName = (isAdminChecked ? "AdminFolderTree"
											  : "CatFolderTree");

			ATreeAS treeSpace = (ATreeAS) (m_asOwner.GetSubSpace(treeName));
			ITreeModel tree   = (ITreeModel) treeSpace.GetModel(ATreeAS.TREEMODEL);

			model.AddFoldersFromTreeSelections(isAdminChecked, tree);

			if (!modelRO.GetMultiSelectMode())
			{
				// In single select mode, we don't reuse the same selection tree, 
				// so we should remove its subspace to avoid confusing it with the
				// next tree we create
				m_asOwner.DeleteSubSpace(treeName);
			}
		}
	}
}

