package com.plumtree.portalpages.common.search;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.pathways.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.server.PT_CLASSIDS;
import com.plumtree.uiinfrastructure.constants.ResourceConstants;
import com.plumtree.xpshared.htmlconstructs.PTStyleClass;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author CraigS, based on MikeS/OlegS code
 */
public abstract class TypeSelectorView extends EditorLikeView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.search.TypeSelectorView");
  
  public static final String HTMLBUTTON_REVEALCLASSIDS   = "in_bu_showclassids";

  public static final String HTMLBUTTON_HIDECLASSIDS     = HTMLBUTTON_REVEALCLASSIDS;

  
  public static final String HTMLHIDDEN_STATUSCLASSIDS   = "in_hi_statusclassids";
  
  //this represents the additional hidden form elements for the object types filter
  public static final String HTMLHIDDEN_ADVSEARCH_CLASSIDS = "in_hi_hidden_advsearch_classid";

  
  public static final String HTMLCHECKBOX_CLASSID_BROAD  = "in_cb_classidbroad";

  
  public static final String HTMLCHECKBOX_CLASSID_DETAIL = "in_cb_classiddetail";
  
  public static final String CB_CHECK_ALL = "in_cb_toggleAllTSV";

  private ITypeSelectorModelRO _model = null;
  private static final String EMPTY = "";

  /**
   * Displays the HTML for the result types filter.
   */
  public HTMLElement Display()
  {
    _model = (ITypeSelectorModelRO) m_model;
    int[] _classIDs = _model.GetOrderedClassIds();
    
    IPathwaysRestAPIService pathwaysHelper = PathwaysRestAPIService.GetInstance(m_asOwner);
    boolean isPathwaysEnabled = pathwaysHelper.IsPathwaysEnabled();
    
    // if pathways is enabled, we must strip portlet bundles out of the array so we can
    // display the advanced search result types filter without it.
    if (isPathwaysEnabled)
    {
    	int length = _classIDs.length;
    	// We are removing 1 item from the classIDs array, so we are creating a temporary array with 1 less item.
    	int[] tempIDs = new int[length - 1];
    	int j =0;
    	
    	// Although we know the index in which portlet bundles is stored in the classIds array, we still have to
    	// recreate the array with -1 item.  
    	for (int i = 0; i< length; i++)
    	{
    		//classid_17 is portlet bundles
    		if ((_classIDs[i] == SearchObjectTypes.CLASSID_17))
    		{
    			// do nothing, since we want to omit this item from the array
    		}
    		else
    		{
    			tempIDs[j] = _classIDs[i];
    			j++;	//separate counter must be kept
    		}
    	}
    	// assigning the modified array back to the classids array.
    	_classIDs = tempIDs;
    }

    HTMLElementCollection result = new HTMLElementCollection();

    try
    {
      result.AddInnerHTMLElement(super.GetHeaderView(GetTitle(), true));

      HTMLTable table = new HTMLTable();
      table.SetCellSpacing("0");
      table.SetCellPadding("5");
      table.SetWidth("100%");
      result.AddInnerHTMLElement(table);

      HTMLTableRow row = new HTMLTableRow();
      table.AddInnerHTMLElement(row);
      row.SetStyleClass(PTStyleClass.OBJECT_CONTENT_BG);

      HTMLTableCell cell = new HTMLTableCell();
      cell.SetWidth("100%");
      cell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
      row.AddInnerHTMLElement(cell);

      HTMLDiv broadDiv = new HTMLDiv();
      broadDiv.SetID("broaddiv");
      if (_model.ShowAbstractTypeView()) {
        cell.AddInnerHTMLElement(broadDiv);
      }

      HTMLDiv detailDiv = new HTMLDiv();
      detailDiv.SetID("detaildiv");
      cell.AddInnerHTMLElement(detailDiv);

      if (_model.AreDetailedOptionsShown())
      {
        broadDiv.SetStyle("display: none;");
      }
      else
      {
        detailDiv.SetStyle("display: none;");
      }

      // create the show more options button
      HTMLInput broadOrDetailInput = new HTMLInput(HTMLInputTypes.HIDDEN,
          HTMLHIDDEN_STATUSCLASSIDS, EMPTY);
      if (_model.AreDetailedOptionsShown()) {
        broadOrDetailInput.SetValue("REVEALED");
      } else {
        broadOrDetailInput.SetValue("HIDDEN");
      }
      broadOrDetailInput.SetID("broadordetail");
      result.AddInnerHTMLElement(broadOrDetailInput);

      HTMLInput showInput = new HTMLInput(HTMLInputTypes.BUTTON,
          HTMLBUTTON_REVEALCLASSIDS, EMPTY);
      showInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

      showInput.SetValue(m_asOwner.GetString(230,
          ResourceConstants.PORTALCOMMONMSGS));
      showInput.SetOnClick("showDetailedOptions();");

      // BEGIN: assembling broadDiv
      HTMLB bold = new HTMLB();
      broadDiv.AddInnerHTMLElement(bold);

      bold.AddInnerHTMLString(m_asOwner.GetString(232,
          ResourceConstants.PORTALCOMMONMSGS));
      broadDiv.AddInnerHTMLElement(new HTMLBr());

      // Pathways doesn't support portlet bundles, so we have to ensure the count
      // is -1 of everything.
      int temporarySearchObjectTypesCount = 0;
      int tempClassIDCount = 0;
      if (isPathwaysEnabled)
      {
    	  // -1 for portlet bundles
    	  temporarySearchObjectTypesCount = SearchObjectTypes.DETAILEDCOUNT -1;
    	  tempClassIDCount = SearchObjectTypes.CLASSIDCOUNT - 1;
      }
      else {
    	  temporarySearchObjectTypesCount = SearchObjectTypes.DETAILEDCOUNT;
    	  tempClassIDCount = SearchObjectTypes.CLASSIDCOUNT;
      }
      for (int last = temporarySearchObjectTypesCount;
          last < tempClassIDCount; last++)
      {
        if ((last + 3) == tempClassIDCount)
        {
          broadDiv.AddInnerHTMLElement(new HTMLBr());
		  bold = new HTMLB();
          broadDiv.AddInnerHTMLElement(bold);

          bold.AddInnerHTMLString(m_asOwner.GetString(233,
              ResourceConstants.PORTALCOMMONMSGS));
          broadDiv.AddInnerHTMLElement(new HTMLBr());
        }

        HTMLInput myInput = new HTMLInput(HTMLInputTypes.CHECKBOX,
            HTMLCHECKBOX_CLASSID_BROAD, EMPTY);
        myInput.SetChecked(_model.IsTypeSelected(_classIDs[last]));
        myInput.SetValue(XPConvert.ToString(_classIDs[last]));
        myInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
        broadDiv.AddInnerHTMLElement(myInput);

        broadDiv.AddInnerHTMLString(GetDisplayableNameForType(_classIDs[last]));
        broadDiv.AddInnerHTMLElement(new HTMLBr());
      }

      broadDiv.AddInnerHTMLElement(new HTMLBr());
      broadDiv.AddInnerHTMLElement(showInput);

      // END: assembling broadDiv
      // BEGIN: assembling detailDiv

      int maxToDisplay = SearchObjectTypes.ENDUSERCOUNT;
      if (_model.ShouldDisplayAdminObjects()) {
        maxToDisplay = SearchObjectTypes.DETAILEDCOUNT;
      }
      HTMLTable detailTable = new HTMLTable();
      detailTable.SetCellPadding("2");
      detailTable.SetCellSpacing("2");
      detailTable.SetBorder("0");
      detailTable.SetWidth("100%");
      detailDiv.AddInnerHTMLElement(detailTable);
      row = new HTMLTableRow();
      detailTable.AddInnerHTMLElement(row);
	  row.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
			
		  // Type header cell
	  cell = new HTMLTableCell();
	  cell.SetHeight("20");
	  cell.SetWidth("20");
	  cell.SetVAlign(CommonHTMLStrings.MIDDLE);
	  row.AddInnerHTMLElement(cell);
	  cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
	  
	  cell.SetVAlign(CommonHTMLStrings.MIDDLE);
	  HTMLInput checkB = new HTMLInput(HTMLInputTypes.CHECKBOX,CB_CHECK_ALL, "");
	  checkB.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
	  checkB.SetOnClick("DoToggleAllCBsTSV()");
	  cell.AddInnerHTMLElement(checkB);


	  cell = new HTMLTableCell();
	  cell.SetHeight("20");
	  cell.SetWidth("100%");
	  cell.SetVAlign(CommonHTMLStrings.MIDDLE);
	  row.AddInnerHTMLElement(cell);
	  cell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
	  cell.AddInnerHTMLString(m_asOwner.GetString(744,ResourceConstants.PORTALCOMMONMSGS));

      boolean allChecked = true;
      int count = 0;
      for (int i = 0; i < maxToDisplay; i += 1)
      {
      	boolean display = true;
      	boolean ischecked;
      	
		if(_classIDs[i] == SearchObjectTypes.CONTENT_APPLICATION || _classIDs[i] == SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE)
		{
			ischecked = _model.IsTypeSelected(SearchObjectTypes.CONTENT_APPLICATION) || _model.IsTypeSelected(SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE);
			
			display = _model.ContentInstalled();
		}
		else if(_classIDs[i] == SearchObjectTypes.COLLAB_APPLICATION ||
			_classIDs[i] == SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE)
		{
			ischecked = _model.IsTypeSelected(SearchObjectTypes.COLLAB_APPLICATION) ||
				_model.IsTypeSelected(SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE);

			display = _model.CollabInstalled();
		}
		//Bug 21114
		else if(_classIDs[i] == PT_CLASSIDS.PT_SITEMAPFOLDER_ID)
		{
			display = false;
			ischecked = _model.IsTypeSelected(_classIDs[i]);
		}
		else
		ischecked = _model.IsTypeSelected(_classIDs[i]);
		
		if(display)	
		{
			count++;
			row = new HTMLTableRow();
			detailTable.AddInnerHTMLElement(row);
			if(count % 2 == 1)
				row.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			else
				row.SetStyleClass(PTStyleClass.LIST_ITEM_ONE_BG);

			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("20");
			cell.SetWidth("20");
			cell.SetVAlign(CommonHTMLStrings.MIDDLE);		

	        HTMLInput cbInput = new HTMLInput(HTMLInputTypes.CHECKBOX,HTMLCHECKBOX_CLASSID_DETAIL, EMPTY);
	        allChecked &= ischecked;
	        cbInput.SetChecked(ischecked);
	        cbInput.SetValue(XPConvert.ToString(_classIDs[i]));
	        cbInput.SetStyleClass(PTStyleClass.FORM_CHECKBOX_TEXT);
	        cell.AddInnerHTMLElement(cbInput);
	        
			cell = new HTMLTableCell();
			row.AddInnerHTMLElement(cell);
			cell.SetHeight("20");
			cell.SetVAlign(CommonHTMLStrings.MIDDLE);		
	        
	        HTMLSpan span = new HTMLSpan();
	        span.SetStyleClass(PTStyleClass.OBJECT_TEXT);
	        span.AddInnerHTMLString(GetDisplayableNameForType(_classIDs[i]));
			cell.AddInnerHTMLElement(span);
		}
      }
	  checkB.SetChecked(allChecked);


      // only show the "check all"/"clear all" buttons if there is a long list
/*      
      if (_model.ShouldDisplayAdminObjects()) {
        HTMLAnchor anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        anchor.SetOnClick("checkAllTypes(); return false;");

        anchor.AddInnerHTMLString(m_asOwner.GetString(235,
          ResourceConstants.PORTALCOMMONMSGS));
        detailDiv.AddInnerHTMLElement(anchor);
        detailDiv.AddInnerHTMLString("&nbsp;|&nbsp;");
        anchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
        anchor.SetOnClick("clearAllTypes(); return false;");

        anchor.AddInnerHTMLString(m_asOwner.GetString(236,
                                  ResourceConstants.PORTALCOMMONMSGS));
        detailDiv.AddInnerHTMLElement(anchor);
        detailDiv.AddInnerHTMLElement(new HTMLBr());
      }
*/	
      if (_model.ShowAbstractTypeView()) {
        // only show the "show broad options" button if we're allowed to
        HTMLInput hideInput = new HTMLInput(HTMLInputTypes.BUTTON,
                                            HTMLBUTTON_HIDECLASSIDS, EMPTY);
        hideInput.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);

        hideInput.SetValue(m_asOwner.GetString(231, ResourceConstants.PORTALCOMMONMSGS));
        hideInput.SetOnClick("showBroadOptions();");
        detailDiv.AddInnerHTMLElement(new HTMLBr());
        detailDiv.AddInnerHTMLElement(hideInput);
      }
    }
    catch (Exception e)
    {
      
        log.Error(e, e.getMessage());
      

      throw new XPException(m_asOwner.GetString(228,
          ResourceConstants.PORTALCOMMONMSGS), e);
    }

    return result;
  }

  /**
   * 
   *
   * @return 
   */
  public HTMLScript DisplayJavascript()
  {
    HTMLScript script  = new HTMLScript("text/javaScript");
    XPStringBuilder sb = new XPStringBuilder();

    try
    {
      sb.Append("\nfunction showDetailedOptions()\n");
      sb.Append("{\n");
      sb.Append("  var options = document.getElementById('detaildiv');\n");
      sb.Append(
        "  var status = document.getElementById('broadordetail');\n");
      sb.Append("  var button = document.getElementById('broaddiv');\n");
      sb.Append("  status.value = 'REVEALED';\n");
      sb.Append("  options.style.display = '';\n");
      sb.Append("  button.style.display = 'none';\n");
      sb.Append("}\n");
      sb.Append("\n");
      sb.Append("\nfunction showBroadOptions()\n");
      sb.Append("{\n");
      sb.Append("  var options = document.getElementById('detaildiv');\n");
      sb.Append(
        "  var status = document.getElementById('broadordetail');\n");
      sb.Append("  var button = document.getElementById('broaddiv');\n");
      sb.Append("  status.value = 'HIDDEN';\n");
      sb.Append("  options.style.display = 'none';\n");
      sb.Append("  button.style.display = '';\n");
      sb.Append("}\n");

/*
      sb.Append("function checkAllTypes()\n");
      sb.Append("{\n");
      sb.Append("  setTypeCheckboxes(true);");
      sb.Append("}\n");
      sb.Append("function clearAllTypes()\n");
      sb.Append("{\n");
      sb.Append("  setTypeCheckboxes(false);");
      sb.Append("}\n");

      sb.Append("function setTypeCheckboxes(value)\n");
      sb.Append("{\n");
      sb.Append("  var fElem = document.").Append(AFormDP.HTMLFORM_NAME)
      .Append(";\n");
      sb.Append("  var feLen = fElem.elements.length;\n");
      sb.Append("  for (var i = 0; i < feLen; i++) {\n");
      sb.Append("    if (fElem.elements[i].name == \"")
      .Append(HTMLCHECKBOX_CLASSID_DETAIL).Append("\") {\n");
      sb.Append("      fElem.elements[i].checked = value;\n");
      sb.Append("    }\n");
      sb.Append("  }\n");
      sb.Append("}\n");
*/
	  sb.Append("\n\nfunction DoToggleAllCBsTSV() {\n");
	  sb.Append("    var fElem = document.mainform;\n");
	  sb.Append("    var feLen = fElem.elements.length;\n");
	  sb.Append("    var checkVal = false;\n");
	  sb.Append("    for (var i = 0; i < feLen; i++) {\n");
	  sb.Append("        if (fElem.elements[i].name == '" + CB_CHECK_ALL + "') {\n");
	  sb.Append("            checkVal = fElem.elements[i].checked;\n");
	  sb.Append("        }\n");
	  sb.Append("    }\n");
	  sb.Append("    for (var i = 0; i < feLen; i++) {\n");
	  sb.Append("        if (fElem.elements[i].name.indexOf('" + HTMLCHECKBOX_CLASSID_DETAIL + "') != -1) {\n");
	  sb.Append("             fElem.elements[i].checked = checkVal;\n");
	  sb.Append("        }\n");
	  sb.Append("    }\n");
	  sb.Append("    return true;\n"); 
	  sb.Append("}\n"); 

      script.AddInnerHTMLString(sb.ToString());
    }
    catch (Exception e)
    {
      
        log.Error(e, "TypeSelectorView::Display An error occured when trying to display the HTML.");
      
     throw new XPException(m_asOwner.GetString(228,
          ResourceConstants.PORTALCOMMONMSGS), e);
    }

    return script;
  }

  /**
   * 
   *
   * @return 
   */
  protected String GetTitle()
  {
    return m_asOwner.GetString(229, ResourceConstants.PORTALCOMMONMSGS);
  }

  private String GetDisplayableNameForType(int classID) {
    switch (classID) {
    case SearchObjectTypes.DOCUMENT_ABSTRACTTYPE:
      return m_asOwner.GetString(239, ResourceConstants.PORTALCOMMONMSGS);
    case SearchObjectTypes.FOLDER_ABSTRACTTYPE:
      return m_asOwner.GetString(240, ResourceConstants.PORTALCOMMONMSGS);
    case SearchObjectTypes.OTHER_ABSTRACTTYPE:
      return m_asOwner.GetString(241, ResourceConstants.PORTALCOMMONMSGS);
    case SearchObjectTypes.PORTAL_APPLICATION:
      return m_asOwner.GetString(242, ResourceConstants.PORTALCOMMONMSGS);
    case SearchObjectTypes.COLLAB_APPLICATION_ON_DETAIL_PAGE:
    case SearchObjectTypes.COLLAB_APPLICATION:
      return m_asOwner.GetString(237, ResourceConstants.PORTALCOMMONMSGS);
    case SearchObjectTypes.CONTENT_APPLICATION:
    case SearchObjectTypes.CONTENT_APPLICATION_ON_DETAIL_PAGE:
      return m_asOwner.GetString(238, ResourceConstants.PORTALCOMMONMSGS);
    default:
      break;
    }

    return SearchResultModel.getDisplayableNameForType(m_asOwner, classID);
  }
  
}

