package com.plumtree.portalpages.common.uiparts;

import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.openfoundation.web.XPHttpUtility;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The View for the default Footer if none is assigned or found.
 * 
 * @author RobertZ
 * @author DavidP
 */
public class DefaultFooterView implements IView
{
	/** MVC Name */
	public static final String STR_MVC_CLASS_NAME = "DefaultFooterView";
	private AActivitySpace m_asOwner;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DefaultFooterView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = null;

		try
		{
			HTMLElementCollection resultGroup = new HTMLElementCollection();
			resultGroup.AddInnerHTMLElement(GetTable());
			result = resultGroup;
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating footer: " +
					e.getMessage());
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner = parent;
	}

	/**
	 * Form default Footer HTML
	 * 
	 * @return HTMLElement					The HTML for the Footer
	 */
	private HTMLElement GetTable()
	{
		HTMLElement result = null;

		try
		{
			// Create footer table
			HTMLTable footerTable = new HTMLTable();
			footerTable.SetID(PTStyleID.PT_FOOTER);
			footerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			footerTable.SetCellPadding(CommonHTMLStrings.FIVE);
			footerTable.SetBorder(CommonHTMLStrings.ZERO);
			footerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);

			// Create footer row
			HTMLTableRow onlyRow = (HTMLTableRow) footerTable.InsertInnerHTMLElement(new HTMLTableRow());

			// Set up table cell
			HTMLTableCell onlyCell = (HTMLTableCell) onlyRow.InsertInnerHTMLElement(new HTMLTableCell());
			onlyCell.SetVAlign(CommonHTMLStrings.MIDDLE);
			onlyCell.SetAlign(CommonHTMLStrings.CENTER);
			onlyCell.SetStyleClass(PTStyleClass.FOOT_HEADER_BG + " " + PTStyleClass.FOOT_TEXT);

			// Put subtitle in its own span
			HTMLSpan subtitleSpan = (HTMLSpan) onlyCell.InsertInnerHTMLElement(new HTMLSpan());
			subtitleSpan.SetStyleClass(PTStyleClass.FOOT_SUBTITLE);
			subtitleSpan.AddInnerHTMLString(m_asOwner.GetString(243, "ptmsgs_portalcommonmsgs"));

			// Continue adding content to the table cell
			/* onlyCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			onlyCell.AddInnerHTMLString(m_asOwner.GetString(244, "ptmsgs_portalcommonmsgs")); */

			// Deliver the finished footer table
			result = footerTable;			
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating footer table: " + e.getMessage());
		}

		return result;
	}
}

