package com.plumtree.portalpages.common.uiparts;

import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * The View for the default Header if none is assigned or found.
 * 
 * @author RobZ
 */
public class DefaultHeaderView implements IView
{
	/** MVC Name */
	public static final String STR_MVC_CLASS_NAME = "DefaultHeaderView";
	private AActivitySpace m_asOwner;
	private NavigationModel m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new DefaultHeaderView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = null;

		try
		{
			HTMLElementCollection resultGroup = new HTMLElementCollection();
			resultGroup.AddInnerHTMLElement(GetTable());
			result = resultGroup;
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating banner: " + e.getMessage());
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	
	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_model		  = (NavigationModel) model;
	}

	/**
	 * Method GetTable.  Form default header banner.
	 * 
	 * @return HTMLElement				The HTML for the banner
	 */
	private HTMLElement GetTable()
	{
		HTMLElement result = null;
		
		try
		{
			/* Build common things we'll need for both standard and 508 display modes */

			// Create outermost table for header
			HTMLTable headerTable = new HTMLTable();
			headerTable.SetID(PTStyleID.PT_HEADER);
			headerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			headerTable.SetCellPadding(CommonHTMLStrings.ZERO);
			headerTable.SetBorder(CommonHTMLStrings.ZERO);
			headerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
			// Add only row to table
			HTMLTableRow headerTableRow = (HTMLTableRow) headerTable.InsertInnerHTMLElement(new HTMLTableRow());
			headerTableRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
			headerTableRow.SetVAlign(CommonHTMLStrings.TOP);

			// Add left cell to table row
			HTMLTableCell leftCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
			leftCell.SetID(PTStyleID.PT_HEADER_LEFT);

			// Add right cell to table row
			HTMLTableCell rightCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
			rightCell.SetID(PTStyleID.PT_HEADER_RIGHT);
			rightCell.SetNoWrap(true);

			// Build title H1 and add to right cell
			HTMLH1 titleH1 = new HTMLH1();
			titleH1.AddInnerHTMLEncodedString(m_model.GetTitleForBanner());
			titleH1.SetStyleClass(PTStyleClass.BAN_HEADER);
			rightCell.AddInnerHTMLElement(titleH1);

			// Build subtitle H2 and add to right cell
			HTMLH2 subTitleH2 = new HTMLH2();
			subTitleH2.AddInnerHTMLEncodedString(m_model.GetSubtitleForBanner());
			subTitleH2.SetStyleClass(PTStyleClass.BAN_SUBHEADER);
			rightCell.AddInnerHTMLElement(subTitleH2);

			/* Prepare table cells tailored specifically for either standard or 508 modes */
			
			if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
			{
				// Configure left cell
				leftCell.SetAlign(CommonHTMLStrings.LEFT);

				// Configure right cell
				rightCell.SetAlign(CommonHTMLStrings.RIGHT);
			}
			else    /* 508 mode */
			{
				// Configure left cell
				leftCell.SetAlign(CommonHTMLStrings.LEFT);
				leftCell.SetWidth(CommonHTMLStrings.TWO);
				leftCell.SetHeight("60");

				// Configure right cell
				rightCell.SetAlign(CommonHTMLStrings.LEFT);
				rightCell.SetWidth("200");
			}

			result = headerTable;
		}
		catch(Exception e)
		{
			result = new HTMLGenericElement("Error creating banner table: " + e.getMessage());
		}

		return result;
	}
}

