package com.plumtree.portalpages.common.uiparts;

import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Navigation model interface for MVC and pluggable navigation.
 * 
 * @author RobZ
 * @author DavidP
 *
 */
public interface INavigationModelRO extends IPluggableNavModelRO
{
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create();

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.IPluggableNavModelRO#GetAccessibleCommunityID(int)
	 */
	public int GetAccessibleCommunityID(int nSubPortalCommID);

	/**
	 * Gets the link to Administration 
	 * @return ICPListEntryIterator
	 */
	public ICPListEntryIterator GetAdminLink();



	/** 
	 * Never check IsCommunityPage before calling this function. Has internal
	 * security check and need to display the edit community membership entry
	 * even when not on community pages.
	 *
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetMyPortalActions(int,
	 *      int)
	 */
	public ICPListEntryIterator GetCommunityActions();

	/**
	 * Gets the Community Pages from the current Community
	 * @return ICPListEntryIterator containing current Community Pages
	 */
	public ICPListEntryIterator GetCurCommPages();

	/**
	 * Gets the ID of the current Community (if in one)
	 * @return Object ID of the current Community
	 */
	public int GetCurCommunityID();

	/**
	 * Gets the name of the current Community (if in one) 
	 * @return Name of the current Community
	 */
	public String GetCurCommunityName();

	/**
	 *  Gets the id of the current document directory folder, or 0 if we are
	 *  not currently in a single doc directory folder.
	 * @return Current Document Directory Folder ID, 0 if not in the Document Directory 
	 */
	public int GetCurDocDirFolderID();

	/**
	 * Get the Mandatory Tabs for the current user
	 *
	 * @param bAddAdminLink				Include Admin link in the list
	 * @return ICPListEntryIterator containing Mandatory Community tabs
	 */
	public ICPListEntryIterator GetCurMandatoryTabs(boolean bAddAdminLink);

	/**
	 * Gets the Mypages for the current user
	 * @param bShowActions				Include Mypage actions
	 * @return ICPListEntryIterator with Mypages
	 */
	public ICPListEntryIterator GetCurMyPages(boolean bShowActions);

	/**
	 * Gets the current page ID, either Mypage or Community
	 * @return Current Mypage or Community page ID
	 */
	public int GetCurPageID();

	/**
	 * Gets the current page name
	 * @return Page Name
	 */
	public String GetCurPageName();

	/**
	 * Get the related communities of the current community
	 *
	 * @return ICPListEntryIterator 
	 */
	public ICPListEntryIterator GetCurRelCommunities();

	/**
	 * Gets the subcommunities of the current community
	 * @return ICPListEntryIterator
	 */
	public ICPListEntryIterator GetCurSubCommunities();

	//
	// Subportal functions END
	//
	//
	// Misc functions
	//

	/**
	 * Gets the default community ID of the current user
	 * 
	 * @return
	 */
	public int GetDefaultCommunity();

	/**
	 * Gets the URL to the default subportal of the current user
	 *
	 * @return 
	 */
	public ASURL GetDefaultSubportalURL();

	/**
	 * Get the directory links 
	 *
	 * @return ICPListEntryIterator
	 */
	public ICPListEntryIterator GetDirectoryLinks();

	/**
	 * Get footer element
	 *
	 * @return HTMLElementCollection
	 */
	public HTMLElementCollection GetFooterElement();

	/**
	 * Checks if a footer has been set for the current page
	 *
	 * @return True if a footer has been set
	 */
	public boolean GetFooterHasBeenSet();

	/**
	 * Checks if a header has been set for the current page
	 *
	 * @return True if a header has been set
	 */
	public boolean GetHeaderHasBeenSet();
	
	/**
	 * Get header element
	 *
	 * @return HTMLElementCollection
	 */
	public HTMLElementCollection GetHeaderElement();
	

	/**
	 * Gets the greeting for the current user
	 *
	 * @return 					String greeting
	 */
	public String GetGreeting();


	/**
	 * Gets the mandatory links for the current user
	 * @return 					Mandatory links ICPListEntryIterator
	 */
	public ICPListEntryIterator GetMandatoryLinks();

	//
	// Subportal functions BEGIN
	//

	/**
	 * Gets the name for the mandatory links folder for the current user
	 * 
	 * @return 					Mandatory folder String name
	 */
	public String GetMandatoryLinksFolderName();

	/**
	 * Helper function, returns the join community link, community actions if on
	 * a community page and the list of communities.
	 *
	 * @param bListActions		True to return the community actions in the list, false otherwise
	 * @return  				Communities the current user is a member of in a ICPListEntryIterator
	 */
	public ICPListEntryIterator GetMyCommunities(boolean bListActions);

	/**
	 * Get the mypage actions for the current page and user
	 *
	 * @return An XPArrayList with ASURLContainer objects.
	 *
	 * @see com.plumtree.xpshared.browsing.myportal.IMyPortalModelHelper#GetMyPagesActions()
	 */
	public ICPListEntryIterator GetMyPageActions();

	/**
	 * @see com.plumtree.xpshared.activityspace.IModelRO#GetName()
	 */
	public String GetName();

	/**
	 * Gets the parent community for the current community. The list
	 * will only contain one item.
	 *
	 * @return 					Parent community 
	 */
	public ICPListEntryIterator GetParentComm();

	/**
	 * Gets the link to the user's My Account page (user portal preferences)
	 * @return 					Personal preference link in an ICPListEntryIterator
	 */
	public ICPListEntryIterator GetPortalSettings();

	/**
	 * Gets the current visibility status of the specified section. Use constants
	 * defined in com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility.
	 * 
	 * @param nSectionIDConst	Navigation section ID (defined in NavVisibility
	 * @return boolean			Section visible or not
	 * 
	 * @see com.plumtree.portalpages.common.uiparts.navpagetype.NavVisibility
	 */
	public boolean GetSectionVisibility(int nSectionIDConst);

	/**
	 * Checks if the specified feature is enabled for current user's subportal 
	 *
	 * @param nType 			Feature type defined in PT_SUBPORTAL_ACCESS_TYPES
	 *
	 * @return 					Feature enabled or not
	 */
	public boolean GetSubPortalEnabled(int nType);

	/**
	 * Gets the page type of the current user's default my home page-type.
	 * 
	 * 
	 * @return 	int				Page type, -1 one if none can be found.			
	 */
	public int GetSubPortalFirstPageType();

	/**
	 * Gets the navigation scheme set for the current user 
	 *
	 * @return 					Navigation scheme ID
	 */
	public int GetSubPortalNavScheme();

	/**
	 * Gets the Page ID of the first page a user should see after logging in.
	 * Set on a user's Subportal
	 *
	 * @return 					Page ID of the first page a user is redirected to after logging in 
	 */
	public int GetSubPortalPageID();

	/**
	 * Gets the Banner set in the subportal
	 *
	 * @return 					Banner HTMLElement
	 */
	public HTMLElement GetSubportalBanner();

	/**
	 * Gets the footer set in the subportal
	 *
	 * @return 					Footer HTMLElement
	 */
	public HTMLElement GetSubportalFooter();

	/**
	 * Gets the subtitle of the current page
	 *
	 * @return 					Page Subtitle String
	 */
	public String GetSubtitleForBanner();

	/**
	 * Gets the title of the current page
	 *
	 * @return 					Page title String
	 */
	public String GetTitleForBanner();

	/**
	 * Checks if the current user has Administrator access
	 *
	 * @return 					boolean			
	 */
	public boolean HasAdministratorAccess();

	/**
	 * Checks if the current user has select access to the current community
	 *
	 * @return 					boolean
	 */
	public boolean HasSelectAccess();

	/**
	 * Checks if the current page is a Community Page
	 * @return 					boolean
	 */
	public boolean IsCommunityPage();

	/**
	 * Checks if the current user is the owner of the current Community
	 * @return 					boolean
	 */
	public boolean IsCurCommOwner();

	/**
 	 * Checks if the current page is a directory page
	 * @return 					boolean
	 */
	public boolean IsDirPage();

	/**
	 * Checks if the current user is the Guest user
	 * @return 					boolean
	 */
	public boolean IsGuestSession();
	
	/**
	 * Checks if the current user is a member of the current Community 
	 * @return 					boolean
	 */
	public boolean IsMemberInCurCommunity();

	/**
	 * Checks if the current page is the login page
	 * @return 					boolean
	 */
	public boolean IsLoginPage();

	/**
	 * Checks if the current page is a mypage
	 * @return 					boolean
	 */
	public boolean IsMyPage();

	/**
	 * Sets a new footer element
	 *
	 * @param bClearPrevContent			True to clear any previously set footer
	 * @param element					The new footer element
	 */
	public void SetFooterElement(boolean bClearPrevContent, HTMLElement element);

	/**
	 * Sets a new header element.
	 *
	 * @param bClearPrevContent			True to clear any previously set header
	 * @param element					The new header element
	 * @throws HTMLException
	 */
	public void SetHeaderElement(boolean bClearPrevContent, HTMLElement element);

	/**
	 * Set the visibility of the specified Navigation section.
	 * @param nSectionIDConst			Section ID defined in NavVisibility
	 * @param bShow						true if the section is displayed, false otherwise 
	 */
	public void SetSectionVisibility(int nSectionIDConst, boolean bShow);

	
	/**
	 * This function checks the MyPortalModel
	 * to see if the current page is a community preview page
	 * (certain actions are disabled in this case).
	 * 
	 * @return 							boolean
	 */
	public boolean IsPreviewPage();
	
	/**
	 * Used by pluggable navigation to access the MyPages model
	 * @return 							The MyPortal IModel interface
	 */
	public IModel GetMyPortalModel();

    /**
	 * Returns true if this page should show the "Inside this Community" header and
	 * sub- and related communitites.
	 *
	 * @return 							true if the page should show community nav links
     */
    public boolean ShowCommunityNavigation();

	/**
	 * Checks if the current user can join the current Community
	 * @return 					boolean
	 */
	public boolean CanJoinCurCommunity();
	
	/**
	 * 
	 * Sets the currently registered view nav scheme to be newNavScheme
	 * 
	 * @return Currently registered Navigation Scheme.
	 */
	public int GetRegisteredViewNavScheme();
	
	/**
	 * 
	 * Sets the currently registered view nav scheme to be newNavScheme
	 * 
	 * @param the new registered view's Nav Scheme
	 */
	public void SetRegisteredViewNavScheme(int newNavScheme);
}

