package com.plumtree.portalpages.common.uiparts;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.directory.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.browsing.myportal.communities.*;
import com.plumtree.portalpages.browsing.myportal.mypages.*;
import com.plumtree.portalpages.browsing.sitemap.sitemappage.*;
import com.plumtree.portalpages.common.folder.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.classtypes.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Common static navigation helper functions.
 *
 * @author robertz
 */
public class NavigationCommonHelpers
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
			"com.plumtree.portalpages.common.uiparts.NavigationCommonHelpers");
	
    /** Default truncation width **/
	public static final int DEFAULT_MENU_TEXT_MAX_LENGTH = 29;
	
	/**
	 * Url template redirect function. Make the name as short as possible to 
	 * send down less data
	 */
	public static final String URLTEMPLATE_REDIRECT_JSFUNCNAME = "templateURLRedirect";
	
	
	/** Javascript variable name constant */
	public static final String JSCRIPT_VAR_MANDTAB_ARRAY = "mandTabsArray";

	/** Javascript variable name constant */
	public static final String JSCRIPT_VAR_DDTABS_ARRAY = "ddTabsArray";
	
	/** Javascript function name constant */
	public static final String JSCRIPT_FUNC_BUILD_URL_FROM_TEMPL = "buildURLFromTemplate";

	/**
	 * Helper function for getting values of settings in NavigationSettings.xml as integers. 
	 * 
	 * @param strKey	Name of the navigation setting.
	 * @param owner		Current Activityspace
	 * @return int		The requested Navigation setting value as integer. -1 if the key doesn't exist or not an integer. 
	 */
	public static int GetNavSettingsValueAsInt(String strKey, AActivitySpace owner)
	{
		try {
			String strValue = (String)owner.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(strKey);
			if (null == strValue)
			{
				// Since these settings are usually not present in the config file,
				// check for this and return a default value.
				return -1;
			}
			return XPConvert.ToInteger(strValue);  
		} catch (Exception e) {
			//log.Error(e, "Unable to return int.");
		}
		return -1;
		
	}

	/**
	 * Helper function for getting values of settings in NavigationSettings.xml as Strings. 
	 * 
	 * @param strKey	Name of the navigation setting
	 * @param owner 	Current Activityspace
	 * @return String	The requested Navigation setting value as a String. null if the value doesn't exist. 
	 */	
	public static String GetNavSettingsValueAsString(String strKey, AActivitySpace owner)
	{
		return (String)owner.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(strKey);
	}

	/**
	 * Adds the end of banner markers for ISC dropdown menus. Should be added to below banner view
	 * when using ISC menus in the above banner view.  
	 * 
	 * @return HTMLElementCollection		HTMLElementCollection to add the dropdown markers to
	 */
	public static HTMLElementCollection CreateDropDownEndMarkers()

	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLSpan span = new HTMLSpan();
		span.SetID("bannerend");

		HTMLGenericElement layer = new HTMLGenericElement(
				"<layer id=\"nsbannerend\"></layer>");

		//result.AddInnerHTMLElement(new HTMLBr());
		result.AddInnerHTMLElement(span);
		result.AddInnerHTMLElement(layer);

		return result;
	}

	/**
	 * Adds a spacer cell with a cell width of 4to the specified HTMLTableRow
	 * 
	 * @param myTableRow			HTMLTableRow to add the spacer cell to
	 */
	public static void CreateHorizontalSpacerCell(HTMLTableRow myTableRow)

	{
		HTMLTableCell myCell = new HTMLTableCell();
		myTableRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.NAV_MIDTABSPACER_BG);

		HTMLImg spacer = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER)
			.GetHTMLElement();
		spacer.SetWidth("4");
		spacer.SetHeight("1");
		spacer.SetBorder("0");
		spacer.SetAlt("");
		//spacer.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(false));
		myCell.AddInnerHTMLElement(spacer);
	}

	/**
	 * Creates a HTMLScript block with an array of the mandatory tabs to display
	 * The javascript array is a two dimensional array - 
	 * element[i][0]: Name of the mandatory community
	 * element[i][1]: Original name of the mandatory community (before truncation), use for tooltip
	 * element[i][2]: URL to the mandatory community
	 * 
	 * @param cpList						List of mandatory tabs
	 * @param parent						Current activityspace
	 * @return HTMLScript					The HTMLScript with the javascript variable
	 */
	public static HTMLScript CreateMandatoryTabsArray(
		ICPListEntryIterator cpList, AActivitySpace parent)

	{
		// Get the maximum length of mandatory tabs names
		String strMaxLength = (String)parent.GetVarPack(PTNavSettingsVarPack.VARPACK_ID).GetVarPackValue(PTNavSettingsVarPack.INTHORIZONTALNAVTAB_TRUNCATION_WIDTH);
		
		// Create an url template mediator for the mandatory tabs links
		CListURLTemplateMediator mediator = new CListURLTemplateMediator(parent, cpList);
		mediator.SetLabelMaxLength( XPConvert.ToInteger(strMaxLength) );

		// - Generate the 2d array in javascript

		// Roughly estimate the size of the buffer we need
		XPStringBuilder buf = new XPStringBuilder((cpList.GetTotalCount() * 50) + 20);
		buf.Append("[\n");

		for (int i = 0; mediator.Next(); i++)
		{
			String[] labelAndURL = (String[]) mediator.GetEntry();

			if (i != 0)
			{
				buf.Append(",");
			}

			// Create the array that stores name, tooltip and url
			// Element 0: Name, Element 1: Tooltip, Element 2: URL
			buf.Append("[\"" +
				JSHelper.JSEncodeString(labelAndURL[CListURLTemplateMediator.TEMPLATEARR_INDEX_LABEL]) + "\",\"" +
				JSHelper.JSEncodeString(mediator.GetNonEncodedEntryOrigLabel()) + "\",\"" +    // DCA - do not encode since accented chars does not display properly 
				labelAndURL[CListURLTemplateMediator.TEMPLATEARR_INDEX_URL] + "\"]\n");
		}
		// Close the outer array
		buf.Append("\t\t" + "]\n");
		return JSHelper.AddSafeJSVariable(JSCRIPT_VAR_MANDTAB_ARRAY, buf.ToString());
	}

	/**
	 * Creates writeStartTable, writeEndOfTable, writeSpacerTable and writeSpacerCell,
	 * dynamic HTML generating Javascript helper functions used in .js files to to position 
	 * dropdown menu tabs and mandatory communities tabs.
	 * 
	 * @param parent				Current Activityspace
	 * @return HTMLScript			HTMLScript block with the javascript helper functions
	 */ 
	public static HTMLScript GenerateJSHTMLHelperFunctions(AActivitySpace parent)

	{
		HTMLScript script = new HTMLScript("text/javascript");
		String strPathToImageServer = ConfigHelper.GetImageServerBaseURL(parent);
		XPStringBuilder buf		    = new XPStringBuilder(300);

		/* 
		function writeStartTable()
		{
		    document.write('<table cellpadding="0" cellspacing="0" width="100%" border="0"><tr class="navMidtabBg">\n');
		}*/
		buf.Append("\t" +
			"function writeStartTable() { document.write('<table cellpadding=\"0\" cellspacing=\"0\" width=\"100%\" border=\"0\"><tr class=\"navMidtabBg\">" +
			"'); }\n");

		/*
		function writeEndofTable()
		{
		    document.write('<td width="100%" class="banHeaderBg">&nbsp;</td></tr></table>\n');
		}*/
		buf.Append("\t" + "function writeEndOfTable() { document.write('" +
			"<td width=\"100%\" class=\"banHeaderBg\">&nbsp;</td></tr></table>" +
			"'); }\n");

		HTMLTable spacerTable = new HTMLTable();
		spacerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		spacerTable.SetBorder(CommonHTMLStrings.ZERO);
		spacerTable.SetCellPadding(CommonHTMLStrings.ZERO);
		spacerTable.SetCellSpacing(CommonHTMLStrings.ZERO);

		HTMLTableRow row = new HTMLTableRow();
		row.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
		spacerTable.AddInnerHTMLElement(row);
		CreateVerticalSpacerCell(row);
		spacerTable.SetImgBaseUrl(strPathToImageServer);

		//	this turns off line breaks for this subtree of htmlelements.
		spacerTable.SetForceLineBreaksAfterSafeElements( false );

		buf.Append("\t" + "function writeSpacerTable() { document.write('" +
			spacerTable.GetDisplayString() + "'); }\n");

		buf.Append("\t" + "function writeSpacerCell() { document.write('" +
			"<td colspan=\"1\" class=\"navMidtabSpacerBg\"><img src=\"" +
			strPathToImageServer +
			"portal/public/img/sp.gif\" alt=\"\" border=\"0\" height=\"1\" width=\"4\"/></td>" +
			"'); }\n");

		script.AddInnerHTMLString(buf.ToString());
		return script;
	}

	/**
	 * Adds a spacer cell to the specified HTMLTableRow 
	 * 
	 * @param myTableRow					The HTMLTableRow to add the spacer cell to
	 */
	public final static void CreateVerticalSpacerCell(HTMLTableRow myTableRow)

	{
		HTMLTableCell myCell = new HTMLTableCell();
		myTableRow.AddInnerHTMLElement(myCell);
		myCell.SetStyleClass(PTStyleClass.NAV_MIDTABSPACER_BG);

		HTMLImg spacer = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER)
			.GetHTMLElement();
		spacer.SetWidth("1");
		spacer.SetHeight("4");
		spacer.SetBorder("0");
		spacer.SetAlt("");
		myCell.AddInnerHTMLElement(spacer);
	}
	
	/**
	 * Prepares a string for use in Javascript code, escapes single quotes (').
	 * 
	 * @param strIn							The stirng to escape
	 * @return								String with escaped single quotes 
	 */
	public final static String EscapeSingleQuotes(String strIn)
	{
		return GeneralHelpers.Replace(strIn, "'", "\\'");		
	}
	
	/**
	 * Helper function that creates a spacer Image with specified width and height
	 * 
	 * @param sWidth		Spacer image width
	 * @param sHeight		Spacer image height
	 * @return HTMLImg		HTMLImg construct
	 */
	public static HTMLImg GetSpacerImage(String sWidth, String sHeight)
	{
		HTMLImg image = null;
		image = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER)
			.GetHTMLElement();
		image.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(true));
		image.SetWidth(sWidth);
		image.SetHeight(sHeight);
		image.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		image.SetBorder(CommonHTMLStrings.ZERO);
		image.SetAlt("");	
		
		return image;
	}

	/**
	 * Helper function that returns a string with the HTML of the formatted image for Communities
	 * 
	 * @param aspace					Current Activityspace
	 * @param mpName					Alt text for the image
	 * @return String					The image as an HTML String
	 */
	public static String GetCommunityImageURLString(AActivitySpace aspace, String commName)
	{
		String imageString = "";
		try
		{
			HTMLImg htmlImg    = null;
			
	
			htmlImg			   = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_COMMUNITY,
					true, aspace).GetHTMLElement();
			htmlImg.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(aspace));
			htmlImg.SetAlt(commName);
			htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			htmlImg.SetBorder(CommonHTMLStrings.ZERO);
	
			// HTMLEncode the string, might contain "s
			//imageString = XPHttpUtility.HtmlEncode( htmlImg.GetDisplayString() );
			imageString = htmlImg.GetDisplayString();
	
		}
		catch (Exception e)
		{
		    log.Error(e, "Unable to get CommunityImageURLString.");
		}
		return imageString;
	}

	/**
	 * Helper function that returns a string with the image source of the formatted image for Communities
	 * 
	 * @param aspace					Current Activityspace
	 * @return String					The image as an image source String
	 */
	public static String GetCommunityImageSource(AActivitySpace aspace)
	{
		String imageString = "";
		try
		{
			imageString = ConfigHelper.GetImageServerBaseURL(aspace) + PTImageType.ICON_COMMUNITIES_MENU.GetFileName() + 
				"', '" + PTImageType.ICON_COMMUNITIES_MENU.GetWidth();
	
		}
		catch (Exception e)
		{
		}
		return imageString;
	}
	
	/**
	 * Helper function that returns a string with the HTML of the formatted image for Mypages
	 * 
	 * @param aspace					Current Activityspace
	 * @param mpName					Alt text for the image
	 * @return String					The image as an HTML String
	 */
	public static String GetMyPageImageURLString(AActivitySpace aspace, String mpName)
	{
		String imageString = "";
		try
		{
			HTMLImg htmlImg    = null;
			
	
			htmlImg			   = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_MYPAGE,
					true, aspace).GetHTMLElement();
			htmlImg.SetImgBaseUrl(ConfigHelper.GetImageServerBaseURL(aspace));
			htmlImg.SetAlt(mpName);
			htmlImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
			htmlImg.SetBorder(CommonHTMLStrings.ZERO);
	
			// HTMLEncode the string, might contain "s
			//imageString = XPHttpUtility.HtmlEncode( htmlImg.GetDisplayString() );
			imageString = htmlImg.GetDisplayString();
	
		}
		catch (Exception e)
		{
		    //log.Error(e, "Unable to get MyPageImageURLString.");
		}
		return imageString;
	}
	
	/**
	 * Helper function that returns a string with the HTML of the formatted image for Mypages
	 * 
	 * @param aspace					Current Activityspace
	 * @param mpName					Alt text for the image
	 * @return String					The image as an HTML String
	 */
	public static String GetMyPageImageSource(AActivitySpace aspace)
	{
		String imageString = "";
		try
		{
			imageString = ConfigHelper.GetImageServerBaseURL(aspace) + PTImageType.ICON_MYPAGE_MENU.GetFileName() + 
				"', '" + PTImageType.ICON_MYPAGE_MENU.GetWidth();
	
		}
		catch (Exception e)
		{
		    //log.Error(e, "Unable to get MyPageImageSource");
		}
		return imageString;
	}

	/**
	 * Parses the ID or IDs needed to create the URL for mypages or community pages (or other types)
	 * Needs to be in sync with the IDs put used as data value for each cell. 
	 * M = MyPages C = Communities , E = Editor, F = Freeform URL (no template) etc
	 * 
	 * @return 	String with the javascript functions
	 */
	public static String writeURLTemplateParseFunction(AActivitySpace space)
	{
		// DCA - figure out if user wants links to open in a new window or in the main window
		String strOpenDocInNewWindow = "0";
		try {
			strOpenDocInNewWindow = (String) PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.OPEN_DOC_NEW_WINDOW, space);
		}
		catch (Exception e)
		{
			// Setting has not been set, log as warning.
			log.Warn(e, "Document preference has not been set for this user, documents will be opened on the main window.");
		}
		
		int nUserID = ((IPTSession)space.GetUserSession()).GetSessionInfo().GetCurrentUserID();
				
		// site map root urls
		ASURL siteMapRootURL = new ASURL(space);
		siteMapRootURL.SetLinkCreateNewSpace(SiteMapAS.STR_MVC_CLASS_NAME, space);
		siteMapRootURL.SetControl(SetSiteMapControl.STR_MVC_CLASS_NAME);
	
		// editor urls
		// Don't know the space name until it's called
		ASURL editorURL = new ASURL(space);
		editorURL.SetLinkCreateNewSpace("'+arArgs[1]+'", space);
	
		// Generic url, create space
		ASURL genericURL = new ASURL(space);
		genericURL.SetLinkCreateNewSpace("'+arArgs[1]+'", space);
		
		XPStringBuilder sb = new XPStringBuilder();
		sb.Append("\tfunction ").Append(JSCRIPT_FUNC_BUILD_URL_FROM_TEMPL).Append("(strID)\n\t{\n").
			Append("\t\tvar arArgs = strID.split(',');\n\tif(!arArgs){\n").
			Append("\t  alert('Invalid menu ID');\n\t  return null; }\n");
			
		// community page
		sb.Append("\tif(arArgs[0] == 'C'){\n\t var strCommURL = ").Append(
		// expected array: 'C', communityid, pageid, profileid
		PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_COMMUNITY_ID),
																						 "arArgs[1]",
																						 "&"+PTCommunities.STR_QS_PAGEID+"='+arArgs[2]+'",
																						 XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)) )
																						 		
  		.Append("\n\t if ( arArgs.length > 3) { strCommURL += '&"+SetCommunityControl.PROFILEID+"='+arArgs[3]; }\n\t"+ 
						"  return strCommURL;\n");																				 

//		/** Friendly URL Community page 
//		 * expected array: 'FC', communityid, pageid, communityname, pagename
//		 ***/
//		// put in placeholders since friendlyurl will change the object names
//		try {
//			// CR: DCA - how are we handling ambiguities when the user clicks on a link after the javascripts have been rendered?
//			// Maybe we should just treat Firendly URLs as Internal Full URLs (look below)?
//			FriendlyURL friendly = new FriendlyURL(PT_CLASSIDS.PT_COMMUNITY_ID, "$$objname$$");
//			// This is to prevent the creation to lookup entries from number of page names, 
//			// which will fail since we are using a dummy value
//			friendly.SetUseIdIfAvailable(true);
//			friendly.SetChildName("$$childname$$");
//			String massagedURL = friendly.GetFriendlyURL(space);
//			massagedURL = GeneralHelpers.Replace(massagedURL, "$$objname$$", "'+arArgs[3]+'");
//			massagedURL = GeneralHelpers.Replace(massagedURL, "$$childname$$", "'+arArgs[4]+'");
//			String baseURL = PTConfigHelper.GetApplicationBaseURL(space);
//			sb.Append("\t} else if(arArgs[0] == 'FC'){\n\t var strCommURL = '").Append(baseURL).Append(massagedURL).Append("'\n");
//			sb.Append("\t\treturn strCommURL;\n");
//		} catch (Throwable e) {
//			log.Error(e, "There was an error creating mapping function for friendly URL, skipping.");
//		}
		// mypage page
		sb.Append("\t} else if (arArgs[0] == 'M') {\n\t return ").Append(

				PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_MYPAGESCONTAINER_ID),
																						 XPConvert.ToString(nUserID),
																						 "&"+PTMyPages.STR_PAGE_ID+"='+arArgs[1]+'",
																						 XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)) ).
		Append("\n");																				 
																						 
		// site map root
		sb.Append("\t} else if (arArgs[0] == 'SM') {\n\t  return '").
			Append(siteMapRootURL.GetURLAsString()).Append("&").Append(SetCommunityControl.STR_COMMUNITY_ID).
			Append("='+arArgs[1]+'&Mode='+arArgs[2]+(eval(arArgs[3]) ? '&Preview=' : '');\n");
			
		// string label
		sb.Append("\t} else if (arArgs[0] == 'S') {\n\t  return null;\n");
			
		// editor url
		sb.Append("\t} else if (arArgs[0] == 'E') {\n\t    var params = '';").
			Append("\n\t    if ( arArgs.length > 1 ) {\n").
			Append("\t      for ( var i = 2; i < arArgs.length; i++ ) {\n").
			Append("\t        params += '&' + arArgs[i];" + "\n\t      } }").
			Append("\n\t  return '").Append(editorURL.GetURLAsString()).Append("' + params;").
			Append("\n");
			 
		// dir page
		sb.Append("\t} else if (arArgs[0] == 'D') {\n\t return ").Append( 
		
		PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGFOLDER_ID),
																							 "arArgs[2]",
																							 "&"+DirConstants.QS_DIRECTORY_MODE+"='+arArgs[1]+'",
																							 XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW))
		).Append("\n");
			
		// Generic with create new space
		sb.Append("\t} else if (arArgs[0] == 'G1') {\n\t    var params = '';").
			Append("\n\t    if ( arArgs.length > 1 ) {\n").
			Append("\t      for ( var i = 2; i < arArgs.length; i++ ) {\n").
			Append("\t        params += '&' + arArgs[i];\n\t      } }").
			Append("\n\t  return '").Append(genericURL.GetURLAsString()).Append("' + params;\n"); 
		
		// Internal full URL
		sb.Append("\t} else if (arArgs[0] == 'IF') {\n\t  return arArgs[1];\n");	
			
		// error 
		sb.Append("\t} else {\n\t    alert('URL Type is not defined');\n").
			Append("\t    return null; }\n\t}\n");
		
		//int nUserID  = ((IPTSession) space.GetUserSession()).GetSessionInfo().GetCurrentUserID();
		
		sb.Append("\tfunction ").Append(URLTEMPLATE_REDIRECT_JSFUNCNAME).Append("(templateURL) {\n").
			Append("\t  if (templateURL == null) { return null; }\n").
			Append("\t  var arArgs = templateURL.split(',');\n");	
		
		// DCA - User Profile URL is different - JO
		sb.Append("\t if (arArgs[0] == 'UP') {\n\t").Append(PTOpenerLinks.GetJSOpenInSameWindow(
		PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_USER_ID), "arArgs[1]", null, 
			XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)))).Append(";\n");

		// DCA - Doc Open URL is also different
		if (null != strOpenDocInNewWindow && strOpenDocInNewWindow.equals("1")) {
			// DCA - Open in a new window
			sb.Append("\t} else if (arArgs[0] == 'DO') {\n\t").Append(PTOpenerLinks.GetJSOpenInNewWindow(
			PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), "arArgs[1]", null, 
			XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)), "docLink", "600", "800", true)).Append(";\n");
			// DCA - full url in a new window	
            sb.Append("\t} else if (arArgs[0] == 'F') {\n\t").Append(PTOpenerLinks.GetJSOpenInNewWindow("arArgs[1]", 
                    "extLink", "600", "800", true)).Append(";\n");
		} else {
			// DCA - Open in the main window
			sb.Append("\t} else if (arArgs[0] == 'DO') {\n\t").Append(PTOpenerLinks.GetJSOpenInSameWindow(
			PTOpenerLinks.GetOpenerJSURLOpenObjID(XPConvert.ToString(PT_CLASSIDS.PT_CATALOGCARD_ID), "arArgs[1]", null, 
			XPConvert.ToString(IPTOpenerConstants.OPENER_MODE_VIEW)))).Append(";\n");
			// DCA - full url in a new window
			sb.Append("\t} else if (arArgs[0] == 'F') {\n\t  window.location = arArgs[1];\n");	
		}
		
		
		
		sb.Append("\t } else {\n").
			Append("\t   window.location = ").Append(JSCRIPT_FUNC_BUILD_URL_FROM_TEMPL).Append("(templateURL);\n").
			Append("\t }\n\t \n\t}\n");
	
		return sb.ToString();
	}  
	
	
}

