
package com.plumtree.portalpages.common.uiparts;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * Control for collapsing and expanding Navigation sections in left vertical views.
 * 
 * @author robertz
 */
public class NavigationControl implements IControl
{
	/** MVC Name */
	public static final String STR_MVC_CLASS_NAME = "Navigation";

	/** Parameter name for the Collapse action */
	public static final String ACTION_COLLAPSE = "NavCol";
	/** Parameter name for the Expand action */
	public static final String ACTION_EXPAND = "NavExp";
	
	
	/** Parameter name for the previous page URL */
	public static final String PREV_PAGE_QSPARAM = "RedirectControl";
	
	protected AActivitySpace m_asOwner;
	protected NavigationModel m_model;

	/**
	 * Constructor for NavigationControl.
	 */
	public NavigationControl()
	{
		super();
	}

	/**
	 * Updates the vertical navigation section visibility array and then redirects to the 
	 * referring page.
	 * 
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Execute(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		if (arguments.ContainsKey(ACTION_COLLAPSE))
		{
			String strSectionID = ((String[]) arguments.GetElement(ACTION_COLLAPSE))[0];
			int nSectionID	    = XPConvert.ToInteger(strSectionID);
			m_model.SetSectionVisibility(nSectionID, false);
		}
		else if (arguments.ContainsKey(ACTION_EXPAND))
		{
			String strSectionID = ((String[]) arguments.GetElement(ACTION_EXPAND))[0];
			int nSectionID	    = XPConvert.ToInteger(strSectionID);
			m_model.SetSectionVisibility(nSectionID, true);
		} 
		
		Redirect redirect = new Redirect();
		
		// Get the argument for the previous url. 
		String prevURL = ((String[])arguments.GetElement(PREV_PAGE_QSPARAM))[0];
		redirect.SetLinkToExternalURL(prevURL);
		redirect.SetIsHTTPRedirect(true);
		return redirect;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new NavigationControl();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IControl#Init(com.plumtree.uiinfrastructure.activityspace.IModel, com.plumtree.uiinfrastructure.activityspace.AActivitySpace)
	 */
	public void Init(IModel model, AActivitySpace space)
	{
		m_model		  = (NavigationModel) model;
		m_asOwner     = space;
	}
}

