package com.plumtree.portalpages.common.uiparts;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the base class for all AS's with a banner.
 * 
 * @author RobZ
 * @author DavidP
 */
public abstract class PlumtreeAS extends AFormAS implements ITypes
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.uiparts.PlumtreeAS");

	protected final static String REGISTERED_VIEW_SESSION_ATTRIBUTE 	= "REGISTERED_VIEW";
    
    private String strLayoutStyleClass = null;
	
	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#GetName()
	 */
	public abstract String GetName();

	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 * AS that extends PlumtreeAS must call this super method if overridden to check for changed navigation scheme
	 */
	public boolean CheckBasicAccess(String strPage, String strControl,
		boolean bSameSpace)
	{
		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.IFormAS#DisplayCommonJavaScript()
	 */
	public HTMLScriptCollection DisplayCommonJavaScript()
	{
		HTMLScriptCollection scripts = super.DisplayCommonJavaScript();

		return scripts;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();

		// Navigation Model
		RegisterModel(NavigationModel.STR_MVC_CLASS_NAME);

		IModel navModel = GetModel(NavigationModel.STR_MVC_CLASS_NAME);

		// Banner Section
		RegisterView(DefaultHeaderView.STR_MVC_CLASS_NAME, navModel);
		RegisterView(DefaultFooterView.STR_MVC_CLASS_NAME, navModel);

		// Navigation Section
		RegisterView(PlumtreeTopBarView.STR_MVC_CLASS_NAME, navModel);
		RegisterControl(NavigationControl.STR_MVC_CLASS_NAME, navModel);
		
		// Error Model
		RegisterModel(ErrorModel.STR_MVC_CLASS_NAME);

		IModel errorModel = GetModel(ErrorModel.STR_MVC_CLASS_NAME);

		RegisterView(ErrorView.STR_MVC_CLASS_NAME, errorModel);
		RegisterControl(ErrorControl.STR_MVC_CLASS_NAME, errorModel);

		int nCurrentScheme; 
		if (GetAccessStyle() == AccessStyles.STANDARD)
		{
			nCurrentScheme = NavTypeConstants.NAV_TYPE_ID_DEFAULT;  //((IPTSession) GetUserSession()).GetSessionInfo().GetCurrentUserCachedSubPortalInfo().GetNavigationScheme();
		} else {
			nCurrentScheme = NavTypeConstants.NAVTYPE_ID_508COMPLIANT;
		}
		INavTypes curNavType = GetNavType(nCurrentScheme);
		IXPEnumerator navAreas = NavAreaHelper.INSTANCE.GetCategoryTypes();
		if (navAreas != null)
		{
			// For each page area within this pluggable nav, 
			// register the view with the AS
			while (navAreas.MoveNext())
			{
				String pView;
				// Register current scheme
				pView = NavAreaHelper.INSTANCE.GetNavAreaViewClassName(curNavType, (NavAreaEnum)navAreas.GetCurrent()); 
				if(pView != null)
				{
					if ( !this.GetViewExists(pView) )
						RegisterView(pView, navModel);
				}
			}
		}
		((NavigationModel) navModel).SetRegisteredViewNavScheme(nCurrentScheme);
	}
	
	/**
	 * Re-Initialize the Activity Space in case models are holding on to an old session.
	 * 
	 */
	public void ReInit() {
		NavigationModel navModel = (NavigationModel) GetModel(NavigationModel.STR_MVC_CLASS_NAME);
		navModel.ReInit(this);
	}

	/**
	 * This method gets the correct navtype for the nav scheme,
	 * correcting for Macintosh users.
	 * 
	 * @param int nNavScheme the desired navigation scheme.
	 * @return INavTypes the appropriate navigation scheme.
	 */
	public INavTypes GetNavType(int nNavScheme)
	{
		INavTypes navType = NavManager.INSTANCE.GetNavType(nNavScheme);
		
		// Use default schema if stored navschema is invalid.
		if ( null == navType) {
			if(log.IsWarnEnabled())
				log.Warn("Invalid navigation scheme: " +
				nNavScheme + " Using default navigation.");
			
			navType = NavManager.INSTANCE.GetNavType(NavTypeConstants.NAV_TYPE_ID_DEFAULT);

		}
		
		return navType;
	}

    public String GetStrLayoutStyleClass() {
        return strLayoutStyleClass;
    }

    public void SetStrLayoutStyleClass(String strLayoutStyleClass) {
        this.strLayoutStyleClass = strLayoutStyleClass;
    }
}

