package com.plumtree.portalpages.common.uiparts;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portaluiinfrastructure.application.varpacks.*;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.layout.*;
import com.plumtree.portaluiinfrastructure.navtype.*;
import com.plumtree.portaluiinfrastructure.opener.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.server.marshalers.*;
import com.plumtree.taskapi.portalui.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.activityspace.utils.*;
import com.plumtree.uiinfrastructure.common.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.helpers.*;
// Put explicit import for Interpreter (to avoid ambiguity of using the deprecated class)
import com.plumtree.uiinfrastructure.interpreter.Interpreter;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * Main display page for the Portal product.
 *
 * @author RobZ
 * @author DavidP
 * @author BridgetF
 * @author NaveenP
 * @author michaeld
 */
abstract public class PlumtreeDP extends AFormDP
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.uiparts.PlumtreeDP");

	public static final String JAVASCRIPT_INITIALIZE_EVENTS = "InitializeEvents();";

	/** Whether or not to display the main form */
	protected boolean m_bAddMainForm = false;

	// default base variables for pluggable nav; overridable by settings 
	// in NavigationSettings.xml	
	protected int m_nTableSpacing 		= 10;
	protected int m_nLeftWidth	 		= 100;
	protected int m_nRightWidth			= 100;
	protected int m_nLeftWidthAlone		= 200;
	protected int m_nRightWidthAlone	= 200;

	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#GetName()
	 */
	abstract public String GetName();

	/**
	 * This string will be added as the subtitle in a banner that has a
	 * subtitle. For example, if you were on a my page named "Green Page", then
	 * return "Green Page" here.
	 *
	 * @return SubHeader
	 *
	 */
	abstract public String GetSubtitleForBanner();

	/**
	 * This string will be added as the title in a banner that has a title. For
	 * example, if this is a my page, return "My Pages" here.
	 *
	 * If you think you don't need a title, then you need to seriously rethink
	 * why you are inheriting from PlumtreeDP.  Because the WHOLE POINT of
	 * PlumtreeDP is that it has a banner.
	 *
	 * @return Header
	 *
	 */
	abstract public String GetTitleForBanner();

	/**
	 * This is a helper method that all classes that inherit from PlumtreeDP
	 * need to implement.  The method should add whatever HTML the child class
	 * wants to display to the body argument.  The parent class will then add
	 * that HTML to the HTMLPage after filling in the banner and navigation.
	 *
	 * @return HTML of the page
	 *
	 * @throws HTMLException 
	 */
	abstract public HTMLElement PageDisplay();

	/**
	 * This method is also used by the BasePage layout NavArea tag.
	 * 
	 * @return Returns NavScheme.
	 */	
	public int GetNavScheme()
	{
		int nScheme = ((INavigationModelRO) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME)).GetSubPortalNavScheme();
		
		if (m_asOwner.GetAccessStyle() != AccessStyles.STANDARD)
		{
			nScheme = NavTypeConstants.NAVTYPE_ID_508COMPLIANT;
		}
		// make sure the navscheme we are going to use is the one that is registered
		RegisterNavScheme(nScheme);
		
		return nScheme;
	}
	/**
	 * @see com.plumtree.xpshared.activityspace.IDisplayPage#display()
	 */
	public void Display(IWebData pageData)
	{
		// initialize all portlet content for the page
		((NavigationModel) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME)).InitializePortletContent();
		
	    if (m_asOwner.GetIsInPlaceRefreshDisplayOn())
	    {
	        try
	        {
	            HTMLElement myElement = PartialContentDisplay();
	            pageData.SetData(myElement);
	        }
	        catch (Exception ex)
	        {
	            log.Error(ex, "Error displaying text: " + ex.getMessage());
				throw new XPException("Error displaying text: " + ex.getMessage(), ex);
	        }
	        finally 
	        {
		        // reset the in place refresh flag so that future hits
		        // will be displayed normally.  this flag is normally 
		        // set to true via an in place refresh repost.
		        m_asOwner.SetIsInPlaceRefreshDisplayOn(false);
	        }	       
	    }
	    else
	    {
			HTMLElement element = null;
			NavigationModel navModel = (NavigationModel)GetOwner().GetModel(NavigationModel.STR_MVC_CLASS_NAME);						
			if ((navModel != null) && (navModel.IsCommunityPage()) && (navModel.GetCurCommunityID() == PT_INTRINSICS.PT_PROFILE_COMMUNITY))
				element = DisplayLayout(Layouts.PROFILE_PAGE);
			else
				element = DisplayLayout(Layouts.BASE_PAGE);

			if (null != element)
	    	{
	    		pageData.SetData(element);
	    		// The page has been successfully displayed using layout mode.
	    		return;
	    	}

	    	// BEGIN: Temp code for deciding navigation
			// Updated: Force to nav schema zero when in low bandwidth or 508 mode
			
	    	int nNavScheme = GetNavScheme();
	    	
			// END: Temp code for deciding navigation
			// Create an HTMLPage
			HTMLPage myPage = new HTMLPage();
	
			// Set the HTMLPage as the data to be sent to the browser.
			pageData.SetData(myPage);

			if (GetOwner().GetAccessStyle() == AccessStyles.SECTION_508)
			{
				myPage.SetDo508Checking(true);
			}
	
			// Important note - We MUST construct the body before constructing the head.
			// This is because intrinsic portlets are dynamically registered with the activity
			// space when the body is constructed.  If the portlet has any Javascript, then
			// it must be added to the head, but you don't know if there's any Javascript to
			// add until the body is generated. Of course the head should still be added to
			// the page before the body as usual. -jic
			// Create body
			HTMLBody myBody = DisplayBody(nNavScheme);
	
			// Create head
			HTMLHead myHead = DisplayHead(nNavScheme);
	
			// Add the head to the page
			myPage.SetHead(myHead);
	
			// Add the body to the page
			myPage.SetBody(myBody);
	    }
	}

	/**
	 * This method checks whether or not the page should be displayed using layout
	 * mode and then displays it.
	 * 
	 * @param _pageData
	 * @return The HTML output of the layout, or null if the layout was disabled.
	 */
	protected HTMLElement DisplayLayout(Layouts layout)
	{
		HTMLElement element = null;

		// The base page and profile page are the only main pages (for tag processing)
		boolean bMainPage = ((layout == Layouts.BASE_PAGE) || (layout == Layouts.PROFILE_PAGE));
		
		// Layout ID of -1 means layouts are not enabled for this page (or globally).
		int nLayoutID = LayoutService.getChooserInstance().GetLayoutWebService(layout, m_asOwner);
				
    	// Only use layouts for standard pages, not 508 or low bandwidth.
    	if ((nLayoutID != -1) && (GetOwner().GetAccessStyle() == AccessStyles.STANDARD))
    	{
    		log.Info("Displaying page layout " + layout.ToString() +
    			" using Page Layout with ID " + nLayoutID);
    		// Get processed HTMLElement from layout
    		element = DisplayLayout(nLayoutID, bMainPage);
    	}    	
    	
		// Bug fix 8751519 - PORTLET SELECTION FLY OUT EDITOR DOES NOT APPEAR UNDER CERTAIN CONDITIONS. 
       	// we have already determined above that layout mode isn't supported in current user's experience definition, but we are checking
    	// the special case if a user belongs to an exp def that doesn't support layout mode, but has navigated into a community
		// that supports it, layout mode SHOULD be enabled for that request while in the community.
    	
    	// Checking if layouts are globally disabled if we're trying to load the Portlet Selection layout.
		if ( (nLayoutID == -1) && (layout == Layouts.PORTLET_SELECTION) )
		{
			//getting the web service id for the layout so we can load the layout requested.
			int backupLayoutID = LayoutService.getChooserInstance().GetLayoutWebServiceBackUp(layout, m_asOwner);
	
			log.Info("Displaying page layout " + layout.ToString() +
	    			" using Page Layout with ID " + nLayoutID);
	    		// Get processed HTMLElement from layout
	    		element = DisplayLayout(backupLayoutID, bMainPage);
		}
		return element;
	}

	/**
	 * This helper method displays a particular layout from a web service.
	 * 
	 * @param _nWebServiceID The webservice to display.
	 * @param _bMainPage whether or not to process the head element for a main page.
	 * This should only be true for one layout per page.
	 * @return the HTML output of displaying the layout.
	 */
	protected HTMLElement DisplayLayout(int _nWebServiceID, boolean _bMainPage)
	{
		try {
			ILayoutManager manager = LayoutService.getManagerInstance();
			Object[][] markup = manager.GetLayout(_nWebServiceID, m_asOwner);
			ILayoutDisplay display = LayoutService.getFactoryInstance().CreateDisplay();
			if (_bMainPage)
			{
				return display.ProcessMainPageLayout(markup, m_asOwner);
			} else
			{
				return display.ProcessLayout(markup, m_asOwner);			
			}
		} catch (Exception e) {
			if (_bMainPage) {
				// DCA - could not display the main page for some reason, switch to classic mode by returning null
				log.Error(e, "PlumtreeDP:DisplayLayout Could not display main page. Switching to classic mode. Please Check the path on webservice with Id " 
						+ _nWebServiceID + " and make sure it is correct.");
				return null;
			} else {
				throw PTException.GetInstance(e);
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.form.AFormDP#GetFormTitle()
	 */
	public String GetFormTitle()
	{
		return GetTitleForBanner();
	}

	/**
	 * Set the AddMainForm member variable. Set it to true if you want to have
	 * the form tag and have the postToSelf javascript automatically printed out.
	 *
	 * @param _bAddMainForm
	 */
	public void SetAddMainForm(boolean _bAddMainForm)
	{
		m_bAddMainForm = _bAddMainForm;
	}

	/**
	 * @return whether or not to add the form tag and have the postToSelf
	 * javascript automatically printed out.
	 */
	public boolean GetAddMainForm()
	{
		return m_bAddMainForm;
	}

	/**
	 * Constructs the body for the Plumtree display page.  Note that this
	 * function must be called prior to calling DisplayHead(), because of the
	 * special case of intrinsic portlets on the MyPortalDP.  Intrinsic
	 * portlets view registration, which occurs in PageDisplay(), must occur
	 * prior to Javascript generation, which occurs during
	 * DisplayJavaScriptFromChild().
	 * 
	 * @param nNavScheme		Navigation scheme ID			
	 * @return HTMLBody			
	 * @see NavTypeConstants
	 */
	protected HTMLBody DisplayBody(int nNavScheme)
	{
		// Calculate whether or not to display javascript.
		boolean bNoJavascript = !(GetUseJavascript());

		boolean displayTopBar = true;
		boolean displayHeader = true;
		boolean displayFooter = true;
		
		NavigationModel navModel = (NavigationModel)GetOwner().GetModel(NavigationModel.STR_MVC_CLASS_NAME);
		int pageID = navModel.GetCurPageID();
		String loginName = ((IPTSession) m_asOwner.GetUserSession()).GetSessionInfo().GetCurrentUserLoginName();
		
		HTMLBody myBody = new HTMLBody();
		
		{
			// Every page's body tag gets a "unique" class attribute, based upon user's login name.
			String bodyStyleString = TaskAPIUIHTML.HTMLEncode(PTStyleClass.GetClassStringForPageUser(loginName));
			
			// Community pages also get a unique class attribute, based upon community id.
			if (navModel.IsCommunityPage())
			{
				String commID = XPConvert.ToString(navModel.GetCurCommunityID());
				bodyStyleString += " " + PTStyleClass.GetClassStringForCommunity(commID);
			}
			myBody.SetStyleClass(bodyStyleString);
		}

		myBody.SetMarginWidth("0");
		myBody.SetMarginHeight("0");
		myBody.SetTopMargin("0");
		myBody.SetLeftMargin("0");
		
		/* portalContentDiv is one of two child nodes contained within the body tag.
		 * All portal content is displayed in this div.
		 * 
		 * This div will be assigned a unique id attribute for mypages and community pages
		 * which have object IDs.
		 */
		HTMLDiv portalContentDiv = (HTMLDiv) myBody.InsertInnerHTMLElement(new HTMLDiv());
		portalContentDiv.SetStyleClass(PTStyleClass.PORTAL_CONTENT);

		/* extensionDiv exists as a parallel node to portalContentDiv,
		 * providing an empty (and by default hidden) region which can be customized 
		 * as desired.  The Plumtree portal does not ever make use of this area.
		 * 
		 * This div will be assigned a unique id attribute for mypages and community pages
		 * which have object IDs.
		 */
		HTMLDiv extensionDiv = (HTMLDiv) myBody.InsertInnerHTMLElement(new HTMLDiv());
		extensionDiv.SetStyleClass(PTStyleClass.EXTERNAL_CONTENT);

		if (pageID != NavigationModel.NO_CURRENT_PAGEID)
		{
			portalContentDiv.SetID(PTStyleID.GetIDStringForPortalContent(pageID));
			extensionDiv.SetID(PTStyleID.GetIDStringForExternalContent(pageID));
			
			// Every page's body tag gets a "unique" id attribute, based on page id.
			myBody.SetID(PTStyleID.GetIDStringForPage(pageID));
		}

//      Remove dom0 registration, handlers will be registered by new jscomponent version
//		if (!bNoJavascript)
//		{
//			String strPCCfunction = "document.PCC.RaiseWindowEvent(event);";
//			myBody.SetOnActivate(strPCCfunction);
//			myBody.SetOnAfterPrint(strPCCfunction);
//			myBody.SetOnBeforeActivate(strPCCfunction);
//			myBody.SetOnBeforeUnload(strPCCfunction);
//			myBody.SetOnBlur(strPCCfunction);
//			myBody.SetOnControlSet(strPCCfunction);
//			myBody.SetOnDeactivate(strPCCfunction);
//			myBody.SetOnError(strPCCfunction);
//			myBody.SetOnFocus(strPCCfunction);
//			myBody.SetOnHelp(strPCCfunction);
//			myBody.SetOnLoad(strPCCfunction);
//			myBody.SetOnResize(strPCCfunction);
//			myBody.SetOnResizeEnd(strPCCfunction);
//			myBody.SetOnResizeStart(strPCCfunction);
//			myBody.SetOnUnload(strPCCfunction);
//		}
		
		HTMLTableCell tCell = null;

		INavTypes navType = ((PlumtreeAS)m_asOwner).GetNavType(nNavScheme);

		// determine if headers, footers, topbar to be set		
		displayTopBar = GetPlugNavFeature(navType, NavFeatureEnum.TOPBAR);
		displayHeader = GetPlugNavFeature(navType, NavFeatureEnum.HEADER);
		displayFooter = GetPlugNavFeature(navType, NavFeatureEnum.FOOTER);	

		OverrideNavSettingsFromVarPack(navType);

		// Setting banner for non community pages; this will set 508 or the default header or 
		// footer, as necessary.
		if (displayHeader && !navModel.GetHeaderHasBeenSet())
		{
			HTMLElement banner = navModel.GetSubportalBanner();
			navModel.SetHeaderElement(true, banner);
		}
		else if (!displayHeader)
		{
			navModel.SetHeaderElement(true, null);
		}
		
		if (displayFooter && !navModel.GetFooterHasBeenSet())
		{
			HTMLElement footer = navModel.GetSubportalFooter();
			navModel.SetFooterElement(true, footer);
		}
		else if (!displayFooter)
		{
			navModel.SetFooterElement(true, null);
		}

		// Pretty bad if we can't even get the default nav
		if ( navType == null)
		{
			log.Error("Fatal error, unable to load default navigation: " + 
				NavTypeConstants.NAV_TYPE_ID_DEFAULT +
				"Pluggable navigation module incorrectly installed or configured.");
		}
		
		
		if (!bNoJavascript)
		{
			/**
			 * This area is handled by the BasePage layout PageBody tag.
			 */

			String strOnLoad = GetOnLoad();
			if (null != strOnLoad)
				myBody.SetOnLoad(strOnLoad);

			/**
			 * End of area handled by the BasePage layout PageBody tag.
			 */
		}
		
		// get the pluggable views
		IView abovebodyView = null;
		IView leftView = null;
		IView rightView = null;
		IView belowbodyView = null;
		IView abovebannerView = null;
		IView belowbannerView = null;
		IView abovefooterView = null;
		IView belowfooterView = null;
		IView topbarView = null;
		
		try
		{				
			abovebodyView = GetPlugNav(navType, NavAreaEnum.ABOVEBODY);
			leftView = GetPlugNav(navType, NavAreaEnum.LEFTOFBODY);
			rightView = GetPlugNav(navType, NavAreaEnum.RIGHTOFBODY);
			belowbodyView = GetPlugNav(navType, NavAreaEnum.BELOWBODY);
			abovebannerView = GetPlugNav(navType, NavAreaEnum.ABOVEBANNER);
			belowbannerView = GetPlugNav(navType, NavAreaEnum.BELOWBANNER);
			abovefooterView = GetPlugNav(navType, NavAreaEnum.ABOVEFOOTER);
			belowfooterView = GetPlugNav(navType, NavAreaEnum.BELOWFOOTER);
			topbarView = GetPlugNav(navType, NavAreaEnum.TOPBAR);
		}
		catch( Exception e )
		{
			HandleNavCrash(false, myBody,"topbar view error",e);
		}

		// build the body using the pluggable views
		
		// always have top bar view
		// unless it's been turned off by the navigation, of course
		if (displayTopBar)
		{
			try
			{
				// retrieve the topbar element
				if ( topbarView != null )
				{
					//flush topbar to improve perception of page loading
				
					//	These lines are commented out until the Interpreter code
					//	is written to deal with flushing. -btg
					//				topBarElement.SetFlushAfterDisplay( true );
					//				topBarElement.SetPauseAfterDisplay( true );
				
					HTMLElement topBarElement = topbarView.Display();
					portalContentDiv.AddInnerHTMLElement(topBarElement);
				}
				
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"topbar view error",e);
			}
		}

		// above banner
		if (abovebannerView != null)
		{
			try
			{				
				portalContentDiv.AddInnerHTMLElement(abovebannerView.Display());
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"above banner view error",e);
			}
		}

		// banner
		if (displayHeader)
		{
			try
			{				
				portalContentDiv.AddInnerHTMLElement(navModel.GetHeaderElement());
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"banner error",e);
			}
		}
			
		// below banner
		if (belowbannerView != null)
		{
			try
			{									
				portalContentDiv.AddInnerHTMLElement(belowbannerView.Display());
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"below banner view error",e);
			}
		}
		
		// MAIN PAGE BODY AREA WITH TOP, LEFT, RIGHT, BOTTOM AND CENTER
		// The body area with above+below is a nested table
		// everything goes into this one tRow
		HTMLTable tOuter = new HTMLTable();
		tOuter.SetID("outerTable");
		HTMLTableRow tRow = new HTMLTableRow();
		
		portalContentDiv.AddInnerHTMLElement(tOuter);
		tOuter.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		tOuter.SetBorder(CommonHTMLStrings.ZERO);
		tOuter.SetCellSpacing(XPConvert.ToString(m_nTableSpacing));
		tOuter.SetCellPadding(CommonHTMLStrings.ZERO);
        
		tOuter.AddInnerHTMLElement(tRow);
		if (bNoJavascript)
		{
			tOuter.SetSummary("Portal");
		}
		
		// left hand navigation
		HTMLTableCell leftNavCell = null;
		if (leftView != null)
		{
			try
			{									
				HTMLElement leftHTML = leftView.Display();
				if ( leftHTML != null )
				{
					// Left hand cell spans multiple rows depending on other views
					// NOTE: this means all other rows should only specify two cells
					leftNavCell = new HTMLTableCell();
					leftNavCell.SetVAlign(CommonHTMLStrings.TOP);
					leftNavCell.SetAlign(CommonHTMLStrings.LEFT);
					leftNavCell.AddInnerHTMLElement(leftHTML);
					tRow.AddInnerHTMLElement(leftNavCell);
				}
			}
			catch( Exception e )
			{
				HandleNavCrash(true,myBody,"left of body view error",e);
			}
		}
		
		// main body in nested table ("inner")
		HTMLTable tInner = new HTMLTable();
		tInner.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		tInner.SetBorder(CommonHTMLStrings.ZERO);
		tInner.SetCellSpacing(CommonHTMLStrings.ZERO);
		tInner.SetCellPadding(CommonHTMLStrings.ZERO);
	
		tCell = new HTMLTableCell();									
		tCell.SetVAlign(CommonHTMLStrings.TOP);
		tCell.SetAlign(CommonHTMLStrings.LEFT);
		tCell.AddInnerHTMLElement(tInner);
		tRow.AddInnerHTMLElement(tCell);
		
		// above body (note use of inner table)
		if (abovebodyView != null)
		{
			try
			{
				HTMLElement abovebodyHTML = abovebodyView.Display();
				if ( abovebodyHTML != null )
				{
					HTMLTableRow tInnerRow = new HTMLTableRow();
					tCell = new HTMLTableCell();									
					tCell.SetVAlign(CommonHTMLStrings.TOP);
					tCell.SetAlign(CommonHTMLStrings.LEFT);
					tCell.AddInnerHTMLElement(abovebodyHTML);
					tInnerRow.AddInnerHTMLElement(tCell);
					tInner.AddInnerHTMLElement(tInnerRow);
				}
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"top of body view error",e);
			}
		}		
		
		// MAIN BODY ROW
		// note use of inner nested table added to outer row
		{		
			HTMLTableRow tInnerRow = new HTMLTableRow();
			tCell = new HTMLTableCell();
			tCell.SetVAlign(CommonHTMLStrings.TOP);
			tCell.SetAlign(CommonHTMLStrings.LEFT);

			// Placeholder for the error view
			HTMLElementCollection errorView = new HTMLElementCollection();
			tCell.AddInnerHTMLElement(errorView);

			/**
			 * This area is handled by the BasePage layout content tag.
			 */

			// main body
			HTMLElementCollection myHTMLBeforeForm = DisplayHTMLBeforeForm();
			if (null != myHTMLBeforeForm)
			{
				tCell.AddInnerHTMLElement(myHTMLBeforeForm);
			}
			
			if (m_bAddMainForm)
			{
				tCell.AddInnerHTMLElement(DisplayForm());
			}
			else
			{
				tCell.AddInnerHTMLElement(PageDisplay());
                String strStyleClass = ((PlumtreeAS) m_asOwner).GetStrLayoutStyleClass();
                if (null != strStyleClass) {
                    tOuter.SetStyleClass(strStyleClass);
                }
			}

			/**
			 * End of area handled by the BasePage layout content tag.
			 */

			/**
			 * This area is handled by the Common error tag.
			 */

			// generate the error view after the main page so we can catch
			// errors from displaying the page.	
			try
			{									
				errorView.AddInnerHTMLElement(GetOwner().GetView(ErrorView.STR_MVC_CLASS_NAME).Display());
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"error section error",e);
			}

			/**
			 * End of area handled by the Common error tag.
			 */

			tInnerRow.AddInnerHTMLElement(tCell);
			tInner.AddInnerHTMLElement(tInnerRow);
		}
		
		// below body navigation (to inner table)
		if (belowbodyView != null)
		{
			try
			{
				HTMLElement belowbodyHTML = belowbodyView.Display();
				if ( belowbodyHTML != null )
				{				
					HTMLTableRow tInnerRow = new HTMLTableRow();
					tCell = new HTMLTableCell();
					tCell.SetVAlign(CommonHTMLStrings.TOP);
					tCell.SetAlign(CommonHTMLStrings.LEFT);
					tCell.AddInnerHTMLElement(belowbodyHTML);
					tInnerRow.AddInnerHTMLElement(tCell);
					tInner.AddInnerHTMLElement(tInnerRow);
				}
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"bottom of body view error",e);
			}
		}		
		
		// right hand navigation (added to outer row)
		HTMLTableCell rightNavCell = null;
		if (rightView != null)
		{		
			try
			{	
				HTMLElement rightHTML = rightView.Display();
				if ( rightHTML != null )
				{							
					rightNavCell = new HTMLTableCell();
					rightNavCell.SetVAlign(CommonHTMLStrings.TOP);
					rightNavCell.SetAlign(CommonHTMLStrings.LEFT);
					rightNavCell.AddInnerHTMLElement(rightHTML);
					tRow.AddInnerHTMLElement(rightNavCell);
				}
			}
			catch( Exception e )
			{
				HandleNavCrash(true, myBody,"right of body view error",e);
			}
		}

		// check to see if cells are null
		if ( leftNavCell != null )
		{
			if (rightNavCell != null)
			{
				leftNavCell.SetWidth(XPConvert.ToString(m_nLeftWidth));
			}
			else
			{
				leftNavCell.SetWidth(XPConvert.ToString(m_nLeftWidthAlone));
			}
		}
		if (rightNavCell != null)
		{
			if ( leftNavCell != null )
			{
				rightNavCell.SetWidth(XPConvert.ToString(m_nRightWidth));
			}
			else
			{
				rightNavCell.SetWidth(XPConvert.ToString(m_nRightWidthAlone));
			}
		}

		
		// above footer
		if (abovefooterView != null)
		{
			try
			{				
				portalContentDiv.AddInnerHTMLElement(abovefooterView.Display());
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"above footer view error",e);
			}
		}

		// Footer
		// bjf -- note that the footer has already been queried and set at this point.
		// we package that up with the query to get the header, rather than triggering
		// two separate, wasteful gadget queries.  This way we use the parallelism of
		// web downloader parallel.
		if (displayFooter)
		{
			try
			{									
				//tFooterCell.AddInnerHTMLElement(navModel.GetFooterElement());
				portalContentDiv.AddInnerHTMLElement(navModel.GetFooterElement());
				
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"footer view error",e);
			}
		}
		
		// below footer
		if (belowfooterView != null)
		{
			try
			{									
				portalContentDiv.AddInnerHTMLElement(belowfooterView.Display());
			}
			catch( Exception e )
			{
				HandleNavCrash(false, myBody,"below footer view error",e);
			}
		}
		
		BrowserType browser = (BrowserType) GetOwner().GetSubSession().GetAttribute(Interpreter.BROWSERTYPE);
		
		if(!bNoJavascript && browser.IsJSPortletCompliant())
		{
			/**
			 * This area is handled by the BasePage layout pagebody tag.
			 */
			portalContentDiv.AddInnerHTMLElement(GetInitializeEventsJavaScript());
			/**
			 * End of area handled by the BasePage layout pagebody tag.
			 */
		}
		
		return myBody;
	}

	public HTMLScript GetInitializeEventsJavaScript()
	{
		HTMLScript script = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		// InitializeEvents is defined in "jsportlet" code included in the head
		script.AddInnerHTMLString(JAVASCRIPT_INITIALIZE_EVENTS);
		return script;
	}

	/**
	 * Get the pluggable navigation view based on enummerated type.
	 * 
	 * @param navType
	 * @param navArea
	 * @return IView
	 */
	private IView GetPlugNav(INavTypes navType, NavAreaEnum navArea)
	{
		IView returnView = null;
		String pViewName = "";
		
		pViewName = navType.GetNavAreaView(navArea);
		
		if (null != pViewName && pViewName.length() > 0)
			returnView = super.m_asOwner.GetView(pViewName);
			
		return returnView;
	}


	/**
	 * Get the pluggable navigation feature boolean
	 * 
	 * @param navType
	 * @param navArea
	 * @return IView
	 */
	private boolean GetPlugNavFeature(INavTypes navType, NavFeatureEnum navFeature)
	{
		return navType.IsFeatureEnabled(navFeature);
	}

	public HTMLScriptCollection GetBasicJavascript()
	{
		HTMLScriptCollection result = new HTMLScriptCollection();

		// Javascript functions
		if (m_bAddMainForm)
		{
			result.AddInnerHTMLElement(DisplayJavascript());
		}

		HTMLScript headScript = DisplayJavaScriptToHead();

		if (headScript != null)
		{
			result.AddInnerHTMLElement(headScript);
		}

		// The Common JS Includes need to come before any functions are registered with
		// the PCC.  This should come before both the PCCHelper and the page and view
		// Javascript (DisplayJavaScriptFromChild, etc...).	

		// Includes jsportlet javascript components files on the page, the version of the jsportlet to use is defined in /settings/config/JSComponentRegistry.xml
		HTMLScriptCollection jsportletScript = new HTMLScriptCollection();
		jsportletScript.AddInnerHTMLElement( ConfigService.getInstance().GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTLET, GetOwner()) );
		result.AddInnerHTMLElement(jsportletScript);

		HTMLScriptCollection scripts = DisplayJavaScriptFromChild();

		if (scripts != null)
		{
			result.AddInnerHTMLElement(scripts);
		}

		// This call gets the common window opener and the common opener JS open function
		result.AddInnerHTMLElement(((IFormAS) GetOwner()).DisplayCommonJavaScript());

		// Common Opener JS Functions
		HTMLScriptCollection commonOpenerJSScript = PTOpenerService.getInstance().GetOpenerJavascript(m_asOwner);
		result.AddInnerHTMLElement(commonOpenerJSScript);
		
		// Add the object that will store all the safe javascript variables.
		result.AddInnerHTMLElement(JSHelper.InitializeSafeJSVarElements());

		HTMLScript scriptPCCHelper = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		scriptPCCHelper.AddInnerHTMLString
			("var windowOnloadFunction = (window.onload) ? window.onload : new Function;\n" +
			"document.PCC.RegisterForWindowEvent(\"onload\", windowOnloadFunction);\n" +
				"var windowOnBlurFunction = (window.onblur) ? window.onblur : new Function;\n" +
				"document.PCC.RegisterForWindowEvent(\"onblur\", windowOnBlurFunction);\n" +
				"var windowOnFocusFunction = (window.onfocus) ? window.onfocus : new Function;\n" +
				"document.PCC.RegisterForWindowEvent(\"onfocus\", windowOnFocusFunction);\n");
	
		result.AddInnerHTMLElement(scriptPCCHelper);

		// Add Javascript from DisplayJavascript PEI
		HTMLScriptCollection myPEIScripts = DisplayJavascriptHelper.getInstance().DoDisplayJavascriptPEIs(m_asOwner);
		if (myPEIScripts != null)
		{
			result.AddInnerHTMLElement(myPEIScripts);
		}
		
		if (m_asOwner.GetIsInPlaceRefreshEnabled())
		{
		    // if in place refresh is enabled, add supporting js.
	
			// Add the callback function for ptinplacerefresh.js to return the jsxml version number prefix
		    //String strXMLVersion = ConfigHelper.GetJSIncluderComponentVersion(ConfigHelper.JSCOMPONENT_JSXML);
		    String strJSXMLPrefixString = ConfigService.getInstance().GetJSIncluderVersionPrefix(ConfigHelper.JSCOMPONENT_JSXML);
		    if ( XPStringUtility.EndsWith(strJSXMLPrefixString, ".")  ) {
		    	strJSXMLPrefixString = XPStringUtility.Substring(strJSXMLPrefixString, 0, strJSXMLPrefixString.length()-1);
		    }
		    
		    HTMLScript preScript = new HTMLScript(HTMLScript.TYPE_JAVASCRIPT);
		    
		    preScript.AddInnerHTMLString("function getJSXMLVersionObject() { return '"+strJSXMLPrefixString+"';}");
		    result.AddInnerHTMLElement(preScript);
		}

		return result;
	}

	/**
	 * Constructs the head for the Plumtree display page.  Note that this
	 * function must be called after calling DisplayBody(), because of the
	 * special case of intrinsic portlets on the MyPortalDP.  Intrinsic
	 * portlets view registration, which occurs in PageDisplay(), must occur
	 * prior to Javascript generation, which occurs during
	 * DisplayJavaScriptFromChild().
	 * 
	 * @param nNavScheme		Navigation scheme ID
	 * @return HTMLHead
	 * @see NavTypeConstants
	 */
	protected HTMLHead DisplayHead(int nNavScheme)
	{
		HTMLHead myHead = new HTMLHead();

		try
		{
			/**
			 * This area is handled by the standard stylesheets tag.
			 */

			myHead.AddInnerHTMLElement(m_asOwner.GetStyleSheetLinks());

			/**
			 * End of area handled by the standard stylesheets tag.
			 */

			/**
			 * This area is handled by the standard realmname tag.
			 */

			HTMLTitle myTitle = new HTMLTitle(XPHttpUtility.HtmlEncode(GetFormTitle()));
			myHead.AddInnerHTMLElement(myTitle);

			/**
			 * End of area handled by the standard realmname tag.
			 */

			// Calculate whether or not to display javascript.
			boolean bNoJavascript = !(GetUseJavascript());

			if (!bNoJavascript)
			{
				/**
				 * This area is handled by the PageRefresh layout content tag.
				 */

				// meta-refresh tag for auto refresh of the page
				HTMLMeta tag = GetMetaRefresh();
				if (tag!= null)
				{
					myHead.AddInnerHTMLElement(tag);
				}

				/**
				 * End of area handled by the PageRefresh layout content tag.
				 */

				/**
				 * This area is handled by the BasePage layout content tag.
				 */
				
				// Javascript functions
				myHead.AddInnerHTMLElement(GetBasicJavascript());

				/**
				 * End of area handled by the BasePage layout content tag.
				 */

				// Add shared JavaScript collection from tag portlets
				// In layout mode, this is handled by the head includes tag.
				myHead.AddInnerHTMLElement(GatewayUtils.GetSharedJavaScriptFromMarkup(m_asOwner));

				// For prefs dropdown menus - only want to include the jsportalmenu javascript on myportal pages and when the navigation scheme is not
				// using the jsportalmenus already
				if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD &&
					  m_asOwner.GetModelExists(MyPortalModel.STR_MVC_CLASS_NAME) && 
					  nNavScheme != NavTypeConstants.NAVTYPE_ID_HORIZONTAL_DHTML_DROPDOWN_JSPORTALMENU )
				{
					try {
						myHead.AddInnerHTMLElement(ConfigService.getInstance().GetJSIncluderJSComponentInclude(ConfigHelper.JSCOMPONENT_JSPORTALMENU, GetOwner()));
					} catch (Exception e) {
						log.Error(e, "Unable to retrieve jscomponent includes. Javascript on the page will most likely NOT work!");
					}
				}
				
				/**
				 * This area is handled by the BasePage layout NavArea tag.
				 */
				
				// URLTemplate script
				HTMLScript script = new HTMLScript("text/javaScript");
				script.AddInnerHTMLString(NavigationCommonHelpers.writeURLTemplateParseFunction(
						m_asOwner));
				myHead.AddInnerHTMLElement(script);
				
				/**
				 * End of area handled by the BasePage layout NavArea tag.
				 */
				
				// Javascript from plugable navs
				INavTypes navType = ((PlumtreeAS)m_asOwner).GetNavType(nNavScheme);
								
				// Pretty bad if we can't even get the default nav
				if ( navType == null)
				{
					log.Error("Fatal error, unable to load default navigation: " + 
						NavTypeConstants.NAV_TYPE_ID_DEFAULT +
						" Pluggable navigation module incorrectly installed or configured.");
				}	
				
				HTMLScriptCollection scripts = navType.JavaScriptIncludes(m_asOwner);
				if ( scripts != null ) {
					myHead.AddInnerHTMLElement(scripts);	
				}
				
				// get the pluggable views and display any javascript they might have
				try 
				{		
					AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.ABOVEBODY));
					AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.LEFTOFBODY));
					AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.RIGHTOFBODY));
					AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.BELOWBODY));
					AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.ABOVEBANNER));
					AddNavViewJavascript(myHead, GetPlugNav(navType, NavAreaEnum.BELOWBANNER));
				}
				catch (Exception e)
				{
					log.Error(e, "Error adding Pluggable NavView javascript to HTMLHead");				
				}
			}

			// JF- Helper method so that Activity Spaces can add HTML into the head
			// (like meta and link tags for example).           
			HTMLElementCollection myHTMLinHead = DisplayHTMLinHEAD();

			if (null != myHTMLinHead)
			{
				myHead.AddInnerHTMLElement(myHTMLinHead);
			}
		}
		catch (Exception e)
		{
			log.Error(e, "Unable to display head.");
		}

		return myHead;
	}

	/**
	 * This is a helper method that all classes that inherit from PlumtreeDP
	 * need to implement.  The method should add whatever HTML the child class
	 * wants to use the DisplayJavaScript and add it to the head.
	 *
	 * @return HTMLScript block
	 *
	 * @throws HTMLException
	 */
	protected HTMLScript DisplayJavaScriptToHead()

	{
		return null;
	}
	
	/**
	 * Makes navigation more bulletproof, gives user feedback when a navigation element fails
	 * @param body
	 * @param details
	 */
	private void HandleNavCrash( boolean vertical, HTMLBody body, String details, Exception e )
	{
		HTMLTable myTable = new HTMLTable();
		myTable.SetSummary(m_asOwner.GetString(550, "ptmsgs_portalcommonmsgs"));
		myTable.SetCellSpacing(CommonHTMLStrings.ZERO);
		myTable.SetCellPadding(CommonHTMLStrings.ZERO);
		myTable.SetBorder(CommonHTMLStrings.ZERO);
		myTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		myTable.SetSummary(m_asOwner.GetString(550, "ptmsgs_portalcommonmsgs"));

		HTMLTableRow myTableRow = new HTMLTableRow();
		myTable.AddInnerHTMLElement(myTableRow);
		myTableRow.SetVAlign(CommonHTMLStrings.TOP);
		myTableRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);

		HTMLTableCell myCell = new HTMLTableCell();

		if (vertical)
		{
			myCell = new HTMLTableCell();
			myTableRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myCell.SetAlign(CommonHTMLStrings.MIDDLE);
			myCell.SetNoWrap(true);
	
			HTMLH1 headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			headerH1.AddInnerHTMLString(details);
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);
		}
		else
		{
			// First Cell
			myTableRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			myCell.SetHeight("60");
	
			// End of First Cell
			// Second Cell
			myCell = new HTMLTableCell();
			myTableRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("200");
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myCell.SetNoWrap(true);
	
			HTMLH1 headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			headerH1.AddInnerHTMLString(details);
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);

			// End of Second Cell
	
			// third cell -- space
			myCell = new HTMLTableCell();
			myTableRow.AddInnerHTMLElement(myCell);
			myCell.SetWidth("10");
			myCell.SetAlign(CommonHTMLStrings.RIGHT);
			myCell.SetNoWrap(true);
	
			headerH1 = new HTMLH1();
			myCell.AddInnerHTMLElement(headerH1);
			headerH1.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			headerH1.SetStyleClass(PTStyleClass.BAN_HEADER);
		}

		// add to the page at this point as a table
		body.AddInnerHTMLElement(myTable);
		log.Error(e, "PlumtreeDP: Pluggable Navigation: " + details);											
	}

	/**
	 * Forms meta-refresh tag for page auto refreshing.
	 * 
	 * Override this method to do custom page refreshes.
	 * 
	 * @return HTMLMeta to be included, or null
	 */
	public HTMLMeta GetMetaRefresh()
	{
		// NOTE: This is only used by MyPortalDP for the mypage (and possibly the community).
		// Should we remove this somehow?
		return null;
	}

	private void OverrideNavSettingsFromVarPack(INavTypes navType)
	{
		// Override table spacing from NavigationSettings.xml
		int nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPTABLESPACING + navType.GetID(), m_asOwner); 
		if ( -1 != nSetting )
		{ 
			m_nTableSpacing = nSetting;
		}
		
		// Override left spacing from NavigationSettings.xml
		nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPLEFTWIDTH + navType.GetID(), m_asOwner); 
		if ( -1 != nSetting )
		{ 
			m_nLeftWidth = nSetting;
		}
		
		// Override left spacing without right spacing from NavigationSettings.xml
		nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPLEFTWIDTHALONE + navType.GetID(), m_asOwner); 
		if ( -1 != nSetting )
		{ 
			m_nLeftWidthAlone = nSetting;
		}
		
		// Override right spacing from NavigationSettings.xml
		nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPRIGHTWIDTH + navType.GetID(), m_asOwner); 
		if ( -1 != nSetting )
		{ 
			m_nRightWidth = nSetting;
		}
	
		// Override right spacing without left spacing from NavigationSettings.xml
		nSetting = NavigationCommonHelpers.GetNavSettingsValueAsInt(PTNavSettingsVarPack.INTPLUMTREEDPRIGHTWIDTHALONE + navType.GetID(), m_asOwner); 
		if ( -1 != nSetting )
		{ 
			m_nRightWidthAlone = nSetting;
		}
	}
	
	private static void AddNavViewJavascript(HTMLHead head, IView navView)
	{
		if( navView != null )
		{
			HTMLScript script = navView.DisplayJavascript();
			
			if( null != script )
			{
				head.AddInnerHTMLElement(script);
			}
		}
	}
	
	protected void RegisterNavScheme(int nCurrentScheme) {
		INavigationModelRO navModel = ((INavigationModelRO) m_asOwner.GetModel(NavigationModel.STR_MVC_CLASS_NAME));
		int nRegisteredScheme = navModel.GetRegisteredViewNavScheme();

		if (nCurrentScheme != nRegisteredScheme) {
			INavTypes regNavType = ((PlumtreeAS) m_asOwner).GetNavType(nRegisteredScheme);
			INavTypes curNavType = ((PlumtreeAS) m_asOwner).GetNavType(nCurrentScheme);
	
			IXPEnumerator navAreas = NavAreaHelper.INSTANCE.GetCategoryTypes();
			if (navAreas != null)
			{
				// For each page area within this pluggable nav, 
				// register the view with the AS
				while (navAreas.MoveNext())
				{
					String pView;
					// Unregister old scheme
					//if (nRegisteredScheme != NavTypeConstants.NAVTYPE_ID_INVALID) {
						pView = NavAreaHelper.INSTANCE.GetNavAreaViewClassName(regNavType, (NavAreaEnum)navAreas.GetCurrent()); 
						if(pView != null)
						{
							if ( m_asOwner.GetViewExists(pView) )
								m_asOwner.UnRegisterView(pView);
						}
					//}
					// Register current scheme
					pView = NavAreaHelper.INSTANCE.GetNavAreaViewClassName(curNavType, (NavAreaEnum)navAreas.GetCurrent()); 
					if(pView != null)
					{
						if ( !m_asOwner.GetViewExists(pView) )
							m_asOwner.RegisterView(pView, navModel);
					}
				}
			}
			navModel.SetRegisteredViewNavScheme(nCurrentScheme);
		}
	}

}
