package com.plumtree.portalpages.common.uiparts;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.login.*;
import com.plumtree.portalpages.browsing.search.advanced.*;
import com.plumtree.portalpages.browsing.search.network.*;
import com.plumtree.portalpages.common.mediator.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;
import com.plumtree.portaluiinfrastructure.friendlyurl.FriendlyURLConstants;
import com.plumtree.portaluiinfrastructure.helpers.PTConfigService;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.uiinfrastructure.login.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This is the View for the Topbar (above the banner)
 * 
 * @author RobertZ
 */
/**
 * @author patrickc
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class PlumtreeTopBarView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_COMMON),
		"com.plumtree.portalpages.common.uiparts.PlumtreeTopBarView");
	
	public static final String STR_MVC_CLASS_NAME = "PTTopBar";

	protected static final String m_actionDivName   = "navactions";
	protected static final String m_editacctDivName = "editacct";

	protected AActivitySpace m_asOwner;
	protected NavigationModel m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new PlumtreeTopBarView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		HTMLElement result = null;

		try
		{
			HTMLElementCollection resultGroup = new HTMLElementCollection();
			resultGroup.AddInnerHTMLElement(GetMainTableElement());
			resultGroup.AddInnerHTMLElement(DisplayJavascript());
			result = resultGroup;
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating topbar: " + e.getMessage());
			log.Error(e, "Error creating topbar: " + e.getMessage());
		}

		return result;
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		m_model		  = (NavigationModel) model;
	}

	/**
	 * Writes out the HTML for the topbar
	 *
	 * @return 						Generated HTML for the topbar
	 */
	protected HTMLElement GetMainTableElement()
	{
		HTMLElement element = new HTMLElementCollection();
		
		// Add main table to element
		HTMLTable ptTopbarTable = (HTMLTable) element.InsertInnerHTMLElement(new HTMLTable());
		ptTopbarTable.SetID(PTStyleID.PT_TOPBAR);
		ptTopbarTable.SetStyleClass(PTStyleClass.BAN_TOPBAR_BG);
		ptTopbarTable.SetCellSpacing(CommonHTMLStrings.ZERO);
		ptTopbarTable.SetCellPadding(CommonHTMLStrings.ZERO);
		ptTopbarTable.SetBorder(CommonHTMLStrings.ZERO);
		ptTopbarTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		
		// Add table row to main table
		HTMLTableRow tableRow = (HTMLTableRow) ptTopbarTable.InsertInnerHTMLElement(new HTMLTableRow());
		
		// Build first table cell
		HTMLTableCell firstCell = (HTMLTableCell) tableRow.InsertInnerHTMLElement(new HTMLTableCell());
		firstCell.SetAlign(CommonHTMLStrings.LEFT);
		firstCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		firstCell.SetNoWrap(true);
		firstCell.SetColSpan(null);
		AddDoubleLineBreakToElement(firstCell);
		
		// Add user nav to first table cell
		AddUserNavSpanToElement(firstCell);
		
		// Build second table cell
		HTMLTableCell secondCell = (HTMLTableCell) tableRow.InsertInnerHTMLElement(new HTMLTableCell());
		secondCell.SetAlign(CommonHTMLStrings.RIGHT);
		secondCell.SetVAlign(CommonHTMLStrings.MIDDLE);
		secondCell.SetNoWrap(true);
		secondCell.SetColSpan(null);
		AddDoubleLineBreakToElement(secondCell);
		
		// Add rules debug button to second table cell if debugging is enabled	
		if (RulesDebugMSGAS.GetIsRulesDebugEnabled(m_asOwner)) {
			AddRulesDebugButtonSpanToElement(secondCell);
		}
		
		// Add help button to second table cell
		AddHelpButtonSpanToElement(secondCell);
		
		// Add vertical separator to second table cell
		secondCell.AddInnerHTMLElement(CreateVerticalBarSpacerImg("1"));
		
		// Add search controls UI to second table cell
		AddSearchControlsSpanToElement(secondCell);

		return element;
	}
	
	protected HTMLImg CreateVerticalBarSpacerImg(String width)
	{
		HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.SPACER).GetHTMLElement();

		img.SetWidth(width);
		img.SetHeight(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		img.SetAlt("");
    	img.SetStyleClass(PTStyleClass.BG_DARK);
    	img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
    	img.SetBorder(CommonHTMLStrings.ZERO);

    	return img;
	}

	// TODO: Move this to common package
	protected HTMLSpan CreateSpacerHTMLSpan(int pixelWidth)
    {
    	HTMLSpan span = new HTMLSpan();
    	span.SetStyleClass("spacer");
    	span.SetStyle("padding-left:" + pixelWidth + "px;");

    	return span;
    }
	
	protected void AddUserNavSpanToElement(HTMLElement element)
	{
		// Create user nav spab
		HTMLSpan ptUserNavSpan = (HTMLSpan) element.InsertInnerHTMLElement(new HTMLSpan());
		ptUserNavSpan.SetID(PTStyleID.PT_USER_NAV);
		ptUserNavSpan.SetStyleClass(PTStyleClass.BAN_GREETING_TEXT + " " + PTStyleClass.BAN_TEXT);
		AddDoubleLineBreakToElement(ptUserNavSpan);
		
		// Add "My Home" link to user nav, as needed
		AddMyHomeLinkToElement(ptUserNavSpan);
		
		// Add welcome text to user nav
		HTMLSpan ptWelcomeText = (HTMLSpan) ptUserNavSpan.InsertInnerHTMLElement(new HTMLSpan());
		ptWelcomeText.SetID(PTStyleID.PT_WELCOME_TEXT);
		ptWelcomeText.AddInnerHTMLEncodedString(m_model.GetGreeting());
		AddDoubleLineBreakToElement(ptUserNavSpan);

		// Add spacing to user nav
		ptUserNavSpan.AddInnerHTMLElement(CreateSpacerHTMLSpan(8));
		AddDoubleLineBreakToElement(ptUserNavSpan);
		
		// Add "My Account" to user nav, as needed
		AddMyAccountLinkToElement(ptUserNavSpan);
		AddDoubleLineBreakToElement(ptUserNavSpan);
		
		// Add spacing to user nav
		ptUserNavSpan.AddInnerHTMLElement(CreateSpacerHTMLSpan(8));
		AddDoubleLineBreakToElement(ptUserNavSpan);
		
		// Add "Log In" / "Log Out" links to user nav, as needed
		AddLoginLogoutLinkToElement(ptUserNavSpan);
		AddDoubleLineBreakToElement(ptUserNavSpan);
	}
	
	protected void AddMyHomeLinkToElement(HTMLElement element)
	{
		HTMLSpan ptMyHomeLink = new HTMLSpan();
		ptMyHomeLink.SetID(PTStyleID.PT_MY_HOME_LINK);
		ptMyHomeLink.SetStyleClass(PTStyleClass.BAN_HELP_TEXT);

		if (!m_model.IsGuestSession() && !m_model.IsPreviewPage())
		{
			ICPListEntryIterator cpList = m_model.GetCategoryLinks(NavCategoryType.MYHOME, false);
			CListURLMediator mediator = new CListURLMediator(m_asOwner, cpList);

			if ( mediator.Next() )
			{
				HTMLAnchor anchor = (HTMLAnchor) mediator.GetEntry();
				ptMyHomeLink.AddInnerHTMLElement(anchor);
				element.AddInnerHTMLElement(ptMyHomeLink);

				// Add spacing and vertical bar to user nav
				AddDoubleLineBreakToElement(element);
				element.AddInnerHTMLElement(CreateSpacerHTMLSpan(1));
				element.AddInnerHTMLElement(CreateVerticalBarSpacerImg("1"));
				element.AddInnerHTMLElement(CreateSpacerHTMLSpan(1));
				AddDoubleLineBreakToElement(element);
			}
		}
	}
	
	// TODO: Stop using this after tidy-formatter is repaired in HTMLElements
	protected void AddDoubleLineBreakToElement(HTMLElement element)
	{
		element.AddInnerHTMLString("\n\n");
	}
	
	protected void AddMyAccountLinkToElement(HTMLElement element)
	{
		// My Account Link
		if (!m_model.IsGuestSession() && !m_model.IsPreviewPage())
		{
			ICPListEntryIterator cpList = m_model.GetPortalSettings();
			CListURLFullLinkMediator mediator = new CListURLFullLinkMediator(m_asOwner, cpList);

			if (mediator.Next())
			{
				HTMLSpan ptMyAccountLink = new HTMLSpan();
				ptMyAccountLink.SetID(PTStyleID.PT_MY_ACCOUNT_LINK);

				HTMLAnchor myAccountLink = (HTMLAnchor) mediator.GetEntry();
				ptMyAccountLink.AddInnerHTMLElement(myAccountLink);

				element.AddInnerHTMLElement(ptMyAccountLink);
			}
			else
			{
				log.Error("Navigation model returned empty My Account link.");
			}
		}
	}
	
	protected void AddLoginLogoutLinkToElement(HTMLElement element)
	{		
		if (!m_model.IsGuestSession())
		{
			if (!m_model.IsEditProfile() && !m_model.IsPreviewPage())
			{
				HTMLSpan ptLogoffLink = new HTMLSpan();
				ptLogoffLink.SetID(PTStyleID.PT_LOGOFF_LINK);
				
				ASURL logoff = new ASURL(m_asOwner);
				logoff.SetLinkGetSpaceIfCached(LoginAS.STR_MVC_CLASS_NAME, m_asOwner);
				logoff.SetControl(LoginControl.STR_MVC_CLASS_NAME);
				logoff.AddControlArgument(LoginHelper.PARAM_DOLOGOUT);
				logoff.AddControlArgument(ASConstants.CLEARSESSION, "true");
				logoff.AddInnerHTMLString(m_asOwner.GetString(335, "ptmsgs_portalcommonmsgs"));
				
				ptLogoffLink.AddInnerHTMLElement(logoff.GetURLAsHTMLElement());
				
				element.AddInnerHTMLElement(ptLogoffLink);
			}

			// Do Nothing -- neither login nor logoff is appropriate
			else {}
		}
		else
		{
			HTMLSpan ptLoginLink = new HTMLSpan();
			ptLoginLink.SetID(PTStyleID.PT_LOGIN_LINK);
			
			ASURL login = new ASURL(m_asOwner);
			login.SetLinkGetSpaceIfCached(LoginAS.STR_MVC_CLASS_NAME, m_asOwner);
			login.SetControl(LoginControl.STR_MVC_CLASS_NAME);
			login.AddControlArgument(LoginHelper.PARAM_LOGIN);
			login.AddInnerHTMLString(m_asOwner.GetString(336, "ptmsgs_portalcommonmsgs"));
			
			ptLoginLink.AddInnerHTMLElement(login.GetURLAsHTMLElement());
			
			element.AddInnerHTMLElement(ptLoginLink);
		}
	}
	
	protected void AddHelpButtonSpanToElement(HTMLElement element)
	{
		HTMLSpan ptHelpButton = (HTMLSpan) element.InsertInnerHTMLElement(new HTMLSpan());
		ptHelpButton.SetID(PTStyleID.PT_HELP_BUTTON);
		ptHelpButton.SetStyleClass(PTStyleClass.BAN_HELP_TEXT);

		HTMLAnchor helpAnchor = HTMLConstructHelpers.GetHelpAnchor( this.m_asOwner );
		ptHelpButton.InsertInnerHTMLElement(helpAnchor);

		AddDoubleLineBreakToElement(ptHelpButton);
	}

	protected void AddRulesDebugButtonSpanToElement(HTMLElement element)
	{
		HTMLSpan ptRulesDebugButton = (HTMLSpan) element.InsertInnerHTMLElement(new HTMLSpan());
		ptRulesDebugButton.SetStyleClass(PTStyleClass.BAN_TEXT);
		ptRulesDebugButton.SetID(PTStyleID.PT_RULES_DEBUG_LINK);

		ASURL urlDebugPopUp = new ASURL(m_asOwner);
		urlDebugPopUp.SetLinkGetSpaceIfCached(RulesDebugMSGAS.STR_MVC_CLASS_NAME, m_asOwner);
		urlDebugPopUp.SetDisplayPage(RulesDebugMSGDP.STR_MVC_CLASS_NAME);
		
		HTMLAnchor rulesDebug = new HTMLAnchor( "#" );
		AccessStyles accessStyles = m_asOwner.GetAccessStyle();
		if( accessStyles == AccessStyles.STANDARD )
		{	
			rulesDebug.SetOnClick( "window.open( '" + urlDebugPopUp.GetURLAsString() + 
				"', 'rulesDebugWindow', 'status=no,toolbar=yes,menubar=no,resizable=yes,scrollbars=yes,location=no,width=1000,height=600'); return false;" );
		} else {
		    rulesDebug.SetHRef(urlDebugPopUp.GetURLAsString());
		}
		
		HTMLImg myDebugIcon = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ICON_SUBPORTAL_RULE, true, m_asOwner).GetHTMLElement();
		rulesDebug.AddInnerHTMLElement(myDebugIcon);
		
		
		myDebugIcon.SetAlt(m_asOwner.GetString(2969, "ptmsgs_portaladminmsgs"));
		myDebugIcon.SetWidth("16");
		myDebugIcon.SetHeight("16");
		myDebugIcon.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		myDebugIcon.SetBorder(CommonHTMLStrings.ZERO);

		rulesDebug.SetTitle(m_asOwner.GetString(2969, "ptmsgs_portaladminmsgs"));
		
		rulesDebug.AddInnerHTMLString(m_asOwner.GetString(2969, "ptmsgs_portaladminmsgs"));
		
		ptRulesDebugButton.InsertInnerHTMLElement(rulesDebug);

		AddDoubleLineBreakToElement(ptRulesDebugButton);
	}
	
	protected void AddSearchControlsSpanToElement(HTMLElement element)
	{
		if (!(m_asOwner.GetName().equals(com.plumtree.portalpages.browsing.search.results.SearchResultAS.STR_MVC_CLASS_NAME) ||
				m_asOwner.GetName().equals(com.plumtree.portalpages.browsing.search.advanced.AdvancedSearchAS.STR_MVC_CLASS_NAME)))
		{
			// Add search controls span to element
			HTMLSpan ptSearchControls = (HTMLSpan) element.InsertInnerHTMLElement(new HTMLSpan());
			ptSearchControls.SetID(PTStyleID.PT_SEARCH_CONTROLS);
			ptSearchControls.SetStyleClass(PTStyleClass.BAN_GREETING_TEXT);

			// TODO: This factory stuff is responsible for adding in the ugly
			// script.  Need to track it down and get it into an include file.
			
			// Add search form to search controls span
			SearchFormFactory factory = new SearchFormFactory(SearchFormFactory.BANNER_NAME_PREFIX, SearchFormFactory.BANNER_NAME_PREFIX, m_asOwner);
			SetupBannerSearchSettings(factory);
			HTMLForm searchForm = factory.GetForm();
			ptSearchControls.AddInnerHTMLElement(searchForm);
			
			// Add "Search:" string to search form
			searchForm.AddInnerHTMLString(m_asOwner.GetString(566, "ptmsgs_portalcommonmsgs"));
			searchForm.AddInnerHTMLElement(CreateSpacerHTMLSpan(6));
			
			// Add individual search elements to search form
			AddSearchScopePulldownToElement(searchForm, factory);
			AddSearchTextBoxToElement(searchForm, factory);
			AddSearchButtonBasicToElement(searchForm, factory);
			AddSearchButtonAdvancedToElement(searchForm, factory);
			AddSearchButtonFederatedToElement(searchForm, factory);
		}
	}
	
	protected void AddSearchScopePulldownToElement(HTMLElement element, SearchFormFactory factory)
	{
		// Set banner search settings.
		// Search dropdown
		boolean bIsCommPage = m_model.IsCommunityPage();
		boolean bIsDirPage  = m_model.IsDirPage();

		if (bIsCommPage || bIsDirPage)
		{
			HTMLSelect select = new HTMLSelect(factory.GetNextSelectName(), "");
			select.SetStyleClass(PTStyleClass.FORM_PULLDOWN_TEXT);

			HTMLOption option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("everything") );
			option.AddInnerHTMLString(m_asOwner.GetString(344, "ptmsgs_portalcommonmsgs"));

			if (bIsCommPage)
			{
				option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("comm") );
				option.AddInnerHTMLString(m_asOwner.GetString(345, "ptmsgs_portalcommonmsgs"));
			}
			else if (bIsDirPage)
			{
				option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("allfold") );
				option.AddInnerHTMLString(m_asOwner.GetString(346, "ptmsgs_portalcommonmsgs"));

				option = (HTMLOption) select.InsertInnerHTMLElement( new HTMLOption("thisfold") );
				option.AddInnerHTMLString(m_asOwner.GetString(347, "ptmsgs_portalcommonmsgs"));
			}

			element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			element.AddInnerHTMLElement(select);
		}
	}
	
	protected void AddSearchTextBoxToElement(HTMLElement element, SearchFormFactory factory)
	{
		// RT - Turning off the name validation for this Search input, since Search Form
		// appends query parameter to the action url and we want it to look friendly like 
		// http://protalurl/searchkeyword?q=searchstring
		
		HTMLInput textBox = new HTMLInput(HTMLInputTypes.TEXT_TYPE, "");

		// If friendly url for search is on, then we skip validation of Input Name because
		boolean bUseFriendlySearch = PTConfigService.getPTInstance().UseFriendlyURLS(FriendlyURLConstants.FRIENDLY_SEARCH_ID, "");
		if(bUseFriendlySearch ) {
			textBox.SetValidateName(false);
		}		

		textBox.SetName(factory.GetInputBoxName());
		
		textBox.SetStyleClass(PTStyleClass.FORM_TEXTBOX_TEXT);
		textBox.SetSize(20);
		textBox.SetMaxLength(200);

		String strSearch = m_asOwner.GetString(341, "ptmsgs_portalcommonmsgs");
		textBox.SetAlt(strSearch);
		textBox.SetTitle(strSearch);

		// Only set keydown if not in 508 mode
		if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
		{
			String onKeyDown = factory.GetInputBoxOnKeyDown();
			if (onKeyDown != null) { textBox.SetOnKeyDown(onKeyDown); }
		}

		element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
		element.AddInnerHTMLElement(textBox);
		element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}
	
	protected void AddSearchButtonBasicToElement(HTMLElement element, SearchFormFactory factory)
	{
		String strSearch = m_asOwner.GetString(341, "ptmsgs_portalcommonmsgs");
		String onclick = factory.GetAnchorOnClick();
		
		HTMLSpan buttonSpan = new HTMLSpan();
		buttonSpan.SetID(PTStyleID.PT_SEARCH_SUBMIT_BUTTON);

		// Full UI mode
		if (onclick != null)
		{
			HTMLAnchor searchButtonAnchor = new HTMLAnchor(ConstructStaticHelpers.BLANK_URL);
			searchButtonAnchor.SetOnClick(onclick);

			PTConstruct searchButton = UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON, true, m_asOwner);

			if (searchButton != null)
			{
				HTMLImg searchButtonImg = (HTMLImg) searchButton.GetHTMLElement();

				searchButtonImg.SetAlt(strSearch);
				searchButtonImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
				searchButtonImg.SetBorder(CommonHTMLStrings.ZERO);
				searchButtonAnchor.AddInnerHTMLElement(searchButtonImg);
				searchButtonAnchor.SetTitle(strSearch);
			}

			buttonSpan.AddInnerHTMLElement(searchButtonAnchor);
			element.AddInnerHTMLElement(buttonSpan);
		}
		
		// 508 UI mode
		else
		{
			HTMLInput searchSubmitButton = new HTMLInput(HTMLInputTypes.SUBMIT, "in_su_ptbanner", strSearch);
			searchSubmitButton.SetValue(strSearch); 
			searchSubmitButton.SetStyleClass(PTStyleClass.FORM_BTN_TEXT);
			searchSubmitButton.SetAlt(m_asOwner.GetString(44, "ptmsgs_portal508quickkeymsgs"));
			searchSubmitButton.SetAccessKey(m_asOwner.GetString(4, "ptmsgs_portal508quickkeymsgs"));
			
			buttonSpan.AddInnerHTMLElement(searchSubmitButton);
			element.AddInnerHTMLElement(buttonSpan);
		}

		element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}
	
	protected void AddSearchButtonAdvancedToElement(HTMLElement element, SearchFormFactory factory)
	{
		String strAdvancedSearch = m_asOwner.GetString(339, "ptmsgs_portalcommonmsgs");
		
		HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_ADVANCED, 
				true, this.m_asOwner).GetHTMLElement();
		img.SetAlt(strAdvancedSearch);
		img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		img.SetBorder(CommonHTMLStrings.ZERO);

		ASURL advsearch = new ASURL(m_asOwner);
		advsearch.SetLinkCreateNewSpace(AdvancedSearchAS.STR_MVC_CLASS_NAME, m_asOwner);
		advsearch.AddInnerHTMLElement(img);
		advsearch.SetLinkTitle(strAdvancedSearch);
		advsearch.SetControl(EditorStartControl.STR_MVC_CLASS_NAME);
		advsearch.AddControlArgument("editorType", "10");
		
		HTMLSpan buttonSpan = new HTMLSpan();
		buttonSpan.SetID(PTStyleID.PT_ADVANCED_SEARCH_BUTTON);
		buttonSpan.AddInnerHTMLElement(advsearch.GetURLAsHTMLElement());

		element.AddInnerHTMLElement(buttonSpan);
		element.AddInnerHTMLString(CommonHTMLStrings.SPACE);
	}
	
	protected void AddSearchButtonFederatedToElement(HTMLElement element, SearchFormFactory factory)
	{
		String strNetworkSearch = m_asOwner.GetString(340, "ptmsgs_portalcommonmsgs");

		HTMLImg img = (HTMLImg) UIConstructFactory.GetConstruct(PTImageType.ACTION_SEARCH_BUTTON_NETWORK,
				true, this.m_asOwner).GetHTMLElement();
		img.SetAlt(strNetworkSearch);
		img.SetAlign(CommonHTMLStrings.ABSMIDDLE);
		img.SetBorder(CommonHTMLStrings.ZERO);

		ASURL netsearch = new ASURL(m_asOwner);
		netsearch.SetLinkCreateNewSpace(NetworkSearchAS.STR_MVC_CLASS_NAME, m_asOwner);
		netsearch.AddInnerHTMLElement(img);
		netsearch.SetLinkTitle(strNetworkSearch);
		netsearch.SetControl(NetworkSearchControl.STR_MVC_CLASS_NAME);

		HTMLSpan buttonSpan = new HTMLSpan();
		buttonSpan.SetID(PTStyleID.PT_FEDERATED_SEARCH_BUTTON);
		buttonSpan.AddInnerHTMLElement(netsearch.GetURLAsHTMLElement());

		element.AddInnerHTMLElement(buttonSpan);
	}

	/**
	 *  Helper method to setup the search form with all the needed settings
	 */
	protected void SetupBannerSearchSettings(SearchFormFactory factory)

	{
		// NOTE: BestBets, spellchecking, and object type defaults are now applied
		// to banner search in BannerStartSearchControl, to make it easier for
		// PSOs or customers to customize these.  Here we just need to tell
		// the factory that this is a banner search.
		factory.ForceBannerSearchDefaults();

		// Add optional pulldown settings
		if (m_model.IsCommunityPage())
		{
			factory.AddOptionalSetting("comm",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_COMMUNITY_ID,
				new int[] { m_model.GetCurCommunityID() });
		}
		else if (m_model.IsDirPage())
		{
			// for "All Folders", any portal object under root docdir folder
			factory.AddOptionalSetting("allfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
				new int[] {  /* root folder = */1 });
			factory.AddOptionalSetting("allfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS,
				PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);

			// for "This Folder", any portal object under current docdir folder
			factory.AddOptionalSetting("thisfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS,
				new int[] { m_model.GetCurDocDirFolderID() });
			factory.AddOptionalSetting("thisfold",
				PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS,
				PT_SEARCH_APPS.PT_SEARCH_APPS_PORTAL);
		}
	}
}

