package com.plumtree.portalpages.common.uiparts;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This is the AS for Rules Debugging Messages.
 * 
 * @author dustina
 */
public class RulesDebugMSGAS extends AFormAS
{
	public static final String STR_MVC_CLASS_NAME = "RulesDebugMSGAS";
	
	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#GetName()
	 */
	public String GetName() {
		return STR_MVC_CLASS_NAME;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new RulesDebugMSGAS();
	}
	
	/**
	 * @see com.plumtree.portaluiinfrastructure.activityspace.AActivitySpace#CheckBasicAccess(String, String, boolean)
	 */
	public boolean CheckBasicAccess(String strPage, String strControl, boolean bSameSpace)
	{
		return true;
	}
	
	public String GetRepostControlName()
	{
		return RepostControl.STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.AActivitySpace#Init()
	 */
	public void Init()
	{
		super.Init();

		RegisterPage(new RulesDebugMSGDP());
		RegisterModel(RulesDebugMSGModel.STR_MVC_CLASS_NAME);
		IModel model = GetModel(RulesDebugMSGModel.STR_MVC_CLASS_NAME);
		RegisterControl(RepostControl.STR_MVC_CLASS_NAME, model);
	}

	/**
	 * This method calculates whether or not the subportal rules debug button
	 * is enabled for the server and the current user.
	 * 
	 * @param _asOwner The current AActivitySpace
	 * @return boolean True implies the rules debug button is enabled.
	 */
	public static boolean GetIsRulesDebugEnabled(AActivitySpace _asOwner)
	{
		IPTServerConfigSettings config = (IPTServerConfigSettings)
			((IPTSession) _asOwner.GetUserSession()).OpenGlobalObject(
			PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);

		boolean bRulesDebugEnabled = false;
		try {
			bRulesDebugEnabled = config.GetSettingAsInt(
					PT_SERVER_CONFIG_SETTINGNAME.PT_SETTINGNAME_ENABLE_DEBUG_SUBPORTAL_RULES_MODE) == 1 ;
		} catch (Exception e) {
			// DCA - setting not found in the database; assume debug mode off
		}
		
		Object ret = PTPersonalSettingsHelper.GetPersonalSettingValue(PersonalSettingNames.
			ENABLE_RULES_DEBUG_MODE, _asOwner);

		bRulesDebugEnabled = ((bRulesDebugEnabled) &&
			(null != ret) && (XPConvert.ToInteger(ret) == 1));

		return bRulesDebugEnabled;
	}
}

