/*
 * Created on Mar 5, 2003
 */
package com.plumtree.portalpages.common.uiparts.navpagetype;

import com.plumtree.portalpages.browsing.myportal.*;
import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.compoundlist.*;

/**
 * Delegates model methods only usable by community page.
 * 
 * @author DavidP
 */
public class CommunityNavPage extends NavigationPage implements ICommunityNavPageRO 
{
	/**	
	 * Unique String Name of category of object.  Critical for link blocking by pluggable nav.
	 */
	public String GetName()
	{
		return NavPageType.COMMUNITY.toString();
	}
	
	/**
	 * CommunityNavPage constructor.   
	 * @param model
	 */
	public CommunityNavPage(INavigationModelRO model)
	{
		super(model,NavPageType.COMMUNITY);
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetAccessibleCommunityID(int)
	 */
	public int GetAccessibleCommunityID(int nSubPortalCommID)
	{
		return m_model.GetAccessibleCommunityID(nSubPortalCommID);
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurCommunityID()
	 */
	public int GetCurCommunityID()
	{
		return m_model.GetCurCommunityID();
	}
	
	/**
	 * Gets the ID of the current Community Page 
	 * 
	 * @return Community Page ID
	 */
	public int GetCurPageID()
	{
		return m_model.GetCurPageID();	
	}
	
	/**
	 * Checks if the current user is a member of the current Community
	 * 
	 * @return True if the user is a member
	 */
	public boolean IsMemberInCurCommunity()
	{
		return m_model.IsMemberInCurCommunity();
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurCommunityName()
	 */
	public String GetCurCommunityName()
	{
		return m_model.GetCurCommunityName();
	}

	/**
	 * Gets the current community pages.
	 * 
	 * @return ICPListEntryIterator
	 */
	public ICPListEntryIterator GetCurCommPages()
	{
		return m_model.GetCurCommPages();
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurRelCommunities()
	 */
	public ICPListEntryIterator GetCurRelCommunities()
	{
		return m_model.GetCurRelCommunities();
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCurSubCommunities()
	 */
	public ICPListEntryIterator GetCurSubCommunities()
	{
		return m_model.GetCurSubCommunities();
	}

	//
	// Subportal functions END
	//
	//
	// Misc functions
	//

	/**
	 * Get the ID of the user's Default Community ID
	 */
	public int GetDefaultCommunity()
	{
		return m_model.GetDefaultCommunity();
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetMyCommunities(boolean)
	 */
	public ICPListEntryIterator GetMyCommunities(boolean bListActions)
	{
		return m_model.GetMyCommunities(bListActions);
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetParentComm()
	 */
	public ICPListEntryIterator GetParentComm()
	{
		return m_model.GetParentComm();
	}

	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#IsCurCommOwner()
	 */
	public boolean IsCurCommOwner()
	{
		return m_model.IsCurCommOwner();
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#GetCommunityID()
	 */
	public int GetCommunityID()
	{
		IMyPortalModelRO portalMod = (IMyPortalModelRO)m_model.GetMyPortalModel();
		if (portalMod == null)
			return 0;
		
		return portalMod.GetCommunityID();
	}
	
	/**
	 * Returns true if this page should show the "Inside this Community" header and
	 * sub- and related communitites.
	 *
	 * @return true if the page should show community nav links
	 */
	public boolean ShowCommunityNavigation()
	{
		return m_model.ShowCommunityNavigation();
	}
	
	/**
	 * 
	 * @see com.plumtree.portalpages.common.plugnav.ICommunityNavPageRO#CanJoinCurCommunity()
	 */
	public boolean CanJoinCurCommunity()
	{
		return m_model.CanJoinCurCommunity();
	}
	
}

