/*
 * Created on Mar 5, 2003
 */
package com.plumtree.portalpages.common.uiparts.navpagetype;

import com.plumtree.portalpages.common.plugnav.*;
import com.plumtree.portalpages.common.uiparts.*;

/**
 * Class used as facade to navigation model for methods 
 * appropriate to which page is current
 * 
 * @author DavidP
 *
 */
public abstract class NavigationPage implements INavigationPageRO
{
	// shared by derived classes but not outside
	protected INavigationModelRO m_model;
	protected NavPageType m_type; 
	
	/**
	 * Protected ctor() to prevent instantiation except through factory method below
	 * Feel free to place navpage-wide code here
	 */
	protected NavigationPage(INavigationModelRO model, NavPageType type)
	{
		m_model = model;
		m_type = type;
	}
	
	/**
	 * Factory to instantiate proper navigation page object by type
	 * 
	 * @param type		NavPageType
	 * @param model		The Navigation model interface
	 * @return 			The requested NavigationPage interface
	 * @see NavPageType
	 */
	public static NavigationPage Create(NavPageType type, INavigationModelRO model)
	{
		// instantiate a navigation page based on nav page type
		// This list must closely match the nav page types
		if (type.equals(NavPageType.COMMUNITY))
			return new CommunityNavPage(model);
		if (type.equals(NavPageType.USERPROFILE))
			return new UserProfileNavPage(model);
		if (type.equals(NavPageType.LOGIN))
			return new LoginNavPage(model);
		if (type.equals(NavPageType.MYPAGE))
			return new MyPageNavPage(model);
		if (type.equals(NavPageType.COMMUNITYPREVIEW))
			return new CommunityPreviewNavPage(model);
		if (type.equals(NavPageType.DIRECTORY))
			return new DirectoryNavPage(model);
		
		// unrecognized type request
		return null;
	}
	
	/**
	 * Returns the type of the page created
	 * 
	 * @return NavPageType
	 */
	public NavPageType GetPageType()
	{
		return m_type;
	}
	
	/**
	 * Core name of object.  Critical for link matchign and naming.
	 * 
	 * @return String
	 */
	public String GetName() 
	{
		// complex - will calls truly defer to the correct parent?
		return "MAJOR NAMING ERROR";
	}
	
	
	// TODO: session hash object for session wide storage of nav state
}

