package com.plumtree.portalpages.condition.conditiontypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author okana
 */
public class ConditionTypeAdminFolderID extends ARegularConditionType {
    
    /* (non-Javadoc)
     * @see com.plumtree.server.condition.IConditionServerType#GetTypeID()
     */
    public int GetTypeID() {
        return ConditionTypeConstants.CONDITIONTYPE_ID_ADMIN_FOLDER;
    }

    /* (non-Javadoc)
     * @see com.plumtree.server.condition.IConditionServerType#Compare(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.server.condition.IValue, com.plumtree.openfoundation.util.XPStringBuilder)
     */
    public boolean Compare(XPHashtable htUserEnvironment, IValue conditionValue, XPStringBuilder sbDebugText) {
        // check that objValue is of type integer and that the admin folder id is in the current environment
        if (conditionValue.GetType() != ValueTypeEnum.INTEGER ||
                !htUserEnvironment.ContainsKey(new Integer(GetTypeID()))) {
            if (null != sbDebugText) {
                sbDebugText.Append("Condition on admin folder returning false because either the condition value is of the wrong type,")
                        .Append(" or the user's admin folder was not found in the user's environment<br>");
                ruleDebugger.Debug("Experience Rules - Condition on admin folder returning false because either the condition value is of the wrong type, or the user's admin folder was not found in the user's environment");
            }
            return false;
        }
        // cast value to type: Integer
        Integer adminFolderID = (Integer) conditionValue.GetValue();

        Integer userEnvAdminFolder = (Integer) htUserEnvironment.GetElement(new Integer(GetTypeID()));

        if (XPConvert.ToInteger(userEnvAdminFolder) == XPConvert.ToInteger(adminFolderID)) {
            if (null != sbDebugText) {
                sbDebugText.Append("Condition on Admin Folder returning true because the Admin Folder ID: ").Append(XPConvert.ToString(adminFolderID))
                           .Append(" matches one of the Admin Folder ID found in the user's environment: ").Append(XPConvert.ToString(userEnvAdminFolder))
                           .Append("<br/>");
                ruleDebugger.Debug("Experience Rules - Condition on Admin Folder returning true because the Admin Folder ID: " + XPConvert.ToString(adminFolderID) + 
                        " matches one of the Admin Folder ID found in the user's environment: " + XPConvert.ToString(userEnvAdminFolder));
            }
            return true;
        }

        if (null != sbDebugText) {
            sbDebugText.Append("Condition on AdminFolderID returning false because the AdminFolderID: ").Append(XPConvert.ToString(adminFolderID))
                    .Append(" does not match one of the AdminFolderIDs found in the user's environment: ").Append(XPConvert.ToString(userEnvAdminFolder))
                    .Append("<br/>");
            ruleDebugger.Debug("Experience Rules - Condition on Admin Folder returning false because the Admin Folder ID: " + XPConvert.ToString(adminFolderID) + 
                    " does not match one of the AdminFolderIDs found in the user's environment: " + XPConvert.ToString(userEnvAdminFolder));
        }
        return false;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.ARegularConditionType#GetCurrentValue(com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.openfoundation.web.IXPRequest, com.plumtree.server.IPTSession, com.plumtree.openfoundation.util.XPHashtable)
     */
    public void GetCurrentValue(AActivitySpace asCurrentSpace, IXPRequest xpRequest, IPTSession userSession, XPHashtable htUserEnvironment) {
        try {
            Integer adminFolder = new Integer(userSession.GetSessionInfo().GetCurrentUserAdminFolderID());
            htUserEnvironment.PutElement(new Integer(GetTypeID()), adminFolder);
        } catch (Exception e) {
            log.Error("ConditionTypeAdminFolderID::GetCurrentValue An error occured while trying to get the current condition value. The following exception occured: " +
                    e);
        }
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetMyConditionsListSectionTitle(XPResourceManager xpRM, String strLanguage) {
        String strResult;
        try {
			strResult = xpRM.GetString(3194, "ptmsgs_portaladminmsgs", strLanguage);
        } catch (Exception e) {
            strResult = "The user is in ANY of the following Administrative Folders:";
        }
        return strResult;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionSubTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetMyConditionsListSectionSubTitle(XPResourceManager xpRM, String strLanguage) {
        String strResult;
        try {
            strResult = xpRM.GetString(781, "ptmsgs_portaladminmsgs", strLanguage);
        } catch (Exception e) {
            strResult = "Administrative Folder Name";
        }
        return strResult;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListAddLabel(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetMyConditionsListAddLabel(XPResourceManager xpRM, String strLanguage) {
        String strResult;
        try {
            strResult = xpRM.GetString(3195, "ptmsgs_portaladminmsgs", strLanguage);
        } catch (Exception e) {
            strResult = "Add Administrative Folders";
        }
        return strResult;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListIcon()
     */
    public PTImageType GetMyConditionsListIcon() {
        return PTImageType.ICON_FOLDER;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValueType()
     */
    public int GetConditionValueType() {
        return ValueTypeEnum.INTEGER;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValue(int, com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO)
     */
    public Object GetConditionValue(int nRow, IPTGrowableSortedArrayWrapperRO saData) {
        Object result = saData.GetItem(nRow, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
        try {
            // check that admin folder id is valid
            XPConvert.ToInteger(result);
        } catch (Exception e) {
            throw new ValidationFailedException();
        }
        return result;
    }

    /* (non-Javadoc)
* @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetValidationFailedString(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
*/
    public String GetValidationFailedString(XPResourceManager xpRM, String strLanguage) {
        String strResult;
        try {
            strResult = xpRM.GetString(3197, "ptmsgs_portaladminmsgs", strLanguage);
        } catch (Exception e) {
            strResult = "Invalid Administrative Folder: An Administrative Folder Value must be an integer.";
        }
        return strResult;
    }

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetDescriptionString(com.plumtree.server.condition.IValue, com.plumtree.server.IPTSession)
     */
    public String GetDescriptionString(IValue ConditionValue, IPTSession ptSession) {
        IPTAdminFolder adminFolder = ptSession.GetAdminCatalog().OpenAdminFolder(XPConvert.ToInteger(ConditionValue.GetValue()), false);
        XPStringBuilder sbAdminF = new XPStringBuilder();
        sbAdminF.Append("User is in Administrative Folder: ").Append(adminFolder.GetName());
        return sbAdminF.ToString();
    }

    /**
     * Overriding Parent's implementation to use a different expandable list
     */
    public void RegisterMyConditionsList(AActivitySpace asCurrentSpace) {
        // Register the model.
        asCurrentSpace.RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier());

        // Get back the Model we just registered because we need it to register the Section and the Control
        IModel mySelectPTObjectModel = asCurrentSpace.GetModel(GetConditionTypeIdentifier());
        asCurrentSpace.RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), mySelectPTObjectModel);
        asCurrentSpace.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), mySelectPTObjectModel);
    }

    /**
     * Overriding Parent's implementation to use a different expandable list
     */
    public void InitializeMyConditionsList(ExpListModel myListModel, String strLanguage) {

        // Get the resource manager for localization
        IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
        XPResourceManager xpRM = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");

        SelectPTObjectModel myPTObjectModel = (SelectPTObjectModel) myListModel;
        // Initialize the Select PTObject list.
        //      _sSectionTitle: Main title.
        //      _sSectionSubTitle: Sub title.
        //      _imgAddIcon: Icon for the add action.
        //      _sAddLabel: Text to display next to the add icon.
        //      _arrObjectClassIDs Class ID of the Objects displayed on the list.
        //      _nListKey: In case you have multiple Expandable Lists on
        //                 the same DP, they should have a different key
        //                 (otherwise, just set it to 1).
        myPTObjectModel.InitializeSelectPTObject(GetMyConditionsListSectionTitle(xpRM, strLanguage),
                GetMyConditionsListSectionSubTitle(xpRM, strLanguage),
                GetMyConditionsListIcon(),
                GetMyConditionsListAddLabel(xpRM, strLanguage),
                new int[]{PT_CLASSIDS.PT_ADMIN_FOLDER_ID},
                GetTypeID());

        myPTObjectModel.SetTreeLeafType(TreeConstants.N_LEAFCOMPOSITESELECT);
        myPTObjectModel.SetDefaultRowIcon(GetMyConditionsListIcon());

        myPTObjectModel.SetTreeTitle(xpRM.GetString(1897, "ptmsgs_portaladminmsgs", strLanguage));
        myPTObjectModel.SetTreeSubTitle(xpRM.GetString(3196, "ptmsgs_portaladminmsgs", strLanguage));
    }

    /**
     * Overriding Parent's implementation to use a different expandable list
     */
    public void AddItemToMyConditionsList(Object objItem, ExpListModel myListModel, IPTSession ptSession) {
        IPTAdminFolder adminFolder = ptSession.GetAdminCatalog().OpenAdminFolder(XPConvert.ToInteger(objItem), false);
        SelectPTObjectModel myPTObjectModel = (SelectPTObjectModel) myListModel;
        Object[] objAdminFolder = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];

        objAdminFolder[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(myPTObjectModel.m_nNextIndex);
        myPTObjectModel.m_nNextIndex++;
        objAdminFolder[SelectPTObjectModel.EXPLIST_COL_CLASSID] = new Integer(PT_CLASSIDS.PT_ADMIN_FOLDER_ID);
        objAdminFolder[SelectPTObjectModel.EXPLIST_COL_OBJECTID] = objItem;
        objAdminFolder[SelectPTObjectModel.EXPLIST_COL_STRING] = adminFolder.GetName();
        myPTObjectModel.GetItems().AddRow(objAdminFolder);
    }
}
