package com.plumtree.portalpages.condition.conditiontypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author dustina
 */
public class ConditionTypeClientIPAddress extends AGuestConditionType {

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AGuestConditionType#GetTypeID()
	 */
	public int GetTypeID() {
		return ConditionTypeConstants.CONDITIONTYPE_ID_IPADDRESS;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AGuestConditionType#Compare(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.server.condition.IValue, com.plumtree.openfoundation.util.XPStringBuilder)
	 */
	public boolean Compare(XPHashtable htUserEnvironment, IValue conditionValue, XPStringBuilder sbDebugText) {
		// check that objValue is of type string and that the url domain is in the current environment
		if (conditionValue.GetType() != ValueTypeEnum.IPADDRESS || 
			!htUserEnvironment.ContainsKey(new Integer(GetTypeID()))) {
			if (null != sbDebugText) {
				sbDebugText.Append("Condition on Client IP Address returning false because either the condition value is of the wrong type,")
					.Append(" or the Client IP Address was not found in the user's environment<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Client IP Address returning false because either the condition value is of the wrong type, or the Client IP Address was not found in the user's environment");
			}
			return false;
		}
		// cast value to type: String
		String[] arIPAddress = (String[]) conditionValue.GetValue();
	
		String[] envIPAddress = (String[]) htUserEnvironment.GetElement(new Integer(GetTypeID()));
    
		// compare values
		for (int i=0; i<arIPAddress.length; i++) {
			if (XPStringUtility.Compare(arIPAddress[i], "*") != 0 && 
				XPStringUtility.Compare(arIPAddress[i], envIPAddress[i]) != 0) {
				if (null != sbDebugText) {
					String strCondIP = arIPAddress[0] + "." + arIPAddress[1] + "." + arIPAddress[2] + "." + arIPAddress[3];
					String strEnvIP = envIPAddress[0] + "." + envIPAddress[1] + "." + envIPAddress[2] + "." + envIPAddress[3];
					sbDebugText.Append("Condition on Client IP Address returning false because the Client IP Address: ")
						.Append(strCondIP).Append(" does not match the one found in the user's environment: ")
						.Append(strEnvIP).Append("<br>");
                    ruleDebugger.Debug("Experience Rules - Condition on Client IP Address returning false because the Client IP Address: " + 
                            strCondIP +   " does not match the one found in the user's environment: " + strEnvIP);
				}
				return false;
			}
		}
		if (null != sbDebugText) {
			String strCondIP = arIPAddress[0] + "." + arIPAddress[1] + "." + arIPAddress[2] + "." + arIPAddress[3];
			String strEnvIP = envIPAddress[0] + "." + envIPAddress[1] + "." + envIPAddress[2] + "." + envIPAddress[3];
			sbDebugText.Append("Condition on Client IP Address returning true because the Client IP Address: ")
				.Append(strCondIP).Append(" matches the one found in the user's environment: ").Append(strEnvIP)
				.Append("<br>");
            ruleDebugger.Debug("Experience Rules - Condition on Client IP Address returning true because the Client IP Address: " + 
                    strCondIP +   " matches the one found in the user's environment: " + strEnvIP);
		}
		return true;
	}

	/* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AGuestConditionType#GetCurrentValue(com.plumtree.portaluiinfrastructure.condition.XPLimitedRequest, com.plumtree.server.IPTSession, com.plumtree.openfoundation.util.XPHashtable)
     */
    public void GetCurrentValue(XPLimitedRequest xpRequest, IPTSession guestReadOnlySession, XPHashtable htUserEnvironment) {
		String strIPAddress = xpRequest.GetClientAddress();
		String[] arIPAddress = new String[4];
		XPStringTokenizer xpTokenizer = new XPStringTokenizer(strIPAddress, ".", false);
		for (int i=0; i<arIPAddress.length; i++) {
			arIPAddress[i] = xpTokenizer.GetNextToken();
		}
		htUserEnvironment.PutElement(new Integer(GetTypeID()), arIPAddress);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2843, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "The user's IP is ANY of the following IPs:";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionSubTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionSubTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2844, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Client IP Addresses";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListAddLabel(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListAddLabel(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2845, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Add an IP Address";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AGuestConditionType#GetMyConditionsListIcon()
	 */
	public PTImageType GetMyConditionsListIcon() {
		return PTImageType.ICON_DOCUMENT_URL;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AGuestConditionType#GetConditionValueType()
	 */
	public int GetConditionValueType() {
		return ValueTypeEnum.IPADDRESS;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValue(int, com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO)
	 */
	public Object GetConditionValue(int nRow, IPTGrowableSortedArrayWrapperRO saData) {
		Object[] arIPAddress = new Object[4];
		arIPAddress[0] = saData.GetItem(nRow, IPAddressListModel.EXPLIST_IPBOX_1);
		arIPAddress[1] = saData.GetItem(nRow, IPAddressListModel.EXPLIST_IPBOX_2);
		arIPAddress[2] = saData.GetItem(nRow, IPAddressListModel.EXPLIST_IPBOX_3);
		arIPAddress[3] = saData.GetItem(nRow, IPAddressListModel.EXPLIST_IPBOX_4);
		for (int i=0; i<4; i++) {
		    try {
                // check that IP Address is valid
		    	String ipAddr = (String)arIPAddress[i];
                if ("*".compareTo(ipAddr) != 0 && ((XPConvert.ToInteger(ipAddr) < 0) || ((i == 0) && (XPConvert.ToInteger(ipAddr) == 0)))) {
		            throw new ValidationFailedException();
		        }
		    } catch (Exception e) {
		        throw new ValidationFailedException();
		    }
		}
        
		return arIPAddress;
	}
	
	/* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetValidationFailedString(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetValidationFailedString(XPResourceManager xpRM, String strLanguage) {
        String strResult;
		try
		{
			strResult = xpRM.GetString(3148, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Invalid IP Address: An IP Address can only consist of positive integers and the '*' (wildcard) character.";
		}
		return strResult;
    }

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetDescriptionString(com.plumtree.server.condition.IValue, com.plumtree.server.IPTSession)
	 */
	public String GetDescriptionString(IValue ConditionValue, IPTSession ptSession) {
		XPStringBuilder sbIPAddress = new XPStringBuilder();
		sbIPAddress.Append("Client IP Address matches ");
		for (int i=0; i<4; i++) {
			sbIPAddress.Append(((String[]) ConditionValue.GetValue())[i]);
			if (i<3) {
				sbIPAddress.Append(".");
			}
		}
		return sbIPAddress.ToString();
	}

	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void RegisterMyConditionsList(AActivitySpace asCurrentSpace) {
		// Register the model.
		asCurrentSpace.RegisterModel(IPAddressListModel.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier());

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel myIPAddressListModel = asCurrentSpace.GetModel(GetConditionTypeIdentifier());
		asCurrentSpace.RegisterView(IPAddressListView.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), myIPAddressListModel);
		asCurrentSpace.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), myIPAddressListModel);
	}

	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void InitializeMyConditionsList(ExpListModel myListModel, String strLanguage) {
		
		// Get the resource manager for localization
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager xpRM     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
		
		IPAddressListModel myIPAddressListModel = (IPAddressListModel) myListModel;
		// Initialize the IPAddress List.
		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		myIPAddressListModel.InitializeGrowableList(
				GetMyConditionsListSectionTitle(xpRM, strLanguage),
				GetMyConditionsListSectionSubTitle(xpRM, strLanguage),
				GetMyConditionsListIcon(),
				GetMyConditionsListAddLabel(xpRM, strLanguage),
				GetTypeID());
	}
	
	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void AddItemToMyConditionsList(Object objItem, ExpListModel myListModel, IPTSession ptSession) {
		IPAddressListModel myIPAddressListModel = (IPAddressListModel) myListModel;
		myIPAddressListModel.AddRowToList(objItem);
	}
	
}
