package com.plumtree.portalpages.condition.conditiontypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author dustina
 */
public class ConditionTypeCommunityID extends ARegularConditionType {
	
	/* (non-Javadoc)
	 * @see com.plumtree.server.condition.IConditionServerType#GetTypeID()
	 */
	public int GetTypeID() {
		return ConditionTypeConstants.CONDITIONTYPE_ID_COMMUNITY;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.server.condition.IConditionServerType#Compare(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.server.condition.IValue, com.plumtree.openfoundation.util.XPStringBuilder)
	 */
	public boolean Compare(XPHashtable htUserEnvironment, IValue conditionValue, XPStringBuilder sbDebugText) {
		// check that objValue is of type integer and that the community id is in the current environment
		if (conditionValue.GetType() != ValueTypeEnum.INTEGER || 
			!htUserEnvironment.ContainsKey(new Integer(GetTypeID()))) {
			if (null != sbDebugText) {
				sbDebugText.Append("Condition on Community returning false because either the condition value is of the wrong type,")
					.Append(" or the Community ID was not found in the user's environment<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Community returning false because either the condition value is of the wrong type, or the Community ID was not found in the user's environment");
			}
			return false;
		}
		// cast value to type: Integer
		Integer comm_id = (Integer) conditionValue.GetValue();
		
		Object env_comm_id = htUserEnvironment.GetElement(new Integer(GetTypeID()));
        
		// compare values
		if (comm_id.equals(env_comm_id))
		{
			if (null != sbDebugText) {
				sbDebugText.Append("Condition on Community returning true because the Community ID: ").Append(XPConvert.ToString(comm_id))
					.Append(" matches the one found in the user's environment: ").Append(XPConvert.ToString(env_comm_id)).Append("<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Community returning true because the Community ID: " + XPConvert.ToString(comm_id) +
                        " matches the one found in the user's environment: " + XPConvert.ToString(env_comm_id));
			}
			return true;
		} else {
			if (null != sbDebugText) {
				sbDebugText.Append("Condition on Community returning false because the Community ID: ").Append(XPConvert.ToString(comm_id))
					.Append(" does not match the one found in the user's environment: ").Append(XPConvert.ToString(env_comm_id))
					.Append("<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Community returning false because the Community ID: " + XPConvert.ToString(comm_id) +
                        " does not match the one found in the user's environment: " + XPConvert.ToString(env_comm_id));
			}
			return false;
		}
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.ARegularConditionType#GetCurrentValue(com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.openfoundation.web.IXPRequest, com.plumtree.server.IPTSession, com.plumtree.openfoundation.util.XPHashtable)
	 */
	public void GetCurrentValue(AActivitySpace asCurrentSpace, IXPRequest xpRequest, IPTSession userSession, XPHashtable htUserEnvironment) {
		
		try {
			int nCommID = NavigationModel.NO_CURRENT_COMMID;
			if (null == asCurrentSpace) 
			{
				return;
			}
			else if (asCurrentSpace.GetModelExists(NavigationModel.STR_MVC_CLASS_NAME))
			{
				NavigationModel navModel = (NavigationModel) asCurrentSpace.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
				nCommID = navModel.CalculateCurCommunityID();
			}
			
			if (nCommID == NavigationModel.NO_CURRENT_COMMID && asCurrentSpace.GetModelExists(GatewayModel.STR_MVC_CLASS_NAME))
			{
				// DCA - for gatewayed content
				GatewayModel gatewayModel = (GatewayModel) asCurrentSpace.GetModel(GatewayModel.STR_MVC_CLASS_NAME);
				nCommID = gatewayModel.GetCommunityID();	
			}
			
			if (nCommID == NavigationModel.NO_CURRENT_COMMID) 
			{
				// DCA - for prefs pages
				IXPEnumerator models = asCurrentSpace.GetModelsEnumerator();
				while (models.MoveNext()) {
					IModel model = (IModel) models.GetCurrent();
					if (model instanceof IIntrinsicPortletPrefsModelRO) {
						nCommID = ((IIntrinsicPortletPrefsModelRO) model).GetCommunityId();
					}
				}
			}
			
			if ( nCommID != NavigationModel.NO_CURRENT_COMMID ) 
			{
				htUserEnvironment.PutElement(new Integer(GetTypeID()), new Integer(nCommID));
			}
			
		}
		catch (Exception e)
		{
			log.Error("ConditionTypeCommunityID::GetCurrentValue An error occured while trying to get the current condition value. The following exception occured: " +
				e);
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2835, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "The user is in ANY of the following Communities:";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionSubTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionSubTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2836, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Community Name";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListAddLabel(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListAddLabel(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2837, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Add Communities";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListIcon()
	 */
	public PTImageType GetMyConditionsListIcon() {
		return PTImageType.ICON_COMMUNITY;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValueType()
	 */
	public int GetConditionValueType() {
		return ValueTypeEnum.INTEGER;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValue(int, com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO)
	 */
	public Object GetConditionValue(int nRow, IPTGrowableSortedArrayWrapperRO saData) {
		Object result = saData.GetItem(nRow, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
		try {
		    // check that community id is valid
		    XPConvert.ToInteger(result);
		} catch (Exception e) {
		    throw new ValidationFailedException();
		}
		return result;
	}
	
	/* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetValidationFailedString(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetValidationFailedString(XPResourceManager xpRM, String strLanguage) {
        String strResult;
		try
		{
			strResult = xpRM.GetString(3147, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Invalid Community: A Community Value must be an integer.";
		}
		return strResult;
    }

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetDescriptionString(com.plumtree.server.condition.IValue, com.plumtree.server.IPTSession)
	 */
	public String GetDescriptionString(IValue ConditionValue, IPTSession ptSession) {
		IPTCommunityInfo ptCommInfo = ((IPTCommunityManager) ptSession.GetCommunities())
			.CachedOpenCommunityInfo(XPConvert.ToInteger(ConditionValue.GetValue()), false);
		
		XPStringBuilder sbCommunity = new XPStringBuilder();
		sbCommunity.Append("User is in Community: ").Append(ptCommInfo.GetName());
		return sbCommunity.ToString();
	}
	
	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void RegisterMyConditionsList(AActivitySpace asCurrentSpace) {
		// Register the model.
		asCurrentSpace.RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier());

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPTObjectModel = asCurrentSpace.GetModel(GetConditionTypeIdentifier());
		asCurrentSpace.RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), mySelectPTObjectModel);
		asCurrentSpace.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), mySelectPTObjectModel);
	}

	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void InitializeMyConditionsList(ExpListModel myListModel, String strLanguage) {
		
		// Get the resource manager for localization
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager xpRM     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
		
		SelectPTObjectModel myPTObjectModel = (SelectPTObjectModel) myListModel;
		// Initialize the Select PTObject list.
		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		myPTObjectModel.InitializeSelectPTObject(
				GetMyConditionsListSectionTitle(xpRM, strLanguage),
				GetMyConditionsListSectionSubTitle(xpRM, strLanguage),
				GetMyConditionsListIcon(),
				GetMyConditionsListAddLabel(xpRM, strLanguage),
				new int[] { PT_CLASSIDS.PT_COMMUNITY_ID }, 
				GetTypeID());

		myPTObjectModel.SetDefaultRowIcon(GetMyConditionsListIcon());
	
		myPTObjectModel.SetTreeTitle(xpRM.GetString(2838, "ptmsgs_portaladminmsgs", strLanguage));
		myPTObjectModel.SetTreeSubTitle(xpRM.GetString(2839, "ptmsgs_portaladminmsgs", strLanguage));
	}
	
	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void AddItemToMyConditionsList(Object objItem, ExpListModel myListModel, IPTSession ptSession) {
		SelectPTObjectModel myPTObjectModel = (SelectPTObjectModel) myListModel;
		IPTCommunityManager ptCommManager = (IPTCommunityManager) ptSession.GetCommunities();
		IPTCommunityInfo ptCommInfo = ptCommManager.CachedOpenCommunityInfo(XPConvert.ToInteger(objItem), false);	
		Object[] objCommunity = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
		
		objCommunity[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] 	= new Integer(myPTObjectModel.m_nNextIndex);
		myPTObjectModel.m_nNextIndex++;
		objCommunity[SelectPTObjectModel.EXPLIST_COL_CLASSID] 				= new Integer(PT_CLASSIDS.PT_COMMUNITY_ID);
		objCommunity[SelectPTObjectModel.EXPLIST_COL_OBJECTID]     			= objItem;
		objCommunity[SelectPTObjectModel.EXPLIST_COL_STRING]     			= ptCommInfo.GetName();
		
		myPTObjectModel.GetItems().AddRow(objCommunity);
	}
}
