package com.plumtree.portalpages.condition.conditiontypes;

import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.application.varpacks.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.web.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.resultwrapper.*;

/**
 * @author dustina
 */
public class ConditionTypeGroupID extends ARegularConditionType {

	/* (non-Javadoc)
	 * @see com.plumtree.server.condition.IConditionServerType#GetTypeID()
	 */
	public int GetTypeID() {
		return ConditionTypeConstants.CONDITIONTYPE_ID_GROUP;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.server.condition.IConditionServerType#Compare(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.server.condition.IValue, com.plumtree.openfoundation.util.XPStringBuilder)
	 */
	public boolean Compare(XPHashtable htUserEnvironment, IValue conditionValue, XPStringBuilder sbDebugText) {
		// check that objValue is of type integer and that the community id is in the current environment
		if (conditionValue.GetType() != ValueTypeEnum.INTEGER || 
			!htUserEnvironment.ContainsKey(new Integer(GetTypeID()))) {
			if (null != sbDebugText) {
				sbDebugText.Append("Condition on Group returning false because either the condition value is of the wrong type,")
					.Append(" or the user's groups was not found in the user's environment<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Group returning false because either the condition value is of the wrong type, or the user's groups was not found in the user's environment");
			}
			return false;
		}
		// cast value to type: Integer
		Integer group_id = (Integer) conditionValue.GetValue();
		
		Object[] env_user_groups = (Object[]) htUserEnvironment.GetElement(new Integer(GetTypeID()));
        
		// check if any group matches the one in the condition
		for (int i=0; i<env_user_groups.length; i++) {
			if (XPConvert.ToInteger(env_user_groups[i]) == XPConvert.ToInteger(group_id)) {
				if (null != sbDebugText) {
					sbDebugText.Append("Condition on Group returning true because the Group ID: ").Append(XPConvert.ToString(group_id))
					    .Append("  matches one of the Group IDs found in the user's environment: ");
                    String strRuleDebugger = "Experience Rules - Condition on Group returning true because the Group ID: " + XPConvert.ToString(group_id) +
                        "  matches one of the Group IDs found in the user's environment: ";
					for (int j=0; j<env_user_groups.length; j++) {
						if (j>0) {
							sbDebugText.Append(", ");
                            strRuleDebugger += ", ";
						}
						sbDebugText.Append(XPConvert.ToString(env_user_groups[j]));
                        strRuleDebugger += XPConvert.ToString(env_user_groups[j]);
					}
					sbDebugText.Append("<br>");
                    ruleDebugger.Debug(strRuleDebugger);
				}
				return true;
			}
		}

		if (null != sbDebugText) {
			sbDebugText.Append("Condition on Group returning false because the Group ID: ").Append(XPConvert.ToString(group_id))
				.Append(" does not match one of the Group IDs found in the user's environment: ");
            String strRuleDebugger = "Experience Rules - Condition on Group returning false because the Group ID: " + XPConvert.ToString(group_id) +
                " does not match one of the Group IDs found in the user's environment: ";
			for (int j=0; j<env_user_groups.length; j++) {
				if (j>0) {
					sbDebugText.Append(", ");
                    strRuleDebugger += ", ";
				}
				sbDebugText.Append(XPConvert.ToString(env_user_groups[j]));
                strRuleDebugger += XPConvert.ToString(env_user_groups[j]);
			}
			sbDebugText.Append("<br>");
            ruleDebugger.Debug(strRuleDebugger);
		}
		return false;
	}
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.ARegularConditionType#GetCurrentValue(com.plumtree.uiinfrastructure.activityspace.AActivitySpace, com.plumtree.openfoundation.web.IXPRequest, com.plumtree.server.IPTSession, com.plumtree.openfoundation.util.XPHashtable)
	 */
	public void GetCurrentValue(AActivitySpace asCurrentSpace, IXPRequest xpRequest, IPTSession userSession, XPHashtable htUserEnvironment) {
		try {
			Object qrGroups = userSession.GetSessionInfo().GetCurrentUserGroupIDs();
			htUserEnvironment.PutElement(new Integer(GetTypeID()), qrGroups);
		}
		catch (Exception e)
		{
		    log.Error("ConditionTypeGroupID::GetCurrentValue An error occured while trying to get the current condition value. The following exception occured: " +
				e);
		}
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2846, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "The user is in ANY of the following Groups:";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionSubTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionSubTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(454, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Group Name";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListAddLabel(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListAddLabel(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(453, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Add Groups";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListIcon()
	 */
	public PTImageType GetMyConditionsListIcon() {
		return PTImageType.ICON_GROUP;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValueType()
	 */
	public int GetConditionValueType() {
		return ValueTypeEnum.INTEGER;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValue(int, com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO)
	 */
	public Object GetConditionValue(int nRow, IPTGrowableSortedArrayWrapperRO saData) {
		Object result = saData.GetItem(nRow, SelectPTObjectModel.EXPLIST_COL_OBJECTID);
		try {
		    // check that group id is valid
		    XPConvert.ToInteger(result);
		} catch (Exception e) {
		    throw new ValidationFailedException();
		}
		return result;
	}
	
	/* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetValidationFailedString(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetValidationFailedString(XPResourceManager xpRM, String strLanguage) {
        String strResult;
		try
		{
			strResult = xpRM.GetString(3146, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Invalid Group: A Group Value must be an integer.";
		}
		return strResult;
    }

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetDescriptionString(com.plumtree.server.condition.IValue, com.plumtree.server.IPTSession)
	 */
	public String GetDescriptionString(IValue ConditionValue, IPTSession ptSession) {
		PTObjectManagerQueryWrapper omUserGroups = new PTObjectManagerQueryWrapper(ptSession.GetUserGroups());
		omUserGroups.QuerySingleObject(XPConvert.ToInteger(ConditionValue.GetValue()));
		IASQueryResult qrAGroup = (IASQueryResult) omUserGroups;
		
		XPStringBuilder sbGroup = new XPStringBuilder();
		sbGroup.Append("User part of Group: ").Append(qrAGroup.GetFields(0, PT_PROPIDS.PT_PROPID_NAME));
		return sbGroup.ToString();
	}	
	
	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void RegisterMyConditionsList(AActivitySpace asCurrentSpace) {
		// Register the model.
		asCurrentSpace.RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier());

		// Get back the Model we just registered because we need it to register the Section and the Control
		IModel mySelectPTObjectModel = asCurrentSpace.GetModel(GetConditionTypeIdentifier());
		asCurrentSpace.RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), mySelectPTObjectModel);
		asCurrentSpace.RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, GetConditionTypeIdentifier(), mySelectPTObjectModel);
	}

	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void InitializeMyConditionsList(ExpListModel myListModel, String strLanguage) {
		
		// Get the resource manager for localization
		IApplication application = ApplicationManager.GetInstance().GetApplication(AppConstants.MAIN_APPLICATION_NAME.ToString());
		XPResourceManager xpRM     = (XPResourceManager) application.GetCachingManager().GetEntry("ResourceManager");
		
		SelectPTObjectModel myPTObjectModel = (SelectPTObjectModel) myListModel;
		// Initialize the Select PTObject list.
		//      _sSectionTitle: Main title.
		//      _sSectionSubTitle: Sub title.
		//      _imgAddIcon: Icon for the add action.
		//      _sAddLabel: Text to display next to the add icon.
		//      _arrObjectClassIDs Class ID of the Objects displayed on the list.
		//      _nListKey: In case you have multiple Expandable Lists on
		//                 the same DP, they should have a different key
		//                 (otherwise, just set it to 1).
		myPTObjectModel.InitializeSelectPTObject(
				GetMyConditionsListSectionTitle(xpRM, strLanguage),
				GetMyConditionsListSectionSubTitle(xpRM, strLanguage),
				GetMyConditionsListIcon(),
				GetMyConditionsListAddLabel(xpRM, strLanguage),
				new int[] { PT_CLASSIDS.PT_USERGROUP_ID }, 
				GetTypeID());

		myPTObjectModel.SetDefaultRowIcon(GetMyConditionsListIcon());
	
		myPTObjectModel.SetTreeTitle(xpRM.GetString(2147, "ptmsgs_portaladminmsgs", strLanguage));
		myPTObjectModel.SetTreeSubTitle(xpRM.GetString(2188, "ptmsgs_portaladminmsgs", strLanguage));
	}
	
	/**
	 * Overriding Parent's implementation to use a different expandable list
	 */
	public void AddItemToMyConditionsList(Object objItem, ExpListModel myListModel, IPTSession ptSession) {
		SelectPTObjectModel myPTObjectModel = (SelectPTObjectModel) myListModel;
		PTObjectManagerQueryWrapper omUserGroups = new PTObjectManagerQueryWrapper(ptSession.GetUserGroups());
		omUserGroups.QuerySingleObject(XPConvert.ToInteger(objItem));
		IASQueryResult qrAGroup = (IASQueryResult) omUserGroups;
		Object[] objGroup = new Object[SelectPTObjectModel.EXPLIST_COL_MAX];
		
		objGroup[SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] 	= new Integer(myPTObjectModel.m_nNextIndex);
		myPTObjectModel.m_nNextIndex++;
		objGroup[SelectPTObjectModel.EXPLIST_COL_CLASSID] 				= new Integer(PT_CLASSIDS.PT_USERGROUP_ID);
		objGroup[SelectPTObjectModel.EXPLIST_COL_OBJECTID]     			= objItem;
		objGroup[SelectPTObjectModel.EXPLIST_COL_STRING]     			= qrAGroup.GetFields(0, PT_PROPIDS.PT_PROPID_NAME);
		
		myPTObjectModel.GetItems().AddRow(objGroup);
	}
}
