package com.plumtree.portalpages.condition.conditiontypes;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openfoundation.web.*;
import com.plumtree.portaluiinfrastructure.condition.*;
import com.plumtree.server.*;
import com.plumtree.server.condition.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author dustina
 */
public class ConditionTypeURLDomain extends AGuestConditionType {

	/* (non-Javadoc)
	 * @see com.plumtree.server.condition.IConditionServerType#GetTypeID()
	 */
	public int GetTypeID() {
		return ConditionTypeConstants.CONDITIONTYPE_ID_URLDOMAIN;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.server.condition.IConditionServerType#Compare(com.plumtree.openfoundation.util.XPHashtable, com.plumtree.server.condition.IValue, com.plumtree.openfoundation.util.XPStringBuilder)
	 */
	public boolean Compare(XPHashtable htUserEnvironment, IValue conditionValue, XPStringBuilder sbDebugText) {
		// check that objValue is of type string and that the url domain is in the current environment
		if (conditionValue.GetType() != ValueTypeEnum.STRING || 
			!htUserEnvironment.ContainsKey(new Integer(GetTypeID()))) {
			if (null != sbDebugText) {
				sbDebugText.Append("Condition on Base URL returning false because either the condition value is of the wrong type,")
					.Append(" or the Base URL was not found in the user's environment<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Base URL returning false because either the condition value is of the wrong type, or the Base URL was not found in the user's environment");
			}
			return false;
		}
		// cast value to type: String
		String strURLDomain = (String) conditionValue.GetValue();
		String strURLPattern = PreparePattern(strURLDomain);
	
		String envURLDomain = (String) htUserEnvironment.GetElement(new Integer(GetTypeID()));
		
		// compare values
		XPRegex urlPattern = new XPRegex(strURLPattern, XPRegex.IGNORE_CASE);
		boolean result = urlPattern.IsMatch(envURLDomain);
		
		if (result)
		{
		    if (null != sbDebugText) {
				sbDebugText.Append("Condition on Base URL returning true because the URL Domain: ").Append(XPHttpUtility.HtmlEncode(strURLDomain))
					    .Append(" matches the one found in the user's environment: ").Append(XPConvert.ToString(envURLDomain)).Append("<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Base URL returning true because the URL Domain: " + XPHttpUtility.HtmlEncode(strURLDomain) +
                        " matches the one found in the user's environment: " + XPConvert.ToString(envURLDomain));
			}
			return true;
		} else {
		    if (null != sbDebugText) {
				sbDebugText.Append("Condition on Base URL returning false because the URL Domain: ").Append(XPHttpUtility.HtmlEncode(strURLDomain))
					.Append(" does not match the one found in the user's environment: ").Append(XPConvert.ToString(envURLDomain))
					.Append("<br>");
                ruleDebugger.Debug("Experience Rules - Condition on Base URL returning false because the URL Domain: " + XPHttpUtility.HtmlEncode(strURLDomain) +
                        " does not match the one found in the user's environment: " + XPConvert.ToString(envURLDomain));
			}
			return false;
		}
	}
	
    private String PreparePattern(String sSource)
    {
		// TODO: Bug#70069 - this should be shared with the user agent condition if possible.
    	// NOTE: the user agent implementation is more performant because it uses a string builder.

    	  //    We will convert occurrences of
          //    '?' to '.'
          //    '.' to '\.'
          //    '*' to '(.*)
          // This allows the user to enter standard file system expressions
          //    like 'Michael ? S*.doc' (i.e. any middle initial, and 
          //    shortened last name), and pass it to the engine in the correct
          //    form (in this case, '^Michael . S(.*)\.doc$')

          sSource = GeneralHelpers.Replace(sSource, ".", "\\.");
          sSource = GeneralHelpers.Replace(sSource, "?", ".");
          sSource = GeneralHelpers.Replace(sSource, "*", "(.*)");
          sSource = GeneralHelpers.Replace(sSource, "[", "\\[");
          sSource = GeneralHelpers.Replace(sSource, "]", "\\]");
          sSource = GeneralHelpers.Replace(sSource, "/", "\\/");
          return "^" + XPStringUtility.ToUpperCase(sSource) + "$";
    }


	/* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AGuestConditionType#GetCurrentValue(com.plumtree.portaluiinfrastructure.condition.XPLimitedRequest, com.plumtree.server.IPTSession, com.plumtree.openfoundation.util.XPHashtable)
     */
    public void GetCurrentValue(XPLimitedRequest xpRequest, IPTSession guestReadOnlySession, XPHashtable htUserEnvironment) {
		String strURLDomain = xpRequest.GetRequestURL();
		int startIndex = XPStringUtility.IndexOf(strURLDomain, "https://");
		if (-1 != startIndex) {
			strURLDomain = XPStringUtility.Substring(strURLDomain, startIndex+8);
		}
		startIndex = XPStringUtility.IndexOf(strURLDomain, "http://");
		if (-1 != startIndex) {
			strURLDomain = XPStringUtility.Substring(strURLDomain, startIndex+7);
		}
		htUserEnvironment.PutElement(new Integer(GetTypeID()), strURLDomain);
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2840, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "The Base URL is ANY of the following URLs:";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListSectionSubTitle(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListSectionSubTitle(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2841, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Base URLs";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListAddLabel(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
	 */
	public String GetMyConditionsListAddLabel(XPResourceManager xpRM, String strLanguage) {
		String strResult;
		try
		{
			strResult = xpRM.GetString(2842, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Add a Base URL";
		}
		return strResult;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetMyConditionsListIcon()
	 */
	public PTImageType GetMyConditionsListIcon() {
		return PTImageType.ICON_DOCUMENT_URL;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValueType()
	 */
	public int GetConditionValueType() {
		return ValueTypeEnum.STRING;
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetConditionValue(int, com.plumtree.uiinfrastructure.arraywrapper.IPTGrowableSortedArrayWrapperRO)
	 */
	public Object GetConditionValue(int nRow, IPTGrowableSortedArrayWrapperRO saData) {
		String result = (String) saData.GetItem(nRow, GrowableListModel.EXPLIST_SORTEDARRAY_PROPID_INPUTTEXT);
		if ("".equals(result)) {
		    throw new ValidationFailedException();
		}
		int startIndex = XPStringUtility.IndexOf(result, "https://");
		if (-1 != startIndex) {
		    result = XPStringUtility.Substring(result, startIndex+8);
		}
		startIndex = XPStringUtility.IndexOf(result, "http://");
		if (-1 != startIndex) {
		    result = XPStringUtility.Substring(result, startIndex+7);
		}
		return result;
	}
	
	/* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetValidationFailedString(com.plumtree.openfoundation.internationalization.XPResourceManager, java.lang.String)
     */
    public String GetValidationFailedString(XPResourceManager xpRM, String strLanguage) {
        String strResult;
		try
		{
			strResult = xpRM.GetString(3145, "ptmsgs_portaladminmsgs", strLanguage);
		} catch (Exception e)
		{
			strResult = "Invalid Base URL: The Base URL cannot be empty.";
		}
		return strResult;
    }
	
	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#AddItemToMyConditionsList(java.lang.Object, com.plumtree.uiinfrastructure.expandablelist.ExpListModel, com.plumtree.server.IPTSession)
	 */
	public void AddItemToMyConditionsList(Object objItem, ExpListModel myListModel, IPTSession ptSession) {
		GrowableListModel myGrowableListModel = (GrowableListModel) myListModel;
		myGrowableListModel.AddRowsToList(new String[] {XPConvert.ToString(objItem)});
	}

	/* (non-Javadoc)
	 * @see com.plumtree.portaluiinfrastructure.condition.AConditionType#GetDescriptionString(com.plumtree.server.condition.IValue, com.plumtree.server.IPTSession)
	 */
	public String GetDescriptionString(IValue ConditionValue, IPTSession ptSession) {
		XPStringBuilder sbURLDomain = new XPStringBuilder();
		sbURLDomain.Append("portal URL equals ").Append(ConditionValue.GetValue());
		return sbURLDomain.ToString();
	}
		
}
