package com.plumtree.portalpages.condition.conditiontypes;

import com.plumtree.openfoundation.util.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.expandablelist.growablelist.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * @author dustina
 */
public class IPAddressListModel extends GrowableListModel {

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "IPAddressListModel";
	
	/**
	 * 1st IP Address box */
	public static final int EXPLIST_IPBOX_1 = 1;
	
	/**
	 * 2st IP Address box */
	public static final int EXPLIST_IPBOX_2 = 2;
		
	/**
	 * 3st IP Address box */
	public static final int EXPLIST_IPBOX_3 = 3;
		
	/**
	 * 4st IP Address box */
	public static final int EXPLIST_IPBOX_4 = 4;
		
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new IPAddressListModel();
	}
	
	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
		
	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX,
				EXPLIST_IPBOX_1, 
				EXPLIST_IPBOX_2,
				EXPLIST_IPBOX_3,
				EXPLIST_IPBOX_4
			};

		// JF- Sort array
		// The growable array will always be sorted by the 1st column.
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_SORTEDARRAY_PROPID_INDEX;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true);
	}
	
	/**
	 * Adds one row at the bottom of the list and
	 * sets the following values:
	 * First column: m_nNextIndex
	 * Second column: m_sDefaultValue
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		boolean bCanAddNewRow = true;

		// JF- Before we add a new row at the end of the list, we check 
		// if you don't already have a "new row" in the list.
		// The user doesn't need to have more than one empty row (or row with the default value).
		// JF- Check the array see if we have the default value in it.
		for (int i = 0; i < m_saData.GetCount(); i++)
		{
			if (m_sDefaultValue.equals(m_saData.GetItem(i, EXPLIST_IPBOX_1)) ||
				m_sDefaultValue.equals(m_saData.GetItem(i, EXPLIST_IPBOX_2)) ||
				m_sDefaultValue.equals(m_saData.GetItem(i, EXPLIST_IPBOX_3)) ||
				m_sDefaultValue.equals(m_saData.GetItem(i, EXPLIST_IPBOX_4)))
			{
				// JF- We already have a new row no need to add one more.
				bCanAddNewRow = false;

				break;
			}
		}

		if (bCanAddNewRow)
		{
			String[] defaultValues = new String[] {m_sDefaultValue, m_sDefaultValue, m_sDefaultValue, m_sDefaultValue};
			AddRowToList(defaultValues);
		}
	}
			
	/**
	 * Adds an array of new rows to the list.
	 *
	 * @param _aData
	 */
	public void AddRowToList(Object _aData)
	{
		// cast to double array type
		Object[] aData = (Object[]) _aData;
		Object[] oRow = new Object[5];
					   
		oRow[EXPLIST_SORTEDARRAY_PROPID_INDEX]     = new Integer(m_nNextIndex);
		m_nNextIndex++;
		oRow[EXPLIST_IPBOX_1] = aData[0];
		oRow[EXPLIST_IPBOX_2] = aData[1];
		oRow[EXPLIST_IPBOX_3] = aData[2];
		oRow[EXPLIST_IPBOX_4] = aData[3];
		super.GetItems().AddRow(oRow);
	}
	
	/**
	 * Saves the data on the row _nRowIndex.
	 *
	 * @param _saData List to update the data on row _nRowIndex
	 * @param _nRowIndex Index of the row to save.
	 * @param _htFormData Data posted by the form.
	 * @return int Status for server side validation.
	 */
	protected int SaveRow(PTGrowableSortedArrayWrapper _saData, int _nRowIndex,
		XPHashtable _htFormData)
	{
		String sDataKey     = GetUniqueString(IPAddressListView.HTMLINPUT_IPBOX_1) + _nRowIndex;
		String[] aDataValue;
		// JF- For each input text posted by the form, we get the value back and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex, EXPLIST_IPBOX_1, aDataValue[0]);
			}
		}
		
		sDataKey     = GetUniqueString(IPAddressListView.HTMLINPUT_IPBOX_2) + _nRowIndex;
		// JF- For each input text posted by the form, we get the value back and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex, EXPLIST_IPBOX_2, aDataValue[0]);
			}
		}
		
		sDataKey     = GetUniqueString(IPAddressListView.HTMLINPUT_IPBOX_3) + _nRowIndex;
		// JF- For each input text posted by the form, we get the value back and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex, EXPLIST_IPBOX_3, aDataValue[0]);
			}
		}

		sDataKey     = GetUniqueString(IPAddressListView.HTMLINPUT_IPBOX_4) + _nRowIndex;
		// JF- For each input text posted by the form, we get the value back and set the new value in the array.
		if (_htFormData.ContainsKey(sDataKey))
		{
			aDataValue = (String[]) _htFormData.GetElement(sDataKey);

			if ((null != aDataValue) && !(0 == aDataValue.length))
			{
				_saData.SetItem(_nRowIndex, EXPLIST_IPBOX_4, aDataValue[0]);
			}
		}
				
		return RepostControl.PAGE_STATUS_VALID;
	}
}
