package com.plumtree.portalpages.devices.choosepage.common;

import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;

/**
 * @author SudhaS
 *
 */
public class ChoosePageDevicesModel implements IChoosePageDevicesModelRO,
	IModel
{
	
	public static final String STR_MVC_CLASS_NAME = "ChoosePageDevices_Devices";
	
	public static final int NUM_LINKS_PER_SCREEN = 5;
	
	private AActivitySpace m_asOwner;
	private IPTSession m_ptSession;
	private int m_nListID   = -1;
	private int m_nCurrentCommunityID = 0;
	private int m_nCurrentPageID = 0;
	private int m_nSavedCommunityID = 0;
	private int m_nSavedPageID = 0;
	
	
	private Object[][] m_oPageMemberships;
	
	private int m_nNumPages = 0;

	/**
	 * 
	 */
	public void CleanupTempData()
	{	
		//m_oPageMemberships = null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	* @see com.plumtree.xpshared.infrastructure.activityspace.IManagedObject#Create()
	*/
	public Object Create()
	{
		return new ChoosePageDevicesModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetListID()
	{
		return m_nListID;
	}
	
	public int GetCurrentCommunity()
	{
		return m_nCurrentCommunityID;
	}
	
	public int GetCurrentPage()
	{
		return m_nCurrentPageID;
	}
	
	public int GetSavedCommunity()
	{
		return m_nSavedCommunityID;
	}
	
	public int GetSavedPage()
	{
		return m_nSavedPageID;
	}
	
	public Object[][] GetPageMemberships()
	{
		return m_oPageMemberships;
	}

	/**
	* Returns the Class name.
	*
	* @return String
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param iCount 
	 * @param iMaxNumber 
	 *
	 * @return 
	 */
	public int GetNumPages(int iCount, int iMaxNumber)
	{
		//SS - Calculate the number of screens to be displayed
		//based on the total number of pages and the pages
		//per screen
		if (iMaxNumber > 0)
		{
			int iNumPages = iCount / iMaxNumber;

			if ((iCount % iMaxNumber) > 0)
			{
				iNumPages++;
			}

			return iNumPages;
		}
		else
		{
			return 1;
		}
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetNumTotalPages()
	{
		return m_nNumPages;
	}
	
 

	/**
	 * 
	 *
	 * @return 
	 */
	public Object[][] SetPageMemberships()
	{
		//SS - Create a new 2d array of communities and their pages
		IPTSessionInfo ptSessionInfo		  = (IPTSessionInfo) m_ptSession.GetSessionInfo();
		IPTQueryResult qrCommunityMemberships = ptSessionInfo.GetCurrentCommunityMembership();

		int nCommMmbrshps = qrCommunityMemberships.RowCount();

		if (nCommMmbrshps > 0)
		{
			m_oPageMemberships = new Object[nCommMmbrshps + 1][3];

			for (int i = 0; i < nCommMmbrshps; i++)
			{
				int nCommunityID = qrCommunityMemberships.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
				String strCommName = qrCommunityMemberships.ItemAsString(i, PT_PROPIDS.PT_PROPID_NAME);
				
				IPTObjectManager omCommunities = m_ptSession.GetCommunities();
				IPTCommunity ptCommunity	   = (IPTCommunity) omCommunities.Open(nCommunityID, false);

				IPTQueryResult qrCommunityPages = ptCommunity.QueryPages(0);
				//SS - Get the array of pages for a community
				Object[] oPages				    = GetPropertiesArray(qrCommunityPages,
						PT_PROPIDS.PT_PROPID_OBJECTID,
						PT_PROPIDS.PT_PROPID_NAME);

				m_oPageMemberships[i + 1][0]	    = strCommName;
				m_oPageMemberships[i + 1][1]	    = new Integer(nCommunityID);
				m_oPageMemberships[i + 1][2]	    = oPages;

				String[] pagenames			    = (String[]) oPages[1];
				m_nNumPages					    = m_nNumPages + pagenames.length;
			}
		}
		else
		{
			m_oPageMemberships = new Object[1][3];
		}
		
		
		//SS - The MyPages go in the first index
		IPTQueryResult qrMyPages = ptSessionInfo.GetCurrentMyPages();
		Object[] arPages			 = GetPropertiesArray(qrMyPages,
				PT_PROPIDS.PT_PROPID_OBJECTID, PT_PROPIDS.PT_PROPID_NAME);

		m_oPageMemberships[0][0]   = "My Page";
		m_oPageMemberships[0][1]   = new Integer(0);
		m_oPageMemberships[0][2]   = arPages;

		String[] arPageNames		 = (String[]) arPages[1];
		m_nNumPages				 = m_nNumPages + arPageNames.length;

		return m_oPageMemberships;
	}
	
	public int GetCommunityIDIndex()
	{
		return GetIndex(true);
	}
	
	public int GetPageIDIndex()
	{
		return GetIndex(false);
	}
	
	
	private int GetIndex(boolean _bGetCommunityIndex)
	{
		//SS - Get the index of a starting display screen for a device.
		//If _bGetCommunityIndex return the community ID value, otherwise
		//return the page page ID value.
		if (m_nListID == 0) return 0;
		
		//SS - The current display screen
		int nIndex = m_nListID * NUM_LINKS_PER_SCREEN;
		int nCount = 1;
		
		for (int i = 0; i < m_oPageMemberships.length; i++)
		{
		
	   		Object[] aPages     = (Object[]) m_oPageMemberships[i][2];
			int[] aPageIDs  = (int[]) aPages[0];
	   		for (int j = 0; j < aPageIDs.length; j++)
	   		{
				//SS - If we have reached the current display screen
	   			if (nCount == nIndex) {
	   				//SS - If we are looking for the community index, and we are the
	   				//end of a community, return the next community
	   				if (_bGetCommunityIndex) {
	   					if (j == aPageIDs.length - 1) return i + 1;
	   					else return i;
	   				//SS - If we are at the end of a community index, return 0 so
	   				//we get the first page in the next community
	   				} else {
	   					if (j == aPageIDs.length - 1) return 0;
	   					else return j + 1;
	   				} 
	   			}
				nCount++;
				
	   			
	   		}
	   		
	   		
		}
	   		
	   	return 0;
	}

	/**
	 * 
	 *
	 * @param _asOwner 
	 */
	public void Init(AActivitySpace _asOwner)
	{
		m_asOwner	    = _asOwner;
		m_ptSession     = (IPTSession) m_asOwner.GetUserSession();
		
		SetPageMemberships();
		
		
	}

	/**
	 * 
	 *
	 * @param _nListID 
	 */
	public void SetListID(int _nListID)
	{
		m_nListID = _nListID;
	}
	
	/**
	 * 
	 *
	 * @param __nCurrentCommunityID 
	 */
	public void SetCurrentCommunityID(int _nCurrentCommunityID)
	{
		m_nCurrentCommunityID = _nCurrentCommunityID;
	}
	
	
	/**
	 * 
	 *
	 * @param __nCurrentCommunityID 
	 */
	
	public void SetCurrentPageID(int _nCurrentPageID)
	{
		m_nCurrentPageID = _nCurrentPageID;
	}
	
	/**
	 * 
	 *
	 * @param __nCurrentCommunityID 
	 */
	public void SetSavedCommunityID(int _nCurrentCommunityID)
	{
		m_nSavedCommunityID = _nCurrentCommunityID;
	}


	/**
	 * 
	 *
	 * @param __nCurrentCommunityID 
	 */

	public void SetSavedPageID(int _nCurrentPageID)
	{
		m_nSavedPageID = _nCurrentPageID;
	}

	/**
	 * 
	 *
	 * @param qr 
	 * @param PropID1 
	 * @param PropID2 
	 *
	 * @return 
	 */
	private Object[] GetPropertiesArray(IPTQueryResult qr, int PropID1,
		int PropID2)
	{
		//SS - Calculate the pageIDs and page names arrays for a community
		int[] arrObjectIDs;
		String[] arrNames;
		int intCount = qr.RowCount();

		if (intCount > 0)
		{
			arrObjectIDs     = new int[intCount];
			arrNames		 = new String[intCount];

			for (int i = 0; i < intCount; i++)
			{
			
				arrObjectIDs[i]     = qr.ItemAsInt(i, PropID1);		
				arrNames[i] = qr.ItemAsString(i, PropID2);
			}

			return new Object[] { arrObjectIDs, arrNames };
		}
		else
		{
			return new Object[0];
		}
	}
}

