package com.plumtree.portalpages.devices.choosepage.wml;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.devices.choosepage.common.*;
import com.plumtree.portalpages.devices.logoff.common.*;
import com.plumtree.portalpages.devices.mypage.common.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.devices.*;
import com.plumtree.xpshared.htmlelements.*;


/**
 * @author SudhaS
 *
 */


public class ChoosePageDevicesView_WML implements IDevicesView
{
    
    public static final String STR_MVC_CLASS_NAME = "ChoosePageDevices_WML";

  

    private AActivitySpace m_asOwner;
    private IChoosePageDevicesModelRO m_asmModel;

    /**
     * 
     *
     * @return 
     */
    public Object Create()
    {
        return new ChoosePageDevicesView_WML();
    }

    /**
     * 
     *
     * @return 
     */
    public HTMLElement Display()
    {
        return null;
    }

    /**
     * 
     *
     * @return 
     */
    public HTMLScript DisplayJavascript()
    {
        return null;
    }

    /**
     * @see com.plumtree.xpshared.portalinfrastructure.activityspace.IView#Display()
     */
    public String DisplayString()
    {
        XPStringBuilder sb;

        sb = new XPStringBuilder();
        
		ASURL myURL = new ASURL(m_asOwner);
		myURL.SetXMLEncoding(true);
		myURL.SetLinkCreateNewSpace("ChoosePageDevices", m_asOwner);
		myURL.SetControl(ChoosePageDevicesControl.STR_MVC_CLASS_NAME);
		myURL.AddControlArgument(MyPageDevicesControl.STR_PAGE_ID, 0);

        sb.Append("<template>\n");
        sb.Append("		<do type=\"prev\"><go href=\"" + myURL.GetURLAsString() + "\"/></do>\n");
        sb.Append("</template>\n");
        sb.Append("<card id=\"ChoosePage\" title=\"ChoosePage\" newcontext=\"true\">\n");

        sb.Append("<p align=\"left\" mode=\"nowrap\">\n");

		//SS - A 2d array of all the pages of which a user is a member.  An array
		//of communities where each community has an array of pages
        Object[][] oPageMemberships = m_asmModel.GetPageMemberships();

		//SS - The total number of community pages to which a user belongs
        int nTotalPages = m_asmModel.GetNumTotalPages();
       
        //SS - The total number of screens that will be displayed on the device.
        //Only 5 links are displayed on each screen shot.
        int nPageCount  = m_asmModel.GetNumPages(nTotalPages, ChoosePageDevicesModel.NUM_LINKS_PER_SCREEN);
        
        //SS - The current screen the user is viewing
        int nListID     = m_asmModel.GetListID();
        
        //SS - The community and page which should be the start of the current display screen
        int nCommunityStart = m_asmModel.GetCommunityIDIndex();
        int nPageStart = m_asmModel.GetPageIDIndex();

        if (nListID >= nPageCount)
        {
            nListID = 0;
        }

        int nStart = nListID * ChoosePageDevicesModel.NUM_LINKS_PER_SCREEN;
        int nEnd   = nStart + ChoosePageDevicesModel.NUM_LINKS_PER_SCREEN;
        
        if (nEnd > nTotalPages)
        {
            nEnd = nTotalPages;
        }

        int nCount = nStart;
		
		
		//SS - Loop through each community.
        for (int i = nCommunityStart; i < oPageMemberships.length; i++)
        {
        	//SS - Break if the end has been reached.  If not for the break,
        	//the loop would continue even after the NUM_LINKS_PER_SCREEN has
        	//been reached.
        	if (nCount == nEnd) break;
            String strCommunityName = (String) oPageMemberships[i][0];
            int nCommunityID     = XPConvert.ToInteger(oPageMemberships[i][1]);

			//SS - The array of pages contains 2 arrays
			//1. An array of page ids
			//2. An array of page names 
            Object[] aPages     = (Object[]) oPageMemberships[i][2];
            int[] aPageIDs  = (int[]) aPages[0];
            String[] aPageNames = (String[]) aPages[1];
            
            
			//SS - Loop through the pages in a community.
            for (int j = nPageStart; j < aPageNames.length; j++)
            {
			  //SS - Break if the end has been reached.  If not for the break,
			  //the loop would continue even after the NUM_LINKS_PER_SCREEN has
			  //been reached.
            	if (nCount==nEnd) break;
   
   				//SS - If we are in between the start and the end indeces
                if ((nStart <= nCount) && (nCount < nEnd))
                {
                	//SS - If we are at the beginning of a screen or have started listing a new community
                    if ((nStart == nCount) || (j == 0))
                    {
                        sb.Append("<b>" + strCommunityName + "</b><br/>");
                    }

					//SS - List the link for the community page
                    myURL = new ASURL(m_asOwner);
                    myURL.SetXMLEncoding(true);

                    myURL.SetLinkCreateNewSpace("MyPage", m_asOwner);
                    myURL.SetControl(MyPageDevicesControl.STR_MVC_CLASS_NAME);
                    
                    myURL.AddControlArgument(MyPageDevicesControl.STR_PAGE_ID, XPConvert.ToInteger(aPageIDs[j]));
                    myURL.AddControlArgument(MyPageDevicesControl.STR_COMMUNITY_ID, nCommunityID);
                    myURL.AddControlArgument(MyPageDevicesControl.STR_PAGE_NAME, aPageNames[j]);


                   	sb.Append("<a href=\"" + myURL.GetURLAsString() + "\">" + aPageNames[j] + "</a><br/>");
                   	nCount++;
                }

				//SS - If we are at the end of the screen and there are more pages to display
                if ((nCount == nEnd) && (nPageCount > 1))
                {
                	//SS - Create the links for going backwards and forwards
                	//They will only be displayed if necessary
                    ASURL myNextURL = new ASURL(m_asOwner);
                    myNextURL.SetXMLEncoding(true);

                    myNextURL.SetLinkCreateNewSpace("ChoosePageDevices", m_asOwner);
                    myNextURL.SetControl(ChoosePageDevicesModel.STR_MVC_CLASS_NAME);
                    myNextURL.AddControlArgument(MyPageDevicesControl.STR_LIST_ID, m_asmModel.GetListID() + 1);
                    
                    ASURL myPrevURL = new ASURL(m_asOwner);
                    myPrevURL.SetXMLEncoding(true);

                    myPrevURL.SetLinkCreateNewSpace("ChoosePageDevices", m_asOwner);
                    myPrevURL.SetControl(ChoosePageDevicesModel.STR_MVC_CLASS_NAME);
                    myPrevURL.AddControlArgument(MyPageDevicesControl.STR_LIST_ID, m_asmModel.GetListID() - 1);
					

					//SS - First screen shot
                    if (nListID == 0)
                    {
                        sb.Append("&nbsp;&nbsp;<a href=\"" + myNextURL.GetURLAsString() + "\">" + m_asOwner.GetString(1412, "ptmsgs_portalbrowsingmsgs") + "</a><br/>");
                    }
                    //SS - Last screen shot
                    else if (nListID == (nPageCount - 1))
                    {
                        sb.Append("&nbsp;&nbsp;<a href=\"" + myPrevURL.GetURLAsString() + "\">" + m_asOwner.GetString(1411, "ptmsgs_portalbrowsingmsgs") + "</a><br/>");
                    }
                    //SS - Somewhere in the middle
                    else
                    {
                        sb.Append("&nbsp;&nbsp;<a href=\"" + myNextURL.GetURLAsString() + "\">" + m_asOwner.GetString(1412, "ptmsgs_portalbrowsingmsgs") + "</a><br/>");

                        sb.Append("&nbsp;&nbsp;<a href=\"" + myPrevURL.GetURLAsString() + "\">" + m_asOwner.GetString(1411, "ptmsgs_portalbrowsingmsgs") + "</a><br/>");
                    }
                }
                

                
            }
			if (nCount==nEnd) break;  
			nPageStart = 0;
	        
		}
        
       
       //SS - Display the logoff link
	   ASURL myLogoffPage = new ASURL(m_asOwner);
	   myLogoffPage.SetXMLEncoding(true);
	   myLogoffPage.SetLinkCreateNewSpace("Logoff", m_asOwner);
	   myLogoffPage.SetControl(LogoffDevicesControl.STR_MVC_CLASS_NAME);
	   sb.Append("<a href=\"" + myLogoffPage.GetURLAsString() + "\">" + m_asOwner.GetString(1431, "ptmsgs_portalbrowsingmsgs") + "</a><br/>");


	   sb.Append("</p>");
	   sb.Append("</card>");

       return (sb.ToString());
    }

    /**
     * @see com.plumtree.xpshared.portalinfrastructure.activityspace.IView#GetName()
     */
    public String GetName()
    {
        return STR_MVC_CLASS_NAME;
    }

    /**PortalSettings
     * @see com.plumtree.xpshared.portalinfrastructure.activityspace.IView#Init(IModelRO, AActivitySpace)
     */
    public void Init(IModelRO model, AActivitySpace parent)
    {
        m_asmModel = (IChoosePageDevicesModelRO) model;
        m_asOwner  = parent;
    }
}

