package com.plumtree.portalpages.devices.portlet.common;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.gateway.*;
import com.plumtree.portalpages.devices.mypage.common.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author SudhaS
 *
 */


public class PortletDevicesModel implements IPortletDevicesModelRO, IModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_DEVICES),
		"com.plumtree.portalpages.devices.portlet.common.PortletDevicesModel");

	
	public static final String STR_MVC_CLASS_NAME = "PortletDevices_Devices";
	private AActivitySpace m_asOwner;
	private IPTSession m_ptSession;
	private String m_strHostPageURI = "";
	private int m_nCommunityID = -1;
	private int m_nListID	   = -1;
	private int m_nNumPortlets  = -1;
	private int m_nPageID	   = -1;
	private int m_nIndex		= -1;
	private String m_strPageName;
	
	
	private IPTMyPortalGadgetContent m_gadgetContent	    = null;
	private IPTState m_objAppDataState = null;

	/**
	 * 
	 */
	public void CleanupTempData()
	{
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IModel#CleanupAllData()
	 */
	public void CleanupAllData()
	{
	}

	/**
	* @see com.plumtree.xpshared.infrastructure.activityspace.IManagedObject#Create()
	*/
	public Object Create()
	{
		return new PortletDevicesModel();
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetCommunityID()
	{
		return m_nCommunityID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetPortletCount()
	{
		return m_nNumPortlets;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetListID()
	{
		return m_nListID;
	}

	/**
	* Returns the Class name.
	*
	* @return String
	*/
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
	public String GetPageName()
	{
		return m_strPageName;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetPageID()
	{
		return m_nPageID;
	}

	/**
	 * 
	 *
	 * @param _asOwner 
	 */
	public void Init(AActivitySpace _asOwner)
	{
		m_asOwner	    = _asOwner;
		m_ptSession     = (IPTSession) m_asOwner.GetUserSession();
	}

	/**
	 * 
	 *
	 * @param _nCommunityID 
	 */
	public void SetCommunityID(int _nCommunityID)
	{
		m_nCommunityID = _nCommunityID;
	}

	/**
	 * 
	 *
	 * @param _strHostPage 
	 */
	public void SetHostPageURI(String _strHostPage)
	{
		m_strHostPageURI = _strHostPage;
	}

	/**
	 * 
	 *
	 * @param _nListID 
	 */
	public void SetListID(int _nListID)
	{
		m_nListID = _nListID;
	}
	
	public void SetPageName(String _strPageName)
	{
		m_strPageName = _strPageName;
	}
	
	public ASURL GetASURL(String _strSpace)
	{
		ASURL myURL = new ASURL(m_asOwner);

		myURL.SetXMLEncoding(true);
		myURL.SetLinkCreateNewSpace(_strSpace, m_asOwner);
		myURL.AddControlArgument(MyPageDevicesControl.STR_PAGE_ID, m_nPageID);
		myURL.AddControlArgument(MyPageDevicesControl.STR_COMMUNITY_ID,
			m_nCommunityID);

		return myURL;
	}

	/**
	 * 
	 *
	 * @param _nPageID 
	 */
	public void SetPageID(int _nPageID)
	{
		m_nPageID = _nPageID;
	}
	
	
	
	public void SetPortletContent(String _strUniqueID)
	{
		m_objAppDataState = AppDataObject.GetAppDataObject(0, m_nPageID,
				m_strHostPageURI, m_asOwner);
				
		IPTPageInfo ptPageInfo = null;			

		//SS - Use the MyPages to open up a MyPage
		if (m_nCommunityID == 0) ptPageInfo = m_ptSession.GetMyPages().GetPage(m_nPageID);
		//SS - Use ITPCommunity to first open up a community and then a MyPage
		else {
			IPTCommunityInfo communityInfo = ((IPTCommunityManager)m_ptSession.GetCommunities()).CachedOpenCommunityInfo(m_nCommunityID, true);
			ptPageInfo = communityInfo.GetPage(m_nPageID);
		}
		m_gadgetContent			   = ptPageInfo.QueryPortletContent(m_objAppDataState,
				_strUniqueID, PT_GADGET_MODES.PT_GADGETMODES_RUNTIME, false);
		
		

		m_nNumPortlets = m_gadgetContent.GetCount();
	}
	
	public String GetPortletContent()
	{
		try
		{
			Object[][] oPortletContent = (Object[][]) m_gadgetContent.GetContent(m_nIndex);

			HTMLElement tagOutput = GatewayUtils.AddMarkupToSingleElement(m_asOwner, oPortletContent);

			return tagOutput.GetDisplayString();
		} catch (Exception e)
		{
			log.Error(e, "Error in PortletDevicesModel: ");
		}

		return("");
	}
	
	public void SetIndex(int _nIndex)
	{
		m_nIndex = _nIndex;
	}
}

