package com.plumtree.portalpages.pei;

import com.plumtree.portalpages.browsing.portalsettings.search.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;


/**  
 * This interface was created to allow developers the ability to create
 * functions that can be dynamically discovered by the Plumtree application
 * for the purposes of performing some functionality when a particular
 * search setting based event occurs.   
 * <br><br>
 * NOTE: Should this interface be implemented more than once within the
 * Dynamic Discovery process, the implementations will be processed in the
 * order that they are displayed within the representative XML file. All
 * implementations will be called.
 */
public interface ISearchSettingActions
{
    /**
     * This functions allows for some functionality to occur after the user has
     * successfully modified or deleted saved searches.
     *
     * @param _asCurrentSpace - Provides access to the current MVC classes as
     *        well as the Application and the HTTP Session
     * @param _ptUserSession - Plumtree session object for the current user
     * @param _arrCurrentSavedSearches -  Array of current saved search names
     *        (after modifying and/or deleting them)
     */
    public void OnAfterModifyOrRemoveSavedSearch(AActivitySpace _asCurrentSpace,
                                                 IPTSession _ptUserSession,
                                                 String[] _arrCurrentSavedSearches);

    /**
     * This function allows for some functionality to occur after the user has
     * saved a search.
     *
     * @param _asCurrentSpace - Provides access to the current MVC classes as
     *        well as the Application and the HTTP Session
     * @param _ptUserSession - Plumtree session object for the current user
     * @param _searchData - This is an instance of the SavedSearchData class, which
     *        provides access to the data associated with the saved search.
     */
    public void OnAfterSaveSearch(AActivitySpace _asCurrentSpace,
                                  IPTSession _ptUserSession,
                                  SavedSearchData _searchData);

    /**
     * This functions allows for some functionality to occur before the user
     * has successfully deleted a saved search.
     *
     * @param _asCurrentSpace - Provides access to the current MVC classes as
     *        well as the Application and the HTTP Session
     * @param _ptUserSession - Plumtree session object for the current user
     * @param _searchData - This is an instance of the SavedSearchData class, which
     *        provides access to the data associated with the saved search.
     *        Changes to the data are ignored.
     */
    public void OnBeforeRemoveSavedSearch(AActivitySpace _asCurrentSpace,
                                          IPTSession _ptUserSession,
                                          SavedSearchData _searchData);

    /**
     * This function allows for some functionality to occur before the user has
     * saved a search.
     *
     * @param _asCurrentSpace - Provides access to the current MVC classes as
     *        well as the Application and the HTTP Session
     * @param _ptUserSession - Plumtree session object for the current user
     * @param _searchData - This is an instance of the SavedSearchData class, which
     *        provides access to the data associated with the saved search.
     */
    public void OnBeforeSaveSearch(AActivitySpace _asCurrentSpace,
                                   IPTSession _ptUserSession,
                                   SavedSearchData _searchData);
}

