package com.plumtree.portalpages.portlets.headerfooter;

import com.plumtree.openlog.OpenLogService;
import com.plumtree.openlog.OpenLogger;
import com.plumtree.portalpages.common.uiparts.DefaultFooterView;
import com.plumtree.portalpages.common.uiparts.DefaultHeaderView;
import com.plumtree.portalpages.common.uiparts.NavigationModel;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView;
import com.plumtree.portaluiinfrastructure.statichelpers.PTDebugHelpers;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;
import com.plumtree.portaluiinfrastructure.*;

/**
 * Standard Footer intrinsic portlet that wraps DefaultFooterView.
 * 
 * @author DavidP
 *
 */
public class StandardFooterView extends IntrinsicPortletView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
			"com.plumtree.portalpages.portlets.headerfooter.StandardFooterView");
	
	
	/** MVC Name */
	public static final String STR_MVC_CLASS_NAME = "StandardFooter";
	private AActivitySpace m_asOwner;
	private IModelRO m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new StandardFooterView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		return DisplayPortlet();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	
	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		
		// Ignore the passed-in model and extract the nav model instead
		m_model = (NavigationModel) parent.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
	}
	

	/**
	 * Form default Footer HTML
	 * 
	 * @return HTMLElement					The HTML for the Footer
	 */
	private HTMLElement GetTable()
	{
		HTMLElement result = null;

		try
		{
			// Create footer table
			HTMLTable footerTable = new HTMLTable();
			footerTable.SetID(PTStyleID.PT_FOOTER);
			footerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			footerTable.SetCellPadding(CommonHTMLStrings.FIVE);
			footerTable.SetBorder(CommonHTMLStrings.ZERO);
			footerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			
            // Configure table
			footerTable.SetStyle("border-bottom:1px solid rgb(2,80,162); width:100%; vertical-align:middle;");

			// Create footer row
			HTMLTableRow onlyRow = (HTMLTableRow) footerTable.InsertInnerHTMLElement(new HTMLTableRow());

			// Set up table cell
			HTMLTableCell onlyCell = (HTMLTableCell) onlyRow.InsertInnerHTMLElement(new HTMLTableCell());
			onlyCell.SetVAlign(CommonHTMLStrings.MIDDLE);
			onlyCell.SetAlign(CommonHTMLStrings.CENTER);
			onlyCell.SetStyle("text-align:center; font:normal 10px/10px Verdana, Arial, Helvetica, sans-serif;");
			//onlyCell.SetStyleClass(PTStyleClass.FOOT_HEADER_BG + " " + PTStyleClass.FOOT_TEXT);

			// Put subtitle in its own span
			//onlyCell.AddInnerHTMLString(m_asOwner.GetString(243, "ptmsgs_portalcommonmsgs"));

			// Continue adding content to the table cell
			onlyCell.AddInnerHTMLString(CommonHTMLStrings.SPACE);
			//onlyCell.AddInnerHTMLString(m_asOwner.GetString(244, "ptmsgs_portalcommonmsgs"));

			// Deliver the finished footer table
			result = footerTable;
			
			
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating footer table: " + e.getMessage());
		}

		return result;
	}
	

	/**
	 * Displays the HTML for the portlet. The child classes must implement this
	 * function. This function is called by Display().
	 *
	 * @return HTML for portlet
	 */
	public HTMLElement DisplayPortlet()
	{
		HTMLElement result = null;

		try
		{
			result = GetTable(); 
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating footer: " + e.getMessage());
		}

		return result;
	}

	/**
	 * Displays the WML for the portlet. The child classes must implement this
	 * function.  This function is called by DisplayWML().
	 *
	 * @return WML for portlet
	 */
	public String DisplayPortletWML()
	{
		return null;
	}
}

