package com.plumtree.portalpages.portlets.headerfooter;

import com.plumtree.openfoundation.web.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.uiparts.*;
import com.plumtree.portaluiinfrastructure.htmlconstructs.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.htmlconstructs.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * An intrinsic portlet that wraps the DefaultHeaderView.
 * Assigned to the default Experience Definition.
 * 
 * @author DavidP
 */
public class StandardHeaderView extends IntrinsicPortletView implements IView
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
			"com.plumtree.portalpages.portlets.headerfooter.StandardHeaderView");
	

	/** MVC Name */
	public static final String STR_MVC_CLASS_NAME = "StandardHeader";
	private AActivitySpace m_asOwner;
	private NavigationModel m_model;

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new StandardHeaderView();
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#display()
	 */
	public HTMLElement Display()
	{
		return DisplayPortlet();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on the page.
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 *
	 * @return HTMLScript
	 */
	public HTMLScript DisplayJavascript()
	{
		return null;
	}

	
	/**
	 * @see com.plumtree.xpshared.activityspace.IView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * @see com.plumtree.xpshared.activityspace.IView#Init(IModel, AActivitySpace)
	 */
	public void Init(IModelRO model, AActivitySpace parent)
	{
		m_asOwner     = parent;
		
		// Ignore the passed-in model and extract the nav model instead
		m_model = (NavigationModel) parent.GetModel(NavigationModel.STR_MVC_CLASS_NAME);
	}
	

	/**
	 * Method GetTable.  Form default header banner.
	 * 
	 * @return HTMLElement				The HTML for the banner
	 */
	private HTMLElement GetTable()
	{
		HTMLElement result = null;
		
		try
		{
			/* Build common things we'll need for both standard and 508 display modes */

           
            
			/* Prepare table cells tailored specifically for either standard or 508 modes */
			
			if (m_asOwner.GetAccessStyle() == AccessStyles.STANDARD)
			{
                HTMLDiv outerDiv = new HTMLDiv();
                outerDiv.SetID("ali-banner");
                
                HTMLDiv logoDiv = new HTMLDiv();
                logoDiv.SetID("ali-bannerLogo");
                //PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.LOGO_BANNER_ORACLE, true, this.m_asOwner);
                HTMLImg myImg		    = new HTMLImg("portal/private/img/banner_logo.gif", m_asOwner.GetString(245, "ptmsgs_portalcommonmsgs"), "33", "421");
                
                logoDiv.AddInnerHTMLElement(myImg);
                outerDiv.AddInnerHTMLElement(logoDiv);
                
                result = outerDiv;
                
// 				Old header code               
//                rightCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
//                
//                // Configure table
//                headerTable.SetStyle("border-bottom:1px solid rgb(2,80,162); width:100%; vertical-align:middle; clear:both;");
//                
//				// Configure left cell
//				leftCell.SetAlign(CommonHTMLStrings.LEFT);
//
//				// Construct logo image and add it to left cell
//				PTConstruct myConstruct = UIConstructFactory.GetConstruct(PTImageType.LOGO_BANNER_ORACLE, true, this.m_asOwner);
//				HTMLImg myImg		    = (HTMLImg) myConstruct.GetHTMLElement();
//				myImg.SetAlt(m_asOwner.GetString(245, "ptmsgs_portalcommonmsgs"));
//				myImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
//				myImg.SetBorder(CommonHTMLStrings.ZERO);
//				leftCell.AddInnerHTMLElement(myImg);
//
//				// Configure middle cell
//                middleCell.SetAlign(CommonHTMLStrings.RIGHT);
//                
//                // Construct logo image and add it to left cell
//                myConstruct = UIConstructFactory.GetConstruct(PTImageType.LOGO_HEADER_SPLASH, true, this.m_asOwner);
//                myImg           = (HTMLImg) myConstruct.GetHTMLElement();
//                myImg.SetAlt(m_asOwner.GetString(245, "ptmsgs_portalcommonmsgs"));
//                myImg.SetAlign(CommonHTMLStrings.ABSMIDDLE);
//                myImg.SetBorder(CommonHTMLStrings.ZERO);
//                middleCell.AddInnerHTMLElement(myImg);
//                
//                // Configure right cell
//                rightCell.SetStyle("text-align:right; font:normal 14px/16px Arial, Helvetica, sans-serif; padding:0px 12px 0px 24px;");
//                rightCell.AddInnerHTMLString("<strong style='text-align:right; font:bold 16px/16px Arial, Helvetica, sans-serif;'>");
//                rightCell.AddInnerHTMLString(XPHttpUtility.HtmlEncode(m_model.GetTitleForBanner()));
//                rightCell.AddInnerHTMLString("</strong>");
//                rightCell.AddInnerHTMLElement(new HTMLBr());
//                rightCell.AddInnerHTMLEncodedString(m_model.GetSubtitleForBanner());
                
			}
			else    /* 508 mode */
			{
				 // Create outermost table for header
	            HTMLTable headerTable = new HTMLTable();
	            headerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
	            headerTable.SetCellPadding(CommonHTMLStrings.ZERO);
	            headerTable.SetBorder(CommonHTMLStrings.ZERO);
	            headerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
	            
	            // Add only row to table
	            HTMLTableRow headerTableRow = (HTMLTableRow) headerTable.InsertInnerHTMLElement(new HTMLTableRow());
				
	            // Add left cell to table row
	            HTMLTableCell leftCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
	
	            // Add right cell to table row
	            HTMLTableCell rightCell = (HTMLTableCell) headerTableRow.InsertInnerHTMLElement(new HTMLTableCell());
				
                headerTable.SetID(PTStyleID.PT_HEADER);
                headerTableRow.SetStyleClass(PTStyleClass.BAN_HEADER_BG);
                headerTableRow.SetVAlign(CommonHTMLStrings.TOP);
                leftCell.SetID(PTStyleID.PT_HEADER_LEFT);
                rightCell.SetID(PTStyleID.PT_HEADER_RIGHT);
                rightCell.SetNoWrap(true);

                // Build title H1 and add to right cell
                HTMLH1 titleH1 = new HTMLH1();
                titleH1.AddInnerHTMLEncodedString(m_model.GetTitleForBanner());
                titleH1.SetStyleClass(PTStyleClass.BAN_HEADER);
                rightCell.AddInnerHTMLElement(titleH1);

                // Build subtitle H2 and add to right cell
                HTMLH2 subTitleH2 = new HTMLH2();
                subTitleH2.AddInnerHTMLEncodedString(m_model.GetSubtitleForBanner());
                subTitleH2.SetStyleClass(PTStyleClass.BAN_SUBHEADER);
                rightCell.AddInnerHTMLElement(subTitleH2);
                
				// Configure left cell
				leftCell.SetAlign(CommonHTMLStrings.LEFT);
				leftCell.SetWidth(CommonHTMLStrings.TWO);
				leftCell.SetHeight("60");

				// Configure right cell
				rightCell.SetAlign(CommonHTMLStrings.LEFT);
				rightCell.SetWidth("200");
				
				result = headerTable;
			}

			
		}
		catch(Exception e)
		{
			result = new HTMLGenericElement("Error creating banner table: " + e.getMessage());
		}

		return result;
	}
	
	
	/**
	 * Displays the HTML for the portlet. The child classes must implement this
	 * function. This function is called by Display().
	 *
	 * @return HTML for portlet
	 */
	public HTMLElement DisplayPortlet()
	{
		HTMLElement result = null;

		try
		{
			result = GetTable(); 
		}
		catch (Exception e)
		{
			result = new HTMLGenericElement("Error creating banner: " + e.getMessage());
		}

		return result;
	}

	/**
	 * Displays the WML for the portlet. The child classes must implement this
	 * function.  This function is called by DisplayWML().
	 *
	 * @return WML for portlet
	 */
	public String DisplayPortletWML()
	{
		return null;
	}
}

