package com.plumtree.portalpages.portlets.intrinsicpageletparamprefeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.classtypedescriptors.providerframework.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * 
 * Model of Community prefs editor specific to portlets for ensemble pagelets  
 * @author rozhang
 */
public class IntrinsicPrefsEditorForPageletParametersModel extends IntrinsicPortletPrefsEditorModel
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.intrinsicpageletparamprefeditor.IntrinsicPrefsEditorForPageletParametersModel");

	
	public static final String STR_MVC_CLASS_NAME = "IntrinsicPrefsEditorForPageletParameters";
	
	public static final int NAME_INDEX = 0;
	public static final int VALUE_INDEX = 1;
	
	/** of type: PREF_TYPE_PERSONAL, PREF_TYPE_COMMUNITY, PREF_TYPE_ADMIN in IntrinsicPortletPrefsEditorModel**/
	protected int m_currPrefType		= -1;
	
	protected String[] m_prefNames 		= null;
	protected String[] m_prefValues 	= null;
	protected String[] m_prefDescs		= null;
	protected boolean[] m_prefChanged	= null;
	
	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnStartEditor(com.plumtree.openfoundation.util.XPHashtable)
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		// ?? figure out what type of editor we are in
		String prefsType = null;
		String descType = null;
		int editorPrefType = this.GetPrefType();
		Object[][] arSettings = null;
		m_currPrefType = editorPrefType;
		
		switch (editorPrefType) {
		
		case PREF_TYPE_PERSONAL:
			prefsType = AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER;
			descType = AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_USER_DESCS;
			arSettings = GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_PORTLET,null);
			break;
		case PREF_TYPE_COMMUNITY:
			prefsType = AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM;
			descType = AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_COMM_DESCS;
			arSettings = GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_COMMUNITYPORTLET,null);
			break;
		case PREF_TYPE_ADMIN:
			prefsType = AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN;
			descType = AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_ADMIN_DESCS;
			arSettings = GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN,null);
			break;
		}
		
		
		// first load param names and desc from webservice object
		// a little messy to swap out the instance variable
		LookupPrefsFromWebservice(prefsType, descType);
		// keep track of names loaded from ws object
		String[] paramNamesFromWS = m_prefNames;
		
		// now load stored preferences and then compare with stored mapping webservice object
		// to check if anything was updated
		String[] loadedPrefNames	= new String[] {};
		// preset the length of the value array, in case no values are loaded
		// from preferences. this array gets assigned to m_prefValues in either
		// case
		String[] loadedPrefValues	= new String[paramNamesFromWS.length];
		for ( int i = 0; i < loadedPrefValues.length; i++ ) {
			loadedPrefValues[i] = "";
		}
		
		if ( arSettings != null && arSettings[NAME_INDEX].length != 0 ) 
		{
			loadedPrefNames	= new String[arSettings[NAME_INDEX].length];
			loadedPrefValues= new String[arSettings[VALUE_INDEX].length];
			for ( int i = 0; i < arSettings[NAME_INDEX].length; i++ ) {
				loadedPrefNames[i]  = (String)arSettings[NAME_INDEX][i];
				loadedPrefValues[i] = (String)arSettings[VALUE_INDEX][i];
			}
		} 
		
		if ( loadedPrefNames.length == 0 || (paramNamesFromWS.length == loadedPrefNames.length) ) {
			// no updates was made or first time we are editing the preferences since none has been stored yet
			// just set the pref values, LookupPrefsFromWebservice already set name and desc
			m_prefValues = loadedPrefValues;
		} else {
			// there was an update, now we take the updated param names from ws object and lookup values from the
			// stored preferences
			
			// go through each param name loaded from ws object and check if there are values assigned to them
			String[] tmpPrefValues = new String[paramNamesFromWS.length]; 
			for ( int i = 0; i < paramNamesFromWS.length; i++ ) {
				String curName = paramNamesFromWS[i];
				int nameIndex = FindIndexInStringArray(loadedPrefNames, curName);
				if ( nameIndex >= 0 ) {
					tmpPrefValues[i] = loadedPrefValues[nameIndex]; // found value
				} else {
					tmpPrefValues[i] = ""; // updated param wtih no value
				}
			}
			m_prefValues = tmpPrefValues;
		}
	}
	
	protected int FindIndexInStringArray(String[] arr, String searchString)
	{
		for ( int i = 0; i < arr.length; i++ ) {
			String strVal = arr[i];
			if ( searchString.equals(strVal) ) {
				return i;
			}
		}
		return -1;
	}

	/**
	 * Loads mapped prefs from webservice object.
	 * Names of mapped prefs for a pagelet is stored with the webservice object
	 * 
	 * @param prefsType A constant of type: AExtensibilityConstants.PT_PROPBAG_HTTPGADGET_PARAMMAPPING_X
	 */
	protected void LookupPrefsFromWebservice(String prefsType, String descType)
	{
		// need to lookup the stored community settings from webservice object properties
		int wsId = super.m_ptPortlet.GetWebServiceID();
		
		IPTWebService webService = (IPTWebService)super.m_ptSession.GetWebServices().Open(wsId, false);
		IXPPropertyBag provInfo = webService.GetProviderInfo();

		String[] convParamFromPrefs = null;
		String[] convParamDescsFromPrefs;
		Object prefs 	= provInfo.ReadAsObject1DArray(prefsType);
		Object prefDescs= provInfo.ReadAsObject1DArray(descType);
		
		if ( prefs == null ) {
			throw new XPIllegalStateException("No mapped pagelet parameters found for portlet. Check mapping in Webservice object with id: "+wsId);
		}
		// convert parameters to string array
		if ( prefs instanceof Object[] ) {
			Object[] tmp = (Object[])prefs;
			Object[] tmpDescs = (Object[])prefDescs;
			if ( tmp.length != tmpDescs.length ) {
				if ( log.IsWarnEnabled() ) {
					log.Warn("Mismatch between length of parameter names and parameter description arrays for webservice with id: "+wsId+
							". Disabling parameter descriptions.");
				}
				convParamDescsFromPrefs = new String[] {};
			} else {
				convParamDescsFromPrefs = new String[tmpDescs.length];
				for ( int j = 0; j < tmpDescs.length; j++ ) {
					 convParamDescsFromPrefs[j] = (String)tmpDescs[j]; 
				}
			}
			
			convParamFromPrefs = new String[tmp.length];
			
			for ( int i = 0; i < tmp.length; i++ ) {
				convParamFromPrefs[i] = (String)tmp[i];
			}
			m_prefNames 	= convParamFromPrefs;
			m_prefValues 	= new String[convParamFromPrefs.length];
			for ( int i = 0; i < m_prefValues.length; i++ ) {
				if ( m_prefValues[i] == null ) {
					m_prefValues[i] = "";
				}
			}
			m_prefDescs  	= convParamDescsFromPrefs; 
		} else {
			// none found, no preferences supported, shouldn't happen
			if ( log.IsWarnEnabled() ) {
				log.Warn("Entering preference editor for pagelet portlet when no preferences are mapped in webservice object with id: "+wsId);
			}
			m_prefNames  = new String[] {};
			m_prefValues = new String[] {};
			m_prefDescs	 = new String[] {};
		}
	}
	
	/**
	 * Called before Finish method
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#SavePage(java.lang.String, com.plumtree.openfoundation.util.XPHashtable)
	 */
	public int SavePage(String sPageName, XPHashtable formData)
	{
		m_prefChanged = new boolean[m_prefNames.length];
		for ( int i = 0; i < m_prefNames.length; i++ ) {
			Object prefValue = formData.GetElement(IntrinsicPrefsEditorForPageletParametersView.CPPREF_INPUT_NAME+i);
			// This happens if portlet has no prefs, just exit from editor when 
			// user presses finish
			if ( prefValue == null ){
				return RepostControl.PAGE_STATUS_VALID;
			}
			
			String prefStringVal = ((String[])prefValue)[0];
			// can only happen if someone tampered with the page
			// don't bother displaying a pretty error message
			if (prefStringVal.length() > EnsembleRestAPIService.ENSEMBLE_PAGELETPARAMETER_MAXLENGTH) {
				return RepostControl.PAGE_STATUS_INVALID;
			}
			if ( m_prefValues[i] == null || !m_prefValues[i].equals(prefStringVal) ) {
				
				// form values come in a string array
				m_prefValues[i] = ((String[])prefValue)[0];
				m_prefChanged[i] = true;
			} else {
				// only save the prefs that changed
				m_prefChanged[i] = false;
			}
			
		}
		return RepostControl.PAGE_STATUS_VALID;
	}
	
	/**
	 * Figure out how to save the prefs depending on the type of the 
	 * prefs. 
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Finish()
	 */
	public void Finish()
	{
		int editorPrefType = this.GetPrefType();
		int prefsType = 0;
		
		switch (editorPrefType) {
		
		case PREF_TYPE_PERSONAL:
			prefsType = SETTINGSTYPE_PORTLET;
			break;
		case PREF_TYPE_COMMUNITY:
			prefsType = SETTINGSTYPE_COMMUNITYPORTLET;
			break;
		case PREF_TYPE_ADMIN:
			prefsType = SETTINGSTYPE_ADMIN;
			break;
		}
		
		// only store the settings that changed
		for ( int i = 0; i < m_prefChanged.length; i++ ) {
			if ( m_prefChanged[i] ) {
				SetSettingValue(prefsType, m_prefNames[i], m_prefValues[i]); 
			}
		}
	}

	/**
	 * 
	 * @return An array with 
	 */
	public String[] GetPortletPrefNames()
	{
		return m_prefNames;
	}
	
	/**
	 * 
	 * @return An array with preference values, never null
	 */
	public String[] GetPortletPrefValues()
	{
		return m_prefValues;
	}
	
	/**
	 * 
	 * @return An array with preference descriptions, never null
	 */
	public String[] GetPortletPrefDescriptions()
	{
		return m_prefDescs;
	}
	
	/**
	 * Returns one of these values:
	 * IntrinsicPortletPrefsEditorModel.PREF_TYPE_PERSONAL, PREF_TYPE_COMMUNITY, PREF_TYPE_ADMIN
	 * @return
	 */
	public int GetCurrPrefType()
	{
		return m_currPrefType;
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#Create()
	 */
	public Object Create()
	{
		return new IntrinsicPrefsEditorForPageletParametersModel();
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

}
