package com.plumtree.portalpages.portlets.intrinsicpageletparamprefeditor;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.restconsumerframework.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * View to display and edit preferences for portlets for ensemble pagelet
 * @author rozhang
 */
public class IntrinsicPrefsEditorForPageletParametersView extends EditorView
{
	public static final String STR_MVC_CLASS_NAME = "IntrinsicPrefsEditorForPageletParametersView";
	
	/** The name prefix of the input box for preference values. Each input box also
	 *  gets an index count appended where the index corresponds to the pref array returned 
	 *  from the model **/
	public static final String CPPREF_INPUT_NAME = "prefValueIndex";
	
	/**
	 * For selenium test
	 */
	public static final String CPPREF_NAMESPAN_PREFIX = "prefsName";
	
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.intrinsicpageletparamprefeditor.IntrinsicPrefsEditorForPageletParametersView");

	/**
	 * 
	 * @see com.plumtree.uiinfrastructure.editor.EditorView#Display()
	 */
	public HTMLElement Display()
	{
		HTMLElementCollection result = new HTMLElementCollection();

		HTMLTable headerTable;
		HTMLTableRow headerRow;
		HTMLTableCell headerCell;
		HTMLSpan headerSpan;

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display IntrinsicPrefsEditorForPageletParametersView");
			result.AddInnerHTMLElement(myComment);

			HTMLTable outerTable = new HTMLTable();
			outerTable.SetWidth("100%");
			outerTable.SetCellSpacing("5");
			outerTable.SetCellPadding("5");
			HTMLTableRow outerRow = new HTMLTableRow();
			HTMLTableCell outerCell = new HTMLTableCell();
			outerCell.SetAlign("center");
			
			result.AddInnerHTMLElement(outerTable);
			outerTable.AddInnerHTMLElement(outerRow);
			outerRow.AddInnerHTMLElement(outerCell);
			
			
			headerTable = new HTMLTable();
			outerCell.AddInnerHTMLElement(headerTable);
			headerTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
			headerTable.SetBorder(CommonHTMLStrings.ZERO);
			headerTable.SetCellPadding(CommonHTMLStrings.FIVE);
			headerTable.SetCellSpacing(CommonHTMLStrings.ZERO);
			
			headerRow = new HTMLTableRow();
			headerTable.AddInnerHTMLElement(headerRow);
			headerRow.SetStyleClass(PTStyleClass.OBJECT_HEADER_BG);	
			
			headerCell = new HTMLTableCell();
			headerRow.AddInnerHTMLElement(headerCell);
			headerCell.SetColSpan(CommonHTMLStrings.THREE);
			headerCell.SetHeight("20");
			headerSpan = new HTMLSpan();
			headerCell.AddInnerHTMLElement(headerSpan);
			headerSpan.SetStyleClass(PTStyleClass.OBJECT_HEADER);
			// Edit Preferences
			
			String tableHeader = null;
			IntrinsicPrefsEditorForPageletParametersModel model = (IntrinsicPrefsEditorForPageletParametersModel)m_asOwner.GetModel(IntrinsicPrefsEditorForPageletParametersModel.STR_MVC_CLASS_NAME);
			switch (model.GetCurrPrefType())
			{
			case IntrinsicPortletPrefsEditorModel.PREF_TYPE_PERSONAL:
				tableHeader = m_asOwner.GetString(1992, ResourceConstants.PORTALBROWSINGMSGS);
				break;
			case IntrinsicPortletPrefsEditorModel.PREF_TYPE_COMMUNITY:
				tableHeader = m_asOwner.GetString(2008, ResourceConstants.PORTALBROWSINGMSGS);
				break;
			case IntrinsicPortletPrefsEditorModel.PREF_TYPE_ADMIN:
				tableHeader = m_asOwner.GetString(2009, ResourceConstants.PORTALBROWSINGMSGS);
				break;
			}
			
			headerSpan.AddInnerHTMLString(tableHeader);
			
			headerRow = new HTMLTableRow();
			headerTable.AddInnerHTMLElement(headerRow);
			
			// start displaying prefs
			String[] prefNames 	= model.GetPortletPrefNames();
			String[] prefValues 	= model.GetPortletPrefValues();
			String[] prefDescs	= model.GetPortletPrefDescriptions();
			DisplayPrefsEditList(outerCell, prefNames, prefValues, prefDescs, CPPREF_INPUT_NAME);
			
			myComment = new HTMLComment( "End: Display IntrinsicPrefsEditorForPageletParametersView");
			result.AddInnerHTMLElement(myComment);
			
		} catch (XPException e ) {
			if ( log.IsWarnEnabled()) {
				IntrinsicPrefsEditorForPageletParametersModel model = (IntrinsicPrefsEditorForPageletParametersModel)m_asOwner.GetModel(IntrinsicPrefsEditorForPageletParametersModel.STR_MVC_CLASS_NAME);
				log.Warn(e, "There was an error displaying intrinsic community prefs editor for a pagelet portlet: "+model.GetPortletName());
			}
			// There was an error displaying this page.
			result.AddInnerHTMLString(m_asOwner.GetString(1996, ResourceConstants.PORTALBROWSINGMSGS));
		}
		return result;

	}



	/**
	 * @param result
	 * @param prefNames
	 * @param prefValues
	 */
	private void DisplayPrefsEditList(HTMLElement result, String[] prefNames, String[] prefValues, String[] prefDescs, String inputIdPrefix)
	{
		if ( prefNames == null || prefValues == null ) {
			throw new XPIllegalArgumentException("Required method argument was null prefNames: "+prefNames+" prefValues: "+prefValues);
		}
		if ( prefNames.length != prefValues.length ) {
			throw new XPIllegalArgumentException("Preferences names and values array are of different length");
		}
		
		HTMLTable prefsTable = new HTMLTable();
		prefsTable.SetID("prefsEditTable"); // used by selenium test
		result.AddInnerHTMLElement(prefsTable);
		prefsTable.SetWidth(CommonHTMLStrings.ONE_HUNDRED_PERCENT);
		prefsTable.SetCellPadding(CommonHTMLStrings.TWO);
		prefsTable.SetCellSpacing(CommonHTMLStrings.ZERO);
		
		HTMLTableRow prefsRow = new HTMLTableRow();
		prefsTable.AddInnerHTMLElement(prefsRow);
		prefsRow.SetStyleClass(PTStyleClass.LIST_SORT_HEADER_BG);
		
		HTMLTableCell prefsCell = new HTMLTableCell();
		prefsRow.AddInnerHTMLElement(prefsCell);
		prefsCell.SetHeight("20");
		prefsCell.SetWidth("35%");
		prefsCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		// Header: Preference Name
		prefsCell.AddInnerHTMLString(m_asOwner.GetString(1993, ResourceConstants.PORTALBROWSINGMSGS));
		
		prefsCell = new HTMLTableCell();
		prefsRow.AddInnerHTMLElement(prefsCell);
		prefsCell.SetHeight("20");
		prefsCell.SetWidth("65%");
		prefsCell.SetStyleClass(PTStyleClass.LIST_SORT_HEADER);
		// Header: Preference Value
		prefsCell.AddInnerHTMLString(m_asOwner.GetString(1994, ResourceConstants.PORTALBROWSINGMSGS));
		
		// if no preferences exist, should not happen since this editor wouldnt not be available with 
		// no comm prefs
		if ( prefNames.length == 0 ) {
			prefsRow = new HTMLTableRow();
			prefsTable.AddInnerHTMLElement(prefsRow);
			prefsRow.SetStyleClass(PTStyleClass.LIST_ITEM_TWO_BG);
			prefsCell = new HTMLTableCell();
			prefsRow.AddInnerHTMLElement(prefsCell);
			prefsCell.SetColSpan("2");
			prefsCell.SetHeight("30");
			prefsCell.SetWidth("100%");
			prefsCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			HTMLSpan prefsSpan = new HTMLSpan();
			prefsCell.AddInnerHTMLElement(prefsSpan);
			// There was an error displaying this page.
			prefsSpan.AddInnerHTMLString(m_asOwner.GetString(1996, ResourceConstants.PORTALBROWSINGMSGS));
		}
		
		// for each prefs, display a row
		for ( int i = 0; i < prefNames.length; i++ )
		{
			prefsRow = new HTMLTableRow();
			prefsTable.AddInnerHTMLElement(prefsRow);
			prefsRow.SetStyleClass( (i % 2 == 0) ? PTStyleClass.LIST_ITEM_TWO_BG : PTStyleClass.LIST_ITEM_ONE_BG);
			
			prefsCell = new HTMLTableCell();
			prefsRow.AddInnerHTMLElement(prefsCell);
			prefsCell.SetHeight("30");
			prefsCell.SetWidth("55%");
			prefsCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			
			HTMLSpan prefsSpan = new HTMLSpan();
			prefsCell.AddInnerHTMLElement(prefsSpan);
			prefsSpan.SetStyleClass(PTStyleClass.OBJECT_SUBTITLE);
			// add prefs name
			prefsSpan.AddInnerHTMLEncodedString(prefNames[i]);
			prefsSpan.SetID(CPPREF_NAMESPAN_PREFIX+i); // for selenium test
			
			// add prefs description
			prefsCell.AddInnerHTMLElement(new HTMLBr());
			
			// shouldn't happen but if there is some error, don't display desc instead of blowing up
			if ( prefDescs.length != 0 ) {
				prefsCell.AddInnerHTMLEncodedString(prefDescs[i]);
			}
			
			prefsCell = new HTMLTableCell();
			prefsRow.AddInnerHTMLElement(prefsCell);
			prefsCell.SetHeight("30");
			prefsCell.SetWidth("45%");
			prefsCell.SetStyleClass(PTStyleClass.OBJECT_TEXT);
			prefsCell.SetNoWrap(true);
			
			HTMLInput prefsValue = new HTMLInput(HTMLInputTypes.TEXT, inputIdPrefix+i, m_asOwner.GetString(1995, ResourceConstants.PORTALBROWSINGMSGS));
			prefsCell.AddInnerHTMLElement(prefsValue);
			// validation for preference value
			prefsValue.SetMaxLength(EnsembleRestAPIService.ENSEMBLE_PAGELETPARAMETER_MAXLENGTH);
			prefsValue.SetSize(45);
			// set prefs value
			if ( prefValues[i] != null ) {
				prefsValue.SetValue( prefValues[i] );
			}
		}
	}
	
	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorView#Create()
	 */
	public Object Create()
	{
		return new IntrinsicPrefsEditorForPageletParametersView();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.editor.EditorView#GetName()
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

}
