package com.plumtree.portalpages.portlets.jobhistory;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.form.*;

/**
 * This class implements the control for the Job History intrinsic portlet
 *
 * @author JohnH
 */
public class JobHistoryPortletControl extends IntrinsicPortletControl
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.jobhistory.JobHistoryPortletControl");

	/**
	 * Class name for the control. For intrinsic portlets, the control must
	 * have the same class name as the model.
	 */
	public static final String STR_MVC_CLASS_NAME = JobHistoryPortletModel.STR_MVC_CLASS_NAME;

	/** Move to the first history page */
	public final static int POSTTOSELF_ACTION_FIRSTHISTORYPAGE    = 22;

	/** Move to the previous history page */
	public final static int POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE = 23;

	/** Move to the next history page */
	public final static int POSTTOSELF_ACTION_NEXTHISTORYPAGE = 24;

	/** Move to the last history page */
	public final static int POSTTOSELF_ACTION_LASTHISTORYPAGE = 25;

	/** Pop up the job detail window */
	public final static int POSTTOSELF_ACTION_JOBDETAIL_POPUP = 30;

	/** Abort job action */
	public final static int POSTTOSELF_ACTION_ABORT = 40;

	//Constant for delete vs. filter mode

	/** Filter mode */
	public final static int FILTERMODE = 1;

	/**
	 * 
	 *
	 * @param arguments 
	 *
	 * @return 
	 */
	public Redirect CheckActionSecurityAndExecute(XPHashtable arguments)
	{
		return null;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobHistoryPortletControl();
	}

	/**
	 * Returns the name for the control
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @param _nAction 
	 * @param _htFormData 
	 */
	public void PerformRepostAction(int _nAction, XPHashtable _htFormData)
	{
	    int nAction = _nAction;

        // JHQ for issue 36772: super.CheckActionSecurityAndExecute() will treate LOW_BANDWIDTH 
        // the same as 508 and therefore look for in_su508PostToSelf_ instead of PostToSelf.
        // But in LB we can execute javascript and we use PostToSelf.
		if (AccessStyles.LOW_BANDWIDTH == m_asOwner.GetAccessStyle())
		{
			if (_htFormData.ContainsKey(RepostControl.HTMLINPUT_POSTTOSELF))
			{
				String[] data = (String[]) _htFormData.GetElement(RepostControl.HTMLINPUT_POSTTOSELF);
	
				if ((0 != data.length) && (null != data[0]))
				{
					nAction = XPConvert.ToInteger(data[0]);
	
					log.Debug("JobHistoryPortletControl::PerformRepostAction Repost action ID value: " +
							nAction);
				}
				else
				{
					log.Warn("JobHistoryPortletControl::PerformRepostAction Repost action ID was not in Query String.");
				}
			}
		}
		
		switch (nAction)
		{
		case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
			SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_FIRSTHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
			SetNewHistoryPageID(_htFormData,
				POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
			SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_NEXTHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_LASTHISTORYPAGE:
			SetNewHistoryPageID(_htFormData, POSTTOSELF_ACTION_LASTHISTORYPAGE);

			break;

		case POSTTOSELF_ACTION_JOBDETAIL_POPUP:
			PerformJobDetailPopupAction(_htFormData);

			break;
		
		case POSTTOSELF_ACTION_ABORT:
			AbortJob(_htFormData);

			break;
			
		}
	}

	/**
	 * JH- PerformJobDetailPopupAction handles the case where a popup is being
	 * displayed
	 *
	 * @param _htFormData is a hashtable that stores the form post data and querystring
	 */
	private void PerformJobDetailPopupAction(XPHashtable _htFormData)
	{
		//JH- Get the row number of the item we're displaying and store it in the Model, where
		//	the Form can get to it.
		((JobHistoryPortletModel) m_model).SetRowToDisplay(XPConvert.ToInteger(
				((String[]) _htFormData.GetElement(
					HistoryViewHelper.POPUP_CONTROL_ARG_ROWTOVIEW))[0]));
		((JobHistoryPortletModel) m_model).SetJobName(((String[]) _htFormData.GetElement(
				HistoryViewHelper.POPUP_CONTROL_ARG_JOBNAME))[0]);
		((JobHistoryPortletModel) m_model).SetRunTime(((String[]) _htFormData.GetElement(
				HistoryViewHelper.POPUP_CONTROL_ARG_RUNTIME))[0]);

		//Reset the current page of the job log to display back to 1
		((JobHistoryPortletModel) m_model).SetCurrentLogPage(1);
	}

	/**
	 * JH- SetNewHistoryPageID sets the History Page ID on the model so the
	 * HistoryViewHelper can know which page of the job history to display
	 *
	 * @param _htFormData
	 * @param intAction - The action to take: First, Previous, Next, Last
	 */
	private void SetNewHistoryPageID(XPHashtable _htFormData, int intAction)
	{
		int intCurrentPage = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					HistoryViewHelper.HTMLHIDDEN_CURRENTPAGE))[0]);
		int intLastPage    = XPConvert.ToInteger(((String[]) _htFormData.GetElement(
					HistoryViewHelper.HTMLHIDDEN_LASTPAGE))[0]);

		//set the appropriate BlockID based on the action
		switch (intAction)
		{
		case POSTTOSELF_ACTION_FIRSTHISTORYPAGE:
			((JobHistoryPortletModel) m_model).SetCurrentPage(1);

			break;

		case POSTTOSELF_ACTION_PREVIOUSHISTORYPAGE:
			((JobHistoryPortletModel) m_model).SetCurrentPage(intCurrentPage - 1);

			break;

		case POSTTOSELF_ACTION_NEXTHISTORYPAGE:
			((JobHistoryPortletModel) m_model).SetCurrentPage(intCurrentPage + 1);

			break;

		case POSTTOSELF_ACTION_LASTHISTORYPAGE:
			((JobHistoryPortletModel) m_model).SetCurrentPage(intLastPage);

			break;
		}
	}

	private void AbortJob(XPHashtable _htFormData)
	{
		//Send a kill message to the job or jobs
		try
		{
			((JobHistoryPortletModel) m_model).KillJobs(_htFormData);
		}
		catch (Exception e)
		{
			
				log.Error("JobLogRepostModel::DoTaskOnStartEditor " + m_asOwner.GetString(632, "ptmsgs_portalcommonmsgs")
						+ e);
			
			UIError myError = new UIError(UIErrorLevel.SERIOUS,
						UIErrorScope.CURRENT_USER,
						null,
						m_asOwner.GetString(632, "ptmsgs_portalcommonmsgs") + e,
						"");

			myError.SetActivitySpace(m_asOwner.GetName());

			UIErrorHandler.RaiseError(myError, m_asOwner.GetSubSession(),m_asOwner.GetApplication());
		}
	}

}

