package com.plumtree.portalpages.portlets.jobhistory;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;

/**
 * This class implements the model for the Job History intrinsic portlet
 *
 * @author JohnH
 */
public class JobHistoryPortletModel extends IntrinsicPortletModel
	implements IJobHistoryPortletModelRO, IRepostModel, IJobLogModelRO
{
	/** Class name for the model */
	public static final String STR_MVC_CLASS_NAME = "JobHistoryPortlet";
	
	/** JobLogHistory helper model */
	private JobLogModelHelper myModelHelper;

	/**
	 * Returns true if this portlet has a control class
	 *
	 * @return boolean
	 */
	public boolean ControlExists()
	{
		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobHistoryPortletModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish()
	{
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Object GetNewTempData()
	{
		return null;
	}

	/**
	 * Returns the portlet name
	 *
	 * @return Portlet name
	 */
	public String GetPortletName()
	{
		return m_ptPortlet.GetLocalizedName();
	}

	/**
	 * Returns the Redirect object  (this is were we need to go at the end of
	 * the Editor).
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}

	/**
	 * Inits the Model with the IPTSession.
	 *
	 * @param parent
	 */
	public void Init(AActivitySpace parent)
	{
		super.Init(parent);

		myModelHelper = new JobLogModelHelper(parent, (IPTSession) parent.GetUserSession());
		
		//Get the locale
		String strLocaleID =
			(String) PTPersonalSettingsHelper.GetPersonalSettingValue(
				PersonalSettingNames.LOCALE,
				parent);

		XPLocale m_Locale = new XPLocale(strLocaleID);

		if (null == m_Locale) {
			m_Locale = XPLocale.GetDefault();
		}


		String strTimeZone =
			(String) PTPersonalSettingsHelper.GetPersonalSettingValue(
				PersonalSettingNames.TIMEZONE,
				parent);

		XPTimeZone m_Timezone = XPTimeZone.GetCurrentTimeZone();
		if (null != strTimeZone)
		{
			m_Timezone = XPTimeZone.GetTimeZone(strTimeZone);
		} else
		{
			m_Timezone = XPTimeZone.GetCurrentTimeZone();
		}

		myModelHelper.InitializeDatePickerMgrs(m_Locale, m_Timezone);

	}


// BEGIN ***************** repost action methods *****************

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return 
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		int nSaveStatus = RepostControl.PAGE_STATUS_VALID;

		return nSaveStatus;
	}

	/**
	 * This function returns an int array of JobID's to be killed
	 *
	 * @param _htFormData
	 * @return int[]
	 */
	public int[] GetArrayOfJobsToKill(XPHashtable _htFormData)
	{
		return myModelHelper.GetArrayOfJobsToKill(_htFormData);
	}

	/**
	 * This function will send a kill message to each job that has been checked
	 * by the user.
	 * 
	 * @param _htFormData
	 */
	public void KillJobs(XPHashtable _htFormData)
	{
		myModelHelper.KillJobs(_htFormData);
	}

// END ***************** repost action methods *****************

// BEGIN ***************** Get and Set methods *****************

	/**
	 * Returns whether the very last request is a search of the job log.
	 * @return int
	 */
	public boolean IsSearchRequest()
	{
		return myModelHelper.IsSearchRequest();
	}

	/**
	 * Returns a string used for searching the job log.
	 * @return String
	 */
	public String GetSearchString()
	{
		return myModelHelper.GetSearchString();
	}
	/**
	 * Returns the log page currently being displayed.
	 * @return int
	 */
	public int GetCurrentLogPage()
	{
		return myModelHelper.GetCurrentLogPage();
	}

	/**
	 * Returns CurrentPage setting.
	 *
	 * @return int
	 */
	public int GetCurrentPage()
	{
		return myModelHelper.GetCurrentPage();
	}

	/**
	 * Returns the jobID.
	 * @return int
	 */
	public int GetJobID()
	{
		return myModelHelper.GetJobID();
	}

	/**
	 * Returns the jobName.
	 * @return String
	 */
	public String GetJobName()
	{
		return myModelHelper.GetJobName();
	}

	/**
	 * Returns the Plumtree Session object.
	 * @return IPTSession
	 */
	public IPTSession GetPTSession()
	{
		return myModelHelper.GetPTSession();
	}

	/**
	 * Returns the job history row to display in the job log detail viewer.
	 * @return int
	 */
	public int GetRowToDisplay()
	{
		return myModelHelper.GetRowToDisplay();
	}

	/**
	 * Returns the runTime.
	 * @return String
	 */
	public String GetRunTime()
	{
		return myModelHelper.GetRunTime();
	}

	/**
	 * Sets the the search term and indicates a result page
	 * @param SearchTerm to be applied against the log text
	 */
	public void SetLogSearchPage(String strSearchText)
	{
		myModelHelper.SetLogSearchPage(strSearchText);
	}

	/**
	 * Sets the the log page currently being displayed.
	 * @param currentLogPage The currentLogPage to set
	 */
	public void SetCurrentLogPage(int currentLogPage)
	{
		myModelHelper.SetCurrentLogPage(currentLogPage);
	}

	/**
	 * Sets CurrentRecord setting.
	 *
	 */
	public void SetCurrentPage(int _intCurrentPage)
	{
		myModelHelper.SetCurrentPage(_intCurrentPage);
	}

	/**
	 * Sets the jobID.
	 * @param jobID The jobID to set
	 */
	public void SetJobID(int jobID)
	{
		myModelHelper.SetJobID(jobID);
	}

	/**
	 * Sets the jobName.
	 * @param jobName The jobName to set
	 */
	public void SetJobName(String jobName)
	{
		myModelHelper.SetJobName(jobName);
	}

	/**
	 * Sets the job history row to display in the job log detail viewer.
	 * @param rowToDisplay The rowToDisplay to set
	 */
	public void SetRowToDisplay(int rowToDisplay)
	{
		myModelHelper.SetRowToDisplay(rowToDisplay);
	}

	/**
	 * Sets the runTime.
	 * @param runTime The runTime to set
	 */
	public void SetRunTime(String runTime)
	{
		myModelHelper.SetRunTime(runTime);
	}
	
	/**
	 * Returns the log file in byte array format
	 * 
	 * @return byte[]
	 */
	public byte[] GetLogFile()
	{
		return null;
	}

	/**
	 * Get the Date picker control manager
	 *
	 * @return JSDatePickerMgr
	 */
	public JSDatePickerMgr GetDatePickerControlManager()
	{
		return myModelHelper.GetDatePickerControlManager();
	}

	// END ***************** Get and Set methods *****************

}

