package com.plumtree.portalpages.portlets.jobhistory;

import com.plumtree.openlog.*;
import com.plumtree.portalpages.common.joblogs.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * This class displays the HTML for the Job History intrinsic portlet
 *
 * @author JohnH
 */
public class JobHistoryPortletView extends IntrinsicPortletView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.jobhistory.JobHistoryPortletView");

	/**
	 * Class name for the view. For intrinsic portlets, the view must have the
	 * same class name as the model.
	 */
	public static final String STR_MVC_CLASS_NAME = JobHistoryPortletModel.STR_MVC_CLASS_NAME;

	private HistoryViewHelper myViewHelper;
	
	/**
	 * Creates a new SamplePortletView object.
	 */
	public JobHistoryPortletView()
	{
		// We need a form because we have a repost button.
		m_bAddFormToPortlet     = true;
		m_bMultiPart = false;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new JobHistoryPortletView();
	}

	/**
	 * This method returns the HTMLScript that encompasses the Javascript on
	 * the page.
	 *
	 * @return HTMLScript
	 *
	 * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
	 */
	public HTMLScript DisplayJavascript()
	{
		HTMLScript myScript = super.DisplayJavascript();
		myViewHelper = new HistoryViewHelper(m_model, m_asOwner, true, IntrinsicPortletView.INTRINSIC_PORTLET_JAVASCRIPT_SUBMIT_FORM + ((IIntrinsicPortletModelRO) m_model).GetPortletID());

		IIntrinsicPortletModelRO iModelRO = (IIntrinsicPortletModelRO) m_model;

		String strPortletFormName			  = IntrinsicPortletView.INTRINSIC_PORTLET_HTMLFORM_NAME +
			iModelRO.GetPortletID();
			
		String newScript = myViewHelper.GetJavascript(strPortletFormName);

		myScript.AddInnerHTMLString(newScript);
		
		return myScript;
	}

	/**
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()
	 */
	public HTMLElement DisplayPortlet()
	{
		HTMLElementCollection result = new HTMLElementCollection();
		myViewHelper = new HistoryViewHelper(m_model, m_asOwner, true, IntrinsicPortletView.INTRINSIC_PORTLET_JAVASCRIPT_SUBMIT_FORM + ((IIntrinsicPortletModelRO) m_model).GetPortletID());

		try
		{
			HTMLComment myComment = new HTMLComment( "Begin: Display HistoryView");
			result.AddInnerHTMLElement(myComment);

			//Add the action bar
			result.AddInnerHTMLElement(myViewHelper.AddActionBar());

			//Add the job log detail
			result.AddInnerHTMLElement(myViewHelper.GetJobLogDetail());
			
			myComment = new HTMLComment( "End: Display HistoryView");
			result.AddInnerHTMLElement(myComment);
		}
		catch (Exception e)
		{
			PlumtreeHelpers.SetUIError(m_asOwner, OpenLogService.GetComponent("Portal_Portlets"), "JobHistoryPortletView::DisplayPortlet", e, true, UIErrorLevel.SERIOUS, 
				m_asOwner.GetString(92, "ptmsgs_portalcommonmsgs"));
		}

		return result;
	}


	/**
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()
	 */
	public String DisplayPortletWML()
	{
		return null;
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
}


