package com.plumtree.portalpages.portlets.login;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.login.*;
import com.plumtree.portalpages.browsing.login.createaccount.*;
import com.plumtree.portalpages.common.login.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.constants.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author mikej
 * Created on Mar 28, 2003
 */
public class LoginPortletView extends IntrinsicPortletView
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.login.LoginPortletView");

	
	public static final String STR_MVC_CLASS_NAME = LoginPortletModel.STR_MVC_CLASS_NAME;
	public static final String LOGIN_PORTLET_FORM = "LoginPortletForm";

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
     */
    public Object Create() {
        return new LoginPortletView();
    }

	/**
	 * 
	 *
	 * @return 
	 */
	public HTMLScript DisplayJavascript()
	{
		return LoginHTML.GetLoginJScript(false, LOGIN_PORTLET_FORM, 
			XPConvert.ToString(((IIntrinsicPortletModelRO) m_model).GetPortletID()));
	}

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortlet()
     */
    public HTMLElement DisplayPortlet()
    {
		HTMLTable myTable;
		HTMLElement myCreateLink = null;

		// Get 508 mode
		boolean b508 = false;

		int nAccessStyle;

		try
		{
			// This should not need to check for the access style cookie because
			// CachePersonalSettings does this for us.

			//	default access style for the current user.
			nAccessStyle = m_asOwner.GetAccessStyle().GetAccessID();
		}
		catch (Exception ex)
		{
			
				log.Debug(ex, "Unable to get config var as int.");
			

			nAccessStyle = 3;
		}
		
		if (nAccessStyle != AccessStyles.STANDARD.GetAccessID())
		{
			b508 = true;
		}

		// Create Login Form
		HTMLForm myForm = new HTMLForm("loginFormID");
		myForm.bForceFormattingOn = true;
		
		myTable = LoginHTML.GetLoginDirections(m_asOwner, "100%", false);
		myForm.AddInnerHTMLElement(myTable);

		// Only create this link if we are actually going to use it.
		if( PTLoginHelper.GetAllowUserCreation( m_asOwner, m_asOwner.GetApplication() ) )
		{
			// CREATE ACCOUNT LINK
			//   This button can just be a redirect because the form
			//   needn't be submitted.
			ASURL myHRef = new ASURL(m_asOwner);
	
			myHRef.SetLinkGetSpaceIfCached(CreateAccountAS.STR_MVC_CLASS_NAME,
				this.m_asOwner);
	
			myHRef.SetControl(CreateAccountControl.STR_MVC_CLASS_NAME);

			// Create an account
			myHRef.AddInnerHTMLString(m_asOwner.GetString(637,
					"ptmsgs_portalbrowsingmsgs"));
	
			// Create an account
			((HTMLAnchor) myHRef.GetURLAsHTMLElement()).SetTitle(m_asOwner.GetString(1459, "ptmsgs_portalbrowsingmsgs"));

			myCreateLink = myHRef.GetURLAsHTMLElement();
		}
		
		IIntrinsicPortletModelRO imodel = (IIntrinsicPortletModelRO) m_model;
		String sUniquifier = XPConvert.ToString(imodel.GetPortletID());
		
		LoginPortletModel model = (LoginPortletModel) m_model;

		//show authsource dropdown?
		boolean bShowAuthsourceDropdown = PTLoginHelper.ShowAuthDropdown();

		boolean bAllowAuthSourceDropdownDisplay = PTLoginHelper.AllowAuthDropdown();

		if (!bAllowAuthSourceDropdownDisplay)
		{
			// Mode 3 means never show auth source dropdown
			bShowAuthsourceDropdown = false;
		}

		LoginHTML.MakeLoginForm(myForm, LOGIN_PORTLET_FORM, LoginAS.STR_MVC_CLASS_NAME, 
			XPConvert.ToString(model.GetPortletID()), 
			LoginControl.STR_MVC_CLASS_NAME, 
			m_asOwner, b508, sUniquifier, myCreateLink, bShowAuthsourceDropdown,
			bAllowAuthSourceDropdownDisplay);

		// WilliamA - check if there's redirect-after-login URL
		// if there is, set it as a hidden input in the login form
		String redirectAfterLoginURL = (String)m_asOwner.GetSubSession().GetAttribute("PT_" + ASConstants.REDIRECT_AFTER_LOGIN);
		if (null != redirectAfterLoginURL && redirectAfterLoginURL.length()>0)
		{
			// Sets the space name for the event to be passed to the server
			HTMLInput myInput = new HTMLInput(HTMLInputTypes.HIDDEN,
				ASConstants.REDIRECT_AFTER_LOGIN_INPUT, 
				ASConstants.REDIRECT_AFTER_LOGIN_INPUT,
				"This is an input");
			myInput.SetValue(redirectAfterLoginURL);
			myForm.AddInnerHTMLElement(myInput);
		}

		return myForm;
    }

	/**
	 * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletView#DisplayPortletWML()
	 */
	public String DisplayPortletWML()
	{
		return null;
	}

    /**
     * @see com.plumtree.uiinfrastructure.activityspace.IMVCObject#GetName()
     */
    public String GetName() {
        return STR_MVC_CLASS_NAME;
    }

}

