package com.plumtree.portalpages.portlets.savedsearch;

import com.plumtree.openfoundation.internationalization.*;
import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.browsing.search.results.*;
import com.plumtree.portaluiinfrastructure.filter.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.*;
import com.plumtree.portaluiinfrastructure.login.*;
import com.plumtree.portaluiinfrastructure.search.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.pagecontrols.framework.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatepicker.*;
import com.plumtree.uiinfrastructure.pagecontrols.jsdatetimepicker.*;
import com.plumtree.uiinfrastructure.pagination.*;
import com.plumtree.uiinfrastructure.statichelpers.*;
import com.plumtree.xpshared.jsutil.*;

/**
 * 
 *
 * @author mikesample
 */
public class SavedSearchPortletModel extends IntrinsicPortletModel 
	implements ISavedSearchPortletModelRO, IRepostModel, IPagination, IPaginationRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.savedsearch.SavedSearchPortletModel");

	/** Class name for the model */
	public static final String STR_MVC_CLASS_NAME = "SavedSearchPortlet";

	
	public final static String strTitleKey = "SRCHTITLE";

	
//	public final static String strSimpleKey = "SIMPLE";

	
//	public final static String strSrchIDKey = "SAVSRCHID";
	
	
	public final static String ADMIN_PREF_DISPLAY_FIELDS = "DISPLAYFLDS";
	
	
	public final static String ADMIN_PREF_PARAMETERIC_PROPS = "PARAMETERICS";
	

	/** Index of search title in data array */
	public final static int DATA_INDEX_SEARCHTITLE = 0;

	/** Index of simple flag in data array */
	public final static int DATA_INDEX_SIMPLE = 1;

	/** Index of search ID in data array */
	public final static int DATA_INDEX_SEARCHID = 2;

	/** Index of search ID in data array */
	public final static int DATA_INDEX_PARAMETERICIDS = 3;
	
	/** Index of search ID in data array */
	public final static int DATA_INDEX_DISPLAY_FIELDS = 4;

	/** Index of Property ID in property info array */
	public final static int PROPINFO_INDEX_ID = 0;

	/** Index of Property Name in property info array */
	public final static int PROPINFO_INDEX_NAME = 1;
	
	/** Index of Property Type in property info array */
	public final static int PROPINFO_INDEX_TYPE = 2;

	/** Index of UI Orientation (column or row) in property info array */
	public final static int PROPINFO_INDEX_ORIENT = 3;
	
	/** orientation values - column */
	public final static String PROPINFO_ORIENT_COL = "c";
	
	/** orientation values - row */
	public final static String PROPINFO_ORIENT_ROW = "r";

	private IPTSavedSearchManager m_SrchMgr;

	
	private int m_nSavSrchID = 0;

	
	private int m_nUserID;
	
	
	private Object[] m_arSearchSettings;

	/* datepicker objects */
	private PageMgr m_pageMgr;
	private JSDateTimePickerMgr m_dtPickerMgr;
	
	private IPTFilter m_filter;
	private FilterIterator m_itrFilter;
	private boolean m_bIsParameterized;
	private boolean m_bHasFollowupResults;
	private int m_nSortID = 0;
	private int m_nPaginateSize = 0;
	private int m_nPaginateTotal = 0;
	private int m_nPaginateFirstIndx = 1;
	private int m_nMaxResultsCnt = 0;
	
	/**
	 * 
	 *
	 * @return 
	 */
	public boolean ControlExists()
	{
		return true;
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavedSearchPortletModel();
	}

	/**
	 * Implement some code to execute when the user clicks on "Finish".
	 */
	public void Finish()
	{
	}

    /* (non-Javadoc)
     * @see com.plumtree.portaluiinfrastructure.intrinsicportlets.IntrinsicPortletModel#InitPortlet(com.plumtree.server.IPTPageInfo, com.plumtree.server.IPTState, com.plumtree.server.IPTGadget, int)
     */
    public void InitPortlet(IPTPageInfo _ptPageInfo, IPTState _ptAppDataState,
            IPTGadget _ptPortlet, int _nPortletID) 
    {
        super.InitPortlet(_ptPageInfo, _ptAppDataState, _ptPortlet, _nPortletID);
        GetData();
        InitDatePickerObjects();
        m_bIsParameterized = InitParametericPropObjects();
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.portlets.savedsearch.ISavedSearchPortletModelRO#GetAdminPrefs()
     */
    public Object[] GetSearchSettings() 
    {
        return m_arSearchSettings;
    }
    
	/**
	 * 
	 *
	 * @return 
	 *
	 * @throws XPException 
	 */
	private void GetData()
	{
		try
		{
			/* we ge the sq id from the ref property */
			/* we are opening the portlet object here because m_ptPortlet uses a 
			 * nullservercontext, which will not allow us to get the object properties */
			IPTGadget ourPortlet = (IPTGadget) this.m_ptSession.GetGadgets().Open(m_nPortletID, false);
			IPTObjectProperties properties = ourPortlet.GetObjectProperties();
			IPTQueryResult result = properties.GetSinglePropertyRefData(PT_INTRINSICS.PT_SNAPSHOT_QUERY_REFERENCE, PT_PROPIDS.PT_PROPID_PROP_VALUE);
			m_nSavSrchID = result.ItemAsInt(0, PT_PROPIDS.PT_PROPID_PROP_VALUE);

			IPTAdminSettings ptAdminSettings = (IPTAdminSettings) m_ptPortlet;

			String[] aSettings = new String[3];
			aSettings[0]     = strTitleKey;
//			aSettings[1]     = strSimpleKey;
//			aSettings[1]     = strSrchIDKey;
			aSettings[1]	 = ADMIN_PREF_PARAMETERIC_PROPS;
			aSettings[2]	 = ADMIN_PREF_DISPLAY_FIELDS;
			

			Object[][] arData = (Object[][]) ptAdminSettings.LookupAdminGadgetSettings(aSettings);

			if (null != arData)
			{
				m_arSearchSettings = new Object[5];
				m_arSearchSettings[DATA_INDEX_SEARCHID] = new Integer(m_nSavSrchID); 

				for (int i = 0; i < arData[0].length; i++)
				{
					String strSettingName = (String) arData[0][i];
					Object oSettingValue = arData[1][i];

					/* we ge the sq id from the ref property */
//					if (XPStringUtility.EqualsIgnoreCase(strSettingName,SavedSearchPortletModel.strSrchIDKey))
//					{
//						m_nSavSrchID     = XPConvert.ToInteger(oSettingValue);
//
//						m_arSearchSettings[DATA_INDEX_SEARCHID] = oSettingValue;
//					}
//					else if (XPStringUtility.EqualsIgnoreCase(strSettingName, SavedSearchPortletModel.strSimpleKey))
//					{
//						// TODO: remove before GA
//						// the following lines allows for backwards compatibility
//						// with the beta version of the admin prefs structure
//						String strValue = XPConvert.ToString(oSettingValue);
//						if (strValue.equals("TRUE"))
//							oSettingValue = new Integer(1);
//						else if (strValue.equals("FALSE"))
//							oSettingValue = new Integer(0);
//						
//						m_arSearchSettings[DATA_INDEX_SIMPLE] = oSettingValue;
//					}
					/*else */
					if (XPStringUtility.EqualsIgnoreCase(strSettingName, SavedSearchPortletModel.strTitleKey))
					{
						m_arSearchSettings[DATA_INDEX_SEARCHTITLE] = oSettingValue;
					}
					else if (XPStringUtility.EqualsIgnoreCase(strSettingName, ADMIN_PREF_PARAMETERIC_PROPS))
					{
					    m_arSearchSettings[DATA_INDEX_PARAMETERICIDS] = oSettingValue;
					}
					else if (XPStringUtility.EqualsIgnoreCase(strSettingName, ADMIN_PREF_DISPLAY_FIELDS))
					{
					    m_arSearchSettings[DATA_INDEX_DISPLAY_FIELDS] = oSettingValue;
					}
				}
			}
		    
		    /* get the PT server objects */
			m_SrchMgr = (IPTSavedSearchManager) m_ptSession.GetSavedSearches();
			IPTSessionInfo si = m_ptSession.GetSessionInfo();
			m_nUserID = si.GetCurrentUserID();
			
			/* set the max results setting */
			m_nMaxResultsCnt = 
			    ((IPTSavedSearch) m_ptSession.GetSavedSearches().Open(m_nSavSrchID, false)).
			    	GetSearchRequest().GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_MAXRESULTS);
			
		}
		catch (Exception e)
		{
			
				log.Error(e, "SavedSearchPortletModel::GetData. " + 
				m_asOwner.GetString(553, "ptmsgs_portalcommonmsgs") + ":" + e.getMessage());
		}
	}

	private String[][] GetDisplayFldsFromAdminPref()
	{
	    String[][] arFieldIDs;
	    
	    String sPref = (String) m_arSearchSettings[DATA_INDEX_DISPLAY_FIELDS];

	    if (null==sPref || 0==sPref.length())
	    {
			log.Warn("SavedSearchPortletModel::GetDisplayFldsFromAdminPref()- Display Fields Admin Prefs not set");
	        arFieldIDs = new String[0][0];
	        
	        return arFieldIDs;
	    }
	    
	    XPStringTokenizer st = new XPStringTokenizer(sPref,",");
	    arFieldIDs = new String[st.GetTokenCount()][2];
	    
		for (int i=0; st.HasMoreElements(); i++) 
		{
		    String sIDandOrient = st.GetNextElement();
		    arFieldIDs[i][0] = XPStringUtility.Substring(sIDandOrient, 0, sIDandOrient.length()-1);
		    arFieldIDs[i][1] = XPStringUtility.Substring(sIDandOrient, sIDandOrient.length()-1);
        }                                                
	    
		return arFieldIDs;
	}

	/**
	 * Helper method to setup date picker objects
	 *
	 */
	private void InitDatePickerObjects()
	{
 		 // Get the user's locale and timezone
		String locale = (String) PTPersonalSettingsHelper.
			GetPersonalSettingValue(PersonalSettingNames.LOCALE, m_asOwner);
		String timezone = (String) PTPersonalSettingsHelper.
			GetPersonalSettingValue(PersonalSettingNames.TIMEZONE, m_asOwner);

		XPLocale xpLocale = null;
		XPTimeZone xpTimeZone = null;

		if (null != locale) 
		{
			xpLocale = new XPLocale(locale);
		} 
		else 
		{
			xpLocale = XPLocale.GetDefault();
		}

		if (null != timezone) 
		{
			xpTimeZone = XPTimeZone.GetTimeZone(timezone);
		}
		else
		{
			xpTimeZone = XPTimeZone.GetCurrentTimeZone();
		}

  		// Initialize the page controls and date/time picker
    	String  strImageServerBaseURL = 
    	    ImgSvrURLHelper.GetInstance().GetRootURL(m_asOwner.GetIsSecuredSpace());
    	
    	m_pageMgr = new PageMgr(
    	        m_asOwner.GetAccessStyle(), 
    	        xpLocale, xpTimeZone, 
    	        strImageServerBaseURL, 
    	        ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		JSRegistry ptJSRegistry = JSRegistry.GetRegistry(
		            strImageServerBaseURL, 
		            ConfigHelper.GetPortalImageServerConnectionURL(m_asOwner));

		m_dtPickerMgr = new JSDateTimePickerMgr(ptJSRegistry, new JSDatePickerVersionMgr(), m_pageMgr);
		
		m_pageMgr.RegisterComponentMgr(m_dtPickerMgr);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Object GetNewTempData()
	{
	    return m_SrchMgr.GetFollowupResults(m_nSavSrchID, m_nUserID, m_nSortID, m_nPaginateFirstIndx-1, m_filter);
	}

	/**
	 * Returns the portlet name
	 *
	 * @return Portlet name
	 */
	public String GetPortletName()
	{
		return m_ptPortlet.GetLocalizedName();
	}

	/**
	 * Returns the Redirect object  (this is were we need to go at the end of
	 * the Editor).
	 *
	 * @return Redirect
	 */
	public Redirect GetRedirectAfterFinish()
	{
		return null;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public IPTSearchResponse GetSearchResponseObject()
	{
	    return (IPTSearchResponse) m_SrchMgr.GetCachedResponse(m_nSavSrchID);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsSubscriptionEnabled()
	{
		return m_SrchMgr.IsSubscribed(m_nSavSrchID, 0);
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public boolean IsUserSubscribed()
	{
		return m_SrchMgr.IsSubscribed(m_nSavSrchID, m_nUserID);
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return 
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
		return RepostControl.PAGE_STATUS_VALID;
	}

	/**
	 * 
	 *
	 * @param nValue 
	 */
	public void SetSubscribe(int nValue)
	{
		switch (nValue)
		{
		case SavedSearchPortletControl.POSTTOSELF_ACTION_SUBSCRIBE:
			m_SrchMgr.AddSubscription(m_nSavSrchID, m_nUserID);

			break;

		case SavedSearchPortletControl.POSTTOSELF_ACTION_UNSUBSCRIBE:
			m_SrchMgr.RemoveSubscription(m_nSavSrchID, m_nUserID);

			break;

		default:}
	}

	public void SetParametericFilter(XPHashtable _htFormData)
	{
	    IPTFilter newFilter = FilterForm.BuildFilterFromForm(m_asOwner, _htFormData, GetDatePickerMgr().GetPreFormDivID());
	    if (null != newFilter)
	    {
	        m_filter = newFilter;
	    }	    
		m_itrFilter.InitFromFilter(m_filter);
	    m_bHasFollowupResults = true;
	}
	
	public void SetSortOrder(int _nSortID)
	{
	    m_nSortID = _nSortID; 
	    m_bHasFollowupResults = true;
	}

	public String GetSortOrder()
	{
	    return XPConvert.ToString(m_nSortID); 
	}

	public IPTSearchResponse GetFollowupResponse()
	{
	    IPTSearchResponse sr = (IPTSearchResponse) GetTempData();
	    
	    m_nPaginateFirstIndx = sr.GetSkipped()+1;
        m_nPaginateSize = sr.GetResultsReturned();
	    m_nPaginateTotal = sr.GetTotalMatches();

	    return sr;
	}

    public int GetTotalMatches()
    {
	    IPTSearchResponse sr = (IPTSearchResponse) GetTempData();
	    
	    return sr.GetTotalMatches();
    }
    
	public boolean HasParametericResults()
	{
	    return m_bHasFollowupResults;
	}
	
	public void ClearParametericResults()
	{
	    m_filter = null;
	    m_nSortID = 0;
	    m_bHasFollowupResults = false;
	    m_nPaginateFirstIndx = 1;
	    m_nPaginateSize = 0;
	    m_nPaginateTotal = 0;
	}

	private boolean isPropertyAccessible(int id)
	{
	    boolean isIntrinsic = (id < PT_SERVERCONSTANTS.PT_MIN_OBJECTID);
        int aclNeeded = (isIntrinsic)? 
        		PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_READ : PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT;
        
        return m_ptSession.GetProperties().IsObjectAccessible(id, m_nUserID, aclNeeded);
	}
	
	public Object[][] GetReturnedPropertyInfo()
	{
	    Object[][] arIDsAndOrient = GetDisplayFldsFromAdminPref();
	    Object[][] arPropInfo = new Object[arIDsAndOrient.length][4];

	    IPTObjectManager ptOM = m_ptSession.GetProperties();
	    for (int i=0; i<arIDsAndOrient.length; i++)
        {
	        int id = XPConvert.ToInteger(arIDsAndOrient[i][0]);
            IPTQueryResult ptQR = ptOM.QuerySingleObject(id);

            if (isPropertyAccessible(id) && (null != ptQR) && (ptQR.RowCount() > 0))
			{
			    arPropInfo[i][PROPINFO_INDEX_TYPE] 		= ptQR.ItemAsObject(0, PT_PROPIDS.PT_PROPID_PROP_VALUETYPE);
			    arPropInfo[i][PROPINFO_INDEX_NAME] 		= ptQR.ItemAsObject(0, PT_PROPIDS.PT_PROPID_NAME);
			    arPropInfo[i][PROPINFO_INDEX_ID] 		= arIDsAndOrient[i][0];
			    arPropInfo[i][PROPINFO_INDEX_ORIENT]	= arIDsAndOrient[i][1];
			}
            else
            {
                log.Warn("Display Property "+arIDsAndOrient[i][0]+" does not exist or is not accessible.");
            }
		}

	    return arPropInfo;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public Redirect ConvertSearchToQueryString()
	{
		IPTSavedSearch ss = (IPTSavedSearch) m_ptSession.GetSavedSearches().Open(m_nSavSrchID, false);
  		IPTSearchQuery sq = ss.GetSearchQuery();
   		IPTSearchRequest sr = ss.GetSearchRequest();
  		IPTFilter filter = (IPTFilter)sq.GetContentAsIPTFilter();
		XPHashtable args = new XPHashtable();

		boolean filterValid = FilterForm.EncodeFilterAsControlArgs(m_ptSession,
				m_asOwner, filter, args);

		// Create a Redirect to the SearchResult space
		Redirect r = new Redirect();
		if (!filterValid)
			return r;

		r.SetLinkCreateNewSpace(SearchResultAS.STR_MVC_CLASS_NAME, m_asOwner);
		r.SetControl(StartSearchControl.STR_MVC_CLASS_NAME);
		r.SetIsHTTPRedirect(true);

		// Add filter arguments
		r.AddControlArguments(args);

		// .. and pass the language on to the search space if need be
		/* bug 24385: we should check the limitByLocale flag to determine if
		 * we should add the required_constraints args.  Checking the language
		 * won't help because when ALlLanguages is set, the value of the 
		 * language is the default locale (many times: 'EN').
		 */
		Object bLimitByLocale = sr.GetSettingsAsObject(
			PT_SEARCH_SETTING.PT_SEARCHSETTING_LIMITBYLOCALE);
		if (XPConvert.ToBoolean(bLimitByLocale))
		{
			String language = sr.GetSettingsAsString(PT_SEARCH_SETTING.PT_SEARCHSETTING_LANGUAGE);

			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_LANGUAGE_S, language);
			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_LIMITBYLOCALE_S, "1");
		}

		r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_MAXRESULTS_S, "10");

		String[] sAdminFolders = null;
		Object[] oAdminFolders = sr.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_ADMINFOLDERS);

		if ((null != oAdminFolders) && (oAdminFolders.length > 0))
		{
			sAdminFolders = new String[oAdminFolders.length];

			for (int i = 0; i < oAdminFolders.length; i++)
			{
				sAdminFolders[i] = XPConvert.ToString(oAdminFolders[i]);
			}

			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ADMINFOLDERS_S, sAdminFolders);
		}

		String[] sCatalogFolders = null;
		Object[] oCatalogFolders = sr.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_DDFOLDERS);

		if ((null != oCatalogFolders) && (oCatalogFolders.length > 0))
		{
			sCatalogFolders = new String[oCatalogFolders.length];

			for (int i = 0; i < oCatalogFolders.length; i++)
			{
				sCatalogFolders[i] = XPConvert.ToString(oCatalogFolders[i]);
			}

			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_DDFOLDERS_S, sCatalogFolders);
		}

		if (0 == sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS))
		{
			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_INCLUDE_SUBFOLDERS_S, "0");
		}

		Object[] arTypes = (Object[]) sr.GetSettingsAsObject1DArray(PT_SEARCH_SETTING.PT_SEARCHSETTING_OBJTYPES);

		if ((null != arTypes) && (arTypes.length > 0))
		{
			String[] strClassIDs = new String[arTypes.length];

			for (int i = 0; i < arTypes.length; i++)
			{
				strClassIDs[i] = XPConvert.ToString(arTypes[i]);
			}

			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_OBJTYPES_S, strClassIDs);
		}

		int iBroadOptions = sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ABSTYPES);

		if (iBroadOptions != 0)
		{
			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ABSTYPES_S, iBroadOptions);
		}

		int iApps = sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_APPS);

		if (iApps != 0)
		{
			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_APPS_S, iApps);
		}
		
		int iOrderProp = sr.GetSettingsAsInt(PT_SEARCH_SETTING.PT_SEARCHSETTING_ORDERBY);

		if (iOrderProp != 0)
		{
			r.AddControlArgument(StartSearchControl.REQUIRED_CONSTRAINT_PREFIX + SearchSettingCollection.PT_SEARCHSETTING_ORDERBY_S, iOrderProp);
		}
		
		return r;
	}
	
    private boolean InitParametericPropObjects() 
    {
        /* check if we have any parameteric properties */
        if (null==m_arSearchSettings[DATA_INDEX_PARAMETERICIDS] ||
            0==XPConvert.ToString(m_arSearchSettings[DATA_INDEX_PARAMETERICIDS]).length())
        {
            return false;
        }
        
        /* ok, we have some set, get each propid and check if the user has access to them */
        XPStringTokenizer tokenizer = new XPStringTokenizer(XPConvert.ToString(m_arSearchSettings[DATA_INDEX_PARAMETERICIDS]), ",");
        IPTObjectManager ptOM = m_ptSession.GetProperties();
        
        XPArrayList ids = new XPArrayList(tokenizer.GetTokenCount());
        XPStringBuilder sbExpectedIDs = new XPStringBuilder(); /* used to keep track of ids we expect to be in the system */
        for (int i=0; tokenizer.HasMoreElements(); i++)
        {
            int id = XPConvert.ToInteger(tokenizer.GetNextElement());
            if (ptOM.IsObjectAccessible(id, m_nUserID, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
            {
                ids.Add(new Integer(id));

                /* record id */
                if (sbExpectedIDs.GetLength()!=0)
                {
                    sbExpectedIDs.Append(",");
                }
                sbExpectedIDs.Append(id);
            }
            else
            {
                log.Warn("User does not have access to parameteric property "+id+".");
            }
        }

        /* did the user have access to any of the props? */
        if (ids.GetSize()==0)
        {
            return false;
        }
        
        /* user has access to some props, use our prepopulated filter or create a 
         * dummy one as initializer */
        m_itrFilter = new FilterIterator(
                m_ptSession, 
                (null==m_filter)? PortalObjectsFactory.CreateSearchFilter() : m_filter, 
                m_asOwner);

        m_itrFilter.SetAllowablePropertyIDs(ids.ToArray());

        if (m_itrFilter.MakeQueryCondition().GetPropInfo().length == 0)
        {
            log.Warn("The following parameteric properties were expected, but not found: "+sbExpectedIDs.ToString());
            return false;
        }
        
		return true;
    }
    
    public FilterIterator GetParametericFilterIterator()
    {
        return m_itrFilter;
    }
    
    public PageMgr GetPageMgr() 
    {
        return m_pageMgr;
    }
    
    public JSDateTimePickerMgr GetDatePickerMgr() 
    {
        return m_dtPickerMgr;
    }
    
    public boolean IsParameterized() 
    {
        return m_bIsParameterized;
    }

    public boolean IsPaginationEnabled()
    {
	    IPTServerConfigSettings ptSC = (IPTServerConfigSettings) m_ptSession.OpenGlobalObject(PT_GLOBALOBJECTS.PT_GLOBAL_SERVERCONFIGSETTINGS, false);
	    return (1==ptSC.GetSettingAsInt(PT_SERVER_CONFIG_SETTINGNAME.PT_CONTENT_SNAPSHOT_PORTLET_MODE));
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPagination#GoToPage(java.lang.String, int, int, java.lang.Object)
     */
    public void GoToPage(String sortOrder, int firstItemOnPage, int pageSize, Object additionalInfo) 
    {
        m_nPaginateFirstIndx = firstItemOnPage;
        m_nPaginateSize = pageSize;
        m_bHasFollowupResults = true;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetFirstDisplayableItem()
     */
    public int GetFirstDisplayableItem() 
    {
        return m_nPaginateFirstIndx;
    }

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetItemsPerPage()
     */
    public int GetItemsPerPage() 
    {
        return m_nMaxResultsCnt;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetNumDisplayableItems()
     */
    public int GetNumDisplayableItems() 
    {
        return m_nPaginateSize;
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.pagination.IPaginationRO#GetTotalItems()
     */
    public int GetTotalItems() 
    {
        return m_nPaginateTotal;
    }
}