package com.plumtree.portalpages.portlets.savedsearch.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.portaluiinfrastructure.tree.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * @author joseq
 *
 * This explist expends the SelectPTObjectModel to include a 5th element to the 
 * data array which holds the orientation of the field (column or row).
 */
public class SavSrchDisplayFieldsListModel extends SelectPTObjectModel implements ISavSrchDisplayFieldsListModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
			OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
			"com.plumtree.portalpages.portlets.savedsearch.prefs.SavSrchDisplayFieldsListModel");

	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SQDisplayFields";

	/**
	 * Number total of columns
	 */
	public static final int EXPLIST_COL_MAX = 5;

	/**
	 * This is the column that holds the display orientation option (column/row)
	 * that we doisplay in the list.
	 */
	public static final int EXPLIST_COL_ORIENTATION = 4;

	public static final String ORIENTATION_ROW = "r";
	public static final String ORIENTATION_COL = "c";
	
	public SavSrchDisplayFieldsListModel()
	{
		super();
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavSrchDisplayFieldsListModel();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}
	
	/**
	 * Initializes the read only expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _arrObjectClassIDs Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeReadOnlySelectPTObject(String _sSectionTitle,
		String _sSectionSubTitle, int[] _arrObjectClassIDs, int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[2][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_STRING);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.TRUE;

		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_ORIENTATION);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = "";
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		m_arrObjectClassIDs = _arrObjectClassIDs;

		super.InitializeReadOnlyExpandableList(_sSectionTitle, arrExpListColInfo, _nListKey);
	}

	/**
	 * Initializes the expandable list.
	 *
	 * @param _sSectionTitle Main title.
	 * @param _sSectionSubTitle Sub title
	 * @param _imgAddIcon Icon for the add action.
	 * @param _sAddLabel Text to display next to the add icon.
	 * @param _arrObjectClassIDs Class ID of the Objects displayed on the list.
	 * @param _nListKey In case you have multiple Expandable Lists on
	 * the same DP, they should have a different key (otherwise, just set it to 1).
	 */
	public void InitializeSelectPTObject(String _sSectionTitle,
		String _sSectionSubTitle, PTImageType _imgAddIcon, String _sAddLabel,
		int[] _arrObjectClassIDs, int _nListKey)
	{
		Object[][] arrExpListColInfo = new Object[2][5];
		arrExpListColInfo[0][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_STRING);
		arrExpListColInfo[0][EXPLIST_COLUMN_TITLE]		    = _sSectionSubTitle;
		arrExpListColInfo[0][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[0][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[0][EXPLIST_COLUMN_ENABLESORT]     = Boolean.TRUE;

		arrExpListColInfo[1][EXPLIST_COLUMN_ID]			    = new Integer(EXPLIST_COL_ORIENTATION);
		arrExpListColInfo[1][EXPLIST_COLUMN_TITLE]		    = "";
		arrExpListColInfo[1][EXPLIST_COLUMN_WIDTH]		    = "100%";
		arrExpListColInfo[1][EXPLIST_COLUMN_COLSPAN]	    = "1";
		arrExpListColInfo[1][EXPLIST_COLUMN_ENABLESORT]     = Boolean.FALSE;

		m_arrObjectClassIDs = _arrObjectClassIDs;

		super.InitializeExpandableList(_sSectionTitle, arrExpListColInfo,
			_imgAddIcon, _sAddLabel, _nListKey);
	}

	/**
	 * Initalizes the list (PTGrowableSortedArrayWrapper)
	 * with a column mapping and an array of sort.
	 * The growable array will always be sorted by the 1st
	 * column ascending.
	 *
	 * @param _saData
	 */
	public void InitializeSortedArray(PTGrowableSortedArrayWrapper _saData)
	{
		// JF- Column mapping
		int[] arrColumns = new int[]
			{
				EXPLIST_SORTEDARRAY_PROPID_INDEX, EXPLIST_COL_CLASSID,
				EXPLIST_COL_OBJECTID, EXPLIST_COL_STRING, EXPLIST_COL_ORIENTATION
			};

		// JF- Sort array
		// The growable array will always be sorted by the String column (the one displayed).
		int[][] arrSort = new int[1][2];
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_PROPID]		  = EXPLIST_COL_STRING;
		arrSort[0][PTSortedArrayWrapper.PTSAW_SORT_ROW_DIRECTION]     = PTSortedArrayWrapper.PTSAW_SORT_ASCENDING;

		// JF- We don't initalize the list itself (null below)
		// At first it's empty and we will be initalized if needed using the 
		// AddRowsToList method.
		_saData.Initialize(arrColumns, null, arrSort, true,
			EXPLIST_DEFAULT_INITIAL_SIZE);
	}

	/**
	 * Clear the list and add all the values from the tree.
	 *
	 * @param _htFormData Form data
	 */
	public void AddRowsOnRepost(XPHashtable _htFormData)
	{
		if (!m_bIsReadOnly)
		{
			SaveTreeID(_htFormData);

			TreeAS asTree = (TreeAS) m_asOwner.GetSubSpace(GetUniqueString(
						SUBSPACE_KEY_SELECTTREE));

			if (null != asTree)
			{
				ITreeModelRO myTree    = (ITreeModelRO) asTree.GetModel(ATreeAS.TREEMODEL);
				XPArrayList mySelected = myTree.GetSelectedItems();
				int nClassID;
				int nObjectID;
				int nIndex;
				String sOrientation;
				
				// JF- Before we clear the items and get the brand new list from the tree, we want to keep a copy of the indexes.
				// If the move row actions are enabled, we need to keep the same indexes for Objects already in the list. 
				// We need to keep the order for existing Objects and add the new ones at the end.
				Object[][] arrIndexMapping = CreateIndexMapping(GetItems());

				Object[][] oNewRows = new Object[mySelected.GetSize()][EXPLIST_COL_MAX];
				for (int i = 0; i < mySelected.GetSize(); i++)
				{
					nClassID	  = ((TreeLeafNode) mySelected.GetElement(i)).m_nClassID;
					nObjectID     = ((TreeLeafNode) mySelected.GetElement(i)).m_nObjectID;
					nIndex		  = GetIndex(arrIndexMapping, nClassID, nObjectID);

					if (-1 == nIndex)
					{
						nIndex = m_nNextIndex;
						m_nNextIndex++;
						sOrientation = ORIENTATION_COL;
					}
					else
					{
					    try
					    {
					        sOrientation = XPConvert.ToString(super.GetItems().GetItem(nIndex,EXPLIST_COL_ORIENTATION));
					    }
					    catch (Exception e)
					    {
					        sOrientation = ORIENTATION_COL;
					    }
					}

//					oNewRow										  = new Object[EXPLIST_COL_MAX];
					oNewRows[i][EXPLIST_SORTEDARRAY_PROPID_INDEX]  = new Integer(nIndex);
					oNewRows[i][EXPLIST_COL_CLASSID]				  = new Integer(nClassID);
					oNewRows[i][EXPLIST_COL_OBJECTID]			  = new Integer(nObjectID);
					oNewRows[i][EXPLIST_COL_ORIENTATION]			  = sOrientation;

					if (PT_CLASSIDS.PT_CATALOGFOLDER_ID == nClassID)
					{
						oNewRows[i][EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).m_strLocation;
					}
					else
					{
						oNewRows[i][EXPLIST_COL_STRING] = ((TreeLeafNode) mySelected.GetElement(i)).GetName();
					}

//					super.GetItems().AddRow(oNewRow);
				}

				// JF- We clear the array before we start adding the selected items from the tree.
				super.GetItems().ClearArray();
				super.GetItems().AddRows(oNewRows);
			}
		}
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.expandablelist.ExpListModel#ModifyRow(com.plumtree.openfoundation.util.XPHashtable)
     */
    public void ModifyRow(XPHashtable _htFormData) 
    {
		int nRowIndex = GetRowIndex(_htFormData);
		try
		{
			super.GetItems().SetItem(nRowIndex, EXPLIST_COL_ORIENTATION, GetOrientation(_htFormData, nRowIndex));
		}
		catch (Exception e)
		{
			log.Error("SavSrchDisplayFieldsListModel::ModifyRow An exception occured" + " when trying to modify the row: " + nRowIndex + ". " + e);
		}
    }
    
    /* (non-Javadoc)
     * @see com.plumtree.portalpages.portlets.savedsearch.prefs.ISavSrchDisplayListModelRO#IsOrientationRow(int)
     */
    public boolean IsOrientationRow(int _iRowIndex) 
    {
		String sOrientaton = (String) super.GetItems().GetItem(_iRowIndex, EXPLIST_COL_ORIENTATION);
		
		return XPStringUtility.EqualsIgnoreCase(sOrientaton, ORIENTATION_ROW);
    }

    /**
	 * Helper method to retrieve the row index from the form data.
	 *
	 * @param _htFormData
	 *
	 * @return int
	 */
	private String GetOrientation(XPHashtable _htFormData, int _nRowIndex)
	{
		String sDataKey = GetUniqueString(SavSrchDisplayFieldsListView.HTMLINPUT_ORIENTATION+_nRowIndex);
		String[] aDataValue = (String[]) _htFormData.GetElement(sDataKey);

		return aDataValue[0];
	}
}