package com.plumtree.portalpages.portlets.savedsearch.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.editor.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.xpshared.htmlconstructs.*;
import com.plumtree.xpshared.htmlelements.*;

/**
 * @author joseq
 *
 * Expandable List that continues properties (used in snapshot qrys).  This extends SelectPTObjectView
 * in that is adds an Orientation (Column or Row) option on each row. 
 */
public class SavSrchDisplayFieldsListView extends SelectPTObjectView 
{
	/**
	 * Class name for the activity space */
	public static final String STR_MVC_CLASS_NAME = "SQDisplayFields";

	/**
	 * HTML Object name: Field Orientation */
	public static final String HTMLINPUT_ORIENTATION   = "in_ra_Orientation";


	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavSrchDisplayFieldsListView();
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

    /* (non-Javadoc)
     * @see com.plumtree.uiinfrastructure.activityspace.IView#DisplayJavascript()
     */
    public HTMLScript DisplayJavascript() 
    {
		HTMLScript myScript = super.DisplayJavascript();
        
		XPStringBuilder sb;
		
		
		// JavaScript to set orientation			
		sb = new XPStringBuilder(300);
		sb.Append("function " +
			((IExpListModelRO) m_model).GetUniqueString("SetOrientation") +
			"(varRowIndex)\n");
		sb.Append("{\n");
		sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
			((IExpListModelRO) m_model).GetUniqueString(
				HTMLHIDDEN_ROWINDEX) + ".value= varRowIndex;\n");
//		sb.Append("  document." + EditorDP.HTMLFORM_NAME + "." +
//			((IExpListModelRO) m_model).GetUniqueString(
//				HTMLHIDDEN_MOVEACTION) + ".value= varMoveAction;\n");
		sb.Append("  postToSelf('" +
			((IExpListModelRO) m_model).GetUniqueInt(
				ExpListControl.POSTTOSELF_ACTION_MODIFYROW) + "');\n");
		sb.Append("}\n");

		myScript.AddInnerHTMLString(sb.ToString());

		return myScript;
    }
    
	/**
	 * Returns the HTML for the row _nRowIndex.
	 * Each row contains just an icon and input text.
	 *
	 * @param _saData
	 * @param _nRowIndex
	 *
	 * @return HTMLElement
	 * @throws Exception
	 */
	public HTMLElement GetHTMLForRow(IPTGrowableSortedArrayWrapperRO _saData,
		int _nRowIndex)
	{
		HTMLElementCollection result = new HTMLElementCollection();
		result.AddInnerHTMLElement(GetHTMLForNameColumn(_saData, _nRowIndex));

		/* field orientation html */
		result.AddInnerHTMLElement(GetHTMLForOrientationRadio(_nRowIndex));
		
		if (((ISelectPTObjectModelRO) m_model).GetEnableMoveRowActions())
		{
			result.AddInnerHTMLElement(super.GetHTMLForMoveRowActions(
					_nRowIndex));
		}

		return result;
	}
	
	/**
	 * Helper method for empty cell between actions
	 * in the action bar.
	 *
	 * @return HTMLTableCell
	 */
	private HTMLTableCell GetHTMLForOrientationRadio(int _nRowIndex)
	{
		HTMLTableCell myCell = new HTMLTableCell();

		if (1 < ((IExpListModelRO) m_model).GetReadOnlyItems().GetCount())
		{
			PTConstruct myConstruct;
			HTMLImg myImage;
			HTMLAnchor myAnchor;
			HTMLInput myInput;
			HTMLSpan mySpan;
			
			// We are building an HTML Cell with the 2 radios: column, row
			myCell.SetAlign("right");
			myCell.SetVAlign("middle");
			myCell.SetStyleClass(PTStyleClass.LIST_TEXT);
			myCell.SetNoWrap(true);
			myCell.AddInnerHTMLString(SPACE);
			
			/* orientation == col radio */
			myInput = new HTMLInput(
			        HTMLInputTypes.RADIO_TYPE,
			        ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_ORIENTATION+_nRowIndex), 
			        "");
			myInput.SetChecked(!((ISavSrchDisplayFieldsListModelRO) m_model).IsOrientationRow(_nRowIndex));
			myInput.SetValue(SavSrchDisplayFieldsListModel.ORIENTATION_COL);
			myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("SetOrientation")+"('"+_nRowIndex+"')");
			myCell.AddInnerHTMLElement(myInput);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(66, ResourceConstants.PORTLETSMSGS));

			/* orientation == row radio */
			myInput = new HTMLInput(
			        HTMLInputTypes.RADIO_TYPE,
			        ((IExpListModelRO) m_model).GetUniqueString(HTMLINPUT_ORIENTATION+_nRowIndex), 
			        "");
			myInput.SetChecked(((ISavSrchDisplayFieldsListModelRO) m_model).IsOrientationRow(_nRowIndex));
			myInput.SetValue(SavSrchDisplayFieldsListModel.ORIENTATION_ROW);
			myInput.SetOnClick(((IExpListModelRO) m_model).GetUniqueString("SetOrientation")+"('"+_nRowIndex+"')");
			myCell.AddInnerHTMLElement(myInput);

			mySpan = new HTMLSpan();
			myCell.AddInnerHTMLElement(mySpan);
			mySpan.SetStyleClass(PTStyleClass.FORM_RADIO);
			mySpan.AddInnerHTMLString(m_asOwner.GetString(67, ResourceConstants.PORTLETSMSGS));

			myCell.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLString(SPACE);
			myCell.AddInnerHTMLString(SPACE);
		}

		myCell.AddInnerHTMLString(SPACE);

		return myCell;
	}
}