package com.plumtree.portalpages.portlets.savedsearch.prefs;

import com.plumtree.portalpages.portlets.savedsearch.*;
import com.plumtree.portaluiinfrastructure.editor.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.expandablelist.*;

/**
 * Activity space for intrinsic portlet. The name of this activity space must
 * be the name of the portlet model + "Prefs".
 *
 * @author mikes
 */
public class SavedSearchPortletPrefsEditorAS extends PTEditorAS
{
	/**
	 * SavedSearchPortletPrefs. For intrinsic portlets, the name of the activity
	 * space is the same as the name of the model plus the suffix "Prefs".
	 */
	public static final String STR_MVC_CLASS_NAME = SavedSearchPortletModel.STR_MVC_CLASS_NAME + IntrinsicPortletPrefsUtils.PREFS_SUFFIX;

	/**
	 * ExpList model displaying which properties to display in a portlet.
	 */
	public static final String STR_MVC_SELECT_DISPLAY_FIELDS = "SelectDisplayFieldsEditor"+ IntrinsicPortletPrefsUtils.PREFS_SUFFIX;
	
	/**
	 * ExpList model displaying which properties to display in a portlet.
	 */
	public static final String STR_MVC_SELECT_PARAMETRIC_FIELDS = "SelectParametericFieldsEditor"+ IntrinsicPortletPrefsUtils.PREFS_SUFFIX;
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavedSearchPortletPrefsEditorAS();
	}

	/**
	 * Returns the Editor title.
	 *
	 * @return String
	 */
	public String GetEditorTitle()
	{
		return GetString(473, "ptmsgs_portalcommonmsgs");
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * Returns the class name of the Property Repost Control.
	 *
	 * @return String
	 */
	public String GetRepostControlName()
	{
		return (SavedSearchPortletPrefsRepostControl.STR_MVC_CLASS_NAME);
	}

	/**
	 * Registers all the classes of the Property Activity Space.
	 */
	public void Init()
	{
		m_strModelName = SavedSearchPortletPrefsModel.STR_MVC_CLASS_NAME;

		// Warning: m_strModelName must be initialized before super.Init() is called.
		super.Init();

		IModel myModel = GetModel(SavedSearchPortletPrefsModel.STR_MVC_CLASS_NAME);

		RegisterPage(new SavedSearchPortletPrefsDP());
		RegisterView(SavedSearchPortletAdminPrefsView.STR_MVC_CLASS_NAME, myModel);
		RegisterControl(SavedSearchPortletPrefsRepostControl.STR_MVC_CLASS_NAME, myModel);

		//****** Register classes for display fields selector
		RegisterModel(SavSrchDisplayFieldsListModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_FIELDS);
		
		IModel myDisplayFieldsSelectModel = GetModel(STR_MVC_SELECT_DISPLAY_FIELDS);
		RegisterView(SavSrchDisplayFieldsListView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_FIELDS, myDisplayFieldsSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_DISPLAY_FIELDS, myDisplayFieldsSelectModel);

		//****** Register classes for display fields selector
		RegisterModel(SelectPTObjectModel.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PARAMETRIC_FIELDS);
		
		IModel myParametericFieldsSelectModel = GetModel(STR_MVC_SELECT_PARAMETRIC_FIELDS);
		RegisterView(SelectPTObjectView.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PARAMETRIC_FIELDS, myParametericFieldsSelectModel);
		RegisterControl(ExpListControl.STR_MVC_CLASS_NAME, STR_MVC_SELECT_PARAMETRIC_FIELDS, myParametericFieldsSelectModel);
				
		SetCurrentPage(SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME);

		//Sets left nav menu
		int nMenuOneID = m_mEditorMenu.StartNewSubMenu(GetString(472, "ptmsgs_portalcommonmsgs"));
		m_mEditorMenu.AddLinkToSubMenu(nMenuOneID, SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME);
	}
	
	
	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.AActivitySpace#SetCurrentPage()
	 *
	 * @param IDisplayPage the current Display Page
	 */
	public void SetCurrentPage(IDisplayPage page) 
	{
		super.SetCurrentPage( page );
	
	    String sPageName = page.GetName();
	
		if (SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME.equals(sPageName)) 
		{
		  this.SetHelpTopic( "PT_AdminPrefs_SnapshotPortlet" );
		}
	}
}