package com.plumtree.portalpages.portlets.savedsearch.prefs;

import com.plumtree.openfoundation.util.*;
import com.plumtree.openlog.*;
import com.plumtree.portalpages.admin.editors.savedsearch.*;
import com.plumtree.portalpages.common.constants.*;
import com.plumtree.portalpages.portlets.savedsearch.*;
import com.plumtree.portaluiinfrastructure.expandablelist.selectptobject.*;
import com.plumtree.portaluiinfrastructure.intrinsicportlets.prefs.*;
import com.plumtree.portaluiinfrastructure.statichelpers.*;
import com.plumtree.server.*;
import com.plumtree.uiinfrastructure.activityspace.*;
import com.plumtree.uiinfrastructure.arraywrapper.*;
import com.plumtree.uiinfrastructure.errordisplay.*;
import com.plumtree.uiinfrastructure.expandablelist.*;
import com.plumtree.uiinfrastructure.form.*;
import com.plumtree.uiinfrastructure.tree.*;
import com.plumtree.xpshared.htmlconstructs.*;

/**
 * Intrinsic portlet prefs model, which extends the
 * IntrinsicPortletPrefsEditorModel, uses the editor framework.
 *
 * @author mikes
 */
public class SavedSearchPortletPrefsModel extends IntrinsicPortletPrefsEditorModel implements ISavedSearchPortletPrefsModelRO
{
	private static OpenLogger log = OpenLogService.GetLogger(
		OpenLogService.GetComponent(PTDebugHelpers.COMPONENT_PORTAL_PORTLETS),
		"com.plumtree.portalpages.portlets.savedsearch.prefs.SavedSearchPortletPrefsModel");

	/** SavedSearchPortletPrefs */
	public static final String STR_MVC_CLASS_NAME = "SavedSearchPortletPrefs";

	
	protected int m_nSavSrchID;

	
	protected String m_strSavSrchName;

	
//	protected boolean m_bSimple;

	
	protected String m_strTitle;
	
	
	public String m_strLastTreeSpaceId = null;

	
	public final String _ui_NoTitle = "<no title>"; //TODO: Move this to xml

	/**
	 * Saved search ID on repost.
	 */
	public void ChangeSavedSearchIDOnRepost()
	{
		if (m_asOwner.GetSubSpaceExists(SavedSearchPortletAdminPrefsView.JAVASCRIPT_SAVSRCHTREE))
		{
			ATreeAS asFolderTree = (ATreeAS) m_asOwner.GetSubSpace(SavedSearchPortletAdminPrefsView.JAVASCRIPT_SAVSRCHTREE);
			ITreeModelRO myTree = (ITreeModelRO) asFolderTree.GetModel(ATreeAS.TREEMODEL);
			XPArrayList mySelected = myTree.GetSelectedItems();

			if ((null != mySelected) && (mySelected.GetSize() > 0))
			{
				TreeLeafNode node = (TreeLeafNode) mySelected.GetElement(0);

				SetSavSrchID(node.m_nObjectID, false);
				SetSavSrchName(node.GetName());
				InitializeDisplayFieldsExpList();
			}
		}
	}

	/**
	 * @see com.plumtree.uiinfrastructure.activityspace.IManagedObject#Create()
	 */
	public Object Create()
	{
		return new SavedSearchPortletPrefsModel();
	}

	/**
	 * Load ADMIN settings on start of editor
	 * @see com.plumtree.uiinfrastructure.editor.EditorModel#DoTaskOnStartEditor(XPHashtable)
	 */
	public void DoTaskOnStartEditor(XPHashtable _htFormData)
	{
		m_nSavSrchID     = 0;
//		m_bSimple		 = true;
		m_strTitle		 = _ui_NoTitle;


		Object[][] arSettings = GetSettingValues(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, null);

		if (null != arSettings)
		{
			for (int i = 0; i < arSettings[0].length; i++)
			{
				String strSettingName = (String) arSettings[0][i];
				Object oSettingValue = arSettings[1][i];

//				if (strSettingName.equals(SavedSearchPortletModel.strSrchIDKey))
//				{
//					SetSavSrchID(XPConvert.ToInteger(oSettingValue), true);
//				}
//				else if (strSettingName.equals(SavedSearchPortletModel.strSimpleKey))
//				{
//					SetSimple(XPConvert.ToBoolean(XPConvert.ToInteger(oSettingValue)));
//				}
				/*else*/ if (strSettingName.equals(SavedSearchPortletModel.strTitleKey))
				{
					SetTitle(XPConvert.ToString(oSettingValue));
				}
			}
			
			IPTObjectProperties properties = m_ptPortlet.GetObjectProperties();
			IPTQueryResult result = properties.GetSinglePropertyRefData(PT_INTRINSICS.PT_SNAPSHOT_QUERY_REFERENCE, PT_PROPIDS.PT_PROPID_PROP_VALUE);
			SetSavSrchID(result.ItemAsInt(0, PT_PROPIDS.PT_PROPID_PROP_VALUE), true);
		}
		else 
		{
		    /* TODO:jhq- we are removing the ability to directly create this 
		     * portlet via SQ editor.  instead, that editor will create the portlet
		     * silently and then add it to an exp list of portlets.  The portlet can 
		     * then be edited by clicking on a link.  therefore, the admin prefs should
		     * already exist and this code should never run.  consider removing it.
		     * 
		     * This portlet can be created from the Snapshot Query Editor.
		     * In the case where it is, we go thru a couple of parent activityspaces
		     * to get here:
		     * 1) Prefs AS (this AS) is opened from
		     * 2) Portlet AS (parent) which is opened from
		     * 3) Snapshot Query AS (grandparent)
		     * 
		     * In the code below we attempt to get the parent AS (PortletAS) and then 
		     * it's parent (SnapshotAS) in an attempt to get the SavedSearchModel, which
		     * can tell us what the ObjectID of the query is.  We want to prepopulate the 
		     * ID.
		     */
		    AActivitySpace parent = m_asOwner.GetParentSpace();
		    if (null!=parent && null!=(parent=parent.GetParentSpace()))
		    {
			    IModelRO oModel = parent.GetModel(SavedSearchModel.STR_MVC_CLASS_NAME);
			    if (null!=oModel)
			    {
			        SetSavSrchID(((ISavedSearchModelRO) oModel).GetObjectID(), true);
			    }
		    }
		}
		
		//***** initialize display fields picker
	    InitializeDisplayFieldsExpList();
		
		//***** initialize parameterized properties picker
	    InitializeParametericFieldsExpList();
	}

	/**
	 * Save ADMIN settings on finish of editor.
	 */
	public void Finish()
	{
//		SetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, 
//		        SavedSearchPortletModel.strSrchIDKey, new Integer(GetSavSrchID()));
//		SetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, 
//		        SavedSearchPortletModel.strSimpleKey, GetSimple() ? "1" : "0");
		SetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, 
		        SavedSearchPortletModel.strTitleKey, GetTitle());
		SetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN,
                SavedSearchPortletModel.ADMIN_PREF_DISPLAY_FIELDS, GetDisplayFldsAndOrientFromExpList());
		SetSettingValue(IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN,
                SavedSearchPortletModel.ADMIN_PREF_PARAMETERIC_PROPS, GetParametericFieldsFromExpList());


		/* set the snapshot query ref property */
		IPTObjectProperties properties = m_ptPortlet.GetObjectProperties();
		Object[][] propdata = new Object[2][1];
		propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_PROPERTYID][0] = new Integer(PT_INTRINSICS.PT_SNAPSHOT_QUERY_REFERENCE);
		propdata[PT_EDIT_PROPDATA_COLUMNS.PT_EDIT_PROPDATA_VALUE][0] = new Integer(GetSavSrchID());
		properties.SetPropertyRefData(propdata);
	}

	/**
	 * Returns the Class name.
	 *
	 * @return String
	 */
	public String GetName()
	{
		return STR_MVC_CLASS_NAME;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public int GetSavSrchID()
	{
		return m_nSavSrchID;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetSavSrchName()
	{
		return m_strSavSrchName;
	}

	/**
	 * 
	 * @return 
	 * 
	 * @deprecated presentation style is no longer used.  This method will always return false.
	 */
	public boolean GetSimple()
	{
//		return m_bSimple;
	    return false;
	}

	/**
	 * 
	 *
	 * @return 
	 * 
	 * 
	 */
	public String GetTitle()
	{
		return m_strTitle;
	}

	/**
	 * 
	 *
	 * @return 
	 */
	public String GetLastTreeSpaceId()
	{
		return m_strLastTreeSpaceId;
	}

	/**
	 * Calls the right save function according to the page name passed in
	 * argument.
	 *
	 * @param _sPageName
	 * @param _htFormData
	 *
	 * @return int Page status for server side validation
	 */
	public int SavePage(String _sPageName, XPHashtable _htFormData)
	{
	    int status = RepostControl.PAGE_STATUS_VALID;
	    
		if (_sPageName.equals(SavedSearchPortletPrefsDP.STR_MVC_CLASS_NAME))
		{
			SaveMainPage(_htFormData);
		}

		if (RepostControl.PAGE_STATUS_INVALID == CheckDisplayFieldsInExpList())
		{
		    status = RepostControl.PAGE_STATUS_INVALID;
		}
		
		return status;
	}

	/**
	 * Sets a new value for the member variable "SavSrchID".
	 *
	 * @param _SavSrchID
	 */
	public void SetSavSrchID(int _nSavSrchID, boolean _bLookupName)
	{
		m_nSavSrchID     = _nSavSrchID;

		if (_bLookupName)
		{
			IPTQueryResult qr = m_ptSession.GetSavedSearches().QuerySingleObject(_nSavSrchID);

			if ((null != qr) && (qr.RowCount() > 0))
			{
				m_strSavSrchName = qr.ItemAsString(0, PT_PROPIDS.PT_PROPID_NAME);
			}
		}

		
			log.Debug("SavedSearchPortletPrefsModel::SetSavSrchID New value: " + _nSavSrchID);
		
	}

	/**
	 * 
	 * @param _bSimple
	 * 
	 * @deprecated presentation style is no longer used.  This method doesn't do anything. 
	 */
	public void SetSimple(boolean _bSimple)
	{
//		m_bSimple = _bSimple;

		
//			log.Debug("SavedSearchPortletPrefsModel::SetSimple New value: " + XPConvert.ToString(_bSimple));
		
	}

	/**
	 * Sets a new value for the member variable "Title".
	 *
	 * @param _Title
	 */
	public void SetTitle(String _Title)
	{
		m_strTitle = _Title;

		
			log.Debug("SavedSearchPortletPrefsModel::SetTitle New value: " + _Title);
		
	}

	/**
	 * 
	 *
	 * @param strName 
	 */
	public void SetSavSrchName(String strName)
	{
		m_strSavSrchName = strName;
	}

	/**
	 * Saves the data on the Main page.
	 *
	 * @param _htFormData
	 */
	protected void SaveMainPage(XPHashtable _htFormData)
	{
		String[] savspc = (String[]) _htFormData.GetElement(SavedSearchPortletAdminPrefsView.HTMLHIDDEN_SAVSRCHSPACEID);

		if ((null != savspc) && !(0 == savspc.length))
		{
			m_strLastTreeSpaceId = savspc[0];
		}

		String[] data;

		// Saving SavSrchID
		data = (String[]) _htFormData.GetElement(SavedSearchPortletAdminPrefsView.HTMLINPUT_SAVSRCHID);

		if ((null != data) && !(0 == data.length))
		{
			boolean bLookupName = !data[0].equals(m_strSavSrchName);

			SetSavSrchID(XPConvert.ToInteger(data[0]), bLookupName);
		}
		else
		{
			log.Warn("SavedSearchPortletPrefsModel::SaveMainPage SavSrchID parameter was not in Query String.");
		}

//		// Saving Simple
//		data = (String[]) _htFormData.GetElement(SavedSearchPortletAdminPrefsView.HTMLINPUT_SIMPLE);
//
//		if ((null != data) && !(0 == data.length))
//		{
//			SetSimple(XPConvert.ToBoolean(data[0]));
//		}
//		else
//		{
//			
//				log.Warn("SavedSearchPortletPrefsModel::SaveMainPage Simple parameter was not in Query String.");
//			
//		}
	}
	

	public int CheckDisplayFieldsInExpList()
	{
		/* check our display fields list for bad property ids that may be lingering around. */
		SelectPTObjectModel mySelectDisplayFieldsModel = (SelectPTObjectModel) m_asOwner
				.GetModel(SavedSearchPortletPrefsEditorAS.STR_MVC_SELECT_DISPLAY_FIELDS);

		String sDisplayableProps = "," + GetDisplayFieldsFromQuery() + ",";
		PTGrowableSortedArrayWrapper arItems = mySelectDisplayFieldsModel.GetItems();
		XPStringBuilder sbBadFields = new XPStringBuilder();

	    XPStringBuilder sbClsidAndObjid = new XPStringBuilder();
	    sbClsidAndObjid.Append(",").Append(PT_CLASSIDS.PT_PROPERTY_ID).Append(",");
	    int nPos = sbClsidAndObjid.GetLength();
	    
		/* loop thru our items and if we find an id that is not displayable, mark it */
		for (int i=0; i<arItems.GetCount(); i++)
	    {
			Object id = arItems.GetItem(i, SelectPTObjectModel.EXPLIST_COL_OBJECTID);

			sbClsidAndObjid.Replace(nPos,sbClsidAndObjid.GetLength(),XPConvert.ToString(id)).Append(",");
			if (-1==XPStringUtility.IndexOf(sDisplayableProps,sbClsidAndObjid.ToString()))
			{
				Object name = arItems.GetItem(i, SelectPTObjectModel.EXPLIST_COL_STRING);
			    sbBadFields.Append(name).Append(", ");
			}
	    }

		/* raise an error. this error is actually ok. the portlet won't display the property. 
		 * however, i suppose (re: someone filed a bug) that we dissuade users from editing the 
		 * portlet prefs if the qry is out of sync. */
	    if (0 < sbBadFields.GetLength())
	    {
	        UIError errBadDisplayFields = new UIError(UIErrorLevel.SERIOUS,
	                UIErrorScope.CURRENT_USER, 
	                m_asOwner.GetString(58, ResourceConstants.PORTLETSMSGS)+
	                	sbBadFields.Substring(0,sbBadFields.GetLength()-2),
	                "Snapshot Query ID "+m_nSavSrchID+" may have been modifed.  This portlet should either be modified to conform to the query or the query needs to modified.");
	        
	        UIErrorHandler.RaiseError(errBadDisplayFields, 
	                m_asOwner.GetSubSession(), 
	                m_asOwner.GetApplication());
	        
	        return RepostControl.PAGE_STATUS_INVALID;
	    }
	    
	    return RepostControl.PAGE_STATUS_VALID;
	}
	
	private void InitializeParametericFieldsExpList()
	{
		SelectPTObjectModel mySelectParametericFieldsModel = (SelectPTObjectModel) m_asOwner.GetModel(SavedSearchPortletPrefsEditorAS.STR_MVC_SELECT_PARAMETRIC_FIELDS);
		mySelectParametericFieldsModel.InitializeSelectPTObject(
		        m_asOwner.GetString(62, ResourceConstants.PORTLETSMSGS), 
		    	m_asOwner.GetString(62, ResourceConstants.PORTLETSMSGS), 
	        	PTImageType.ICON_PROPERTY, 
	        	m_asOwner.GetString(63, ResourceConstants.PORTLETSMSGS), 
	        	new int[]{PT_CLASSIDS.PT_PROPERTY_ID}, 
	        	2);

		mySelectParametericFieldsModel.SetTableInstructions(m_asOwner.GetString(64, ResourceConstants.PORTLETSMSGS));
		mySelectParametericFieldsModel.SetTreeTitle(m_asOwner.GetString(62, ResourceConstants.PORTLETSMSGS));
		mySelectParametericFieldsModel.SetTreeSubTitle(m_asOwner.GetString(63, ResourceConstants.PORTLETSMSGS));
		mySelectParametericFieldsModel.SetDefaultRowIcon(PTImageType.ICON_PROPERTY); 

		mySelectParametericFieldsModel.SetEmptyListMessages(
		        m_asOwner.GetString(60, ResourceConstants.PORTLETSMSGS),
		        m_asOwner.GetString(61, ResourceConstants.PORTLETSMSGS));

		mySelectParametericFieldsModel.SetEnableMoveRowActions(false);

		/* only show properties that are searchable */
		String sSearchableProps = GetSearchableProperties();
		
		if (0<sSearchableProps.length())
		{
		    mySelectParametericFieldsModel.SetDisplayObjects(sSearchableProps);
		}
		else
		{
		    mySelectParametericFieldsModel.DisableAddButton();
		}

		
		// **************  populate parameterized fields list
	    String sParametericFlds = (String) GetSettingValue(
	            IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, 
	            SavedSearchPortletModel.ADMIN_PREF_PARAMETERIC_PROPS);

		if (null != sParametericFlds)
		{
		    XPStringTokenizer st = new XPStringTokenizer(sParametericFlds,",");
		    Object[][] arFields = new Object[st.GetTokenCount()][SelectPTObjectModel.EXPLIST_COL_MAX];
		    
			for (int i=0; st.HasMoreElements(); i++)
		    {
				Object id = st.GetNextElement();

				//TODO: jhq error check
				IPTProperty prop = null;
				try
				{
				    prop = (IPTProperty) m_ptSession.GetProperties().Open(XPConvert.ToInteger(id),false);
				}
				catch (Exception e)
				{
				    log.Warn("Parameteric property "+id+" does not exist or is not accessible.");
				}

				Object name;
				if (null!=prop)
				{
					name = prop.GetLocalizedName();
				}
				else
				{
				    name = id;
				}

				arFields[i][SelectPTObjectModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectParametericFieldsModel.m_nNextIndex);
				mySelectParametericFieldsModel.m_nNextIndex++;

				arFields[i][SelectPTObjectModel.EXPLIST_COL_CLASSID] 		= new Integer(PT_CLASSIDS.PT_PROPERTY_ID);
				arFields[i][SelectPTObjectModel.EXPLIST_COL_OBJECTID]		= id;
				arFields[i][SelectPTObjectModel.EXPLIST_COL_STRING]  		= name;
		    }

			mySelectParametericFieldsModel.SetDefaultObjects(arFields);
		}
	}

	private void InitializeDisplayFieldsExpList()
	{
	    SavSrchDisplayFieldsListModel mySelectDisplayFieldsModel = (SavSrchDisplayFieldsListModel) m_asOwner
			.GetModel(SavedSearchPortletPrefsEditorAS.STR_MVC_SELECT_DISPLAY_FIELDS);
		
		mySelectDisplayFieldsModel.InitializeSelectPTObject(
		    m_asOwner.GetString(55, ResourceConstants.PORTLETSMSGS), 
		    m_asOwner.GetString(55, ResourceConstants.PORTLETSMSGS), 
	        PTImageType.ICON_PROPERTY, 
	        m_asOwner.GetString(56, ResourceConstants.PORTLETSMSGS), 
	        new int[]{PT_CLASSIDS.PT_PROPERTY_ID}, 
	        1);

		mySelectDisplayFieldsModel.SetDefaultRowIcon(PTImageType.ICON_PROPERTY); 
		mySelectDisplayFieldsModel.SetEnableMoveRowActions(true);

		mySelectDisplayFieldsModel.SetTreeTitle(m_asOwner.GetString(55, ResourceConstants.PORTLETSMSGS));
		mySelectDisplayFieldsModel.SetTreeSubTitle(m_asOwner.GetString(56, ResourceConstants.PORTLETSMSGS));
		
		/* only show properties that are returned from query */
		String sDisplayableProps = GetDisplayFieldsFromQuery();
		if (0<sDisplayableProps.length())
		{
		    mySelectDisplayFieldsModel.SetDisplayObjects(sDisplayableProps);

			mySelectDisplayFieldsModel.SetTableInstructions(m_asOwner.GetString(57, ResourceConstants.PORTLETSMSGS));
			mySelectDisplayFieldsModel.SetEmptyListMessages(
				    m_asOwner.GetString(59, ResourceConstants.PORTLETSMSGS),
				    m_asOwner.GetString(72, ResourceConstants.PORTLETSMSGS));
		}
		else
		{
		    mySelectDisplayFieldsModel.DisableAddButton();

		    mySelectDisplayFieldsModel.SetTableInstructions(m_asOwner.GetString(73, ResourceConstants.PORTLETSMSGS));
		}
		
		
		// **************  populate display fields list
		/* what we are going to do is get an array of property ids
		 * that were stored as admin prefs.  these ids will be checked
		 * against the properties are being returned by the snapshot query.
		 * if the id is no longer being returned by the qry (i.e. the query
		 * was edited since this portlet was last saved), then we add it to 
		 * a list of bad fields and report it later.
		 */
	    String[][] arDisplayFlds = GetDisplayFldsFromAdminPref();
	    
		if (0<arDisplayFlds.length)
		{
		    /* will hold names of bad properties */
		    XPStringBuilder sbBadFields = new XPStringBuilder();
		    
		    /* the list of displayble fields on the exp list is in "clsid,objid" format,
		     * we want to use this format to check for bad fields.  we will use a 
		     * string buffer so that we don't have create a bunch of strings, we can 
		     * just minipulate the string buffer */
		    XPStringBuilder sbClsidAndObjid = new XPStringBuilder();
		    sbClsidAndObjid.Append(PT_CLASSIDS.PT_PROPERTY_ID).Append(",");
		    int nPos = sbClsidAndObjid.GetLength();
	
		    /* this is the default rows array for the exp list */
		    Object[][] arFields = new Object[arDisplayFlds.length][SavSrchDisplayFieldsListModel.EXPLIST_COL_MAX];
	
		    /* beginning & ending comma for easy comparisons below */
		    sDisplayableProps = ","+sDisplayableProps+",";
	
		    /* lets loop thru the ids that were stored as admin prefs */
			for (int i=0; i<arDisplayFlds.length; i++)
		    {
				String id = arDisplayFlds[i][0];
				
				//TODO: jhq error check
				IPTProperty prop = null;
				boolean isAccessible = true;
				try
				{
				    prop = (IPTProperty) m_ptSession.GetProperties().Open(XPConvert.ToInteger(id),false);
				}
				catch (Exception e)
				{
				    log.Warn("Display property "+id+" does not exist or is not accessible.");
				    isAccessible = false;
				}
				
				Object name;
				if (null!=prop)
			    {
			    	name = prop.GetLocalizedName();
			    }
				else
				{
				    name = id;
				}
	
				/* stringbuffer holds "clsid,objid", each time replace the objid.
				 * if the "clsid,objid," is not in the list, bad! 
				 * also, we couldn't get access the prop then it's bad (sorta) */
				sbClsidAndObjid.Replace(nPos, sbClsidAndObjid.GetLength(), id).Append(",");
				if (-1==XPStringUtility.IndexOf(sDisplayableProps,sbClsidAndObjid.ToString()) ||
					!isAccessible)
				{
				    sbBadFields.Append(name).Append(", ");
				}
	
				/* create a row for this field (even if it's bad). */
				arFields[i][SavSrchDisplayFieldsListModel.EXPLIST_SORTEDARRAY_PROPID_INDEX] = new Integer(mySelectDisplayFieldsModel.m_nNextIndex);
				mySelectDisplayFieldsModel.m_nNextIndex++;
				
				arFields[i][SavSrchDisplayFieldsListModel.EXPLIST_COL_CLASSID] 		= new Integer(PT_CLASSIDS.PT_PROPERTY_ID);
				arFields[i][SavSrchDisplayFieldsListModel.EXPLIST_COL_OBJECTID]		= id;
				arFields[i][SavSrchDisplayFieldsListModel.EXPLIST_COL_STRING]  		= name;
				arFields[i][SavSrchDisplayFieldsListModel.EXPLIST_COL_ORIENTATION]  = arDisplayFlds[i][1];
		    }
	
			/* add all our rows */
		    mySelectDisplayFieldsModel.SetDefaultObjects(arFields);

			/* if we have bad fields, report */
		    if (0 < sbBadFields.GetLength())
		    {
		        UIError errBadDisplayFields = new UIError(UIErrorLevel.SERIOUS,
		                UIErrorScope.CURRENT_USER, 
		                m_asOwner.GetString(76, ResourceConstants.PORTLETSMSGS)+sbBadFields.Substring(0,sbBadFields.GetLength()-2),
		                "Snapshot Query ID "+m_nSavSrchID+" may have been modifed.  This portlet should either be modified to conform to the query or the query needs to modified.");
		        
		        UIErrorHandler.RaiseError(errBadDisplayFields, 
		                m_asOwner.GetSubSession(), 
		                m_asOwner.GetApplication());
		    }
		}
	}
	
	private String GetSearchableProperties()
	{
		/* only show properties that are searchable */
		Object[][] filter = new Object[3][2];

		filter[0][0]     = new Integer(PT_PROPIDS.PT_PROPID_PROP_SEARCHABLE);
		filter[1][0]     = new Integer(PT_FILTEROPS.PT_FILTEROP_EQ);
		filter[2][0]     = new Integer(1);

		filter[0][1]     = new Integer(PT_PROPIDS.PT_PROPID_ACCESSLEVEL);
		filter[1][1]     = new Integer(PT_FILTEROPS.PT_FILTEROP_GTE);
		filter[2][1]     = new Integer(PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT);

		IPTQueryResult qrSearchableProps = m_ptSession.GetProperties().Query(
		        PT_PROPIDS.PT_PROPID_OBJECTID,
			    -1,
			    PT_PROPIDS.PT_PROPID_NAME,
			    0,-1,filter);
		
		if (null==qrSearchableProps || qrSearchableProps.RowCount()==0)
	    {
	        return "";
	    }
		
		XPStringBuilder sPropsToDisplay = new XPStringBuilder();
		for (int i=0; i<qrSearchableProps.RowCount(); i++)
		{
		    int id = qrSearchableProps.ItemAsInt(i, PT_PROPIDS.PT_PROPID_OBJECTID);
		    sPropsToDisplay.Append(PT_CLASSIDS.PT_PROPERTY_ID);
		    sPropsToDisplay.Append(",");
		    sPropsToDisplay.Append(id);
		    sPropsToDisplay.Append(",");
		}
		
		/* remove the last ',' b4 returning */
		return sPropsToDisplay.Substring(0,sPropsToDisplay.GetLength()-1);
	}

	private String GetDisplayFieldsFromQuery()
	{
		/* 0 is default value when we haven't assigned a saved search to this portlet yet */
		if (0==m_nSavSrchID)
		{
		    return "";
		}
		
		IPTObjectManager ptOM = m_ptSession.GetSavedSearches();
	    IPTSavedSearch ptSnapshot = (IPTSavedSearch) ptOM.Open(m_nSavSrchID, false);
	    
	    Object[] arPropIDs = ptSnapshot.GetReturnProps();
	    if (null==arPropIDs || arPropIDs.length==0)
	    {
	        return "";
	    }
	    
		XPStringBuilder sPropsToDisplay = new XPStringBuilder();
		int userid = m_ptSession.GetSessionInfo().GetCurrentUserID();
		ptOM = m_ptSession.GetProperties();
		
	    for (int i=0; i<arPropIDs.length; i++)
	    {
	        int propid = XPConvert.ToInteger(arPropIDs[i]);
	        if (ptOM.IsObjectAccessible(propid, userid, PT_ACCESS_LEVELS.PT_ACCESS_LEVEL_SELECT))
	        {
		        sPropsToDisplay.Append(PT_CLASSIDS.PT_PROPERTY_ID);
			    sPropsToDisplay.Append(",");
			    sPropsToDisplay.Append(propid);
			    sPropsToDisplay.Append(",");
	        }
	    }
	    
		if (0<sPropsToDisplay.GetLength())
		{
		    /* remove the last ',' b4 returning */
		    return sPropsToDisplay.Substring(0,sPropsToDisplay.GetLength()-1);
		}
		else
		{
		    return "";
		}
	}
	
	private String[][] GetDisplayFldsFromAdminPref()
	{
	    String[][] arFieldIDs;
	    
	    String sPref = (String) GetSettingValue(
	            IntrinsicPortletPrefsEditorModel.SETTINGSTYPE_ADMIN, 
	            SavedSearchPortletModel.ADMIN_PREF_DISPLAY_FIELDS);

	    if (null==sPref)
	    {
	        arFieldIDs = new String[0][0];
	        return arFieldIDs;
	    }
	    
	    XPStringTokenizer st = new XPStringTokenizer(sPref,",");
	    arFieldIDs = new String[st.GetTokenCount()][2];
	    
		for (int i=0; st.HasMoreElements(); i++) 
		{
		    String sIDandOrient = st.GetNextElement();
		    arFieldIDs[i][0] = XPStringUtility.Substring(sIDandOrient, 0, sIDandOrient.length()-1);
		    arFieldIDs[i][1] = XPStringUtility.Substring(sIDandOrient, sIDandOrient.length()-1);
        }                                                
	    
		return arFieldIDs;
	}

	private String GetDisplayFldsAndOrientFromExpList()
	{
		ExpListModel model = (ExpListModel) m_asOwner.
			GetModel(SavedSearchPortletPrefsEditorAS.STR_MVC_SELECT_DISPLAY_FIELDS);

		PTGrowableSortedArrayWrapper saItems = model.GetItems();
		if (0==saItems.GetCount())
		{
		    return "";
		}
		
		XPStringBuilder sbDisplayFields = new XPStringBuilder();
		for (int i=0; i<saItems.GetCount(); i++) 
		{
		    sbDisplayFields
		    	.Append(saItems.GetItem(i,SavSrchDisplayFieldsListModel.EXPLIST_COL_OBJECTID))
		    	.Append(saItems.GetItem(i,SavSrchDisplayFieldsListModel.EXPLIST_COL_ORIENTATION))
		    	.Append(",");
        }                                                
	    
		/* remove the last ',' b4 returning */
		return sbDisplayFields.Substring(0,sbDisplayFields.GetLength()-1);
	}

	private String GetParametericFieldsFromExpList()
	{
		ExpListModel model = (ExpListModel) m_asOwner.
			GetModel(SavedSearchPortletPrefsEditorAS.STR_MVC_SELECT_PARAMETRIC_FIELDS);

		PTGrowableSortedArrayWrapper saItems = model.GetItems();
		if (0==saItems.GetCount())
		{
		    return "";
		}
		
		XPStringBuilder sbFields = new XPStringBuilder();
		for (int i=0; i<saItems.GetCount(); i++) 
		{
		    sbFields
		    	.Append(saItems.GetItem(i,SelectPTObjectModel.EXPLIST_COL_OBJECTID))
		    	.Append(",");
        }                                                
	    
		/* remove the last ',' b4 returning */
		return sbFields.Substring(0,sbFields.GetLength()-1);
	}
}